package Geo::Coordinates::OSTN02;
require Exporter;
use strict;
use warnings;

our @ISA = qw(Exporter);
our $VERSION = '2.01';
our @EXPORT = qw();
our @EXPORT_OK = qw(
    OSGB36_to_ETRS89
    ETRS89_to_OSGB36
);

# OSTN02 Data (lots of it...)
our @ostn_data = <DATA>;
our %ostn_shift_for=();

sub ETRS89_to_OSGB36 {
    return unless defined wantarray;

    my ($x,  $y,  $z ) = (@_, 0);
    my ($dx, $dy, $dz) = _find_OSTN02_shifts_at($x,$y);

    ($x, $y, $z) = _round_to_nearest_mm($x+$dx, $y+$dy, $z-$dz);

    return ($x, $y, $z) if wantarray;
    return "$x $y $z";
}

sub OSGB36_to_ETRS89 {
    return unless defined wantarray;

    my $epsilon = 0.00001;
    my ($x0, $y0, $z0) = (@_, 0);
    my ($dx, $dy, $dz) = _find_OSTN02_shifts_at($x0,$y0);
    my ($x,  $y,  $z ) = ($x0-$dx, $y0-$dy, $z0+$dz);
    my ($last_dx, $last_dy) = ($dx, $dy);
    APPROX:
    while (1) {
        ($dx, $dy, $dz) = _find_OSTN02_shifts_at($x,$y);
        ($x, $y) = ($x0-$dx, $y0-$dy);
        last APPROX if abs($dx-$last_dx)<$epsilon && abs($dy-$last_dy)<$epsilon;
        ($last_dx, $last_dy) = ($dx, $dy);
    }

    ($x, $y, $z) = _round_to_nearest_mm($x0-$dx, $y0-$dy, $z0+$dz);

    return ($x, $y, $z) if wantarray;
    return "$x $y $z";
}

sub _round_to_nearest_mm {
    my ($x,  $y,  $z ) = @_;
    $x = int($x*1000+0.5)/1000;
    $y = int($y*1000+0.5)/1000;
    $z = int($z*1000+0.5)/1000;
    return ($x, $y, $z);
}

sub _find_OSTN02_shifts_at {

    my ($x, $y) = @_;

    my $e_index = int($x/1000);
    my $n_index = int($y/1000);

    my $x0 = $e_index * 1000;
    my $y0 = $n_index * 1000;

    my $s0_ref = _get_ostn_ref($e_index+0, $n_index+0) || die "OSTN not defined for $x $y\n";
    my $s1_ref = _get_ostn_ref($e_index+1, $n_index+0) || die "OSTN not defined for $x $y\n";
    my $s2_ref = _get_ostn_ref($e_index+1, $n_index+1) || die "OSTN not defined for $x $y\n";
    my $s3_ref = _get_ostn_ref($e_index+0, $n_index+1) || die "OSTN not defined for $x $y\n";

    my $dx = $x - $x0; # offset within square
    my $dy = $y - $y0;

    my $t = $dx/1000;
    my $u = $dy/1000;

    my $f0 = (1-$t)*(1-$u);
    my $f1 =    $t *(1-$u);
    my $f2 =    $t *   $u ;
    my $f3 = (1-$t)*   $u ;

    my $se = $f0*$s0_ref->[0] + $f1*$s1_ref->[0] + $f2*$s2_ref->[0] + $f3*$s3_ref->[0];
    my $sn = $f0*$s0_ref->[1] + $f1*$s1_ref->[1] + $f2*$s2_ref->[1] + $f3*$s3_ref->[1];
    my $sg = $f0*$s0_ref->[2] + $f1*$s1_ref->[2] + $f2*$s2_ref->[2] + $f3*$s3_ref->[2];

    return ($se, $sn, $sg);

}

sub _get_ostn_ref {
    my $x = shift;
    my $y = shift;
    my $key = $x + ($y*701) + 1;

    return $ostn_shift_for{$key} if exists $ostn_shift_for{$key};

    my $lo = 0;
    my $hi = @ostn_data;
    my $mid;
    while (1) {
        $mid = ($hi+$lo)/2;
        my ($k, @data) = split ' ', $ostn_data[$mid];
        $ostn_shift_for{$k} = \@data;
        last        if $k == $key;
        $lo = $mid  if $k  < $key;
        $hi = $mid  if $k  > $key;
    }

    return $ostn_shift_for{$key};
}

=head1 NAME

Geo::Coordinates::OSTN02 -- Implement the OSTN02 transformation

Version: 2.00

=head1 SYNOPSIS

  use Geo::Coordinates::OSTN02 qw/OSGB36_to_ETRS89 ETRS89_to_OSGB36/;

  ($x, $y, $z) = OSGB36_to_ETRS89($e, $n, $h);
  ($e, $n, $h) = ETRS89_to_OSGB36($x, $y, $z);

=head1 DESCRIPTION

The purpose and use of these modules is described briefly in the companion
L<Geo::Coordinates::OSGB> modules.  In essence they implement in Perl the
Ordnance Survey's OSTN02 transformation which is part of the current
definition of the British National Grid.  You are strongly recommended to
read the official public guides and other introductory documents that are
published by the Ordnance Survey of Great Britain with a wealth of other
technical information about the OSTN02 transformation.  The best starting
point on the web is
http://www.ordnancesurvey.co.uk/oswebsite/gps/information/index.html

=head1 FUNCTIONS

The following functions can be exported from the C<Geo::Coordinates::OSTN02>
module:

    OSGB36_to_ETRS89
    ETRS89_to_OSGB36

None is exported by default.

=over 4

=item OSGB36_to_ETRS89(easting, northing, [elevation])

Transforms from normal OSGB36 grid references to a pseudo-grid based on the WGS84/ETRS89 geoid
model, which can then be translated to lat/long coordinates using C<grid_to_ll()> with the 'WGS84'
parameter.

   my $elevation = '100'; # in metres
   my ($e, $n) = parse_grid_trad('TQ304293');
   my ($x, $y, $z) = OSGB36_to_ETRS89($e, $n, $elevation);
   my ($lat, $lon) = grid_to_ll($x, $y, 'ETRS89'); # or you can say 'WGS84' if you like - same thing

Elevation will default to 0 metres if you omit it.

=item ETRS89_to_OSGB36(x, y, [z])

Transforms WGS84/ETRS89 pseudo-grid coordinates into OSGB36 grid references.

  my ($lat, $lon, $height) = (51.5, -1, 10); # Somewhere in London
  my ($x, $y) = ll_to_grid($lat, $lon, 'ETRS89'); # or 'WGS84'
  my ($e, $n, $elevation) = ETRS89_to_OSGB36($x, $y, $height);

=back

=head1 BUGS

Please report any to toby@cpan.org

=head1 EXAMPLES

See the test routines included in the distribution.

=head1 AUTHOR

Toby Thurston ---  4 Sep 2007

web: http://www.wildfire.dircon.co.uk

=head1 SEE ALSO

See L<Geo::Coordinates::OSGB> for the main routines.

=cut

1;
__DATA__
80  91.888  -81.603  53.184  2
81  91.903  -81.597  53.178  2
82  91.917  -81.592  53.173  2
83  91.936  -81.582  53.168  2
84  91.956  -81.569  53.164  2
85  91.976  -81.557  53.160  2
86  91.996  -81.545  53.157  2
87  92.016  -81.534  53.154  2
88  92.035  -81.522  53.151  2
89  92.056  -81.510  53.148  2
90  92.076  -81.497  53.143  2
91  92.096  -81.485  53.139  2
92  92.116  -81.473  53.135  2
93  92.139  -81.462  53.131  2
94  92.163  -81.450  53.127  2
95  92.188  -81.439  53.123  2
96  92.212  -81.428  53.117  2
97  92.236  -81.416  53.112  2
98  92.261  -81.405  53.105  2
99  92.285  -81.394  53.098  2
100  92.310  -81.382  53.092  2
780  91.873  -81.579  53.192  2
781  91.887  -81.574  53.184  2
782  91.902  -81.569  53.178  2
783  91.916  -81.563  53.172  2
784  91.932  -81.557  53.167  2
785  91.951  -81.545  53.162  2
786  91.971  -81.533  53.158  2
787  91.992  -81.521  53.155  2
788  92.012  -81.509  53.152  2
789  92.031  -81.497  53.148  2
790  92.052  -81.484  53.145  2
791  92.072  -81.473  53.140  2
792  92.091  -81.461  53.136  2
793  92.115  -81.450  53.132  2
794  92.140  -81.437  53.128  2
795  92.164  -81.426  53.124  2
796  92.189  -81.415  53.119  2
797  92.213  -81.403  53.114  2
798  92.237  -81.392  53.108  2
799  92.262  -81.381  53.102  2
800  92.286  -81.369  53.094  2
801  92.311  -81.358  53.089  2
802  92.336  -81.347  53.082  2
1480  91.858  -81.556  53.201  2
1481  91.872  -81.550  53.193  2
1482  91.887  -81.545  53.185  2
1483  91.901  -81.540  53.179  2
1484  91.916  -81.535  53.172  2
1485  91.930  -81.529  53.166  2
1486  91.947  -81.520  53.161  2
1487  91.967  -81.508  53.157  2
1488  91.988  -81.496  53.154  2
1489  92.007  -81.484  53.150  2
1490  92.027  -81.472  53.146  2
1491  92.048  -81.460  53.143  2
1492  92.068  -81.448  53.137  2
1493  92.092  -81.437  53.133  2
1494  92.117  -81.425  53.129  2
1495  92.141  -81.414  53.124  2
1496  92.165  -81.403  53.120  2
1497  92.190  -81.391  53.116  2
1498  92.214  -81.380  53.110  2
1499  92.239  -81.368  53.105  2
1500  92.263  -81.356  53.098  2
1501  92.288  -81.345  53.091  2
1502  92.312  -81.334  53.085  2
1503  92.337  -81.322  53.079  2
1504  92.356  -81.315  53.072  2
1569  93.499  -80.739  53.060  1
1570  93.513  -80.729  53.056  1
1571  93.520  -80.719  53.050  1
1572  93.528  -80.709  53.045  1
2181  91.857  -81.527  53.204  2
2182  91.872  -81.522  53.195  2
2183  91.886  -81.516  53.187  2
2184  91.900  -81.511  53.180  2
2185  91.915  -81.506  53.173  2
2186  91.929  -81.500  53.167  2
2187  91.944  -81.495  53.161  2
2188  91.963  -81.484  53.157  2
2189  91.984  -81.472  53.152  2
2190  92.003  -81.459  53.148  2
2191  92.023  -81.447  53.144  2
2192  92.044  -81.435  53.140  2
2193  92.069  -81.424  53.135  2
2194  92.093  -81.412  53.130  2
2195  92.118  -81.401  53.126  2
2196  92.142  -81.390  53.121  2
2197  92.166  -81.378  53.117  2
2198  92.191  -81.367  53.112  2
2199  92.215  -81.356  53.106  2
2200  92.240  -81.344  53.101  2
2201  92.264  -81.333  53.094  2
2202  92.289  -81.321  53.088  2
2203  92.313  -81.310  53.082  2
2204  92.333  -81.302  53.075  2
2205  92.351  -81.294  53.069  2
2206  92.369  -81.287  53.061  2
2226  92.739  -81.134  53.425  1
2227  92.758  -81.127  53.415  1
2228  92.776  -81.118  53.405  1
2229  92.794  -81.111  53.394  1
2230  92.813  -81.103  53.384  1
2269  93.478  -80.729  53.068  1
2270  93.494  -80.718  53.063  1
2271  93.510  -80.707  53.058  1
2272  93.518  -80.698  53.053  1
2273  93.525  -80.688  53.048  1
2274  93.533  -80.678  53.042  1
2275  93.540  -80.667  53.037  1
2276  93.547  -80.657  53.032  1
2277  93.554  -80.648  53.026  1
2278  93.561  -80.638  53.019  1
2279  93.568  -80.628  53.011  1
2280  93.575  -80.618  53.003  1
2881  91.843  -81.503  53.219  2
2882  91.857  -81.497  53.208  2
2883  91.871  -81.492  53.198  2
2884  91.885  -81.487  53.189  2
2885  91.900  -81.481  53.182  2
2886  91.915  -81.476  53.174  2
2887  91.929  -81.472  53.168  2
2888  91.943  -81.466  53.162  2
2889  91.959  -81.459  53.157  2
2890  91.979  -81.447  53.152  2
2891  91.999  -81.434  53.147  2
2892  92.021  -81.423  53.143  2
2893  92.045  -81.412  53.139  2
2894  92.070  -81.400  53.133  2
2895  92.094  -81.389  53.128  2
2896  92.119  -81.377  53.123  2
2897  92.143  -81.365  53.118  2
2898  92.167  -81.354  53.113  2
2899  92.192  -81.343  53.108  2
2900  92.217  -81.331  53.103  2
2901  92.241  -81.320  53.097  2
2902  92.266  -81.309  53.091  2
2903  92.290  -81.297  53.084  2
2904  92.309  -81.289  53.078  2
2905  92.328  -81.281  53.072  2
2906  92.346  -81.274  53.065  2
2907  92.365  -81.266  53.058  2
2926  92.716  -81.121  53.429  1
2927  92.734  -81.114  53.419  1
2928  92.753  -81.106  53.409  1
2929  92.771  -81.099  53.397  1
2930  92.790  -81.091  53.387  1
2931  92.808  -81.083  53.377  1
2932  92.827  -81.075  53.366  1
2933  92.845  -81.068  53.357  1
2934  92.864  -81.060  53.347  1
2935  92.882  -81.052  53.338  1
2936  92.901  -81.045  53.329  1
2969  93.457  -80.718  53.075  1
2970  93.473  -80.708  53.070  1
2971  93.489  -80.698  53.065  1
2972  93.505  -80.687  53.060  1
2973  93.516  -80.676  53.056  1
2974  93.523  -80.667  53.051  1
2975  93.531  -80.657  53.046  1
2976  93.538  -80.647  53.040  1
2977  93.545  -80.636  53.035  1
2978  93.552  -80.626  53.029  1
2979  93.559  -80.616  53.022  1
2980  93.566  -80.607  53.015  1
2981  93.573  -80.597  53.007  1
2982  93.579  -80.586  52.999  1
2983  93.586  -80.576  52.991  1
3581  91.827  -81.479  53.239  2
3582  91.842  -81.474  53.226  2
3583  91.856  -81.469  53.214  2
3584  91.871  -81.463  53.203  2
3585  91.885  -81.458  53.193  2
3586  91.899  -81.453  53.185  2
3587  91.914  -81.447  53.177  2
3588  91.928  -81.442  53.170  2
3589  91.943  -81.437  53.163  2
3590  91.957  -81.431  53.157  2
3591  91.975  -81.422  53.152  2
3592  91.997  -81.410  53.147  2
3593  92.022  -81.399  53.142  2
3594  92.047  -81.387  53.137  2
3595  92.071  -81.376  53.132  2
3596  92.095  -81.365  53.127  2
3597  92.120  -81.353  53.121  2
3598  92.144  -81.342  53.116  2
3599  92.169  -81.331  53.110  2
3600  92.193  -81.319  53.105  2
3601  92.218  -81.308  53.099  2
3602  92.242  -81.296  53.094  2
3603  92.267  -81.284  53.087  2
3604  92.286  -81.276  53.080  2
3605  92.305  -81.268  53.074  2
3606  92.323  -81.261  53.068  2
3607  92.342  -81.253  53.061  2
3608  92.360  -81.246  53.054  2
3609  92.379  -81.238  53.047  2
3626  92.693  -81.108  53.434  1
3627  92.711  -81.101  53.423  1
3628  92.730  -81.093  53.413  1
3629  92.748  -81.086  53.402  1
3630  92.767  -81.078  53.391  1
3631  92.785  -81.071  53.380  1
3632  92.804  -81.063  53.369  1
3633  92.822  -81.055  53.359  1
3634  92.841  -81.048  53.349  1
3635  92.859  -81.039  53.339  1
3636  92.877  -81.032  53.329  1
3637  92.896  -81.024  53.320  1
3638  92.915  -81.017  53.310  1
3639  92.933  -81.009  53.301  1
3669  93.435  -80.708  53.079  1
3670  93.451  -80.698  53.075  1
3671  93.468  -80.687  53.072  1
3672  93.484  -80.676  53.067  1
3673  93.500  -80.666  53.062  1
3674  93.514  -80.655  53.058  1
3675  93.521  -80.645  53.054  1
3676  93.529  -80.635  53.049  1
3677  93.536  -80.626  53.043  1
3678  93.543  -80.615  53.037  1
3679  93.550  -80.605  53.031  1
3680  93.557  -80.595  53.024  1
3681  93.564  -80.585  53.017  1
3682  93.571  -80.576  53.010  1
3683  93.577  -80.565  53.002  1
3684  93.584  -80.555  52.994  1
3685  93.591  -80.545  52.985  1
4282  91.827  -81.450  53.247  2
4283  91.841  -81.445  53.233  2
4284  91.856  -81.440  53.221  2
4285  91.870  -81.434  53.209  2
4286  91.884  -81.429  53.199  2
4287  91.899  -81.424  53.189  2
4288  91.913  -81.419  53.180  2
4289  91.928  -81.413  53.173  2
4290  91.942  -81.408  53.166  2
4291  91.956  -81.403  53.159  2
4292  91.974  -81.398  53.153  2
4293  91.999  -81.386  53.147  2
4294  92.023  -81.375  53.142  2
4295  92.048  -81.363  53.137  2
4296  92.072  -81.352  53.131  2
4297  92.096  -81.340  53.125  2
4298  92.121  -81.329  53.119  2
4299  92.145  -81.318  53.114  2
4300  92.170  -81.306  53.108  2
4301  92.195  -81.295  53.102  2
4302  92.219  -81.284  53.096  2
4303  92.243  -81.272  53.090  2
4304  92.263  -81.263  53.084  2
4305  92.282  -81.256  53.076  2
4306  92.300  -81.248  53.070  2
4307  92.319  -81.240  53.064  2
4308  92.337  -81.233  53.058  2
4309  92.356  -81.225  53.051  2
4310  92.374  -81.218  53.044  2
4311  92.392  -81.210  53.037  2
4327  92.688  -81.088  53.429  1
4328  92.707  -81.080  53.417  1
4329  92.725  -81.073  53.406  1
4330  92.743  -81.065  53.395  1
4331  92.762  -81.058  53.384  1
4332  92.781  -81.050  53.373  1
4333  92.799  -81.043  53.361  1
4334  92.817  -81.035  53.351  1
4335  92.836  -81.027  53.340  1
4336  92.855  -81.020  53.329  1
4337  92.873  -81.012  53.320  1
4338  92.892  -81.004  53.309  1
4339  92.910  -80.996  53.300  1
4340  92.928  -80.989  53.291  1
4369  93.414  -80.698  53.081  1
4370  93.430  -80.687  53.078  1
4371  93.446  -80.676  53.075  1
4372  93.463  -80.666  53.071  1
4373  93.479  -80.655  53.068  1
4374  93.495  -80.645  53.064  1
4375  93.512  -80.634  53.060  1
4376  93.519  -80.624  53.055  1
4377  93.526  -80.614  53.051  1
4378  93.534  -80.604  53.045  1
4379  93.541  -80.594  53.039  1
4380  93.548  -80.584  53.033  1
4381  93.555  -80.574  53.026  1
4382  93.562  -80.564  53.019  1
4383  93.569  -80.554  53.011  1
4384  93.575  -80.544  53.003  1
4385  93.582  -80.534  52.995  1
4386  93.589  -80.524  52.986  1
4387  93.593  -80.519  52.977  1
4983  91.826  -81.422  53.257  2
4984  91.841  -81.416  53.242  2
4985  91.855  -81.411  53.228  2
4986  91.869  -81.406  53.216  2
4987  91.884  -81.400  53.205  2
4988  91.898  -81.395  53.195  2
4989  91.913  -81.390  53.185  2
4990  91.927  -81.384  53.177  2
4991  91.940  -81.378  53.169  2
4992  91.954  -81.373  53.162  2
4993  91.968  -81.367  53.155  2
4994  92.000  -81.363  53.149  2
4995  92.024  -81.351  53.142  2
4996  92.049  -81.340  53.137  2
4997  92.073  -81.328  53.131  2
4998  92.097  -81.316  53.124  2
4999  92.122  -81.305  53.118  2
5000  92.147  -81.293  53.112  2
5001  92.171  -81.282  53.106  2
5002  92.196  -81.271  53.100  2
5003  92.220  -81.259  53.093  2
5004  92.240  -81.251  53.086  2
5005  92.259  -81.243  53.080  2
5006  92.277  -81.236  53.072  2
5007  92.296  -81.228  53.065  2
5008  92.314  -81.220  53.059  2
5009  92.333  -81.212  53.054  2
5010  92.351  -81.205  53.047  2
5011  92.369  -81.197  53.040  2
5012  92.388  -81.190  53.033  2
5027  92.665  -81.075  53.435  1
5028  92.684  -81.068  53.423  1
5029  92.702  -81.060  53.411  1
5030  92.721  -81.052  53.400  1
5031  92.739  -81.045  53.388  1
5032  92.758  -81.037  53.376  1
5033  92.776  -81.030  53.364  1
5034  92.794  -81.022  53.352  1
5035  92.813  -81.014  53.341  1
5036  92.832  -81.007  53.330  1
5037  92.850  -80.999  53.320  1
5038  92.868  -80.992  53.309  1
5039  92.887  -80.984  53.299  1
5040  92.905  -80.977  53.289  1
5041  92.924  -80.968  53.280  1
5042  92.942  -80.961  53.271  1
5069  93.392  -80.687  53.082  1
5070  93.409  -80.676  53.078  1
5071  93.425  -80.666  53.076  1
5072  93.441  -80.655  53.073  1
5073  93.458  -80.645  53.070  1
5074  93.474  -80.634  53.067  1
5075  93.490  -80.624  53.065  1
5076  93.507  -80.613  53.061  1
5077  93.517  -80.603  53.056  1
5078  93.524  -80.593  53.052  1
5079  93.532  -80.583  53.046  1
5080  93.539  -80.573  53.041  1
5081  93.546  -80.563  53.035  1
5082  93.553  -80.553  53.028  1
5083  93.560  -80.543  53.021  1
5084  93.567  -80.533  53.013  1
5085  93.573  -80.523  53.005  1
5086  93.580  -80.514  52.997  1
5087  93.583  -80.510  52.988  1
5088  93.586  -80.504  52.979  1
5089  93.590  -80.500  52.970  1
5090  93.593  -80.495  52.961  1
5683  91.811  -81.398  53.286  2
5684  91.825  -81.393  53.269  2
5685  91.840  -81.387  53.253  2
5686  91.855  -81.382  53.238  2
5687  91.869  -81.377  53.225  2
5688  91.883  -81.371  53.213  2
5689  91.896  -81.365  53.202  2
5690  91.911  -81.359  53.192  2
5691  91.925  -81.354  53.182  2
5692  91.939  -81.349  53.174  2
5693  91.953  -81.343  53.165  2
5694  91.966  -81.337  53.158  2
5695  92.000  -81.339  53.151  2
5696  92.026  -81.328  53.144  2
5697  92.050  -81.315  53.137  2
5698  92.074  -81.304  53.131  2
5699  92.099  -81.293  53.124  2
5700  92.123  -81.281  53.117  2
5701  92.148  -81.270  53.110  2
5702  92.172  -81.259  53.104  2
5703  92.197  -81.247  53.098  2
5704  92.217  -81.238  53.090  2
5705  92.236  -81.231  53.083  2
5706  92.254  -81.223  53.076  2
5707  92.273  -81.215  53.069  2
5708  92.291  -81.208  53.062  2
5709  92.309  -81.200  53.055  2
5710  92.328  -81.192  53.049  2
5711  92.347  -81.184  53.042  2
5712  92.365  -81.177  53.036  2
5713  92.383  -81.169  53.030  2
5727  92.642  -81.062  53.441  1
5728  92.660  -81.055  53.429  1
5729  92.679  -81.047  53.416  1
5730  92.698  -81.039  53.404  1
5731  92.716  -81.032  53.392  1
5732  92.734  -81.024  53.380  1
5733  92.753  -81.017  53.368  1
5734  92.772  -81.009  53.355  1
5735  92.790  -81.002  53.343  1
5736  92.808  -80.994  53.331  1
5737  92.827  -80.986  53.320  1
5738  92.845  -80.979  53.309  1
5739  92.864  -80.971  53.298  1
5740  92.882  -80.964  53.288  1
5741  92.901  -80.956  53.278  1
5742  92.919  -80.949  53.268  1
5743  92.938  -80.941  53.260  1
5769  93.371  -80.676  53.081  1
5770  93.387  -80.667  53.077  1
5771  93.404  -80.656  53.074  1
5772  93.420  -80.645  53.071  1
5773  93.436  -80.635  53.069  1
5774  93.452  -80.624  53.067  1
5775  93.469  -80.613  53.064  1
5776  93.485  -80.603  53.063  1
5777  93.502  -80.592  53.061  1
5778  93.515  -80.582  53.057  1
5779  93.522  -80.572  53.052  1
5780  93.530  -80.562  53.047  1
5781  93.537  -80.552  53.042  1
5782  93.544  -80.541  53.035  1
5783  93.551  -80.532  53.029  1
5784  93.558  -80.522  53.022  1
5785  93.565  -80.512  53.015  1
5786  93.570  -80.504  53.006  1
5787  93.573  -80.500  52.998  1
5788  93.576  -80.495  52.989  1
5789  93.580  -80.490  52.980  1
5790  93.583  -80.485  52.971  1
5791  93.586  -80.481  52.962  1
5792  93.590  -80.476  52.953  1
6384  91.811  -81.369  53.300  2
6385  91.825  -81.364  53.282  2
6386  91.839  -81.358  53.265  2
6387  91.853  -81.353  53.249  2
6388  91.867  -81.347  53.235  2
6389  91.881  -81.341  53.222  2
6390  91.895  -81.335  53.210  2
6391  91.909  -81.330  53.199  2
6392  91.923  -81.325  53.189  2
6393  91.937  -81.318  53.179  2
6394  91.951  -81.313  53.170  2
6395  91.965  -81.307  53.161  2
6396  91.985  -81.304  53.154  2
6397  92.028  -81.306  53.146  2
6398  92.052  -81.293  53.139  2
6399  92.076  -81.281  53.132  2
6400  92.100  -81.268  53.124  2
6401  92.125  -81.257  53.116  2
6402  92.149  -81.246  53.109  2
6403  92.173  -81.234  53.103  2
6404  92.194  -81.225  53.095  2
6405  92.213  -81.218  53.088  2
6406  92.231  -81.210  53.080  2
6407  92.249  -81.202  53.073  2
6408  92.268  -81.195  53.065  2
6409  92.286  -81.187  53.058  2
6410  92.305  -81.180  53.051  2
6411  92.323  -81.172  53.045  2
6412  92.342  -81.165  53.039  2
6413  92.360  -81.156  53.032  2
6414  92.379  -81.149  53.026  2
6415  92.398  -81.141  53.018  2
6428  92.638  -81.043  53.436  1
6429  92.656  -81.035  53.423  1
6430  92.674  -81.027  53.409  1
6431  92.693  -81.019  53.397  1
6432  92.711  -81.011  53.384  1
6433  92.730  -81.004  53.371  1
6434  92.748  -80.996  53.359  1
6435  92.767  -80.989  53.346  1
6436  92.785  -80.981  53.333  1
6437  92.804  -80.974  53.321  1
6438  92.822  -80.966  53.309  1
6439  92.841  -80.958  53.298  1
6440  92.859  -80.951  53.287  1
6441  92.878  -80.943  53.277  1
6442  92.896  -80.936  53.267  1
6443  92.915  -80.928  53.257  1
6444  92.933  -80.920  53.248  1
6445  92.951  -80.913  53.240  1
6470  93.366  -80.656  53.074  1
6471  93.382  -80.645  53.071  1
6472  93.399  -80.635  53.069  1
6473  93.415  -80.624  53.066  1
6474  93.431  -80.613  53.065  1
6475  93.447  -80.603  53.063  1
6476  93.464  -80.592  53.062  1
6477  93.480  -80.582  53.061  1
6478  93.497  -80.571  53.058  1
6479  93.513  -80.560  53.055  1
6480  93.520  -80.551  53.052  1
6481  93.528  -80.541  53.047  1
6482  93.535  -80.531  53.042  1
6483  93.542  -80.520  53.036  1
6484  93.549  -80.510  53.029  1
6485  93.556  -80.500  53.022  1
6486  93.560  -80.494  53.015  1
6487  93.563  -80.490  53.007  1
6488  93.567  -80.485  52.998  1
6489  93.570  -80.481  52.990  1
6490  93.573  -80.475  52.981  1
6491  93.576  -80.471  52.972  1
6492  93.580  -80.466  52.963  1
6493  93.583  -80.462  52.954  1
6494  93.586  -80.457  52.944  1
7085  91.809  -81.340  53.315  2
7086  91.823  -81.334  53.297  2
7087  91.837  -81.328  53.279  2
7088  91.851  -81.322  53.262  2
7089  91.865  -81.317  53.247  2
7090  91.879  -81.311  53.233  2
7091  91.893  -81.306  53.220  2
7092  91.907  -81.300  53.208  2
7093  91.921  -81.294  53.197  2
7094  91.935  -81.289  53.186  2
7095  91.949  -81.283  53.176  2
7096  91.963  -81.278  53.166  2
7097  91.977  -81.271  53.158  2
7098  92.024  -81.279  53.150  2
7099  92.054  -81.271  53.142  2
7100  92.078  -81.259  53.134  2
7101  92.102  -81.246  53.125  2
7102  92.126  -81.234  53.117  2
7103  92.150  -81.221  53.109  2
7104  92.171  -81.212  53.101  2
7105  92.190  -81.205  53.094  2
7106  92.208  -81.197  53.086  2
7107  92.226  -81.190  53.078  2
7108  92.245  -81.182  53.070  2
7109  92.264  -81.174  53.062  2
7110  92.282  -81.167  53.055  2
7111  92.300  -81.159  53.048  2
7112  92.319  -81.152  53.042  2
7113  92.337  -81.144  53.035  2
7114  92.356  -81.137  53.028  2
7115  92.374  -81.129  53.022  2
7116  92.392  -81.121  53.015  2
7129  92.633  -81.022  53.430  1
7130  92.651  -81.014  53.417  1
7131  92.670  -81.007  53.403  1
7132  92.689  -80.999  53.390  1
7133  92.707  -80.991  53.377  1
7134  92.725  -80.983  53.363  1
7135  92.744  -80.976  53.350  1
7136  92.762  -80.968  53.336  1
7137  92.781  -80.961  53.322  1
7138  92.799  -80.953  53.311  1
7139  92.817  -80.945  53.299  1
7140  92.836  -80.938  53.287  1
7141  92.855  -80.930  53.276  1
7142  92.873  -80.923  53.265  1
7143  92.892  -80.915  53.255  1
7144  92.910  -80.908  53.245  1
7145  92.928  -80.900  53.236  1
7146  92.947  -80.892  53.227  1
7170  93.345  -80.645  53.069  1
7171  93.361  -80.635  53.067  1
7172  93.377  -80.624  53.065  1
7173  93.394  -80.613  53.063  1
7174  93.410  -80.603  53.061  1
7175  93.426  -80.592  53.060  1
7176  93.442  -80.582  53.059  1
7177  93.459  -80.571  53.059  1
7178  93.475  -80.560  53.057  1
7179  93.492  -80.550  53.056  1
7180  93.508  -80.540  53.054  1
7181  93.518  -80.529  53.050  1
7182  93.525  -80.519  53.046  1
7183  93.533  -80.510  53.041  1
7184  93.540  -80.499  53.035  1
7185  93.547  -80.489  53.029  1
7186  93.550  -80.485  53.022  1
7187  93.553  -80.480  53.015  1
7188  93.557  -80.475  53.007  1
7189  93.560  -80.471  52.999  1
7190  93.563  -80.466  52.990  1
7191  93.567  -80.461  52.981  1
7192  93.570  -80.457  52.972  1
7193  93.573  -80.452  52.963  1
7194  93.577  -80.447  52.955  1
7195  93.580  -80.443  52.945  1
7196  93.583  -80.438  52.935  1
7786  91.807  -81.309  53.333  2
7787  91.821  -81.304  53.314  2
7788  91.835  -81.298  53.295  2
7789  91.849  -81.293  53.277  2
7790  91.863  -81.287  53.261  2
7791  91.877  -81.281  53.246  2
7792  91.891  -81.275  53.232  2
7793  91.905  -81.270  53.219  2
7794  91.919  -81.265  53.206  2
7795  91.933  -81.259  53.194  2
7796  91.947  -81.253  53.183  2
7797  91.961  -81.247  53.173  2
7798  91.975  -81.242  53.164  2
7799  92.009  -81.244  53.155  2
7800  92.056  -81.249  53.146  2
7801  92.079  -81.236  53.137  2
7802  92.103  -81.224  53.128  2
7803  92.128  -81.212  53.120  2
7804  92.147  -81.199  53.111  2
7805  92.165  -81.191  53.103  2
7806  92.185  -81.184  53.094  2
7807  92.203  -81.177  53.085  2
7808  92.222  -81.169  53.077  2
7809  92.240  -81.162  53.068  2
7810  92.259  -81.154  53.060  2
7811  92.277  -81.146  53.053  2
7812  92.296  -81.139  53.046  2
7813  92.314  -81.131  53.039  2
7814  92.333  -81.124  53.032  2
7815  92.351  -81.116  53.026  2
7816  92.370  -81.108  53.019  2
7817  92.388  -81.101  53.012  2
7830  92.628  -81.002  53.425  1
7831  92.647  -80.994  53.411  1
7832  92.665  -80.986  53.396  1
7833  92.684  -80.979  53.382  1
7834  92.702  -80.971  53.369  1
7835  92.721  -80.964  53.355  1
7836  92.739  -80.955  53.341  1
7837  92.758  -80.948  53.327  1
7838  92.776  -80.940  53.313  1
7839  92.795  -80.933  53.300  1
7840  92.813  -80.925  53.288  1
7841  92.832  -80.917  53.275  1
7842  92.850  -80.910  53.264  1
7843  92.868  -80.902  53.253  1
7844  92.887  -80.895  53.243  1
7845  92.906  -80.887  53.233  1
7846  92.924  -80.880  53.223  1
7847  92.942  -80.872  53.214  1
7848  92.961  -80.864  53.206  1
7870  93.323  -80.635  53.064  1
7871  93.339  -80.624  53.062  1
7872  93.356  -80.613  53.059  1
7873  93.372  -80.603  53.057  1
7874  93.389  -80.592  53.056  1
7875  93.405  -80.582  53.055  1
7876  93.421  -80.572  53.054  1
7877  93.437  -80.561  53.054  1
7878  93.454  -80.551  53.054  1
7879  93.470  -80.540  53.053  1
7880  93.487  -80.529  53.053  1
7881  93.503  -80.519  53.052  1
7882  93.516  -80.508  53.048  1
7883  93.523  -80.498  53.044  1
7884  93.531  -80.488  53.039  1
7885  93.537  -80.479  53.034  1
7886  93.540  -80.475  53.028  1
7887  93.543  -80.470  53.021  1
7888  93.547  -80.466  53.014  1
7889  93.550  -80.461  53.006  1
7890  93.553  -80.457  52.998  1
7891  93.557  -80.452  52.990  1
7892  93.560  -80.447  52.981  1
7893  93.563  -80.442  52.972  1
7894  93.567  -80.438  52.964  1
7895  93.570  -80.433  52.955  1
7896  93.573  -80.428  52.945  1
7897  93.577  -80.424  52.936  1
7898  93.580  -80.419  52.927  1
8486  91.791  -81.285  53.374  2
8487  91.805  -81.280  53.353  2
8488  91.819  -81.274  53.332  2
8489  91.834  -81.268  53.313  2
8490  91.847  -81.262  53.294  2
8491  91.861  -81.257  53.277  2
8492  91.875  -81.251  53.261  2
8493  91.889  -81.246  53.245  2
8494  91.904  -81.240  53.231  2
8495  91.917  -81.234  53.218  2
8496  91.931  -81.229  53.204  2
8497  91.945  -81.223  53.193  2
8498  91.959  -81.218  53.182  2
8499  91.974  -81.212  53.171  2
8500  91.994  -81.209  53.161  2
8501  92.048  -81.219  53.151  2
8502  92.081  -81.214  53.141  2
8503  92.105  -81.201  53.132  2
8504  92.126  -81.190  53.123  2
8505  92.142  -81.179  53.114  2
8506  92.158  -81.168  53.105  2
8507  92.177  -81.162  53.094  2
8508  92.197  -81.155  53.085  2
8509  92.216  -81.148  53.076  2
8510  92.236  -81.141  53.067  2
8511  92.254  -81.133  53.059  2
8512  92.273  -81.126  53.051  2
8513  92.291  -81.118  53.044  2
8514  92.309  -81.111  53.037  2
8515  92.328  -81.103  53.030  2
8516  92.347  -81.096  53.023  2
8517  92.365  -81.088  53.016  2
8518  92.383  -81.080  53.009  2
8531  92.624  -80.981  53.419  1
8532  92.642  -80.974  53.405  1
8533  92.661  -80.966  53.389  1
8534  92.679  -80.958  53.375  1
8535  92.698  -80.951  53.362  1
8536  92.716  -80.943  53.347  1
8537  92.734  -80.936  53.332  1
8538  92.753  -80.928  53.318  1
8539  92.772  -80.920  53.304  1
8540  92.790  -80.912  53.290  1
8541  92.808  -80.905  53.277  1
8542  92.827  -80.897  53.265  1
8543  92.845  -80.889  53.253  1
8544  92.864  -80.882  53.241  1
8545  92.882  -80.874  53.231  1
8546  92.901  -80.867  53.220  1
8547  92.919  -80.859  53.210  1
8548  92.938  -80.851  53.200  1
8549  92.956  -80.844  53.193  1
8550  92.975  -80.836  53.184  1
8551  92.991  -80.826  53.176  1
8571  93.318  -80.614  53.055  1
8572  93.334  -80.604  53.053  1
8573  93.351  -80.593  53.051  1
8574  93.367  -80.582  53.049  1
8575  93.383  -80.572  53.048  1
8576  93.400  -80.561  53.047  1
8577  93.416  -80.551  53.047  1
8578  93.432  -80.540  53.048  1
8579  93.449  -80.529  53.048  1
8580  93.465  -80.519  53.048  1
8581  93.482  -80.508  53.048  1
8582  93.498  -80.497  53.048  1
8583  93.514  -80.487  53.047  1
8584  93.521  -80.477  53.044  1
8585  93.526  -80.469  53.038  1
8586  93.530  -80.465  53.032  1
8587  93.533  -80.460  53.026  1
8588  93.537  -80.456  53.019  1
8589  93.540  -80.451  53.012  1
8590  93.543  -80.447  53.005  1
8591  93.547  -80.442  52.998  1
8592  93.550  -80.438  52.990  1
8593  93.553  -80.432  52.981  1
8594  93.557  -80.428  52.972  1
8595  93.560  -80.423  52.964  1
8596  93.563  -80.419  52.954  1
8597  93.567  -80.414  52.945  1
8598  93.570  -80.410  52.937  1
8599  93.573  -80.405  52.928  1
8600  93.577  -80.400  52.919  1
9187  91.790  -81.255  53.395  2
9188  91.803  -81.249  53.373  2
9189  91.817  -81.244  53.352  2
9190  91.831  -81.238  53.332  2
9191  91.846  -81.233  53.312  2
9192  91.860  -81.227  53.294  2
9193  91.873  -81.221  53.277  2
9194  91.887  -81.215  53.260  2
9195  91.901  -81.210  53.245  2
9196  91.916  -81.204  53.231  2
9197  91.930  -81.199  53.217  2
9198  91.943  -81.193  53.204  2
9199  91.957  -81.187  53.191  2
9200  91.971  -81.182  53.180  2
9201  91.986  -81.176  53.169  2
9202  92.032  -81.184  53.158  2
9203  92.083  -81.191  53.147  2
9204  92.104  -81.180  53.137  2
9205  92.120  -81.168  53.127  2
9206  92.136  -81.158  53.117  2
9207  92.152  -81.147  53.106  2
9208  92.170  -81.138  53.096  2
9209  92.190  -81.131  53.086  2
9210  92.209  -81.124  53.076  2
9211  92.228  -81.118  53.067  2
9212  92.248  -81.112  53.059  2
9213  92.268  -81.105  53.050  2
9214  92.287  -81.098  53.043  2
9215  92.305  -81.090  53.035  2
9216  92.323  -81.083  53.027  2
9217  92.342  -81.075  53.020  2
9218  92.360  -81.068  53.014  2
9219  92.379  -81.060  53.007  2
9232  92.619  -80.961  53.414  1
9233  92.638  -80.953  53.399  1
9234  92.656  -80.945  53.384  1
9235  92.674  -80.938  53.370  1
9236  92.693  -80.930  53.355  1
9237  92.712  -80.923  53.339  1
9238  92.730  -80.915  53.325  1
9239  92.748  -80.908  53.310  1
9240  92.767  -80.900  53.296  1
9241  92.785  -80.892  53.281  1
9242  92.804  -80.884  53.267  1
9243  92.823  -80.877  53.254  1
9244  92.841  -80.869  53.241  1
9245  92.859  -80.861  53.230  1
9246  92.878  -80.854  53.218  1
9247  92.896  -80.846  53.207  1
9248  92.915  -80.839  53.197  1
9249  92.933  -80.831  53.187  1
9250  92.951  -80.823  53.179  1
9251  92.970  -80.815  53.171  1
9252  92.986  -80.804  53.163  1
9253  93.002  -80.794  53.155  1
9254  93.018  -80.783  53.148  1
9255  93.035  -80.773  53.141  1
9256  93.051  -80.762  53.135  1
9257  93.068  -80.751  53.129  1
9272  93.313  -80.593  53.044  1
9273  93.329  -80.582  53.042  1
9274  93.346  -80.572  53.041  1
9275  93.362  -80.561  53.040  1
9276  93.378  -80.551  53.040  1
9277  93.395  -80.540  53.039  1
9278  93.411  -80.529  53.039  1
9279  93.427  -80.519  53.040  1
9280  93.444  -80.508  53.041  1
9281  93.460  -80.497  53.043  1
9282  93.477  -80.487  53.044  1
9283  93.493  -80.476  53.045  1
9284  93.509  -80.466  53.045  1
9285  93.516  -80.460  53.042  1
9286  93.520  -80.455  53.036  1
9287  93.523  -80.450  53.029  1
9288  93.526  -80.446  53.022  1
9289  93.530  -80.441  53.016  1
9290  93.533  -80.437  53.009  1
9291  93.537  -80.432  53.003  1
9292  93.540  -80.428  52.996  1
9293  93.543  -80.423  52.989  1
9294  93.547  -80.418  52.980  1
9295  93.550  -80.413  52.971  1
9296  93.553  -80.409  52.964  1
9297  93.557  -80.404  52.954  1
9298  93.560  -80.400  52.946  1
9299  93.563  -80.395  52.937  1
9300  93.567  -80.391  52.928  1
9301  93.570  -80.386  52.919  1
9302  93.574  -80.381  52.910  1
9888  91.788  -81.225  53.418  2
9889  91.802  -81.219  53.395  2
9890  91.815  -81.214  53.373  2
9891  91.829  -81.209  53.352  2
9892  91.844  -81.202  53.331  2
9893  91.858  -81.197  53.313  2
9894  91.872  -81.191  53.294  2
9895  91.885  -81.186  53.277  2
9896  91.899  -81.180  53.260  2
9897  91.914  -81.174  53.245  2
9898  91.928  -81.169  53.230  2
9899  91.942  -81.163  53.216  2
9900  91.955  -81.158  53.202  2
9901  91.969  -81.152  53.190  2
9902  91.984  -81.146  53.178  2
9903  92.018  -81.149  53.166  2
9904  92.067  -81.160  53.154  2
9905  92.091  -81.157  53.143  2
9906  92.111  -81.147  53.132  2
9907  92.131  -81.137  53.121  2
9908  92.147  -81.126  53.109  2
9909  92.163  -81.115  53.099  2
9910  92.182  -81.108  53.088  2
9911  92.202  -81.102  53.078  2
9912  92.221  -81.095  53.068  2
9913  92.240  -81.088  53.059  2
9914  92.260  -81.082  53.050  2
9915  92.279  -81.075  53.042  2
9916  92.299  -81.068  53.034  2
9917  92.318  -81.061  53.026  2
9918  92.338  -81.055  53.019  2
9919  92.356  -81.047  53.011  2
9920  92.374  -81.039  53.004  2
9933  92.615  -80.940  53.409  1
9934  92.633  -80.933  53.394  1
9935  92.651  -80.925  53.379  1
9936  92.670  -80.917  53.363  1
9937  92.689  -80.910  53.348  1
9938  92.707  -80.902  53.333  1
9939  92.725  -80.895  53.317  1
9940  92.744  -80.887  53.302  1
9941  92.762  -80.880  53.286  1
9942  92.781  -80.872  53.271  1
9943  92.799  -80.864  53.257  1
9944  92.818  -80.857  53.244  1
9945  92.836  -80.848  53.231  1
9946  92.855  -80.841  53.218  1
9947  92.873  -80.833  53.206  1
9948  92.892  -80.826  53.195  1
9949  92.910  -80.818  53.184  1
9950  92.929  -80.811  53.174  1
9951  92.947  -80.803  53.165  1
9952  92.965  -80.794  53.158  1
9953  92.981  -80.783  53.150  1
9954  92.997  -80.773  53.141  1
9955  93.013  -80.762  53.135  1
9956  93.030  -80.751  53.128  1
9957  93.046  -80.741  53.121  1
9958  93.063  -80.730  53.115  1
9959  93.079  -80.720  53.109  1
9960  93.095  -80.710  53.103  1
9961  93.112  -80.699  53.097  1
9962  93.128  -80.688  53.090  1
9972  93.292  -80.582  53.036  1
9973  93.308  -80.572  53.033  1
9974  93.324  -80.561  53.032  1
9975  93.341  -80.551  53.030  1
9976  93.357  -80.540  53.029  1
9977  93.373  -80.529  53.029  1
9978  93.390  -80.519  53.029  1
9979  93.406  -80.508  53.030  1
9980  93.422  -80.498  53.032  1
9981  93.439  -80.488  53.034  1
9982  93.455  -80.477  53.037  1
9983  93.468  -80.466  53.040  1
9984  93.481  -80.457  53.042  1
9985  93.497  -80.450  53.042  1
9986  93.509  -80.445  53.039  1
9987  93.513  -80.441  53.032  1
9988  93.516  -80.436  53.025  1
9989  93.520  -80.431  53.018  1
9990  93.523  -80.427  53.012  1
9991  93.526  -80.422  53.006  1
9992  93.530  -80.418  53.000  1
9993  93.534  -80.413  52.994  1
9994  93.537  -80.409  52.987  1
9995  93.540  -80.403  52.979  1
9996  93.543  -80.399  52.971  1
9997  93.547  -80.394  52.963  1
9998  93.550  -80.390  52.954  1
9999  93.553  -80.385  52.945  1
10000  93.557  -80.381  52.936  1
10001  93.560  -80.376  52.927  1
10002  93.564  -80.371  52.919  1
10003  93.574  -80.363  52.910  1
10589  91.786  -81.195  53.441  2
10590  91.800  -81.190  53.418  2
10591  91.814  -81.184  53.395  2
10592  91.828  -81.178  53.373  2
10593  91.842  -81.173  53.352  2
10594  91.856  -81.167  53.332  2
10595  91.870  -81.162  53.313  2
10596  91.884  -81.155  53.294  2
10597  91.898  -81.150  53.277  2
10598  91.912  -81.144  53.261  2
10599  91.926  -81.139  53.245  2
10600  91.940  -81.133  53.229  2
10601  91.954  -81.127  53.215  2
10602  91.968  -81.122  53.201  2
10603  91.982  -81.116  53.187  2
10604  92.003  -81.113  53.174  2
10605  92.038  -81.129  53.162  2
10606  92.066  -81.133  53.150  2
10607  92.086  -81.123  53.138  2
10608  92.107  -81.112  53.125  2
10609  92.127  -81.102  53.114  2
10610  92.150  -81.093  53.103  2
10611  92.174  -81.085  53.092  2
10612  92.194  -81.078  53.081  2
10613  92.213  -81.071  53.070  2
10614  92.233  -81.065  53.060  2
10615  92.252  -81.058  53.051  2
10616  92.272  -81.052  53.042  2
10617  92.291  -81.045  53.034  2
10618  92.311  -81.039  53.026  2
10619  92.331  -81.032  53.018  2
10620  92.350  -81.025  53.011  2
10621  92.369  -81.019  53.003  2
10634  92.610  -80.920  53.405  1
10635  92.629  -80.912  53.390  1
10636  92.647  -80.905  53.373  1
10637  92.665  -80.897  53.357  1
10638  92.684  -80.889  53.342  1
10639  92.702  -80.882  53.327  1
10640  92.721  -80.874  53.310  1
10641  92.739  -80.867  53.294  1
10642  92.758  -80.859  53.278  1
10643  92.776  -80.851  53.263  1
10644  92.795  -80.844  53.248  1
10645  92.813  -80.836  53.234  1
10646  92.832  -80.829  53.220  1
10647  92.850  -80.821  53.207  1
10648  92.868  -80.813  53.195  1
10649  92.887  -80.805  53.183  1
10650  92.906  -80.798  53.172  1
10651  92.924  -80.790  53.162  1
10652  92.942  -80.782  53.152  1
10653  92.959  -80.773  53.145  1
10654  92.976  -80.762  53.137  1
10655  92.992  -80.752  53.128  1
10656  93.008  -80.742  53.121  1
10657  93.025  -80.731  53.114  1
10658  93.041  -80.720  53.107  1
10659  93.058  -80.710  53.102  1
10660  93.074  -80.699  53.096  1
10661  93.090  -80.688  53.090  1
10662  93.107  -80.678  53.083  1
10663  93.123  -80.667  53.077  1
10664  93.139  -80.657  53.071  1
10665  93.156  -80.646  53.064  1
10673  93.286  -80.561  53.023  1
10674  93.303  -80.551  53.021  1
10675  93.319  -80.541  53.020  1
10676  93.336  -80.530  53.018  1
10677  93.352  -80.519  53.017  1
10678  93.368  -80.509  53.017  1
10679  93.384  -80.498  53.018  1
10680  93.401  -80.488  53.020  1
10681  93.414  -80.476  53.022  1
10682  93.426  -80.465  53.025  1
10683  93.439  -80.454  53.030  1
10684  93.452  -80.449  53.034  1
10685  93.468  -80.443  53.037  1
10686  93.485  -80.435  53.037  1
10687  93.498  -80.430  53.034  1
10688  93.506  -80.426  53.029  1
10689  93.510  -80.422  53.021  1
10690  93.513  -80.417  53.014  1
10691  93.516  -80.413  53.009  1
10692  93.520  -80.408  53.003  1
10693  93.523  -80.403  52.998  1
10694  93.526  -80.399  52.993  1
10695  93.530  -80.394  52.985  1
10696  93.534  -80.389  52.977  1
10697  93.537  -80.385  52.970  1
10698  93.540  -80.380  52.962  1
10699  93.543  -80.375  52.953  1
10700  93.547  -80.371  52.944  1
10701  93.550  -80.366  52.935  1
10702  93.554  -80.361  52.927  1
10703  93.564  -80.353  52.919  1
10704  93.574  -80.344  52.910  1
10705  93.584  -80.335  52.901  1
11291  91.798  -81.159  53.441  2
11292  91.812  -81.154  53.417  2
11293  91.826  -81.149  53.394  2
11294  91.840  -81.143  53.373  2
11295  91.854  -81.137  53.352  2
11296  91.868  -81.131  53.332  2
11297  91.882  -81.126  53.312  2
11298  91.896  -81.120  53.295  2
11299  91.910  -81.115  53.278  2
11300  91.924  -81.108  53.260  2
11301  91.938  -81.103  53.244  2
11302  91.952  -81.098  53.229  2
11303  91.965  -81.096  53.214  2
11304  91.979  -81.095  53.199  2
11305  91.992  -81.095  53.186  2
11306  92.010  -81.098  53.173  2
11307  92.040  -81.108  53.159  2
11308  92.061  -81.098  53.145  2
11309  92.082  -81.088  53.133  2
11310  92.112  -81.079  53.121  2
11311  92.143  -81.070  53.108  2
11312  92.164  -81.063  53.096  2
11313  92.184  -81.055  53.084  2
11314  92.205  -81.049  53.073  2
11315  92.224  -81.042  53.062  2
11316  92.244  -81.035  53.052  2
11317  92.265  -81.028  53.044  2
11318  92.284  -81.022  53.035  2
11319  92.303  -81.015  53.026  2
11320  92.323  -81.008  53.018  2
11321  92.342  -81.002  53.011  2
11322  92.362  -80.996  53.003  2
11336  92.624  -80.892  53.384  1
11337  92.642  -80.884  53.368  1
11338  92.661  -80.877  53.352  1
11339  92.679  -80.869  53.336  1
11340  92.698  -80.861  53.320  1
11341  92.716  -80.854  53.303  1
11342  92.735  -80.846  53.287  1
11343  92.753  -80.839  53.271  1
11344  92.772  -80.831  53.255  1
11345  92.790  -80.823  53.239  1
11346  92.808  -80.816  53.225  1
11347  92.827  -80.808  53.210  1
11348  92.846  -80.801  53.197  1
11349  92.864  -80.793  53.184  1
11350  92.882  -80.786  53.172  1
11351  92.901  -80.777  53.160  1
11352  92.919  -80.770  53.150  1
11353  92.938  -80.762  53.140  1
11354  92.954  -80.752  53.132  1
11355  92.971  -80.742  53.124  1
11356  92.987  -80.731  53.116  1
11357  93.003  -80.720  53.108  1
11358  93.020  -80.710  53.101  1
11359  93.036  -80.699  53.094  1
11360  93.053  -80.688  53.088  1
11361  93.069  -80.678  53.082  1
11362  93.085  -80.667  53.076  1
11363  93.101  -80.657  53.070  1
11364  93.118  -80.646  53.064  1
11365  93.134  -80.635  53.058  1
11366  93.151  -80.625  53.052  1
11367  93.167  -80.614  53.046  1
11374  93.281  -80.541  53.011  1
11375  93.298  -80.530  53.009  1
11376  93.314  -80.519  53.007  1
11377  93.331  -80.509  53.006  1
11378  93.347  -80.498  53.005  1
11379  93.360  -80.487  53.004  1
11380  93.372  -80.476  53.006  1
11381  93.385  -80.465  53.008  1
11382  93.398  -80.453  53.011  1
11383  93.410  -80.444  53.016  1
11384  93.424  -80.441  53.021  1
11385  93.440  -80.435  53.027  1
11386  93.456  -80.428  53.029  1
11387  93.473  -80.420  53.029  1
11388  93.486  -80.415  53.027  1
11389  93.496  -80.412  53.023  1
11390  93.503  -80.407  53.017  1
11391  93.507  -80.403  53.011  1
11392  93.510  -80.398  53.007  1
11393  93.513  -80.394  53.002  1
11394  93.516  -80.389  52.997  1
11395  93.520  -80.385  52.991  1
11396  93.523  -80.380  52.984  1
11397  93.526  -80.375  52.977  1
11398  93.530  -80.370  52.969  1
11399  93.534  -80.366  52.961  1
11400  93.537  -80.361  52.952  1
11401  93.540  -80.356  52.943  1
11402  93.544  -80.352  52.934  1
11403  93.554  -80.343  52.926  1
11404  93.564  -80.334  52.918  1
11405  93.574  -80.325  52.909  1
11406  93.584  -80.317  52.901  1
11407  93.594  -80.309  52.892  1
11992  91.796  -81.130  53.465  2
11993  91.810  -81.124  53.441  2
11994  91.824  -81.118  53.417  2
11995  91.838  -81.113  53.395  2
11996  91.852  -81.107  53.373  2
11997  91.866  -81.102  53.352  2
11998  91.880  -81.096  53.332  2
11999  91.894  -81.090  53.314  2
12000  91.908  -81.089  53.296  2
12001  91.921  -81.088  53.277  2
12002  91.934  -81.087  53.261  2
12003  91.947  -81.086  53.245  2
12004  91.961  -81.086  53.229  2
12005  91.974  -81.085  53.213  2
12006  91.987  -81.084  53.198  2
12007  92.001  -81.083  53.184  2
12008  92.015  -81.083  53.169  2
12009  92.040  -81.075  53.155  2
12010  92.065  -81.067  53.141  2
12011  92.090  -81.059  53.128  2
12012  92.115  -81.051  53.115  2
12013  92.140  -81.043  53.102  2
12014  92.165  -81.035  53.090  2
12015  92.190  -81.027  53.078  2
12016  92.215  -81.020  53.067  2
12017  92.235  -81.013  53.056  2
12018  92.255  -81.006  53.047  2
12019  92.275  -80.999  53.037  2
12020  92.295  -80.992  53.028  2
12021  92.315  -80.986  53.020  2
12022  92.335  -80.979  53.011  2
12023  92.354  -80.972  53.003  2
12038  92.638  -80.864  53.364  1
12039  92.656  -80.856  53.348  1
12040  92.674  -80.848  53.332  1
12041  92.693  -80.841  53.315  1
12042  92.712  -80.833  53.297  1
12043  92.730  -80.826  53.281  1
12044  92.748  -80.818  53.264  1
12045  92.767  -80.811  53.247  1
12046  92.785  -80.803  53.231  1
12047  92.804  -80.795  53.216  1
12048  92.823  -80.788  53.201  1
12049  92.841  -80.780  53.187  1
12050  92.859  -80.773  53.173  1
12051  92.878  -80.765  53.161  1
12052  92.897  -80.757  53.149  1
12053  92.915  -80.750  53.137  1
12054  92.933  -80.742  53.128  1
12055  92.949  -80.731  53.120  1
12056  92.966  -80.720  53.111  1
12057  92.982  -80.710  53.103  1
12058  92.998  -80.699  53.096  1
12059  93.015  -80.688  53.089  1
12060  93.031  -80.678  53.082  1
12061  93.048  -80.667  53.075  1
12062  93.064  -80.657  53.069  1
12063  93.080  -80.646  53.063  1
12064  93.096  -80.635  53.057  1
12065  93.113  -80.626  53.051  1
12066  93.129  -80.615  53.045  1
12067  93.146  -80.604  53.039  1
12068  93.162  -80.594  53.034  1
12069  93.179  -80.583  53.028  1
12070  93.195  -80.573  53.022  1
12075  93.276  -80.519  52.999  1
12076  93.293  -80.509  52.996  1
12077  93.306  -80.498  52.994  1
12078  93.319  -80.487  52.992  1
12079  93.331  -80.475  52.991  1
12080  93.343  -80.464  52.991  1
12081  93.356  -80.453  52.993  1
12082  93.368  -80.442  52.996  1
12083  93.382  -80.437  53.000  1
12084  93.396  -80.433  53.006  1
12085  93.412  -80.427  53.012  1
12086  93.428  -80.420  53.018  1
12087  93.444  -80.413  53.021  1
12088  93.460  -80.406  53.021  1
12089  93.475  -80.400  53.019  1
12090  93.485  -80.396  53.016  1
12091  93.494  -80.393  53.012  1
12092  93.500  -80.388  53.009  1
12093  93.503  -80.384  53.005  1
12094  93.507  -80.379  53.001  1
12095  93.510  -80.375  52.996  1
12096  93.513  -80.370  52.991  1
12097  93.517  -80.366  52.983  1
12098  93.520  -80.361  52.976  1
12099  93.523  -80.356  52.968  1
12100  93.526  -80.351  52.960  1
12101  93.530  -80.347  52.951  1
12102  93.534  -80.342  52.943  1
12103  93.544  -80.333  52.935  1
12104  93.554  -80.325  52.926  1
12105  93.564  -80.316  52.917  1
12106  93.574  -80.307  52.910  1
12107  93.584  -80.299  52.901  1
12108  93.594  -80.290  52.892  1
12693  91.794  -81.099  53.489  2
12694  91.808  -81.094  53.465  2
12695  91.822  -81.089  53.442  2
12696  91.836  -81.083  53.418  2
12697  91.850  -81.081  53.396  2
12698  91.863  -81.080  53.375  2
12699  91.876  -81.080  53.354  2
12700  91.889  -81.079  53.335  2
12701  91.903  -81.078  53.316  2
12702  91.916  -81.077  53.297  2
12703  91.930  -81.077  53.279  2
12704  91.943  -81.076  53.261  2
12705  91.956  -81.075  53.244  2
12706  91.970  -81.075  53.228  2
12707  91.985  -81.074  53.212  2
12708  91.999  -81.074  53.196  2
12709  92.013  -81.069  53.181  2
12710  92.027  -81.060  53.165  2
12711  92.042  -81.050  53.151  2
12712  92.060  -81.042  53.137  2
12713  92.082  -81.033  53.123  2
12714  92.107  -81.026  53.109  2
12715  92.132  -81.017  53.097  2
12716  92.157  -81.010  53.085  2
12717  92.181  -81.002  53.073  2
12718  92.207  -80.994  53.062  2
12719  92.232  -80.986  53.051  2
12720  92.258  -80.978  53.041  2
12721  92.284  -80.971  53.032  2
12722  92.306  -80.963  53.023  2
12723  92.325  -80.956  53.014  2
12724  92.346  -80.949  53.005  2
12740  92.652  -80.836  53.344  1
12741  92.670  -80.828  53.328  1
12742  92.689  -80.820  53.310  1
12743  92.707  -80.813  53.293  1
12744  92.725  -80.805  53.276  1
12745  92.744  -80.798  53.258  1
12746  92.763  -80.790  53.242  1
12747  92.781  -80.782  53.225  1
12748  92.799  -80.775  53.209  1
12749  92.818  -80.767  53.194  1
12750  92.836  -80.760  53.179  1
12751  92.855  -80.752  53.164  1
12752  92.873  -80.745  53.152  1
12753  92.892  -80.737  53.140  1
12754  92.910  -80.729  53.128  1
12755  92.928  -80.720  53.118  1
12756  92.944  -80.710  53.108  1
12757  92.960  -80.699  53.100  1
12758  92.977  -80.688  53.092  1
12759  92.993  -80.678  53.084  1
12760  93.010  -80.668  53.077  1
12761  93.026  -80.657  53.070  1
12762  93.043  -80.647  53.063  1
12763  93.059  -80.636  53.057  1
12764  93.075  -80.626  53.050  1
12765  93.091  -80.615  53.045  1
12766  93.108  -80.604  53.039  1
12767  93.124  -80.594  53.033  1
12768  93.141  -80.583  53.027  1
12769  93.157  -80.573  53.022  1
12770  93.174  -80.562  53.017  1
12771  93.190  -80.551  53.011  1
12772  93.206  -80.541  53.005  1
12773  93.222  -80.530  52.999  1
12774  93.238  -80.519  52.994  1
12775  93.252  -80.509  52.990  1
12776  93.265  -80.497  52.986  1
12777  93.277  -80.486  52.983  1
12778  93.289  -80.475  52.981  1
12779  93.302  -80.464  52.979  1
12780  93.314  -80.453  52.979  1
12781  93.327  -80.441  52.979  1
12782  93.340  -80.433  52.981  1
12783  93.353  -80.429  52.983  1
12784  93.367  -80.425  52.986  1
12785  93.383  -80.419  52.992  1
12786  93.400  -80.412  52.999  1
12787  93.416  -80.405  53.006  1
12788  93.432  -80.397  53.010  1
12789  93.448  -80.391  53.012  1
12790  93.463  -80.385  53.011  1
12791  93.473  -80.381  53.009  1
12792  93.483  -80.378  53.008  1
12793  93.493  -80.374  53.007  1
12794  93.497  -80.369  53.006  1
12795  93.500  -80.365  53.002  1
12796  93.503  -80.360  52.997  1
12797  93.507  -80.356  52.992  1
12798  93.510  -80.351  52.983  1
12799  93.513  -80.347  52.975  1
12800  93.517  -80.341  52.966  1
12801  93.520  -80.337  52.959  1
12802  93.523  -80.332  52.951  1
12803  93.534  -80.324  52.942  1
12804  93.544  -80.315  52.934  1
12805  93.554  -80.306  52.925  1
12806  93.564  -80.297  52.916  1
12807  93.574  -80.289  52.909  1
12808  93.584  -80.280  52.900  1
12809  93.594  -80.272  52.892  1
13394  91.792  -81.074  53.513  2
13395  91.805  -81.073  53.490  2
13396  91.818  -81.072  53.466  2
13397  91.832  -81.071  53.442  2
13398  91.845  -81.071  53.420  2
13399  91.858  -81.070  53.398  2
13400  91.872  -81.069  53.377  2
13401  91.885  -81.068  53.356  2
13402  91.898  -81.068  53.336  2
13403  91.913  -81.068  53.316  2
13404  91.927  -81.067  53.298  2
13405  91.942  -81.066  53.280  2
13406  91.956  -81.066  53.262  2
13407  91.970  -81.065  53.245  2
13408  91.985  -81.065  53.228  2
13409  91.999  -81.060  53.211  2
13410  92.012  -81.055  53.194  2
13411  92.026  -81.050  53.178  2
13412  92.040  -81.038  53.162  2
13413  92.054  -81.026  53.148  2
13414  92.070  -81.017  53.133  2
13415  92.086  -81.009  53.119  2
13416  92.106  -81.001  53.105  2
13417  92.127  -80.992  53.093  2
13418  92.149  -80.984  53.080  2
13419  92.173  -80.976  53.068  2
13420  92.199  -80.968  53.057  2
13421  92.223  -80.960  53.047  2
13422  92.248  -80.952  53.037  2
13423  92.274  -80.944  53.027  2
13424  92.299  -80.936  53.017  2
13442  92.665  -80.808  53.325  1
13443  92.684  -80.800  53.308  1
13444  92.702  -80.792  53.290  1
13445  92.721  -80.785  53.273  1
13446  92.739  -80.777  53.254  1
13447  92.758  -80.770  53.237  1
13448  92.776  -80.762  53.220  1
13449  92.795  -80.754  53.204  1
13450  92.813  -80.747  53.188  1
13451  92.832  -80.739  53.173  1
13452  92.850  -80.732  53.157  1
13453  92.869  -80.724  53.144  1
13454  92.887  -80.717  53.132  1
13455  92.906  -80.709  53.120  1
13456  92.923  -80.700  53.109  1
13457  92.939  -80.689  53.100  1
13458  92.955  -80.679  53.091  1
13459  92.972  -80.668  53.083  1
13460  92.988  -80.657  53.075  1
13461  93.005  -80.647  53.067  1
13462  93.021  -80.636  53.060  1
13463  93.038  -80.626  53.053  1
13464  93.054  -80.615  53.047  1
13465  93.070  -80.604  53.041  1
13466  93.086  -80.594  53.034  1
13467  93.103  -80.583  53.028  1
13468  93.119  -80.573  53.022  1
13469  93.136  -80.562  53.016  1
13470  93.152  -80.551  53.010  1
13471  93.168  -80.541  53.005  1
13472  93.185  -80.530  52.999  1
13473  93.198  -80.519  52.993  1
13474  93.211  -80.508  52.987  1
13475  93.223  -80.497  52.982  1
13476  93.235  -80.486  52.977  1
13477  93.248  -80.475  52.973  1
13478  93.260  -80.463  52.970  1
13479  93.273  -80.452  52.967  1
13480  93.285  -80.441  52.966  1
13481  93.298  -80.430  52.965  1
13482  93.311  -80.425  52.966  1
13483  93.325  -80.422  52.967  1
13484  93.339  -80.418  52.969  1
13485  93.355  -80.411  52.973  1
13486  93.371  -80.404  52.979  1
13487  93.388  -80.397  52.986  1
13488  93.404  -80.390  52.993  1
13489  93.420  -80.383  52.998  1
13490  93.436  -80.375  53.001  1
13491  93.451  -80.369  53.001  1
13492  93.462  -80.366  53.002  1
13493  93.472  -80.362  53.002  1
13494  93.481  -80.359  53.002  1
13495  93.490  -80.355  53.002  1
13496  93.493  -80.350  52.999  1
13497  93.497  -80.346  52.996  1
13498  93.500  -80.341  52.992  1
13499  93.503  -80.337  52.983  1
13500  93.507  -80.332  52.974  1
13501  93.510  -80.327  52.965  1
13502  93.513  -80.322  52.956  1
13503  93.523  -80.314  52.948  1
13504  93.534  -80.305  52.940  1
13505  93.544  -80.297  52.931  1
13506  93.554  -80.288  52.923  1
13507  93.564  -80.279  52.915  1
13508  93.574  -80.271  52.906  1
13509  93.584  -80.262  52.899  1
13510  93.594  -80.253  52.891  1
13511  93.604  -80.244  52.884  1
14096  91.801  -81.062  53.514  2
14097  91.814  -81.061  53.490  2
14098  91.827  -81.061  53.467  2
14099  91.841  -81.060  53.445  2
14100  91.856  -81.060  53.422  2
14101  91.870  -81.059  53.399  2
14102  91.884  -81.059  53.378  2
14103  91.898  -81.058  53.357  2
14104  91.913  -81.058  53.336  2
14105  91.927  -81.058  53.318  2
14106  91.942  -81.057  53.299  2
14107  91.956  -81.056  53.280  2
14108  91.970  -81.055  53.262  2
14109  91.984  -81.051  53.245  2
14110  91.998  -81.046  53.226  2
14111  92.011  -81.041  53.209  2
14112  92.025  -81.036  53.192  2
14113  92.039  -81.027  53.176  2
14114  92.053  -81.015  53.160  2
14115  92.067  -81.003  53.146  2
14116  92.082  -80.992  53.131  2
14117  92.098  -80.984  53.116  2
14118  92.114  -80.976  53.103  2
14119  92.131  -80.967  53.089  2
14120  92.152  -80.959  53.077  2
14121  92.173  -80.951  53.065  2
14122  92.194  -80.942  53.054  2
14123  92.215  -80.934  53.043  2
14124  92.240  -80.927  53.032  2
14125  92.265  -80.918  53.022  2
14144  92.680  -80.780  53.307  1
14145  92.698  -80.773  53.289  1
14146  92.716  -80.764  53.272  1
14147  92.735  -80.757  53.253  1
14148  92.753  -80.749  53.235  1
14149  92.772  -80.742  53.218  1
14150  92.790  -80.734  53.200  1
14151  92.808  -80.726  53.183  1
14152  92.827  -80.719  53.168  1
14153  92.846  -80.711  53.152  1
14154  92.864  -80.704  53.138  1
14155  92.882  -80.696  53.126  1
14156  92.901  -80.688  53.114  1
14157  92.918  -80.679  53.103  1
14158  92.934  -80.668  53.093  1
14159  92.950  -80.657  53.084  1
14160  92.967  -80.647  53.075  1
14161  92.983  -80.636  53.067  1
14162  93.000  -80.626  53.059  1
14163  93.016  -80.615  53.051  1
14164  93.032  -80.604  53.045  1
14165  93.049  -80.594  53.038  1
14166  93.065  -80.583  53.031  1
14167  93.081  -80.573  53.024  1
14168  93.098  -80.562  53.018  1
14169  93.114  -80.551  53.012  1
14170  93.131  -80.541  53.005  1
14171  93.144  -80.530  52.999  1
14172  93.156  -80.519  52.993  1
14173  93.169  -80.508  52.987  1
14174  93.182  -80.497  52.981  1
14175  93.194  -80.485  52.975  1
14176  93.206  -80.474  52.969  1
14177  93.219  -80.463  52.964  1
14178  93.231  -80.452  52.960  1
14179  93.243  -80.441  52.956  1
14180  93.256  -80.429  52.953  1
14181  93.269  -80.421  52.951  1
14182  93.283  -80.417  52.951  1
14183  93.297  -80.413  52.952  1
14184  93.310  -80.410  52.952  1
14185  93.327  -80.403  52.954  1
14186  93.343  -80.397  52.959  1
14187  93.359  -80.389  52.965  1
14188  93.375  -80.382  52.971  1
14189  93.392  -80.375  52.978  1
14190  93.408  -80.368  52.984  1
14191  93.424  -80.360  52.988  1
14192  93.440  -80.353  52.991  1
14193  93.450  -80.350  52.993  1
14194  93.460  -80.347  52.994  1
14195  93.470  -80.344  52.995  1
14196  93.480  -80.340  52.995  1
14197  93.487  -80.336  52.995  1
14198  93.490  -80.331  52.992  1
14199  93.493  -80.327  52.989  1
14200  93.497  -80.322  52.980  1
14201  93.500  -80.318  52.971  1
14202  93.503  -80.312  52.961  1
14203  93.513  -80.304  52.952  1
14204  93.523  -80.296  52.944  1
14205  93.534  -80.287  52.935  1
14206  93.544  -80.278  52.927  1
14207  93.554  -80.269  52.919  1
14208  93.564  -80.261  52.911  1
14209  93.574  -80.252  52.903  1
14210  93.584  -80.243  52.897  1
14211  93.594  -80.235  52.890  1
14212  93.604  -80.226  52.882  1
14797  91.798  -81.052  53.539  2
14798  91.812  -81.052  53.515  2
14799  91.826  -81.052  53.492  2
14800  91.841  -81.051  53.469  2
14801  91.856  -81.050  53.446  2
14802  91.870  -81.050  53.424  2
14803  91.884  -81.049  53.401  2
14804  91.898  -81.049  53.380  2
14805  91.913  -81.049  53.359  2
14806  91.927  -81.048  53.339  2
14807  91.942  -81.048  53.319  2
14808  91.956  -81.046  53.299  2
14809  91.969  -81.042  53.280  2
14810  91.984  -81.036  53.262  2
14811  91.997  -81.032  53.243  2
14812  92.011  -81.027  53.225  2
14813  92.024  -81.023  53.208  2
14814  92.038  -81.017  53.190  2
14815  92.052  -81.005  53.175  2
14816  92.066  -80.992  53.159  2
14817  92.080  -80.980  53.144  2
14818  92.094  -80.968  53.129  2
14819  92.109  -80.959  53.114  2
14820  92.126  -80.951  53.100  2
14821  92.142  -80.943  53.087  2
14822  92.158  -80.935  53.074  2
14823  92.177  -80.927  53.063  2
14824  92.198  -80.918  53.051  2
14825  92.219  -80.910  53.040  2
14826  92.239  -80.902  53.029  2
14846  92.693  -80.752  53.289  1
14847  92.712  -80.745  53.271  1
14848  92.730  -80.737  53.253  1
14849  92.748  -80.729  53.234  1
14850  92.767  -80.721  53.216  1
14851  92.786  -80.714  53.199  1
14852  92.804  -80.706  53.182  1
14853  92.823  -80.698  53.165  1
14854  92.841  -80.691  53.150  1
14855  92.859  -80.683  53.136  1
14856  92.878  -80.676  53.122  1
14857  92.897  -80.668  53.109  1
14858  92.913  -80.657  53.099  1
14859  92.929  -80.647  53.088  1
14860  92.945  -80.636  53.079  1
14861  92.962  -80.626  53.069  1
14862  92.978  -80.615  53.060  1
14863  92.995  -80.604  53.052  1
14864  93.011  -80.594  53.044  1
14865  93.027  -80.584  53.037  1
14866  93.044  -80.573  53.029  1
14867  93.060  -80.563  53.022  1
14868  93.076  -80.552  53.015  1
14869  93.090  -80.541  53.009  1
14870  93.102  -80.529  53.002  1
14871  93.115  -80.519  52.995  1
14872  93.128  -80.507  52.988  1
14873  93.140  -80.496  52.982  1
14874  93.152  -80.485  52.976  1
14875  93.165  -80.474  52.969  1
14876  93.178  -80.463  52.962  1
14877  93.190  -80.451  52.956  1
14878  93.202  -80.441  52.951  1
14879  93.215  -80.429  52.946  1
14880  93.227  -80.418  52.943  1
14881  93.240  -80.413  52.940  1
14882  93.255  -80.410  52.938  1
14883  93.268  -80.406  52.936  1
14884  93.282  -80.402  52.937  1
14885  93.298  -80.396  52.938  1
14886  93.314  -80.388  52.941  1
14887  93.331  -80.381  52.945  1
14888  93.347  -80.375  52.951  1
14889  93.363  -80.367  52.956  1
14890  93.379  -80.360  52.961  1
14891  93.396  -80.353  52.968  1
14892  93.412  -80.346  52.973  1
14893  93.428  -80.338  52.978  1
14894  93.438  -80.335  52.981  1
14895  93.448  -80.331  52.983  1
14896  93.458  -80.328  52.985  1
14897  93.468  -80.325  52.986  1
14898  93.478  -80.322  52.987  1
14899  93.483  -80.317  52.986  1
14900  93.487  -80.312  52.983  1
14901  93.490  -80.308  52.975  1
14902  93.493  -80.303  52.966  1
14903  93.503  -80.294  52.955  1
14904  93.513  -80.286  52.946  1
14905  93.523  -80.277  52.938  1
14906  93.534  -80.269  52.930  1
14907  93.544  -80.260  52.922  1
14908  93.554  -80.251  52.915  1
14909  93.564  -80.243  52.908  1
14910  93.574  -80.234  52.900  1
14911  93.584  -80.225  52.894  1
14912  93.594  -80.216  52.887  1
14913  93.604  -80.208  52.879  1
15498  91.798  -81.043  53.563  2
15499  91.812  -81.043  53.540  2
15500  91.826  -81.042  53.516  2
15501  91.841  -81.042  53.493  2
15502  91.856  -81.041  53.470  2
15503  91.870  -81.040  53.447  2
15504  91.884  -81.040  53.425  2
15505  91.898  -81.039  53.402  2
15506  91.913  -81.039  53.381  2
15507  91.927  -81.039  53.360  2
15508  91.942  -81.037  53.339  2
15509  91.955  -81.033  53.319  2
15510  91.969  -81.027  53.300  2
15511  91.983  -81.023  53.281  2
15512  91.996  -81.018  53.262  2
15513  92.010  -81.013  53.243  2
15514  92.023  -81.008  53.225  2
15515  92.037  -81.004  53.207  2
15516  92.051  -80.995  53.190  2
15517  92.065  -80.983  53.174  2
15518  92.079  -80.971  53.158  2
15519  92.093  -80.958  53.142  2
15520  92.107  -80.945  53.128  2
15521  92.122  -80.934  53.113  2
15522  92.138  -80.926  53.098  2
15523  92.154  -80.918  53.085  2
15524  92.170  -80.910  53.073  2
15525  92.186  -80.902  53.061  2
15526  92.202  -80.894  53.050  2
15548  92.707  -80.723  53.272  1
15549  92.725  -80.717  53.253  1
15550  92.744  -80.709  53.235  1
15551  92.763  -80.701  53.216  1
15552  92.781  -80.694  53.199  1
15553  92.799  -80.685  53.182  1
15554  92.818  -80.678  53.165  1
15555  92.837  -80.670  53.149  1
15556  92.855  -80.663  53.135  1
15557  92.873  -80.655  53.121  1
15558  92.892  -80.647  53.108  1
15559  92.908  -80.636  53.098  1
15560  92.924  -80.626  53.088  1
15561  92.940  -80.616  53.078  1
15562  92.957  -80.605  53.067  1
15563  92.973  -80.594  53.057  1
15564  92.990  -80.584  53.049  1
15565  93.006  -80.573  53.040  1
15566  93.022  -80.563  53.032  1
15567  93.036  -80.551  53.023  1
15568  93.049  -80.541  53.016  1
15569  93.061  -80.529  53.008  1
15570  93.074  -80.518  53.001  1
15571  93.086  -80.507  52.993  1
15572  93.098  -80.496  52.986  1
15573  93.111  -80.485  52.979  1
15574  93.123  -80.473  52.972  1
15575  93.136  -80.462  52.966  1
15576  93.148  -80.451  52.958  1
15577  93.160  -80.440  52.951  1
15578  93.173  -80.428  52.944  1
15579  93.186  -80.418  52.938  1
15580  93.198  -80.409  52.933  1
15581  93.212  -80.405  52.930  1
15582  93.226  -80.401  52.927  1
15583  93.240  -80.398  52.924  1
15584  93.254  -80.394  52.922  1
15585  93.270  -80.388  52.923  1
15586  93.286  -80.381  52.924  1
15587  93.302  -80.374  52.927  1
15588  93.319  -80.366  52.931  1
15589  93.335  -80.359  52.936  1
15590  93.351  -80.352  52.941  1
15591  93.367  -80.345  52.946  1
15592  93.383  -80.337  52.952  1
15593  93.400  -80.331  52.958  1
15594  93.416  -80.324  52.962  1
15595  93.427  -80.319  52.966  1
15596  93.437  -80.316  52.969  1
15597  93.446  -80.312  52.970  1
15598  93.457  -80.309  52.972  1
15599  93.467  -80.306  52.972  1
15600  93.477  -80.303  52.971  1
15601  93.480  -80.298  52.969  1
15602  93.483  -80.294  52.963  1
15603  93.493  -80.284  52.956  1
15604  93.503  -80.276  52.947  1
15605  93.513  -80.268  52.938  1
15606  93.523  -80.259  52.930  1
15607  93.534  -80.250  52.923  1
15608  93.544  -80.241  52.916  1
15609  93.554  -80.233  52.910  1
15610  93.564  -80.224  52.904  1
15611  93.574  -80.215  52.896  1
15612  93.584  -80.207  52.890  1
15613  93.594  -80.198  52.884  1
15614  93.604  -80.190  52.876  1
16200  91.812  -81.033  53.563  2
16201  91.826  -81.033  53.540  2
16202  91.841  -81.032  53.516  2
16203  91.856  -81.032  53.493  2
16204  91.870  -81.031  53.470  2
16205  91.884  -81.030  53.448  2
16206  91.898  -81.030  53.425  2
16207  91.913  -81.030  53.404  2
16208  91.927  -81.028  53.382  2
16209  91.941  -81.024  53.361  2
16210  91.954  -81.018  53.341  2
16211  91.968  -81.014  53.321  2
16212  91.982  -81.009  53.301  2
16213  91.996  -81.004  53.282  2
16214  92.009  -80.999  53.263  2
16215  92.023  -80.995  53.244  2
16216  92.036  -80.990  53.226  2
16217  92.050  -80.984  53.208  2
16218  92.064  -80.972  53.191  2
16219  92.078  -80.960  53.175  2
16220  92.092  -80.948  53.159  2
16221  92.106  -80.936  53.143  2
16222  92.121  -80.924  53.128  2
16223  92.135  -80.911  53.112  2
16224  92.150  -80.901  53.099  2
16225  92.165  -80.893  53.086  2
16226  92.181  -80.885  53.073  2
16227  92.198  -80.877  53.061  2
16250  92.719  -80.694  53.256  1
16251  92.738  -80.687  53.237  1
16252  92.758  -80.680  53.218  1
16253  92.776  -80.673  53.200  1
16254  92.795  -80.666  53.184  1
16255  92.813  -80.658  53.167  1
16256  92.832  -80.650  53.150  1
16257  92.850  -80.642  53.136  1
16258  92.869  -80.635  53.122  1
16259  92.886  -80.626  53.110  1
16260  92.903  -80.616  53.099  1
16261  92.919  -80.605  53.090  1
16262  92.935  -80.594  53.080  1
16263  92.952  -80.584  53.068  1
16264  92.968  -80.573  53.058  1
16265  92.982  -80.563  53.048  1
16266  92.995  -80.551  53.040  1
16267  93.007  -80.540  53.030  1
16268  93.019  -80.529  53.021  1
16269  93.032  -80.518  53.012  1
16270  93.045  -80.507  53.003  1
16271  93.057  -80.495  52.995  1
16272  93.069  -80.484  52.986  1
16273  93.082  -80.473  52.979  1
16274  93.094  -80.462  52.971  1
16275  93.107  -80.450  52.963  1
16276  93.119  -80.439  52.955  1
16277  93.132  -80.428  52.948  1
16278  93.144  -80.417  52.941  1
16279  93.156  -80.406  52.934  1
16280  93.170  -80.401  52.927  1
16281  93.184  -80.397  52.922  1
16282  93.198  -80.394  52.917  1
16283  93.212  -80.390  52.913  1
16284  93.225  -80.387  52.911  1
16285  93.241  -80.380  52.909  1
16286  93.258  -80.373  52.909  1
16287  93.274  -80.366  52.911  1
16288  93.290  -80.359  52.913  1
16289  93.306  -80.352  52.916  1
16290  93.323  -80.344  52.921  1
16291  93.339  -80.337  52.926  1
16292  93.355  -80.330  52.932  1
16293  93.371  -80.323  52.937  1
16294  93.388  -80.316  52.942  1
16295  93.404  -80.309  52.946  1
16296  93.415  -80.304  52.949  1
16297  93.425  -80.301  52.952  1
16298  93.435  -80.297  52.954  1
16299  93.445  -80.294  52.954  1
16300  93.455  -80.290  52.955  1
16301  93.465  -80.287  52.954  1
16302  93.474  -80.284  52.953  1
16303  93.483  -80.275  52.949  1
16304  93.493  -80.266  52.942  1
16305  93.503  -80.258  52.935  1
16306  93.513  -80.249  52.928  1
16307  93.523  -80.240  52.922  1
16308  93.534  -80.232  52.916  1
16309  93.544  -80.223  52.910  1
16310  93.554  -80.215  52.904  1
16311  93.564  -80.206  52.899  1
16312  93.574  -80.197  52.893  1
16313  93.584  -80.188  52.887  1
16314  93.594  -80.180  52.880  1
16315  93.604  -80.171  52.873  1
16316  93.614  -80.162  52.867  1
16902  91.826  -81.024  53.563  2
16903  91.841  -81.023  53.540  2
16904  91.856  -81.022  53.517  2
16905  91.870  -81.022  53.494  2
16906  91.884  -81.021  53.472  2
16907  91.898  -81.021  53.449  2
16908  91.913  -81.019  53.427  2
16909  91.926  -81.014  53.406  2
16910  91.940  -81.009  53.384  2
16911  91.954  -81.005  53.363  2
16912  91.967  -81.000  53.343  2
16913  91.981  -80.995  53.322  2
16914  91.995  -80.990  53.303  2
16915  92.008  -80.986  53.284  2
16916  92.022  -80.980  53.265  2
16917  92.035  -80.976  53.246  2
16918  92.050  -80.971  53.228  2
16919  92.063  -80.962  53.210  2
16920  92.077  -80.949  53.193  2
16921  92.091  -80.937  53.176  2
16922  92.105  -80.925  53.160  2
16923  92.120  -80.913  53.144  2
16924  92.134  -80.901  53.129  2
16925  92.148  -80.889  53.114  2
16926  92.162  -80.877  53.100  2
16927  92.177  -80.868  53.086  2
16951  92.689  -80.674  53.260  1
16952  92.715  -80.667  53.241  1
16953  92.741  -80.659  53.223  1
16954  92.768  -80.651  53.205  1
16955  92.789  -80.644  53.188  1
16956  92.809  -80.638  53.171  1
16957  92.827  -80.630  53.154  1
16958  92.846  -80.623  53.139  1
16959  92.864  -80.614  53.125  1
16960  92.881  -80.605  53.113  1
16961  92.898  -80.594  53.104  1
16962  92.914  -80.584  53.095  1
16963  92.928  -80.573  53.085  1
16964  92.941  -80.562  53.074  1
16965  92.953  -80.551  53.063  1
16966  92.966  -80.540  53.053  1
16967  92.978  -80.529  53.042  1
16968  92.991  -80.517  53.033  1
16969  93.003  -80.506  53.023  1
16970  93.015  -80.495  53.011  1
16971  93.028  -80.484  53.000  1
16972  93.040  -80.472  52.991  1
16973  93.053  -80.461  52.981  1
16974  93.065  -80.450  52.973  1
16975  93.077  -80.439  52.964  1
16976  93.090  -80.428  52.956  1
16977  93.102  -80.416  52.947  1
16978  93.115  -80.406  52.939  1
16979  93.128  -80.397  52.932  1
16980  93.142  -80.393  52.924  1
16981  93.155  -80.390  52.917  1
16982  93.169  -80.386  52.911  1
16983  93.183  -80.382  52.905  1
16984  93.197  -80.378  52.901  1
16985  93.213  -80.372  52.898  1
16986  93.229  -80.365  52.897  1
16987  93.246  -80.358  52.897  1
16988  93.262  -80.351  52.898  1
16989  93.278  -80.344  52.900  1
16990  93.294  -80.337  52.905  1
16991  93.310  -80.329  52.909  1
16992  93.327  -80.322  52.914  1
16993  93.343  -80.316  52.918  1
16994  93.359  -80.308  52.922  1
16995  93.375  -80.301  52.925  1
16996  93.392  -80.294  52.929  1
16997  93.404  -80.289  52.931  1
16998  93.414  -80.286  52.932  1
16999  93.424  -80.282  52.934  1
17000  93.433  -80.279  52.935  1
17001  93.443  -80.275  52.935  1
17002  93.453  -80.272  52.936  1
17003  93.463  -80.256  52.936  1
17004  93.483  -80.256  52.932  1
17005  93.493  -80.248  52.927  1
17006  93.503  -80.240  52.922  1
17007  93.513  -80.231  52.917  1
17008  93.523  -80.222  52.913  1
17009  93.534  -80.213  52.909  1
17010  93.544  -80.205  52.904  1
17011  93.554  -80.196  52.898  1
17012  93.564  -80.187  52.894  1
17013  93.574  -80.179  52.889  1
17014  93.584  -80.170  52.883  1
17015  93.594  -80.162  52.877  1
17016  93.604  -80.153  52.871  1
17017  93.614  -80.144  52.865  1
17058  93.990  -79.964  52.391  1
17059  93.999  -79.962  52.375  1
17060  94.007  -79.961  52.361  1
17061  94.016  -79.959  52.346  1
17062  94.025  -79.958  52.330  1
17063  94.033  -79.956  52.315  1
17064  94.042  -79.955  52.299  1
17065  94.050  -79.953  52.284  1
17066  94.059  -79.952  52.268  1
17603  91.826  -81.014  53.587  2
17604  91.841  -81.013  53.564  2
17605  91.856  -81.013  53.541  2
17606  91.870  -81.012  53.518  2
17607  91.884  -81.012  53.496  2
17608  91.898  -81.010  53.473  2
17609  91.912  -81.005  53.451  2
17610  91.926  -81.000  53.429  2
17611  91.939  -80.996  53.407  2
17612  91.953  -80.991  53.387  2
17613  91.966  -80.986  53.366  2
17614  91.980  -80.981  53.346  2
17615  91.994  -80.977  53.326  2
17616  92.008  -80.971  53.307  2
17617  92.021  -80.967  53.287  2
17618  92.035  -80.962  53.268  2
17619  92.049  -80.958  53.249  2
17620  92.062  -80.952  53.230  2
17621  92.076  -80.939  53.213  2
17622  92.090  -80.927  53.196  2
17623  92.104  -80.915  53.179  2
17624  92.119  -80.903  53.162  2
17625  92.133  -80.890  53.147  2
17626  92.147  -80.878  53.131  2
17627  92.161  -80.866  53.116  2
17652  92.651  -80.655  53.266  1
17653  92.677  -80.648  53.247  1
17654  92.704  -80.640  53.230  1
17655  92.730  -80.632  53.211  1
17656  92.757  -80.625  53.193  1
17657  92.783  -80.617  53.176  1
17658  92.809  -80.610  53.160  1
17659  92.836  -80.601  53.145  1
17660  92.860  -80.594  53.131  1
17661  92.874  -80.584  53.120  1
17662  92.887  -80.573  53.110  1
17663  92.899  -80.561  53.101  1
17664  92.912  -80.551  53.091  1
17665  92.924  -80.539  53.080  1
17666  92.936  -80.528  53.070  1
17667  92.949  -80.517  53.059  1
17668  92.961  -80.506  53.048  1
17669  92.974  -80.494  53.038  1
17670  92.986  -80.483  53.027  1
17671  92.999  -80.472  53.014  1
17672  93.011  -80.461  53.001  1
17673  93.023  -80.450  52.989  1
17674  93.036  -80.438  52.978  1
17675  93.049  -80.428  52.968  1
17676  93.061  -80.416  52.958  1
17677  93.073  -80.405  52.950  1
17678  93.086  -80.394  52.941  1
17679  93.099  -80.389  52.932  1
17680  93.113  -80.385  52.924  1
17681  93.127  -80.381  52.915  1
17682  93.141  -80.378  52.908  1
17683  93.155  -80.375  52.901  1
17684  93.168  -80.371  52.895  1
17685  93.185  -80.364  52.891  1
17686  93.201  -80.357  52.888  1
17687  93.217  -80.350  52.887  1
17688  93.233  -80.343  52.886  1
17689  93.250  -80.336  52.888  1
17690  93.266  -80.329  52.890  1
17691  93.282  -80.322  52.895  1
17692  93.298  -80.315  52.899  1
17693  93.314  -80.307  52.902  1
17694  93.331  -80.300  52.905  1
17695  93.347  -80.293  52.907  1
17696  93.363  -80.286  52.909  1
17697  93.379  -80.278  52.911  1
17698  93.392  -80.274  52.912  1
17699  93.402  -80.270  52.914  1
17700  93.412  -80.267  52.916  1
17701  93.422  -80.263  52.917  1
17702  93.432  -80.260  52.917  1
17703  93.442  -80.243  52.917  1
17704  93.451  -80.225  52.917  1
17705  93.465  -80.226  52.916  1
17706  93.488  -80.227  52.913  1
17707  93.503  -80.221  52.909  1
17708  93.513  -80.212  52.906  1
17709  93.523  -80.204  52.903  1
17710  93.534  -80.195  52.901  1
17711  93.544  -80.187  52.897  1
17712  93.554  -80.178  52.892  1
17713  93.564  -80.169  52.889  1
17714  93.574  -80.160  52.884  1
17715  93.584  -80.152  52.879  1
17716  93.594  -80.143  52.874  1
17717  93.604  -80.134  52.869  1
17718  93.614  -80.126  52.863  1
17719  93.624  -80.117  52.857  1
17758  93.981  -79.951  52.416  1
17759  93.989  -79.949  52.401  1
17760  93.998  -79.948  52.386  1
17761  94.006  -79.946  52.372  1
17762  94.015  -79.945  52.357  1
17763  94.024  -79.943  52.341  1
17764  94.032  -79.942  52.326  1
17765  94.041  -79.940  52.310  1
17766  94.049  -79.939  52.295  1
17767  94.058  -79.938  52.279  1
17768  94.066  -79.936  52.263  1
18305  91.841  -81.004  53.588  2
18306  91.856  -81.003  53.565  2
18307  91.870  -81.003  53.542  2
18308  91.884  -81.001  53.520  2
18309  91.897  -80.996  53.497  2
18310  91.911  -80.991  53.476  2
18311  91.925  -80.986  53.454  2
18312  91.939  -80.982  53.432  2
18313  91.952  -80.977  53.411  2
18314  91.966  -80.972  53.390  2
18315  91.980  -80.967  53.370  2
18316  91.993  -80.962  53.350  2
18317  92.007  -80.958  53.330  2
18318  92.020  -80.953  53.310  2
18319  92.034  -80.948  53.290  2
18320  92.048  -80.943  53.271  2
18321  92.062  -80.939  53.252  2
18322  92.075  -80.929  53.234  2
18323  92.089  -80.917  53.217  2
18324  92.103  -80.905  53.199  2
18325  92.118  -80.892  53.182  2
18326  92.132  -80.880  53.166  2
18327  92.146  -80.868  53.149  2
18353  92.616  -80.638  53.274  1
18354  92.641  -80.629  53.256  1
18355  92.666  -80.622  53.237  1
18356  92.693  -80.613  53.219  1
18357  92.719  -80.606  53.201  1
18358  92.745  -80.598  53.183  1
18359  92.772  -80.591  53.167  1
18360  92.798  -80.583  53.152  1
18361  92.824  -80.576  53.139  1
18362  92.850  -80.568  53.129  1
18363  92.868  -80.554  53.119  1
18364  92.882  -80.539  53.108  1
18365  92.895  -80.528  53.098  1
18366  92.908  -80.516  53.087  1
18367  92.920  -80.505  53.077  1
18368  92.932  -80.494  53.067  1
18369  92.945  -80.483  53.055  1
18370  92.957  -80.472  53.043  1
18371  92.970  -80.460  53.031  1
18372  92.982  -80.450  53.018  1
18373  92.995  -80.438  53.005  1
18374  93.007  -80.427  52.991  1
18375  93.019  -80.416  52.978  1
18376  93.032  -80.405  52.967  1
18377  93.044  -80.394  52.956  1
18378  93.057  -80.385  52.946  1
18379  93.071  -80.381  52.937  1
18380  93.085  -80.378  52.928  1
18381  93.098  -80.374  52.919  1
18382  93.113  -80.370  52.910  1
18383  93.126  -80.367  52.902  1
18384  93.140  -80.363  52.894  1
18385  93.156  -80.356  52.888  1
18386  93.172  -80.350  52.884  1
18387  93.189  -80.342  52.880  1
18388  93.205  -80.335  52.878  1
18389  93.221  -80.328  52.879  1
18390  93.237  -80.321  52.880  1
18391  93.254  -80.314  52.882  1
18392  93.270  -80.306  52.885  1
18393  93.286  -80.300  52.888  1
18394  93.302  -80.293  52.891  1
18395  93.319  -80.285  52.892  1
18396  93.335  -80.278  52.892  1
18397  93.351  -80.271  52.893  1
18398  93.367  -80.264  52.893  1
18399  93.380  -80.259  52.894  1
18400  93.391  -80.255  52.896  1
18401  93.401  -80.252  52.897  1
18402  93.410  -80.248  52.898  1
18403  93.420  -80.233  52.899  1
18404  93.430  -80.211  52.899  1
18405  93.439  -80.194  52.900  1
18406  93.445  -80.196  52.899  1
18407  93.470  -80.196  52.898  1
18408  93.493  -80.196  52.897  1
18409  93.513  -80.194  52.895  1
18410  93.523  -80.185  52.894  1
18411  93.534  -80.177  52.892  1
18412  93.544  -80.168  52.890  1
18413  93.554  -80.159  52.887  1
18414  93.564  -80.151  52.884  1
18415  93.574  -80.142  52.881  1
18416  93.584  -80.134  52.876  1
18417  93.594  -80.124  52.871  1
18418  93.604  -80.116  52.867  1
18419  93.614  -80.107  52.861  1
18420  93.624  -80.099  52.856  1
18421  93.634  -80.090  52.851  1
18458  93.971  -79.938  52.440  1
18459  93.980  -79.936  52.425  1
18460  93.988  -79.935  52.410  1
18461  93.997  -79.933  52.396  1
18462  94.005  -79.932  52.382  1
18463  94.014  -79.930  52.367  1
18464  94.023  -79.929  52.352  1
18465  94.031  -79.927  52.336  1
18466  94.040  -79.926  52.321  1
18467  94.048  -79.925  52.305  1
18468  94.057  -79.924  52.290  1
18469  94.065  -79.922  52.275  1
18470  94.074  -79.921  52.259  1
18497  94.231  -79.587  51.699  1
18498  94.244  -79.567  51.671  1
18499  94.257  -79.548  51.644  1
18500  94.269  -79.528  51.616  1
18501  94.282  -79.508  51.586  1
18502  94.295  -79.488  51.558  1
18503  94.308  -79.469  51.530  1
18504  94.320  -79.449  51.501  1
18505  94.337  -79.471  51.473  1
18506  94.353  -79.503  51.443  1
18507  94.370  -79.534  51.413  1
18508  94.388  -79.565  51.383  1
18509  94.405  -79.596  51.353  1
19007  91.856  -80.994  53.588  2
19008  91.869  -80.992  53.566  2
19009  91.883  -80.986  53.544  2
19010  91.897  -80.982  53.522  2
19011  91.911  -80.977  53.501  2
19012  91.924  -80.972  53.479  2
19013  91.938  -80.967  53.456  2
19014  91.951  -80.963  53.436  2
19015  91.965  -80.958  53.416  2
19016  91.979  -80.953  53.395  2
19017  91.993  -80.949  53.374  2
19018  92.006  -80.944  53.353  2
19019  92.020  -80.939  53.333  2
19020  92.033  -80.934  53.313  2
19021  92.047  -80.930  53.294  2
19022  92.061  -80.925  53.275  2
19023  92.074  -80.919  53.257  2
19024  92.088  -80.907  53.238  2
19025  92.102  -80.894  53.220  2
19026  92.117  -80.882  53.203  2
19027  92.131  -80.870  53.186  2
19054  92.598  -80.621  53.285  1
19055  92.619  -80.613  53.266  1
19056  92.640  -80.604  53.248  1
19057  92.661  -80.596  53.229  1
19058  92.683  -80.588  53.210  1
19059  92.708  -80.580  53.192  1
19060  92.734  -80.572  53.176  1
19061  92.760  -80.564  53.161  1
19062  92.786  -80.557  53.147  1
19063  92.812  -80.549  53.136  1
19064  92.839  -80.541  53.126  1
19065  92.859  -80.529  53.117  1
19066  92.873  -80.514  53.106  1
19067  92.888  -80.500  53.096  1
19068  92.902  -80.485  53.086  1
19069  92.916  -80.471  53.075  1
19070  92.928  -80.460  53.062  1
19071  92.940  -80.449  53.049  1
19072  92.953  -80.438  53.035  1
19073  92.966  -80.426  53.022  1
19074  92.978  -80.416  53.009  1
19075  92.990  -80.404  52.994  1
19076  93.003  -80.393  52.979  1
19077  93.015  -80.382  52.967  1
19078  93.029  -80.377  52.955  1
19079  93.043  -80.373  52.945  1
19080  93.057  -80.370  52.935  1
19081  93.070  -80.366  52.925  1
19082  93.084  -80.363  52.915  1
19083  93.098  -80.359  52.906  1
19084  93.112  -80.356  52.898  1
19085  93.128  -80.349  52.890  1
19086  93.144  -80.341  52.884  1
19087  93.160  -80.334  52.879  1
19088  93.177  -80.328  52.876  1
19089  93.193  -80.320  52.873  1
19090  93.209  -80.313  52.873  1
19091  93.225  -80.306  52.874  1
19092  93.241  -80.299  52.875  1
19093  93.258  -80.292  52.877  1
19094  93.274  -80.284  52.878  1
19095  93.290  -80.278  52.878  1
19096  93.306  -80.270  52.879  1
19097  93.323  -80.263  52.879  1
19098  93.339  -80.256  52.878  1
19099  93.355  -80.249  52.877  1
19100  93.369  -80.243  52.878  1
19101  93.379  -80.240  52.878  1
19102  93.389  -80.237  52.878  1
19103  93.399  -80.222  52.879  1
19104  93.409  -80.201  52.881  1
19105  93.419  -80.179  52.883  1
19106  93.427  -80.163  52.883  1
19107  93.433  -80.165  52.883  1
19108  93.450  -80.165  52.884  1
19109  93.475  -80.165  52.885  1
19110  93.498  -80.166  52.885  1
19111  93.522  -80.166  52.884  1
19112  93.534  -80.159  52.883  1
19113  93.544  -80.149  52.883  1
19114  93.554  -80.141  52.881  1
19115  93.564  -80.132  52.879  1
19116  93.574  -80.124  52.876  1
19117  93.584  -80.115  52.872  1
19118  93.594  -80.106  52.868  1
19119  93.604  -80.098  52.864  1
19120  93.614  -80.089  52.859  1
19121  93.624  -80.080  52.853  1
19122  93.634  -80.071  52.848  1
19123  93.644  -80.063  52.841  1
19158  93.962  -79.925  52.462  1
19159  93.970  -79.924  52.448  1
19160  93.979  -79.922  52.434  1
19161  93.987  -79.921  52.419  1
19162  93.996  -79.919  52.405  1
19163  94.004  -79.918  52.391  1
19164  94.013  -79.916  52.377  1
19165  94.022  -79.914  52.361  1
19166  94.030  -79.913  52.346  1
19167  94.039  -79.912  52.330  1
19168  94.047  -79.911  52.315  1
19169  94.056  -79.909  52.299  1
19170  94.064  -79.908  52.284  1
19171  94.073  -79.906  52.268  1
19196  94.251  -79.560  51.765  1
19197  94.241  -79.567  51.738  1
19198  94.229  -79.573  51.712  1
19199  94.241  -79.554  51.685  1
19200  94.254  -79.535  51.657  1
19201  94.266  -79.515  51.629  1
19202  94.279  -79.495  51.600  1
19203  94.292  -79.476  51.572  1
19204  94.305  -79.456  51.543  1
19205  94.317  -79.436  51.514  1
19206  94.332  -79.439  51.486  1
19207  94.349  -79.471  51.456  1
19208  94.366  -79.502  51.426  1
19209  94.383  -79.533  51.395  1
19210  94.400  -79.565  51.365  1
19211  94.417  -79.596  51.334  1
19212  94.434  -79.627  51.304  1
19709  91.869  -80.977  53.589  2
19710  91.882  -80.973  53.567  2
19711  91.896  -80.968  53.546  2
19712  91.910  -80.963  53.524  2
19713  91.923  -80.958  53.503  2
19714  91.937  -80.954  53.482  2
19715  91.951  -80.949  53.461  2
19716  91.964  -80.944  53.440  2
19717  91.978  -80.939  53.419  2
19718  91.992  -80.935  53.398  2
19719  92.005  -80.930  53.377  2
19720  92.019  -80.925  53.358  2
19721  92.032  -80.920  53.337  2
19722  92.047  -80.915  53.317  2
19723  92.060  -80.911  53.298  2
19724  92.074  -80.906  53.279  2
19725  92.087  -80.896  53.261  2
19726  92.101  -80.884  53.242  2
19727  92.116  -80.872  53.224  2
19755  92.581  -80.605  53.296  1
19756  92.602  -80.597  53.278  1
19757  92.623  -80.588  53.259  1
19758  92.644  -80.580  53.240  1
19759  92.665  -80.572  53.221  1
19760  92.686  -80.563  53.203  1
19761  92.707  -80.555  53.187  1
19762  92.727  -80.547  53.171  1
19763  92.749  -80.538  53.157  1
19764  92.775  -80.531  53.145  1
19765  92.801  -80.522  53.136  1
19766  92.828  -80.515  53.127  1
19767  92.850  -80.505  53.117  1
19768  92.864  -80.490  53.107  1
19769  92.879  -80.475  53.096  1
19770  92.894  -80.460  53.084  1
19771  92.908  -80.444  53.070  1
19772  92.922  -80.429  53.056  1
19773  92.936  -80.415  53.042  1
19774  92.949  -80.403  53.028  1
19775  92.961  -80.393  53.013  1
19776  92.974  -80.381  52.998  1
19777  92.987  -80.373  52.982  1
19778  93.000  -80.369  52.968  1
19779  93.014  -80.366  52.956  1
19780  93.028  -80.362  52.945  1
19781  93.042  -80.358  52.935  1
19782  93.056  -80.355  52.924  1
19783  93.070  -80.351  52.913  1
19784  93.083  -80.347  52.904  1
19785  93.099  -80.341  52.895  1
19786  93.116  -80.334  52.888  1
19787  93.132  -80.327  52.882  1
19788  93.148  -80.319  52.877  1
19789  93.164  -80.312  52.874  1
19790  93.181  -80.306  52.872  1
19791  93.197  -80.298  52.870  1
19792  93.213  -80.291  52.869  1
19793  93.229  -80.284  52.869  1
19794  93.246  -80.277  52.869  1
19795  93.262  -80.270  52.869  1
19796  93.278  -80.262  52.868  1
19797  93.294  -80.256  52.869  1
19798  93.311  -80.248  52.868  1
19799  93.327  -80.241  52.867  1
19800  93.343  -80.234  52.866  1
19801  93.357  -80.228  52.865  1
19802  93.367  -80.225  52.864  1
19803  93.377  -80.212  52.863  1
19804  93.387  -80.190  52.864  1
19805  93.397  -80.169  52.866  1
19806  93.407  -80.148  52.869  1
19807  93.416  -80.132  52.870  1
19808  93.421  -80.134  52.871  1
19809  93.432  -80.134  52.873  1
19810  93.455  -80.135  52.874  1
19811  93.479  -80.135  52.875  1
19812  93.503  -80.136  52.876  1
19813  93.527  -80.136  52.876  1
19814  93.544  -80.131  52.876  1
19815  93.554  -80.123  52.875  1
19816  93.564  -80.114  52.875  1
19817  93.574  -80.106  52.871  1
19818  93.584  -80.096  52.868  1
19819  93.594  -80.088  52.865  1
19820  93.604  -80.079  52.861  1
19821  93.614  -80.071  52.856  1
19822  93.624  -80.062  52.851  1
19823  93.634  -80.053  52.846  1
19824  93.644  -80.045  52.839  1
19825  93.654  -80.036  52.832  1
19858  93.953  -79.912  52.484  1
19859  93.961  -79.911  52.470  1
19860  93.970  -79.909  52.457  1
19861  93.978  -79.908  52.442  1
19862  93.987  -79.906  52.428  1
19863  93.995  -79.905  52.414  1
19864  94.004  -79.903  52.400  1
19865  94.012  -79.902  52.386  1
19866  94.021  -79.900  52.370  1
19867  94.030  -79.899  52.355  1
19868  94.038  -79.898  52.340  1
19869  94.047  -79.896  52.325  1
19870  94.055  -79.895  52.309  1
19871  94.064  -79.893  52.293  1
19872  94.072  -79.892  52.277  1
19873  94.081  -79.890  52.260  1
19896  94.265  -79.535  51.804  1
19897  94.255  -79.541  51.778  1
19898  94.244  -79.546  51.752  1
19899  94.232  -79.552  51.725  1
19900  94.238  -79.541  51.699  1
19901  94.251  -79.521  51.672  1
19902  94.263  -79.501  51.643  1
19903  94.276  -79.482  51.614  1
19904  94.289  -79.462  51.586  1
19905  94.301  -79.442  51.558  1
19906  94.315  -79.422  51.528  1
19907  94.328  -79.408  51.500  1
19908  94.345  -79.439  51.470  1
19909  94.361  -79.470  51.439  1
19910  94.379  -79.502  51.408  1
19911  94.396  -79.533  51.377  1
19912  94.413  -79.564  51.347  1
19913  94.429  -79.595  51.316  1
19914  94.447  -79.627  51.285  1
20412  91.895  -80.954  53.569  2
20413  91.909  -80.949  53.548  2
20414  91.923  -80.945  53.527  2
20415  91.936  -80.939  53.506  2
20416  91.950  -80.935  53.485  2
20417  91.963  -80.930  53.464  2
20418  91.977  -80.926  53.443  2
20419  91.991  -80.920  53.422  2
20420  92.005  -80.916  53.402  2
20421  92.018  -80.911  53.382  2
20422  92.032  -80.906  53.361  2
20423  92.046  -80.902  53.341  2
20424  92.059  -80.897  53.322  2
20425  92.073  -80.892  53.302  2
20426  92.087  -80.886  53.284  2
20427  92.101  -80.873  53.265  2
20456  92.565  -80.588  53.309  1
20457  92.586  -80.580  53.290  1
20458  92.606  -80.572  53.272  1
20459  92.628  -80.563  53.253  1
20460  92.648  -80.555  53.234  1
20461  92.669  -80.547  53.216  1
20462  92.690  -80.538  53.199  1
20463  92.711  -80.530  53.183  1
20464  92.732  -80.522  53.167  1
20465  92.753  -80.513  53.156  1
20466  92.773  -80.505  53.146  1
20467  92.794  -80.497  53.138  1
20468  92.816  -80.489  53.129  1
20469  92.841  -80.480  53.119  1
20470  92.855  -80.465  53.108  1
20471  92.870  -80.450  53.094  1
20472  92.884  -80.435  53.079  1
20473  92.899  -80.419  53.064  1
20474  92.913  -80.404  53.049  1
20475  92.930  -80.388  53.033  1
20476  92.946  -80.371  53.018  1
20477  92.962  -80.365  53.002  1
20478  92.977  -80.364  52.985  1
20479  92.992  -80.362  52.971  1
20480  93.007  -80.359  52.958  1
20481  93.022  -80.356  52.947  1
20482  93.038  -80.353  52.936  1
20483  93.053  -80.350  52.926  1
20484  93.066  -80.344  52.915  1
20485  93.078  -80.337  52.907  1
20486  93.091  -80.328  52.898  1
20487  93.105  -80.319  52.890  1
20488  93.120  -80.312  52.884  1
20489  93.136  -80.305  52.879  1
20490  93.152  -80.298  52.875  1
20491  93.169  -80.290  52.873  1
20492  93.185  -80.284  52.869  1
20493  93.201  -80.276  52.866  1
20494  93.217  -80.269  52.864  1
20495  93.234  -80.262  52.862  1
20496  93.250  -80.255  52.862  1
20497  93.266  -80.247  52.861  1
20498  93.282  -80.240  52.860  1
20499  93.298  -80.233  52.859  1
20500  93.315  -80.226  52.857  1
20501  93.331  -80.218  52.856  1
20502  93.346  -80.212  52.854  1
20503  93.356  -80.202  52.853  1
20504  93.365  -80.181  52.852  1
20505  93.375  -80.159  52.853  1
20506  93.386  -80.137  52.855  1
20507  93.395  -80.116  52.857  1
20508  93.404  -80.101  52.859  1
20509  93.410  -80.102  52.860  1
20510  93.415  -80.104  52.861  1
20511  93.436  -80.104  52.863  1
20512  93.461  -80.105  52.865  1
20513  93.484  -80.105  52.867  1
20514  93.508  -80.106  52.869  1
20515  93.532  -80.106  52.869  1
20516  93.554  -80.104  52.870  1
20517  93.564  -80.096  52.870  1
20518  93.573  -80.087  52.868  1
20519  93.583  -80.078  52.866  1
20520  93.593  -80.070  52.862  1
20521  93.604  -80.061  52.858  1
20522  93.614  -80.052  52.853  1
20523  93.624  -80.043  52.848  1
20524  93.634  -80.035  52.843  1
20525  93.644  -80.026  52.837  1
20526  93.654  -80.018  52.830  1
20527  93.664  -80.009  52.823  1
20557  93.934  -79.901  52.517  1
20558  93.943  -79.899  52.505  1
20559  93.952  -79.898  52.492  1
20560  93.960  -79.896  52.479  1
20561  93.969  -79.895  52.465  1
20562  93.977  -79.893  52.451  1
20563  93.986  -79.892  52.438  1
20564  93.994  -79.890  52.425  1
20565  94.003  -79.889  52.410  1
20566  94.011  -79.887  52.395  1
20567  94.020  -79.886  52.381  1
20568  94.029  -79.885  52.365  1
20569  94.037  -79.883  52.349  1
20570  94.046  -79.882  52.334  1
20571  94.054  -79.880  52.318  1
20572  94.063  -79.879  52.302  1
20573  94.071  -79.877  52.286  1
20574  94.080  -79.876  52.270  1
20575  94.088  -79.874  52.253  1
20596  94.268  -79.528  51.841  1
20597  94.269  -79.515  51.816  1
20598  94.258  -79.520  51.790  1
20599  94.247  -79.526  51.765  1
20600  94.236  -79.532  51.739  1
20601  94.235  -79.527  51.713  1
20602  94.248  -79.507  51.686  1
20603  94.260  -79.488  51.657  1
20604  94.273  -79.468  51.629  1
20605  94.286  -79.448  51.601  1
20606  94.298  -79.429  51.572  1
20607  94.312  -79.409  51.543  1
20608  94.324  -79.389  51.515  1
20609  94.340  -79.407  51.485  1
20610  94.357  -79.439  51.453  1
20611  94.374  -79.470  51.423  1
20612  94.391  -79.501  51.392  1
20613  94.408  -79.532  51.360  1
20614  94.425  -79.564  51.329  1
20615  94.442  -79.595  51.297  1
20616  94.459  -79.626  51.266  1
20617  94.476  -79.658  51.234  1
21115  91.922  -80.930  53.551  2
21116  91.936  -80.926  53.530  2
21117  91.949  -80.921  53.509  2
21118  91.963  -80.917  53.488  2
21119  91.977  -80.911  53.468  2
21120  91.990  -80.907  53.447  2
21121  92.004  -80.902  53.427  2
21122  92.017  -80.897  53.406  2
21123  92.031  -80.892  53.385  2
21124  92.045  -80.888  53.366  2
21125  92.059  -80.883  53.346  2
21126  92.072  -80.878  53.326  2
21157  92.548  -80.573  53.324  1
21158  92.569  -80.564  53.305  1
21159  92.590  -80.556  53.286  1
21160  92.611  -80.547  53.267  1
21161  92.632  -80.539  53.249  1
21162  92.652  -80.531  53.231  1
21163  92.673  -80.522  53.214  1
21164  92.694  -80.514  53.197  1
21165  92.715  -80.506  53.181  1
21166  92.736  -80.497  53.169  1
21167  92.757  -80.489  53.159  1
21168  92.778  -80.481  53.150  1
21169  92.798  -80.472  53.142  1
21170  92.819  -80.464  53.132  1
21171  92.840  -80.456  53.120  1
21172  92.863  -80.432  53.106  1
21173  92.883  -80.408  53.090  1
21174  92.901  -80.391  53.073  1
21175  92.917  -80.374  53.056  1
21176  92.934  -80.357  53.039  1
21177  92.951  -80.341  53.022  1
21178  92.966  -80.336  53.005  1
21179  92.981  -80.339  52.989  1
21180  92.995  -80.342  52.975  1
21181  93.009  -80.346  52.962  1
21182  93.023  -80.349  52.950  1
21183  93.036  -80.347  52.939  1
21184  93.048  -80.341  52.929  1
21185  93.060  -80.334  52.919  1
21186  93.072  -80.326  52.910  1
21187  93.085  -80.318  52.901  1
21188  93.099  -80.309  52.893  1
21189  93.113  -80.300  52.886  1
21190  93.126  -80.291  52.881  1
21191  93.140  -80.283  52.876  1
21192  93.157  -80.275  52.872  1
21193  93.173  -80.269  52.868  1
21194  93.189  -80.261  52.863  1
21195  93.205  -80.254  52.860  1
21196  93.221  -80.247  52.859  1
21197  93.238  -80.240  52.857  1
21198  93.255  -80.233  52.856  1
21199  93.271  -80.225  52.854  1
21200  93.288  -80.218  52.852  1
21201  93.304  -80.211  52.849  1
21202  93.321  -80.204  52.848  1
21203  93.334  -80.192  52.847  1
21204  93.344  -80.170  52.846  1
21205  93.354  -80.149  52.845  1
21206  93.364  -80.127  52.845  1
21207  93.373  -80.106  52.845  1
21208  93.383  -80.084  52.846  1
21209  93.392  -80.069  52.848  1
21210  93.398  -80.071  52.850  1
21211  93.404  -80.073  52.851  1
21212  93.418  -80.074  52.854  1
21213  93.441  -80.074  52.857  1
21214  93.466  -80.074  52.860  1
21215  93.489  -80.074  52.863  1
21216  93.513  -80.075  52.864  1
21217  93.537  -80.075  52.865  1
21218  93.561  -80.076  52.866  1
21219  93.573  -80.068  52.865  1
21220  93.583  -80.060  52.863  1
21221  93.593  -80.051  52.860  1
21222  93.604  -80.043  52.856  1
21223  93.614  -80.034  52.851  1
21224  93.624  -80.025  52.846  1
21225  93.634  -80.017  52.841  1
21226  93.644  -80.008  52.835  1
21227  93.654  -79.999  52.828  1
21228  93.664  -79.990  52.822  1
21229  93.674  -79.982  52.814  1
21230  93.684  -79.973  52.805  1
21231  93.694  -79.965  52.796  1
21232  93.704  -79.956  52.788  1
21233  93.714  -79.947  52.779  1
21234  93.724  -79.939  52.769  1
21235  93.734  -79.930  52.760  1
21236  93.745  -79.921  52.750  1
21258  93.933  -79.886  52.524  1
21259  93.942  -79.885  52.512  1
21260  93.951  -79.883  52.500  1
21261  93.959  -79.882  52.487  1
21262  93.968  -79.880  52.474  1
21263  93.976  -79.879  52.460  1
21264  93.985  -79.877  52.447  1
21265  93.993  -79.876  52.434  1
21266  94.002  -79.874  52.420  1
21267  94.010  -79.874  52.405  1
21268  94.019  -79.872  52.390  1
21269  94.028  -79.871  52.375  1
21270  94.036  -79.869  52.359  1
21271  94.045  -79.867  52.344  1
21272  94.053  -79.866  52.328  1
21273  94.062  -79.864  52.312  1
21274  94.070  -79.863  52.295  1
21275  94.079  -79.861  52.279  1
21276  94.087  -79.860  52.262  1
21296  94.259  -79.541  51.878  1
21297  94.267  -79.514  51.853  1
21298  94.272  -79.494  51.828  1
21299  94.261  -79.501  51.803  1
21300  94.250  -79.507  51.778  1
21301  94.239  -79.512  51.753  1
21302  94.232  -79.514  51.727  1
21303  94.245  -79.494  51.699  1
21304  94.258  -79.475  51.671  1
21305  94.270  -79.455  51.643  1
21306  94.283  -79.435  51.615  1
21307  94.296  -79.416  51.587  1
21308  94.309  -79.396  51.558  1
21309  94.321  -79.376  51.529  1
21310  94.336  -79.376  51.499  1
21311  94.353  -79.407  51.468  1
21312  94.369  -79.438  51.437  1
21313  94.387  -79.469  51.405  1
21314  94.404  -79.501  51.373  1
21315  94.421  -79.532  51.342  1
21316  94.437  -79.563  51.310  1
21317  94.455  -79.595  51.277  1
21318  94.472  -79.626  51.245  1
21319  94.485  -79.664  51.212  1
21320  94.493  -79.707  51.179  1
21819  91.962  -80.902  53.513  2
21820  91.976  -80.898  53.492  2
21821  91.990  -80.893  53.472  2
21822  92.003  -80.888  53.451  2
21823  92.017  -80.883  53.430  2
21858  92.533  -80.556  53.339  1
21859  92.553  -80.548  53.321  1
21860  92.573  -80.540  53.301  1
21861  92.594  -80.532  53.283  1
21862  92.615  -80.523  53.265  1
21863  92.636  -80.515  53.247  1
21864  92.657  -80.507  53.229  1
21865  92.677  -80.498  53.212  1
21866  92.698  -80.490  53.196  1
21867  92.719  -80.482  53.184  1
21868  92.740  -80.473  53.174  1
21869  92.761  -80.465  53.165  1
21870  92.782  -80.457  53.156  1
21871  92.802  -80.448  53.146  1
21872  92.824  -80.440  53.133  1
21873  92.844  -80.431  53.117  1
21874  92.866  -80.415  53.101  1
21875  92.889  -80.388  53.084  1
21876  92.912  -80.360  53.066  1
21877  92.935  -80.333  53.048  1
21878  92.955  -80.309  53.030  1
21879  92.971  -80.306  53.013  1
21880  92.983  -80.311  52.996  1
21881  92.994  -80.316  52.981  1
21882  93.006  -80.321  52.968  1
21883  93.018  -80.326  52.955  1
21884  93.030  -80.331  52.944  1
21885  93.042  -80.330  52.933  1
21886  93.054  -80.323  52.924  1
21887  93.067  -80.316  52.914  1
21888  93.080  -80.306  52.904  1
21889  93.093  -80.298  52.895  1
21890  93.107  -80.289  52.888  1
21891  93.119  -80.279  52.882  1
21892  93.136  -80.270  52.877  1
21893  93.161  -80.262  52.872  1
21894  93.178  -80.254  52.867  1
21895  93.194  -80.247  52.862  1
21896  93.211  -80.240  52.858  1
21897  93.227  -80.233  52.856  1
21898  93.244  -80.225  52.855  1
21899  93.261  -80.218  52.853  1
21900  93.277  -80.211  52.851  1
21901  93.294  -80.204  52.848  1
21902  93.310  -80.196  52.846  1
21903  93.320  -80.186  52.844  1
21904  93.325  -80.165  52.843  1
21905  93.333  -80.140  52.842  1
21906  93.342  -80.117  52.840  1
21907  93.352  -80.096  52.839  1
21908  93.362  -80.074  52.840  1
21909  93.372  -80.052  52.840  1
21910  93.380  -80.038  52.841  1
21911  93.386  -80.040  52.843  1
21912  93.392  -80.042  52.845  1
21913  93.399  -80.043  52.847  1
21914  93.423  -80.043  52.851  1
21915  93.446  -80.043  52.855  1
21916  93.471  -80.044  52.859  1
21917  93.494  -80.044  52.860  1
21918  93.518  -80.045  52.861  1
21919  93.542  -80.045  52.863  1
21920  93.566  -80.046  52.862  1
21921  93.583  -80.042  52.861  1
21922  93.593  -80.033  52.859  1
21923  93.604  -80.024  52.854  1
21924  93.614  -80.015  52.850  1
21925  93.624  -80.007  52.845  1
21926  93.634  -79.998  52.840  1
21927  93.644  -79.990  52.834  1
21928  93.654  -79.981  52.827  1
21929  93.664  -79.972  52.820  1
21930  93.674  -79.964  52.813  1
21931  93.684  -79.955  52.804  1
21932  93.694  -79.946  52.795  1
21933  93.704  -79.937  52.787  1
21934  93.714  -79.929  52.778  1
21935  93.724  -79.920  52.769  1
21936  93.734  -79.911  52.760  1
21937  93.745  -79.904  52.751  1
21938  93.753  -79.902  52.741  1
21959  93.933  -79.872  52.532  1
21960  93.941  -79.871  52.520  1
21961  93.950  -79.869  52.508  1
21962  93.959  -79.867  52.495  1
21963  93.967  -79.866  52.483  1
21964  93.976  -79.864  52.469  1
21965  93.984  -79.863  52.455  1
21966  93.993  -79.861  52.442  1
21967  94.001  -79.861  52.429  1
21968  94.010  -79.859  52.415  1
21969  94.018  -79.858  52.400  1
21970  94.027  -79.856  52.384  1
21971  94.035  -79.855  52.369  1
21972  94.044  -79.853  52.353  1
21973  94.052  -79.852  52.337  1
21974  94.061  -79.850  52.321  1
21975  94.069  -79.849  52.304  1
21976  94.078  -79.847  52.288  1
21977  94.086  -79.845  52.270  1
21978  94.095  -79.844  52.253  1
21995  94.241  -79.579  51.934  1
21996  94.249  -79.553  51.912  1
21997  94.258  -79.527  51.888  1
21998  94.266  -79.501  51.864  1
21999  94.275  -79.476  51.840  1
22000  94.264  -79.480  51.815  1
22001  94.253  -79.486  51.790  1
22002  94.243  -79.492  51.765  1
22003  94.231  -79.498  51.739  1
22004  94.242  -79.481  51.712  1
22005  94.255  -79.461  51.685  1
22006  94.267  -79.441  51.656  1
22007  94.280  -79.422  51.628  1
22008  94.293  -79.402  51.600  1
22009  94.306  -79.382  51.572  1
22010  94.318  -79.363  51.543  1
22011  94.331  -79.344  51.513  1
22012  94.348  -79.375  51.482  1
22013  94.365  -79.407  51.451  1
22014  94.382  -79.438  51.419  1
22015  94.399  -79.469  51.386  1
22016  94.416  -79.501  51.354  1
22017  94.433  -79.532  51.322  1
22018  94.450  -79.563  51.290  1
22019  94.465  -79.598  51.255  1
22020  94.474  -79.641  51.222  1
22021  94.483  -79.684  51.189  1
22022  94.491  -79.727  51.156  1
22559  92.529  -80.539  53.357  1
22560  92.546  -80.531  53.338  1
22561  92.562  -80.523  53.319  1
22562  92.578  -80.515  53.301  1
22563  92.598  -80.507  53.282  1
22564  92.619  -80.498  53.263  1
22565  92.640  -80.490  53.244  1
22566  92.661  -80.482  53.227  1
22567  92.682  -80.473  53.212  1
22568  92.703  -80.465  53.200  1
22569  92.723  -80.457  53.190  1
22570  92.744  -80.448  53.180  1
22571  92.765  -80.440  53.170  1
22572  92.786  -80.431  53.159  1
22573  92.807  -80.423  53.146  1
22574  92.828  -80.415  53.130  1
22575  92.848  -80.406  53.113  1
22576  92.869  -80.398  53.096  1
22577  92.892  -80.371  53.078  1
22578  92.915  -80.344  53.060  1
22579  92.938  -80.316  53.042  1
22580  92.961  -80.289  53.025  1
22581  92.976  -80.288  53.007  1
22582  92.989  -80.294  52.991  1
22583  93.001  -80.299  52.976  1
22584  93.013  -80.303  52.963  1
22585  93.024  -80.309  52.951  1
22586  93.037  -80.314  52.940  1
22587  93.049  -80.312  52.929  1
22588  93.061  -80.305  52.918  1
22589  93.074  -80.296  52.907  1
22590  93.087  -80.287  52.896  1
22591  93.098  -80.277  52.889  1
22592  93.109  -80.266  52.882  1
22593  93.131  -80.257  52.876  1
22594  93.156  -80.249  52.871  1
22595  93.181  -80.240  52.866  1
22596  93.200  -80.233  52.862  1
22597  93.216  -80.225  52.858  1
22598  93.233  -80.218  52.856  1
22599  93.250  -80.212  52.854  1
22600  93.266  -80.204  52.851  1
22601  93.283  -80.197  52.849  1
22602  93.299  -80.190  52.847  1
22603  93.309  -80.178  52.844  1
22604  93.307  -80.162  52.842  1
22605  93.315  -80.137  52.841  1
22606  93.324  -80.113  52.839  1
22607  93.332  -80.089  52.837  1
22608  93.341  -80.065  52.836  1
22609  93.350  -80.043  52.836  1
22610  93.360  -80.021  52.836  1
22611  93.368  -80.007  52.836  1
22612  93.374  -80.008  52.838  1
22613  93.380  -80.011  52.840  1
22614  93.386  -80.012  52.844  1
22615  93.404  -80.013  52.847  1
22616  93.428  -80.013  52.852  1
22617  93.451  -80.013  52.856  1
22618  93.476  -80.014  52.859  1
22619  93.499  -80.014  52.860  1
22620  93.523  -80.015  52.861  1
22621  93.547  -80.015  52.861  1
22622  93.571  -80.015  52.860  1
22623  93.593  -80.015  52.857  1
22624  93.604  -80.005  52.853  1
22625  93.614  -79.997  52.848  1
22626  93.624  -79.989  52.844  1
22627  93.634  -79.980  52.839  1
22628  93.644  -79.971  52.833  1
22629  93.654  -79.962  52.826  1
22630  93.664  -79.954  52.819  1
22631  93.674  -79.945  52.812  1
22632  93.684  -79.936  52.804  1
22633  93.694  -79.928  52.795  1
22634  93.704  -79.919  52.786  1
22635  93.714  -79.911  52.778  1
22636  93.724  -79.902  52.770  1
22637  93.734  -79.893  52.760  1
22638  93.744  -79.889  52.751  1
22639  93.752  -79.889  52.742  1
22640  93.761  -79.887  52.733  1
22661  93.940  -79.856  52.527  1
22662  93.949  -79.855  52.514  1
22663  93.958  -79.853  52.502  1
22664  93.966  -79.852  52.490  1
22665  93.975  -79.850  52.477  1
22666  93.983  -79.849  52.464  1
22667  93.992  -79.848  52.451  1
22668  94.000  -79.846  52.437  1
22669  94.009  -79.845  52.423  1
22670  94.017  -79.843  52.409  1
22671  94.026  -79.842  52.393  1
22672  94.035  -79.840  52.377  1
22673  94.043  -79.839  52.362  1
22674  94.052  -79.837  52.345  1
22675  94.060  -79.836  52.329  1
22676  94.069  -79.834  52.313  1
22677  94.077  -79.833  52.296  1
22678  94.086  -79.831  52.278  1
22679  94.095  -79.830  52.260  1
22695  94.231  -79.592  51.964  1
22696  94.240  -79.565  51.943  1
22697  94.248  -79.539  51.921  1
22698  94.257  -79.513  51.898  1
22699  94.265  -79.488  51.874  1
22700  94.274  -79.462  51.851  1
22701  94.267  -79.460  51.826  1
22702  94.257  -79.466  51.801  1
22703  94.246  -79.472  51.776  1
22704  94.235  -79.478  51.751  1
22705  94.239  -79.467  51.725  1
22706  94.252  -79.447  51.697  1
22707  94.264  -79.428  51.669  1
22708  94.277  -79.408  51.641  1
22709  94.290  -79.388  51.613  1
22710  94.302  -79.369  51.585  1
22711  94.316  -79.349  51.556  1
22712  94.328  -79.329  51.527  1
22713  94.344  -79.344  51.495  1
22714  94.361  -79.375  51.463  1
22715  94.378  -79.407  51.430  1
22716  94.395  -79.438  51.398  1
22717  94.412  -79.469  51.365  1
22718  94.429  -79.501  51.333  1
22719  94.445  -79.532  51.301  1
22720  94.454  -79.576  51.266  1
22721  94.463  -79.619  51.232  1
22722  94.472  -79.662  51.198  1
22723  94.481  -79.705  51.166  1
22724  94.489  -79.748  51.132  1
22725  94.498  -79.792  51.099  1
23260  92.525  -80.522  53.375  1
23261  92.542  -80.514  53.357  1
23262  92.558  -80.506  53.338  1
23263  92.573  -80.498  53.319  1
23264  92.589  -80.490  53.300  1
23265  92.605  -80.482  53.281  1
23266  92.623  -80.474  53.263  1
23267  92.644  -80.466  53.245  1
23268  92.665  -80.457  53.229  1
23269  92.686  -80.449  53.217  1
23270  92.707  -80.441  53.206  1
23271  92.727  -80.432  53.195  1
23272  92.748  -80.424  53.184  1
23273  92.769  -80.416  53.172  1
23274  92.790  -80.407  53.159  1
23275  92.811  -80.399  53.144  1
23276  92.832  -80.391  53.127  1
23277  92.853  -80.382  53.110  1
23278  92.873  -80.374  53.092  1
23279  92.896  -80.353  53.074  1
23280  92.919  -80.326  53.056  1
23281  92.941  -80.299  53.038  1
23282  92.965  -80.272  53.021  1
23283  92.979  -80.270  53.004  1
23284  92.992  -80.275  52.987  1
23285  93.005  -80.281  52.972  1
23286  93.017  -80.286  52.958  1
23287  93.030  -80.291  52.946  1
23288  93.043  -80.296  52.934  1
23289  93.055  -80.294  52.922  1
23290  93.066  -80.284  52.910  1
23291  93.077  -80.274  52.900  1
23292  93.088  -80.263  52.892  1
23293  93.101  -80.253  52.884  1
23294  93.126  -80.245  52.876  1
23295  93.151  -80.237  52.871  1
23296  93.176  -80.228  52.866  1
23297  93.201  -80.219  52.862  1
23298  93.222  -80.212  52.859  1
23299  93.239  -80.204  52.857  1
23300  93.256  -80.197  52.855  1
23301  93.272  -80.190  52.851  1
23302  93.289  -80.183  52.848  1
23303  93.297  -80.171  52.845  1
23304  93.296  -80.154  52.843  1
23305  93.297  -80.134  52.842  1
23306  93.305  -80.110  52.840  1
23307  93.314  -80.086  52.839  1
23308  93.323  -80.062  52.836  1
23309  93.331  -80.037  52.834  1
23310  93.340  -80.013  52.833  1
23311  93.348  -79.990  52.832  1
23312  93.357  -79.976  52.833  1
23313  93.362  -79.977  52.834  1
23314  93.370  -79.982  52.836  1
23315  93.381  -79.992  52.840  1
23316  93.395  -79.988  52.844  1
23317  93.409  -79.983  52.849  1
23318  93.433  -79.983  52.854  1
23319  93.457  -79.983  52.857  1
23320  93.481  -79.983  52.859  1
23321  93.504  -79.983  52.860  1
23322  93.529  -79.984  52.860  1
23323  93.552  -79.984  52.858  1
23324  93.576  -79.985  52.856  1
23325  93.600  -79.985  52.851  1
23326  93.614  -79.979  52.847  1
23327  93.624  -79.970  52.842  1
23328  93.634  -79.961  52.838  1
23329  93.644  -79.953  52.831  1
23330  93.654  -79.944  52.824  1
23331  93.664  -79.936  52.818  1
23332  93.674  -79.927  52.810  1
23333  93.684  -79.918  52.802  1
23334  93.694  -79.909  52.794  1
23335  93.704  -79.901  52.785  1
23336  93.714  -79.892  52.777  1
23337  93.724  -79.883  52.770  1
23338  93.734  -79.877  52.760  1
23339  93.743  -79.876  52.751  1
23340  93.751  -79.874  52.742  1
23341  93.760  -79.873  52.733  1
23362  93.939  -79.842  52.533  1
23363  93.948  -79.840  52.521  1
23364  93.957  -79.839  52.509  1
23365  93.965  -79.837  52.496  1
23366  93.974  -79.836  52.483  1
23367  93.982  -79.835  52.470  1
23368  93.991  -79.833  52.457  1
23369  93.999  -79.832  52.443  1
23370  94.008  -79.830  52.429  1
23371  94.016  -79.829  52.414  1
23372  94.025  -79.827  52.399  1
23373  94.034  -79.826  52.383  1
23374  94.042  -79.824  52.367  1
23375  94.051  -79.823  52.351  1
23376  94.059  -79.821  52.335  1
23377  94.068  -79.820  52.319  1
23378  94.076  -79.818  52.302  1
23379  94.085  -79.817  52.285  1
23380  94.094  -79.816  52.267  1
23381  94.102  -79.814  52.250  1
23395  94.222  -79.604  51.993  1
23396  94.230  -79.578  51.971  1
23397  94.239  -79.552  51.951  1
23398  94.247  -79.526  51.930  1
23399  94.256  -79.501  51.907  1
23400  94.264  -79.474  51.883  1
23401  94.273  -79.448  51.860  1
23402  94.271  -79.440  51.835  1
23403  94.260  -79.446  51.810  1
23404  94.249  -79.452  51.786  1
23405  94.238  -79.457  51.762  1
23406  94.236  -79.454  51.736  1
23407  94.249  -79.435  51.709  1
23408  94.261  -79.415  51.681  1
23409  94.274  -79.394  51.653  1
23410  94.287  -79.375  51.625  1
23411  94.299  -79.355  51.597  1
23412  94.313  -79.335  51.569  1
23413  94.325  -79.316  51.539  1
23414  94.339  -79.313  51.508  1
23415  94.356  -79.344  51.475  1
23416  94.373  -79.375  51.442  1
23417  94.390  -79.406  51.409  1
23418  94.407  -79.438  51.376  1
23419  94.424  -79.469  51.343  1
23420  94.434  -79.510  51.311  1
23421  94.443  -79.553  51.276  1
23422  94.452  -79.596  51.241  1
23423  94.461  -79.639  51.207  1
23424  94.470  -79.683  51.174  1
23425  94.479  -79.726  51.140  1
23426  94.487  -79.770  51.107  1
23961  92.521  -80.505  53.395  1
23962  92.537  -80.497  53.377  1
23963  92.553  -80.489  53.358  1
23964  92.569  -80.481  53.339  1
23965  92.585  -80.473  53.320  1
23966  92.601  -80.465  53.301  1
23967  92.618  -80.457  53.282  1
23968  92.634  -80.449  53.264  1
23969  92.649  -80.441  53.247  1
23970  92.669  -80.433  53.233  1
23971  92.690  -80.425  53.221  1
23972  92.711  -80.416  53.210  1
23973  92.732  -80.408  53.199  1
23974  92.753  -80.400  53.186  1
23975  92.773  -80.391  53.173  1
23976  92.794  -80.383  53.157  1
23977  92.815  -80.375  53.141  1
23978  92.836  -80.366  53.124  1
23979  92.857  -80.358  53.108  1
23980  92.877  -80.350  53.090  1
23981  92.899  -80.337  53.072  1
23982  92.922  -80.309  53.053  1
23983  92.945  -80.282  53.036  1
23984  92.968  -80.255  53.019  1
23985  92.983  -80.252  53.001  1
23986  92.996  -80.257  52.983  1
23987  93.008  -80.262  52.966  1
23988  93.021  -80.268  52.952  1
23989  93.034  -80.273  52.939  1
23990  93.047  -80.278  52.926  1
23991  93.057  -80.271  52.914  1
23992  93.067  -80.261  52.904  1
23993  93.078  -80.250  52.895  1
23994  93.096  -80.241  52.887  1
23995  93.121  -80.232  52.879  1
23996  93.146  -80.224  52.873  1
23997  93.171  -80.215  52.868  1
23998  93.196  -80.207  52.864  1
23999  93.221  -80.199  52.861  1
24000  93.245  -80.190  52.858  1
24001  93.262  -80.183  52.855  1
24002  93.278  -80.176  52.852  1
24003  93.286  -80.164  52.848  1
24004  93.284  -80.146  52.845  1
24005  93.283  -80.129  52.842  1
24006  93.288  -80.108  52.840  1
24007  93.296  -80.083  52.838  1
24008  93.304  -80.059  52.836  1
24009  93.313  -80.034  52.833  1
24010  93.322  -80.010  52.831  1
24011  93.330  -79.986  52.830  1
24012  93.339  -79.964  52.827  1
24013  93.354  -79.958  52.828  1
24014  93.365  -79.968  52.830  1
24015  93.375  -79.977  52.831  1
24016  93.387  -79.987  52.836  1
24017  93.404  -79.974  52.840  1
24018  93.418  -79.968  52.845  1
24019  93.431  -79.962  52.852  1
24020  93.444  -79.956  52.856  1
24021  93.462  -79.953  52.858  1
24022  93.485  -79.953  52.860  1
24023  93.509  -79.953  52.859  1
24024  93.533  -79.954  52.857  1
24025  93.557  -79.954  52.854  1
24026  93.581  -79.955  52.849  1
24027  93.605  -79.955  52.845  1
24028  93.624  -79.952  52.841  1
24029  93.634  -79.943  52.835  1
24030  93.644  -79.934  52.829  1
24031  93.654  -79.926  52.823  1
24032  93.664  -79.917  52.816  1
24033  93.674  -79.908  52.808  1
24034  93.684  -79.900  52.800  1
24035  93.694  -79.891  52.792  1
24036  93.704  -79.883  52.784  1
24037  93.714  -79.874  52.776  1
24038  93.724  -79.865  52.769  1
24039  93.733  -79.863  52.759  1
24040  93.742  -79.861  52.750  1
24041  93.751  -79.860  52.742  1
24042  93.759  -79.858  52.733  1
24043  93.768  -79.857  52.724  1
24063  93.938  -79.827  52.538  1
24064  93.947  -79.826  52.527  1
24065  93.956  -79.824  52.514  1
24066  93.964  -79.823  52.501  1
24067  93.973  -79.822  52.488  1
24068  93.981  -79.820  52.475  1
24069  93.990  -79.819  52.462  1
24070  93.998  -79.817  52.449  1
24071  94.007  -79.816  52.435  1
24072  94.015  -79.814  52.419  1
24073  94.024  -79.813  52.404  1
24074  94.033  -79.811  52.388  1
24075  94.041  -79.810  52.372  1
24076  94.050  -79.808  52.356  1
24077  94.058  -79.807  52.340  1
24078  94.067  -79.805  52.324  1
24079  94.075  -79.804  52.307  1
24080  94.084  -79.803  52.290  1
24081  94.092  -79.802  52.272  1
24082  94.101  -79.800  52.254  1
24083  94.110  -79.798  52.237  1
24094  94.204  -79.642  52.038  1
24095  94.212  -79.616  52.018  1
24096  94.221  -79.590  51.997  1
24097  94.229  -79.564  51.977  1
24098  94.238  -79.538  51.957  1
24099  94.247  -79.513  51.936  1
24100  94.255  -79.487  51.914  1
24101  94.264  -79.461  51.891  1
24102  94.272  -79.435  51.867  1
24103  94.274  -79.420  51.843  1
24104  94.263  -79.426  51.819  1
24105  94.252  -79.432  51.795  1
24106  94.241  -79.438  51.772  1
24107  94.233  -79.441  51.746  1
24108  94.246  -79.421  51.719  1
24109  94.259  -79.401  51.692  1
24110  94.271  -79.382  51.664  1
24111  94.284  -79.362  51.636  1
24112  94.297  -79.342  51.609  1
24113  94.310  -79.322  51.581  1
24114  94.322  -79.303  51.551  1
24115  94.335  -79.283  51.519  1
24116  94.352  -79.312  51.486  1
24117  94.369  -79.343  51.453  1
24118  94.386  -79.375  51.420  1
24119  94.403  -79.406  51.386  1
24120  94.415  -79.444  51.353  1
24121  94.424  -79.488  51.319  1
24122  94.432  -79.531  51.284  1
24123  94.441  -79.574  51.250  1
24124  94.450  -79.617  51.216  1
24125  94.459  -79.661  51.182  1
24126  94.468  -79.704  51.148  1
24127  94.477  -79.747  51.114  1
24662  92.517  -80.488  53.417  1
24663  92.533  -80.480  53.398  1
24664  92.549  -80.472  53.379  1
24665  92.565  -80.464  53.359  1
24666  92.581  -80.457  53.342  1
24667  92.597  -80.448  53.322  1
24668  92.614  -80.440  53.303  1
24669  92.629  -80.432  53.284  1
24670  92.645  -80.424  53.266  1
24671  92.661  -80.416  53.250  1
24672  92.677  -80.408  53.235  1
24673  92.694  -80.400  53.224  1
24674  92.715  -80.391  53.211  1
24675  92.736  -80.383  53.199  1
24676  92.757  -80.375  53.185  1
24677  92.778  -80.366  53.170  1
24678  92.798  -80.358  53.154  1
24679  92.819  -80.350  53.138  1
24680  92.840  -80.341  53.122  1
24681  92.861  -80.333  53.105  1
24682  92.882  -80.325  53.087  1
24683  92.903  -80.316  53.068  1
24684  92.925  -80.292  53.051  1
24685  92.948  -80.265  53.033  1
24686  92.971  -80.237  53.014  1
24687  92.987  -80.234  52.995  1
24688  92.999  -80.239  52.978  1
24689  93.012  -80.244  52.961  1
24690  93.025  -80.250  52.947  1
24691  93.038  -80.255  52.933  1
24692  93.048  -80.256  52.921  1
24693  93.058  -80.248  52.910  1
24694  93.068  -80.237  52.901  1
24695  93.091  -80.228  52.892  1
24696  93.116  -80.220  52.884  1
24697  93.141  -80.212  52.877  1
24698  93.166  -80.203  52.871  1
24699  93.191  -80.194  52.866  1
24700  93.216  -80.186  52.862  1
24701  93.241  -80.178  52.859  1
24702  93.266  -80.169  52.857  1
24703  93.275  -80.156  52.853  1
24704  93.273  -80.139  52.848  1
24705  93.271  -80.122  52.844  1
24706  93.270  -80.105  52.842  1
24707  93.278  -80.080  52.838  1
24708  93.287  -80.056  52.835  1
24709  93.295  -80.032  52.833  1
24710  93.304  -80.008  52.830  1
24711  93.313  -79.990  52.828  1
24712  93.322  -79.971  52.826  1
24713  93.334  -79.957  52.823  1
24714  93.358  -79.952  52.823  1
24715  93.370  -79.962  52.825  1
24716  93.381  -79.971  52.828  1
24717  93.392  -79.981  52.833  1
24718  93.414  -79.961  52.837  1
24719  93.427  -79.955  52.842  1
24720  93.440  -79.949  52.848  1
24721  93.453  -79.943  52.852  1
24722  93.467  -79.936  52.856  1
24723  93.480  -79.930  52.857  1
24724  93.493  -79.924  52.856  1
24725  93.514  -79.923  52.854  1
24726  93.538  -79.924  52.850  1
24727  93.562  -79.924  52.846  1
24728  93.586  -79.924  52.842  1
24729  93.610  -79.924  52.837  1
24730  93.634  -79.924  52.832  1
24731  93.644  -79.916  52.826  1
24732  93.654  -79.908  52.821  1
24733  93.664  -79.899  52.815  1
24734  93.674  -79.890  52.807  1
24735  93.684  -79.881  52.798  1
24736  93.694  -79.873  52.791  1
24737  93.704  -79.864  52.783  1
24738  93.714  -79.855  52.775  1
24739  93.724  -79.850  52.767  1
24740  93.732  -79.849  52.758  1
24741  93.741  -79.847  52.749  1
24742  93.750  -79.845  52.741  1
24743  93.758  -79.844  52.732  1
24744  93.767  -79.842  52.723  1
24764  93.938  -79.813  52.541  1
24765  93.946  -79.811  52.530  1
24766  93.955  -79.811  52.517  1
24767  93.964  -79.809  52.505  1
24768  93.972  -79.808  52.493  1
24769  93.981  -79.806  52.479  1
24770  93.989  -79.805  52.466  1
24771  93.998  -79.803  52.453  1
24772  94.006  -79.802  52.439  1
24773  94.015  -79.800  52.423  1
24774  94.024  -79.798  52.408  1
24775  94.032  -79.797  52.392  1
24776  94.041  -79.795  52.376  1
24777  94.049  -79.794  52.360  1
24778  94.058  -79.792  52.344  1
24779  94.066  -79.791  52.328  1
24780  94.075  -79.790  52.310  1
24781  94.083  -79.789  52.293  1
24782  94.092  -79.787  52.275  1
24783  94.101  -79.786  52.258  1
24784  94.109  -79.784  52.241  1
24785  94.117  -79.783  52.223  1
24794  94.194  -79.654  52.064  1
24795  94.203  -79.629  52.043  1
24796  94.211  -79.603  52.023  1
24797  94.220  -79.577  52.003  1
24798  94.228  -79.551  51.983  1
24799  94.237  -79.525  51.963  1
24800  94.246  -79.499  51.942  1
24801  94.254  -79.473  51.921  1
24802  94.263  -79.447  51.898  1
24803  94.271  -79.422  51.875  1
24804  94.277  -79.400  51.851  1
24805  94.266  -79.406  51.828  1
24806  94.255  -79.412  51.805  1
24807  94.245  -79.418  51.782  1
24808  94.234  -79.423  51.757  1
24809  94.243  -79.407  51.730  1
24810  94.256  -79.388  51.702  1
24811  94.268  -79.368  51.676  1
24812  94.281  -79.348  51.649  1
24813  94.294  -79.328  51.622  1
24814  94.307  -79.309  51.594  1
24815  94.319  -79.289  51.563  1
24816  94.332  -79.269  51.530  1
24817  94.347  -79.280  51.496  1
24818  94.364  -79.312  51.463  1
24819  94.382  -79.343  51.430  1
24820  94.395  -79.379  51.396  1
24821  94.404  -79.422  51.363  1
24822  94.413  -79.465  51.329  1
24823  94.422  -79.508  51.294  1
24824  94.430  -79.551  51.259  1
24825  94.439  -79.595  51.225  1
24826  94.448  -79.639  51.190  1
24827  94.457  -79.682  51.156  1
24828  94.466  -79.725  51.122  1
25363  92.513  -80.472  53.438  1
25364  92.529  -80.463  53.420  1
25365  92.545  -80.455  53.401  1
25366  92.561  -80.447  53.382  1
25367  92.577  -80.439  53.363  1
25368  92.593  -80.431  53.343  1
25369  92.609  -80.423  53.323  1
25370  92.625  -80.415  53.304  1
25371  92.641  -80.407  53.285  1
25372  92.657  -80.399  53.267  1
25373  92.673  -80.391  53.250  1
25374  92.690  -80.383  53.234  1
25375  92.705  -80.375  53.221  1
25376  92.721  -80.367  53.208  1
25377  92.740  -80.359  53.195  1
25378  92.761  -80.350  53.182  1
25379  92.782  -80.342  53.167  1
25380  92.802  -80.334  53.152  1
25381  92.824  -80.325  53.136  1
25382  92.844  -80.317  53.119  1
25383  92.865  -80.309  53.101  1
25384  92.886  -80.300  53.083  1
25385  92.907  -80.292  53.065  1
25386  92.929  -80.275  53.047  1
25387  92.951  -80.248  53.026  1
25388  92.975  -80.221  53.007  1
25389  92.990  -80.216  52.988  1
25390  93.003  -80.222  52.970  1
25391  93.016  -80.226  52.954  1
25392  93.028  -80.231  52.940  1
25393  93.041  -80.236  52.927  1
25394  93.048  -80.233  52.915  1
25395  93.061  -80.225  52.906  1
25396  93.086  -80.216  52.896  1
25397  93.111  -80.208  52.888  1
25398  93.135  -80.199  52.880  1
25399  93.157  -80.189  52.874  1
25400  93.180  -80.178  52.869  1
25401  93.202  -80.168  52.865  1
25402  93.224  -80.159  52.862  1
25403  93.247  -80.148  52.859  1
25404  93.261  -80.137  52.855  1
25405  93.260  -80.115  52.850  1
25406  93.258  -80.097  52.845  1
25407  93.260  -80.077  52.841  1
25408  93.269  -80.053  52.837  1
25409  93.278  -80.034  52.833  1
25410  93.287  -80.015  52.829  1
25411  93.296  -79.996  52.827  1
25412  93.305  -79.977  52.825  1
25413  93.317  -79.961  52.822  1
25414  93.331  -79.952  52.819  1
25415  93.352  -79.947  52.819  1
25416  93.376  -79.957  52.821  1
25417  93.387  -79.966  52.825  1
25418  93.398  -79.976  52.829  1
25419  93.421  -79.949  52.834  1
25420  93.436  -79.940  52.839  1
25421  93.449  -79.934  52.844  1
25422  93.463  -79.928  52.849  1
25423  93.476  -79.923  52.853  1
25424  93.489  -79.917  52.854  1
25425  93.502  -79.911  52.853  1
25426  93.516  -79.905  52.851  1
25427  93.529  -79.899  52.846  1
25428  93.543  -79.893  52.843  1
25429  93.567  -79.893  52.840  1
25430  93.591  -79.894  52.835  1
25431  93.615  -79.894  52.829  1
25432  93.639  -79.895  52.823  1
25433  93.654  -79.889  52.817  1
25434  93.664  -79.880  52.810  1
25435  93.674  -79.872  52.803  1
25436  93.684  -79.863  52.796  1
25437  93.694  -79.855  52.789  1
25438  93.704  -79.845  52.781  1
25439  93.714  -79.837  52.772  1
25440  93.723  -79.836  52.764  1
25441  93.731  -79.834  52.757  1
25442  93.740  -79.833  52.748  1
25443  93.749  -79.831  52.739  1
25444  93.757  -79.830  52.731  1
25445  93.766  -79.828  52.722  1
25446  93.774  -79.827  52.713  1
25465  93.937  -79.798  52.544  1
25466  93.945  -79.798  52.533  1
25467  93.954  -79.796  52.520  1
25468  93.963  -79.795  52.509  1
25469  93.971  -79.793  52.496  1
25470  93.980  -79.792  52.483  1
25471  93.988  -79.790  52.469  1
25472  93.997  -79.789  52.456  1
25473  94.005  -79.787  52.442  1
25474  94.014  -79.786  52.427  1
25475  94.023  -79.784  52.411  1
25476  94.031  -79.783  52.395  1
25477  94.040  -79.781  52.379  1
25478  94.048  -79.780  52.363  1
25479  94.057  -79.778  52.346  1
25480  94.065  -79.777  52.331  1
25481  94.074  -79.776  52.313  1
25482  94.082  -79.774  52.295  1
25483  94.091  -79.773  52.278  1
25484  94.100  -79.771  52.261  1
25485  94.108  -79.770  52.244  1
25486  94.117  -79.768  52.228  1
25487  94.125  -79.767  52.211  1
25492  94.168  -79.719  52.122  1
25493  94.177  -79.692  52.104  1
25494  94.185  -79.667  52.087  1
25495  94.194  -79.641  52.068  1
25496  94.202  -79.615  52.048  1
25497  94.210  -79.589  52.028  1
25498  94.219  -79.563  52.008  1
25499  94.227  -79.538  51.988  1
25500  94.236  -79.512  51.968  1
25501  94.245  -79.486  51.948  1
25502  94.253  -79.460  51.927  1
25503  94.262  -79.434  51.904  1
25504  94.270  -79.408  51.882  1
25505  94.279  -79.382  51.860  1
25506  94.269  -79.386  51.838  1
25507  94.259  -79.391  51.816  1
25508  94.248  -79.397  51.794  1
25509  94.237  -79.404  51.769  1
25510  94.240  -79.394  51.742  1
25511  94.253  -79.374  51.714  1
25512  94.265  -79.354  51.688  1
25513  94.278  -79.335  51.663  1
25514  94.291  -79.315  51.637  1
25515  94.303  -79.295  51.609  1
25516  94.316  -79.275  51.577  1
25517  94.329  -79.256  51.542  1
25518  94.343  -79.249  51.508  1
25519  94.360  -79.280  51.475  1
25520  94.376  -79.313  51.441  1
25521  94.384  -79.357  51.406  1
25522  94.393  -79.400  51.372  1
25523  94.402  -79.443  51.338  1
25524  94.411  -79.486  51.303  1
25525  94.419  -79.529  51.268  1
25526  94.428  -79.573  51.233  1
25527  94.437  -79.616  51.198  1
25528  94.446  -79.659  51.164  1
25529  94.455  -79.702  51.129  1
26065  92.525  -80.447  53.442  1
26066  92.541  -80.438  53.423  1
26067  92.557  -80.430  53.404  1
26068  92.573  -80.422  53.385  1
26069  92.589  -80.414  53.365  1
26070  92.605  -80.406  53.345  1
26071  92.621  -80.398  53.325  1
26072  92.637  -80.390  53.305  1
26073  92.653  -80.382  53.285  1
26074  92.669  -80.374  53.266  1
26075  92.685  -80.366  53.248  1
26076  92.701  -80.358  53.232  1
26077  92.717  -80.350  53.216  1
26078  92.733  -80.342  53.201  1
26079  92.749  -80.334  53.187  1
26080  92.766  -80.326  53.174  1
26081  92.786  -80.318  53.160  1
26082  92.807  -80.309  53.146  1
26083  92.828  -80.301  53.131  1
26084  92.849  -80.293  53.115  1
26085  92.869  -80.284  53.097  1
26086  92.890  -80.276  53.077  1
26087  92.911  -80.268  53.058  1
26088  92.932  -80.259  53.037  1
26089  92.955  -80.231  53.017  1
26090  92.978  -80.204  52.998  1
26091  92.994  -80.198  52.978  1
26092  93.007  -80.203  52.961  1
26093  93.019  -80.209  52.946  1
26094  93.032  -80.214  52.933  1
26095  93.042  -80.213  52.921  1
26096  93.050  -80.208  52.910  1
26097  93.068  -80.196  52.901  1
26098  93.090  -80.186  52.892  1
26099  93.112  -80.176  52.884  1
26100  93.135  -80.166  52.877  1
26101  93.157  -80.156  52.871  1
26102  93.180  -80.146  52.867  1
26103  93.202  -80.136  52.863  1
26104  93.224  -80.125  52.859  1
26105  93.248  -80.120  52.855  1
26106  93.247  -80.099  52.850  1
26107  93.245  -80.078  52.844  1
26108  93.252  -80.060  52.840  1
26109  93.261  -80.041  52.835  1
26110  93.270  -80.022  52.830  1
26111  93.279  -80.002  52.824  1
26112  93.288  -79.983  52.822  1
26113  93.298  -79.967  52.819  1
26114  93.313  -79.958  52.817  1
26115  93.328  -79.949  52.815  1
26116  93.347  -79.942  52.815  1
26117  93.381  -79.952  52.817  1
26118  93.393  -79.961  52.820  1
26119  93.403  -79.971  52.824  1
26120  93.428  -79.940  52.830  1
26121  93.445  -79.927  52.834  1
26122  93.459  -79.921  52.840  1
26123  93.472  -79.914  52.845  1
26124  93.485  -79.908  52.849  1
26125  93.498  -79.902  52.851  1
26126  93.512  -79.896  52.851  1
26127  93.525  -79.891  52.849  1
26128  93.538  -79.885  52.844  1
26129  93.552  -79.879  52.841  1
26130  93.565  -79.873  52.838  1
26131  93.578  -79.867  52.833  1
26132  93.596  -79.864  52.827  1
26133  93.620  -79.864  52.821  1
26134  93.644  -79.864  52.814  1
26135  93.664  -79.862  52.807  1
26136  93.674  -79.853  52.800  1
26137  93.684  -79.845  52.793  1
26138  93.694  -79.836  52.787  1
26139  93.704  -79.827  52.778  1
26140  93.713  -79.823  52.770  1
26141  93.722  -79.821  52.762  1
26142  93.730  -79.820  52.755  1
26143  93.739  -79.818  52.746  1
26144  93.748  -79.817  52.738  1
26145  93.756  -79.815  52.730  1
26146  93.765  -79.814  52.721  1
26147  93.773  -79.812  52.712  1
26148  93.782  -79.811  52.704  1
26166  93.936  -79.785  52.546  1
26167  93.944  -79.783  52.535  1
26168  93.953  -79.782  52.523  1
26169  93.962  -79.780  52.511  1
26170  93.970  -79.779  52.499  1
26171  93.979  -79.777  52.486  1
26172  93.987  -79.776  52.472  1
26173  93.996  -79.774  52.458  1
26174  94.004  -79.773  52.445  1
26175  94.013  -79.771  52.430  1
26176  94.022  -79.770  52.414  1
26177  94.030  -79.768  52.398  1
26178  94.039  -79.767  52.383  1
26179  94.047  -79.765  52.366  1
26180  94.056  -79.764  52.349  1
26181  94.064  -79.763  52.334  1
26182  94.073  -79.761  52.316  1
26183  94.081  -79.760  52.298  1
26184  94.090  -79.758  52.281  1
26185  94.099  -79.757  52.264  1
26186  94.107  -79.755  52.248  1
26187  94.116  -79.754  52.231  1
26188  94.124  -79.752  52.214  1
26189  94.133  -79.751  52.196  1
26190  94.141  -79.749  52.178  1
26191  94.150  -79.748  52.160  1
26192  94.158  -79.731  52.142  1
26193  94.167  -79.705  52.125  1
26194  94.176  -79.679  52.108  1
26195  94.184  -79.654  52.091  1
26196  94.193  -79.628  52.071  1
26197  94.201  -79.601  52.051  1
26198  94.210  -79.576  52.032  1
26199  94.218  -79.550  52.012  1
26200  94.227  -79.524  51.992  1
26201  94.236  -79.498  51.973  1
26202  94.244  -79.473  51.953  1
26203  94.252  -79.447  51.932  1
26204  94.261  -79.421  51.910  1
26205  94.269  -79.395  51.889  1
26206  94.278  -79.369  51.868  1
26207  94.273  -79.366  51.848  1
26208  94.262  -79.372  51.829  1
26209  94.251  -79.378  51.807  1
26210  94.240  -79.383  51.783  1
26211  94.237  -79.381  51.754  1
26212  94.250  -79.361  51.727  1
26213  94.262  -79.341  51.702  1
26214  94.275  -79.322  51.678  1
26215  94.288  -79.302  51.653  1
26216  94.300  -79.282  51.624  1
26217  94.314  -79.263  51.593  1
26218  94.326  -79.243  51.556  1
26219  94.339  -79.223  51.521  1
26220  94.355  -79.248  51.487  1
26221  94.364  -79.291  51.451  1
26222  94.373  -79.334  51.415  1
26223  94.382  -79.377  51.381  1
26224  94.391  -79.420  51.348  1
26225  94.400  -79.463  51.312  1
26226  94.409  -79.507  51.276  1
26227  94.417  -79.551  51.241  1
26228  94.426  -79.594  51.206  1
26229  94.435  -79.637  51.171  1
26230  94.444  -79.680  51.137  1
26766  92.521  -80.429  53.465  1
26767  92.537  -80.422  53.446  1
26768  92.553  -80.413  53.426  1
26769  92.569  -80.405  53.407  1
26770  92.585  -80.397  53.387  1
26771  92.601  -80.389  53.367  1
26772  92.617  -80.381  53.347  1
26773  92.633  -80.373  53.325  1
26774  92.649  -80.365  53.305  1
26775  92.665  -80.357  53.284  1
26776  92.681  -80.349  53.265  1
26777  92.697  -80.341  53.245  1
26778  92.713  -80.333  53.227  1
26779  92.729  -80.325  53.210  1
26780  92.745  -80.317  53.195  1
26781  92.761  -80.309  53.180  1
26782  92.777  -80.301  53.166  1
26783  92.793  -80.293  53.153  1
26784  92.811  -80.284  53.139  1
26785  92.832  -80.276  53.124  1
26786  92.853  -80.268  53.107  1
26787  92.873  -80.259  53.088  1
26788  92.895  -80.251  53.068  1
26789  92.915  -80.243  53.047  1
26790  92.936  -80.234  53.027  1
26791  92.958  -80.214  53.007  1
26792  92.981  -80.187  52.987  1
26793  92.998  -80.180  52.968  1
26794  93.010  -80.185  52.952  1
26795  93.023  -80.190  52.938  1
26796  93.035  -80.193  52.926  1
26797  93.042  -80.190  52.915  1
26798  93.056  -80.177  52.905  1
26799  93.070  -80.164  52.896  1
26800  93.089  -80.153  52.888  1
26801  93.112  -80.143  52.880  1
26802  93.134  -80.133  52.873  1
26803  93.156  -80.123  52.867  1
26804  93.179  -80.113  52.862  1
26805  93.201  -80.103  52.859  1
26806  93.225  -80.096  52.854  1
26807  93.233  -80.083  52.849  1
26808  93.231  -80.062  52.844  1
26809  93.244  -80.047  52.839  1
26810  93.253  -80.028  52.833  1
26811  93.262  -80.009  52.827  1
26812  93.271  -79.990  52.821  1
26813  93.281  -79.971  52.817  1
26814  93.295  -79.962  52.814  1
26815  93.310  -79.953  52.811  1
26816  93.325  -79.944  52.810  1
26817  93.341  -79.936  52.811  1
26818  93.387  -79.946  52.813  1
26819  93.398  -79.955  52.816  1
26820  93.410  -79.961  52.821  1
26821  93.435  -79.930  52.826  1
26822  93.454  -79.913  52.830  1
26823  93.468  -79.907  52.837  1
26824  93.481  -79.901  52.842  1
26825  93.494  -79.895  52.846  1
26826  93.508  -79.889  52.849  1
26827  93.521  -79.883  52.849  1
26828  93.534  -79.877  52.848  1
26829  93.548  -79.871  52.844  1
26830  93.561  -79.864  52.841  1
26831  93.574  -79.858  52.838  1
26832  93.587  -79.853  52.832  1
26833  93.601  -79.847  52.825  1
26834  93.614  -79.841  52.818  1
26835  93.627  -79.835  52.812  1
26836  93.649  -79.834  52.805  1
26837  93.673  -79.834  52.798  1
26838  93.684  -79.827  52.791  1
26839  93.694  -79.817  52.784  1
26840  93.704  -79.810  52.776  1
26841  93.713  -79.808  52.768  1
26842  93.721  -79.807  52.761  1
26843  93.730  -79.805  52.753  1
26844  93.739  -79.804  52.745  1
26845  93.747  -79.802  52.737  1
26846  93.756  -79.801  52.729  1
26847  93.764  -79.799  52.720  1
26848  93.773  -79.798  52.712  1
26849  93.781  -79.796  52.704  1
26867  93.935  -79.770  52.549  1
26868  93.943  -79.769  52.538  1
26869  93.952  -79.767  52.526  1
26870  93.961  -79.766  52.514  1
26871  93.969  -79.764  52.501  1
26872  93.978  -79.763  52.488  1
26873  93.986  -79.761  52.475  1
26874  93.995  -79.760  52.461  1
26875  94.003  -79.758  52.447  1
26876  94.012  -79.757  52.432  1
26877  94.020  -79.755  52.416  1
26878  94.029  -79.754  52.400  1
26879  94.038  -79.752  52.385  1
26880  94.046  -79.751  52.369  1
26881  94.055  -79.750  52.352  1
26882  94.063  -79.748  52.336  1
26883  94.072  -79.747  52.318  1
26884  94.080  -79.745  52.300  1
26885  94.089  -79.744  52.284  1
26886  94.098  -79.742  52.267  1
26887  94.106  -79.741  52.250  1
26888  94.115  -79.739  52.233  1
26889  94.123  -79.738  52.216  1
26890  94.132  -79.736  52.198  1
26891  94.140  -79.735  52.180  1
26892  94.149  -79.733  52.162  1
26893  94.157  -79.717  52.144  1
26894  94.166  -79.692  52.127  1
26895  94.175  -79.666  52.111  1
26896  94.183  -79.640  52.093  1
26897  94.192  -79.614  52.074  1
26898  94.200  -79.588  52.054  1
26899  94.209  -79.563  52.034  1
26900  94.217  -79.537  52.014  1
26901  94.226  -79.510  51.995  1
26902  94.235  -79.485  51.976  1
26903  94.243  -79.459  51.956  1
26904  94.252  -79.433  51.936  1
26905  94.260  -79.407  51.914  1
26906  94.269  -79.382  51.895  1
26907  94.277  -79.356  51.876  1
26908  94.276  -79.346  51.858  1
26909  94.265  -79.352  51.839  1
26910  94.265  -79.353  51.817  1
26911  94.278  -79.352  51.792  1
26912  94.290  -79.350  51.764  1
26913  94.302  -79.348  51.737  1
26914  94.313  -79.338  51.712  1
26915  94.319  -79.316  51.688  1
26916  94.326  -79.296  51.662  1
26917  94.332  -79.275  51.634  1
26918  94.337  -79.254  51.604  1
26919  94.339  -79.233  51.569  1
26920  94.340  -79.212  51.534  1
26921  94.345  -79.225  51.498  1
26922  94.354  -79.269  51.460  1
26923  94.362  -79.312  51.424  1
26924  94.371  -79.355  51.389  1
26925  94.380  -79.398  51.355  1
26926  94.389  -79.441  51.319  1
26927  94.398  -79.485  51.284  1
26928  94.407  -79.528  51.249  1
26929  94.415  -79.571  51.215  1
26930  94.424  -79.614  51.179  1
26931  94.433  -79.657  51.145  1
27468  92.533  -80.404  53.469  1
27469  92.549  -80.397  53.449  1
27470  92.565  -80.388  53.429  1
27471  92.581  -80.380  53.410  1
27472  92.597  -80.372  53.389  1
27473  92.613  -80.364  53.368  1
27474  92.629  -80.356  53.347  1
27475  92.645  -80.348  53.325  1
27476  92.661  -80.340  53.304  1
27477  92.677  -80.332  53.283  1
27478  92.693  -80.324  53.262  1
27479  92.709  -80.316  53.243  1
27480  92.725  -80.308  53.223  1
27481  92.741  -80.300  53.204  1
27482  92.757  -80.292  53.187  1
27483  92.773  -80.284  53.172  1
27484  92.789  -80.276  53.159  1
27485  92.805  -80.268  53.145  1
27486  92.821  -80.259  53.131  1
27487  92.838  -80.252  53.115  1
27488  92.857  -80.243  53.096  1
27489  92.878  -80.235  53.077  1
27490  92.899  -80.227  53.056  1
27491  92.919  -80.218  53.035  1
27492  92.940  -80.210  53.015  1
27493  92.961  -80.197  52.995  1
27494  92.985  -80.170  52.975  1
27495  93.001  -80.162  52.957  1
27496  93.014  -80.167  52.943  1
27497  93.027  -80.172  52.932  1
27498  93.035  -80.171  52.920  1
27499  93.048  -80.159  52.910  1
27500  93.062  -80.146  52.901  1
27501  93.075  -80.134  52.893  1
27502  93.089  -80.121  52.884  1
27503  93.111  -80.111  52.876  1
27504  93.134  -80.100  52.869  1
27505  93.156  -80.090  52.863  1
27506  93.178  -80.080  52.859  1
27507  93.202  -80.073  52.855  1
27508  93.219  -80.066  52.850  1
27509  93.222  -80.047  52.845  1
27510  93.236  -80.035  52.838  1
27511  93.246  -80.015  52.831  1
27512  93.255  -79.996  52.825  1
27513  93.264  -79.977  52.819  1
27514  93.278  -79.968  52.813  1
27515  93.292  -79.958  52.808  1
27516  93.307  -79.949  52.805  1
27517  93.322  -79.940  52.805  1
27518  93.337  -79.931  52.807  1
27519  93.386  -79.940  52.809  1
27520  93.404  -79.950  52.814  1
27521  93.417  -79.952  52.819  1
27522  93.442  -79.921  52.823  1
27523  93.464  -79.899  52.828  1
27524  93.477  -79.892  52.834  1
27525  93.490  -79.886  52.839  1
27526  93.503  -79.880  52.844  1
27527  93.517  -79.875  52.846  1
27528  93.530  -79.869  52.846  1
27529  93.544  -79.863  52.846  1
27530  93.557  -79.857  52.844  1
27531  93.570  -79.851  52.842  1
27532  93.583  -79.845  52.839  1
27533  93.596  -79.839  52.834  1
27534  93.610  -79.833  52.826  1
27535  93.623  -79.827  52.818  1
27536  93.636  -79.820  52.811  1
27537  93.650  -79.815  52.805  1
27538  93.663  -79.809  52.798  1
27539  93.678  -79.804  52.790  1
27540  93.694  -79.799  52.783  1
27541  93.703  -79.795  52.776  1
27542  93.712  -79.794  52.768  1
27543  93.720  -79.792  52.759  1
27544  93.729  -79.791  52.752  1
27545  93.737  -79.789  52.744  1
27546  93.746  -79.788  52.736  1
27547  93.755  -79.786  52.728  1
27548  93.763  -79.785  52.720  1
27549  93.772  -79.783  52.712  1
27550  93.780  -79.782  52.705  1
27551  93.789  -79.780  52.697  1
27568  93.934  -79.756  52.550  1
27569  93.943  -79.755  52.539  1
27570  93.952  -79.753  52.527  1
27571  93.960  -79.751  52.514  1
27572  93.969  -79.750  52.501  1
27573  93.977  -79.748  52.489  1
27574  93.986  -79.747  52.475  1
27575  93.994  -79.745  52.461  1
27576  94.003  -79.744  52.447  1
27577  94.011  -79.742  52.432  1
27578  94.020  -79.741  52.417  1
27579  94.029  -79.739  52.401  1
27580  94.037  -79.739  52.385  1
27581  94.046  -79.737  52.368  1
27582  94.054  -79.736  52.352  1
27583  94.063  -79.734  52.336  1
27584  94.071  -79.733  52.318  1
27585  94.080  -79.731  52.301  1
27586  94.088  -79.730  52.285  1
27587  94.097  -79.728  52.267  1
27588  94.106  -79.726  52.250  1
27589  94.114  -79.725  52.234  1
27590  94.123  -79.723  52.217  1
27591  94.131  -79.722  52.199  1
27592  94.140  -79.720  52.181  1
27593  94.148  -79.720  52.163  1
27594  94.157  -79.704  52.146  1
27595  94.165  -79.678  52.129  1
27596  94.174  -79.652  52.112  1
27597  94.182  -79.626  52.094  1
27598  94.191  -79.601  52.075  1
27599  94.199  -79.575  52.055  1
27600  94.208  -79.549  52.034  1
27601  94.216  -79.523  52.016  1
27602  94.225  -79.498  51.997  1
27603  94.234  -79.472  51.977  1
27604  94.242  -79.446  51.959  1
27605  94.251  -79.419  51.939  1
27606  94.259  -79.394  51.918  1
27607  94.268  -79.368  51.900  1
27608  94.276  -79.342  51.882  1
27609  94.286  -79.325  51.865  1
27610  94.293  -79.325  51.847  1
27611  94.301  -79.326  51.825  1
27612  94.309  -79.326  51.799  1
27613  94.317  -79.326  51.771  1
27614  94.325  -79.326  51.743  1
27615  94.329  -79.330  51.718  1
27616  94.329  -79.316  51.693  1
27617  94.331  -79.294  51.667  1
27618  94.332  -79.273  51.640  1
27619  94.334  -79.253  51.611  1
27620  94.335  -79.231  51.577  1
27621  94.337  -79.210  51.542  1
27622  94.334  -79.209  51.505  1
27623  94.343  -79.246  51.467  1
27624  94.352  -79.289  51.431  1
27625  94.360  -79.333  51.396  1
27626  94.369  -79.376  51.362  1
27627  94.378  -79.419  51.327  1
27628  94.387  -79.463  51.291  1
27629  94.396  -79.506  51.256  1
27630  94.405  -79.549  51.222  1
27631  94.413  -79.592  51.186  1
27632  94.422  -79.636  51.151  1
28169  92.528  -80.388  53.493  1
28170  92.545  -80.379  53.473  1
28171  92.561  -80.372  53.453  1
28172  92.577  -80.363  53.433  1
28173  92.593  -80.355  53.412  1
28174  92.609  -80.347  53.390  1
28175  92.625  -80.339  53.369  1
28176  92.641  -80.331  53.347  1
28177  92.657  -80.323  53.325  1
28178  92.673  -80.315  53.304  1
28179  92.689  -80.307  53.283  1
28180  92.705  -80.299  53.261  1
28181  92.721  -80.291  53.240  1
28182  92.737  -80.283  53.220  1
28183  92.753  -80.275  53.200  1
28184  92.769  -80.267  53.182  1
28185  92.785  -80.259  53.165  1
28186  92.801  -80.251  53.149  1
28187  92.817  -80.243  53.135  1
28188  92.833  -80.234  53.120  1
28189  92.849  -80.227  53.104  1
28190  92.865  -80.218  53.085  1
28191  92.882  -80.211  53.065  1
28192  92.903  -80.203  53.044  1
28193  92.924  -80.194  53.022  1
28194  92.944  -80.186  53.000  1
28195  92.965  -80.178  52.981  1
28196  92.988  -80.153  52.964  1
28197  93.005  -80.144  52.949  1
28198  93.018  -80.149  52.937  1
28199  93.028  -80.151  52.926  1
28200  93.040  -80.141  52.915  1
28201  93.054  -80.128  52.907  1
28202  93.067  -80.115  52.898  1
28203  93.081  -80.102  52.888  1
28204  93.094  -80.090  52.879  1
28205  93.111  -80.077  52.872  1
28206  93.133  -80.068  52.865  1
28207  93.155  -80.058  52.859  1
28208  93.179  -80.049  52.855  1
28209  93.206  -80.049  52.850  1
28210  93.213  -80.034  52.845  1
28211  93.227  -80.021  52.838  1
28212  93.237  -80.003  52.831  1
28213  93.247  -79.984  52.823  1
28214  93.260  -79.973  52.816  1
28215  93.275  -79.964  52.811  1
28216  93.289  -79.955  52.807  1
28217  93.304  -79.946  52.804  1
28218  93.319  -79.936  52.805  1
28219  93.334  -79.927  52.806  1
28220  93.380  -79.935  52.808  1
28221  93.409  -79.945  52.813  1
28222  93.424  -79.943  52.818  1
28223  93.449  -79.912  52.823  1
28224  93.473  -79.885  52.827  1
28225  93.486  -79.879  52.832  1
28226  93.499  -79.873  52.836  1
28227  93.513  -79.867  52.841  1
28228  93.526  -79.861  52.842  1
28229  93.540  -79.855  52.843  1
28230  93.553  -79.849  52.843  1
28231  93.566  -79.842  52.844  1
28232  93.579  -79.837  52.843  1
28233  93.592  -79.831  52.840  1
28234  93.606  -79.825  52.835  1
28235  93.619  -79.819  52.827  1
28236  93.632  -79.813  52.819  1
28237  93.646  -79.807  52.810  1
28238  93.659  -79.801  52.804  1
28239  93.672  -79.795  52.797  1
28240  93.684  -79.787  52.790  1
28241  93.694  -79.777  52.784  1
28242  93.708  -79.770  52.776  1
28243  93.715  -79.772  52.767  1
28244  93.721  -79.775  52.758  1
28245  93.728  -79.776  52.750  1
28246  93.736  -79.775  52.742  1
28247  93.745  -79.773  52.734  1
28248  93.754  -79.772  52.726  1
28249  93.762  -79.770  52.718  1
28250  93.771  -79.769  52.710  1
28251  93.779  -79.767  52.702  1
28252  93.788  -79.766  52.695  1
28269  93.933  -79.742  52.550  1
28270  93.942  -79.740  52.539  1
28271  93.951  -79.739  52.526  1
28272  93.959  -79.737  52.513  1
28273  93.968  -79.736  52.500  1
28274  93.976  -79.734  52.489  1
28275  93.985  -79.733  52.475  1
28276  93.993  -79.731  52.461  1
28277  94.002  -79.730  52.446  1
28278  94.010  -79.728  52.432  1
28279  94.019  -79.726  52.416  1
28280  94.028  -79.726  52.401  1
28281  94.036  -79.724  52.385  1
28282  94.045  -79.723  52.368  1
28283  94.053  -79.721  52.351  1
28284  94.062  -79.720  52.336  1
28285  94.070  -79.718  52.318  1
28286  94.079  -79.717  52.301  1
28287  94.087  -79.715  52.284  1
28288  94.096  -79.714  52.267  1
28289  94.105  -79.712  52.250  1
28290  94.113  -79.711  52.233  1
28291  94.122  -79.709  52.217  1
28292  94.130  -79.708  52.199  1
28293  94.139  -79.707  52.181  1
28294  94.147  -79.705  52.163  1
28295  94.156  -79.691  52.145  1
28296  94.165  -79.665  52.128  1
28297  94.173  -79.639  52.111  1
28298  94.182  -79.614  52.094  1
28299  94.190  -79.588  52.074  1
28300  94.199  -79.561  52.054  1
28301  94.207  -79.535  52.034  1
28302  94.215  -79.510  52.016  1
28303  94.224  -79.484  51.997  1
28304  94.232  -79.458  51.978  1
28305  94.241  -79.432  51.959  1
28306  94.250  -79.407  51.940  1
28307  94.258  -79.381  51.921  1
28308  94.266  -79.354  51.903  1
28309  94.274  -79.328  51.886  1
28310  94.288  -79.313  51.869  1
28311  94.296  -79.313  51.850  1
28312  94.305  -79.313  51.827  1
28313  94.312  -79.313  51.802  1
28314  94.320  -79.313  51.774  1
28315  94.328  -79.313  51.745  1
28316  94.326  -79.322  51.718  1
28317  94.326  -79.313  51.693  1
28318  94.327  -79.293  51.667  1
28319  94.329  -79.272  51.641  1
28320  94.331  -79.250  51.613  1
28321  94.332  -79.229  51.581  1
28322  94.331  -79.214  51.546  1
28323  94.323  -79.217  51.509  1
28324  94.332  -79.224  51.472  1
28325  94.341  -79.267  51.437  1
28326  94.350  -79.310  51.403  1
28327  94.358  -79.353  51.370  1
28328  94.367  -79.397  51.334  1
28329  94.376  -79.440  51.298  1
28330  94.385  -79.483  51.262  1
28331  94.394  -79.526  51.228  1
28332  94.403  -79.570  51.193  1
28333  94.411  -79.613  51.157  1
28871  92.541  -80.363  53.498  1
28872  92.557  -80.354  53.478  1
28873  92.573  -80.347  53.457  1
28874  92.589  -80.338  53.435  1
28875  92.605  -80.330  53.413  1
28876  92.621  -80.322  53.392  1
28877  92.637  -80.314  53.370  1
28878  92.653  -80.306  53.347  1
28879  92.669  -80.298  53.326  1
28880  92.685  -80.290  53.304  1
28881  92.701  -80.282  53.282  1
28882  92.717  -80.274  53.259  1
28883  92.733  -80.266  53.238  1
28884  92.749  -80.258  53.217  1
28885  92.765  -80.250  53.197  1
28886  92.781  -80.242  53.178  1
28887  92.797  -80.234  53.159  1
28888  92.813  -80.226  53.142  1
28889  92.829  -80.218  53.126  1
28890  92.845  -80.209  53.109  1
28891  92.861  -80.202  53.091  1
28892  92.877  -80.193  53.071  1
28893  92.894  -80.186  53.050  1
28894  92.909  -80.178  53.029  1
28895  92.928  -80.169  53.007  1
28896  92.948  -80.161  52.988  1
28897  92.970  -80.153  52.972  1
28898  92.991  -80.136  52.956  1
28899  93.009  -80.126  52.943  1
28900  93.021  -80.131  52.932  1
28901  93.031  -80.124  52.922  1
28902  93.046  -80.111  52.914  1
28903  93.059  -80.098  52.902  1
28904  93.073  -80.085  52.891  1
28905  93.086  -80.072  52.883  1
28906  93.100  -80.059  52.874  1
28907  93.114  -80.046  52.867  1
28908  93.133  -80.035  52.860  1
28909  93.155  -80.025  52.855  1
28910  93.183  -80.026  52.850  1
28911  93.204  -80.019  52.844  1
28912  93.219  -80.007  52.838  1
28913  93.230  -79.990  52.830  1
28914  93.242  -79.977  52.822  1
28915  93.257  -79.968  52.816  1
28916  93.272  -79.959  52.811  1
28917  93.286  -79.950  52.807  1
28918  93.301  -79.941  52.805  1
28919  93.316  -79.932  52.805  1
28920  93.331  -79.923  52.806  1
28921  93.374  -79.930  52.808  1
28922  93.415  -79.939  52.814  1
28923  93.431  -79.933  52.818  1
28924  93.457  -79.902  52.822  1
28925  93.482  -79.871  52.825  1
28926  93.495  -79.864  52.828  1
28927  93.509  -79.859  52.831  1
28928  93.522  -79.853  52.835  1
28929  93.535  -79.847  52.836  1
28930  93.549  -79.841  52.838  1
28931  93.562  -79.835  52.839  1
28932  93.575  -79.829  52.841  1
28933  93.588  -79.823  52.841  1
28934  93.602  -79.817  52.838  1
28935  93.615  -79.811  52.835  1
28936  93.628  -79.805  52.828  1
28937  93.641  -79.799  52.820  1
28938  93.653  -79.791  52.811  1
28939  93.663  -79.781  52.804  1
28940  93.673  -79.771  52.797  1
28941  93.683  -79.761  52.790  1
28942  93.693  -79.751  52.785  1
28943  93.706  -79.743  52.776  1
28944  93.721  -79.737  52.765  1
28945  93.734  -79.733  52.756  1
28946  93.741  -79.735  52.746  1
28947  93.748  -79.737  52.738  1
28948  93.754  -79.740  52.730  1
28949  93.761  -79.742  52.723  1
28950  93.767  -79.745  52.715  1
28951  93.774  -79.747  52.707  1
28952  93.780  -79.750  52.700  1
28953  93.787  -79.752  52.693  1
28954  93.795  -79.751  52.686  1
28956  93.813  -79.748  52.671  1
28957  93.821  -79.746  52.663  1
28958  93.830  -79.745  52.655  1
28959  93.838  -79.743  52.648  1
28960  93.847  -79.742  52.640  1
28961  93.855  -79.740  52.632  1
28962  93.864  -79.739  52.623  1
28963  93.872  -79.737  52.615  1
28964  93.881  -79.736  52.607  1
28965  93.890  -79.734  52.597  1
28970  93.932  -79.727  52.548  1
28971  93.941  -79.726  52.536  1
28972  93.949  -79.724  52.524  1
28973  93.958  -79.723  52.511  1
28974  93.967  -79.721  52.499  1
28975  93.975  -79.720  52.486  1
28976  93.984  -79.718  52.472  1
28977  93.992  -79.717  52.459  1
28978  94.001  -79.715  52.445  1
28979  94.009  -79.714  52.430  1
28980  94.018  -79.713  52.415  1
28981  94.027  -79.711  52.399  1
28982  94.035  -79.710  52.384  1
28983  94.044  -79.708  52.367  1
28984  94.052  -79.707  52.350  1
28985  94.061  -79.705  52.334  1
28986  94.069  -79.704  52.317  1
28987  94.078  -79.702  52.299  1
28988  94.086  -79.701  52.283  1
28989  94.095  -79.699  52.266  1
28990  94.104  -79.698  52.249  1
28991  94.112  -79.696  52.232  1
28992  94.121  -79.695  52.216  1
28993  94.129  -79.694  52.198  1
28994  94.138  -79.692  52.180  1
28995  94.146  -79.691  52.162  1
28996  94.155  -79.677  52.144  1
28997  94.164  -79.651  52.127  1
28998  94.172  -79.626  52.110  1
28999  94.181  -79.600  52.092  1
29000  94.189  -79.574  52.073  1
29001  94.198  -79.548  52.053  1
29002  94.206  -79.523  52.033  1
29003  94.215  -79.497  52.014  1
29004  94.223  -79.470  51.996  1
29005  94.232  -79.444  51.977  1
29006  94.241  -79.419  51.959  1
29007  94.249  -79.393  51.940  1
29008  94.257  -79.366  51.921  1
29009  94.264  -79.340  51.903  1
29010  94.273  -79.314  51.886  1
29011  94.289  -79.304  51.868  1
29012  94.300  -79.300  51.848  1
29013  94.308  -79.300  51.826  1
29014  94.316  -79.300  51.801  1
29015  94.323  -79.300  51.773  1
29016  94.327  -79.303  51.745  1
29017  94.324  -79.315  51.719  1
29018  94.323  -79.312  51.694  1
29019  94.324  -79.291  51.668  1
29020  94.326  -79.270  51.642  1
29021  94.327  -79.249  51.614  1
29022  94.329  -79.228  51.584  1
29023  94.323  -79.219  51.550  1
29024  94.311  -79.225  51.514  1
29025  94.321  -79.219  51.478  1
29026  94.330  -79.245  51.443  1
29027  94.339  -79.288  51.409  1
29028  94.348  -79.332  51.376  1
29029  94.356  -79.375  51.340  1
29030  94.365  -79.418  51.304  1
29031  94.374  -79.461  51.269  1
29032  94.383  -79.504  51.235  1
29033  94.392  -79.548  51.199  1
29034  94.401  -79.591  51.164  1
29035  94.409  -79.634  51.128  1
29572  92.538  -80.349  53.524  1
29573  92.553  -80.337  53.503  1
29574  92.569  -80.329  53.482  1
29575  92.585  -80.322  53.460  1
29576  92.600  -80.313  53.439  1
29577  92.617  -80.305  53.417  1
29578  92.633  -80.297  53.394  1
29579  92.649  -80.289  53.372  1
29580  92.665  -80.281  53.350  1
29581  92.681  -80.273  53.327  1
29582  92.697  -80.265  53.304  1
29583  92.713  -80.257  53.280  1
29584  92.729  -80.249  53.258  1
29585  92.745  -80.241  53.236  1
29586  92.761  -80.233  53.215  1
29587  92.777  -80.225  53.194  1
29588  92.793  -80.217  53.173  1
29589  92.809  -80.209  53.153  1
29590  92.825  -80.201  53.134  1
29591  92.841  -80.193  53.116  1
29592  92.857  -80.184  53.098  1
29593  92.873  -80.177  53.078  1
29594  92.889  -80.168  53.058  1
29595  92.905  -80.161  53.037  1
29596  92.921  -80.153  53.016  1
29597  92.937  -80.144  52.998  1
29598  92.953  -80.137  52.981  1
29599  92.974  -80.128  52.965  1
29600  92.995  -80.119  52.951  1
29601  93.012  -80.108  52.939  1
29602  93.023  -80.106  52.928  1
29603  93.037  -80.093  52.918  1
29604  93.051  -80.080  52.907  1
29605  93.065  -80.067  52.896  1
29606  93.078  -80.054  52.886  1
29607  93.092  -80.041  52.877  1
29608  93.106  -80.028  52.869  1
29609  93.119  -80.015  52.861  1
29610  93.133  -80.002  52.855  1
29611  93.172  -80.017  52.849  1
29612  93.190  -80.005  52.842  1
29613  93.208  -79.993  52.836  1
29614  93.224  -79.983  52.829  1
29615  93.239  -79.974  52.823  1
29616  93.254  -79.965  52.816  1
29617  93.269  -79.955  52.811  1
29618  93.283  -79.946  52.807  1
29619  93.298  -79.937  52.805  1
29620  93.313  -79.928  52.805  1
29621  93.328  -79.919  52.806  1
29622  93.369  -79.924  52.809  1
29623  93.418  -79.934  52.815  1
29624  93.438  -79.924  52.818  1
29625  93.464  -79.893  52.821  1
29626  93.489  -79.862  52.822  1
29627  93.505  -79.851  52.824  1
29628  93.518  -79.845  52.827  1
29629  93.531  -79.839  52.831  1
29630  93.545  -79.833  52.832  1
29631  93.558  -79.827  52.833  1
29632  93.571  -79.821  52.834  1
29633  93.584  -79.815  52.835  1
29634  93.597  -79.809  52.836  1
29635  93.611  -79.803  52.834  1
29636  93.623  -79.795  52.831  1
29637  93.632  -79.785  52.825  1
29638  93.642  -79.775  52.819  1
29639  93.652  -79.765  52.810  1
29640  93.662  -79.755  52.803  1
29641  93.672  -79.745  52.797  1
29642  93.682  -79.735  52.791  1
29643  93.692  -79.725  52.784  1
29644  93.704  -79.717  52.774  1
29645  93.719  -79.710  52.762  1
29646  93.734  -79.704  52.752  1
29647  93.750  -79.698  52.742  1
29648  93.761  -79.695  52.734  1
29649  93.767  -79.698  52.725  1
29650  93.774  -79.700  52.718  1
29651  93.780  -79.702  52.710  1
29652  93.787  -79.705  52.703  1
29653  93.793  -79.708  52.697  1
29654  93.800  -79.710  52.690  1
29655  93.806  -79.713  52.683  1
29656  93.813  -79.715  52.675  1
29657  93.820  -79.717  52.668  1
29658  93.826  -79.720  52.661  1
29659  93.833  -79.723  52.653  1
29660  93.840  -79.725  52.645  1
29661  93.846  -79.727  52.638  1
29662  93.855  -79.726  52.629  1
29663  93.863  -79.724  52.621  1
29664  93.872  -79.723  52.613  1
29665  93.880  -79.721  52.604  1
29666  93.889  -79.720  52.595  1
29667  93.898  -79.719  52.586  1
29668  93.906  -79.717  52.576  1
29669  93.915  -79.716  52.566  1
29670  93.923  -79.714  52.556  1
29671  93.932  -79.713  52.545  1
29672  93.940  -79.711  52.533  1
29673  93.949  -79.710  52.521  1
29674  93.958  -79.708  52.508  1
29675  93.966  -79.707  52.495  1
29676  93.975  -79.705  52.482  1
29677  93.983  -79.704  52.469  1
29678  93.992  -79.702  52.455  1
29679  94.000  -79.701  52.442  1
29680  94.009  -79.700  52.427  1
29681  94.017  -79.698  52.411  1
29682  94.026  -79.697  52.395  1
29683  94.035  -79.695  52.379  1
29684  94.043  -79.694  52.363  1
29685  94.051  -79.692  52.347  1
29686  94.060  -79.691  52.332  1
29687  94.068  -79.689  52.315  1
29688  94.077  -79.688  52.297  1
29689  94.085  -79.686  52.280  1
29690  94.094  -79.685  52.264  1
29691  94.103  -79.683  52.247  1
29692  94.111  -79.682  52.230  1
29693  94.120  -79.681  52.214  1
29694  94.128  -79.679  52.197  1
29695  94.137  -79.678  52.179  1
29696  94.145  -79.676  52.160  1
29697  94.154  -79.664  52.142  1
29698  94.163  -79.638  52.124  1
29699  94.171  -79.612  52.107  1
29700  94.180  -79.586  52.091  1
29701  94.188  -79.560  52.072  1
29702  94.197  -79.535  52.051  1
29703  94.205  -79.509  52.032  1
29704  94.214  -79.483  52.013  1
29705  94.222  -79.457  51.994  1
29706  94.231  -79.431  51.975  1
29707  94.239  -79.405  51.957  1
29708  94.247  -79.379  51.939  1
29709  94.254  -79.352  51.920  1
29710  94.262  -79.325  51.903  1
29711  94.273  -79.305  51.885  1
29712  94.289  -79.294  51.866  1
29713  94.303  -79.286  51.847  1
29714  94.311  -79.287  51.825  1
29715  94.319  -79.287  51.801  1
29716  94.327  -79.287  51.773  1
29717  94.325  -79.296  51.746  1
29718  94.321  -79.307  51.721  1
29719  94.319  -79.310  51.697  1
29720  94.321  -79.289  51.671  1
29721  94.322  -79.268  51.645  1
29722  94.324  -79.247  51.617  1
29723  94.325  -79.226  51.587  1
29724  94.316  -79.225  51.554  1
29725  94.302  -79.231  51.519  1
29726  94.310  -79.226  51.483  1
29727  94.319  -79.222  51.449  1
29728  94.328  -79.266  51.415  1
29729  94.337  -79.309  51.382  1
29730  94.346  -79.352  51.347  1
29731  94.354  -79.395  51.311  1
29732  94.363  -79.438  51.276  1
29733  94.372  -79.482  51.241  1
29734  94.381  -79.525  51.206  1
29735  94.390  -79.569  51.170  1
29736  94.398  -79.612  51.135  1
29737  94.407  -79.655  51.098  1
29738  94.416  -79.698  51.061  1
30274  92.552  -80.327  53.528  1
30275  92.565  -80.315  53.507  1
30276  92.580  -80.304  53.485  1
30277  92.596  -80.297  53.464  1
30278  92.613  -80.288  53.442  1
30279  92.629  -80.280  53.419  1
30280  92.645  -80.272  53.396  1
30281  92.661  -80.264  53.374  1
30282  92.676  -80.256  53.351  1
30283  92.693  -80.248  53.327  1
30284  92.709  -80.240  53.304  1
30285  92.725  -80.232  53.281  1
30286  92.741  -80.224  53.258  1
30287  92.757  -80.216  53.235  1
30288  92.773  -80.208  53.213  1
30289  92.789  -80.200  53.191  1
30290  92.805  -80.192  53.169  1
30291  92.821  -80.184  53.148  1
30292  92.837  -80.176  53.127  1
30293  92.853  -80.168  53.106  1
30294  92.869  -80.159  53.086  1
30295  92.885  -80.152  53.066  1
30296  92.901  -80.143  53.047  1
30297  92.917  -80.136  53.027  1
30298  92.933  -80.127  53.009  1
30299  92.949  -80.119  52.991  1
30300  92.965  -80.112  52.975  1
30301  92.981  -80.103  52.960  1
30302  92.999  -80.095  52.946  1
30303  93.015  -80.088  52.935  1
30304  93.029  -80.075  52.923  1
30305  93.043  -80.062  52.911  1
30306  93.059  -80.050  52.900  1
30307  93.083  -80.040  52.890  1
30308  93.108  -80.030  52.880  1
30309  93.132  -80.020  52.871  1
30310  93.157  -80.009  52.863  1
30311  93.182  -79.999  52.855  1
30312  93.200  -79.990  52.848  1
30313  93.211  -79.983  52.841  1
30314  93.222  -79.975  52.835  1
30315  93.233  -79.968  52.829  1
30316  93.246  -79.960  52.822  1
30317  93.259  -79.953  52.816  1
30318  93.272  -79.946  52.811  1
30319  93.285  -79.938  52.808  1
30320  93.297  -79.931  52.807  1
30321  93.310  -79.924  52.808  1
30322  93.325  -79.914  52.810  1
30323  93.363  -79.918  52.812  1
30324  93.413  -79.929  52.814  1
30325  93.445  -79.914  52.816  1
30326  93.471  -79.883  52.818  1
30327  93.496  -79.853  52.820  1
30328  93.514  -79.837  52.821  1
30329  93.527  -79.831  52.823  1
30330  93.541  -79.825  52.827  1
30331  93.554  -79.819  52.829  1
30332  93.567  -79.813  52.830  1
30333  93.580  -79.807  52.829  1
30334  93.592  -79.799  52.829  1
30335  93.602  -79.789  52.829  1
30336  93.612  -79.779  52.829  1
30337  93.622  -79.769  52.825  1
30338  93.632  -79.759  52.820  1
30339  93.641  -79.749  52.815  1
30340  93.651  -79.739  52.807  1
30341  93.661  -79.729  52.800  1
30342  93.671  -79.719  52.794  1
30343  93.681  -79.709  52.788  1
30344  93.691  -79.699  52.779  1
30345  93.702  -79.690  52.769  1
30346  93.717  -79.683  52.758  1
30347  93.732  -79.677  52.746  1
30348  93.748  -79.670  52.736  1
30349  93.763  -79.664  52.727  1
30350  93.778  -79.657  52.720  1
30351  93.787  -79.657  52.713  1
30352  93.793  -79.661  52.705  1
30353  93.800  -79.663  52.698  1
30354  93.806  -79.665  52.692  1
30355  93.813  -79.668  52.685  1
30356  93.820  -79.670  52.678  1
30357  93.826  -79.673  52.671  1
30358  93.833  -79.675  52.664  1
30359  93.840  -79.678  52.657  1
30360  93.846  -79.680  52.650  1
30361  93.853  -79.683  52.641  1
30362  93.859  -79.686  52.634  1
30363  93.866  -79.688  52.626  1
30364  93.872  -79.690  52.618  1
30365  93.879  -79.692  52.610  1
30366  93.886  -79.695  52.601  1
30367  93.892  -79.698  52.591  1
30368  93.899  -79.700  52.582  1
30369  93.905  -79.703  52.573  1
30370  93.914  -79.701  52.562  1
30371  93.922  -79.700  52.552  1
30372  93.931  -79.698  52.541  1
30373  93.939  -79.697  52.530  1
30374  93.948  -79.695  52.517  1
30375  93.957  -79.694  52.505  1
30376  93.965  -79.692  52.491  1
30377  93.974  -79.691  52.478  1
30378  93.982  -79.689  52.465  1
30379  93.991  -79.688  52.452  1
30380  93.999  -79.687  52.437  1
30381  94.008  -79.686  52.423  1
30382  94.016  -79.684  52.408  1
30383  94.025  -79.683  52.392  1
30384  94.034  -79.681  52.376  1
30385  94.042  -79.679  52.360  1
30386  94.051  -79.678  52.344  1
30387  94.059  -79.676  52.329  1
30388  94.068  -79.675  52.312  1
30389  94.076  -79.673  52.295  1
30390  94.085  -79.672  52.279  1
30391  94.094  -79.670  52.262  1
30392  94.102  -79.669  52.245  1
30393  94.111  -79.668  52.229  1
30394  94.119  -79.667  52.213  1
30395  94.128  -79.665  52.195  1
30396  94.136  -79.664  52.177  1
30397  94.145  -79.662  52.159  1
30398  94.153  -79.651  52.141  1
30399  94.162  -79.625  52.123  1
30400  94.171  -79.599  52.106  1
30401  94.179  -79.573  52.088  1
30402  94.187  -79.547  52.069  1
30403  94.196  -79.521  52.049  1
30404  94.204  -79.495  52.030  1
30405  94.213  -79.469  52.011  1
30406  94.221  -79.443  51.992  1
30407  94.228  -79.416  51.974  1
30408  94.237  -79.390  51.957  1
30409  94.245  -79.363  51.939  1
30410  94.252  -79.338  51.920  1
30411  94.260  -79.311  51.902  1
30412  94.274  -79.295  51.884  1
30413  94.289  -79.285  51.866  1
30414  94.306  -79.275  51.848  1
30415  94.314  -79.273  51.827  1
30416  94.322  -79.273  51.803  1
30417  94.326  -79.278  51.775  1
30418  94.322  -79.288  51.749  1
30419  94.319  -79.300  51.724  1
30420  94.316  -79.308  51.700  1
30421  94.317  -79.288  51.675  1
30422  94.319  -79.266  51.649  1
30423  94.320  -79.245  51.621  1
30424  94.321  -79.225  51.592  1
30425  94.308  -79.231  51.559  1
30426  94.294  -79.237  51.525  1
30427  94.298  -79.234  51.489  1
30428  94.308  -79.228  51.456  1
30429  94.317  -79.244  51.422  1
30430  94.326  -79.287  51.388  1
30431  94.335  -79.330  51.354  1
30432  94.343  -79.373  51.319  1
30433  94.352  -79.416  51.284  1
30434  94.361  -79.460  51.249  1
30435  94.370  -79.503  51.213  1
30436  94.379  -79.546  51.177  1
30437  94.388  -79.589  51.142  1
30438  94.396  -79.632  51.105  1
30439  94.405  -79.676  51.068  1
30440  94.414  -79.719  51.030  1
30441  94.423  -79.762  50.993  1
30977  92.578  -80.292  53.510  1
30978  92.592  -80.280  53.489  1
30979  92.609  -80.272  53.467  1
30980  92.625  -80.263  53.444  1
30981  92.641  -80.255  53.421  1
30982  92.656  -80.247  53.398  1
30983  92.672  -80.239  53.375  1
30984  92.689  -80.231  53.351  1
30985  92.705  -80.223  53.328  1
30986  92.721  -80.215  53.304  1
30987  92.737  -80.207  53.281  1
30988  92.753  -80.199  53.257  1
30989  92.769  -80.191  53.234  1
30990  92.785  -80.183  53.211  1
30991  92.801  -80.174  53.188  1
30992  92.817  -80.167  53.166  1
30993  92.833  -80.159  53.144  1
30994  92.849  -80.151  53.122  1
30995  92.865  -80.143  53.101  1
30996  92.881  -80.134  53.081  1
30997  92.897  -80.127  53.061  1
30998  92.913  -80.118  53.040  1
30999  92.929  -80.111  53.021  1
31000  92.945  -80.102  53.003  1
31001  92.961  -80.094  52.986  1
31002  92.977  -80.087  52.970  1
31003  92.993  -80.078  52.955  1
31004  93.009  -80.071  52.942  1
31005  93.023  -80.062  52.928  1
31006  93.044  -80.052  52.916  1
31007  93.064  -80.041  52.904  1
31008  93.085  -80.030  52.893  1
31009  93.106  -80.020  52.883  1
31010  93.126  -80.009  52.874  1
31011  93.147  -79.999  52.864  1
31012  93.167  -79.988  52.855  1
31013  93.188  -79.977  52.847  1
31014  93.213  -79.968  52.841  1
31015  93.231  -79.960  52.834  1
31016  93.243  -79.952  52.828  1
31017  93.256  -79.945  52.822  1
31018  93.269  -79.937  52.817  1
31019  93.281  -79.930  52.813  1
31020  93.295  -79.922  52.811  1
31021  93.308  -79.914  52.810  1
31022  93.322  -79.906  52.811  1
31023  93.335  -79.898  52.811  1
31024  93.359  -79.895  52.811  1
31025  93.406  -79.902  52.813  1
31026  93.442  -79.889  52.814  1
31027  93.478  -79.874  52.815  1
31028  93.503  -79.843  52.817  1
31029  93.523  -79.823  52.818  1
31030  93.537  -79.817  52.820  1
31031  93.550  -79.811  52.822  1
31032  93.561  -79.803  52.825  1
31033  93.571  -79.793  52.827  1
31034  93.581  -79.783  52.827  1
31035  93.591  -79.773  52.824  1
31036  93.601  -79.763  52.823  1
31037  93.611  -79.753  52.821  1
31038  93.621  -79.743  52.817  1
31039  93.631  -79.733  52.813  1
31040  93.640  -79.723  52.809  1
31041  93.650  -79.713  52.802  1
31042  93.660  -79.703  52.796  1
31043  93.670  -79.693  52.790  1
31044  93.680  -79.683  52.782  1
31045  93.690  -79.673  52.773  1
31046  93.700  -79.664  52.763  1
31047  93.715  -79.657  52.751  1
31048  93.730  -79.651  52.740  1
31049  93.746  -79.644  52.730  1
31050  93.761  -79.638  52.721  1
31051  93.776  -79.631  52.713  1
31052  93.791  -79.625  52.707  1
31053  93.806  -79.618  52.700  1
31054  93.813  -79.620  52.693  1
31055  93.820  -79.623  52.687  1
31056  93.826  -79.626  52.680  1
31057  93.833  -79.628  52.673  1
31058  93.840  -79.630  52.667  1
31059  93.846  -79.633  52.660  1
31060  93.853  -79.636  52.653  1
31061  93.859  -79.638  52.646  1
31062  93.866  -79.640  52.638  1
31063  93.872  -79.643  52.630  1
31064  93.879  -79.645  52.623  1
31065  93.886  -79.648  52.615  1
31066  93.892  -79.651  52.607  1
31067  93.899  -79.653  52.598  1
31068  93.905  -79.655  52.588  1
31069  93.912  -79.657  52.578  1
31070  93.918  -79.661  52.569  1
31071  93.925  -79.663  52.558  1
31072  93.931  -79.665  52.547  1
31073  93.938  -79.668  52.537  1
31074  93.944  -79.670  52.526  1
31075  93.951  -79.673  52.513  1
31076  93.958  -79.675  52.501  1
31077  93.965  -79.678  52.488  1
31078  93.973  -79.676  52.475  1
31079  93.981  -79.675  52.462  1
31080  93.990  -79.674  52.448  1
31081  93.998  -79.673  52.434  1
31082  94.007  -79.671  52.419  1
31083  94.015  -79.670  52.404  1
31084  94.024  -79.668  52.388  1
31085  94.033  -79.667  52.373  1
31086  94.041  -79.665  52.357  1
31087  94.050  -79.664  52.342  1
31088  94.058  -79.662  52.327  1
31089  94.067  -79.661  52.310  1
31090  94.075  -79.659  52.293  1
31091  94.084  -79.657  52.277  1
31092  94.092  -79.656  52.259  1
31093  94.101  -79.655  52.243  1
31094  94.110  -79.654  52.227  1
31095  94.118  -79.652  52.211  1
31096  94.127  -79.651  52.193  1
31097  94.135  -79.649  52.175  1
31098  94.144  -79.648  52.157  1
31099  94.152  -79.637  52.140  1
31100  94.161  -79.611  52.122  1
31101  94.170  -79.585  52.105  1
31102  94.178  -79.560  52.087  1
31103  94.187  -79.534  52.068  1
31104  94.195  -79.508  52.048  1
31105  94.203  -79.482  52.029  1
31106  94.211  -79.455  52.010  1
31107  94.219  -79.429  51.991  1
31108  94.226  -79.402  51.974  1
31109  94.235  -79.375  51.958  1
31110  94.242  -79.349  51.940  1
31111  94.250  -79.322  51.922  1
31112  94.258  -79.297  51.904  1
31113  94.274  -79.286  51.886  1
31114  94.290  -79.275  51.868  1
31115  94.306  -79.265  51.850  1
31116  94.318  -79.260  51.829  1
31117  94.325  -79.260  51.805  1
31118  94.323  -79.270  51.779  1
31119  94.320  -79.281  51.754  1
31120  94.316  -79.292  51.729  1
31121  94.313  -79.303  51.706  1
31122  94.314  -79.285  51.682  1
31123  94.315  -79.265  51.657  1
31124  94.317  -79.244  51.630  1
31125  94.314  -79.231  51.599  1
31126  94.300  -79.237  51.567  1
31127  94.287  -79.243  51.533  1
31128  94.286  -79.242  51.497  1
31129  94.296  -79.235  51.463  1
31130  94.306  -79.228  51.430  1
31131  94.315  -79.264  51.397  1
31132  94.324  -79.307  51.362  1
31133  94.333  -79.350  51.328  1
31134  94.341  -79.394  51.293  1
31135  94.350  -79.438  51.256  1
31136  94.359  -79.481  51.220  1
31137  94.368  -79.524  51.185  1
31138  94.377  -79.567  51.149  1
31139  94.386  -79.610  51.112  1
31140  94.394  -79.654  51.074  1
31141  94.403  -79.697  51.037  1
31142  94.412  -79.740  50.999  1
31143  94.424  -79.760  50.962  1
31680  92.605  -80.257  53.492  1
31681  92.621  -80.247  53.469  1
31682  92.636  -80.238  53.447  1
31683  92.652  -80.231  53.424  1
31684  92.668  -80.222  53.401  1
31685  92.685  -80.214  53.377  1
31686  92.701  -80.206  53.351  1
31687  92.717  -80.198  53.327  1
31688  92.732  -80.190  53.304  1
31689  92.748  -80.182  53.279  1
31690  92.765  -80.174  53.255  1
31691  92.781  -80.166  53.232  1
31692  92.797  -80.158  53.208  1
31693  92.813  -80.149  53.185  1
31694  92.829  -80.142  53.162  1
31695  92.845  -80.134  53.140  1
31696  92.861  -80.126  53.118  1
31697  92.877  -80.118  53.097  1
31698  92.893  -80.109  53.076  1
31699  92.909  -80.102  53.055  1
31700  92.925  -80.093  53.035  1
31701  92.941  -80.086  53.017  1
31702  92.957  -80.077  52.998  1
31703  92.973  -80.069  52.981  1
31704  92.989  -80.062  52.965  1
31705  93.005  -80.053  52.949  1
31706  93.021  -80.046  52.934  1
31707  93.036  -80.036  52.920  1
31708  93.047  -80.030  52.908  1
31709  93.068  -80.019  52.895  1
31710  93.088  -80.008  52.885  1
31711  93.109  -79.998  52.876  1
31712  93.129  -79.987  52.866  1
31713  93.150  -79.977  52.856  1
31714  93.170  -79.966  52.847  1
31715  93.194  -79.956  52.840  1
31716  93.219  -79.947  52.834  1
31717  93.241  -79.938  52.828  1
31718  93.256  -79.930  52.823  1
31719  93.271  -79.921  52.820  1
31720  93.286  -79.913  52.817  1
31721  93.301  -79.905  52.814  1
31722  93.315  -79.896  52.814  1
31723  93.330  -79.888  52.813  1
31724  93.345  -79.880  52.812  1
31725  93.360  -79.871  52.812  1
31726  93.393  -79.859  52.813  1
31727  93.428  -79.846  52.813  1
31728  93.465  -79.833  52.814  1
31729  93.500  -79.820  52.815  1
31730  93.531  -79.807  52.817  1
31731  93.541  -79.797  52.818  1
31732  93.550  -79.787  52.819  1
31733  93.560  -79.777  52.821  1
31734  93.570  -79.767  52.823  1
31735  93.580  -79.757  52.823  1
31736  93.590  -79.747  52.820  1
31737  93.600  -79.737  52.817  1
31738  93.610  -79.727  52.813  1
31739  93.620  -79.717  52.810  1
31740  93.630  -79.707  52.806  1
31741  93.640  -79.697  52.802  1
31742  93.649  -79.687  52.797  1
31743  93.659  -79.677  52.790  1
31744  93.670  -79.667  52.783  1
31745  93.679  -79.657  52.776  1
31746  93.689  -79.647  52.765  1
31747  93.699  -79.637  52.754  1
31748  93.713  -79.630  52.742  1
31749  93.728  -79.624  52.733  1
31750  93.744  -79.617  52.723  1
31751  93.759  -79.611  52.714  1
31752  93.774  -79.604  52.707  1
31753  93.789  -79.598  52.700  1
31754  93.804  -79.592  52.693  1
31755  93.820  -79.585  52.688  1
31756  93.833  -79.581  52.682  1
31757  93.840  -79.583  52.676  1
31758  93.846  -79.585  52.669  1
31759  93.853  -79.588  52.663  1
31760  93.859  -79.591  52.657  1
31761  93.866  -79.593  52.649  1
31762  93.872  -79.595  52.642  1
31763  93.879  -79.598  52.635  1
31764  93.886  -79.601  52.627  1
31765  93.892  -79.603  52.620  1
31766  93.899  -79.606  52.612  1
31767  93.905  -79.608  52.604  1
31768  93.912  -79.610  52.595  1
31769  93.918  -79.613  52.585  1
31770  93.925  -79.616  52.575  1
31771  93.931  -79.618  52.565  1
31772  93.938  -79.620  52.554  1
31773  93.944  -79.623  52.544  1
31774  93.951  -79.626  52.533  1
31775  93.958  -79.628  52.522  1
31776  93.965  -79.630  52.509  1
31777  93.971  -79.633  52.497  1
31778  93.978  -79.636  52.485  1
31779  93.984  -79.638  52.471  1
31780  93.991  -79.641  52.458  1
31781  93.997  -79.643  52.444  1
31782  94.004  -79.645  52.431  1
31783  94.010  -79.648  52.416  1
31784  94.017  -79.651  52.401  1
31785  94.024  -79.653  52.386  1
31786  94.032  -79.652  52.370  1
31787  94.040  -79.651  52.354  1
31788  94.049  -79.649  52.339  1
31789  94.057  -79.648  52.324  1
31790  94.066  -79.646  52.308  1
31791  94.074  -79.645  52.291  1
31792  94.083  -79.643  52.274  1
31793  94.091  -79.642  52.257  1
31794  94.100  -79.641  52.241  1
31795  94.109  -79.639  52.225  1
31796  94.117  -79.638  52.209  1
31797  94.126  -79.636  52.192  1
31798  94.134  -79.635  52.174  1
31799  94.143  -79.633  52.156  1
31800  94.151  -79.624  52.139  1
31801  94.160  -79.598  52.122  1
31802  94.169  -79.572  52.104  1
31803  94.177  -79.546  52.086  1
31804  94.185  -79.520  52.067  1
31805  94.193  -79.494  52.047  1
31806  94.201  -79.467  52.029  1
31807  94.209  -79.441  52.010  1
31808  94.217  -79.414  51.991  1
31809  94.224  -79.388  51.975  1
31810  94.232  -79.361  51.959  1
31811  94.240  -79.335  51.943  1
31812  94.248  -79.308  51.925  1
31813  94.259  -79.287  51.906  1
31814  94.274  -79.276  51.888  1
31815  94.290  -79.266  51.870  1
31816  94.307  -79.256  51.851  1
31817  94.321  -79.247  51.830  1
31818  94.324  -79.251  51.808  1
31819  94.321  -79.263  51.784  1
31820  94.317  -79.273  51.760  1
31821  94.314  -79.285  51.736  1
31822  94.310  -79.296  51.713  1
31823  94.310  -79.284  51.690  1
31824  94.312  -79.263  51.665  1
31825  94.314  -79.242  51.639  1
31826  94.306  -79.237  51.608  1
31827  94.293  -79.243  51.575  1
31828  94.279  -79.249  51.542  1
31829  94.275  -79.250  51.507  1
31830  94.285  -79.244  51.472  1
31831  94.294  -79.237  51.439  1
31832  94.304  -79.242  51.407  1
31833  94.313  -79.285  51.372  1
31834  94.322  -79.328  51.337  1
31835  94.331  -79.372  51.302  1
31836  94.339  -79.415  51.265  1
31837  94.348  -79.458  51.229  1
31838  94.357  -79.501  51.193  1
31839  94.366  -79.545  51.157  1
31840  94.374  -79.588  51.119  1
31841  94.384  -79.631  51.082  1
31842  94.392  -79.674  51.044  1
31843  94.403  -79.708  51.006  1
31844  94.416  -79.720  50.968  1
31845  94.429  -79.734  50.931  1
31846  94.442  -79.747  50.894  1
32383  92.633  -80.222  53.472  1
32384  92.648  -80.213  53.448  1
32385  92.664  -80.206  53.425  1
32386  92.681  -80.197  53.400  1
32387  92.697  -80.189  53.376  1
32388  92.712  -80.181  53.352  1
32389  92.728  -80.173  53.327  1
32390  92.744  -80.165  53.303  1
32391  92.761  -80.157  53.278  1
32392  92.777  -80.149  53.254  1
32393  92.793  -80.141  53.229  1
32394  92.808  -80.133  53.205  1
32395  92.825  -80.124  53.182  1
32396  92.841  -80.117  53.160  1
32397  92.857  -80.109  53.137  1
32398  92.873  -80.101  53.115  1
32399  92.889  -80.093  53.093  1
32400  92.905  -80.084  53.071  1
32401  92.921  -80.077  53.051  1
32402  92.937  -80.068  53.031  1
32403  92.953  -80.061  53.012  1
32404  92.969  -80.052  52.993  1
32405  92.985  -80.044  52.975  1
32406  93.001  -80.037  52.959  1
32407  93.017  -80.028  52.942  1
32408  93.033  -80.021  52.927  1
32409  93.049  -80.008  52.913  1
32410  93.056  -80.005  52.900  1
32411  93.071  -79.997  52.889  1
32412  93.091  -79.987  52.878  1
32413  93.112  -79.976  52.868  1
32414  93.133  -79.965  52.859  1
32415  93.153  -79.955  52.851  1
32416  93.174  -79.944  52.842  1
32417  93.199  -79.935  52.836  1
32418  93.222  -79.926  52.831  1
32419  93.237  -79.918  52.826  1
32420  93.252  -79.909  52.824  1
32421  93.267  -79.901  52.821  1
32422  93.282  -79.892  52.819  1
32423  93.296  -79.884  52.818  1
32424  93.311  -79.876  52.817  1
32425  93.330  -79.867  52.815  1
32426  93.353  -79.857  52.814  1
32427  93.379  -79.846  52.814  1
32428  93.415  -79.834  52.814  1
32429  93.451  -79.821  52.815  1
32430  93.487  -79.808  52.816  1
32431  93.519  -79.795  52.817  1
32432  93.534  -79.778  52.818  1
32433  93.549  -79.762  52.817  1
32434  93.559  -79.751  52.818  1
32435  93.569  -79.741  52.818  1
32436  93.579  -79.731  52.818  1
32437  93.589  -79.721  52.815  1
32438  93.599  -79.711  52.811  1
32439  93.609  -79.701  52.807  1
32440  93.619  -79.691  52.803  1
32441  93.629  -79.681  52.799  1
32442  93.639  -79.671  52.795  1
32443  93.648  -79.661  52.789  1
32444  93.658  -79.651  52.782  1
32445  93.669  -79.642  52.774  1
32446  93.679  -79.631  52.767  1
32447  93.688  -79.621  52.756  1
32448  93.698  -79.611  52.745  1
32449  93.712  -79.604  52.733  1
32450  93.727  -79.597  52.724  1
32451  93.742  -79.591  52.715  1
32452  93.757  -79.585  52.708  1
32453  93.772  -79.578  52.701  1
32454  93.787  -79.572  52.694  1
32455  93.802  -79.565  52.688  1
32456  93.818  -79.559  52.683  1
32457  93.833  -79.552  52.678  1
32458  93.848  -79.546  52.672  1
32459  93.859  -79.544  52.665  1
32460  93.866  -79.546  52.660  1
32461  93.872  -79.548  52.653  1
32462  93.879  -79.551  52.646  1
32463  93.886  -79.554  52.640  1
32464  93.892  -79.556  52.632  1
32465  93.899  -79.558  52.625  1
32466  93.905  -79.561  52.617  1
32467  93.912  -79.563  52.610  1
32468  93.918  -79.566  52.601  1
32469  93.925  -79.568  52.592  1
32470  93.931  -79.571  52.582  1
32471  93.938  -79.573  52.572  1
32472  93.944  -79.576  52.562  1
32473  93.951  -79.579  52.552  1
32474  93.958  -79.581  52.541  1
32475  93.965  -79.583  52.530  1
32476  93.971  -79.585  52.518  1
32477  93.978  -79.588  52.506  1
32478  93.984  -79.591  52.493  1
32479  93.991  -79.593  52.480  1
32480  93.997  -79.596  52.467  1
32481  94.004  -79.598  52.454  1
32482  94.010  -79.601  52.440  1
32483  94.017  -79.603  52.427  1
32484  94.024  -79.606  52.412  1
32485  94.030  -79.608  52.397  1
32486  94.037  -79.610  52.383  1
32487  94.043  -79.614  52.367  1
32488  94.050  -79.616  52.352  1
32489  94.056  -79.618  52.336  1
32490  94.063  -79.620  52.321  1
32491  94.069  -79.623  52.305  1
32492  94.076  -79.626  52.288  1
32493  94.083  -79.628  52.272  1
32494  94.091  -79.628  52.255  1
32495  94.100  -79.626  52.239  1
32496  94.108  -79.625  52.223  1
32497  94.117  -79.623  52.208  1
32498  94.125  -79.622  52.191  1
32499  94.134  -79.620  52.174  1
32500  94.142  -79.619  52.156  1
32501  94.150  -79.610  52.140  1
32502  94.159  -79.585  52.124  1
32503  94.168  -79.558  52.106  1
32504  94.175  -79.532  52.087  1
32505  94.183  -79.506  52.068  1
32506  94.191  -79.479  52.048  1
32507  94.199  -79.453  52.029  1
32508  94.207  -79.426  52.010  1
32509  94.214  -79.400  51.994  1
32510  94.222  -79.373  51.978  1
32511  94.230  -79.347  51.962  1
32512  94.238  -79.320  51.946  1
32513  94.246  -79.294  51.927  1
32514  94.259  -79.278  51.908  1
32515  94.275  -79.267  51.889  1
32516  94.291  -79.256  51.871  1
32517  94.307  -79.246  51.852  1
32518  94.323  -79.235  51.832  1
32519  94.322  -79.244  51.811  1
32520  94.318  -79.255  51.789  1
32521  94.315  -79.266  51.767  1
32522  94.311  -79.277  51.744  1
32523  94.308  -79.288  51.721  1
32524  94.307  -79.282  51.698  1
32525  94.309  -79.261  51.674  1
32526  94.310  -79.240  51.648  1
32527  94.298  -79.243  51.617  1
32528  94.285  -79.249  51.585  1
32529  94.272  -79.254  51.552  1
32530  94.264  -79.258  51.518  1
32531  94.273  -79.251  51.484  1
32532  94.283  -79.244  51.450  1
32533  94.293  -79.238  51.417  1
32534  94.302  -79.263  51.382  1
32535  94.311  -79.306  51.346  1
32536  94.320  -79.350  51.311  1
32537  94.329  -79.393  51.275  1
32538  94.337  -79.436  51.239  1
32539  94.346  -79.479  51.202  1
32540  94.355  -79.523  51.165  1
32541  94.364  -79.566  51.128  1
32542  94.372  -79.609  51.090  1
32543  94.382  -79.652  51.051  1
32544  94.394  -79.668  51.013  1
32545  94.407  -79.682  50.974  1
32546  94.420  -79.695  50.937  1
32547  94.433  -79.708  50.899  1
32548  94.447  -79.720  50.861  1
33085  92.646  -80.200  53.473  1
33086  92.660  -80.188  53.449  1
33087  92.676  -80.181  53.425  1
33088  92.692  -80.172  53.400  1
33089  92.708  -80.164  53.376  1
33090  92.724  -80.156  53.351  1
33091  92.740  -80.148  53.326  1
33092  92.757  -80.140  53.301  1
33093  92.773  -80.132  53.276  1
33094  92.788  -80.124  53.252  1
33095  92.804  -80.116  53.228  1
33096  92.820  -80.108  53.204  1
33097  92.837  -80.100  53.180  1
33098  92.853  -80.092  53.157  1
33099  92.869  -80.084  53.134  1
33100  92.885  -80.076  53.111  1
33101  92.901  -80.068  53.089  1
33102  92.917  -80.059  53.068  1
33103  92.933  -80.052  53.046  1
33104  92.949  -80.043  53.026  1
33105  92.965  -80.036  53.006  1
33106  92.981  -80.027  52.987  1
33107  92.997  -80.019  52.970  1
33108  93.013  -80.012  52.952  1
33109  93.029  -80.003  52.936  1
33110  93.046  -79.994  52.920  1
33111  93.063  -79.981  52.907  1
33112  93.070  -79.977  52.893  1
33113  93.076  -79.974  52.880  1
33114  93.095  -79.965  52.871  1
33115  93.116  -79.954  52.863  1
33116  93.136  -79.943  52.854  1
33117  93.156  -79.933  52.846  1
33118  93.180  -79.923  52.840  1
33119  93.203  -79.914  52.835  1
33120  93.218  -79.905  52.831  1
33121  93.233  -79.897  52.829  1
33122  93.248  -79.889  52.827  1
33123  93.263  -79.880  52.824  1
33124  93.277  -79.872  52.823  1
33125  93.301  -79.862  52.821  1
33126  93.324  -79.852  52.819  1
33127  93.347  -79.843  52.818  1
33128  93.370  -79.833  52.818  1
33129  93.402  -79.821  52.818  1
33130  93.438  -79.808  52.818  1
33131  93.474  -79.795  52.819  1
33132  93.506  -79.783  52.819  1
33133  93.521  -79.766  52.819  1
33134  93.537  -79.750  52.817  1
33135  93.551  -79.734  52.815  1
33136  93.566  -79.718  52.814  1
33137  93.578  -79.705  52.812  1
33138  93.588  -79.695  52.809  1
33139  93.598  -79.686  52.805  1
33140  93.608  -79.675  52.801  1
33141  93.618  -79.665  52.796  1
33142  93.628  -79.655  52.791  1
33143  93.638  -79.645  52.786  1
33144  93.648  -79.636  52.779  1
33145  93.657  -79.625  52.772  1
33146  93.667  -79.615  52.764  1
33147  93.678  -79.605  52.756  1
33148  93.687  -79.595  52.746  1
33149  93.697  -79.585  52.736  1
33150  93.710  -79.577  52.725  1
33151  93.725  -79.570  52.716  1
33152  93.740  -79.564  52.708  1
33153  93.755  -79.557  52.701  1
33154  93.770  -79.551  52.694  1
33155  93.785  -79.545  52.688  1
33156  93.800  -79.538  52.682  1
33157  93.816  -79.532  52.678  1
33158  93.831  -79.526  52.672  1
33159  93.846  -79.520  52.667  1
33160  93.861  -79.513  52.661  1
33161  93.876  -79.507  52.656  1
33162  93.886  -79.506  52.649  1
33163  93.892  -79.509  52.642  1
33164  93.899  -79.511  52.636  1
33165  93.905  -79.513  52.629  1
33166  93.912  -79.516  52.622  1
33167  93.918  -79.519  52.614  1
33168  93.925  -79.521  52.606  1
33169  93.931  -79.523  52.598  1
33170  93.938  -79.526  52.590  1
33171  93.944  -79.529  52.580  1
33172  93.951  -79.531  52.570  1
33173  93.958  -79.533  52.559  1
33174  93.965  -79.536  52.548  1
33175  93.971  -79.538  52.537  1
33176  93.978  -79.541  52.525  1
33177  93.984  -79.544  52.514  1
33178  93.991  -79.546  52.501  1
33179  93.997  -79.548  52.488  1
33180  94.004  -79.551  52.475  1
33181  94.010  -79.554  52.463  1
33182  94.017  -79.556  52.450  1
33183  94.024  -79.558  52.436  1
33184  94.030  -79.561  52.423  1
33185  94.037  -79.563  52.408  1
33186  94.043  -79.566  52.393  1
33187  94.050  -79.569  52.379  1
33188  94.056  -79.571  52.364  1
33189  94.063  -79.573  52.349  1
33190  94.069  -79.576  52.333  1
33191  94.076  -79.579  52.319  1
33192  94.082  -79.581  52.302  1
33193  94.089  -79.583  52.285  1
33194  94.096  -79.585  52.269  1
33195  94.103  -79.588  52.253  1
33196  94.109  -79.591  52.237  1
33197  94.116  -79.593  52.222  1
33198  94.122  -79.596  52.206  1
33199  94.129  -79.598  52.190  1
33200  94.135  -79.601  52.174  1
33201  94.142  -79.604  52.158  1
33202  94.150  -79.597  52.142  1
33203  94.157  -79.570  52.125  1
33204  94.166  -79.544  52.107  1
33205  94.173  -79.517  52.089  1
33206  94.181  -79.491  52.070  1
33207  94.189  -79.464  52.050  1
33208  94.197  -79.438  52.030  1
33209  94.205  -79.412  52.012  1
33210  94.212  -79.385  51.996  1
33211  94.220  -79.359  51.980  1
33212  94.228  -79.332  51.965  1
33213  94.236  -79.306  51.949  1
33214  94.244  -79.279  51.930  1
33215  94.260  -79.268  51.910  1
33216  94.275  -79.257  51.890  1
33217  94.291  -79.247  51.870  1
33218  94.300  -79.244  51.851  1
33219  94.308  -79.242  51.832  1
33220  94.317  -79.239  51.814  1
33221  94.316  -79.247  51.794  1
33222  94.312  -79.258  51.774  1
33223  94.309  -79.269  51.753  1
33224  94.305  -79.281  51.730  1
33225  94.303  -79.280  51.707  1
33226  94.305  -79.259  51.684  1
33227  94.305  -79.242  51.660  1
33228  94.291  -79.248  51.630  1
33229  94.277  -79.254  51.599  1
33230  94.264  -79.260  51.566  1
33231  94.252  -79.266  51.533  1
33232  94.262  -79.259  51.498  1
33233  94.272  -79.253  51.464  1
33234  94.281  -79.246  51.430  1
33235  94.291  -79.241  51.393  1
33236  94.300  -79.284  51.357  1
33237  94.309  -79.327  51.321  1
33238  94.318  -79.370  51.284  1
33239  94.327  -79.413  51.249  1
33240  94.335  -79.457  51.213  1
33241  94.344  -79.500  51.176  1
33242  94.353  -79.543  51.137  1
33243  94.362  -79.586  51.099  1
33244  94.372  -79.616  51.059  1
33245  94.386  -79.629  51.020  1
33246  94.399  -79.642  50.981  1
33247  94.412  -79.655  50.943  1
33248  94.425  -79.668  50.905  1
33249  94.438  -79.681  50.867  1
33788  92.673  -80.165  53.450  1
33789  92.688  -80.156  53.425  1
33790  92.704  -80.147  53.400  1
33791  92.720  -80.139  53.375  1
33792  92.736  -80.131  53.350  1
33793  92.753  -80.123  53.325  1
33794  92.768  -80.115  53.299  1
33795  92.784  -80.107  53.275  1
33796  92.800  -80.099  53.251  1
33797  92.816  -80.091  53.226  1
33798  92.833  -80.083  53.202  1
33799  92.849  -80.075  53.178  1
33800  92.865  -80.067  53.154  1
33801  92.880  -80.059  53.130  1
33802  92.897  -80.051  53.107  1
33803  92.913  -80.043  53.085  1
33804  92.929  -80.035  53.064  1
33805  92.945  -80.027  53.043  1
33806  92.961  -80.018  53.022  1
33807  92.977  -80.011  53.002  1
33808  92.993  -80.002  52.982  1
33809  93.009  -79.994  52.964  1
33810  93.025  -79.987  52.947  1
33811  93.041  -79.978  52.930  1
33812  93.058  -79.968  52.915  1
33813  93.076  -79.954  52.900  1
33814  93.083  -79.950  52.887  1
33815  93.090  -79.946  52.875  1
33816  93.098  -79.943  52.866  1
33817  93.119  -79.932  52.857  1
33818  93.139  -79.921  52.851  1
33819  93.160  -79.911  52.846  1
33820  93.184  -79.902  52.841  1
33821  93.199  -79.893  52.837  1
33822  93.214  -79.885  52.835  1
33823  93.228  -79.877  52.833  1
33824  93.248  -79.867  52.831  1
33825  93.271  -79.858  52.829  1
33826  93.295  -79.848  52.826  1
33827  93.318  -79.839  52.824  1
33828  93.341  -79.829  52.822  1
33829  93.364  -79.819  52.821  1
33830  93.389  -79.809  52.821  1
33831  93.425  -79.796  52.821  1
33832  93.461  -79.783  52.822  1
33833  93.494  -79.770  52.822  1
33834  93.509  -79.754  52.820  1
33835  93.524  -79.738  52.817  1
33836  93.539  -79.722  52.814  1
33837  93.554  -79.706  52.810  1
33838  93.569  -79.689  52.807  1
33839  93.584  -79.673  52.804  1
33840  93.597  -79.659  52.800  1
33841  93.607  -79.649  52.795  1
33842  93.617  -79.639  52.788  1
33843  93.627  -79.629  52.782  1
33844  93.637  -79.620  52.777  1
33845  93.647  -79.609  52.770  1
33846  93.657  -79.599  52.762  1
33847  93.666  -79.589  52.754  1
33848  93.677  -79.579  52.746  1
33849  93.687  -79.570  52.736  1
33850  93.696  -79.559  52.727  1
33851  93.708  -79.551  52.717  1
33852  93.723  -79.544  52.708  1
33853  93.738  -79.538  52.700  1
33854  93.753  -79.531  52.692  1
33855  93.768  -79.525  52.686  1
33856  93.783  -79.518  52.680  1
33857  93.798  -79.512  52.675  1
33858  93.814  -79.505  52.672  1
33859  93.829  -79.499  52.667  1
33860  93.844  -79.492  52.662  1
33861  93.859  -79.486  52.657  1
33862  93.874  -79.479  52.652  1
33863  93.890  -79.473  52.646  1
33864  93.905  -79.466  52.639  1
33865  93.912  -79.469  52.633  1
33866  93.918  -79.471  52.627  1
33867  93.925  -79.474  52.620  1
33868  93.931  -79.476  52.612  1
33869  93.938  -79.479  52.604  1
33870  93.944  -79.482  52.595  1
33871  93.951  -79.484  52.587  1
33872  93.958  -79.486  52.577  1
33873  93.965  -79.488  52.566  1
33874  93.971  -79.491  52.555  1
33875  93.978  -79.494  52.544  1
33876  93.984  -79.496  52.533  1
33877  93.991  -79.499  52.522  1
33878  93.997  -79.501  52.510  1
33879  94.004  -79.504  52.497  1
33880  94.010  -79.506  52.484  1
33881  94.017  -79.509  52.471  1
33882  94.024  -79.511  52.458  1
33883  94.030  -79.513  52.445  1
33884  94.037  -79.516  52.432  1
33885  94.043  -79.519  52.419  1
33886  94.050  -79.521  52.404  1
33887  94.056  -79.523  52.390  1
33888  94.063  -79.526  52.375  1
33889  94.069  -79.529  52.361  1
33890  94.076  -79.531  52.346  1
33891  94.082  -79.534  52.332  1
33892  94.089  -79.536  52.317  1
33893  94.096  -79.538  52.300  1
33894  94.103  -79.541  52.283  1
33895  94.105  -79.546  52.267  1
33896  94.106  -79.551  52.250  1
33897  94.107  -79.557  52.234  1
33898  94.109  -79.562  52.219  1
33899  94.110  -79.568  52.205  1
33900  94.113  -79.573  52.190  1
33901  94.122  -79.574  52.174  1
33902  94.135  -79.571  52.159  1
33903  94.146  -79.558  52.143  1
33904  94.154  -79.550  52.126  1
33905  94.162  -79.524  52.109  1
33906  94.170  -79.499  52.092  1
33907  94.178  -79.474  52.073  1
33908  94.187  -79.448  52.053  1
33909  94.195  -79.423  52.032  1
33910  94.202  -79.397  52.014  1
33911  94.210  -79.370  51.997  1
33912  94.218  -79.344  51.982  1
33913  94.226  -79.318  51.967  1
33914  94.234  -79.291  51.951  1
33915  94.244  -79.269  51.932  1
33916  94.260  -79.259  51.911  1
33917  94.268  -79.256  51.890  1
33918  94.276  -79.254  51.870  1
33919  94.284  -79.251  51.851  1
33920  94.293  -79.249  51.834  1
33921  94.301  -79.247  51.817  1
33922  94.309  -79.244  51.798  1
33923  94.310  -79.250  51.780  1
33924  94.306  -79.262  51.761  1
33925  94.302  -79.273  51.739  1
33926  94.300  -79.278  51.717  1
33927  94.301  -79.257  51.694  1
33928  94.296  -79.248  51.671  1
33929  94.283  -79.254  51.642  1
33930  94.270  -79.260  51.611  1
33931  94.257  -79.266  51.579  1
33932  94.243  -79.272  51.547  1
33933  94.251  -79.267  51.514  1
33934  94.260  -79.260  51.479  1
33935  94.270  -79.253  51.445  1
33936  94.280  -79.247  51.408  1
33937  94.289  -79.262  51.370  1
33938  94.298  -79.305  51.333  1
33939  94.307  -79.348  51.296  1
33940  94.316  -79.391  51.259  1
33941  94.325  -79.435  51.223  1
33942  94.333  -79.478  51.185  1
33943  94.342  -79.521  51.147  1
33944  94.351  -79.563  51.108  1
33945  94.364  -79.577  51.068  1
33946  94.377  -79.590  51.028  1
33947  94.391  -79.603  50.989  1
33948  94.404  -79.616  50.951  1
33949  94.417  -79.629  50.912  1
33950  94.430  -79.642  50.873  1
34491  92.700  -80.131  53.424  1
34492  92.716  -80.122  53.399  1
34493  92.732  -80.114  53.374  1
34494  92.748  -80.106  53.348  1
34495  92.764  -80.098  53.324  1
34496  92.780  -80.090  53.299  1
34497  92.796  -80.082  53.274  1
34498  92.812  -80.074  53.249  1
34499  92.829  -80.066  53.223  1
34500  92.845  -80.058  53.199  1
34501  92.860  -80.050  53.175  1
34502  92.876  -80.042  53.150  1
34503  92.893  -80.034  53.126  1
34504  92.909  -80.026  53.103  1
34505  92.925  -80.018  53.081  1
34506  92.941  -80.010  53.059  1
34507  92.956  -80.002  53.038  1
34508  92.973  -79.993  53.017  1
34509  92.989  -79.986  52.996  1
34510  93.005  -79.977  52.978  1
34511  93.021  -79.970  52.959  1
34512  93.037  -79.961  52.942  1
34513  93.053  -79.953  52.925  1
34514  93.070  -79.942  52.909  1
34515  93.088  -79.928  52.894  1
34516  93.097  -79.923  52.881  1
34517  93.103  -79.919  52.870  1
34518  93.111  -79.915  52.860  1
34519  93.122  -79.909  52.854  1
34520  93.143  -79.899  52.850  1
34521  93.165  -79.889  52.846  1
34522  93.180  -79.881  52.842  1
34523  93.195  -79.872  52.840  1
34524  93.219  -79.863  52.838  1
34525  93.242  -79.853  52.835  1
34526  93.265  -79.843  52.834  1
34527  93.288  -79.834  52.831  1
34528  93.312  -79.824  52.828  1
34529  93.335  -79.814  52.825  1
34530  93.358  -79.805  52.825  1
34531  93.382  -79.795  52.825  1
34532  93.412  -79.784  52.824  1
34533  93.447  -79.771  52.824  1
34534  93.482  -79.758  52.823  1
34535  93.497  -79.742  52.822  1
34536  93.512  -79.726  52.818  1
34537  93.527  -79.710  52.813  1
34538  93.542  -79.694  52.808  1
34539  93.557  -79.677  52.804  1
34540  93.572  -79.661  52.800  1
34541  93.586  -79.645  52.796  1
34542  93.602  -79.629  52.789  1
34543  93.616  -79.614  52.781  1
34544  93.626  -79.604  52.773  1
34545  93.636  -79.593  52.768  1
34546  93.646  -79.583  52.760  1
34547  93.656  -79.573  52.752  1
34548  93.665  -79.563  52.744  1
34549  93.676  -79.554  52.735  1
34550  93.686  -79.543  52.727  1
34551  93.695  -79.533  52.718  1
34552  93.706  -79.524  52.710  1
34553  93.721  -79.517  52.701  1
34554  93.736  -79.511  52.692  1
34555  93.751  -79.504  52.684  1
34556  93.767  -79.498  52.678  1
34557  93.782  -79.491  52.673  1
34558  93.797  -79.485  52.669  1
34559  93.812  -79.479  52.666  1
34560  93.827  -79.473  52.662  1
34561  93.842  -79.466  52.657  1
34562  93.857  -79.460  52.653  1
34563  93.872  -79.453  52.648  1
34564  93.888  -79.447  52.643  1
34565  93.903  -79.440  52.637  1
34566  93.918  -79.434  52.631  1
34567  93.931  -79.429  52.625  1
34568  93.938  -79.432  52.618  1
34569  93.944  -79.434  52.610  1
34570  93.951  -79.437  52.602  1
34571  93.958  -79.439  52.593  1
34572  93.965  -79.441  52.584  1
34573  93.971  -79.444  52.574  1
34574  93.978  -79.447  52.562  1
34575  93.984  -79.449  52.551  1
34576  93.991  -79.451  52.540  1
34577  93.997  -79.454  52.529  1
34578  94.004  -79.457  52.518  1
34579  94.010  -79.459  52.505  1
34580  94.017  -79.461  52.493  1
34581  94.024  -79.464  52.480  1
34582  94.030  -79.466  52.467  1
34583  94.037  -79.469  52.454  1
34584  94.043  -79.472  52.440  1
34585  94.050  -79.474  52.427  1
34586  94.056  -79.476  52.414  1
34587  94.059  -79.481  52.401  1
34588  94.060  -79.487  52.386  1
34589  94.061  -79.492  52.371  1
34590  94.062  -79.498  52.357  1
34591  94.063  -79.504  52.344  1
34592  94.064  -79.509  52.331  1
34593  94.065  -79.514  52.316  1
34594  94.067  -79.520  52.299  1
34595  94.068  -79.526  52.281  1
34596  94.069  -79.531  52.265  1
34597  94.070  -79.536  52.248  1
34598  94.075  -79.540  52.232  1
34599  94.084  -79.542  52.219  1
34600  94.093  -79.544  52.205  1
34601  94.102  -79.546  52.190  1
34602  94.112  -79.548  52.174  1
34603  94.128  -79.507  52.158  1
34604  94.143  -79.506  52.140  1
34605  94.149  -79.506  52.123  1
34606  94.158  -79.496  52.107  1
34607  94.167  -79.476  52.090  1
34608  94.175  -79.451  52.073  1
34609  94.183  -79.426  52.054  1
34610  94.191  -79.400  52.034  1
34611  94.199  -79.375  52.014  1
34612  94.207  -79.350  51.996  1
34613  94.215  -79.325  51.981  1
34614  94.223  -79.299  51.966  1
34615  94.231  -79.274  51.950  1
34616  94.238  -79.267  51.931  1
34617  94.245  -79.266  51.911  1
34618  94.253  -79.263  51.890  1
34619  94.261  -79.261  51.870  1
34620  94.269  -79.259  51.853  1
34621  94.277  -79.256  51.837  1
34622  94.285  -79.254  51.821  1
34623  94.294  -79.251  51.802  1
34624  94.302  -79.249  51.785  1
34625  94.303  -79.254  51.768  1
34626  94.300  -79.266  51.748  1
34627  94.296  -79.276  51.727  1
34628  94.298  -79.256  51.704  1
34629  94.289  -79.253  51.681  1
34630  94.276  -79.259  51.652  1
34631  94.262  -79.266  51.622  1
34632  94.249  -79.272  51.591  1
34633  94.236  -79.278  51.561  1
34634  94.239  -79.275  51.529  1
34635  94.249  -79.268  51.495  1
34636  94.259  -79.262  51.461  1
34637  94.268  -79.255  51.423  1
34638  94.278  -79.248  51.385  1
34639  94.287  -79.282  51.347  1
34640  94.296  -79.325  51.309  1
34641  94.305  -79.369  51.272  1
34642  94.314  -79.412  51.234  1
34643  94.322  -79.455  51.196  1
34644  94.331  -79.499  51.157  1
34645  94.342  -79.525  51.118  1
34646  94.356  -79.538  51.077  1
34647  94.369  -79.551  51.037  1
34648  94.382  -79.563  50.998  1
34649  94.395  -79.576  50.959  1
34650  94.408  -79.589  50.919  1
34651  94.421  -79.602  50.880  1
34652  94.434  -79.616  50.840  1
35195  92.744  -80.089  53.372  1
35196  92.760  -80.081  53.347  1
35197  92.776  -80.073  53.321  1
35198  92.792  -80.065  53.296  1
35199  92.808  -80.057  53.271  1
35200  92.825  -80.049  53.245  1
35201  92.840  -80.041  53.221  1
35202  92.856  -80.033  53.196  1
35203  92.872  -80.025  53.171  1
35204  92.888  -80.017  53.147  1
35205  92.905  -80.008  53.123  1
35206  92.921  -80.001  53.099  1
35207  92.936  -79.993  53.076  1
35208  92.952  -79.985  53.054  1
35209  92.969  -79.977  53.033  1
35210  92.985  -79.968  53.011  1
35211  93.001  -79.961  52.992  1
35212  93.017  -79.952  52.973  1
35213  93.032  -79.945  52.953  1
35214  93.049  -79.936  52.935  1
35215  93.065  -79.928  52.918  1
35216  93.082  -79.916  52.901  1
35217  93.100  -79.902  52.888  1
35218  93.111  -79.896  52.875  1
35219  93.117  -79.892  52.864  1
35220  93.124  -79.888  52.858  1
35221  93.131  -79.884  52.854  1
35222  93.146  -79.877  52.851  1
35223  93.166  -79.868  52.847  1
35224  93.189  -79.858  52.844  1
35225  93.213  -79.849  52.841  1
35226  93.236  -79.839  52.838  1
35227  93.259  -79.830  52.836  1
35228  93.282  -79.820  52.833  1
35229  93.306  -79.810  52.830  1
35230  93.329  -79.801  52.828  1
35231  93.352  -79.791  52.827  1
35232  93.375  -79.781  52.826  1
35233  93.399  -79.772  52.826  1
35234  93.434  -79.759  52.826  1
35235  93.470  -79.746  52.825  1
35236  93.485  -79.730  52.823  1
35237  93.500  -79.714  52.818  1
35238  93.515  -79.698  52.813  1
35239  93.530  -79.682  52.807  1
35240  93.545  -79.665  52.802  1
35241  93.559  -79.649  52.796  1
35242  93.574  -79.633  52.790  1
35243  93.589  -79.617  52.782  1
35244  93.604  -79.601  52.773  1
35245  93.619  -79.585  52.765  1
35246  93.634  -79.569  52.758  1
35247  93.645  -79.557  52.750  1
35248  93.655  -79.548  52.742  1
35249  93.665  -79.538  52.734  1
35250  93.675  -79.527  52.725  1
35251  93.685  -79.517  52.718  1
35252  93.695  -79.507  52.710  1
35253  93.704  -79.498  52.701  1
35254  93.719  -79.491  52.692  1
35255  93.734  -79.484  52.684  1
35256  93.750  -79.478  52.676  1
35257  93.765  -79.472  52.670  1
35258  93.780  -79.465  52.665  1
35259  93.795  -79.459  52.662  1
35260  93.810  -79.452  52.660  1
35261  93.825  -79.446  52.657  1
35262  93.840  -79.439  52.653  1
35263  93.855  -79.433  52.649  1
35264  93.870  -79.426  52.646  1
35265  93.886  -79.420  52.642  1
35266  93.901  -79.413  52.636  1
35267  93.916  -79.407  52.630  1
35268  93.931  -79.400  52.625  1
35269  93.946  -79.394  52.619  1
35270  93.958  -79.392  52.612  1
35271  93.965  -79.394  52.603  1
35272  93.971  -79.397  52.593  1
35273  93.978  -79.399  52.584  1
35274  93.984  -79.402  52.572  1
35275  93.991  -79.404  52.561  1
35276  93.997  -79.407  52.549  1
35277  94.004  -79.410  52.537  1
35278  94.010  -79.412  52.525  1
35279  94.013  -79.416  52.513  1
35280  94.014  -79.422  52.500  1
35281  94.015  -79.428  52.488  1
35282  94.016  -79.433  52.476  1
35283  94.017  -79.438  52.463  1
35284  94.018  -79.444  52.449  1
35285  94.019  -79.450  52.436  1
35286  94.020  -79.455  52.423  1
35287  94.022  -79.460  52.411  1
35288  94.023  -79.466  52.397  1
35289  94.024  -79.472  52.383  1
35290  94.025  -79.477  52.368  1
35291  94.026  -79.483  52.354  1
35292  94.027  -79.488  52.341  1
35293  94.028  -79.494  52.331  1
35294  94.029  -79.500  52.316  1
35295  94.030  -79.505  52.298  1
35296  94.037  -79.508  52.279  1
35297  94.046  -79.510  52.262  1
35298  94.055  -79.512  52.246  1
35299  94.064  -79.513  52.230  1
35300  94.073  -79.516  52.218  1
35301  94.083  -79.517  52.205  1
35302  94.092  -79.519  52.190  1
35303  94.128  -79.478  52.173  1
35304  94.139  -79.432  52.156  1
35305  94.141  -79.453  52.137  1
35306  94.145  -79.463  52.119  1
35307  94.154  -79.453  52.104  1
35308  94.163  -79.443  52.087  1
35309  94.171  -79.429  52.070  1
35310  94.179  -79.403  52.052  1
35311  94.187  -79.378  52.033  1
35312  94.195  -79.352  52.013  1
35313  94.203  -79.327  51.993  1
35314  94.211  -79.302  51.976  1
35315  94.219  -79.276  51.962  1
35316  94.227  -79.257  51.947  1
35317  94.234  -79.267  51.929  1
35318  94.239  -79.266  51.910  1
35319  94.245  -79.266  51.892  1
35320  94.250  -79.266  51.874  1
35321  94.255  -79.265  51.858  1
35322  94.262  -79.263  51.843  1
35323  94.270  -79.261  51.826  1
35324  94.278  -79.259  51.807  1
35325  94.286  -79.256  51.790  1
35326  94.295  -79.254  51.773  1
35327  94.297  -79.258  51.755  1
35328  94.294  -79.269  51.734  1
35329  94.294  -79.254  51.712  1
35330  94.281  -79.259  51.687  1
35331  94.268  -79.266  51.660  1
35332  94.255  -79.272  51.632  1
35333  94.242  -79.278  51.603  1
35334  94.228  -79.284  51.573  1
35335  94.227  -79.283  51.542  1
35336  94.238  -79.276  51.510  1
35337  94.247  -79.269  51.478  1
35338  94.257  -79.263  51.441  1
35339  94.267  -79.256  51.403  1
35340  94.276  -79.260  51.363  1
35341  94.285  -79.303  51.326  1
35342  94.294  -79.347  51.287  1
35343  94.302  -79.390  51.247  1
35344  94.312  -79.433  51.208  1
35345  94.321  -79.473  51.168  1
35346  94.334  -79.485  51.127  1
35347  94.347  -79.498  51.086  1
35348  94.360  -79.511  51.047  1
35349  94.373  -79.524  51.007  1
35350  94.387  -79.537  50.967  1
35351  94.400  -79.550  50.928  1
35352  94.413  -79.563  50.887  1
35353  94.426  -79.576  50.847  1
35899  92.788  -80.048  53.318  1
35900  92.804  -80.040  53.292  1
35901  92.820  -80.032  53.267  1
35902  92.836  -80.024  53.242  1
35903  92.852  -80.016  53.216  1
35904  92.868  -80.008  53.192  1
35905  92.884  -80.000  53.166  1
35906  92.901  -79.992  53.141  1
35907  92.916  -79.983  53.117  1
35908  92.932  -79.976  53.094  1
35909  92.948  -79.968  53.071  1
35910  92.965  -79.960  53.048  1
35911  92.981  -79.952  53.027  1
35912  92.997  -79.943  53.007  1
35913  93.012  -79.936  52.986  1
35914  93.028  -79.927  52.965  1
35915  93.045  -79.920  52.947  1
35916  93.061  -79.911  52.929  1
35917  93.077  -79.903  52.911  1
35918  93.095  -79.889  52.896  1
35919  93.113  -79.876  52.883  1
35920  93.124  -79.868  52.871  1
35921  93.131  -79.864  52.863  1
35922  93.138  -79.861  52.859  1
35923  93.144  -79.857  52.856  1
35924  93.160  -79.851  52.851  1
35925  93.184  -79.843  52.847  1
35926  93.207  -79.835  52.843  1
35927  93.230  -79.825  52.839  1
35928  93.253  -79.815  52.837  1
35929  93.276  -79.805  52.834  1
35930  93.300  -79.796  52.831  1
35931  93.323  -79.786  52.830  1
35932  93.346  -79.776  52.829  1
35933  93.369  -79.767  52.828  1
35934  93.393  -79.758  52.828  1
35935  93.421  -79.746  52.828  1
35936  93.457  -79.734  52.826  1
35937  93.473  -79.717  52.823  1
35938  93.488  -79.701  52.819  1
35939  93.502  -79.686  52.813  1
35940  93.517  -79.670  52.806  1
35941  93.533  -79.653  52.799  1
35942  93.547  -79.637  52.792  1
35943  93.562  -79.621  52.785  1
35944  93.577  -79.605  52.777  1
35945  93.592  -79.588  52.767  1
35946  93.607  -79.573  52.758  1
35947  93.622  -79.557  52.751  1
35948  93.637  -79.541  52.743  1
35949  93.651  -79.524  52.735  1
35950  93.664  -79.511  52.727  1
35951  93.674  -79.501  52.717  1
35952  93.684  -79.491  52.708  1
35953  93.694  -79.482  52.699  1
35954  93.704  -79.472  52.690  1
35955  93.717  -79.464  52.682  1
35956  93.732  -79.457  52.674  1
35957  93.748  -79.451  52.668  1
35958  93.763  -79.444  52.662  1
35959  93.778  -79.438  52.658  1
35960  93.793  -79.432  52.656  1
35961  93.808  -79.426  52.655  1
35962  93.823  -79.419  52.653  1
35963  93.838  -79.413  52.650  1
35964  93.854  -79.407  52.647  1
35965  93.869  -79.400  52.645  1
35966  93.884  -79.394  52.642  1
35967  93.899  -79.387  52.637  1
35968  93.914  -79.381  52.631  1
35969  93.929  -79.374  52.627  1
35970  93.944  -79.368  52.623  1
35971  93.960  -79.363  52.616  1
35972  93.971  -79.360  52.607  1
35973  93.969  -79.363  52.597  1
35974  93.970  -79.369  52.586  1
35975  93.971  -79.374  52.574  1
35976  93.972  -79.379  52.561  1
35977  93.973  -79.385  52.548  1
35978  93.975  -79.391  52.536  1
35979  93.976  -79.396  52.523  1
35980  93.977  -79.402  52.510  1
35981  93.978  -79.407  52.498  1
35982  93.979  -79.413  52.486  1
35983  93.980  -79.418  52.473  1
35984  93.981  -79.424  52.460  1
35985  93.982  -79.429  52.447  1
35986  93.983  -79.435  52.434  1
35987  93.984  -79.441  52.421  1
35988  93.985  -79.446  52.408  1
35989  93.986  -79.451  52.394  1
35990  93.987  -79.457  52.379  1
35991  93.988  -79.463  52.366  1
35992  93.989  -79.468  52.353  1
35993  93.991  -79.474  52.342  1
35994  93.999  -79.476  52.330  1
35995  94.008  -79.478  52.315  1
35996  94.017  -79.479  52.297  1
35997  94.027  -79.482  52.278  1
35998  94.036  -79.483  52.260  1
35999  94.045  -79.485  52.243  1
36000  94.054  -79.487  52.228  1
36001  94.063  -79.488  52.216  1
36002  94.072  -79.491  52.203  1
36003  94.121  -79.447  52.189  1
36004  94.099  -79.427  52.171  1
36005  94.136  -79.379  52.153  1
36006  94.138  -79.400  52.134  1
36007  94.141  -79.419  52.114  1
36008  94.149  -79.409  52.099  1
36009  94.158  -79.399  52.083  1
36010  94.167  -79.390  52.067  1
36011  94.175  -79.380  52.048  1
36012  94.183  -79.355  52.030  1
36013  94.191  -79.329  52.010  1
36014  94.199  -79.304  51.990  1
36015  94.207  -79.279  51.972  1
36016  94.215  -79.253  51.957  1
36017  94.223  -79.253  51.943  1
36018  94.230  -79.263  51.925  1
36019  94.236  -79.266  51.909  1
36020  94.241  -79.266  51.893  1
36021  94.246  -79.265  51.877  1
36022  94.251  -79.265  51.863  1
36023  94.257  -79.264  51.848  1
36024  94.262  -79.264  51.832  1
36025  94.267  -79.263  51.812  1
36026  94.272  -79.263  51.795  1
36027  94.279  -79.261  51.779  1
36028  94.287  -79.259  51.761  1
36029  94.291  -79.261  51.742  1
36030  94.287  -79.259  51.720  1
36031  94.274  -79.266  51.696  1
36032  94.261  -79.272  51.670  1
36033  94.247  -79.278  51.643  1
36034  94.234  -79.284  51.615  1
36035  94.220  -79.290  51.585  1
36036  94.216  -79.291  51.555  1
36037  94.226  -79.284  51.523  1
36038  94.236  -79.278  51.490  1
36039  94.246  -79.271  51.454  1
36040  94.255  -79.264  51.417  1
36041  94.265  -79.257  51.379  1
36042  94.274  -79.281  51.343  1
36043  94.283  -79.324  51.304  1
36044  94.292  -79.368  51.263  1
36045  94.300  -79.411  51.222  1
36046  94.313  -79.433  51.181  1
36047  94.326  -79.446  51.139  1
36048  94.339  -79.459  51.098  1
36049  94.352  -79.472  51.057  1
36050  94.365  -79.485  51.016  1
36051  94.378  -79.498  50.976  1
36052  94.392  -79.511  50.936  1
36053  94.405  -79.524  50.896  1
36054  94.418  -79.537  50.855  1
36055  94.431  -79.550  50.815  1
36602  92.816  -80.015  53.289  1
36603  92.832  -80.007  53.263  1
36604  92.848  -79.999  53.237  1
36605  92.864  -79.991  53.212  1
36606  92.880  -79.983  53.186  1
36607  92.896  -79.975  53.160  1
36608  92.912  -79.967  53.136  1
36609  92.928  -79.958  53.112  1
36610  92.944  -79.951  53.089  1
36611  92.960  -79.943  53.065  1
36612  92.977  -79.935  53.043  1
36613  92.992  -79.927  53.022  1
36614  93.008  -79.918  53.000  1
36615  93.024  -79.911  52.979  1
36616  93.041  -79.902  52.959  1
36617  93.057  -79.895  52.940  1
36618  93.073  -79.886  52.922  1
36619  93.089  -79.877  52.906  1
36620  93.108  -79.863  52.892  1
36621  93.126  -79.849  52.879  1
36622  93.138  -79.841  52.870  1
36623  93.144  -79.837  52.863  1
36624  93.151  -79.833  52.857  1
36625  93.158  -79.830  52.852  1
36626  93.179  -79.823  52.848  1
36627  93.202  -79.814  52.844  1
36628  93.224  -79.807  52.840  1
36629  93.248  -79.798  52.837  1
36630  93.271  -79.791  52.835  1
36631  93.294  -79.782  52.832  1
36632  93.317  -79.772  52.830  1
36633  93.340  -79.763  52.830  1
36634  93.363  -79.753  52.830  1
36635  93.387  -79.743  52.830  1
36636  93.410  -79.734  52.829  1
36637  93.444  -79.721  52.827  1
36638  93.461  -79.705  52.824  1
36639  93.476  -79.689  52.820  1
36640  93.490  -79.673  52.813  1
36641  93.505  -79.657  52.805  1
36642  93.520  -79.641  52.797  1
36643  93.535  -79.625  52.789  1
36644  93.550  -79.609  52.781  1
36645  93.565  -79.593  52.772  1
36646  93.580  -79.576  52.762  1
36647  93.594  -79.560  52.753  1
36648  93.610  -79.545  52.744  1
36649  93.625  -79.529  52.737  1
36650  93.639  -79.512  52.729  1
36651  93.654  -79.496  52.721  1
36652  93.669  -79.480  52.711  1
36653  93.683  -79.466  52.702  1
36654  93.693  -79.456  52.693  1
36655  93.703  -79.445  52.684  1
36656  93.715  -79.438  52.676  1
36657  93.730  -79.431  52.669  1
36658  93.746  -79.425  52.662  1
36659  93.761  -79.418  52.656  1
36660  93.776  -79.412  52.652  1
36661  93.791  -79.405  52.650  1
36662  93.806  -79.399  52.651  1
36663  93.822  -79.392  52.650  1
36664  93.837  -79.386  52.650  1
36665  93.852  -79.380  52.647  1
36666  93.866  -79.378  52.645  1
36667  93.882  -79.375  52.643  1
36668  93.896  -79.372  52.640  1
36669  93.911  -79.369  52.636  1
36670  93.926  -79.366  52.633  1
36671  93.941  -79.363  52.630  1
36672  93.946  -79.360  52.623  1
36673  93.951  -79.357  52.614  1
36674  93.946  -79.356  52.603  1
36675  93.938  -79.357  52.591  1
36676  93.935  -79.359  52.579  1
36677  93.936  -79.365  52.565  1
36678  93.937  -79.370  52.550  1
36679  93.938  -79.375  52.536  1
36680  93.939  -79.382  52.523  1
36681  93.940  -79.387  52.509  1
36682  93.941  -79.392  52.498  1
36683  93.942  -79.398  52.485  1
36684  93.943  -79.404  52.472  1
36685  93.944  -79.409  52.459  1
36686  93.945  -79.415  52.447  1
36687  93.946  -79.420  52.433  1
36688  93.947  -79.426  52.420  1
36689  93.949  -79.432  52.407  1
36690  93.950  -79.437  52.393  1
36691  93.952  -79.442  52.379  1
36692  93.961  -79.444  52.366  1
36693  93.970  -79.446  52.354  1
36694  93.979  -79.447  52.342  1
36695  93.988  -79.449  52.329  1
36696  93.998  -79.451  52.313  1
36697  94.007  -79.453  52.296  1
36698  94.016  -79.455  52.277  1
36699  94.025  -79.457  52.258  1
36700  94.035  -79.458  52.241  1
36701  94.044  -79.460  52.225  1
36702  94.053  -79.462  52.212  1
36703  94.096  -79.425  52.199  1
36704  94.107  -79.390  52.184  1
36705  94.109  -79.345  52.167  1
36706  94.134  -79.326  52.148  1
36707  94.136  -79.347  52.129  1
36708  94.138  -79.369  52.110  1
36709  94.145  -79.366  52.093  1
36710  94.153  -79.356  52.077  1
36711  94.162  -79.346  52.061  1
36712  94.171  -79.336  52.042  1
36713  94.179  -79.326  52.024  1
36714  94.187  -79.306  52.006  1
36715  94.195  -79.281  51.987  1
36716  94.203  -79.256  51.968  1
36717  94.211  -79.238  51.951  1
36718  94.218  -79.249  51.937  1
36719  94.225  -79.259  51.921  1
36720  94.232  -79.266  51.906  1
36721  94.237  -79.265  51.893  1
36722  94.243  -79.265  51.880  1
36723  94.248  -79.264  51.867  1
36724  94.253  -79.264  51.854  1
36725  94.258  -79.263  51.838  1
36726  94.263  -79.263  51.818  1
36727  94.269  -79.263  51.801  1
36728  94.274  -79.262  51.786  1
36729  94.279  -79.262  51.767  1
36730  94.284  -79.261  51.749  1
36731  94.285  -79.261  51.728  1
36732  94.267  -79.271  51.705  1
36733  94.253  -79.277  51.679  1
36734  94.240  -79.283  51.653  1
36735  94.226  -79.289  51.626  1
36736  94.213  -79.295  51.597  1
36737  94.205  -79.298  51.566  1
36738  94.214  -79.292  51.534  1
36739  94.224  -79.285  51.501  1
36740  94.234  -79.278  51.464  1
36741  94.244  -79.272  51.429  1
36742  94.254  -79.266  51.394  1
36743  94.263  -79.259  51.359  1
36744  94.272  -79.302  51.320  1
36745  94.281  -79.345  51.278  1
36746  94.291  -79.381  51.235  1
36747  94.304  -79.394  51.193  1
36748  94.317  -79.407  51.151  1
36749  94.330  -79.419  51.109  1
36750  94.344  -79.432  51.068  1
36751  94.357  -79.446  51.026  1
36752  94.370  -79.459  50.985  1
36753  94.383  -79.472  50.945  1
36754  94.396  -79.485  50.904  1
36755  94.409  -79.498  50.864  1
36756  94.422  -79.510  50.824  1
37308  92.892  -79.958  53.180  1
37309  92.908  -79.950  53.156  1
37310  92.924  -79.942  53.131  1
37311  92.940  -79.933  53.106  1
37312  92.956  -79.926  53.083  1
37313  92.972  -79.918  53.060  1
37314  92.988  -79.910  53.037  1
37315  93.004  -79.902  53.015  1
37316  93.020  -79.893  52.993  1
37317  93.037  -79.886  52.973  1
37318  93.053  -79.877  52.953  1
37319  93.068  -79.870  52.935  1
37320  93.084  -79.861  52.918  1
37321  93.101  -79.851  52.902  1
37322  93.120  -79.837  52.889  1
37323  93.138  -79.823  52.877  1
37324  93.151  -79.814  52.868  1
37325  93.158  -79.810  52.860  1
37326  93.165  -79.806  52.854  1
37327  93.174  -79.802  52.850  1
37328  93.197  -79.794  52.847  1
37329  93.220  -79.786  52.843  1
37330  93.242  -79.778  52.839  1
37331  93.266  -79.770  52.836  1
37332  93.289  -79.762  52.834  1
37333  93.311  -79.755  52.834  1
37334  93.335  -79.746  52.834  1
37335  93.358  -79.739  52.834  1
37336  93.381  -79.730  52.834  1
37337  93.404  -79.720  52.832  1
37338  93.431  -79.709  52.830  1
37339  93.448  -79.693  52.826  1
37340  93.463  -79.677  52.821  1
37341  93.478  -79.661  52.814  1
37342  93.493  -79.645  52.806  1
37343  93.508  -79.629  52.796  1
37344  93.523  -79.613  52.787  1
37345  93.538  -79.597  52.778  1
37346  93.553  -79.581  52.768  1
37347  93.568  -79.564  52.758  1
37348  93.582  -79.548  52.748  1
37349  93.597  -79.532  52.740  1
37350  93.612  -79.516  52.732  1
37351  93.627  -79.500  52.725  1
37352  93.642  -79.484  52.717  1
37353  93.657  -79.468  52.708  1
37354  93.672  -79.452  52.699  1
37355  93.687  -79.435  52.690  1
37356  93.702  -79.419  52.681  1
37357  93.713  -79.411  52.673  1
37358  93.728  -79.404  52.665  1
37359  93.744  -79.398  52.658  1
37360  93.759  -79.395  52.652  1
37361  93.773  -79.393  52.649  1
37362  93.788  -79.390  52.647  1
37363  93.803  -79.387  52.648  1
37364  93.818  -79.385  52.649  1
37365  93.833  -79.382  52.649  1
37366  93.848  -79.379  52.647  1
37367  93.862  -79.375  52.645  1
37368  93.877  -79.373  52.643  1
37369  93.892  -79.370  52.641  1
37370  93.907  -79.367  52.638  1
37371  93.918  -79.364  52.636  1
37372  93.922  -79.360  52.634  1
37373  93.926  -79.357  52.628  1
37374  93.931  -79.353  52.619  1
37375  93.929  -79.352  52.609  1
37376  93.921  -79.352  52.597  1
37377  93.913  -79.353  52.585  1
37378  93.905  -79.353  52.571  1
37379  93.901  -79.356  52.555  1
37380  93.902  -79.361  52.539  1
37381  93.903  -79.366  52.525  1
37382  93.904  -79.372  52.512  1
37383  93.905  -79.378  52.499  1
37384  93.906  -79.383  52.487  1
37385  93.907  -79.389  52.473  1
37386  93.908  -79.394  52.460  1
37387  93.909  -79.400  52.447  1
37388  93.910  -79.406  52.434  1
37389  93.914  -79.410  52.420  1
37390  93.923  -79.412  52.408  1
37391  93.932  -79.413  52.394  1
37392  93.941  -79.416  52.381  1
37393  93.951  -79.417  52.368  1
37394  93.960  -79.419  52.356  1
37395  93.969  -79.421  52.342  1
37396  93.978  -79.422  52.327  1
37397  93.987  -79.425  52.311  1
37398  93.996  -79.426  52.294  1
37399  94.006  -79.428  52.275  1
37400  94.015  -79.430  52.256  1
37401  94.024  -79.432  52.238  1
37402  94.033  -79.434  52.221  1
37403  94.071  -79.402  52.207  1
37404  94.115  -79.353  52.193  1
37405  94.084  -79.346  52.178  1
37406  94.085  -79.346  52.161  1
37407  94.116  -79.328  52.142  1
37408  94.133  -79.295  52.124  1
37409  94.135  -79.316  52.106  1
37410  94.140  -79.322  52.088  1
37411  94.149  -79.313  52.072  1
37412  94.157  -79.303  52.056  1
37413  94.166  -79.293  52.037  1
37414  94.175  -79.283  52.019  1
37415  94.183  -79.273  52.002  1
37416  94.191  -79.259  51.984  1
37417  94.200  -79.234  51.964  1
37418  94.207  -79.234  51.947  1
37419  94.214  -79.244  51.932  1
37420  94.221  -79.255  51.917  1
37421  94.228  -79.265  51.904  1
37422  94.234  -79.265  51.892  1
37423  94.239  -79.264  51.881  1
37424  94.244  -79.264  51.868  1
37425  94.249  -79.263  51.855  1
37426  94.254  -79.263  51.841  1
37427  94.260  -79.263  51.822  1
37428  94.265  -79.262  51.805  1
37429  94.270  -79.262  51.790  1
37430  94.275  -79.261  51.772  1
37431  94.281  -79.259  51.754  1
37432  94.289  -79.254  51.733  1
37433  94.297  -79.250  51.711  1
37434  94.278  -79.259  51.686  1
37435  94.260  -79.269  51.660  1
37436  94.242  -79.278  51.633  1
37437  94.223  -79.288  51.605  1
37438  94.204  -79.298  51.575  1
37439  94.206  -79.297  51.543  1
37440  94.213  -79.293  51.510  1
37441  94.222  -79.287  51.474  1
37442  94.232  -79.280  51.439  1
37443  94.242  -79.273  51.407  1
37444  94.252  -79.267  51.372  1
37445  94.261  -79.280  51.333  1
37446  94.270  -79.323  51.291  1
37447  94.282  -79.341  51.247  1
37448  94.295  -79.354  51.204  1
37449  94.309  -79.367  51.162  1
37450  94.322  -79.380  51.120  1
37451  94.335  -79.394  51.078  1
37452  94.348  -79.407  51.036  1
37453  94.361  -79.419  50.995  1
37454  94.374  -79.432  50.954  1
37455  94.388  -79.445  50.913  1
37456  94.401  -79.458  50.873  1
37457  94.414  -79.471  50.833  1
38013  92.952  -79.908  53.102  1
38014  92.968  -79.901  53.078  1
38015  92.984  -79.892  53.054  1
38016  93.000  -79.885  53.031  1
38017  93.016  -79.877  53.009  1
38018  93.032  -79.868  52.989  1
38019  93.048  -79.861  52.969  1
38020  93.064  -79.852  52.948  1
38021  93.080  -79.845  52.930  1
38022  93.096  -79.836  52.914  1
38023  93.114  -79.824  52.899  1
38024  93.132  -79.811  52.886  1
38025  93.150  -79.797  52.875  1
38026  93.165  -79.786  52.865  1
38027  93.171  -79.783  52.858  1
38028  93.179  -79.779  52.853  1
38029  93.192  -79.773  52.850  1
38030  93.215  -79.766  52.847  1
38031  93.238  -79.758  52.843  1
38032  93.261  -79.750  52.840  1
38033  93.284  -79.742  52.838  1
38034  93.307  -79.734  52.838  1
38035  93.330  -79.726  52.839  1
38036  93.353  -79.718  52.839  1
38037  93.376  -79.710  52.838  1
38038  93.399  -79.702  52.836  1
38039  93.422  -79.694  52.833  1
38040  93.434  -79.685  52.829  1
38041  93.448  -79.669  52.823  1
38042  93.463  -79.654  52.816  1
38043  93.477  -79.638  52.808  1
38044  93.492  -79.622  52.797  1
38045  93.506  -79.606  52.787  1
38046  93.521  -79.590  52.777  1
38047  93.536  -79.575  52.767  1
38048  93.550  -79.559  52.757  1
38049  93.565  -79.543  52.747  1
38050  93.579  -79.527  52.740  1
38051  93.594  -79.511  52.734  1
38052  93.609  -79.496  52.727  1
38053  93.623  -79.480  52.720  1
38054  93.638  -79.464  52.710  1
38055  93.652  -79.448  52.701  1
38056  93.667  -79.432  52.692  1
38057  93.682  -79.417  52.683  1
38058  93.707  -79.404  52.673  1
38059  93.725  -79.399  52.664  1
38060  93.740  -79.397  52.656  1
38061  93.755  -79.394  52.650  1
38062  93.769  -79.391  52.646  1
38063  93.784  -79.388  52.644  1
38064  93.799  -79.385  52.646  1
38065  93.814  -79.382  52.648  1
38066  93.829  -79.380  52.648  1
38067  93.844  -79.377  52.647  1
38068  93.858  -79.374  52.645  1
38069  93.873  -79.372  52.642  1
38070  93.888  -79.369  52.640  1
38071  93.893  -79.365  52.639  1
38072  93.898  -79.361  52.638  1
38073  93.902  -79.358  52.636  1
38074  93.907  -79.354  52.630  1
38075  93.911  -79.350  52.622  1
38076  93.912  -79.348  52.613  1
38077  93.904  -79.348  52.601  1
38078  93.896  -79.349  52.588  1
38079  93.888  -79.350  52.574  1
38080  93.880  -79.350  52.558  1
38081  93.872  -79.350  52.543  1
38082  93.866  -79.352  52.529  1
38083  93.867  -79.357  52.516  1
38084  93.868  -79.363  52.504  1
38085  93.869  -79.369  52.491  1
38086  93.870  -79.374  52.478  1
38087  93.875  -79.378  52.466  1
38088  93.885  -79.379  52.453  1
38089  93.894  -79.382  52.439  1
38090  93.903  -79.383  52.425  1
38091  93.912  -79.385  52.412  1
38092  93.922  -79.387  52.398  1
38093  93.931  -79.388  52.383  1
38094  93.940  -79.391  52.369  1
38095  93.949  -79.392  52.355  1
38096  93.959  -79.394  52.340  1
38097  93.968  -79.396  52.323  1
38098  93.977  -79.397  52.306  1
38099  93.986  -79.400  52.288  1
38100  93.995  -79.401  52.270  1
38101  94.004  -79.404  52.252  1
38102  94.014  -79.405  52.234  1
38103  94.047  -79.379  52.217  1
38104  94.101  -79.328  52.200  1
38105  94.109  -79.325  52.186  1
38106  94.094  -79.332  52.170  1
38107  94.080  -79.338  52.152  1
38108  94.094  -79.334  52.135  1
38109  94.117  -79.293  52.117  1
38110  94.133  -79.263  52.100  1
38111  94.136  -79.278  52.084  1
38112  94.144  -79.269  52.068  1
38113  94.153  -79.259  52.051  1
38114  94.161  -79.249  52.032  1
38115  94.170  -79.239  52.014  1
38116  94.179  -79.229  51.997  1
38117  94.187  -79.219  51.980  1
38118  94.195  -79.219  51.960  1
38119  94.202  -79.230  51.943  1
38120  94.209  -79.240  51.928  1
38121  94.217  -79.250  51.914  1
38122  94.224  -79.260  51.902  1
38123  94.229  -79.264  51.891  1
38124  94.235  -79.264  51.881  1
38125  94.240  -79.263  51.868  1
38126  94.246  -79.263  51.855  1
38127  94.251  -79.263  51.842  1
38128  94.256  -79.262  51.824  1
38129  94.261  -79.262  51.808  1
38130  94.266  -79.261  51.792  1
38131  94.272  -79.260  51.774  1
38132  94.280  -79.255  51.755  1
38133  94.287  -79.250  51.735  1
38134  94.295  -79.245  51.713  1
38135  94.303  -79.241  51.689  1
38136  94.290  -79.247  51.663  1
38137  94.272  -79.257  51.636  1
38138  94.253  -79.267  51.609  1
38139  94.235  -79.276  51.579  1
38140  94.226  -79.281  51.548  1
38141  94.229  -79.280  51.516  1
38142  94.231  -79.278  51.482  1
38143  94.234  -79.278  51.448  1
38144  94.237  -79.276  51.417  1
38145  94.241  -79.275  51.382  1
38146  94.250  -79.268  51.343  1
38147  94.261  -79.289  51.302  1
38148  94.274  -79.302  51.259  1
38149  94.287  -79.315  51.215  1
38150  94.300  -79.328  51.172  1
38151  94.314  -79.341  51.131  1
38152  94.327  -79.354  51.089  1
38153  94.340  -79.367  51.047  1
38154  94.353  -79.380  51.005  1
38155  94.366  -79.393  50.964  1
38156  94.380  -79.406  50.922  1
38157  94.393  -79.419  50.881  1
38158  94.406  -79.432  50.841  1
38716  92.980  -79.876  53.072  1
38717  92.996  -79.867  53.049  1
38718  93.012  -79.860  53.027  1
38719  93.028  -79.852  53.006  1
38720  93.044  -79.843  52.985  1
38721  93.060  -79.836  52.965  1
38722  93.076  -79.827  52.946  1
38723  93.092  -79.820  52.929  1
38724  93.109  -79.811  52.913  1
38725  93.126  -79.798  52.899  1
38726  93.144  -79.785  52.887  1
38727  93.162  -79.770  52.875  1
38728  93.179  -79.759  52.866  1
38729  93.185  -79.755  52.859  1
38730  93.192  -79.751  52.853  1
38731  93.210  -79.745  52.851  1
38732  93.233  -79.737  52.848  1
38733  93.256  -79.729  52.846  1
38734  93.279  -79.721  52.844  1
38735  93.302  -79.714  52.844  1
38736  93.325  -79.705  52.844  1
38737  93.348  -79.698  52.844  1
38738  93.371  -79.689  52.842  1
38739  93.394  -79.682  52.840  1
38740  93.416  -79.675  52.837  1
38741  93.436  -79.667  52.833  1
38742  93.444  -79.657  52.826  1
38743  93.452  -79.645  52.818  1
38744  93.461  -79.635  52.810  1
38745  93.469  -79.623  52.799  1
38746  93.482  -79.608  52.789  1
38747  93.497  -79.592  52.778  1
38748  93.512  -79.576  52.768  1
38749  93.526  -79.561  52.758  1
38750  93.541  -79.545  52.748  1
38751  93.556  -79.529  52.742  1
38752  93.570  -79.513  52.737  1
38753  93.585  -79.498  52.731  1
38754  93.600  -79.482  52.724  1
38755  93.614  -79.466  52.715  1
38756  93.629  -79.451  52.706  1
38757  93.643  -79.435  52.696  1
38758  93.665  -79.421  52.687  1
38759  93.693  -79.410  52.677  1
38760  93.721  -79.397  52.667  1
38761  93.736  -79.395  52.657  1
38762  93.751  -79.392  52.651  1
38763  93.766  -79.389  52.645  1
38764  93.780  -79.387  52.641  1
38765  93.795  -79.384  52.643  1
38766  93.810  -79.381  52.645  1
38767  93.825  -79.379  52.645  1
38768  93.840  -79.375  52.643  1
38769  93.855  -79.372  52.642  1
38770  93.864  -79.369  52.641  1
38771  93.868  -79.366  52.638  1
38772  93.873  -79.362  52.637  1
38773  93.877  -79.358  52.636  1
38774  93.882  -79.355  52.636  1
38775  93.887  -79.351  52.630  1
38776  93.891  -79.347  52.623  1
38777  93.894  -79.344  52.614  1
38778  93.886  -79.344  52.602  1
38779  93.879  -79.345  52.589  1
38780  93.871  -79.345  52.576  1
38781  93.864  -79.346  52.560  1
38782  93.857  -79.346  52.548  1
38783  93.849  -79.346  52.535  1
38784  93.842  -79.347  52.522  1
38785  93.840  -79.346  52.511  1
38786  93.848  -79.347  52.498  1
38787  93.856  -79.349  52.485  1
38788  93.865  -79.351  52.473  1
38789  93.874  -79.353  52.460  1
38790  93.884  -79.355  52.445  1
38791  93.893  -79.357  52.430  1
38792  93.902  -79.358  52.415  1
38793  93.911  -79.360  52.400  1
38794  93.921  -79.362  52.384  1
38795  93.930  -79.364  52.368  1
38796  93.939  -79.366  52.353  1
38797  93.948  -79.367  52.337  1
38798  93.958  -79.369  52.320  1
38799  93.967  -79.371  52.303  1
38800  93.976  -79.373  52.285  1
38801  93.985  -79.375  52.267  1
38802  93.994  -79.376  52.250  1
38803  94.023  -79.357  52.232  1
38804  94.053  -79.338  52.215  1
38805  94.082  -79.335  52.198  1
38806  94.087  -79.318  52.181  1
38807  94.087  -79.319  52.164  1
38808  94.090  -79.325  52.146  1
38809  94.076  -79.332  52.128  1
38810  94.096  -79.303  52.111  1
38811  94.117  -79.256  52.093  1
38812  94.132  -79.232  52.077  1
38813  94.140  -79.225  52.061  1
38814  94.148  -79.216  52.044  1
38815  94.157  -79.212  52.025  1
38816  94.165  -79.222  52.007  1
38817  94.174  -79.231  51.989  1
38818  94.180  -79.228  51.973  1
38819  94.184  -79.222  51.955  1
38820  94.198  -79.225  51.939  1
38821  94.205  -79.236  51.924  1
38822  94.212  -79.246  51.912  1
38823  94.219  -79.256  51.900  1
38824  94.226  -79.264  51.890  1
38825  94.231  -79.263  51.881  1
38826  94.237  -79.263  51.869  1
38827  94.242  -79.263  51.855  1
38828  94.247  -79.262  51.841  1
38829  94.252  -79.262  51.825  1
38830  94.258  -79.261  51.809  1
38831  94.263  -79.261  51.793  1
38832  94.270  -79.256  51.774  1
38833  94.278  -79.252  51.754  1
38834  94.286  -79.247  51.734  1
38835  94.293  -79.241  51.713  1
38836  94.301  -79.237  51.690  1
38837  94.310  -79.231  51.665  1
38838  94.302  -79.235  51.638  1
38839  94.283  -79.245  51.610  1
38840  94.265  -79.255  51.581  1
38841  94.247  -79.265  51.551  1
38842  94.249  -79.263  51.520  1
38843  94.252  -79.263  51.487  1
38844  94.255  -79.261  51.455  1
38845  94.257  -79.260  51.424  1
38846  94.260  -79.259  51.389  1
38847  94.258  -79.262  51.351  1
38848  94.260  -79.259  51.311  1
38849  94.269  -79.266  51.269  1
38850  94.279  -79.275  51.226  1
38851  94.292  -79.289  51.182  1
38852  94.305  -79.302  51.141  1
38853  94.318  -79.315  51.099  1
38854  94.331  -79.328  51.057  1
38855  94.345  -79.341  51.015  1
38856  94.358  -79.353  50.973  1
38857  94.371  -79.366  50.932  1
38858  94.384  -79.380  50.890  1
38859  94.397  -79.393  50.849  1
39418  92.992  -79.851  53.069  1
39419  93.008  -79.842  53.046  1
39420  93.024  -79.835  53.024  1
39421  93.040  -79.827  53.003  1
39422  93.056  -79.818  52.982  1
39423  93.072  -79.811  52.963  1
39424  93.088  -79.802  52.945  1
39425  93.105  -79.795  52.929  1
39426  93.121  -79.786  52.914  1
39427  93.139  -79.772  52.900  1
39428  93.157  -79.758  52.888  1
39429  93.175  -79.745  52.877  1
39430  93.192  -79.732  52.868  1
39431  93.199  -79.728  52.862  1
39432  93.206  -79.724  52.858  1
39433  93.228  -79.717  52.856  1
39434  93.251  -79.708  52.854  1
39435  93.274  -79.701  52.852  1
39436  93.297  -79.692  52.850  1
39437  93.320  -79.685  52.848  1
39438  93.343  -79.676  52.847  1
39439  93.366  -79.669  52.845  1
39440  93.389  -79.661  52.842  1
39441  93.411  -79.655  52.838  1
39442  93.433  -79.648  52.832  1
39443  93.447  -79.640  52.826  1
39444  93.455  -79.629  52.819  1
39445  93.463  -79.618  52.811  1
39446  93.471  -79.607  52.801  1
39447  93.479  -79.596  52.791  1
39448  93.487  -79.585  52.780  1
39449  93.495  -79.574  52.771  1
39450  93.503  -79.563  52.760  1
39451  93.517  -79.548  52.750  1
39452  93.532  -79.532  52.745  1
39453  93.546  -79.516  52.741  1
39454  93.561  -79.500  52.736  1
39455  93.575  -79.485  52.729  1
39456  93.590  -79.469  52.720  1
39457  93.605  -79.453  52.711  1
39458  93.623  -79.438  52.701  1
39459  93.651  -79.426  52.691  1
39460  93.679  -79.414  52.681  1
39461  93.707  -79.403  52.671  1
39462  93.732  -79.393  52.660  1
39463  93.747  -79.391  52.652  1
39464  93.762  -79.388  52.646  1
39465  93.776  -79.385  52.640  1
39466  93.791  -79.382  52.641  1
39467  93.806  -79.379  52.642  1
39468  93.821  -79.376  52.642  1
39469  93.835  -79.374  52.640  1
39470  93.839  -79.370  52.639  1
39471  93.844  -79.366  52.638  1
39472  93.848  -79.363  52.637  1
39473  93.853  -79.359  52.636  1
39474  93.857  -79.356  52.635  1
39475  93.865  -79.350  52.634  1
39476  93.877  -79.343  52.629  1
39477  93.890  -79.335  52.622  1
39478  93.896  -79.332  52.613  1
39479  93.895  -79.333  52.601  1
39480  93.894  -79.334  52.590  1
39481  93.888  -79.335  52.577  1
39482  93.880  -79.335  52.563  1
39483  93.873  -79.335  52.552  1
39484  93.865  -79.335  52.541  1
39485  93.858  -79.335  52.531  1
39486  93.860  -79.337  52.519  1
39487  93.863  -79.339  52.507  1
39488  93.870  -79.336  52.494  1
39489  93.878  -79.332  52.481  1
39490  93.887  -79.330  52.467  1
39491  93.894  -79.332  52.452  1
39492  93.902  -79.333  52.435  1
39493  93.910  -79.335  52.418  1
39494  93.918  -79.337  52.401  1
39495  93.925  -79.338  52.383  1
39496  93.933  -79.340  52.366  1
39497  93.941  -79.341  52.350  1
39498  93.949  -79.343  52.334  1
39499  93.957  -79.344  52.318  1
39500  93.965  -79.346  52.301  1
39501  93.972  -79.347  52.283  1
39502  93.980  -79.349  52.264  1
39503  93.987  -79.355  52.248  1
39504  94.015  -79.351  52.230  1
39505  94.044  -79.347  52.213  1
39506  94.073  -79.344  52.196  1
39507  94.068  -79.321  52.177  1
39508  94.059  -79.306  52.159  1
39509  94.062  -79.313  52.139  1
39510  94.065  -79.319  52.122  1
39511  94.078  -79.320  52.104  1
39512  94.100  -79.275  52.086  1
39513  94.122  -79.229  52.070  1
39514  94.135  -79.218  52.054  1
39515  94.143  -79.228  52.037  1
39516  94.151  -79.237  52.018  1
39517  94.159  -79.246  52.000  1
39518  94.166  -79.237  51.982  1
39519  94.173  -79.229  51.967  1
39520  94.175  -79.226  51.950  1
39521  94.185  -79.227  51.935  1
39522  94.201  -79.231  51.921  1
39523  94.208  -79.242  51.910  1
39524  94.215  -79.252  51.900  1
39525  94.222  -79.263  51.890  1
39526  94.227  -79.263  51.880  1
39527  94.232  -79.263  51.868  1
39528  94.238  -79.262  51.855  1
39529  94.243  -79.262  51.842  1
39530  94.249  -79.261  51.826  1
39531  94.254  -79.261  51.809  1
39532  94.260  -79.258  51.792  1
39533  94.268  -79.253  51.773  1
39534  94.276  -79.248  51.752  1
39535  94.284  -79.243  51.731  1
39536  94.292  -79.238  51.711  1
39537  94.299  -79.233  51.688  1
39538  94.308  -79.228  51.663  1
39539  94.316  -79.223  51.637  1
39540  94.314  -79.224  51.609  1
39541  94.295  -79.234  51.580  1
39542  94.276  -79.243  51.549  1
39543  94.269  -79.247  51.520  1
39544  94.272  -79.246  51.490  1
39545  94.275  -79.244  51.459  1
39546  94.277  -79.244  51.428  1
39547  94.280  -79.242  51.394  1
39548  94.254  -79.263  51.357  1
39549  94.262  -79.253  51.318  1
39550  94.277  -79.247  51.278  1
39551  94.285  -79.253  51.236  1
39552  94.294  -79.261  51.193  1
39553  94.302  -79.269  51.150  1
39554  94.311  -79.276  51.108  1
39555  94.323  -79.288  51.066  1
39556  94.336  -79.301  51.024  1
39557  94.349  -79.314  50.983  1
39558  94.362  -79.328  50.941  1
39559  94.376  -79.341  50.899  1
39560  94.389  -79.353  50.857  1
39561  94.402  -79.366  50.817  1
40120  93.004  -79.826  53.066  1
40121  93.020  -79.817  53.043  1
40122  93.036  -79.810  53.022  1
40123  93.052  -79.802  53.000  1
40124  93.068  -79.793  52.980  1
40125  93.084  -79.786  52.962  1
40126  93.100  -79.777  52.946  1
40127  93.116  -79.770  52.929  1
40128  93.133  -79.760  52.915  1
40129  93.151  -79.746  52.902  1
40130  93.169  -79.732  52.890  1
40131  93.187  -79.718  52.880  1
40132  93.206  -79.704  52.872  1
40133  93.212  -79.701  52.868  1
40134  93.223  -79.696  52.864  1
40135  93.246  -79.688  52.862  1
40136  93.269  -79.680  52.859  1
40137  93.292  -79.672  52.857  1
40138  93.315  -79.664  52.854  1
40139  93.338  -79.656  52.851  1
40140  93.361  -79.648  52.848  1
40141  93.383  -79.642  52.844  1
40142  93.405  -79.636  52.839  1
40143  93.427  -79.629  52.834  1
40144  93.450  -79.623  52.827  1
40145  93.458  -79.612  52.820  1
40146  93.466  -79.601  52.812  1
40147  93.474  -79.590  52.803  1
40148  93.482  -79.579  52.794  1
40149  93.490  -79.568  52.783  1
40150  93.498  -79.557  52.774  1
40151  93.506  -79.546  52.765  1
40152  93.514  -79.535  52.757  1
40153  93.521  -79.524  52.751  1
40154  93.530  -79.513  52.746  1
40155  93.538  -79.502  52.741  1
40156  93.552  -79.486  52.735  1
40157  93.566  -79.471  52.726  1
40158  93.581  -79.455  52.716  1
40159  93.609  -79.443  52.705  1
40160  93.637  -79.432  52.695  1
40161  93.665  -79.419  52.685  1
40162  93.693  -79.408  52.674  1
40163  93.721  -79.396  52.663  1
40164  93.743  -79.389  52.654  1
40165  93.758  -79.386  52.647  1
40166  93.772  -79.383  52.642  1
40167  93.787  -79.381  52.639  1
40168  93.802  -79.378  52.639  1
40169  93.810  -79.375  52.639  1
40170  93.815  -79.371  52.637  1
40171  93.819  -79.367  52.637  1
40172  93.824  -79.363  52.636  1
40173  93.835  -79.357  52.636  1
40174  93.847  -79.349  52.634  1
40175  93.860  -79.342  52.633  1
40176  93.872  -79.335  52.633  1
40177  93.885  -79.327  52.628  1
40178  93.897  -79.319  52.621  1
40179  93.898  -79.319  52.612  1
40180  93.896  -79.320  52.601  1
40181  93.895  -79.322  52.590  1
40182  93.894  -79.322  52.579  1
40183  93.893  -79.323  52.567  1
40184  93.889  -79.324  52.556  1
40185  93.882  -79.325  52.546  1
40186  93.877  -79.325  52.536  1
40187  93.880  -79.327  52.524  1
40188  93.884  -79.328  52.511  1
40189  93.888  -79.330  52.497  1
40190  93.893  -79.329  52.483  1
40191  93.901  -79.325  52.468  1
40192  93.909  -79.322  52.452  1
40193  93.917  -79.319  52.434  1
40194  93.925  -79.315  52.416  1
40195  93.933  -79.314  52.399  1
40196  93.941  -79.316  52.381  1
40197  93.948  -79.317  52.365  1
40198  93.957  -79.319  52.349  1
40199  93.964  -79.321  52.332  1
40200  93.972  -79.322  52.316  1
40201  93.980  -79.324  52.299  1
40202  93.988  -79.325  52.281  1
40203  94.000  -79.329  52.262  1
40204  94.006  -79.342  52.246  1
40205  94.006  -79.360  52.229  1
40206  94.035  -79.357  52.211  1
40207  94.063  -79.353  52.194  1
40208  94.048  -79.325  52.175  1
40209  94.031  -79.294  52.155  1
40210  94.034  -79.300  52.134  1
40211  94.051  -79.301  52.115  1
40212  94.071  -79.301  52.097  1
40213  94.091  -79.300  52.079  1
40214  94.113  -79.269  52.064  1
40215  94.129  -79.243  52.047  1
40216  94.137  -79.253  52.030  1
40217  94.145  -79.256  52.012  1
40218  94.151  -79.247  51.993  1
40219  94.158  -79.239  51.975  1
40220  94.164  -79.232  51.961  1
40221  94.165  -79.230  51.946  1
40222  94.172  -79.229  51.933  1
40223  94.189  -79.232  51.921  1
40224  94.203  -79.237  51.911  1
40225  94.210  -79.247  51.901  1
40226  94.218  -79.258  51.890  1
40227  94.224  -79.263  51.879  1
40228  94.229  -79.262  51.867  1
40229  94.235  -79.262  51.855  1
40230  94.240  -79.261  51.842  1
40231  94.245  -79.261  51.826  1
40232  94.251  -79.259  51.809  1
40233  94.259  -79.254  51.791  1
40234  94.266  -79.249  51.772  1
40235  94.274  -79.244  51.752  1
40236  94.282  -79.239  51.732  1
40237  94.290  -79.234  51.712  1
40238  94.298  -79.229  51.688  1
40239  94.306  -79.225  51.663  1
40240  94.314  -79.219  51.637  1
40241  94.322  -79.215  51.609  1
40242  94.325  -79.212  51.581  1
40243  94.307  -79.222  51.552  1
40244  94.290  -79.231  51.524  1
40245  94.292  -79.229  51.494  1
40246  94.295  -79.228  51.464  1
40247  94.297  -79.227  51.432  1
40248  94.266  -79.257  51.397  1
40249  94.255  -79.259  51.361  1
40250  94.260  -79.251  51.324  1
40251  94.282  -79.238  51.285  1
40252  94.294  -79.234  51.244  1
40253  94.302  -79.241  51.203  1
40254  94.311  -79.248  51.161  1
40255  94.319  -79.256  51.118  1
40256  94.327  -79.263  51.075  1
40257  94.335  -79.271  51.034  1
40258  94.344  -79.278  50.992  1
40259  94.354  -79.288  50.949  1
40260  94.367  -79.301  50.907  1
40261  94.381  -79.314  50.866  1
40262  94.394  -79.327  50.825  1
40822  93.016  -79.801  53.063  1
40823  93.032  -79.792  53.041  1
40824  93.048  -79.785  53.020  1
40825  93.064  -79.776  52.999  1
40826  93.080  -79.768  52.980  1
40827  93.096  -79.761  52.963  1
40828  93.112  -79.752  52.947  1
40829  93.128  -79.745  52.932  1
40830  93.145  -79.733  52.918  1
40831  93.163  -79.720  52.906  1
40832  93.182  -79.706  52.895  1
40833  93.200  -79.692  52.885  1
40834  93.218  -79.678  52.880  1
40835  93.226  -79.673  52.875  1
40836  93.241  -79.667  52.871  1
40837  93.264  -79.660  52.866  1
40838  93.287  -79.651  52.863  1
40839  93.310  -79.644  52.861  1
40840  93.333  -79.636  52.857  1
40841  93.356  -79.629  52.853  1
40842  93.378  -79.623  52.847  1
40843  93.400  -79.616  52.841  1
40844  93.422  -79.610  52.836  1
40845  93.444  -79.604  52.829  1
40846  93.461  -79.595  52.821  1
40847  93.469  -79.584  52.814  1
40848  93.477  -79.573  52.805  1
40849  93.485  -79.562  52.796  1
40850  93.493  -79.551  52.786  1
40851  93.500  -79.540  52.778  1
40852  93.508  -79.529  52.769  1
40853  93.516  -79.518  52.762  1
40854  93.524  -79.507  52.755  1
40855  93.533  -79.496  52.749  1
40856  93.540  -79.485  52.744  1
40857  93.549  -79.475  52.739  1
40858  93.559  -79.467  52.730  1
40859  93.572  -79.463  52.720  1
40860  93.596  -79.450  52.708  1
40861  93.623  -79.436  52.696  1
40862  93.651  -79.425  52.685  1
40863  93.679  -79.413  52.674  1
40864  93.707  -79.401  52.665  1
40865  93.735  -79.389  52.657  1
40866  93.754  -79.385  52.651  1
40867  93.768  -79.382  52.646  1
40868  93.781  -79.379  52.641  1
40869  93.786  -79.375  52.638  1
40870  93.791  -79.371  52.637  1
40871  93.804  -79.363  52.635  1
40872  93.817  -79.356  52.635  1
40873  93.829  -79.348  52.635  1
40874  93.842  -79.341  52.634  1
40875  93.854  -79.334  52.634  1
40876  93.867  -79.326  52.633  1
40877  93.880  -79.319  52.632  1
40878  93.892  -79.311  52.627  1
40879  93.901  -79.306  52.621  1
40880  93.899  -79.307  52.612  1
40881  93.898  -79.308  52.601  1
40882  93.897  -79.309  52.591  1
40883  93.895  -79.310  52.581  1
40884  93.894  -79.311  52.570  1
40885  93.893  -79.312  52.560  1
40886  93.890  -79.315  52.550  1
40887  93.896  -79.316  52.540  1
40888  93.902  -79.316  52.528  1
40889  93.905  -79.319  52.514  1
40890  93.908  -79.320  52.498  1
40891  93.912  -79.322  52.484  1
40892  93.916  -79.323  52.468  1
40893  93.924  -79.319  52.451  1
40894  93.932  -79.316  52.432  1
40895  93.940  -79.312  52.416  1
40896  93.948  -79.308  52.399  1
40897  93.956  -79.304  52.381  1
40898  93.964  -79.300  52.366  1
40899  93.972  -79.297  52.349  1
40900  93.980  -79.298  52.332  1
40901  93.987  -79.300  52.315  1
40902  93.995  -79.302  52.297  1
40903  94.009  -79.307  52.280  1
40904  94.025  -79.313  52.262  1
40905  94.026  -79.329  52.245  1
40906  94.017  -79.353  52.228  1
40907  94.026  -79.366  52.211  1
40908  94.047  -79.358  52.193  1
40909  94.029  -79.328  52.173  1
40910  94.013  -79.297  52.153  1
40911  94.026  -79.287  52.132  1
40912  94.045  -79.284  52.113  1
40913  94.064  -79.281  52.094  1
40914  94.084  -79.281  52.075  1
40915  94.104  -79.281  52.058  1
40916  94.124  -79.268  52.042  1
40917  94.131  -79.266  52.025  1
40918  94.137  -79.257  52.006  1
40919  94.143  -79.249  51.988  1
40920  94.150  -79.241  51.971  1
40921  94.154  -79.235  51.958  1
40922  94.156  -79.233  51.946  1
40923  94.158  -79.231  51.936  1
40924  94.175  -79.234  51.926  1
40925  94.192  -79.238  51.914  1
40926  94.206  -79.244  51.902  1
40927  94.213  -79.253  51.891  1
40928  94.220  -79.262  51.879  1
40929  94.225  -79.262  51.867  1
40930  94.230  -79.261  51.855  1
40931  94.236  -79.261  51.841  1
40932  94.241  -79.260  51.826  1
40933  94.249  -79.255  51.810  1
40934  94.257  -79.250  51.792  1
40935  94.265  -79.245  51.772  1
40936  94.272  -79.241  51.752  1
40937  94.280  -79.235  51.734  1
40938  94.288  -79.231  51.715  1
40939  94.296  -79.225  51.691  1
40940  94.304  -79.221  51.665  1
40941  94.312  -79.216  51.639  1
40942  94.320  -79.211  51.612  1
40943  94.328  -79.206  51.584  1
40944  94.335  -79.201  51.557  1
40945  94.318  -79.209  51.530  1
40946  94.313  -79.213  51.500  1
40947  94.315  -79.212  51.468  1
40948  94.296  -79.231  51.435  1
40949  94.261  -79.261  51.400  1
40950  94.255  -79.256  51.364  1
40951  94.258  -79.248  51.329  1
40952  94.285  -79.231  51.291  1
40953  94.299  -79.225  51.252  1
40954  94.311  -79.222  51.211  1
40955  94.319  -79.228  51.169  1
40956  94.327  -79.235  51.127  1
40957  94.335  -79.243  51.085  1
40958  94.344  -79.250  51.043  1
40959  94.352  -79.258  51.001  1
40960  94.360  -79.266  50.958  1
40961  94.368  -79.273  50.916  1
40962  94.377  -79.280  50.875  1
40963  94.385  -79.288  50.834  1
41524  93.028  -79.776  53.061  1
41525  93.044  -79.767  53.040  1
41526  93.060  -79.760  53.019  1
41527  93.076  -79.751  53.000  1
41528  93.092  -79.744  52.982  1
41529  93.108  -79.736  52.965  1
41530  93.124  -79.727  52.949  1
41531  93.140  -79.720  52.935  1
41532  93.157  -79.708  52.921  1
41533  93.176  -79.693  52.910  1
41534  93.194  -79.679  52.900  1
41535  93.212  -79.666  52.893  1
41536  93.230  -79.652  52.887  1
41537  93.240  -79.646  52.881  1
41538  93.259  -79.639  52.876  1
41539  93.282  -79.631  52.872  1
41540  93.305  -79.623  52.868  1
41541  93.328  -79.616  52.862  1
41542  93.350  -79.609  52.856  1
41543  93.372  -79.603  52.850  1
41544  93.395  -79.597  52.843  1
41545  93.417  -79.590  52.838  1
41546  93.439  -79.584  52.831  1
41547  93.461  -79.577  52.824  1
41548  93.472  -79.567  52.815  1
41549  93.480  -79.556  52.807  1
41550  93.487  -79.545  52.799  1
41551  93.495  -79.534  52.790  1
41552  93.503  -79.523  52.782  1
41553  93.511  -79.512  52.773  1
41554  93.521  -79.504  52.765  1
41555  93.531  -79.497  52.758  1
41556  93.541  -79.489  52.752  1
41557  93.551  -79.482  52.747  1
41558  93.561  -79.474  52.741  1
41559  93.571  -79.467  52.732  1
41560  93.587  -79.464  52.722  1
41561  93.604  -79.461  52.711  1
41562  93.621  -79.457  52.697  1
41563  93.647  -79.441  52.686  1
41564  93.672  -79.426  52.676  1
41565  93.698  -79.411  52.668  1
41566  93.723  -79.396  52.662  1
41567  93.750  -79.383  52.656  1
41568  93.761  -79.377  52.650  1
41569  93.774  -79.369  52.644  1
41570  93.786  -79.363  52.639  1
41571  93.799  -79.355  52.636  1
41572  93.811  -79.347  52.636  1
41573  93.824  -79.340  52.636  1
41574  93.836  -79.332  52.636  1
41575  93.849  -79.325  52.635  1
41576  93.861  -79.318  52.634  1
41577  93.874  -79.310  52.634  1
41578  93.887  -79.303  52.634  1
41579  93.899  -79.295  52.630  1
41580  93.902  -79.294  52.623  1
41581  93.901  -79.294  52.614  1
41582  93.898  -79.297  52.605  1
41583  93.895  -79.300  52.595  1
41584  93.891  -79.303  52.584  1
41585  93.888  -79.307  52.572  1
41586  93.885  -79.310  52.563  1
41587  93.888  -79.310  52.553  1
41588  93.896  -79.309  52.543  1
41589  93.905  -79.310  52.530  1
41590  93.917  -79.310  52.515  1
41591  93.929  -79.310  52.500  1
41592  93.933  -79.312  52.484  1
41593  93.936  -79.313  52.467  1
41594  93.939  -79.315  52.450  1
41595  93.946  -79.313  52.432  1
41596  93.955  -79.309  52.415  1
41597  93.963  -79.306  52.399  1
41598  93.971  -79.302  52.383  1
41599  93.978  -79.298  52.368  1
41600  93.986  -79.294  52.351  1
41601  93.994  -79.291  52.332  1
41602  94.005  -79.290  52.314  1
41603  94.019  -79.294  52.296  1
41604  94.034  -79.297  52.279  1
41605  94.047  -79.300  52.261  1
41606  94.045  -79.315  52.244  1
41607  94.038  -79.341  52.228  1
41608  94.029  -79.365  52.211  1
41609  94.028  -79.361  52.192  1
41610  94.019  -79.328  52.173  1
41611  94.011  -79.296  52.153  1
41612  94.026  -79.289  52.131  1
41613  94.046  -79.286  52.111  1
41614  94.065  -79.284  52.092  1
41615  94.084  -79.281  52.073  1
41616  94.104  -79.278  52.057  1
41617  94.112  -79.268  52.040  1
41618  94.123  -79.267  52.024  1
41619  94.129  -79.259  52.005  1
41620  94.136  -79.250  51.987  1
41621  94.142  -79.243  51.972  1
41622  94.144  -79.239  51.960  1
41623  94.146  -79.237  51.949  1
41624  94.148  -79.234  51.940  1
41625  94.161  -79.237  51.931  1
41626  94.179  -79.240  51.919  1
41627  94.196  -79.244  51.906  1
41628  94.209  -79.250  51.893  1
41629  94.216  -79.259  51.879  1
41630  94.221  -79.261  51.867  1
41631  94.227  -79.261  51.855  1
41632  94.232  -79.260  51.843  1
41633  94.240  -79.256  51.827  1
41634  94.247  -79.251  51.811  1
41635  94.255  -79.247  51.794  1
41636  94.263  -79.241  51.774  1
41637  94.271  -79.237  51.755  1
41638  94.278  -79.231  51.737  1
41639  94.286  -79.227  51.718  1
41640  94.294  -79.222  51.694  1
41641  94.302  -79.217  51.669  1
41642  94.310  -79.212  51.642  1
41643  94.318  -79.207  51.616  1
41644  94.326  -79.202  51.590  1
41645  94.333  -79.197  51.565  1
41646  94.341  -79.192  51.536  1
41647  94.333  -79.197  51.506  1
41648  94.327  -79.203  51.473  1
41649  94.274  -79.253  51.438  1
41650  94.261  -79.257  51.403  1
41651  94.256  -79.252  51.368  1
41652  94.255  -79.245  51.333  1
41653  94.282  -79.228  51.296  1
41654  94.305  -79.216  51.258  1
41655  94.316  -79.212  51.219  1
41656  94.327  -79.209  51.178  1
41657  94.336  -79.216  51.136  1
41658  94.344  -79.222  51.095  1
41659  94.352  -79.230  51.052  1
41660  94.360  -79.237  51.010  1
41661  94.368  -79.245  50.968  1
41662  94.377  -79.253  50.925  1
41663  94.385  -79.260  50.884  1
41664  94.394  -79.268  50.843  1
41724  95.166  -80.028  48.741  1
41725  95.186  -80.034  48.705  1
41726  95.210  -80.035  48.668  1
41727  95.233  -80.037  48.631  1
41728  95.257  -80.038  48.595  1
41729  95.280  -80.040  48.560  1
41730  95.304  -80.041  48.524  1
41731  95.328  -80.043  48.489  1
42226  93.040  -79.751  53.061  1
42227  93.056  -79.742  53.040  1
42228  93.072  -79.735  53.020  1
42229  93.088  -79.726  53.001  1
42230  93.104  -79.719  52.984  1
42231  93.120  -79.711  52.967  1
42232  93.136  -79.702  52.952  1
42233  93.152  -79.695  52.938  1
42234  93.170  -79.681  52.926  1
42235  93.188  -79.667  52.915  1
42236  93.206  -79.654  52.906  1
42237  93.224  -79.639  52.899  1
42238  93.242  -79.626  52.893  1
42239  93.255  -79.618  52.887  1
42240  93.277  -79.610  52.881  1
42241  93.300  -79.602  52.875  1
42242  93.323  -79.596  52.868  1
42243  93.345  -79.590  52.861  1
42244  93.367  -79.583  52.855  1
42245  93.389  -79.577  52.848  1
42246  93.411  -79.570  52.843  1
42247  93.433  -79.564  52.837  1
42248  93.455  -79.558  52.829  1
42249  93.474  -79.551  52.822  1
42250  93.484  -79.541  52.813  1
42251  93.493  -79.534  52.804  1
42252  93.503  -79.526  52.796  1
42253  93.513  -79.519  52.787  1
42254  93.523  -79.511  52.778  1
42255  93.533  -79.504  52.769  1
42256  93.543  -79.496  52.761  1
42257  93.553  -79.488  52.754  1
42258  93.563  -79.481  52.748  1
42259  93.573  -79.473  52.741  1
42260  93.587  -79.469  52.732  1
42261  93.603  -79.466  52.722  1
42262  93.619  -79.463  52.710  1
42263  93.635  -79.460  52.699  1
42264  93.651  -79.457  52.689  1
42265  93.673  -79.447  52.679  1
42266  93.698  -79.432  52.673  1
42267  93.723  -79.418  52.667  1
42268  93.745  -79.404  52.661  1
42269  93.758  -79.396  52.654  1
42270  93.771  -79.387  52.648  1
42271  93.784  -79.379  52.642  1
42272  93.797  -79.369  52.638  1
42273  93.809  -79.361  52.638  1
42274  93.823  -79.353  52.639  1
42275  93.836  -79.344  52.639  1
42276  93.848  -79.335  52.637  1
42277  93.861  -79.326  52.637  1
42278  93.873  -79.310  52.637  1
42279  93.885  -79.295  52.637  1
42280  93.897  -79.286  52.633  1
42281  93.897  -79.289  52.626  1
42282  93.893  -79.293  52.618  1
42283  93.890  -79.296  52.609  1
42284  93.886  -79.299  52.599  1
42285  93.883  -79.303  52.587  1
42286  93.880  -79.306  52.574  1
42287  93.878  -79.308  52.564  1
42288  93.889  -79.303  52.554  1
42289  93.897  -79.301  52.543  1
42290  93.903  -79.303  52.530  1
42291  93.913  -79.303  52.515  1
42292  93.926  -79.303  52.501  1
42293  93.938  -79.303  52.484  1
42294  93.951  -79.304  52.468  1
42295  93.961  -79.305  52.451  1
42296  93.964  -79.306  52.434  1
42297  93.969  -79.306  52.417  1
42298  93.977  -79.303  52.401  1
42299  93.985  -79.299  52.385  1
42300  93.993  -79.295  52.369  1
42301  94.001  -79.291  52.351  1
42302  94.016  -79.295  52.332  1
42303  94.030  -79.298  52.313  1
42304  94.032  -79.299  52.295  1
42305  94.034  -79.300  52.277  1
42306  94.036  -79.300  52.260  1
42307  94.038  -79.300  52.243  1
42308  94.036  -79.316  52.227  1
42309  94.030  -79.343  52.210  1
42310  94.024  -79.360  52.192  1
42311  94.016  -79.327  52.174  1
42312  94.008  -79.294  52.154  1
42313  94.027  -79.291  52.131  1
42314  94.046  -79.288  52.111  1
42315  94.065  -79.286  52.092  1
42316  94.084  -79.284  52.073  1
42317  94.091  -79.272  52.057  1
42318  94.097  -79.259  52.041  1
42319  94.115  -79.269  52.024  1
42320  94.121  -79.261  52.006  1
42321  94.128  -79.253  51.989  1
42322  94.133  -79.245  51.974  1
42323  94.135  -79.243  51.963  1
42324  94.137  -79.241  51.954  1
42325  94.138  -79.238  51.945  1
42326  94.148  -79.238  51.937  1
42327  94.165  -79.242  51.924  1
42328  94.182  -79.245  51.911  1
42329  94.199  -79.249  51.896  1
42330  94.212  -79.255  51.881  1
42331  94.218  -79.261  51.868  1
42332  94.223  -79.260  51.856  1
42333  94.229  -79.258  51.845  1
42334  94.238  -79.253  51.829  1
42335  94.246  -79.248  51.812  1
42336  94.253  -79.243  51.795  1
42337  94.261  -79.238  51.776  1
42338  94.269  -79.233  51.757  1
42339  94.277  -79.228  51.738  1
42340  94.284  -79.223  51.718  1
42341  94.292  -79.218  51.695  1
42342  94.300  -79.213  51.670  1
42343  94.308  -79.208  51.644  1
42344  94.316  -79.203  51.621  1
42345  94.324  -79.198  51.597  1
42346  94.332  -79.194  51.572  1
42347  94.339  -79.189  51.544  1
42348  94.345  -79.187  51.512  1
42349  94.305  -79.226  51.479  1
42350  94.267  -79.258  51.443  1
42351  94.262  -79.253  51.409  1
42352  94.257  -79.248  51.374  1
42353  94.253  -79.243  51.340  1
42354  94.280  -79.226  51.304  1
42355  94.307  -79.209  51.266  1
42356  94.321  -79.203  51.227  1
42357  94.332  -79.200  51.187  1
42358  94.344  -79.196  51.146  1
42359  94.352  -79.203  51.104  1
42360  94.360  -79.209  51.062  1
42361  94.369  -79.217  51.019  1
42362  94.377  -79.225  50.977  1
42363  94.386  -79.232  50.935  1
42364  94.394  -79.240  50.893  1
42365  94.402  -79.247  50.852  1
42424  95.144  -79.976  48.779  1
42425  95.158  -79.989  48.743  1
42426  95.176  -79.996  48.707  1
42427  95.200  -79.997  48.671  1
42428  95.224  -79.999  48.634  1
42429  95.247  -80.000  48.597  1
42430  95.271  -80.002  48.561  1
42431  95.294  -80.003  48.526  1
42432  95.318  -80.005  48.490  1
42433  95.341  -80.006  48.455  1
42434  95.365  -80.008  48.419  1
42928  93.052  -79.726  53.062  1
42929  93.068  -79.717  53.041  1
42930  93.084  -79.710  53.022  1
42931  93.100  -79.701  53.004  1
42932  93.116  -79.694  52.987  1
42933  93.132  -79.686  52.971  1
42934  93.148  -79.677  52.957  1
42935  93.164  -79.669  52.944  1
42936  93.183  -79.655  52.932  1
42937  93.201  -79.641  52.922  1
42938  93.219  -79.627  52.912  1
42939  93.237  -79.614  52.904  1
42940  93.255  -79.600  52.898  1
42941  93.272  -79.590  52.891  1
42942  93.295  -79.583  52.883  1
42943  93.317  -79.576  52.875  1
42944  93.339  -79.570  52.868  1
42945  93.361  -79.564  52.862  1
42946  93.382  -79.558  52.856  1
42947  93.403  -79.553  52.850  1
42948  93.425  -79.547  52.844  1
42949  93.446  -79.541  52.836  1
42950  93.467  -79.535  52.829  1
42951  93.483  -79.532  52.820  1
42952  93.499  -79.529  52.811  1
42953  93.515  -79.526  52.803  1
42954  93.525  -79.518  52.794  1
42955  93.536  -79.510  52.785  1
42956  93.546  -79.503  52.776  1
42957  93.555  -79.495  52.767  1
42958  93.565  -79.488  52.760  1
42959  93.575  -79.480  52.752  1
42960  93.586  -79.473  52.746  1
42961  93.602  -79.470  52.737  1
42962  93.618  -79.468  52.726  1
42963  93.634  -79.465  52.713  1
42964  93.650  -79.462  52.704  1
42965  93.666  -79.459  52.695  1
42966  93.682  -79.457  52.686  1
42967  93.698  -79.454  52.679  1
42968  93.723  -79.439  52.672  1
42969  93.741  -79.429  52.666  1
42970  93.754  -79.419  52.660  1
42971  93.766  -79.411  52.653  1
42972  93.779  -79.403  52.648  1
42973  93.791  -79.387  52.644  1
42974  93.802  -79.371  52.643  1
42975  93.814  -79.356  52.643  1
42976  93.826  -79.340  52.642  1
42977  93.838  -79.324  52.641  1
42978  93.849  -79.309  52.641  1
42979  93.861  -79.293  52.641  1
42980  93.874  -79.286  52.640  1
42981  93.888  -79.285  52.636  1
42982  93.888  -79.288  52.630  1
42983  93.885  -79.291  52.621  1
42984  93.881  -79.295  52.613  1
42985  93.878  -79.298  52.602  1
42986  93.874  -79.301  52.589  1
42987  93.871  -79.305  52.577  1
42988  93.880  -79.301  52.566  1
42989  93.891  -79.296  52.555  1
42990  93.899  -79.294  52.544  1
42991  93.904  -79.296  52.530  1
42992  93.910  -79.297  52.516  1
42993  93.922  -79.297  52.502  1
42994  93.934  -79.297  52.485  1
42995  93.947  -79.297  52.469  1
42996  93.960  -79.298  52.452  1
42997  93.972  -79.298  52.436  1
42998  93.985  -79.299  52.419  1
42999  93.992  -79.300  52.403  1
43000  94.000  -79.296  52.386  1
43001  94.011  -79.297  52.368  1
43002  94.014  -79.297  52.350  1
43003  94.016  -79.298  52.331  1
43004  94.018  -79.299  52.311  1
43005  94.020  -79.299  52.293  1
43006  94.023  -79.300  52.275  1
43007  94.025  -79.300  52.257  1
43008  94.027  -79.301  52.240  1
43009  94.029  -79.301  52.224  1
43010  94.026  -79.318  52.208  1
43011  94.020  -79.344  52.192  1
43012  94.013  -79.325  52.175  1
43013  94.008  -79.296  52.155  1
43014  94.027  -79.293  52.132  1
43015  94.047  -79.291  52.111  1
43016  94.066  -79.288  52.092  1
43017  94.071  -79.275  52.073  1
43018  94.077  -79.263  52.056  1
43019  94.082  -79.251  52.041  1
43020  94.100  -79.259  52.027  1
43021  94.113  -79.263  52.009  1
43022  94.120  -79.254  51.993  1
43023  94.124  -79.249  51.979  1
43024  94.125  -79.247  51.969  1
43025  94.127  -79.244  51.960  1
43026  94.129  -79.241  51.951  1
43027  94.134  -79.241  51.942  1
43028  94.151  -79.244  51.929  1
43029  94.168  -79.247  51.914  1
43030  94.185  -79.251  51.900  1
43031  94.202  -79.254  51.884  1
43032  94.214  -79.260  51.871  1
43033  94.220  -79.259  51.858  1
43034  94.228  -79.254  51.847  1
43035  94.236  -79.249  51.831  1
43036  94.244  -79.244  51.813  1
43037  94.251  -79.239  51.795  1
43038  94.259  -79.234  51.777  1
43039  94.267  -79.229  51.757  1
43040  94.273  -79.226  51.737  1
43041  94.280  -79.222  51.717  1
43042  94.286  -79.219  51.694  1
43043  94.293  -79.216  51.670  1
43044  94.299  -79.212  51.647  1
43045  94.306  -79.208  51.625  1
43046  94.313  -79.205  51.603  1
43047  94.319  -79.201  51.578  1
43048  94.321  -79.203  51.551  1
43049  94.317  -79.213  51.520  1
43050  94.282  -79.249  51.485  1
43051  94.268  -79.254  51.449  1
43052  94.263  -79.250  51.415  1
43053  94.258  -79.244  51.381  1
43054  94.252  -79.239  51.347  1
43055  94.278  -79.223  51.312  1
43056  94.305  -79.206  51.275  1
43057  94.327  -79.194  51.235  1
43058  94.338  -79.190  51.196  1
43059  94.349  -79.187  51.155  1
43060  94.360  -79.183  51.113  1
43061  94.369  -79.190  51.071  1
43062  94.377  -79.197  51.029  1
43063  94.386  -79.204  50.987  1
43064  94.394  -79.212  50.945  1
43065  94.402  -79.219  50.903  1
43066  94.410  -79.227  50.862  1
43124  95.123  -79.924  48.818  1
43125  95.136  -79.936  48.781  1
43126  95.149  -79.949  48.745  1
43127  95.167  -79.958  48.709  1
43128  95.190  -79.959  48.672  1
43129  95.214  -79.961  48.636  1
43130  95.237  -79.962  48.599  1
43131  95.261  -79.964  48.563  1
43132  95.284  -79.965  48.527  1
43133  95.308  -79.967  48.492  1
43134  95.332  -79.968  48.456  1
43135  95.355  -79.970  48.421  1
43136  95.379  -79.971  48.386  1
43629  93.048  -79.709  53.084  1
43630  93.064  -79.701  53.063  1
43631  93.080  -79.692  53.043  1
43632  93.095  -79.685  53.025  1
43633  93.112  -79.676  53.008  1
43634  93.128  -79.669  52.992  1
43635  93.144  -79.661  52.976  1
43636  93.160  -79.652  52.962  1
43637  93.177  -79.642  52.950  1
43638  93.195  -79.629  52.939  1
43639  93.213  -79.615  52.928  1
43640  93.231  -79.601  52.918  1
43641  93.249  -79.587  52.910  1
43642  93.267  -79.573  52.901  1
43643  93.286  -79.566  52.892  1
43644  93.307  -79.560  52.886  1
43645  93.329  -79.554  52.879  1
43646  93.350  -79.548  52.872  1
43647  93.371  -79.542  52.866  1
43648  93.392  -79.536  52.859  1
43649  93.413  -79.531  52.852  1
43650  93.435  -79.525  52.845  1
43651  93.456  -79.520  52.837  1
43652  93.474  -79.515  52.829  1
43653  93.490  -79.512  52.819  1
43654  93.505  -79.508  52.811  1
43655  93.521  -79.505  52.802  1
43656  93.537  -79.502  52.793  1
43657  93.553  -79.499  52.785  1
43658  93.567  -79.494  52.776  1
43659  93.577  -79.487  52.768  1
43660  93.587  -79.479  52.760  1
43661  93.601  -79.475  52.753  1
43662  93.617  -79.473  52.743  1
43663  93.633  -79.469  52.732  1
43664  93.649  -79.466  52.720  1
43665  93.665  -79.463  52.710  1
43666  93.681  -79.460  52.702  1
43667  93.694  -79.456  52.694  1
43668  93.707  -79.451  52.686  1
43669  93.720  -79.446  52.679  1
43670  93.732  -79.432  52.673  1
43671  93.744  -79.416  52.666  1
43672  93.756  -79.400  52.659  1
43673  93.767  -79.385  52.654  1
43674  93.779  -79.369  52.650  1
43675  93.791  -79.353  52.649  1
43676  93.802  -79.338  52.649  1
43677  93.814  -79.322  52.649  1
43678  93.826  -79.306  52.647  1
43679  93.837  -79.291  52.647  1
43680  93.851  -79.286  52.646  1
43681  93.865  -79.285  52.644  1
43682  93.879  -79.285  52.639  1
43683  93.880  -79.287  52.633  1
43684  93.876  -79.291  52.625  1
43685  93.873  -79.294  52.616  1
43686  93.869  -79.297  52.605  1
43687  93.866  -79.300  52.592  1
43688  93.870  -79.299  52.579  1
43689  93.881  -79.294  52.568  1
43690  93.892  -79.288  52.558  1
43691  93.900  -79.288  52.545  1
43692  93.906  -79.288  52.533  1
43693  93.911  -79.290  52.519  1
43694  93.918  -79.291  52.504  1
43695  93.930  -79.291  52.487  1
43696  93.943  -79.291  52.470  1
43697  93.956  -79.292  52.453  1
43698  93.968  -79.292  52.438  1
43699  93.981  -79.292  52.422  1
43700  93.994  -79.292  52.404  1
43701  94.004  -79.292  52.385  1
43702  94.003  -79.295  52.367  1
43703  94.003  -79.297  52.348  1
43704  94.004  -79.298  52.329  1
43705  94.007  -79.299  52.310  1
43706  94.009  -79.300  52.291  1
43707  94.011  -79.300  52.273  1
43708  94.013  -79.300  52.255  1
43709  94.015  -79.301  52.238  1
43710  94.017  -79.302  52.223  1
43711  94.019  -79.302  52.207  1
43712  94.017  -79.319  52.192  1
43713  94.010  -79.324  52.175  1
43714  94.008  -79.298  52.155  1
43715  94.028  -79.295  52.133  1
43716  94.046  -79.292  52.113  1
43717  94.051  -79.280  52.094  1
43718  94.057  -79.267  52.077  1
43719  94.063  -79.255  52.062  1
43720  94.068  -79.242  52.048  1
43721  94.084  -79.249  52.035  1
43722  94.103  -79.259  52.019  1
43723  94.112  -79.256  52.004  1
43724  94.114  -79.252  51.992  1
43725  94.116  -79.250  51.982  1
43726  94.118  -79.247  51.973  1
43727  94.120  -79.245  51.964  1
43728  94.121  -79.243  51.953  1
43729  94.137  -79.246  51.939  1
43730  94.154  -79.250  51.923  1
43731  94.172  -79.253  51.907  1
43732  94.189  -79.256  51.891  1
43733  94.208  -79.258  51.876  1
43734  94.214  -79.259  51.862  1
43735  94.221  -79.256  51.850  1
43736  94.227  -79.252  51.833  1
43737  94.234  -79.248  51.815  1
43738  94.241  -79.245  51.796  1
43739  94.247  -79.241  51.776  1
43740  94.254  -79.237  51.755  1
43741  94.260  -79.234  51.735  1
43742  94.267  -79.231  51.715  1
43743  94.273  -79.227  51.692  1
43744  94.280  -79.224  51.670  1
43745  94.286  -79.220  51.650  1
43746  94.292  -79.216  51.630  1
43747  94.299  -79.213  51.608  1
43748  94.297  -79.221  51.585  1
43749  94.293  -79.231  51.558  1
43750  94.290  -79.241  51.527  1
43751  94.274  -79.256  51.493  1
43752  94.269  -79.250  51.458  1
43753  94.264  -79.245  51.423  1
43754  94.258  -79.241  51.389  1
43755  94.253  -79.235  51.355  1
43756  94.275  -79.220  51.321  1
43757  94.302  -79.203  51.284  1
43758  94.330  -79.187  51.245  1
43759  94.343  -79.181  51.204  1
43760  94.354  -79.178  51.164  1
43761  94.365  -79.174  51.123  1
43762  94.377  -79.170  51.081  1
43763  94.386  -79.177  51.039  1
43764  94.394  -79.184  50.997  1
43765  94.402  -79.192  50.954  1
43766  94.410  -79.199  50.913  1
43767  94.419  -79.206  50.873  1
43824  95.102  -79.871  48.858  1
43825  95.115  -79.884  48.821  1
43826  95.128  -79.897  48.784  1
43827  95.141  -79.910  48.748  1
43828  95.157  -79.921  48.711  1
43829  95.180  -79.922  48.674  1
43830  95.204  -79.924  48.637  1
43831  95.228  -79.925  48.601  1
43832  95.251  -79.926  48.565  1
43833  95.275  -79.927  48.529  1
43834  95.298  -79.929  48.493  1
43835  95.322  -79.930  48.457  1
43836  95.345  -79.932  48.423  1
43837  95.369  -79.933  48.387  1
44331  93.060  -79.684  53.086  1
44332  93.075  -79.676  53.066  1
44333  93.091  -79.667  53.047  1
44334  93.108  -79.660  53.030  1
44335  93.124  -79.651  53.013  1
44336  93.140  -79.644  52.997  1
44337  93.156  -79.636  52.982  1
44338  93.171  -79.627  52.969  1
44339  93.189  -79.617  52.956  1
44340  93.207  -79.602  52.944  1
44341  93.225  -79.588  52.933  1
44342  93.243  -79.575  52.924  1
44343  93.262  -79.561  52.914  1
44344  93.280  -79.550  52.904  1
44345  93.298  -79.544  52.898  1
44346  93.318  -79.538  52.890  1
44347  93.339  -79.532  52.884  1
44348  93.360  -79.526  52.878  1
44349  93.381  -79.520  52.872  1
44350  93.402  -79.515  52.865  1
44351  93.423  -79.509  52.858  1
44352  93.445  -79.503  52.850  1
44353  93.465  -79.498  52.842  1
44354  93.480  -79.494  52.833  1
44355  93.496  -79.491  52.824  1
44356  93.512  -79.488  52.814  1
44357  93.528  -79.485  52.805  1
44358  93.544  -79.482  52.796  1
44359  93.559  -79.479  52.789  1
44360  93.575  -79.476  52.780  1
44361  93.588  -79.472  52.772  1
44362  93.603  -79.467  52.761  1
44363  93.616  -79.462  52.750  1
44364  93.628  -79.457  52.739  1
44365  93.641  -79.452  52.729  1
44366  93.654  -79.447  52.719  1
44367  93.667  -79.443  52.711  1
44368  93.680  -79.438  52.704  1
44369  93.693  -79.433  52.695  1
44370  93.707  -79.426  52.688  1
44371  93.720  -79.414  52.681  1
44372  93.732  -79.398  52.673  1
44373  93.744  -79.382  52.666  1
44374  93.756  -79.367  52.660  1
44375  93.767  -79.351  52.657  1
44376  93.779  -79.336  52.656  1
44377  93.790  -79.320  52.656  1
44378  93.802  -79.304  52.655  1
44379  93.814  -79.289  52.654  1
44380  93.827  -79.285  52.653  1
44381  93.841  -79.285  52.651  1
44382  93.855  -79.285  52.648  1
44383  93.869  -79.284  52.643  1
44384  93.871  -79.286  52.636  1
44385  93.867  -79.289  52.627  1
44386  93.864  -79.293  52.619  1
44387  93.861  -79.296  52.608  1
44388  93.860  -79.297  52.595  1
44389  93.871  -79.292  52.583  1
44390  93.883  -79.287  52.572  1
44391  93.894  -79.281  52.561  1
44392  93.902  -79.280  52.548  1
44393  93.907  -79.281  52.535  1
44394  93.913  -79.283  52.521  1
44395  93.919  -79.284  52.506  1
44396  93.926  -79.285  52.489  1
44397  93.939  -79.285  52.472  1
44398  93.952  -79.285  52.456  1
44399  93.964  -79.286  52.439  1
44400  93.980  -79.285  52.421  1
44401  93.995  -79.283  52.403  1
44402  94.004  -79.283  52.385  1
44403  94.004  -79.286  52.367  1
44404  94.003  -79.288  52.348  1
44405  94.003  -79.291  52.329  1
44406  94.003  -79.294  52.310  1
44407  94.002  -79.296  52.291  1
44408  94.002  -79.298  52.272  1
44409  94.002  -79.300  52.254  1
44410  94.004  -79.301  52.238  1
44411  94.006  -79.302  52.222  1
44412  94.008  -79.302  52.207  1
44413  94.010  -79.303  52.192  1
44414  94.007  -79.320  52.175  1
44415  94.009  -79.300  52.156  1
44416  94.026  -79.296  52.135  1
44417  94.031  -79.284  52.116  1
44418  94.037  -79.271  52.098  1
44419  94.043  -79.259  52.083  1
44420  94.048  -79.247  52.070  1
44421  94.054  -79.234  52.057  1
44422  94.069  -79.239  52.045  1
44423  94.087  -79.250  52.031  1
44424  94.103  -79.258  52.018  1
44425  94.105  -79.256  52.007  1
44426  94.107  -79.253  51.997  1
44427  94.109  -79.250  51.987  1
44428  94.112  -79.247  51.977  1
44429  94.114  -79.243  51.965  1
44430  94.129  -79.243  51.949  1
44431  94.148  -79.244  51.932  1
44432  94.167  -79.246  51.914  1
44433  94.186  -79.247  51.898  1
44434  94.197  -79.253  51.882  1
44435  94.202  -79.265  51.866  1
44436  94.208  -79.264  51.852  1
44437  94.214  -79.260  51.834  1
44438  94.221  -79.256  51.816  1
44439  94.227  -79.253  51.797  1
44440  94.234  -79.250  51.776  1
44441  94.241  -79.246  51.755  1
44442  94.247  -79.242  51.735  1
44443  94.253  -79.239  51.716  1
44444  94.260  -79.235  51.694  1
44445  94.266  -79.231  51.672  1
44446  94.273  -79.228  51.652  1
44447  94.277  -79.228  51.632  1
44448  94.273  -79.238  51.611  1
44449  94.270  -79.248  51.588  1
44450  94.266  -79.257  51.564  1
44451  94.268  -79.251  51.536  1
44452  94.275  -79.252  51.503  1
44453  94.270  -79.247  51.468  1
44454  94.264  -79.241  51.433  1
44455  94.259  -79.237  51.399  1
44456  94.254  -79.231  51.366  1
44457  94.273  -79.218  51.331  1
44458  94.300  -79.201  51.294  1
44459  94.327  -79.184  51.255  1
44460  94.348  -79.172  51.214  1
44461  94.360  -79.169  51.174  1
44462  94.371  -79.165  51.132  1
44463  94.383  -79.161  51.091  1
44464  94.394  -79.158  51.049  1
44465  94.402  -79.164  51.007  1
44466  94.410  -79.172  50.964  1
44467  94.419  -79.179  50.923  1
44468  94.427  -79.186  50.883  1
44524  95.080  -79.819  48.897  1
44525  95.093  -79.832  48.861  1
44526  95.106  -79.845  48.824  1
44527  95.119  -79.858  48.787  1
44528  95.132  -79.871  48.750  1
44529  95.147  -79.883  48.713  1
44530  95.171  -79.884  48.676  1
44531  95.194  -79.886  48.639  1
44532  95.218  -79.887  48.603  1
44533  95.241  -79.889  48.567  1
44534  95.265  -79.890  48.531  1
44535  95.288  -79.892  48.495  1
44536  95.312  -79.893  48.459  1
44537  95.336  -79.895  48.424  1
44538  95.359  -79.896  48.389  1
44539  95.383  -79.897  48.353  1
45033  93.071  -79.659  53.089  1
45034  93.087  -79.651  53.070  1
45035  93.103  -79.642  53.051  1
45036  93.120  -79.635  53.034  1
45037  93.136  -79.626  53.017  1
45038  93.152  -79.619  53.002  1
45039  93.167  -79.610  52.988  1
45040  93.184  -79.602  52.975  1
45041  93.201  -79.590  52.962  1
45042  93.219  -79.576  52.950  1
45043  93.237  -79.563  52.939  1
45044  93.256  -79.548  52.928  1
45045  93.274  -79.535  52.919  1
45046  93.292  -79.529  52.910  1
45047  93.311  -79.523  52.903  1
45048  93.330  -79.516  52.896  1
45049  93.349  -79.510  52.892  1
45050  93.370  -79.504  52.886  1
45051  93.391  -79.498  52.880  1
45052  93.412  -79.493  52.873  1
45053  93.433  -79.487  52.866  1
45054  93.455  -79.482  52.857  1
45055  93.471  -79.478  52.848  1
45056  93.487  -79.475  52.839  1
45057  93.502  -79.472  52.829  1
45058  93.518  -79.468  52.819  1
45059  93.534  -79.465  52.810  1
45060  93.550  -79.462  52.801  1
45061  93.560  -79.457  52.792  1
45062  93.570  -79.453  52.782  1
45063  93.586  -79.448  52.770  1
45064  93.602  -79.444  52.759  1
45065  93.615  -79.439  52.749  1
45066  93.628  -79.435  52.739  1
45067  93.640  -79.429  52.729  1
45068  93.653  -79.425  52.721  1
45069  93.666  -79.419  52.713  1
45070  93.680  -79.415  52.705  1
45071  93.694  -79.407  52.698  1
45072  93.708  -79.396  52.690  1
45073  93.720  -79.381  52.682  1
45074  93.732  -79.365  52.674  1
45075  93.744  -79.349  52.667  1
45076  93.755  -79.334  52.665  1
45077  93.767  -79.318  52.664  1
45078  93.778  -79.303  52.664  1
45079  93.790  -79.287  52.662  1
45080  93.804  -79.285  52.660  1
45081  93.818  -79.285  52.658  1
45082  93.832  -79.284  52.656  1
45083  93.846  -79.283  52.651  1
45084  93.860  -79.282  52.645  1
45085  93.862  -79.285  52.638  1
45086  93.859  -79.288  52.629  1
45087  93.856  -79.291  52.621  1
45088  93.852  -79.294  52.610  1
45089  93.862  -79.291  52.598  1
45090  93.873  -79.285  52.587  1
45091  93.885  -79.279  52.576  1
45092  93.896  -79.274  52.565  1
45093  93.903  -79.273  52.552  1
45094  93.909  -79.275  52.538  1
45095  93.914  -79.275  52.524  1
45096  93.920  -79.277  52.508  1
45097  93.926  -79.278  52.492  1
45098  93.935  -79.279  52.475  1
45099  93.949  -79.278  52.458  1
45100  93.965  -79.277  52.441  1
45101  93.981  -79.275  52.422  1
45102  93.996  -79.274  52.404  1
45103  94.005  -79.274  52.386  1
45104  94.005  -79.277  52.368  1
45105  94.004  -79.279  52.350  1
45106  94.004  -79.281  52.331  1
45107  94.003  -79.285  52.311  1
45108  94.003  -79.287  52.293  1
45109  94.002  -79.289  52.275  1
45110  94.002  -79.292  52.256  1
45111  94.002  -79.294  52.239  1
45112  94.001  -79.297  52.223  1
45113  94.001  -79.300  52.209  1
45114  94.000  -79.302  52.194  1
45115  94.001  -79.303  52.178  1
45116  94.006  -79.300  52.159  1
45117  94.011  -79.288  52.138  1
45118  94.017  -79.275  52.120  1
45119  94.023  -79.263  52.103  1
45120  94.028  -79.250  52.090  1
45121  94.034  -79.237  52.079  1
45122  94.040  -79.225  52.069  1
45123  94.054  -79.229  52.058  1
45124  94.072  -79.240  52.047  1
45125  94.098  -79.256  52.036  1
45126  94.101  -79.254  52.025  1
45127  94.104  -79.250  52.013  1
45128  94.107  -79.245  52.002  1
45129  94.110  -79.240  51.990  1
45130  94.113  -79.234  51.976  1
45131  94.125  -79.234  51.960  1
45132  94.144  -79.235  51.942  1
45133  94.164  -79.237  51.923  1
45134  94.181  -79.239  51.905  1
45135  94.185  -79.250  51.887  1
45136  94.190  -79.262  51.870  1
45137  94.195  -79.272  51.853  1
45138  94.201  -79.269  51.835  1
45139  94.207  -79.265  51.816  1
45140  94.214  -79.261  51.796  1
45141  94.220  -79.258  51.775  1
45142  94.227  -79.254  51.755  1
45143  94.234  -79.250  51.736  1
45144  94.240  -79.247  51.718  1
45145  94.247  -79.244  51.697  1
45146  94.253  -79.240  51.675  1
45147  94.253  -79.246  51.655  1
45148  94.249  -79.255  51.634  1
45149  94.246  -79.265  51.614  1
45150  94.248  -79.256  51.592  1
45151  94.251  -79.244  51.569  1
45152  94.258  -79.227  51.542  1
45153  94.276  -79.206  51.511  1
45154  94.270  -79.243  51.477  1
45155  94.265  -79.237  51.443  1
45156  94.260  -79.233  51.409  1
45157  94.255  -79.228  51.377  1
45158  94.270  -79.215  51.342  1
45159  94.298  -79.198  51.304  1
45160  94.325  -79.181  51.264  1
45161  94.352  -79.165  51.224  1
45162  94.365  -79.159  51.183  1
45163  94.377  -79.156  51.142  1
45164  94.388  -79.152  51.100  1
45165  94.399  -79.149  51.059  1
45166  94.410  -79.145  51.018  1
45167  94.419  -79.151  50.975  1
45168  94.427  -79.159  50.934  1
45169  94.435  -79.166  50.894  1
45224  95.058  -79.767  48.938  1
45225  95.071  -79.780  48.901  1
45226  95.085  -79.792  48.864  1
45227  95.098  -79.805  48.827  1
45228  95.111  -79.818  48.791  1
45229  95.124  -79.832  48.753  1
45230  95.137  -79.845  48.715  1
45231  95.161  -79.846  48.678  1
45232  95.184  -79.848  48.642  1
45233  95.208  -79.849  48.605  1
45234  95.232  -79.851  48.568  1
45235  95.255  -79.852  48.533  1
45236  95.279  -79.854  48.498  1
45237  95.302  -79.855  48.462  1
45238  95.326  -79.857  48.426  1
45239  95.349  -79.858  48.390  1
45240  95.373  -79.860  48.355  1
45241  95.397  -79.861  48.320  1
45735  93.083  -79.634  53.092  1
45736  93.099  -79.626  53.074  1
45737  93.116  -79.617  53.056  1
45738  93.132  -79.610  53.039  1
45739  93.147  -79.601  53.023  1
45740  93.163  -79.594  53.008  1
45741  93.180  -79.585  52.995  1
45742  93.196  -79.577  52.982  1
45743  93.214  -79.563  52.970  1
45744  93.232  -79.550  52.958  1
45745  93.250  -79.536  52.947  1
45746  93.268  -79.523  52.936  1
45747  93.286  -79.513  52.928  1
45748  93.305  -79.507  52.920  1
45749  93.324  -79.501  52.913  1
45750  93.342  -79.494  52.908  1
45751  93.360  -79.488  52.904  1
45752  93.380  -79.482  52.898  1
45753  93.401  -79.477  52.892  1
45754  93.422  -79.471  52.883  1
45755  93.444  -79.465  52.874  1
45756  93.462  -79.461  52.864  1
45757  93.477  -79.458  52.855  1
45758  93.493  -79.454  52.845  1
45759  93.509  -79.451  52.835  1
45760  93.521  -79.447  52.825  1
45761  93.532  -79.443  52.815  1
45762  93.541  -79.438  52.805  1
45763  93.552  -79.434  52.793  1
45764  93.568  -79.429  52.781  1
45765  93.585  -79.426  52.770  1
45766  93.601  -79.421  52.760  1
45767  93.614  -79.416  52.749  1
45768  93.627  -79.411  52.740  1
45769  93.640  -79.407  52.732  1
45770  93.653  -79.401  52.723  1
45771  93.666  -79.397  52.715  1
45772  93.681  -79.386  52.707  1
45773  93.695  -79.376  52.700  1
45774  93.708  -79.363  52.692  1
45775  93.720  -79.347  52.685  1
45776  93.731  -79.332  52.680  1
45777  93.743  -79.316  52.675  1
45778  93.755  -79.300  52.672  1
45779  93.767  -79.285  52.670  1
45780  93.781  -79.285  52.667  1
45781  93.795  -79.284  52.665  1
45782  93.809  -79.284  52.662  1
45783  93.823  -79.283  52.658  1
45784  93.837  -79.282  52.653  1
45785  93.851  -79.281  52.647  1
45786  93.854  -79.284  52.640  1
45787  93.851  -79.287  52.632  1
45788  93.847  -79.291  52.623  1
45789  93.852  -79.288  52.612  1
45790  93.864  -79.283  52.600  1
45791  93.875  -79.278  52.590  1
45792  93.886  -79.272  52.579  1
45793  93.897  -79.267  52.567  1
45794  93.905  -79.266  52.555  1
45795  93.910  -79.267  52.541  1
45796  93.916  -79.269  52.526  1
45797  93.922  -79.270  52.510  1
45798  93.927  -79.271  52.494  1
45799  93.936  -79.270  52.478  1
45800  93.951  -79.269  52.461  1
45801  93.966  -79.268  52.443  1
45802  93.982  -79.266  52.424  1
45803  93.997  -79.265  52.407  1
45804  94.006  -79.266  52.389  1
45805  94.005  -79.268  52.371  1
45806  94.005  -79.270  52.352  1
45807  94.004  -79.273  52.333  1
45808  94.004  -79.275  52.313  1
45809  94.004  -79.278  52.295  1
45810  94.003  -79.281  52.278  1
45811  94.003  -79.283  52.260  1
45812  94.002  -79.285  52.243  1
45813  94.002  -79.288  52.226  1
45814  94.001  -79.291  52.211  1
45815  94.001  -79.293  52.196  1
45816  94.003  -79.292  52.180  1
45817  94.004  -79.288  52.163  1
45818  94.002  -79.278  52.143  1
45819  94.002  -79.266  52.126  1
45820  94.008  -79.254  52.111  1
45821  94.014  -79.241  52.098  1
45822  94.019  -79.229  52.088  1
45823  94.025  -79.217  52.079  1
45824  94.039  -79.219  52.072  1
45825  94.061  -79.233  52.062  1
45826  94.085  -79.246  52.052  1
45827  94.099  -79.247  52.042  1
45828  94.102  -79.242  52.029  1
45829  94.105  -79.237  52.017  1
45830  94.108  -79.231  52.004  1
45831  94.111  -79.226  51.990  1
45832  94.122  -79.225  51.972  1
45833  94.141  -79.226  51.953  1
45834  94.160  -79.228  51.933  1
45835  94.169  -79.236  51.913  1
45836  94.174  -79.247  51.893  1
45837  94.178  -79.259  51.874  1
45838  94.183  -79.269  51.855  1
45839  94.188  -79.277  51.835  1
45840  94.194  -79.273  51.814  1
45841  94.201  -79.269  51.795  1
45842  94.207  -79.266  51.775  1
45843  94.214  -79.263  51.756  1
45844  94.220  -79.259  51.738  1
45845  94.227  -79.256  51.719  1
45846  94.232  -79.253  51.700  1
45847  94.229  -79.263  51.679  1
45848  94.225  -79.272  51.658  1
45849  94.228  -79.263  51.637  1
45850  94.231  -79.249  51.617  1
45851  94.235  -79.236  51.597  1
45852  94.238  -79.222  51.573  1
45853  94.253  -79.199  51.546  1
45854  94.273  -79.169  51.517  1
45855  94.271  -79.226  51.484  1
45856  94.266  -79.234  51.451  1
45857  94.261  -79.228  51.419  1
45858  94.255  -79.224  51.387  1
45859  94.268  -79.212  51.352  1
45860  94.295  -79.195  51.314  1
45861  94.323  -79.178  51.273  1
45862  94.350  -79.162  51.233  1
45863  94.370  -79.150  51.192  1
45864  94.382  -79.147  51.150  1
45865  94.393  -79.143  51.110  1
45866  94.404  -79.140  51.069  1
45867  94.416  -79.136  51.028  1
45868  94.427  -79.132  50.985  1
45869  94.435  -79.138  50.945  1
45870  94.444  -79.146  50.906  1
45924  95.037  -79.714  48.978  1
45925  95.050  -79.727  48.941  1
45926  95.063  -79.740  48.904  1
45927  95.076  -79.753  48.867  1
45928  95.090  -79.767  48.830  1
45929  95.103  -79.780  48.793  1
45930  95.116  -79.792  48.756  1
45931  95.129  -79.805  48.718  1
45932  95.151  -79.808  48.682  1
45933  95.175  -79.810  48.645  1
45934  95.198  -79.811  48.608  1
45935  95.222  -79.813  48.571  1
45936  95.245  -79.814  48.537  1
45937  95.269  -79.816  48.501  1
45938  95.293  -79.817  48.465  1
45939  95.316  -79.819  48.429  1
45940  95.340  -79.820  48.393  1
45941  95.363  -79.822  48.358  1
45942  95.387  -79.823  48.324  1
46436  93.079  -79.617  53.115  1
46437  93.095  -79.609  53.096  1
46438  93.112  -79.601  53.078  1
46439  93.127  -79.592  53.061  1
46440  93.143  -79.585  53.045  1
46441  93.159  -79.576  53.030  1
46442  93.176  -79.569  53.016  1
46443  93.192  -79.560  53.002  1
46444  93.208  -79.551  52.990  1
46445  93.226  -79.538  52.978  1
46446  93.244  -79.524  52.966  1
46447  93.263  -79.510  52.955  1
46448  93.281  -79.498  52.946  1
46449  93.299  -79.491  52.938  1
46450  93.318  -79.485  52.931  1
46451  93.336  -79.479  52.927  1
46452  93.355  -79.473  52.922  1
46453  93.373  -79.467  52.916  1
46454  93.392  -79.461  52.909  1
46455  93.411  -79.455  52.901  1
46456  93.432  -79.449  52.893  1
46457  93.452  -79.444  52.885  1
46458  93.468  -79.441  52.875  1
46459  93.484  -79.438  52.865  1
46460  93.493  -79.433  52.854  1
46461  93.503  -79.429  52.843  1
46462  93.513  -79.424  52.832  1
46463  93.523  -79.419  52.820  1
46464  93.534  -79.415  52.807  1
46465  93.551  -79.411  52.795  1
46466  93.567  -79.407  52.784  1
46467  93.584  -79.402  52.773  1
46468  93.600  -79.398  52.761  1
46469  93.613  -79.393  52.752  1
46470  93.626  -79.388  52.743  1
46471  93.639  -79.383  52.734  1
46472  93.652  -79.376  52.725  1
46473  93.667  -79.366  52.717  1
46474  93.682  -79.357  52.710  1
46475  93.696  -79.345  52.704  1
46476  93.708  -79.329  52.699  1
46477  93.720  -79.314  52.694  1
46478  93.731  -79.298  52.688  1
46479  93.744  -79.285  52.683  1
46480  93.758  -79.285  52.678  1
46481  93.771  -79.284  52.674  1
46482  93.785  -79.283  52.671  1
46483  93.799  -79.282  52.667  1
46484  93.814  -79.282  52.663  1
46485  93.828  -79.281  52.657  1
46486  93.842  -79.281  52.651  1
46487  93.846  -79.282  52.644  1
46488  93.842  -79.286  52.636  1
46489  93.843  -79.287  52.627  1
46490  93.854  -79.281  52.616  1
46491  93.865  -79.276  52.605  1
46492  93.876  -79.270  52.595  1
46493  93.888  -79.265  52.584  1
46494  93.899  -79.259  52.573  1
46495  93.906  -79.259  52.560  1
46496  93.912  -79.260  52.547  1
46497  93.917  -79.262  52.532  1
46498  93.923  -79.263  52.517  1
46499  93.931  -79.263  52.500  1
46500  93.941  -79.261  52.482  1
46501  93.952  -79.260  52.464  1
46502  93.967  -79.259  52.446  1
46503  93.983  -79.257  52.429  1
46504  93.998  -79.256  52.412  1
46505  94.007  -79.256  52.394  1
46506  94.006  -79.259  52.375  1
46507  94.006  -79.261  52.356  1
46508  94.005  -79.264  52.335  1
46509  94.005  -79.266  52.316  1
46510  94.004  -79.269  52.299  1
46511  94.004  -79.272  52.283  1
46512  94.004  -79.274  52.266  1
46513  94.003  -79.276  52.248  1
46514  94.003  -79.279  52.230  1
46515  94.004  -79.279  52.213  1
46516  94.007  -79.278  52.197  1
46517  94.010  -79.277  52.182  1
46518  94.011  -79.273  52.167  1
46519  94.008  -79.263  52.149  1
46520  94.006  -79.253  52.133  1
46521  94.004  -79.243  52.119  1
46522  94.001  -79.232  52.107  1
46523  94.005  -79.221  52.097  1
46524  94.010  -79.208  52.089  1
46525  94.025  -79.210  52.085  1
46526  94.047  -79.220  52.076  1
46527  94.065  -79.225  52.066  1
46528  94.083  -79.230  52.056  1
46529  94.100  -79.234  52.043  1
46530  94.103  -79.228  52.031  1
46531  94.106  -79.223  52.017  1
46532  94.109  -79.218  52.002  1
46533  94.119  -79.216  51.983  1
46534  94.138  -79.217  51.963  1
46535  94.153  -79.222  51.942  1
46536  94.157  -79.232  51.920  1
46537  94.162  -79.244  51.899  1
46538  94.167  -79.255  51.877  1
46539  94.171  -79.266  51.857  1
46540  94.176  -79.278  51.835  1
46541  94.181  -79.281  51.815  1
46542  94.188  -79.278  51.796  1
46543  94.194  -79.274  51.778  1
46544  94.200  -79.271  51.761  1
46545  94.207  -79.267  51.742  1
46546  94.209  -79.270  51.724  1
46547  94.205  -79.280  51.705  1
46548  94.208  -79.268  51.685  1
46549  94.211  -79.255  51.664  1
46550  94.215  -79.241  51.643  1
46551  94.218  -79.228  51.622  1
46552  94.221  -79.215  51.601  1
46553  94.226  -79.200  51.576  1
46554  94.247  -79.170  51.550  1
46555  94.268  -79.140  51.522  1
46556  94.273  -79.171  51.491  1
46557  94.267  -79.230  51.460  1
46558  94.261  -79.225  51.429  1
46559  94.256  -79.220  51.396  1
46560  94.266  -79.209  51.359  1
46561  94.293  -79.193  51.320  1
46562  94.320  -79.176  51.280  1
46563  94.347  -79.159  51.240  1
46564  94.374  -79.142  51.199  1
46565  94.387  -79.137  51.159  1
46566  94.399  -79.134  51.119  1
46567  94.410  -79.130  51.079  1
46568  94.421  -79.127  51.038  1
46569  94.432  -79.123  50.996  1
46570  94.443  -79.119  50.957  1
46571  94.452  -79.125  50.917  1
46625  95.028  -79.675  48.981  1
46626  95.042  -79.688  48.944  1
46627  95.055  -79.701  48.908  1
46628  95.068  -79.714  48.871  1
46629  95.081  -79.727  48.834  1
46630  95.094  -79.740  48.796  1
46631  95.107  -79.753  48.759  1
46632  95.120  -79.766  48.722  1
46633  95.141  -79.770  48.685  1
46634  95.165  -79.772  48.648  1
46635  95.188  -79.773  48.612  1
46636  95.212  -79.775  48.575  1
46637  95.236  -79.776  48.540  1
46638  95.259  -79.778  48.504  1
46639  95.282  -79.780  48.467  1
46640  95.306  -79.781  48.432  1
46641  95.330  -79.783  48.396  1
46642  95.353  -79.784  48.361  1
46643  95.377  -79.786  48.326  1
46644  95.401  -79.787  48.291  1
46711  96.850  -79.882  46.251  1
46712  96.872  -79.886  46.227  1
46713  96.894  -79.891  46.203  1
47138  93.091  -79.592  53.120  1
47139  93.107  -79.584  53.102  1
47140  93.123  -79.576  53.084  1
47141  93.139  -79.567  53.067  1
47142  93.155  -79.560  53.052  1
47143  93.171  -79.551  53.038  1
47144  93.188  -79.544  53.024  1
47145  93.203  -79.535  53.010  1
47146  93.220  -79.525  52.998  1
47147  93.238  -79.511  52.987  1
47148  93.257  -79.498  52.976  1
47149  93.275  -79.484  52.966  1
47150  93.293  -79.476  52.957  1
47151  93.311  -79.469  52.951  1
47152  93.330  -79.463  52.946  1
47153  93.349  -79.457  52.941  1
47154  93.367  -79.451  52.935  1
47155  93.386  -79.445  52.928  1
47156  93.404  -79.439  52.921  1
47157  93.423  -79.433  52.914  1
47158  93.442  -79.427  52.907  1
47159  93.455  -79.423  52.897  1
47160  93.465  -79.419  52.887  1
47161  93.475  -79.414  52.876  1
47162  93.485  -79.410  52.864  1
47163  93.495  -79.405  52.852  1
47164  93.504  -79.400  52.840  1
47165  93.516  -79.396  52.827  1
47166  93.533  -79.392  52.814  1
47167  93.549  -79.388  52.801  1
47168  93.566  -79.384  52.789  1
47169  93.582  -79.379  52.777  1
47170  93.599  -79.375  52.766  1
47171  93.612  -79.370  52.757  1
47172  93.625  -79.366  52.746  1
47173  93.639  -79.357  52.739  1
47174  93.654  -79.347  52.734  1
47175  93.669  -79.337  52.729  1
47176  93.684  -79.326  52.722  1
47177  93.696  -79.312  52.716  1
47178  93.708  -79.296  52.710  1
47179  93.720  -79.285  52.704  1
47180  93.734  -79.284  52.698  1
47181  93.748  -79.284  52.692  1
47182  93.762  -79.283  52.686  1
47183  93.776  -79.282  52.680  1
47184  93.790  -79.281  52.675  1
47185  93.804  -79.281  52.670  1
47186  93.819  -79.280  52.663  1
47187  93.833  -79.280  52.656  1
47188  93.837  -79.281  52.649  1
47189  93.834  -79.285  52.642  1
47190  93.845  -79.279  52.632  1
47191  93.856  -79.274  52.622  1
47192  93.867  -79.269  52.612  1
47193  93.878  -79.263  52.601  1
47194  93.889  -79.258  52.590  1
47195  93.900  -79.253  52.579  1
47196  93.907  -79.252  52.566  1
47197  93.913  -79.253  52.553  1
47198  93.919  -79.254  52.538  1
47199  93.927  -79.254  52.523  1
47200  93.936  -79.253  52.506  1
47201  93.946  -79.252  52.488  1
47202  93.956  -79.250  52.469  1
47203  93.968  -79.250  52.452  1
47204  93.984  -79.248  52.436  1
47205  93.999  -79.247  52.420  1
47206  94.007  -79.247  52.402  1
47207  94.007  -79.250  52.383  1
47208  94.006  -79.253  52.362  1
47209  94.006  -79.255  52.341  1
47210  94.006  -79.257  52.322  1
47211  94.005  -79.260  52.304  1
47212  94.005  -79.263  52.288  1
47213  94.004  -79.265  52.272  1
47214  94.005  -79.266  52.253  1
47215  94.008  -79.264  52.235  1
47216  94.011  -79.263  52.217  1
47217  94.013  -79.263  52.201  1
47218  94.016  -79.261  52.187  1
47219  94.018  -79.259  52.172  1
47220  94.015  -79.249  52.155  1
47221  94.013  -79.238  52.140  1
47222  94.010  -79.228  52.126  1
47223  94.008  -79.218  52.116  1
47224  94.006  -79.208  52.108  1
47225  94.003  -79.199  52.101  1
47226  94.008  -79.195  52.096  1
47227  94.026  -79.200  52.087  1
47228  94.044  -79.204  52.078  1
47229  94.062  -79.209  52.068  1
47230  94.080  -79.213  52.056  1
47231  94.099  -79.219  52.042  1
47232  94.105  -79.215  52.028  1
47233  94.107  -79.209  52.012  1
47234  94.116  -79.206  51.993  1
47235  94.134  -79.208  51.972  1
47236  94.141  -79.218  51.951  1
47237  94.145  -79.229  51.927  1
47238  94.150  -79.241  51.904  1
47239  94.154  -79.252  51.881  1
47240  94.159  -79.263  51.858  1
47241  94.164  -79.275  51.837  1
47242  94.168  -79.286  51.817  1
47243  94.174  -79.286  51.799  1
47244  94.181  -79.282  51.783  1
47245  94.187  -79.279  51.766  1
47246  94.185  -79.287  51.748  1
47247  94.188  -79.274  51.731  1
47248  94.192  -79.260  51.711  1
47249  94.195  -79.247  51.691  1
47250  94.198  -79.234  51.670  1
47251  94.202  -79.221  51.649  1
47252  94.205  -79.207  51.627  1
47253  94.208  -79.194  51.605  1
47254  94.221  -79.172  51.580  1
47255  94.242  -79.142  51.554  1
47256  94.262  -79.112  51.526  1
47257  94.274  -79.116  51.497  1
47258  94.268  -79.190  51.468  1
47259  94.262  -79.221  51.438  1
47260  94.257  -79.216  51.405  1
47261  94.263  -79.206  51.367  1
47262  94.290  -79.190  51.327  1
47263  94.318  -79.173  51.287  1
47264  94.345  -79.156  51.248  1
47265  94.372  -79.140  51.208  1
47266  94.393  -79.128  51.168  1
47267  94.404  -79.125  51.129  1
47268  94.415  -79.121  51.089  1
47269  94.426  -79.118  51.049  1
47270  94.437  -79.114  51.008  1
47271  94.449  -79.110  50.968  1
47272  94.460  -79.106  50.929  1
47326  95.020  -79.636  48.985  1
47327  95.033  -79.648  48.948  1
47328  95.046  -79.662  48.912  1
47329  95.059  -79.675  48.875  1
47330  95.072  -79.688  48.837  1
47331  95.086  -79.701  48.800  1
47332  95.099  -79.714  48.762  1
47333  95.112  -79.726  48.725  1
47334  95.131  -79.733  48.689  1
47335  95.155  -79.734  48.652  1
47336  95.179  -79.736  48.615  1
47337  95.202  -79.737  48.579  1
47338  95.226  -79.739  48.542  1
47339  95.249  -79.740  48.506  1
47340  95.273  -79.742  48.471  1
47341  95.297  -79.743  48.435  1
47342  95.320  -79.745  48.399  1
47343  95.343  -79.746  48.364  1
47344  95.367  -79.748  48.329  1
47345  95.391  -79.749  48.294  1
47346  95.414  -79.751  48.259  1
47411  96.823  -79.859  46.274  1
47412  96.846  -79.864  46.251  1
47413  96.868  -79.868  46.227  1
47414  96.891  -79.874  46.202  1
47415  96.913  -79.878  46.177  1
47416  96.936  -79.883  46.153  1
47417  96.958  -79.887  46.128  1
47418  96.997  -79.887  46.105  1
47419  97.043  -79.884  46.081  1
47420  97.089  -79.882  46.058  1
47421  97.135  -79.880  46.035  1
47840  93.104  -79.569  53.126  1
47841  93.119  -79.559  53.108  1
47842  93.135  -79.551  53.091  1
47843  93.151  -79.542  53.076  1
47844  93.167  -79.535  53.061  1
47845  93.183  -79.526  53.047  1
47846  93.199  -79.519  53.034  1
47847  93.215  -79.510  53.021  1
47848  93.233  -79.499  53.009  1
47849  93.251  -79.485  52.998  1
47850  93.269  -79.471  52.989  1
47851  93.287  -79.460  52.980  1
47852  93.306  -79.454  52.972  1
47853  93.324  -79.448  52.966  1
47854  93.343  -79.442  52.960  1
47855  93.361  -79.436  52.955  1
47856  93.380  -79.430  52.950  1
47857  93.398  -79.424  52.943  1
47858  93.417  -79.418  52.937  1
47859  93.434  -79.412  52.931  1
47860  93.443  -79.407  52.921  1
47861  93.451  -79.402  52.911  1
47862  93.460  -79.397  52.899  1
47863  93.468  -79.391  52.887  1
47864  93.476  -79.386  52.875  1
47865  93.486  -79.382  52.862  1
47866  93.498  -79.377  52.849  1
47867  93.515  -79.373  52.836  1
47868  93.532  -79.369  52.822  1
47869  93.548  -79.365  52.808  1
47870  93.565  -79.360  52.795  1
47871  93.581  -79.357  52.784  1
47872  93.598  -79.352  52.774  1
47873  93.612  -79.347  52.764  1
47874  93.626  -79.337  52.758  1
47875  93.641  -79.327  52.753  1
47876  93.656  -79.316  52.749  1
47877  93.671  -79.306  52.742  1
47878  93.684  -79.294  52.736  1
47879  93.697  -79.285  52.729  1
47880  93.711  -79.284  52.722  1
47881  93.725  -79.283  52.715  1
47882  93.739  -79.282  52.707  1
47883  93.753  -79.281  52.699  1
47884  93.767  -79.281  52.692  1
47885  93.781  -79.281  52.685  1
47886  93.795  -79.280  52.679  1
47887  93.809  -79.279  52.672  1
47888  93.823  -79.278  52.665  1
47889  93.829  -79.280  52.657  1
47890  93.835  -79.278  52.649  1
47891  93.846  -79.272  52.641  1
47892  93.857  -79.267  52.631  1
47893  93.868  -79.262  52.621  1
47894  93.880  -79.256  52.610  1
47895  93.891  -79.250  52.598  1
47896  93.902  -79.245  52.586  1
47897  93.909  -79.245  52.573  1
47898  93.915  -79.246  52.559  1
47899  93.922  -79.247  52.545  1
47900  93.931  -79.245  52.531  1
47901  93.941  -79.244  52.514  1
47902  93.951  -79.243  52.495  1
47903  93.961  -79.241  52.476  1
47904  93.971  -79.241  52.460  1
47905  93.985  -79.239  52.445  1
47906  94.000  -79.237  52.429  1
47907  94.008  -79.238  52.411  1
47908  94.008  -79.241  52.391  1
47909  94.007  -79.244  52.370  1
47910  94.007  -79.246  52.348  1
47911  94.006  -79.248  52.328  1
47912  94.006  -79.251  52.309  1
47913  94.006  -79.252  52.294  1
47914  94.009  -79.251  52.277  1
47915  94.012  -79.250  52.259  1
47916  94.014  -79.249  52.240  1
47917  94.017  -79.248  52.223  1
47918  94.019  -79.247  52.208  1
47919  94.023  -79.246  52.194  1
47920  94.025  -79.244  52.180  1
47921  94.023  -79.234  52.165  1
47922  94.019  -79.228  52.150  1
47923  94.015  -79.220  52.137  1
47924  94.012  -79.213  52.127  1
47925  94.009  -79.206  52.119  1
47926  94.005  -79.200  52.112  1
47927  94.010  -79.195  52.106  1
47928  94.022  -79.194  52.097  1
47929  94.034  -79.194  52.088  1
47930  94.046  -79.192  52.079  1
47931  94.060  -79.193  52.067  1
47932  94.077  -79.197  52.054  1
47933  94.096  -79.202  52.040  1
47934  94.106  -79.201  52.023  1
47935  94.112  -79.197  52.003  1
47936  94.125  -79.203  51.980  1
47937  94.129  -79.215  51.956  1
47938  94.134  -79.226  51.932  1
47939  94.138  -79.237  51.908  1
47940  94.143  -79.249  51.883  1
47941  94.147  -79.260  51.861  1
47942  94.152  -79.272  51.840  1
47943  94.156  -79.282  51.821  1
47944  94.161  -79.294  51.804  1
47945  94.165  -79.293  51.788  1
47946  94.169  -79.279  51.772  1
47947  94.172  -79.266  51.756  1
47948  94.175  -79.253  51.738  1
47949  94.179  -79.240  51.719  1
47950  94.182  -79.226  51.698  1
47951  94.185  -79.213  51.677  1
47952  94.189  -79.200  51.655  1
47953  94.192  -79.187  51.632  1
47954  94.195  -79.173  51.609  1
47955  94.216  -79.143  51.583  1
47956  94.237  -79.114  51.557  1
47957  94.253  -79.093  51.530  1
47958  94.267  -79.089  51.503  1
47959  94.269  -79.136  51.475  1
47960  94.263  -79.210  51.446  1
47961  94.258  -79.212  51.413  1
47962  94.261  -79.204  51.374  1
47963  94.288  -79.187  51.334  1
47964  94.316  -79.170  51.295  1
47965  94.343  -79.153  51.256  1
47966  94.370  -79.137  51.217  1
47967  94.397  -79.120  51.178  1
47968  94.409  -79.115  51.138  1
47969  94.420  -79.112  51.099  1
47970  94.432  -79.109  51.060  1
47971  94.443  -79.105  51.020  1
47972  94.454  -79.101  50.979  1
47973  94.466  -79.097  50.940  1
48027  95.012  -79.596  48.990  1
48028  95.025  -79.610  48.952  1
48029  95.038  -79.623  48.915  1
48030  95.051  -79.636  48.879  1
48031  95.064  -79.648  48.841  1
48032  95.077  -79.661  48.804  1
48033  95.091  -79.674  48.767  1
48034  95.104  -79.687  48.731  1
48035  95.122  -79.695  48.694  1
48036  95.145  -79.696  48.657  1
48037  95.169  -79.698  48.620  1
48038  95.192  -79.699  48.583  1
48039  95.216  -79.701  48.547  1
48040  95.240  -79.702  48.511  1
48041  95.263  -79.704  48.475  1
48042  95.286  -79.705  48.440  1
48043  95.310  -79.707  48.403  1
48044  95.334  -79.708  48.367  1
48045  95.357  -79.710  48.332  1
48046  95.381  -79.711  48.297  1
48047  95.404  -79.713  48.262  1
48069  95.851  -79.581  47.504  1
48070  95.874  -79.594  47.472  1
48071  95.896  -79.607  47.440  1
48072  95.919  -79.620  47.409  1
48073  95.942  -79.633  47.376  1
48074  95.965  -79.646  47.345  1
48075  95.988  -79.659  47.313  1
48076  96.011  -79.673  47.281  1
48077  96.033  -79.679  47.251  1
48111  96.797  -79.836  46.298  1
48112  96.820  -79.841  46.273  1
48113  96.842  -79.846  46.250  1
48114  96.865  -79.851  46.226  1
48115  96.887  -79.855  46.202  1
48116  96.910  -79.860  46.177  1
48117  96.932  -79.864  46.152  1
48118  96.955  -79.869  46.128  1
48119  96.993  -79.869  46.105  1
48120  97.039  -79.866  46.081  1
48121  97.086  -79.864  46.058  1
48122  97.133  -79.861  46.035  1
48123  97.132  -79.873  46.013  1
48124  97.131  -79.884  45.989  1
48125  97.131  -79.897  45.965  1
48126  97.134  -79.926  45.941  1
48127  97.138  -79.954  45.920  1
48542  93.117  -79.546  53.133  1
48543  93.131  -79.534  53.115  1
48544  93.147  -79.526  53.100  1
48545  93.163  -79.518  53.085  1
48546  93.179  -79.510  53.071  1
48547  93.195  -79.501  53.058  1
48548  93.211  -79.494  53.045  1
48549  93.227  -79.485  53.033  1
48550  93.245  -79.473  53.022  1
48551  93.263  -79.459  53.012  1
48552  93.281  -79.445  53.003  1
48553  93.300  -79.438  52.995  1
48554  93.319  -79.432  52.988  1
48555  93.337  -79.426  52.983  1
48556  93.355  -79.420  52.979  1
48557  93.374  -79.414  52.972  1
48558  93.393  -79.408  52.966  1
48559  93.411  -79.402  52.959  1
48560  93.426  -79.397  52.951  1
48561  93.437  -79.392  52.941  1
48562  93.445  -79.387  52.930  1
48563  93.453  -79.382  52.919  1
48564  93.462  -79.377  52.909  1
48565  93.470  -79.372  52.897  1
48566  93.478  -79.366  52.885  1
48567  93.489  -79.361  52.872  1
48568  93.505  -79.357  52.860  1
48569  93.521  -79.352  52.846  1
48570  93.538  -79.347  52.831  1
48571  93.554  -79.344  52.817  1
48572  93.570  -79.339  52.804  1
48573  93.586  -79.335  52.794  1
48574  93.602  -79.329  52.786  1
48575  93.617  -79.319  52.779  1
48576  93.631  -79.309  52.774  1
48577  93.646  -79.298  52.770  1
48578  93.660  -79.288  52.763  1
48579  93.675  -79.280  52.756  1
48580  93.689  -79.279  52.749  1
48581  93.702  -79.279  52.740  1
48582  93.716  -79.279  52.732  1
48583  93.730  -79.279  52.724  1
48584  93.744  -79.279  52.715  1
48585  93.758  -79.279  52.707  1
48586  93.772  -79.279  52.699  1
48587  93.786  -79.279  52.692  1
48588  93.800  -79.278  52.685  1
48589  93.814  -79.278  52.677  1
48590  93.826  -79.275  52.669  1
48591  93.837  -79.270  52.661  1
48592  93.848  -79.265  52.652  1
48593  93.859  -79.259  52.643  1
48594  93.870  -79.254  52.633  1
48595  93.881  -79.249  52.622  1
48596  93.892  -79.244  52.610  1
48597  93.903  -79.238  52.598  1
48598  93.910  -79.237  52.585  1
48599  93.917  -79.238  52.571  1
48600  93.927  -79.237  52.557  1
48601  93.936  -79.236  52.541  1
48602  93.946  -79.234  52.523  1
48603  93.956  -79.234  52.504  1
48604  93.966  -79.232  52.485  1
48605  93.975  -79.231  52.471  1
48606  93.986  -79.230  52.455  1
48607  94.001  -79.228  52.437  1
48608  94.009  -79.229  52.419  1
48609  94.008  -79.232  52.398  1
48610  94.008  -79.234  52.377  1
48611  94.007  -79.237  52.354  1
48612  94.007  -79.239  52.333  1
48613  94.010  -79.237  52.314  1
48614  94.013  -79.237  52.297  1
48615  94.015  -79.235  52.281  1
48616  94.018  -79.234  52.264  1
48617  94.020  -79.234  52.246  1
48618  94.023  -79.232  52.230  1
48619  94.023  -79.232  52.217  1
48620  94.023  -79.231  52.204  1
48621  94.023  -79.231  52.191  1
48622  94.025  -79.234  52.176  1
48623  94.021  -79.228  52.162  1
48624  94.018  -79.221  52.149  1
48625  94.014  -79.214  52.139  1
48626  94.011  -79.206  52.131  1
48627  94.007  -79.200  52.124  1
48628  94.011  -79.196  52.118  1
48629  94.024  -79.194  52.109  1
48630  94.036  -79.194  52.100  1
48631  94.048  -79.192  52.091  1
48632  94.059  -79.191  52.079  1
48633  94.071  -79.190  52.066  1
48634  94.083  -79.189  52.051  1
48635  94.096  -79.188  52.034  1
48636  94.109  -79.189  52.012  1
48637  94.113  -79.200  51.989  1
48638  94.118  -79.212  51.963  1
48639  94.123  -79.223  51.938  1
48640  94.128  -79.234  51.913  1
48641  94.133  -79.247  51.889  1
48642  94.138  -79.258  51.867  1
48643  94.143  -79.269  51.846  1
48644  94.148  -79.281  51.827  1
48645  94.150  -79.289  51.810  1
48646  94.148  -79.288  51.795  1
48647  94.151  -79.273  51.780  1
48648  94.155  -79.257  51.764  1
48649  94.159  -79.241  51.746  1
48650  94.164  -79.225  51.727  1
48651  94.168  -79.209  51.705  1
48652  94.172  -79.194  51.683  1
48653  94.176  -79.179  51.661  1
48654  94.179  -79.165  51.638  1
48655  94.189  -79.146  51.614  1
48656  94.204  -79.131  51.587  1
48657  94.219  -79.115  51.561  1
48658  94.234  -79.100  51.534  1
48659  94.247  -79.100  51.510  1
48660  94.259  -79.118  51.483  1
48661  94.265  -79.156  51.454  1
48662  94.258  -79.208  51.420  1
48663  94.259  -79.201  51.382  1
48664  94.286  -79.184  51.342  1
48665  94.313  -79.168  51.302  1
48666  94.340  -79.151  51.264  1
48667  94.367  -79.134  51.225  1
48668  94.395  -79.117  51.186  1
48669  94.415  -79.106  51.148  1
48670  94.426  -79.103  51.110  1
48671  94.437  -79.100  51.071  1
48672  94.449  -79.096  51.031  1
48673  94.460  -79.092  50.991  1
48674  94.471  -79.088  50.953  1
48728  95.003  -79.557  48.994  1
48729  95.016  -79.570  48.956  1
48730  95.030  -79.583  48.920  1
48731  95.043  -79.596  48.883  1
48732  95.056  -79.609  48.846  1
48733  95.069  -79.622  48.808  1
48734  95.082  -79.635  48.772  1
48735  95.095  -79.648  48.736  1
48736  95.112  -79.657  48.699  1
48737  95.135  -79.659  48.662  1
48738  95.159  -79.661  48.626  1
48739  95.183  -79.662  48.589  1
48740  95.206  -79.664  48.552  1
48741  95.230  -79.664  48.516  1
48742  95.253  -79.666  48.480  1
48743  95.277  -79.667  48.444  1
48744  95.301  -79.669  48.408  1
48745  95.324  -79.670  48.372  1
48746  95.347  -79.672  48.337  1
48747  95.371  -79.673  48.301  1
48748  95.395  -79.675  48.265  1
48749  95.418  -79.676  48.230  1
48758  95.630  -79.690  47.913  1
48759  95.654  -79.692  47.879  1
48760  95.678  -79.693  47.845  1
48761  95.693  -79.673  47.810  1
48762  95.708  -79.651  47.776  1
48763  95.723  -79.630  47.742  1
48764  95.738  -79.609  47.709  1
48765  95.753  -79.588  47.675  1
48766  95.768  -79.566  47.641  1
48767  95.783  -79.545  47.608  1
48768  95.802  -79.540  47.575  1
48769  95.824  -79.553  47.542  1
48770  95.847  -79.566  47.509  1
48771  95.870  -79.579  47.477  1
48772  95.893  -79.592  47.445  1
48773  95.916  -79.605  47.413  1
48774  95.939  -79.618  47.380  1
48775  95.961  -79.631  47.348  1
48776  95.984  -79.645  47.317  1
48777  96.007  -79.656  47.285  1
48778  96.030  -79.661  47.254  1
48779  96.052  -79.665  47.224  1
48811  96.771  -79.814  46.324  1
48812  96.794  -79.818  46.298  1
48813  96.816  -79.823  46.273  1
48814  96.839  -79.828  46.250  1
48815  96.861  -79.833  46.226  1
48816  96.884  -79.837  46.201  1
48817  96.906  -79.842  46.177  1
48818  96.929  -79.846  46.152  1
48819  96.951  -79.851  46.128  1
48820  96.990  -79.851  46.104  1
48821  97.036  -79.849  46.081  1
48822  97.083  -79.845  46.058  1
48823  97.129  -79.843  46.035  1
48824  97.130  -79.854  46.013  1
48825  97.129  -79.865  45.989  1
48826  97.128  -79.877  45.965  1
48827  97.132  -79.906  45.942  1
48828  97.135  -79.935  45.920  1
48829  97.139  -79.964  45.899  1
49244  93.130  -79.523  53.141  1
49245  93.144  -79.511  53.125  1
49246  93.159  -79.501  53.110  1
49247  93.175  -79.493  53.096  1
49248  93.191  -79.485  53.083  1
49249  93.207  -79.476  53.071  1
49250  93.223  -79.469  53.059  1
49251  93.239  -79.460  53.046  1
49252  93.258  -79.447  53.036  1
49253  93.276  -79.432  53.027  1
49254  93.294  -79.423  53.018  1
49255  93.312  -79.417  53.012  1
49256  93.331  -79.411  53.007  1
49257  93.349  -79.405  53.002  1
49258  93.368  -79.399  52.994  1
49259  93.386  -79.393  52.987  1
49260  93.404  -79.387  52.979  1
49261  93.419  -79.382  52.970  1
49262  93.431  -79.378  52.959  1
49263  93.439  -79.372  52.949  1
49264  93.447  -79.367  52.938  1
49265  93.455  -79.362  52.927  1
49266  93.463  -79.357  52.916  1
49267  93.471  -79.352  52.904  1
49268  93.485  -79.346  52.891  1
49269  93.500  -79.341  52.878  1
49270  93.516  -79.337  52.864  1
49271  93.532  -79.332  52.849  1
49272  93.548  -79.328  52.836  1
49273  93.564  -79.323  52.826  1
49274  93.581  -79.319  52.817  1
49275  93.596  -79.314  52.810  1
49276  93.611  -79.304  52.802  1
49277  93.626  -79.294  52.796  1
49278  93.640  -79.284  52.790  1
49279  93.655  -79.273  52.784  1
49280  93.669  -79.267  52.777  1
49281  93.683  -79.263  52.769  1
49282  93.697  -79.263  52.759  1
49283  93.711  -79.263  52.750  1
49284  93.725  -79.263  52.741  1
49285  93.739  -79.263  52.733  1
49286  93.753  -79.263  52.724  1
49287  93.767  -79.263  52.716  1
49288  93.780  -79.263  52.707  1
49289  93.794  -79.263  52.700  1
49290  93.807  -79.264  52.692  1
49291  93.820  -79.263  52.684  1
49292  93.833  -79.259  52.675  1
49293  93.846  -79.256  52.666  1
49294  93.859  -79.252  52.657  1
49295  93.871  -79.247  52.647  1
49296  93.883  -79.241  52.636  1
49297  93.894  -79.236  52.625  1
49298  93.905  -79.231  52.613  1
49299  93.912  -79.231  52.599  1
49300  93.922  -79.229  52.585  1
49301  93.932  -79.228  52.569  1
49302  93.941  -79.227  52.552  1
49303  93.951  -79.225  52.534  1
49304  93.961  -79.225  52.515  1
49305  93.971  -79.223  52.498  1
49306  93.980  -79.222  52.483  1
49307  93.990  -79.221  52.467  1
49308  94.002  -79.219  52.449  1
49309  94.009  -79.220  52.429  1
49310  94.009  -79.223  52.408  1
49311  94.009  -79.225  52.386  1
49312  94.011  -79.225  52.364  1
49313  94.014  -79.223  52.344  1
49314  94.016  -79.222  52.324  1
49315  94.017  -79.222  52.307  1
49316  94.017  -79.221  52.290  1
49317  94.017  -79.220  52.274  1
49318  94.017  -79.220  52.258  1
49319  94.017  -79.219  52.243  1
49320  94.017  -79.219  52.229  1
49321  94.017  -79.219  52.216  1
49322  94.017  -79.218  52.203  1
49323  94.019  -79.222  52.189  1
49324  94.024  -79.228  52.176  1
49325  94.020  -79.221  52.164  1
49326  94.017  -79.214  52.155  1
49327  94.013  -79.207  52.147  1
49328  94.010  -79.200  52.139  1
49329  94.013  -79.196  52.131  1
49330  94.025  -79.194  52.123  1
49331  94.037  -79.194  52.113  1
49332  94.049  -79.193  52.102  1
49333  94.061  -79.191  52.091  1
49334  94.073  -79.190  52.077  1
49335  94.085  -79.189  52.062  1
49336  94.094  -79.187  52.044  1
49337  94.100  -79.188  52.022  1
49338  94.107  -79.200  51.998  1
49339  94.112  -79.211  51.971  1
49340  94.117  -79.223  51.945  1
49341  94.122  -79.234  51.919  1
49342  94.127  -79.246  51.896  1
49343  94.132  -79.257  51.875  1
49344  94.137  -79.269  51.855  1
49345  94.138  -79.276  51.835  1
49346  94.138  -79.282  51.818  1
49347  94.136  -79.280  51.803  1
49348  94.133  -79.277  51.788  1
49349  94.135  -79.265  51.772  1
49350  94.139  -79.249  51.754  1
49351  94.143  -79.233  51.734  1
49352  94.147  -79.217  51.711  1
49353  94.151  -79.201  51.689  1
49354  94.155  -79.184  51.666  1
49355  94.160  -79.169  51.642  1
49356  94.170  -79.152  51.618  1
49357  94.185  -79.137  51.591  1
49358  94.199  -79.121  51.565  1
49359  94.214  -79.106  51.539  1
49360  94.227  -79.112  51.515  1
49361  94.239  -79.130  51.489  1
49362  94.251  -79.147  51.460  1
49363  94.260  -79.175  51.427  1
49364  94.256  -79.198  51.390  1
49365  94.283  -79.181  51.351  1
49366  94.311  -79.165  51.311  1
49367  94.338  -79.148  51.273  1
49368  94.365  -79.131  51.235  1
49369  94.393  -79.115  51.197  1
49370  94.420  -79.097  51.159  1
49371  94.431  -79.093  51.121  1
49372  94.442  -79.090  51.083  1
49373  94.454  -79.087  51.043  1
49374  94.465  -79.083  51.004  1
49375  94.476  -79.079  50.966  1
49376  94.488  -79.075  50.928  1
49429  94.995  -79.518  48.999  1
49430  95.008  -79.531  48.961  1
49431  95.021  -79.544  48.924  1
49432  95.034  -79.557  48.887  1
49433  95.047  -79.570  48.850  1
49434  95.060  -79.582  48.814  1
49435  95.073  -79.596  48.777  1
49436  95.087  -79.609  48.741  1
49437  95.102  -79.620  48.704  1
49438  95.126  -79.621  48.668  1
49439  95.149  -79.623  48.632  1
49440  95.173  -79.624  48.596  1
49441  95.196  -79.626  48.559  1
49442  95.220  -79.627  48.522  1
49443  95.244  -79.629  48.486  1
49444  95.267  -79.630  48.449  1
49445  95.290  -79.632  48.413  1
49446  95.314  -79.633  48.377  1
49447  95.338  -79.634  48.341  1
49448  95.361  -79.636  48.305  1
49449  95.385  -79.637  48.269  1
49450  95.408  -79.639  48.234  1
49451  95.432  -79.640  48.199  1
49452  95.456  -79.642  48.164  1
49453  95.479  -79.643  48.129  1
49454  95.503  -79.645  48.093  1
49455  95.526  -79.646  48.057  1
49456  95.550  -79.648  48.022  1
49457  95.573  -79.649  47.987  1
49458  95.597  -79.651  47.952  1
49459  95.621  -79.652  47.918  1
49460  95.644  -79.654  47.883  1
49461  95.668  -79.655  47.849  1
49462  95.686  -79.642  47.815  1
49463  95.701  -79.621  47.781  1
49464  95.716  -79.600  47.748  1
49465  95.731  -79.579  47.714  1
49466  95.746  -79.557  47.680  1
49467  95.761  -79.536  47.647  1
49468  95.776  -79.515  47.614  1
49469  95.798  -79.525  47.580  1
49470  95.821  -79.538  47.547  1
49471  95.844  -79.551  47.514  1
49472  95.867  -79.564  47.481  1
49473  95.890  -79.577  47.450  1
49474  95.912  -79.590  47.418  1
49475  95.935  -79.603  47.385  1
49476  95.958  -79.617  47.353  1
49477  95.981  -79.629  47.321  1
49478  96.004  -79.638  47.289  1
49479  96.026  -79.643  47.258  1
49480  96.048  -79.648  47.228  1
49511  96.745  -79.791  46.349  1
49512  96.768  -79.796  46.323  1
49513  96.790  -79.801  46.297  1
49514  96.813  -79.805  46.273  1
49515  96.835  -79.810  46.249  1
49516  96.858  -79.814  46.225  1
49517  96.880  -79.819  46.201  1
49518  96.902  -79.823  46.177  1
49519  96.925  -79.828  46.152  1
49520  96.948  -79.833  46.128  1
49521  96.986  -79.833  46.104  1
49522  97.033  -79.830  46.081  1
49523  97.079  -79.827  46.058  1
49524  97.125  -79.825  46.035  1
49525  97.127  -79.836  46.013  1
49526  97.126  -79.847  45.989  1
49527  97.125  -79.858  45.965  1
49528  97.129  -79.887  45.943  1
49529  97.133  -79.915  45.921  1
49530  97.136  -79.944  45.899  1
49531  97.140  -79.973  45.878  1
49532  97.143  -80.002  45.855  1
49945  93.129  -79.513  53.166  1
49946  93.143  -79.501  53.151  1
49947  93.157  -79.489  53.137  1
49948  93.171  -79.477  53.122  1
49949  93.187  -79.468  53.108  1
49950  93.203  -79.460  53.096  1
49951  93.219  -79.451  53.084  1
49952  93.235  -79.444  53.072  1
49953  93.252  -79.434  53.061  1
49954  93.270  -79.420  53.052  1
49955  93.288  -79.407  53.042  1
49956  93.306  -79.401  53.036  1
49957  93.325  -79.395  53.029  1
49958  93.344  -79.389  53.022  1
49959  93.362  -79.383  53.015  1
49960  93.380  -79.377  53.007  1
49961  93.396  -79.372  52.998  1
49962  93.411  -79.368  52.988  1
49963  93.424  -79.363  52.977  1
49964  93.432  -79.358  52.966  1
49965  93.440  -79.353  52.955  1
49966  93.448  -79.347  52.944  1
49967  93.457  -79.342  52.933  1
49968  93.466  -79.337  52.921  1
49969  93.481  -79.332  52.908  1
49970  93.495  -79.326  52.894  1
49971  93.510  -79.321  52.880  1
49972  93.526  -79.316  52.867  1
49973  93.543  -79.313  52.855  1
49974  93.559  -79.308  52.846  1
49975  93.575  -79.303  52.838  1
49976  93.591  -79.300  52.832  1
49977  93.606  -79.289  52.824  1
49978  93.621  -79.279  52.816  1
49979  93.635  -79.269  52.810  1
49980  93.649  -79.259  52.804  1
49981  93.663  -79.254  52.796  1
49982  93.678  -79.249  52.787  1
49983  93.692  -79.246  52.778  1
49984  93.706  -79.246  52.769  1
49985  93.719  -79.246  52.760  1
49986  93.733  -79.246  52.751  1
49987  93.747  -79.246  52.743  1
49988  93.761  -79.246  52.735  1
49989  93.775  -79.246  52.726  1
49990  93.789  -79.246  52.718  1
49991  93.799  -79.253  52.709  1
49992  93.813  -79.250  52.701  1
49993  93.826  -79.246  52.692  1
49994  93.839  -79.242  52.683  1
49995  93.852  -79.238  52.674  1
49996  93.865  -79.234  52.664  1
49997  93.878  -79.230  52.654  1
49998  93.892  -79.226  52.643  1
49999  93.905  -79.222  52.631  1
50000  93.915  -79.221  52.616  1
50001  93.925  -79.220  52.600  1
50002  93.936  -79.219  52.582  1
50003  93.946  -79.218  52.565  1
50004  93.956  -79.216  52.547  1
50005  93.966  -79.216  52.529  1
50006  93.975  -79.214  52.513  1
50007  93.985  -79.213  52.497  1
50008  93.995  -79.212  52.481  1
50009  94.004  -79.210  52.464  1
50010  94.010  -79.211  52.442  1
50011  94.012  -79.211  52.421  1
50012  94.013  -79.210  52.399  1
50013  94.013  -79.210  52.377  1
50014  94.013  -79.209  52.357  1
50015  94.013  -79.209  52.338  1
50016  94.013  -79.208  52.320  1
50017  94.013  -79.208  52.303  1
50018  94.013  -79.207  52.287  1
50019  94.013  -79.206  52.272  1
50020  94.012  -79.206  52.258  1
50021  94.012  -79.206  52.245  1
50022  94.012  -79.205  52.232  1
50023  94.012  -79.205  52.219  1
50024  94.014  -79.206  52.205  1
50025  94.018  -79.213  52.193  1
50026  94.022  -79.220  52.182  1
50027  94.019  -79.215  52.174  1
50028  94.015  -79.207  52.165  1
50029  94.012  -79.200  52.157  1
50030  94.014  -79.196  52.149  1
50031  94.027  -79.195  52.139  1
50032  94.039  -79.194  52.128  1
50033  94.051  -79.193  52.116  1
50034  94.063  -79.191  52.102  1
50035  94.074  -79.190  52.088  1
50036  94.080  -79.187  52.072  1
50037  94.085  -79.184  52.053  1
50038  94.092  -79.187  52.031  1
50039  94.099  -79.200  52.007  1
50040  94.106  -79.211  51.980  1
50041  94.111  -79.222  51.953  1
50042  94.116  -79.234  51.929  1
50043  94.121  -79.245  51.906  1
50044  94.126  -79.257  51.885  1
50045  94.126  -79.263  51.864  1
50046  94.126  -79.269  51.845  1
50047  94.126  -79.275  51.827  1
50048  94.124  -79.272  51.811  1
50049  94.121  -79.269  51.795  1
50050  94.119  -79.266  51.779  1
50051  94.119  -79.256  51.761  1
50052  94.123  -79.241  51.740  1
50053  94.127  -79.224  51.717  1
50054  94.131  -79.208  51.694  1
50055  94.135  -79.192  51.671  1
50056  94.143  -79.175  51.646  1
50057  94.153  -79.159  51.620  1
50058  94.165  -79.142  51.595  1
50059  94.180  -79.127  51.570  1
50060  94.194  -79.112  51.545  1
50061  94.207  -79.125  51.520  1
50062  94.219  -79.142  51.494  1
50063  94.231  -79.159  51.466  1
50064  94.243  -79.177  51.435  1
50065  94.255  -79.195  51.399  1
50066  94.281  -79.179  51.361  1
50067  94.309  -79.162  51.321  1
50068  94.336  -79.145  51.284  1
50069  94.363  -79.128  51.246  1
50070  94.390  -79.112  51.208  1
50071  94.417  -79.095  51.170  1
50072  94.436  -79.084  51.133  1
50073  94.448  -79.081  51.095  1
50074  94.459  -79.078  51.056  1
50075  94.470  -79.074  51.018  1
50076  94.482  -79.070  50.980  1
50077  94.493  -79.066  50.941  1
50078  94.504  -79.062  50.904  1
50130  94.986  -79.479  49.004  1
50131  94.999  -79.491  48.967  1
50132  95.013  -79.504  48.930  1
50133  95.026  -79.517  48.894  1
50134  95.039  -79.530  48.857  1
50135  95.052  -79.544  48.820  1
50136  95.065  -79.557  48.783  1
50137  95.078  -79.570  48.746  1
50138  95.092  -79.582  48.710  1
50139  95.116  -79.583  48.675  1
50140  95.139  -79.585  48.640  1
50141  95.163  -79.586  48.604  1
50142  95.187  -79.588  48.565  1
50143  95.210  -79.589  48.528  1
50144  95.234  -79.591  48.492  1
50145  95.257  -79.592  48.455  1
50146  95.281  -79.594  48.419  1
50147  95.305  -79.595  48.383  1
50148  95.328  -79.597  48.346  1
50149  95.351  -79.598  48.310  1
50150  95.375  -79.600  48.274  1
50151  95.399  -79.601  48.238  1
50152  95.422  -79.603  48.203  1
50153  95.446  -79.604  48.168  1
50154  95.469  -79.605  48.133  1
50155  95.493  -79.607  48.097  1
50156  95.517  -79.608  48.062  1
50157  95.540  -79.610  48.027  1
50158  95.564  -79.611  47.992  1
50159  95.587  -79.613  47.957  1
50160  95.611  -79.614  47.922  1
50161  95.634  -79.616  47.888  1
50162  95.658  -79.617  47.854  1
50163  95.679  -79.612  47.821  1
50164  95.694  -79.591  47.787  1
50165  95.709  -79.570  47.754  1
50166  95.724  -79.548  47.720  1
50167  95.739  -79.527  47.687  1
50168  95.754  -79.506  47.653  1
50169  95.772  -79.497  47.619  1
50170  95.795  -79.510  47.586  1
50171  95.818  -79.523  47.553  1
50172  95.840  -79.536  47.520  1
50173  95.863  -79.549  47.487  1
50174  95.886  -79.562  47.456  1
50175  95.909  -79.575  47.424  1
50176  95.932  -79.588  47.390  1
50177  95.955  -79.601  47.358  1
50178  95.977  -79.614  47.326  1
50179  96.000  -79.620  47.294  1
50180  96.022  -79.625  47.263  1
50181  96.045  -79.629  47.231  1
50182  96.067  -79.634  47.200  1
50211  96.719  -79.769  46.375  1
50212  96.742  -79.773  46.350  1
50213  96.764  -79.778  46.324  1
50214  96.787  -79.783  46.298  1
50215  96.809  -79.787  46.272  1
50216  96.831  -79.792  46.249  1
50217  96.854  -79.796  46.225  1
50218  96.877  -79.801  46.201  1
50219  96.899  -79.806  46.176  1
50220  96.922  -79.811  46.152  1
50221  96.944  -79.815  46.127  1
50222  96.982  -79.814  46.104  1
50223  97.029  -79.812  46.081  1
50224  97.076  -79.809  46.058  1
50225  97.122  -79.807  46.035  1
50226  97.125  -79.817  46.013  1
50227  97.124  -79.829  45.989  1
50228  97.123  -79.840  45.965  1
50229  97.126  -79.867  45.942  1
50230  97.130  -79.896  45.920  1
50231  97.134  -79.925  45.899  1
50232  97.137  -79.953  45.877  1
50233  97.141  -79.982  45.855  1
50234  97.144  -80.010  45.834  1
50647  93.142  -79.491  53.178  1
50648  93.156  -79.479  53.163  1
50649  93.170  -79.466  53.149  1
50650  93.185  -79.454  53.135  1
50651  93.199  -79.443  53.122  1
50652  93.215  -79.435  53.110  1
50653  93.231  -79.426  53.098  1
50654  93.247  -79.419  53.087  1
50655  93.264  -79.408  53.077  1
50656  93.282  -79.394  53.067  1
50657  93.300  -79.385  53.059  1
50658  93.319  -79.379  53.051  1
50659  93.338  -79.374  53.044  1
50660  93.356  -79.368  53.036  1
50661  93.373  -79.362  53.027  1
50662  93.388  -79.357  53.018  1
50663  93.403  -79.353  53.007  1
50664  93.418  -79.349  52.996  1
50665  93.426  -79.344  52.985  1
50666  93.434  -79.338  52.972  1
50667  93.442  -79.333  52.962  1
50668  93.450  -79.328  52.950  1
50669  93.462  -79.322  52.937  1
50670  93.476  -79.317  52.924  1
50671  93.491  -79.312  52.910  1
50672  93.506  -79.306  52.896  1
50673  93.521  -79.301  52.883  1
50674  93.538  -79.297  52.874  1
50675  93.554  -79.293  52.866  1
50676  93.570  -79.288  52.859  1
50677  93.586  -79.284  52.852  1
50678  93.601  -79.274  52.844  1
50679  93.615  -79.264  52.837  1
50680  93.630  -79.254  52.829  1
50681  93.644  -79.247  52.822  1
50682  93.658  -79.241  52.814  1
50683  93.672  -79.236  52.805  1
50684  93.686  -79.231  52.796  1
50685  93.700  -79.229  52.787  1
50686  93.714  -79.229  52.779  1
50687  93.728  -79.229  52.770  1
50688  93.742  -79.229  52.762  1
50689  93.756  -79.229  52.754  1
50690  93.770  -79.229  52.745  1
50691  93.780  -79.237  52.736  1
50692  93.792  -79.240  52.728  1
50693  93.805  -79.236  52.719  1
50694  93.819  -79.232  52.710  1
50695  93.832  -79.228  52.701  1
50696  93.845  -79.224  52.691  1
50697  93.858  -79.220  52.683  1
50698  93.871  -79.216  52.672  1
50699  93.885  -79.213  52.660  1
50700  93.899  -79.213  52.647  1
50701  93.899  -79.210  52.630  1
50702  93.910  -79.209  52.613  1
50703  93.921  -79.209  52.596  1
50704  93.931  -79.207  52.579  1
50705  93.942  -79.206  52.562  1
50706  93.954  -79.205  52.546  1
50707  93.964  -79.204  52.530  1
50708  93.975  -79.203  52.515  1
50709  93.986  -79.202  52.498  1
50710  93.997  -79.200  52.481  1
50711  94.007  -79.203  52.460  1
50712  94.008  -79.200  52.438  1
50713  94.008  -79.197  52.417  1
50714  94.008  -79.197  52.395  1
50715  94.008  -79.196  52.375  1
50716  94.008  -79.196  52.355  1
50717  94.008  -79.195  52.337  1
50718  94.008  -79.194  52.321  1
50719  94.008  -79.194  52.305  1
50720  94.008  -79.194  52.290  1
50721  94.008  -79.193  52.275  1
50722  94.008  -79.193  52.262  1
50723  94.008  -79.192  52.250  1
50724  94.008  -79.191  52.238  1
50725  94.008  -79.191  52.224  1
50726  94.012  -79.198  52.212  1
50727  94.016  -79.205  52.202  1
50728  94.020  -79.212  52.194  1
50729  94.018  -79.208  52.185  1
50730  94.014  -79.201  52.176  1
50731  94.016  -79.196  52.168  1
50732  94.028  -79.195  52.157  1
50733  94.040  -79.194  52.144  1
50734  94.052  -79.193  52.130  1
50735  94.060  -79.190  52.114  1
50736  94.066  -79.187  52.098  1
50737  94.071  -79.184  52.081  1
50738  94.077  -79.181  52.062  1
50739  94.084  -79.187  52.040  1
50740  94.091  -79.199  52.015  1
50741  94.098  -79.210  51.989  1
50742  94.105  -79.222  51.963  1
50743  94.110  -79.234  51.939  1
50744  94.114  -79.244  51.918  1
50745  94.114  -79.250  51.898  1
50746  94.114  -79.256  51.878  1
50747  94.114  -79.261  51.860  1
50748  94.114  -79.266  51.842  1
50749  94.111  -79.263  51.824  1
50750  94.109  -79.260  51.807  1
50751  94.106  -79.257  51.789  1
50752  94.104  -79.254  51.769  1
50753  94.103  -79.247  51.746  1
50754  94.107  -79.231  51.722  1
50755  94.111  -79.216  51.698  1
50756  94.117  -79.200  51.673  1
50757  94.127  -79.182  51.648  1
50758  94.137  -79.165  51.623  1
50759  94.147  -79.149  51.599  1
50760  94.160  -79.133  51.575  1
50761  94.175  -79.118  51.551  1
50762  94.187  -79.136  51.525  1
50763  94.199  -79.153  51.499  1
50764  94.211  -79.172  51.473  1
50765  94.235  -79.179  51.442  1
50766  94.260  -79.175  51.408  1
50767  94.280  -79.171  51.372  1
50768  94.306  -79.159  51.333  1
50769  94.333  -79.143  51.295  1
50770  94.360  -79.126  51.257  1
50771  94.388  -79.109  51.219  1
50772  94.415  -79.092  51.182  1
50773  94.442  -79.075  51.145  1
50774  94.453  -79.072  51.107  1
50775  94.465  -79.068  51.069  1
50776  94.476  -79.065  51.031  1
50777  94.487  -79.061  50.992  1
50778  94.498  -79.057  50.955  1
50779  94.509  -79.053  50.917  1
50780  94.521  -79.049  50.880  1
50781  94.532  -79.046  50.843  1
50829  94.952  -79.413  49.083  1
50830  94.965  -79.426  49.046  1
50831  94.978  -79.439  49.010  1
50832  94.991  -79.452  48.973  1
50833  95.004  -79.465  48.937  1
50834  95.017  -79.478  48.900  1
50835  95.031  -79.491  48.863  1
50836  95.044  -79.504  48.826  1
50837  95.057  -79.517  48.789  1
50838  95.070  -79.530  48.753  1
50839  95.083  -79.543  48.717  1
50840  95.106  -79.545  48.683  1
50841  95.130  -79.547  48.648  1
50842  95.153  -79.548  48.614  1
50843  95.177  -79.550  48.575  1
50844  95.200  -79.551  48.537  1
50845  95.224  -79.553  48.499  1
50846  95.248  -79.554  48.461  1
50847  95.271  -79.556  48.425  1
50848  95.295  -79.557  48.388  1
50849  95.318  -79.559  48.352  1
50850  95.342  -79.560  48.315  1
50851  95.366  -79.562  48.279  1
50852  95.389  -79.563  48.243  1
50853  95.412  -79.565  48.209  1
50854  95.436  -79.567  48.173  1
50855  95.460  -79.568  48.138  1
50856  95.483  -79.570  48.102  1
50857  95.507  -79.571  48.067  1
50858  95.530  -79.573  48.032  1
50859  95.554  -79.574  47.997  1
50860  95.578  -79.575  47.962  1
50861  95.601  -79.576  47.928  1
50862  95.625  -79.578  47.894  1
50863  95.648  -79.579  47.860  1
50864  95.672  -79.581  47.827  1
50865  95.687  -79.561  47.793  1
50866  95.702  -79.540  47.760  1
50867  95.717  -79.518  47.727  1
50868  95.732  -79.497  47.693  1
50869  95.747  -79.476  47.660  1
50870  95.768  -79.482  47.626  1
50871  95.792  -79.495  47.593  1
50872  95.814  -79.508  47.560  1
50873  95.837  -79.521  47.527  1
50874  95.860  -79.534  47.494  1
50875  95.883  -79.548  47.462  1
50876  95.905  -79.560  47.430  1
50877  95.928  -79.573  47.397  1
50878  95.951  -79.586  47.364  1
50879  95.974  -79.598  47.331  1
50880  95.996  -79.602  47.299  1
50881  96.019  -79.607  47.268  1
50882  96.041  -79.611  47.236  1
50883  96.063  -79.616  47.205  1
50884  96.086  -79.620  47.174  1
50911  96.693  -79.746  46.401  1
50912  96.716  -79.751  46.375  1
50913  96.738  -79.755  46.350  1
50914  96.760  -79.760  46.324  1
50915  96.783  -79.764  46.298  1
50916  96.806  -79.769  46.273  1
50917  96.828  -79.773  46.249  1
50918  96.851  -79.779  46.226  1
50919  96.873  -79.783  46.201  1
50920  96.895  -79.788  46.177  1
50921  96.918  -79.792  46.152  1
50922  96.940  -79.797  46.127  1
50923  96.979  -79.797  46.104  1
50924  97.026  -79.794  46.082  1
50925  97.072  -79.792  46.059  1
50926  97.118  -79.789  46.036  1
50927  97.123  -79.798  46.013  1
50928  97.122  -79.811  45.990  1
50929  97.121  -79.822  45.966  1
50930  97.124  -79.849  45.942  1
50931  97.127  -79.877  45.921  1
50932  97.131  -79.905  45.899  1
50933  97.135  -79.934  45.877  1
50934  97.138  -79.963  45.855  1
50935  97.145  -79.975  45.834  1
50936  97.152  -79.983  45.812  1
51348  93.141  -79.481  53.204  1
51349  93.155  -79.469  53.190  1
51350  93.169  -79.456  53.176  1
51351  93.184  -79.444  53.163  1
51352  93.198  -79.432  53.149  1
51353  93.212  -79.419  53.136  1
51354  93.227  -79.410  53.124  1
51355  93.243  -79.401  53.113  1
51356  93.259  -79.394  53.103  1
51357  93.276  -79.382  53.093  1
51358  93.295  -79.370  53.083  1
51359  93.313  -79.364  53.074  1
51360  93.332  -79.358  53.066  1
51361  93.350  -79.352  53.057  1
51362  93.365  -79.347  53.047  1
51363  93.380  -79.343  53.037  1
51364  93.395  -79.338  53.026  1
51365  93.410  -79.334  53.015  1
51366  93.420  -79.328  53.002  1
51367  93.428  -79.324  52.990  1
51368  93.436  -79.319  52.979  1
51369  93.444  -79.313  52.967  1
51370  93.457  -79.308  52.954  1
51371  93.472  -79.303  52.942  1
51372  93.487  -79.297  52.928  1
51373  93.502  -79.291  52.915  1
51374  93.516  -79.286  52.904  1
51375  93.532  -79.281  52.894  1
51376  93.548  -79.277  52.886  1
51377  93.564  -79.272  52.879  1
51378  93.580  -79.269  52.872  1
51379  93.595  -79.259  52.865  1
51380  93.610  -79.249  52.857  1
51381  93.625  -79.239  52.848  1
51382  93.638  -79.234  52.839  1
51383  93.652  -79.228  52.830  1
51384  93.666  -79.223  52.822  1
51385  93.681  -79.218  52.813  1
51386  93.695  -79.212  52.805  1
51387  93.709  -79.212  52.798  1
51388  93.722  -79.212  52.789  1
51389  93.736  -79.212  52.780  1
51390  93.751  -79.212  52.772  1
51391  93.762  -79.219  52.764  1
51392  93.772  -79.228  52.755  1
51393  93.785  -79.226  52.747  1
51394  93.798  -79.222  52.738  1
51395  93.811  -79.219  52.728  1
51396  93.824  -79.215  52.719  1
51397  93.837  -79.210  52.709  1
51398  93.850  -79.206  52.701  1
51399  93.864  -79.204  52.689  1
51400  93.878  -79.204  52.676  1
51401  93.893  -79.204  52.663  1
51402  93.890  -79.201  52.645  1
51403  93.894  -79.199  52.628  1
51404  93.905  -79.198  52.611  1
51405  93.916  -79.197  52.596  1
51406  93.926  -79.196  52.580  1
51407  93.937  -79.194  52.565  1
51408  93.948  -79.194  52.549  1
51409  93.960  -79.192  52.532  1
51410  93.970  -79.191  52.515  1
51411  93.990  -79.192  52.496  1
51412  93.997  -79.195  52.473  1
51413  93.999  -79.199  52.451  1
51414  94.001  -79.198  52.429  1
51415  94.002  -79.192  52.407  1
51416  94.003  -79.186  52.388  1
51417  94.003  -79.182  52.370  1
51418  94.003  -79.182  52.355  1
51419  94.003  -79.181  52.339  1
51420  94.003  -79.181  52.323  1
51421  94.003  -79.181  52.308  1
51422  94.003  -79.180  52.295  1
51423  94.003  -79.179  52.283  1
51424  94.003  -79.178  52.271  1
51425  94.003  -79.178  52.260  1
51426  94.003  -79.178  52.247  1
51427  94.006  -79.183  52.235  1
51428  94.010  -79.190  52.224  1
51429  94.014  -79.197  52.216  1
51430  94.018  -79.203  52.207  1
51431  94.017  -79.201  52.197  1
51432  94.018  -79.196  52.188  1
51433  94.030  -79.195  52.176  1
51434  94.041  -79.194  52.162  1
51435  94.046  -79.190  52.145  1
51436  94.052  -79.187  52.127  1
51437  94.057  -79.184  52.109  1
51438  94.063  -79.181  52.090  1
51439  94.068  -79.177  52.070  1
51440  94.075  -79.187  52.048  1
51441  94.083  -79.199  52.025  1
51442  94.090  -79.210  51.999  1
51443  94.097  -79.222  51.975  1
51444  94.102  -79.231  51.952  1
51445  94.102  -79.237  51.931  1
51446  94.102  -79.242  51.912  1
51447  94.102  -79.248  51.894  1
51448  94.102  -79.254  51.876  1
51449  94.102  -79.258  51.857  1
51450  94.099  -79.255  51.838  1
51451  94.097  -79.252  51.819  1
51452  94.094  -79.249  51.799  1
51453  94.091  -79.246  51.777  1
51454  94.089  -79.243  51.753  1
51455  94.086  -79.239  51.727  1
51456  94.091  -79.223  51.702  1
51457  94.101  -79.206  51.676  1
51458  94.111  -79.190  51.651  1
51459  94.121  -79.172  51.627  1
51460  94.130  -79.156  51.604  1
51461  94.140  -79.139  51.581  1
51462  94.154  -79.131  51.558  1
51463  94.167  -79.148  51.534  1
51464  94.188  -79.158  51.508  1
51465  94.216  -79.163  51.483  1
51466  94.243  -79.169  51.453  1
51467  94.266  -79.153  51.420  1
51468  94.283  -79.128  51.385  1
51469  94.306  -79.147  51.346  1
51470  94.331  -79.140  51.308  1
51471  94.358  -79.123  51.270  1
51472  94.386  -79.106  51.232  1
51473  94.413  -79.090  51.195  1
51474  94.440  -79.072  51.158  1
51475  94.459  -79.063  51.120  1
51476  94.470  -79.059  51.081  1
51477  94.481  -79.056  51.043  1
51478  94.492  -79.052  51.005  1
51479  94.504  -79.048  50.967  1
51480  94.515  -79.044  50.930  1
51481  94.526  -79.040  50.893  1
51482  94.538  -79.037  50.856  1
51483  94.549  -79.034  50.819  1
51529  94.933  -79.365  49.126  1
51530  94.943  -79.374  49.089  1
51531  94.956  -79.387  49.052  1
51532  94.969  -79.400  49.015  1
51533  94.983  -79.413  48.979  1
51534  94.996  -79.426  48.943  1
51535  95.009  -79.439  48.907  1
51536  95.022  -79.452  48.870  1
51537  95.035  -79.465  48.833  1
51538  95.048  -79.478  48.797  1
51539  95.061  -79.491  48.760  1
51540  95.074  -79.504  48.724  1
51541  95.096  -79.507  48.690  1
51542  95.120  -79.509  48.657  1
51543  95.143  -79.510  48.624  1
51544  95.167  -79.512  48.586  1
51545  95.191  -79.513  48.546  1
51546  95.214  -79.515  48.506  1
51547  95.238  -79.516  48.468  1
51548  95.261  -79.518  48.430  1
51549  95.285  -79.520  48.394  1
51550  95.309  -79.521  48.357  1
51551  95.332  -79.523  48.321  1
51552  95.355  -79.524  48.285  1
51553  95.379  -79.526  48.249  1
51554  95.403  -79.527  48.214  1
51555  95.426  -79.529  48.178  1
51556  95.450  -79.530  48.143  1
51557  95.473  -79.532  48.107  1
51558  95.497  -79.533  48.072  1
51559  95.521  -79.535  48.037  1
51560  95.544  -79.536  48.002  1
51561  95.568  -79.538  47.968  1
51562  95.591  -79.539  47.934  1
51563  95.615  -79.541  47.900  1
51564  95.638  -79.542  47.867  1
51565  95.662  -79.544  47.833  1
51566  95.680  -79.531  47.800  1
51567  95.695  -79.510  47.767  1
51568  95.710  -79.488  47.734  1
51569  95.726  -79.467  47.701  1
51570  95.742  -79.454  47.667  1
51571  95.765  -79.467  47.634  1
51572  95.788  -79.480  47.601  1
51573  95.811  -79.493  47.568  1
51574  95.833  -79.506  47.534  1
51575  95.856  -79.520  47.502  1
51576  95.879  -79.532  47.469  1
51577  95.902  -79.545  47.436  1
51578  95.925  -79.558  47.403  1
51579  95.948  -79.571  47.370  1
51580  95.970  -79.579  47.337  1
51581  95.992  -79.584  47.304  1
51582  96.015  -79.588  47.273  1
51583  96.038  -79.593  47.241  1
51584  96.060  -79.598  47.210  1
51585  96.083  -79.603  47.178  1
51611  96.667  -79.723  46.426  1
51612  96.689  -79.728  46.401  1
51613  96.712  -79.733  46.376  1
51614  96.735  -79.737  46.350  1
51615  96.757  -79.742  46.323  1
51616  96.780  -79.746  46.299  1
51617  96.802  -79.751  46.274  1
51618  96.824  -79.756  46.250  1
51619  96.847  -79.761  46.226  1
51620  96.869  -79.765  46.202  1
51621  96.892  -79.770  46.177  1
51622  96.914  -79.774  46.152  1
51623  96.937  -79.779  46.128  1
51624  96.976  -79.779  46.105  1
51625  97.022  -79.776  46.082  1
51626  97.069  -79.773  46.060  1
51627  97.115  -79.770  46.037  1
51628  97.120  -79.780  46.013  1
51629  97.120  -79.792  45.990  1
51630  97.119  -79.803  45.966  1
51631  97.122  -79.829  45.943  1
51632  97.125  -79.858  45.922  1
51633  97.129  -79.886  45.899  1
51634  97.132  -79.915  45.878  1
51635  97.138  -79.933  45.856  1
51636  97.145  -79.941  45.834  1
51637  97.152  -79.949  45.812  1
51638  97.159  -79.956  45.791  1
51639  97.166  -79.964  45.771  1
52050  93.154  -79.458  53.217  1
52051  93.168  -79.446  53.203  1
52052  93.183  -79.434  53.190  1
52053  93.197  -79.422  53.177  1
52054  93.211  -79.410  53.164  1
52055  93.225  -79.397  53.151  1
52056  93.239  -79.385  53.140  1
52057  93.255  -79.376  53.129  1
52058  93.271  -79.369  53.117  1
52059  93.289  -79.356  53.107  1
52060  93.307  -79.348  53.097  1
52061  93.326  -79.342  53.088  1
52062  93.342  -79.338  53.077  1
52063  93.357  -79.333  53.067  1
52064  93.372  -79.328  53.057  1
52065  93.387  -79.324  53.045  1
52066  93.402  -79.319  53.033  1
52067  93.413  -79.314  53.020  1
52068  93.421  -79.309  53.008  1
52069  93.429  -79.303  52.996  1
52070  93.438  -79.299  52.984  1
52071  93.453  -79.293  52.972  1
52072  93.468  -79.288  52.959  1
52073  93.483  -79.282  52.946  1
52074  93.497  -79.277  52.934  1
52075  93.512  -79.272  52.923  1
52076  93.527  -79.266  52.915  1
52077  93.543  -79.262  52.907  1
52078  93.559  -79.257  52.899  1
52079  93.575  -79.253  52.893  1
52080  93.590  -79.244  52.885  1
52081  93.605  -79.234  52.877  1
52082  93.619  -79.227  52.868  1
52083  93.633  -79.222  52.858  1
52084  93.647  -79.216  52.848  1
52085  93.661  -79.210  52.839  1
52086  93.675  -79.205  52.831  1
52087  93.689  -79.200  52.824  1
52088  93.703  -79.196  52.817  1
52089  93.717  -79.196  52.809  1
52090  93.731  -79.196  52.800  1
52091  93.743  -79.200  52.792  1
52092  93.753  -79.209  52.783  1
52093  93.764  -79.216  52.775  1
52094  93.777  -79.212  52.767  1
52095  93.790  -79.209  52.757  1
52096  93.803  -79.205  52.748  1
52097  93.817  -79.201  52.738  1
52098  93.830  -79.197  52.730  1
52099  93.844  -79.196  52.720  1
52100  93.858  -79.195  52.707  1
52101  93.873  -79.195  52.693  1
52102  93.888  -79.195  52.679  1
52103  93.884  -79.192  52.661  1
52104  93.878  -79.188  52.644  1
52105  93.889  -79.187  52.629  1
52106  93.900  -79.186  52.614  1
52107  93.911  -79.185  52.600  1
52108  93.922  -79.184  52.585  1
52109  93.932  -79.183  52.569  1
52110  93.943  -79.181  52.551  1
52111  93.962  -79.182  52.531  1
52112  93.981  -79.184  52.510  1
52113  93.988  -79.186  52.486  1
52114  93.990  -79.190  52.463  1
52115  93.992  -79.195  52.441  1
52116  93.994  -79.197  52.422  1
52117  93.995  -79.190  52.405  1
52118  93.996  -79.184  52.389  1
52119  93.997  -79.178  52.376  1
52120  93.997  -79.172  52.360  1
52121  93.998  -79.168  52.345  1
52122  93.998  -79.167  52.330  1
52123  93.998  -79.166  52.317  1
52124  93.998  -79.166  52.306  1
52125  93.998  -79.165  52.295  1
52126  93.998  -79.165  52.284  1
52127  93.998  -79.165  52.272  1
52128  94.000  -79.169  52.260  1
52129  94.004  -79.175  52.249  1
52130  94.008  -79.182  52.241  1
52131  94.012  -79.189  52.232  1
52132  94.016  -79.196  52.222  1
52133  94.019  -79.196  52.211  1
52134  94.027  -79.194  52.197  1
52135  94.032  -79.190  52.180  1
52136  94.038  -79.187  52.161  1
52137  94.043  -79.184  52.142  1
52138  94.049  -79.180  52.122  1
52139  94.054  -79.177  52.102  1
52140  94.060  -79.175  52.081  1
52141  94.067  -79.187  52.060  1
52142  94.074  -79.198  52.036  1
52143  94.082  -79.209  52.013  1
52144  94.086  -79.218  51.990  1
52145  94.089  -79.225  51.969  1
52146  94.089  -79.230  51.949  1
52147  94.089  -79.235  51.931  1
52148  94.089  -79.241  51.913  1
52149  94.090  -79.247  51.894  1
52150  94.089  -79.250  51.874  1
52151  94.086  -79.247  51.853  1
52152  94.084  -79.244  51.832  1
52153  94.082  -79.241  51.809  1
52154  94.079  -79.237  51.784  1
52155  94.077  -79.234  51.759  1
52156  94.077  -79.231  51.732  1
52157  94.081  -79.223  51.706  1
52158  94.090  -79.207  51.680  1
52159  94.099  -79.191  51.655  1
52160  94.108  -79.175  51.631  1
52161  94.117  -79.159  51.610  1
52162  94.126  -79.144  51.589  1
52163  94.142  -79.136  51.568  1
52164  94.170  -79.142  51.545  1
52165  94.197  -79.147  51.521  1
52166  94.224  -79.153  51.496  1
52167  94.252  -79.159  51.466  1
52168  94.269  -79.131  51.434  1
52169  94.282  -79.103  51.400  1
52170  94.308  -79.107  51.361  1
52171  94.332  -79.122  51.322  1
52172  94.356  -79.120  51.284  1
52173  94.383  -79.103  51.245  1
52174  94.410  -79.087  51.208  1
52175  94.437  -79.070  51.170  1
52176  94.464  -79.053  51.133  1
52177  94.475  -79.050  51.094  1
52178  94.486  -79.046  51.055  1
52179  94.498  -79.043  51.018  1
52180  94.509  -79.039  50.980  1
52181  94.521  -79.035  50.943  1
52182  94.532  -79.031  50.906  1
52183  94.543  -79.028  50.869  1
52184  94.554  -79.024  50.832  1
52185  94.565  -79.021  50.795  1
52186  94.577  -79.017  50.757  1
52228  94.925  -79.329  49.206  1
52229  94.933  -79.337  49.169  1
52230  94.942  -79.344  49.132  1
52231  94.950  -79.352  49.095  1
52232  94.958  -79.360  49.059  1
52233  94.967  -79.366  49.023  1
52234  94.975  -79.374  48.987  1
52235  94.987  -79.387  48.950  1
52236  95.000  -79.400  48.914  1
52237  95.014  -79.413  48.878  1
52238  95.027  -79.426  48.842  1
52239  95.040  -79.438  48.805  1
52240  95.053  -79.451  48.768  1
52241  95.066  -79.464  48.732  1
52242  95.087  -79.469  48.697  1
52243  95.110  -79.471  48.664  1
52244  95.133  -79.473  48.630  1
52245  95.157  -79.474  48.591  1
52246  95.181  -79.476  48.552  1
52247  95.204  -79.477  48.513  1
52248  95.228  -79.479  48.475  1
52249  95.252  -79.480  48.438  1
52250  95.275  -79.482  48.401  1
52251  95.299  -79.483  48.364  1
52252  95.322  -79.485  48.327  1
52253  95.346  -79.486  48.291  1
52254  95.370  -79.488  48.255  1
52255  95.393  -79.489  48.219  1
52256  95.416  -79.491  48.184  1
52257  95.440  -79.492  48.148  1
52258  95.464  -79.494  48.112  1
52259  95.487  -79.495  48.077  1
52260  95.511  -79.497  48.042  1
52261  95.534  -79.498  48.007  1
52262  95.558  -79.500  47.974  1
52263  95.582  -79.501  47.940  1
52264  95.605  -79.503  47.907  1
52265  95.629  -79.504  47.874  1
52266  95.652  -79.506  47.841  1
52267  95.673  -79.501  47.808  1
52268  95.688  -79.479  47.775  1
52269  95.703  -79.458  47.741  1
52270  95.719  -79.437  47.708  1
52271  95.739  -79.439  47.674  1
52272  95.761  -79.452  47.641  1
52273  95.784  -79.465  47.609  1
52274  95.807  -79.478  47.575  1
52275  95.830  -79.491  47.542  1
52276  95.853  -79.504  47.509  1
52277  95.876  -79.517  47.475  1
52278  95.898  -79.530  47.442  1
52279  95.921  -79.543  47.410  1
52280  95.944  -79.557  47.376  1
52281  95.967  -79.561  47.343  1
52282  95.989  -79.566  47.310  1
52283  96.012  -79.570  47.277  1
52284  96.034  -79.576  47.245  1
52285  96.056  -79.580  47.214  1
52286  96.079  -79.585  47.182  1
52287  96.102  -79.589  47.150  1
52308  96.574  -79.687  46.532  1
52309  96.596  -79.692  46.505  1
52310  96.618  -79.696  46.477  1
52311  96.641  -79.701  46.452  1
52312  96.664  -79.705  46.427  1
52313  96.686  -79.710  46.403  1
52314  96.709  -79.714  46.376  1
52315  96.731  -79.719  46.350  1
52316  96.753  -79.723  46.325  1
52317  96.776  -79.729  46.300  1
52318  96.798  -79.733  46.276  1
52319  96.821  -79.738  46.252  1
52320  96.843  -79.742  46.227  1
52321  96.866  -79.747  46.203  1
52322  96.888  -79.751  46.179  1
52323  96.911  -79.756  46.154  1
52324  96.933  -79.761  46.130  1
52325  96.972  -79.761  46.106  1
52326  97.019  -79.758  46.084  1
52327  97.065  -79.755  46.062  1
52328  97.112  -79.752  46.039  1
52329  97.118  -79.762  46.016  1
52330  97.117  -79.773  45.992  1
52331  97.117  -79.785  45.968  1
52332  97.119  -79.810  45.944  1
52333  97.123  -79.839  45.922  1
52334  97.126  -79.867  45.900  1
52335  97.131  -79.891  45.878  1
52336  97.138  -79.899  45.857  1
52337  97.145  -79.906  45.834  1
52338  97.152  -79.914  45.812  1
52339  97.159  -79.921  45.791  1
52340  97.166  -79.929  45.771  1
52341  97.173  -79.936  45.750  1
52751  93.153  -79.447  53.244  1
52752  93.167  -79.435  53.230  1
52753  93.182  -79.423  53.217  1
52754  93.196  -79.411  53.204  1
52755  93.210  -79.399  53.191  1
52756  93.224  -79.387  53.178  1
52757  93.238  -79.375  53.166  1
52758  93.252  -79.363  53.155  1
52759  93.267  -79.351  53.142  1
52760  93.283  -79.343  53.131  1
52761  93.301  -79.333  53.121  1
52762  93.320  -79.327  53.110  1
52763  93.335  -79.322  53.099  1
52764  93.350  -79.318  53.088  1
52765  93.364  -79.313  53.077  1
52766  93.379  -79.309  53.066  1
52767  93.395  -79.304  53.054  1
52768  93.407  -79.300  53.040  1
52769  93.415  -79.294  53.026  1
52770  93.423  -79.289  53.013  1
52771  93.434  -79.284  53.000  1
52772  93.448  -79.278  52.988  1
52773  93.464  -79.273  52.976  1
52774  93.478  -79.268  52.964  1
52775  93.493  -79.263  52.953  1
52776  93.508  -79.257  52.943  1
52777  93.523  -79.252  52.935  1
52778  93.538  -79.247  52.927  1
52779  93.553  -79.242  52.919  1
52780  93.570  -79.237  52.913  1
52781  93.585  -79.230  52.905  1
52782  93.600  -79.219  52.897  1
52783  93.614  -79.214  52.887  1
52784  93.628  -79.209  52.877  1
52785  93.642  -79.203  52.867  1
52786  93.655  -79.198  52.858  1
52787  93.670  -79.193  52.850  1
52788  93.684  -79.187  52.843  1
52789  93.698  -79.182  52.836  1
52790  93.712  -79.178  52.829  1
52791  93.724  -79.182  52.821  1
52792  93.734  -79.191  52.812  1
52793  93.745  -79.200  52.804  1
52794  93.757  -79.203  52.796  1
52795  93.770  -79.199  52.787  1
52796  93.783  -79.195  52.778  1
52797  93.796  -79.191  52.768  1
52798  93.809  -79.187  52.759  1
52799  93.824  -79.187  52.751  1
52800  93.838  -79.187  52.741  1
52801  93.853  -79.186  52.728  1
52802  93.867  -79.186  52.713  1
52803  93.882  -79.186  52.698  1
52804  93.879  -79.183  52.682  1
52805  93.870  -79.179  52.666  1
52806  93.873  -79.177  52.651  1
52807  93.884  -79.175  52.637  1
52808  93.895  -79.175  52.623  1
52809  93.906  -79.173  52.607  1
52810  93.917  -79.172  52.589  1
52811  93.934  -79.172  52.570  1
52812  93.955  -79.174  52.549  1
52813  93.970  -79.175  52.527  1
52814  93.978  -79.178  52.503  1
52815  93.981  -79.181  52.480  1
52816  93.983  -79.186  52.459  1
52817  93.985  -79.190  52.442  1
52818  93.987  -79.194  52.426  1
52819  93.988  -79.190  52.412  1
52820  93.989  -79.184  52.399  1
52821  93.990  -79.177  52.384  1
52822  93.991  -79.171  52.369  1
52823  93.991  -79.165  52.356  1
52824  93.992  -79.159  52.342  1
52825  93.993  -79.153  52.331  1
52826  93.993  -79.153  52.321  1
52827  93.993  -79.152  52.310  1
52828  93.993  -79.151  52.299  1
52829  93.994  -79.153  52.287  1
52830  93.998  -79.160  52.276  1
52831  94.002  -79.167  52.269  1
52832  94.006  -79.174  52.259  1
52833  94.011  -79.184  52.247  1
52834  94.016  -79.193  52.235  1
52835  94.019  -79.190  52.219  1
52836  94.024  -79.187  52.201  1
52837  94.029  -79.184  52.180  1
52838  94.035  -79.180  52.160  1
52839  94.040  -79.177  52.139  1
52840  94.046  -79.174  52.118  1
52841  94.052  -79.175  52.098  1
52842  94.059  -79.187  52.076  1
52843  94.065  -79.197  52.053  1
52844  94.069  -79.204  52.030  1
52845  94.073  -79.212  52.008  1
52846  94.076  -79.219  51.987  1
52847  94.076  -79.224  51.967  1
52848  94.077  -79.228  51.950  1
52849  94.077  -79.234  51.932  1
52850  94.078  -79.239  51.912  1
52851  94.077  -79.241  51.891  1
52852  94.074  -79.238  51.868  1
52853  94.073  -79.235  51.844  1
52854  94.073  -79.231  51.818  1
52855  94.074  -79.228  51.792  1
52856  94.075  -79.225  51.765  1
52857  94.076  -79.221  51.736  1
52858  94.079  -79.213  51.709  1
52859  94.088  -79.197  51.684  1
52860  94.097  -79.182  51.661  1
52861  94.106  -79.166  51.640  1
52862  94.115  -79.150  51.620  1
52863  94.127  -79.132  51.602  1
52864  94.150  -79.112  51.583  1
52865  94.178  -79.123  51.563  1
52866  94.205  -79.134  51.540  1
52867  94.232  -79.143  51.516  1
52868  94.256  -79.137  51.487  1
52869  94.269  -79.109  51.455  1
52870  94.281  -79.081  51.420  1
52871  94.305  -79.078  51.379  1
52872  94.332  -79.086  51.338  1
52873  94.358  -79.096  51.298  1
52874  94.381  -79.100  51.259  1
52875  94.408  -79.084  51.221  1
52876  94.435  -79.067  51.183  1
52877  94.463  -79.050  51.146  1
52878  94.481  -79.041  51.107  1
52879  94.492  -79.037  51.069  1
52880  94.503  -79.034  51.030  1
52881  94.514  -79.030  50.993  1
52882  94.526  -79.026  50.956  1
52883  94.537  -79.022  50.919  1
52884  94.548  -79.019  50.883  1
52885  94.559  -79.015  50.845  1
52886  94.571  -79.012  50.807  1
52887  94.582  -79.008  50.770  1
52888  94.594  -79.004  50.733  1
52928  94.925  -79.302  49.249  1
52929  94.933  -79.309  49.213  1
52930  94.942  -79.316  49.177  1
52931  94.950  -79.324  49.140  1
52932  94.958  -79.332  49.103  1
52933  94.967  -79.339  49.067  1
52934  94.975  -79.347  49.030  1
52935  94.983  -79.354  48.994  1
52936  94.991  -79.361  48.958  1
52937  94.999  -79.369  48.921  1
52938  95.008  -79.376  48.886  1
52939  95.019  -79.386  48.850  1
52940  95.032  -79.399  48.813  1
52941  95.045  -79.412  48.777  1
52942  95.058  -79.426  48.741  1
52943  95.076  -79.432  48.705  1
52944  95.100  -79.433  48.670  1
52945  95.124  -79.435  48.635  1
52946  95.147  -79.436  48.597  1
52947  95.171  -79.438  48.559  1
52948  95.194  -79.439  48.520  1
52949  95.218  -79.441  48.483  1
52950  95.242  -79.442  48.445  1
52951  95.265  -79.444  48.408  1
52952  95.289  -79.445  48.370  1
52953  95.313  -79.447  48.334  1
52954  95.336  -79.448  48.297  1
52955  95.359  -79.450  48.260  1
52956  95.383  -79.451  48.225  1
52957  95.407  -79.453  48.190  1
52958  95.430  -79.454  48.154  1
52959  95.454  -79.456  48.118  1
52960  95.477  -79.457  48.083  1
52961  95.501  -79.459  48.048  1
52962  95.525  -79.460  48.014  1
52963  95.548  -79.462  47.980  1
52964  95.572  -79.463  47.946  1
52965  95.595  -79.465  47.913  1
52966  95.619  -79.466  47.880  1
52967  95.642  -79.468  47.847  1
52968  95.666  -79.469  47.815  1
52969  95.682  -79.449  47.782  1
52970  95.696  -79.428  47.750  1
52971  95.712  -79.411  47.717  1
52972  95.735  -79.424  47.684  1
52973  95.758  -79.437  47.650  1
52974  95.781  -79.450  47.618  1
52975  95.804  -79.463  47.584  1
52976  95.827  -79.476  47.550  1
52977  95.849  -79.489  47.517  1
52978  95.872  -79.502  47.483  1
52979  95.895  -79.516  47.450  1
52980  95.918  -79.529  47.416  1
52981  95.941  -79.538  47.382  1
52982  95.963  -79.543  47.348  1
52983  95.985  -79.548  47.315  1
52984  96.008  -79.553  47.282  1
52985  96.031  -79.557  47.250  1
52986  96.053  -79.562  47.218  1
52987  96.076  -79.567  47.186  1
52988  96.098  -79.571  47.154  1
53005  96.480  -79.650  46.640  1
53006  96.503  -79.654  46.613  1
53007  96.525  -79.659  46.586  1
53008  96.547  -79.664  46.559  1
53009  96.570  -79.669  46.532  1
53010  96.592  -79.673  46.505  1
53011  96.615  -79.678  46.478  1
53012  96.638  -79.683  46.452  1
53013  96.660  -79.687  46.428  1
53014  96.682  -79.692  46.403  1
53015  96.705  -79.696  46.378  1
53016  96.727  -79.701  46.351  1
53017  96.750  -79.706  46.326  1
53018  96.772  -79.711  46.301  1
53019  96.795  -79.715  46.277  1
53020  96.817  -79.720  46.253  1
53021  96.840  -79.724  46.229  1
53022  96.862  -79.729  46.205  1
53023  96.885  -79.733  46.181  1
53024  96.907  -79.739  46.157  1
53025  96.930  -79.743  46.132  1
53026  96.969  -79.742  46.109  1
53027  97.015  -79.740  46.087  1
53028  97.062  -79.737  46.065  1
53029  97.108  -79.735  46.042  1
53030  97.116  -79.743  46.018  1
53031  97.115  -79.755  45.995  1
53032  97.114  -79.767  45.970  1
53033  97.117  -79.791  45.946  1
53034  97.120  -79.819  45.924  1
53035  97.124  -79.848  45.901  1
53036  97.131  -79.857  45.879  1
53037  97.138  -79.864  45.857  1
53038  97.145  -79.872  45.834  1
53039  97.152  -79.880  45.812  1
53040  97.159  -79.887  45.791  1
53041  97.166  -79.895  45.770  1
53042  97.173  -79.902  45.749  1
53043  97.180  -79.910  45.729  1
53452  93.153  -79.438  53.271  1
53453  93.166  -79.425  53.257  1
53454  93.181  -79.413  53.244  1
53455  93.195  -79.400  53.231  1
53456  93.209  -79.388  53.218  1
53457  93.223  -79.376  53.205  1
53458  93.237  -79.364  53.193  1
53459  93.251  -79.352  53.181  1
53460  93.265  -79.340  53.167  1
53461  93.279  -79.328  53.156  1
53462  93.295  -79.317  53.144  1
53463  93.312  -79.313  53.132  1
53464  93.327  -79.308  53.121  1
53465  93.342  -79.303  53.109  1
53466  93.357  -79.299  53.098  1
53467  93.371  -79.294  53.087  1
53468  93.386  -79.290  53.074  1
53469  93.401  -79.285  53.061  1
53470  93.409  -79.280  53.047  1
53471  93.417  -79.275  53.034  1
53472  93.429  -79.269  53.022  1
53473  93.444  -79.264  53.010  1
53474  93.459  -79.259  52.997  1
53475  93.474  -79.253  52.985  1
53476  93.489  -79.248  52.974  1
53477  93.504  -79.242  52.963  1
53478  93.518  -79.237  52.955  1
53479  93.533  -79.231  52.947  1
53480  93.548  -79.226  52.940  1
53481  93.564  -79.222  52.932  1
53482  93.579  -79.215  52.924  1
53483  93.594  -79.206  52.916  1
53484  93.608  -79.201  52.907  1
53485  93.622  -79.196  52.897  1
53486  93.636  -79.190  52.888  1
53487  93.650  -79.185  52.879  1
53488  93.664  -79.180  52.871  1
53489  93.678  -79.175  52.864  1
53490  93.692  -79.170  52.856  1
53491  93.705  -79.167  52.849  1
53492  93.716  -79.173  52.842  1
53493  93.726  -79.182  52.834  1
53494  93.736  -79.190  52.826  1
53495  93.749  -79.189  52.817  1
53496  93.762  -79.185  52.808  1
53497  93.775  -79.181  52.799  1
53498  93.789  -79.178  52.790  1
53499  93.803  -79.178  52.781  1
53500  93.818  -79.178  52.772  1
53501  93.833  -79.178  52.761  1
53502  93.847  -79.177  52.749  1
53503  93.862  -79.177  52.735  1
53504  93.876  -79.177  52.719  1
53505  93.873  -79.174  52.703  1
53506  93.864  -79.170  52.688  1
53507  93.857  -79.166  52.674  1
53508  93.868  -79.165  52.660  1
53509  93.879  -79.164  52.644  1
53510  93.890  -79.162  52.628  1
53511  93.906  -79.162  52.609  1
53512  93.926  -79.164  52.589  1
53513  93.946  -79.165  52.569  1
53514  93.960  -79.167  52.548  1
53515  93.967  -79.170  52.526  1
53516  93.972  -79.173  52.504  1
53517  93.974  -79.178  52.484  1
53518  93.976  -79.181  52.468  1
53519  93.978  -79.186  52.453  1
53520  93.980  -79.190  52.440  1
53521  93.981  -79.188  52.427  1
53522  93.982  -79.182  52.412  1
53523  93.983  -79.176  52.398  1
53524  93.984  -79.170  52.385  1
53525  93.985  -79.164  52.371  1
53526  93.986  -79.157  52.359  1
53527  93.986  -79.151  52.348  1
53528  93.987  -79.145  52.339  1
53529  93.988  -79.139  52.328  1
53530  93.989  -79.138  52.318  1
53531  93.993  -79.147  52.307  1
53532  93.998  -79.156  52.297  1
53533  94.003  -79.166  52.287  1
53534  94.008  -79.176  52.274  1
53535  94.013  -79.186  52.261  1
53536  94.017  -79.185  52.244  1
53537  94.020  -79.182  52.224  1
53538  94.024  -79.179  52.201  1
53539  94.028  -79.176  52.180  1
53540  94.032  -79.174  52.159  1
53541  94.037  -79.170  52.138  1
53542  94.044  -79.175  52.117  1
53543  94.048  -79.183  52.095  1
53544  94.052  -79.190  52.073  1
53545  94.056  -79.198  52.050  1
53546  94.060  -79.206  52.028  1
53547  94.063  -79.213  52.007  1
53548  94.064  -79.218  51.986  1
53549  94.064  -79.223  51.969  1
53550  94.065  -79.228  51.950  1
53551  94.065  -79.233  51.930  1
53552  94.070  -79.233  51.908  1
53553  94.070  -79.229  51.883  1
53554  94.071  -79.225  51.857  1
53555  94.072  -79.222  51.830  1
53556  94.073  -79.218  51.802  1
53557  94.073  -79.215  51.773  1
53558  94.074  -79.211  51.743  1
53559  94.077  -79.204  51.716  1
53560  94.086  -79.188  51.691  1
53561  94.095  -79.172  51.670  1
53562  94.104  -79.156  51.651  1
53563  94.114  -79.140  51.634  1
53564  94.135  -79.115  51.618  1
53565  94.157  -79.090  51.600  1
53566  94.185  -79.099  51.580  1
53567  94.212  -79.109  51.559  1
53568  94.240  -79.120  51.535  1
53569  94.257  -79.112  51.507  1
53570  94.269  -79.087  51.474  1
53571  94.281  -79.059  51.438  1
53572  94.301  -79.048  51.396  1
53573  94.328  -79.057  51.354  1
53574  94.355  -79.065  51.313  1
53575  94.383  -79.074  51.273  1
53576  94.406  -79.081  51.234  1
53577  94.433  -79.065  51.197  1
53578  94.460  -79.047  51.159  1
53579  94.486  -79.032  51.121  1
53580  94.497  -79.028  51.082  1
53581  94.508  -79.024  51.044  1
53582  94.520  -79.021  51.007  1
53583  94.531  -79.017  50.970  1
53584  94.542  -79.013  50.933  1
53585  94.554  -79.010  50.896  1
53586  94.565  -79.006  50.858  1
53587  94.576  -79.002  50.821  1
53588  94.588  -78.999  50.783  1
53589  94.599  -78.995  50.746  1
53590  94.610  -78.991  50.709  1
53591  94.619  -78.997  50.672  1
53628  94.925  -79.274  49.293  1
53629  94.933  -79.281  49.256  1
53630  94.942  -79.289  49.220  1
53631  94.950  -79.296  49.184  1
53632  94.958  -79.303  49.149  1
53633  94.967  -79.311  49.111  1
53634  94.975  -79.319  49.075  1
53635  94.983  -79.326  49.039  1
53636  94.991  -79.334  49.002  1
53637  95.000  -79.341  48.966  1
53638  95.008  -79.349  48.930  1
53639  95.017  -79.356  48.894  1
53640  95.025  -79.363  48.858  1
53641  95.033  -79.371  48.822  1
53642  95.041  -79.379  48.786  1
53643  95.049  -79.386  48.750  1
53644  95.067  -79.394  48.713  1
53645  95.091  -79.396  48.677  1
53646  95.114  -79.397  48.640  1
53647  95.137  -79.399  48.603  1
53648  95.161  -79.400  48.566  1
53649  95.185  -79.402  48.528  1
53650  95.208  -79.403  48.490  1
53651  95.232  -79.404  48.452  1
53652  95.255  -79.406  48.415  1
53653  95.279  -79.407  48.378  1
53654  95.303  -79.409  48.341  1
53655  95.326  -79.410  48.303  1
53656  95.350  -79.412  48.266  1
53657  95.374  -79.413  48.232  1
53658  95.397  -79.415  48.195  1
53659  95.420  -79.416  48.159  1
53660  95.444  -79.418  48.124  1
53661  95.468  -79.419  48.089  1
53662  95.491  -79.421  48.055  1
53663  95.515  -79.422  48.020  1
53664  95.538  -79.424  47.986  1
53665  95.562  -79.425  47.952  1
53666  95.586  -79.427  47.920  1
53667  95.609  -79.429  47.887  1
53668  95.633  -79.430  47.854  1
53669  95.656  -79.432  47.822  1
53670  95.675  -79.419  47.790  1
53671  95.690  -79.398  47.759  1
53672  95.709  -79.396  47.727  1
53673  95.732  -79.409  47.694  1
53674  95.755  -79.422  47.662  1
53675  95.777  -79.435  47.628  1
53676  95.800  -79.448  47.594  1
53677  95.823  -79.461  47.559  1
53678  95.846  -79.474  47.525  1
53679  95.869  -79.488  47.491  1
53680  95.892  -79.501  47.457  1
53681  95.914  -79.513  47.423  1
53682  95.937  -79.521  47.388  1
53683  95.959  -79.526  47.353  1
53684  95.982  -79.530  47.319  1
53685  96.005  -79.535  47.286  1
53686  96.027  -79.539  47.254  1
53687  96.049  -79.544  47.222  1
53688  96.072  -79.548  47.190  1
53689  96.094  -79.553  47.157  1
53704  96.432  -79.623  46.698  1
53705  96.454  -79.627  46.669  1
53706  96.476  -79.632  46.640  1
53707  96.499  -79.637  46.613  1
53708  96.521  -79.642  46.586  1
53709  96.544  -79.646  46.559  1
53710  96.567  -79.651  46.532  1
53711  96.589  -79.655  46.506  1
53712  96.611  -79.660  46.479  1
53713  96.634  -79.664  46.453  1
53714  96.656  -79.669  46.429  1
53715  96.679  -79.674  46.404  1
53716  96.701  -79.679  46.379  1
53717  96.724  -79.683  46.353  1
53718  96.746  -79.688  46.327  1
53719  96.768  -79.692  46.302  1
53720  96.791  -79.697  46.278  1
53721  96.814  -79.701  46.254  1
53722  96.836  -79.706  46.231  1
53723  96.859  -79.711  46.207  1
53724  96.881  -79.716  46.183  1
53725  96.903  -79.720  46.161  1
53726  96.926  -79.725  46.137  1
53727  96.965  -79.724  46.114  1
53728  97.012  -79.722  46.093  1
53729  97.058  -79.719  46.069  1
53730  97.105  -79.717  46.045  1
53731  97.114  -79.725  46.021  1
53732  97.113  -79.736  45.998  1
53733  97.112  -79.748  45.973  1
53734  97.114  -79.771  45.949  1
53735  97.118  -79.800  45.925  1
53736  97.124  -79.814  45.903  1
53737  97.131  -79.822  45.880  1
53738  97.138  -79.830  45.856  1
53739  97.145  -79.837  45.834  1
53740  97.152  -79.845  45.812  1
53741  97.159  -79.852  45.790  1
53742  97.166  -79.860  45.770  1
53743  97.173  -79.867  45.749  1
53744  97.180  -79.875  45.728  1
53745  97.187  -79.883  45.707  1
54154  93.166  -79.415  53.285  1
54155  93.180  -79.403  53.272  1
54156  93.194  -79.391  53.258  1
54157  93.208  -79.379  53.245  1
54158  93.222  -79.366  53.232  1
54159  93.236  -79.354  53.219  1
54160  93.250  -79.341  53.206  1
54161  93.264  -79.329  53.193  1
54162  93.278  -79.317  53.181  1
54163  93.292  -79.305  53.168  1
54164  93.304  -79.297  53.156  1
54165  93.319  -79.293  53.142  1
54166  93.334  -79.288  53.130  1
54167  93.349  -79.284  53.119  1
54168  93.364  -79.279  53.108  1
54169  93.379  -79.275  53.095  1
54170  93.394  -79.270  53.081  1
54171  93.402  -79.266  53.068  1
54172  93.410  -79.260  53.056  1
54173  93.425  -79.255  53.045  1
54174  93.440  -79.250  53.033  1
54175  93.455  -79.244  53.020  1
54176  93.470  -79.238  53.009  1
54177  93.485  -79.233  52.997  1
54178  93.499  -79.228  52.987  1
54179  93.514  -79.222  52.977  1
54180  93.529  -79.217  52.969  1
54181  93.544  -79.212  52.962  1
54182  93.559  -79.206  52.954  1
54183  93.574  -79.200  52.946  1
54184  93.588  -79.194  52.938  1
54185  93.603  -79.188  52.928  1
54186  93.617  -79.183  52.918  1
54187  93.630  -79.178  52.909  1
54188  93.643  -79.175  52.901  1
54189  93.656  -79.172  52.893  1
54190  93.670  -79.169  52.886  1
54191  93.683  -79.165  52.880  1
54192  93.696  -79.162  52.873  1
54193  93.707  -79.164  52.865  1
54194  93.718  -79.172  52.857  1
54195  93.728  -79.179  52.848  1
54196  93.742  -79.175  52.840  1
54197  93.755  -79.172  52.831  1
54198  93.769  -79.169  52.822  1
54199  93.783  -79.169  52.812  1
54200  93.798  -79.169  52.802  1
54201  93.813  -79.169  52.793  1
54202  93.827  -79.169  52.781  1
54203  93.842  -79.168  52.768  1
54204  93.856  -79.168  52.755  1
54205  93.870  -79.168  52.741  1
54206  93.868  -79.165  52.726  1
54207  93.859  -79.161  52.712  1
54208  93.850  -79.157  52.698  1
54209  93.852  -79.154  52.682  1
54210  93.863  -79.153  52.666  1
54211  93.878  -79.153  52.648  1
54212  93.898  -79.154  52.629  1
54213  93.919  -79.156  52.610  1
54214  93.939  -79.156  52.591  1
54215  93.949  -79.159  52.572  1
54216  93.957  -79.162  52.550  1
54217  93.963  -79.165  52.530  1
54218  93.965  -79.169  52.512  1
54219  93.967  -79.173  52.497  1
54220  93.969  -79.178  52.483  1
54221  93.971  -79.181  52.470  1
54222  93.973  -79.186  52.457  1
54223  93.974  -79.187  52.443  1
54224  93.975  -79.181  52.429  1
54225  93.976  -79.175  52.416  1
54226  93.977  -79.169  52.402  1
54227  93.978  -79.162  52.389  1
54228  93.979  -79.156  52.377  1
54229  93.980  -79.150  52.368  1
54230  93.980  -79.144  52.358  1
54231  93.984  -79.139  52.348  1
54232  93.990  -79.139  52.338  1
54233  93.995  -79.149  52.327  1
54234  94.000  -79.159  52.316  1
54235  94.005  -79.169  52.302  1
54236  94.010  -79.178  52.289  1
54237  94.014  -79.181  52.271  1
54238  94.017  -79.178  52.250  1
54239  94.021  -79.175  52.227  1
54240  94.025  -79.172  52.205  1
54241  94.029  -79.169  52.183  1
54242  94.032  -79.166  52.161  1
54243  94.031  -79.169  52.139  1
54244  94.035  -79.177  52.117  1
54245  94.039  -79.184  52.093  1
54246  94.043  -79.192  52.071  1
54247  94.047  -79.200  52.048  1
54248  94.050  -79.207  52.026  1
54249  94.051  -79.212  52.005  1
54250  94.051  -79.217  51.986  1
54251  94.052  -79.222  51.967  1
54252  94.059  -79.223  51.947  1
54253  94.070  -79.222  51.924  1
54254  94.070  -79.219  51.898  1
54255  94.070  -79.216  51.871  1
54256  94.070  -79.212  51.843  1
54257  94.071  -79.208  51.814  1
54258  94.072  -79.204  51.783  1
54259  94.072  -79.201  51.752  1
54260  94.075  -79.194  51.726  1
54261  94.084  -79.179  51.704  1
54262  94.093  -79.163  51.683  1
54263  94.102  -79.147  51.665  1
54264  94.122  -79.123  51.651  1
54265  94.144  -79.098  51.636  1
54266  94.166  -79.072  51.618  1
54267  94.192  -79.074  51.599  1
54268  94.220  -79.084  51.577  1
54269  94.248  -79.095  51.554  1
54270  94.261  -79.080  51.525  1
54271  94.271  -79.059  51.492  1
54272  94.281  -79.037  51.454  1
54273  94.298  -79.019  51.412  1
54274  94.325  -79.028  51.370  1
54275  94.352  -79.036  51.328  1
54276  94.380  -79.044  51.287  1
54277  94.407  -79.053  51.248  1
54278  94.430  -79.062  51.210  1
54279  94.458  -79.045  51.173  1
54280  94.485  -79.028  51.135  1
54281  94.502  -79.019  51.096  1
54282  94.514  -79.015  51.058  1
54283  94.525  -79.012  51.020  1
54284  94.537  -79.008  50.983  1
54285  94.548  -79.004  50.946  1
54286  94.559  -79.001  50.909  1
54287  94.570  -78.997  50.871  1
54288  94.581  -78.993  50.834  1
54289  94.593  -78.990  50.796  1
54290  94.604  -78.986  50.759  1
54291  94.615  -78.982  50.722  1
54292  94.627  -78.978  50.685  1
54293  94.635  -78.984  50.647  1
54327  94.917  -79.238  49.375  1
54328  94.925  -79.246  49.338  1
54329  94.933  -79.253  49.301  1
54330  94.942  -79.261  49.264  1
54331  94.950  -79.269  49.228  1
54332  94.959  -79.276  49.193  1
54333  94.967  -79.284  49.157  1
54334  94.975  -79.291  49.120  1
54335  94.983  -79.298  49.083  1
54336  94.991  -79.306  49.048  1
54337  95.000  -79.313  49.012  1
54338  95.008  -79.321  48.975  1
54339  95.017  -79.328  48.939  1
54340  95.025  -79.336  48.903  1
54341  95.033  -79.343  48.867  1
54342  95.041  -79.350  48.832  1
54343  95.052  -79.366  48.796  1
54344  95.068  -79.385  48.760  1
54345  95.082  -79.385  48.723  1
54346  95.105  -79.389  48.686  1
54347  95.136  -79.394  48.649  1
54348  95.164  -79.394  48.611  1
54349  95.181  -79.390  48.574  1
54350  95.198  -79.385  48.537  1
54351  95.215  -79.381  48.499  1
54352  95.232  -79.376  48.460  1
54353  95.249  -79.372  48.423  1
54354  95.269  -79.370  48.386  1
54355  95.293  -79.372  48.348  1
54356  95.316  -79.372  48.310  1
54357  95.340  -79.374  48.272  1
54358  95.364  -79.375  48.237  1
54359  95.387  -79.377  48.201  1
54360  95.411  -79.379  48.165  1
54361  95.435  -79.380  48.130  1
54362  95.458  -79.382  48.095  1
54363  95.481  -79.383  48.059  1
54364  95.505  -79.385  48.025  1
54365  95.529  -79.386  47.991  1
54366  95.552  -79.388  47.958  1
54367  95.576  -79.389  47.927  1
54368  95.599  -79.391  47.895  1
54369  95.623  -79.392  47.863  1
54370  95.647  -79.394  47.831  1
54371  95.668  -79.389  47.798  1
54372  95.683  -79.368  47.769  1
54373  95.705  -79.381  47.739  1
54374  95.729  -79.394  47.708  1
54375  95.751  -79.407  47.676  1
54376  95.774  -79.420  47.641  1
54377  95.797  -79.433  47.605  1
54378  95.820  -79.446  47.569  1
54379  95.842  -79.460  47.534  1
54380  95.865  -79.473  47.499  1
54381  95.888  -79.485  47.464  1
54382  95.911  -79.498  47.429  1
54383  95.934  -79.503  47.393  1
54384  95.956  -79.507  47.357  1
54385  95.978  -79.512  47.324  1
54386  96.001  -79.516  47.290  1
54387  96.023  -79.521  47.257  1
54388  96.046  -79.526  47.225  1
54389  96.068  -79.530  47.192  1
54390  96.091  -79.535  47.160  1
54391  96.113  -79.540  47.128  1
54404  96.405  -79.600  46.729  1
54405  96.428  -79.604  46.699  1
54406  96.450  -79.610  46.668  1
54407  96.473  -79.614  46.640  1
54408  96.496  -79.619  46.613  1
54409  96.518  -79.623  46.586  1
54410  96.540  -79.628  46.559  1
54411  96.563  -79.632  46.532  1
54412  96.585  -79.637  46.505  1
54413  96.608  -79.642  46.479  1
54414  96.630  -79.647  46.454  1
54415  96.653  -79.651  46.429  1
54416  96.675  -79.656  46.405  1
54417  96.697  -79.661  46.380  1
54418  96.720  -79.665  46.355  1
54419  96.743  -79.670  46.330  1
54420  96.765  -79.674  46.304  1
54421  96.788  -79.679  46.279  1
54422  96.810  -79.684  46.256  1
54423  96.832  -79.689  46.232  1
54424  96.855  -79.693  46.209  1
54425  96.878  -79.698  46.187  1
54426  96.900  -79.702  46.167  1
54427  96.923  -79.707  46.148  1
54428  96.962  -79.706  46.128  1
54429  97.009  -79.704  46.105  1
54430  97.055  -79.701  46.082  1
54431  97.103  -79.698  46.057  1
54432  97.111  -79.707  46.030  1
54433  97.111  -79.718  46.003  1
54434  97.110  -79.730  45.976  1
54435  97.112  -79.752  45.951  1
54436  97.117  -79.772  45.927  1
54437  97.124  -79.780  45.905  1
54438  97.131  -79.787  45.881  1
54439  97.138  -79.795  45.857  1
54440  97.145  -79.803  45.834  1
54441  97.152  -79.811  45.812  1
54442  97.159  -79.818  45.791  1
54443  97.166  -79.826  45.770  1
54444  97.173  -79.833  45.748  1
54445  97.180  -79.841  45.728  1
54446  97.188  -79.849  45.707  1
54447  97.195  -79.856  45.686  1
54855  93.165  -79.404  53.312  1
54856  93.179  -79.392  53.299  1
54857  93.193  -79.380  53.285  1
54858  93.207  -79.368  53.271  1
54859  93.221  -79.356  53.258  1
54860  93.235  -79.344  53.245  1
54861  93.249  -79.332  53.232  1
54862  93.263  -79.319  53.219  1
54863  93.277  -79.307  53.206  1
54864  93.291  -79.295  53.192  1
54865  93.303  -79.290  53.179  1
54866  93.314  -79.283  53.165  1
54867  93.326  -79.274  53.152  1
54868  93.341  -79.269  53.141  1
54869  93.356  -79.265  53.129  1
54870  93.371  -79.260  53.116  1
54871  93.386  -79.256  53.103  1
54872  93.396  -79.250  53.090  1
54873  93.406  -79.245  53.079  1
54874  93.421  -79.240  53.068  1
54875  93.436  -79.234  53.057  1
54876  93.450  -79.229  53.045  1
54877  93.466  -79.224  53.034  1
54878  93.480  -79.219  53.022  1
54879  93.495  -79.213  53.013  1
54880  93.510  -79.208  53.003  1
54881  93.524  -79.203  52.993  1
54882  93.540  -79.197  52.986  1
54883  93.554  -79.191  52.978  1
54884  93.569  -79.187  52.970  1
54885  93.582  -79.184  52.961  1
54886  93.595  -79.180  52.950  1
54887  93.608  -79.177  52.940  1
54888  93.621  -79.174  52.931  1
54889  93.634  -79.170  52.924  1
54890  93.647  -79.167  52.916  1
54891  93.660  -79.164  52.910  1
54892  93.673  -79.161  52.904  1
54893  93.686  -79.157  52.897  1
54894  93.699  -79.154  52.889  1
54895  93.709  -79.163  52.882  1
54896  93.721  -79.165  52.873  1
54897  93.734  -79.162  52.864  1
54898  93.749  -79.160  52.855  1
54899  93.763  -79.160  52.846  1
54900  93.778  -79.159  52.836  1
54901  93.792  -79.159  52.826  1
54902  93.806  -79.159  52.816  1
54903  93.821  -79.159  52.803  1
54904  93.836  -79.159  52.791  1
54905  93.850  -79.159  52.778  1
54906  93.865  -79.159  52.764  1
54907  93.862  -79.156  52.750  1
54908  93.853  -79.152  52.737  1
54909  93.845  -79.148  52.724  1
54910  93.837  -79.143  52.706  1
54911  93.850  -79.143  52.689  1
54912  93.870  -79.144  52.671  1
54913  93.891  -79.146  52.651  1
54914  93.911  -79.147  52.632  1
54915  93.931  -79.148  52.613  1
54916  93.939  -79.150  52.595  1
54917  93.946  -79.153  52.576  1
54918  93.954  -79.156  52.558  1
54919  93.956  -79.160  52.542  1
54920  93.958  -79.164  52.529  1
54921  93.960  -79.169  52.515  1
54922  93.962  -79.173  52.502  1
54923  93.964  -79.177  52.489  1
54924  93.966  -79.181  52.476  1
54925  93.968  -79.186  52.462  1
54926  93.968  -79.180  52.450  1
54927  93.969  -79.174  52.435  1
54928  93.970  -79.167  52.421  1
54929  93.971  -79.161  52.408  1
54930  93.972  -79.155  52.398  1
54931  93.973  -79.149  52.387  1
54932  93.979  -79.145  52.378  1
54933  93.985  -79.142  52.368  1
54934  93.991  -79.141  52.357  1
54935  93.996  -79.151  52.345  1
54936  94.001  -79.161  52.331  1
54937  94.006  -79.171  52.317  1
54938  94.011  -79.176  52.299  1
54939  94.014  -79.173  52.277  1
54940  94.018  -79.170  52.255  1
54941  94.022  -79.168  52.232  1
54942  94.026  -79.165  52.209  1
54943  94.026  -79.166  52.186  1
54944  94.025  -79.169  52.163  1
54945  94.024  -79.173  52.140  1
54946  94.026  -79.178  52.116  1
54947  94.030  -79.186  52.093  1
54948  94.034  -79.194  52.070  1
54949  94.038  -79.202  52.047  1
54950  94.038  -79.206  52.025  1
54951  94.039  -79.212  52.006  1
54952  94.044  -79.213  51.986  1
54953  94.055  -79.212  51.963  1
54954  94.066  -79.212  51.939  1
54955  94.071  -79.209  51.913  1
54956  94.070  -79.206  51.885  1
54957  94.069  -79.202  51.856  1
54958  94.069  -79.198  51.826  1
54959  94.070  -79.194  51.796  1
54960  94.071  -79.191  51.766  1
54961  94.073  -79.185  51.743  1
54962  94.082  -79.169  51.722  1
54963  94.091  -79.153  51.703  1
54964  94.109  -79.131  51.687  1
54965  94.131  -79.106  51.671  1
54966  94.153  -79.081  51.656  1
54967  94.175  -79.055  51.638  1
54968  94.200  -79.049  51.618  1
54969  94.227  -79.060  51.597  1
54970  94.254  -79.068  51.572  1
54971  94.264  -79.048  51.541  1
54972  94.274  -79.027  51.507  1
54973  94.284  -79.006  51.469  1
54974  94.297  -78.995  51.427  1
54975  94.322  -78.998  51.384  1
54976  94.349  -79.006  51.343  1
54977  94.377  -79.015  51.302  1
54978  94.404  -79.024  51.263  1
54979  94.431  -79.032  51.224  1
54980  94.455  -79.042  51.186  1
54981  94.482  -79.025  51.148  1
54982  94.508  -79.010  51.110  1
54983  94.520  -79.006  51.072  1
54984  94.531  -79.002  51.034  1
54985  94.542  -78.999  50.997  1
54986  94.553  -78.995  50.959  1
54987  94.564  -78.991  50.922  1
54988  94.575  -78.988  50.884  1
54989  94.587  -78.984  50.847  1
54990  94.598  -78.981  50.809  1
54991  94.610  -78.977  50.772  1
54992  94.621  -78.973  50.734  1
54993  94.632  -78.969  50.697  1
54994  94.643  -78.966  50.660  1
54995  94.652  -78.971  50.622  1
54996  94.661  -78.979  50.584  1
54997  94.669  -78.987  50.547  1
54998  94.677  -78.994  50.508  1
55027  94.917  -79.211  49.421  1
55028  94.925  -79.219  49.384  1
55029  94.933  -79.225  49.346  1
55030  94.942  -79.233  49.310  1
55031  94.950  -79.241  49.274  1
55032  94.959  -79.248  49.238  1
55033  94.967  -79.256  49.202  1
55034  94.975  -79.263  49.166  1
55035  94.983  -79.271  49.129  1
55036  94.992  -79.278  49.093  1
55037  95.000  -79.285  49.057  1
55038  95.008  -79.293  49.022  1
55039  95.017  -79.300  48.986  1
55040  95.025  -79.308  48.950  1
55041  95.035  -79.321  48.914  1
55042  95.047  -79.339  48.878  1
55043  95.060  -79.357  48.843  1
55044  95.072  -79.375  48.808  1
55045  95.111  -79.400  48.772  1
55046  95.101  -79.382  48.734  1
55047  95.125  -79.385  48.697  1
55048  95.148  -79.389  48.659  1
55049  95.172  -79.393  48.622  1
55050  95.199  -79.397  48.584  1
55051  95.237  -79.403  48.547  1
55052  95.273  -79.408  48.509  1
55053  95.292  -79.404  48.470  1
55054  95.309  -79.400  48.432  1
55055  95.326  -79.395  48.394  1
55056  95.343  -79.391  48.356  1
55057  95.360  -79.386  48.318  1
55058  95.378  -79.382  48.281  1
55059  95.395  -79.377  48.245  1
55060  95.412  -79.372  48.208  1
55061  95.429  -79.368  48.173  1
55062  95.447  -79.363  48.138  1
55063  95.464  -79.359  48.102  1
55064  95.481  -79.354  48.066  1
55065  95.498  -79.350  48.031  1
55066  95.519  -79.348  47.998  1
55067  95.542  -79.350  47.966  1
55068  95.566  -79.351  47.934  1
55069  95.590  -79.353  47.903  1
55070  95.613  -79.354  47.872  1
55071  95.636  -79.356  47.841  1
55072  95.660  -79.357  47.812  1
55073  95.679  -79.353  47.781  1
55074  95.702  -79.366  47.752  1
55075  95.725  -79.379  47.722  1
55076  95.748  -79.392  47.689  1
55077  95.770  -79.405  47.654  1
55078  95.794  -79.418  47.618  1
55079  95.816  -79.432  47.583  1
55080  95.839  -79.444  47.547  1
55081  95.862  -79.457  47.510  1
55082  95.885  -79.470  47.472  1
55083  95.907  -79.480  47.434  1
55084  95.930  -79.485  47.398  1
55085  95.952  -79.489  47.362  1
55086  95.975  -79.494  47.327  1
55087  95.997  -79.498  47.293  1
55088  96.020  -79.503  47.260  1
55089  96.042  -79.508  47.228  1
55090  96.064  -79.513  47.194  1
55091  96.087  -79.517  47.162  1
55092  96.110  -79.522  47.129  1
55103  96.357  -79.573  46.788  1
55104  96.379  -79.577  46.758  1
55105  96.402  -79.582  46.728  1
55106  96.425  -79.587  46.698  1
55107  96.447  -79.592  46.668  1
55108  96.469  -79.596  46.640  1
55109  96.492  -79.601  46.612  1
55110  96.514  -79.605  46.585  1
55111  96.537  -79.610  46.559  1
55112  96.559  -79.614  46.532  1
55113  96.582  -79.620  46.505  1
55114  96.604  -79.624  46.479  1
55115  96.626  -79.629  46.454  1
55116  96.650  -79.632  46.430  1
55117  96.674  -79.636  46.407  1
55118  96.697  -79.640  46.382  1
55119  96.722  -79.644  46.357  1
55120  96.745  -79.648  46.332  1
55121  96.769  -79.651  46.306  1
55122  96.793  -79.655  46.281  1
55123  96.817  -79.660  46.258  1
55124  96.841  -79.664  46.235  1
55125  96.865  -79.667  46.213  1
55126  96.888  -79.671  46.192  1
55127  96.912  -79.675  46.173  1
55128  96.927  -79.685  46.156  1
55129  96.972  -79.683  46.136  1
55130  97.021  -79.679  46.114  1
55131  97.070  -79.676  46.091  1
55132  97.098  -79.672  46.067  1
55133  97.120  -79.668  46.042  1
55134  97.115  -79.690  46.014  1
55135  97.108  -79.711  45.986  1
55136  97.110  -79.730  45.958  1
55137  97.117  -79.738  45.932  1
55138  97.124  -79.745  45.908  1
55139  97.131  -79.753  45.883  1
55140  97.138  -79.761  45.859  1
55141  97.145  -79.768  45.835  1
55142  97.152  -79.776  45.813  1
55143  97.160  -79.783  45.791  1
55144  97.167  -79.791  45.769  1
55145  97.174  -79.798  45.748  1
55146  97.181  -79.806  45.727  1
55147  97.188  -79.814  45.707  1
55148  97.195  -79.822  45.685  1
55149  97.202  -79.830  45.664  1
55556  93.164  -79.394  53.339  1
55557  93.178  -79.382  53.325  1
55558  93.192  -79.370  53.312  1
55559  93.206  -79.358  53.298  1
55560  93.220  -79.345  53.284  1
55561  93.234  -79.333  53.271  1
55562  93.248  -79.321  53.257  1
55563  93.262  -79.309  53.244  1
55564  93.276  -79.297  53.231  1
55565  93.290  -79.285  53.217  1
55566  93.304  -79.279  53.204  1
55567  93.313  -79.277  53.189  1
55568  93.324  -79.269  53.176  1
55569  93.336  -79.259  53.164  1
55570  93.348  -79.250  53.151  1
55571  93.363  -79.246  53.138  1
55572  93.378  -79.241  53.125  1
55573  93.390  -79.236  53.113  1
55574  93.402  -79.231  53.103  1
55575  93.417  -79.225  53.092  1
55576  93.431  -79.220  53.081  1
55577  93.446  -79.215  53.070  1
55578  93.461  -79.209  53.059  1
55579  93.476  -79.204  53.049  1
55580  93.491  -79.199  53.040  1
55581  93.505  -79.194  53.030  1
55582  93.520  -79.188  53.021  1
55583  93.534  -79.184  53.013  1
55584  93.549  -79.179  53.004  1
55585  93.563  -79.174  52.994  1
55586  93.576  -79.172  52.984  1
55587  93.588  -79.170  52.973  1
55588  93.600  -79.169  52.963  1
55589  93.612  -79.167  52.955  1
55590  93.625  -79.165  52.947  1
55591  93.638  -79.162  52.940  1
55592  93.650  -79.159  52.934  1
55593  93.663  -79.156  52.929  1
55594  93.677  -79.153  52.922  1
55595  93.690  -79.150  52.915  1
55596  93.701  -79.154  52.908  1
55597  93.714  -79.152  52.900  1
55598  93.728  -79.151  52.890  1
55599  93.743  -79.151  52.881  1
55600  93.757  -79.151  52.871  1
55601  93.772  -79.150  52.861  1
55602  93.786  -79.150  52.851  1
55603  93.801  -79.150  52.840  1
55604  93.816  -79.150  52.827  1
55605  93.830  -79.150  52.815  1
55606  93.845  -79.150  52.802  1
55607  93.859  -79.150  52.789  1
55608  93.857  -79.147  52.776  1
55609  93.848  -79.143  52.763  1
55610  93.839  -79.139  52.748  1
55611  93.832  -79.135  52.732  1
55612  93.842  -79.134  52.714  1
55613  93.863  -79.136  52.695  1
55614  93.883  -79.137  52.676  1
55615  93.904  -79.138  52.656  1
55616  93.921  -79.140  52.638  1
55617  93.928  -79.142  52.621  1
55618  93.936  -79.145  52.604  1
55619  93.943  -79.147  52.588  1
55620  93.946  -79.151  52.575  1
55621  93.948  -79.156  52.562  1
55622  93.951  -79.160  52.550  1
55623  93.953  -79.164  52.537  1
55624  93.955  -79.169  52.525  1
55625  93.957  -79.173  52.512  1
55626  93.958  -79.177  52.498  1
55627  93.960  -79.181  52.485  1
55628  93.962  -79.178  52.470  1
55629  93.963  -79.172  52.455  1
55630  93.963  -79.166  52.440  1
55631  93.964  -79.160  52.428  1
55632  93.968  -79.156  52.417  1
55633  93.974  -79.152  52.407  1
55634  93.981  -79.148  52.396  1
55635  93.987  -79.145  52.385  1
55636  93.993  -79.143  52.373  1
55637  93.998  -79.154  52.360  1
55638  94.003  -79.164  52.345  1
55639  94.008  -79.172  52.327  1
55640  94.012  -79.169  52.306  1
55641  94.015  -79.166  52.283  1
55642  94.019  -79.163  52.260  1
55643  94.020  -79.163  52.236  1
55644  94.019  -79.166  52.213  1
55645  94.019  -79.169  52.188  1
55646  94.018  -79.173  52.163  1
55647  94.017  -79.176  52.139  1
55648  94.016  -79.180  52.116  1
55649  94.020  -79.188  52.092  1
55650  94.025  -79.196  52.069  1
55651  94.025  -79.200  52.047  1
55652  94.030  -79.203  52.026  1
55653  94.041  -79.203  52.004  1
55654  94.052  -79.201  51.978  1
55655  94.063  -79.200  51.952  1
55656  94.072  -79.199  51.926  1
55657  94.071  -79.195  51.898  1
55658  94.070  -79.192  51.868  1
55659  94.068  -79.188  51.839  1
55660  94.069  -79.184  51.810  1
55661  94.069  -79.181  51.784  1
55662  94.071  -79.176  51.763  1
55663  94.080  -79.160  51.743  1
55664  94.096  -79.140  51.725  1
55665  94.118  -79.114  51.709  1
55666  94.139  -79.089  51.692  1
55667  94.161  -79.063  51.675  1
55668  94.183  -79.038  51.657  1
55669  94.207  -79.025  51.637  1
55670  94.235  -79.036  51.615  1
55671  94.257  -79.037  51.589  1
55672  94.267  -79.015  51.556  1
55673  94.277  -78.995  51.521  1
55674  94.289  -78.981  51.482  1
55675  94.309  -78.991  51.440  1
55676  94.329  -79.000  51.398  1
55677  94.351  -78.997  51.356  1
55678  94.374  -78.990  51.315  1
55679  94.400  -78.994  51.276  1
55680  94.427  -79.002  51.237  1
55681  94.455  -79.011  51.200  1
55682  94.480  -79.022  51.162  1
55683  94.507  -79.006  51.124  1
55684  94.525  -78.997  51.086  1
55685  94.536  -78.993  51.049  1
55686  94.547  -78.990  51.011  1
55687  94.558  -78.986  50.974  1
55688  94.570  -78.982  50.936  1
55689  94.581  -78.979  50.898  1
55690  94.593  -78.975  50.860  1
55691  94.604  -78.971  50.822  1
55692  94.615  -78.968  50.785  1
55693  94.626  -78.964  50.747  1
55694  94.637  -78.960  50.710  1
55695  94.648  -78.957  50.672  1
55696  94.660  -78.953  50.634  1
55697  94.669  -78.959  50.597  1
55698  94.677  -78.966  50.559  1
55699  94.685  -78.974  50.521  1
55700  94.694  -78.981  50.483  1
55701  94.702  -78.989  50.445  1
55702  94.710  -78.996  50.407  1
55703  94.718  -79.003  50.369  1
55704  94.726  -79.011  50.331  1
55705  94.735  -79.018  50.294  1
55706  94.743  -79.026  50.257  1
55727  94.917  -79.183  49.467  1
55728  94.925  -79.190  49.430  1
55729  94.934  -79.198  49.392  1
55730  94.942  -79.206  49.356  1
55731  94.951  -79.213  49.319  1
55732  94.959  -79.220  49.283  1
55733  94.967  -79.228  49.247  1
55734  94.975  -79.235  49.211  1
55735  94.983  -79.243  49.175  1
55736  94.992  -79.250  49.139  1
55737  95.000  -79.258  49.103  1
55738  95.008  -79.266  49.067  1
55739  95.018  -79.276  49.032  1
55740  95.030  -79.294  48.996  1
55741  95.042  -79.313  48.961  1
55742  95.055  -79.331  48.925  1
55743  95.067  -79.349  48.890  1
55744  95.079  -79.367  48.855  1
55745  95.115  -79.391  48.820  1
55746  95.135  -79.400  48.783  1
55747  95.120  -79.378  48.746  1
55748  95.144  -79.382  48.708  1
55749  95.168  -79.385  48.670  1
55750  95.192  -79.389  48.633  1
55751  95.215  -79.393  48.595  1
55752  95.239  -79.397  48.557  1
55753  95.263  -79.401  48.519  1
55754  95.300  -79.407  48.481  1
55755  95.337  -79.412  48.442  1
55756  95.374  -79.417  48.403  1
55757  95.403  -79.419  48.365  1
55758  95.420  -79.414  48.328  1
55759  95.438  -79.410  48.291  1
55760  95.455  -79.405  48.253  1
55761  95.472  -79.400  48.217  1
55762  95.489  -79.396  48.182  1
55763  95.506  -79.391  48.146  1
55764  95.523  -79.387  48.110  1
55765  95.540  -79.382  48.074  1
55766  95.558  -79.378  48.039  1
55767  95.575  -79.373  48.005  1
55768  95.592  -79.369  47.974  1
55769  95.609  -79.364  47.942  1
55770  95.626  -79.360  47.911  1
55771  95.642  -79.354  47.881  1
55772  95.652  -79.346  47.852  1
55773  95.661  -79.338  47.825  1
55774  95.670  -79.340  47.794  1
55775  95.691  -79.352  47.763  1
55776  95.718  -79.364  47.732  1
55777  95.744  -79.377  47.699  1
55778  95.767  -79.390  47.664  1
55779  95.790  -79.404  47.628  1
55780  95.813  -79.416  47.592  1
55781  95.835  -79.429  47.555  1
55782  95.859  -79.442  47.517  1
55783  95.881  -79.456  47.477  1
55784  95.904  -79.462  47.438  1
55785  95.926  -79.466  47.401  1
55786  95.949  -79.471  47.365  1
55787  95.971  -79.476  47.329  1
55788  95.993  -79.481  47.295  1
55789  96.016  -79.485  47.262  1
55790  96.039  -79.490  47.229  1
55791  96.061  -79.494  47.196  1
55792  96.084  -79.499  47.163  1
55793  96.106  -79.504  47.130  1
55803  96.340  -79.545  46.818  1
55804  96.365  -79.548  46.788  1
55805  96.388  -79.552  46.757  1
55806  96.412  -79.556  46.727  1
55807  96.436  -79.560  46.697  1
55808  96.460  -79.563  46.667  1
55809  96.484  -79.567  46.639  1
55810  96.508  -79.571  46.612  1
55811  96.532  -79.575  46.584  1
55812  96.555  -79.579  46.558  1
55813  96.579  -79.582  46.532  1
55814  96.603  -79.586  46.505  1
55815  96.627  -79.590  46.479  1
55816  96.651  -79.594  46.455  1
55817  96.675  -79.598  46.431  1
55818  96.698  -79.601  46.408  1
55819  96.723  -79.605  46.384  1
55820  96.746  -79.609  46.359  1
55821  96.770  -79.613  46.333  1
55822  96.794  -79.617  46.308  1
55823  96.818  -79.620  46.283  1
55824  96.842  -79.624  46.260  1
55825  96.866  -79.628  46.238  1
55826  96.890  -79.632  46.217  1
55827  96.909  -79.639  46.197  1
55828  96.920  -79.651  46.180  1
55829  96.939  -79.661  46.161  1
55830  96.987  -79.657  46.141  1
55831  97.036  -79.653  46.119  1
55832  97.068  -79.649  46.096  1
55833  97.090  -79.645  46.075  1
55834  97.111  -79.642  46.054  1
55835  97.134  -79.638  46.028  1
55836  97.130  -79.659  45.999  1
55837  97.116  -79.690  45.970  1
55838  97.117  -79.703  45.940  1
55839  97.124  -79.711  45.912  1
55840  97.132  -79.718  45.886  1
55841  97.139  -79.726  45.861  1
55842  97.146  -79.733  45.836  1
55843  97.153  -79.742  45.813  1
55844  97.160  -79.749  45.790  1
55845  97.167  -79.757  45.769  1
55846  97.174  -79.764  45.747  1
55847  97.181  -79.772  45.726  1
55848  97.188  -79.780  45.706  1
55849  97.195  -79.787  45.684  1
55850  97.202  -79.795  45.663  1
55851  97.209  -79.802  45.642  1
56258  93.177  -79.372  53.352  1
56259  93.191  -79.360  53.338  1
56260  93.205  -79.347  53.324  1
56261  93.219  -79.335  53.311  1
56262  93.233  -79.323  53.297  1
56263  93.247  -79.311  53.283  1
56264  93.261  -79.299  53.269  1
56265  93.275  -79.286  53.256  1
56266  93.289  -79.274  53.243  1
56267  93.304  -79.269  53.229  1
56268  93.313  -79.266  53.214  1
56269  93.323  -79.263  53.200  1
56270  93.334  -79.255  53.187  1
56271  93.346  -79.244  53.174  1
56272  93.357  -79.234  53.161  1
56273  93.370  -79.226  53.148  1
56274  93.383  -79.222  53.137  1
56275  93.398  -79.216  53.126  1
56276  93.412  -79.211  53.115  1
56277  93.427  -79.206  53.103  1
56278  93.441  -79.200  53.093  1
56279  93.456  -79.196  53.083  1
56280  93.471  -79.190  53.073  1
56281  93.485  -79.186  53.064  1
56282  93.499  -79.181  53.055  1
56283  93.514  -79.176  53.046  1
56284  93.529  -79.172  53.038  1
56285  93.543  -79.166  53.029  1
56286  93.557  -79.162  53.019  1
56287  93.571  -79.158  53.008  1
56288  93.583  -79.156  52.997  1
56289  93.595  -79.155  52.988  1
56290  93.608  -79.153  52.979  1
56291  93.620  -79.152  52.972  1
56292  93.632  -79.150  52.966  1
56293  93.644  -79.149  52.960  1
56294  93.656  -79.147  52.954  1
56295  93.669  -79.146  52.948  1
56296  93.681  -79.144  52.941  1
56297  93.693  -79.143  52.935  1
56298  93.708  -79.142  52.927  1
56299  93.722  -79.142  52.918  1
56300  93.737  -79.142  52.908  1
56301  93.752  -79.142  52.898  1
56302  93.766  -79.141  52.887  1
56303  93.781  -79.141  52.876  1
56304  93.795  -79.141  52.865  1
56305  93.810  -79.141  52.853  1
56306  93.825  -79.141  52.840  1
56307  93.839  -79.140  52.827  1
56308  93.854  -79.140  52.815  1
56309  93.851  -79.137  52.802  1
56310  93.843  -79.134  52.788  1
56311  93.834  -79.130  52.773  1
56312  93.837  -79.128  52.757  1
56313  93.842  -79.127  52.740  1
56314  93.855  -79.128  52.720  1
56315  93.875  -79.128  52.701  1
56316  93.896  -79.130  52.682  1
56317  93.911  -79.131  52.664  1
56318  93.918  -79.134  52.648  1
56319  93.925  -79.137  52.633  1
56320  93.933  -79.139  52.619  1
56321  93.937  -79.143  52.608  1
56322  93.939  -79.147  52.595  1
56323  93.941  -79.151  52.583  1
56324  93.943  -79.156  52.571  1
56325  93.945  -79.160  52.559  1
56326  93.947  -79.164  52.546  1
56327  93.949  -79.169  52.532  1
56328  93.951  -79.173  52.518  1
56329  93.953  -79.177  52.503  1
56330  93.955  -79.178  52.487  1
56331  93.956  -79.171  52.472  1
56332  93.957  -79.165  52.459  1
56333  93.963  -79.162  52.446  1
56334  93.970  -79.158  52.434  1
56335  93.976  -79.155  52.423  1
56336  93.983  -79.151  52.412  1
56337  93.989  -79.147  52.400  1
56338  93.995  -79.147  52.387  1
56339  94.000  -79.156  52.372  1
56340  94.005  -79.166  52.355  1
56341  94.009  -79.164  52.335  1
56342  94.012  -79.162  52.311  1
56343  94.015  -79.159  52.287  1
56344  94.014  -79.163  52.262  1
56345  94.013  -79.166  52.237  1
56346  94.012  -79.170  52.213  1
56347  94.011  -79.173  52.188  1
56348  94.011  -79.176  52.162  1
56349  94.010  -79.180  52.138  1
56350  94.009  -79.183  52.115  1
56351  94.011  -79.190  52.092  1
56352  94.015  -79.194  52.068  1
56353  94.026  -79.193  52.045  1
56354  94.037  -79.191  52.021  1
56355  94.048  -79.190  51.992  1
56356  94.059  -79.190  51.965  1
56357  94.070  -79.188  51.936  1
56358  94.072  -79.185  51.908  1
56359  94.071  -79.182  51.879  1
56360  94.069  -79.178  51.852  1
56361  94.068  -79.175  51.826  1
56362  94.068  -79.171  51.803  1
56363  94.069  -79.166  51.786  1
56364  94.082  -79.147  51.768  1
56365  94.104  -79.122  51.749  1
56366  94.126  -79.096  51.730  1
56367  94.148  -79.071  51.713  1
56368  94.170  -79.046  51.695  1
56369  94.192  -79.021  51.676  1
56370  94.214  -79.000  51.656  1
56371  94.242  -79.011  51.633  1
56372  94.260  -79.005  51.605  1
56373  94.270  -78.984  51.571  1
56374  94.281  -78.967  51.535  1
56375  94.301  -78.977  51.495  1
56376  94.322  -78.987  51.452  1
56377  94.341  -78.996  51.410  1
56378  94.361  -79.006  51.369  1
56379  94.383  -79.006  51.328  1
56380  94.406  -78.998  51.289  1
56381  94.429  -78.990  51.251  1
56382  94.452  -78.983  51.215  1
56383  94.479  -78.990  51.178  1
56384  94.506  -78.999  51.140  1
56385  94.530  -78.988  51.102  1
56386  94.541  -78.984  51.064  1
56387  94.553  -78.981  51.026  1
56388  94.564  -78.977  50.988  1
56389  94.575  -78.973  50.950  1
56390  94.586  -78.970  50.912  1
56391  94.598  -78.966  50.873  1
56392  94.609  -78.962  50.835  1
56393  94.620  -78.959  50.798  1
56394  94.631  -78.955  50.760  1
56395  94.643  -78.951  50.723  1
56396  94.654  -78.948  50.685  1
56397  94.666  -78.944  50.647  1
56398  94.677  -78.940  50.609  1
56399  94.685  -78.946  50.571  1
56400  94.694  -78.953  50.533  1
56401  94.702  -78.961  50.495  1
56402  94.710  -78.968  50.457  1
56403  94.718  -78.976  50.419  1
56404  94.727  -78.984  50.381  1
56405  94.735  -78.991  50.343  1
56406  94.743  -78.998  50.305  1
56407  94.752  -79.006  50.268  1
56408  94.760  -79.013  50.230  1
56409  94.768  -79.021  50.192  1
56410  94.776  -79.028  50.154  1
56411  94.785  -79.036  50.117  1
56425  94.901  -79.140  49.590  1
56426  94.909  -79.148  49.553  1
56427  94.917  -79.156  49.514  1
56428  94.925  -79.162  49.477  1
56429  94.934  -79.170  49.440  1
56430  94.942  -79.178  49.403  1
56431  94.951  -79.185  49.366  1
56432  94.959  -79.193  49.329  1
56433  94.967  -79.200  49.293  1
56434  94.975  -79.208  49.256  1
56435  94.983  -79.215  49.221  1
56436  94.992  -79.222  49.185  1
56437  95.001  -79.231  49.149  1
56438  95.013  -79.250  49.114  1
56439  95.025  -79.268  49.078  1
56440  95.038  -79.286  49.043  1
56441  95.050  -79.304  49.008  1
56442  95.062  -79.322  48.973  1
56443  95.074  -79.341  48.938  1
56444  95.087  -79.359  48.903  1
56445  95.119  -79.382  48.868  1
56446  95.120  -79.374  48.832  1
56447  95.126  -79.370  48.795  1
56448  95.137  -79.372  48.758  1
56449  95.162  -79.376  48.720  1
56450  95.187  -79.382  48.682  1
56451  95.211  -79.385  48.644  1
56452  95.235  -79.389  48.605  1
56453  95.259  -79.393  48.567  1
56454  95.282  -79.397  48.530  1
56455  95.306  -79.401  48.492  1
56456  95.330  -79.405  48.453  1
56457  95.364  -79.410  48.415  1
56458  95.401  -79.415  48.376  1
56459  95.438  -79.421  48.339  1
56460  95.475  -79.426  48.302  1
56461  95.512  -79.432  48.264  1
56462  95.532  -79.428  48.228  1
56463  95.549  -79.423  48.192  1
56464  95.566  -79.419  48.155  1
56465  95.583  -79.414  48.119  1
56466  95.593  -79.407  48.083  1
56467  95.603  -79.398  48.047  1
56468  95.612  -79.390  48.015  1
56469  95.621  -79.382  47.983  1
56470  95.631  -79.373  47.951  1
56471  95.640  -79.365  47.921  1
56472  95.650  -79.357  47.891  1
56473  95.659  -79.349  47.863  1
56474  95.669  -79.341  47.835  1
56475  95.678  -79.336  47.804  1
56476  95.687  -79.346  47.772  1
56477  95.696  -79.357  47.739  1
56478  95.705  -79.367  47.704  1
56479  95.730  -79.379  47.668  1
56480  95.756  -79.391  47.631  1
56481  95.783  -79.404  47.592  1
56482  95.810  -79.417  47.554  1
56483  95.837  -79.429  47.516  1
56484  95.877  -79.434  47.478  1
56485  95.906  -79.441  47.440  1
56486  95.925  -79.452  47.403  1
56487  95.949  -79.457  47.367  1
56488  95.974  -79.460  47.331  1
56489  95.999  -79.462  47.296  1
56490  96.024  -79.464  47.262  1
56491  96.049  -79.466  47.230  1
56492  96.074  -79.469  47.197  1
56493  96.099  -79.472  47.164  1
56494  96.124  -79.474  47.131  1
56495  96.150  -79.476  47.099  1
56502  96.318  -79.501  46.877  1
56503  96.342  -79.505  46.848  1
56504  96.366  -79.509  46.818  1
56505  96.389  -79.513  46.788  1
56506  96.413  -79.516  46.758  1
56507  96.437  -79.520  46.727  1
56508  96.461  -79.524  46.696  1
56509  96.485  -79.528  46.665  1
56510  96.509  -79.532  46.637  1
56511  96.533  -79.535  46.610  1
56512  96.556  -79.539  46.583  1
56513  96.581  -79.543  46.557  1
56514  96.604  -79.547  46.531  1
56515  96.628  -79.551  46.506  1
56516  96.652  -79.554  46.480  1
56517  96.676  -79.558  46.456  1
56518  96.700  -79.562  46.432  1
56519  96.724  -79.567  46.408  1
56520  96.747  -79.570  46.384  1
56521  96.771  -79.574  46.360  1
56522  96.795  -79.578  46.335  1
56523  96.819  -79.582  46.310  1
56524  96.843  -79.585  46.286  1
56525  96.867  -79.589  46.263  1
56526  96.891  -79.593  46.242  1
56527  96.902  -79.605  46.221  1
56528  96.913  -79.617  46.201  1
56529  96.924  -79.630  46.182  1
56530  96.954  -79.635  46.161  1
56531  97.003  -79.631  46.140  1
56532  97.038  -79.627  46.117  1
56533  97.060  -79.623  46.097  1
56534  97.082  -79.620  46.077  1
56535  97.103  -79.616  46.056  1
56536  97.125  -79.612  46.029  1
56537  97.147  -79.608  46.004  1
56538  97.158  -79.616  45.977  1
56539  97.149  -79.639  45.947  1
56540  97.124  -79.676  45.916  1
56541  97.132  -79.684  45.888  1
56542  97.139  -79.692  45.862  1
56543  97.146  -79.699  45.837  1
56544  97.153  -79.707  45.813  1
56545  97.160  -79.714  45.790  1
56546  97.167  -79.722  45.769  1
56547  97.174  -79.730  45.747  1
56548  97.181  -79.737  45.726  1
56549  97.188  -79.745  45.705  1
56550  97.195  -79.752  45.684  1
56551  97.203  -79.760  45.662  1
56552  97.210  -79.768  45.642  1
56553  97.217  -79.776  45.623  1
56959  93.176  -79.362  53.379  1
56960  93.190  -79.350  53.365  1
56961  93.204  -79.337  53.351  1
56962  93.218  -79.325  53.337  1
56963  93.232  -79.313  53.323  1
56964  93.247  -79.300  53.310  1
56965  93.260  -79.288  53.296  1
56966  93.274  -79.276  53.282  1
56967  93.288  -79.264  53.268  1
56968  93.304  -79.257  53.253  1
56969  93.314  -79.255  53.239  1
56970  93.324  -79.253  53.224  1
56971  93.333  -79.250  53.212  1
56972  93.345  -79.241  53.198  1
56973  93.356  -79.230  53.185  1
56974  93.367  -79.220  53.173  1
56975  93.379  -79.209  53.160  1
56976  93.393  -79.203  53.148  1
56977  93.407  -79.198  53.136  1
56978  93.421  -79.193  53.125  1
56979  93.436  -79.188  53.114  1
56980  93.450  -79.183  53.104  1
56981  93.465  -79.178  53.094  1
56982  93.479  -79.174  53.086  1
56983  93.494  -79.169  53.077  1
56984  93.508  -79.164  53.069  1
56985  93.522  -79.159  53.062  1
56986  93.537  -79.154  53.053  1
56987  93.551  -79.149  53.044  1
56988  93.566  -79.144  53.033  1
56989  93.578  -79.142  53.022  1
56990  93.590  -79.140  53.013  1
56991  93.603  -79.139  53.004  1
56992  93.615  -79.137  52.998  1
56993  93.627  -79.136  52.991  1
56994  93.639  -79.134  52.985  1
56995  93.651  -79.133  52.980  1
56996  93.663  -79.131  52.974  1
56997  93.676  -79.131  52.968  1
56998  93.687  -79.134  52.962  1
56999  93.702  -79.134  52.954  1
57000  93.716  -79.133  52.945  1
57001  93.731  -79.133  52.934  1
57002  93.746  -79.133  52.924  1
57003  93.761  -79.132  52.913  1
57004  93.775  -79.132  52.902  1
57005  93.790  -79.132  52.890  1
57006  93.804  -79.132  52.879  1
57007  93.819  -79.132  52.866  1
57008  93.834  -79.131  52.854  1
57009  93.848  -79.131  52.842  1
57010  93.846  -79.128  52.830  1
57011  93.837  -79.125  52.816  1
57012  93.838  -79.123  52.800  1
57013  93.843  -79.122  52.783  1
57014  93.847  -79.121  52.766  1
57015  93.852  -79.119  52.747  1
57016  93.868  -79.120  52.728  1
57017  93.889  -79.121  52.709  1
57018  93.900  -79.123  52.692  1
57019  93.908  -79.126  52.676  1
57020  93.915  -79.128  52.662  1
57021  93.922  -79.131  52.650  1
57022  93.928  -79.134  52.639  1
57023  93.930  -79.138  52.627  1
57024  93.932  -79.143  52.615  1
57025  93.934  -79.147  52.603  1
57026  93.936  -79.151  52.591  1
57027  93.938  -79.156  52.578  1
57028  93.940  -79.159  52.564  1
57029  93.942  -79.164  52.549  1
57030  93.944  -79.169  52.534  1
57031  93.946  -79.172  52.519  1
57032  93.948  -79.176  52.504  1
57033  93.953  -79.172  52.489  1
57034  93.959  -79.168  52.475  1
57035  93.965  -79.165  52.460  1
57036  93.972  -79.161  52.449  1
57037  93.978  -79.157  52.438  1
57038  93.984  -79.154  52.426  1
57039  93.991  -79.150  52.414  1
57040  93.997  -79.149  52.400  1
57041  94.002  -79.159  52.382  1
57042  94.006  -79.159  52.362  1
57043  94.010  -79.157  52.338  1
57044  94.009  -79.160  52.314  1
57045  94.008  -79.163  52.288  1
57046  94.007  -79.166  52.262  1
57047  94.006  -79.170  52.238  1
57048  94.005  -79.173  52.213  1
57049  94.004  -79.177  52.186  1
57050  94.003  -79.180  52.161  1
57051  94.003  -79.182  52.136  1
57052  94.003  -79.184  52.112  1
57053  94.011  -79.183  52.086  1
57054  94.022  -79.181  52.061  1
57055  94.033  -79.181  52.034  1
57056  94.044  -79.180  52.005  1
57057  94.055  -79.178  51.976  1
57058  94.066  -79.178  51.947  1
57059  94.073  -79.175  51.918  1
57060  94.072  -79.172  51.892  1
57061  94.070  -79.169  51.868  1
57062  94.069  -79.165  51.847  1
57063  94.068  -79.161  51.827  1
57064  94.069  -79.155  51.810  1
57065  94.091  -79.131  51.792  1
57066  94.113  -79.105  51.770  1
57067  94.135  -79.080  51.752  1
57068  94.156  -79.054  51.733  1
57069  94.179  -79.029  51.714  1
57070  94.200  -79.003  51.694  1
57071  94.222  -78.978  51.673  1
57072  94.250  -78.987  51.649  1
57073  94.263  -78.972  51.621  1
57074  94.274  -78.953  51.586  1
57075  94.294  -78.963  51.548  1
57076  94.314  -78.973  51.507  1
57077  94.334  -78.982  51.465  1
57078  94.354  -78.992  51.423  1
57079  94.373  -79.002  51.381  1
57080  94.394  -79.012  51.341  1
57081  94.415  -79.015  51.303  1
57082  94.437  -79.006  51.266  1
57083  94.461  -78.999  51.231  1
57084  94.484  -78.991  51.195  1
57085  94.506  -78.984  51.158  1
57086  94.530  -78.977  51.119  1
57087  94.547  -78.975  51.081  1
57088  94.558  -78.971  51.042  1
57089  94.569  -78.968  51.003  1
57090  94.580  -78.964  50.965  1
57091  94.592  -78.961  50.926  1
57092  94.603  -78.957  50.887  1
57093  94.614  -78.953  50.849  1
57094  94.626  -78.949  50.811  1
57095  94.637  -78.946  50.773  1
57096  94.648  -78.942  50.736  1
57097  94.660  -78.939  50.697  1
57098  94.671  -78.935  50.659  1
57099  94.682  -78.931  50.621  1
57100  94.693  -78.927  50.583  1
57101  94.702  -78.933  50.545  1
57102  94.710  -78.940  50.507  1
57103  94.718  -78.948  50.469  1
57104  94.727  -78.955  50.431  1
57105  94.735  -78.963  50.393  1
57106  94.744  -78.971  50.355  1
57107  94.752  -78.978  50.317  1
57108  94.760  -78.985  50.280  1
57109  94.768  -78.993  50.242  1
57110  94.776  -79.000  50.204  1
57111  94.785  -79.008  50.166  1
57112  94.793  -79.015  50.128  1
57113  94.802  -79.023  50.090  1
57114  94.810  -79.031  50.053  1
57115  94.818  -79.038  50.015  1
57116  94.826  -79.045  49.978  1
57117  94.835  -79.053  49.939  1
57123  94.884  -79.097  49.714  1
57124  94.893  -79.105  49.676  1
57125  94.901  -79.112  49.638  1
57126  94.909  -79.120  49.601  1
57127  94.917  -79.128  49.564  1
57128  94.926  -79.135  49.526  1
57129  94.934  -79.143  49.489  1
57130  94.942  -79.150  49.451  1
57131  94.951  -79.157  49.413  1
57132  94.959  -79.165  49.376  1
57133  94.967  -79.172  49.340  1
57134  94.975  -79.180  49.304  1
57135  94.984  -79.187  49.267  1
57136  94.996  -79.205  49.232  1
57137  95.008  -79.223  49.196  1
57138  95.020  -79.241  49.160  1
57139  95.033  -79.259  49.125  1
57140  95.045  -79.278  49.090  1
57141  95.057  -79.296  49.056  1
57142  95.069  -79.315  49.021  1
57143  95.082  -79.333  48.986  1
57144  95.090  -79.347  48.952  1
57145  95.104  -79.357  48.917  1
57146  95.116  -79.358  48.882  1
57147  95.127  -79.360  48.846  1
57148  95.139  -79.361  48.809  1
57149  95.151  -79.363  48.772  1
57150  95.175  -79.366  48.734  1
57151  95.199  -79.372  48.695  1
57152  95.224  -79.376  48.657  1
57153  95.249  -79.381  48.619  1
57154  95.274  -79.386  48.581  1
57155  95.299  -79.391  48.543  1
57156  95.323  -79.395  48.505  1
57157  95.348  -79.400  48.467  1
57158  95.373  -79.405  48.429  1
57159  95.397  -79.409  48.392  1
57160  95.427  -79.413  48.356  1
57161  95.465  -79.419  48.320  1
57162  95.503  -79.423  48.281  1
57163  95.542  -79.428  48.244  1
57164  95.570  -79.425  48.207  1
57165  95.580  -79.419  48.169  1
57166  95.590  -79.413  48.131  1
57167  95.600  -79.408  48.094  1
57168  95.610  -79.401  48.058  1
57169  95.620  -79.393  48.027  1
57170  95.629  -79.385  47.994  1
57171  95.638  -79.376  47.961  1
57172  95.648  -79.368  47.930  1
57173  95.657  -79.360  47.898  1
57174  95.667  -79.352  47.867  1
57175  95.676  -79.344  47.837  1
57176  95.686  -79.335  47.804  1
57177  95.695  -79.342  47.770  1
57178  95.704  -79.353  47.735  1
57179  95.713  -79.363  47.701  1
57180  95.722  -79.373  47.666  1
57181  95.732  -79.383  47.630  1
57182  95.741  -79.394  47.594  1
57183  95.768  -79.407  47.557  1
57184  95.818  -79.404  47.519  1
57185  95.872  -79.401  47.481  1
57186  95.925  -79.397  47.442  1
57187  95.945  -79.408  47.403  1
57188  95.965  -79.419  47.366  1
57189  95.984  -79.430  47.330  1
57190  96.004  -79.441  47.296  1
57191  96.023  -79.452  47.262  1
57192  96.043  -79.463  47.229  1
57193  96.062  -79.474  47.196  1
57194  96.084  -79.482  47.163  1
57195  96.108  -79.485  47.130  1
57196  96.133  -79.488  47.098  1
57197  96.159  -79.490  47.066  1
57198  96.184  -79.492  47.034  1
57199  96.209  -79.494  47.002  1
57200  96.234  -79.497  46.970  1
57201  96.259  -79.499  46.939  1
57202  96.285  -79.501  46.908  1
57203  96.310  -79.504  46.875  1
57204  96.334  -79.507  46.845  1
57205  96.360  -79.509  46.816  1
57206  96.385  -79.511  46.785  1
57207  96.410  -79.513  46.755  1
57208  96.435  -79.516  46.725  1
57209  96.460  -79.518  46.694  1
57210  96.485  -79.521  46.663  1
57211  96.511  -79.523  46.635  1
57212  96.536  -79.526  46.608  1
57213  96.560  -79.528  46.581  1
57214  96.586  -79.530  46.556  1
57215  96.611  -79.532  46.530  1
57216  96.636  -79.535  46.504  1
57217  96.661  -79.538  46.479  1
57218  96.686  -79.540  46.455  1
57219  96.712  -79.542  46.432  1
57220  96.737  -79.545  46.409  1
57221  96.762  -79.547  46.385  1
57222  96.787  -79.549  46.361  1
57223  96.812  -79.551  46.337  1
57224  96.837  -79.554  46.311  1
57225  96.862  -79.557  46.288  1
57226  96.884  -79.559  46.267  1
57227  96.895  -79.571  46.246  1
57228  96.906  -79.584  46.225  1
57229  96.917  -79.596  46.204  1
57230  96.928  -79.609  46.182  1
57231  96.969  -79.608  46.160  1
57232  97.008  -79.604  46.138  1
57233  97.030  -79.601  46.115  1
57234  97.051  -79.598  46.095  1
57235  97.073  -79.594  46.075  1
57236  97.095  -79.590  46.053  1
57237  97.119  -79.585  46.027  1
57238  97.147  -79.579  46.003  1
57239  97.174  -79.568  45.977  1
57240  97.202  -79.557  45.948  1
57241  97.181  -79.589  45.917  1
57242  97.155  -79.628  45.889  1
57243  97.139  -79.657  45.863  1
57244  97.146  -79.664  45.838  1
57245  97.153  -79.672  45.813  1
57246  97.160  -79.679  45.790  1
57247  97.167  -79.688  45.769  1
57248  97.174  -79.695  45.747  1
57249  97.181  -79.703  45.725  1
57250  97.188  -79.711  45.704  1
57251  97.195  -79.718  45.682  1
57252  97.203  -79.726  45.661  1
57253  97.210  -79.733  45.641  1
57254  97.217  -79.741  45.623  1
57255  97.224  -79.748  45.605  1
57660  93.175  -79.351  53.405  1
57661  93.189  -79.339  53.392  1
57662  93.203  -79.327  53.377  1
57663  93.217  -79.315  53.363  1
57664  93.231  -79.303  53.349  1
57665  93.246  -79.291  53.336  1
57666  93.260  -79.278  53.322  1
57667  93.273  -79.266  53.307  1
57668  93.288  -79.253  53.293  1
57669  93.304  -79.247  53.278  1
57670  93.314  -79.244  53.263  1
57671  93.324  -79.241  53.249  1
57672  93.334  -79.239  53.236  1
57673  93.343  -79.237  53.223  1
57674  93.355  -79.226  53.209  1
57675  93.366  -79.216  53.196  1
57676  93.377  -79.206  53.182  1
57677  93.389  -79.196  53.169  1
57678  93.396  -79.194  53.156  1
57679  93.415  -79.181  53.144  1
57680  93.430  -79.175  53.134  1
57681  93.444  -79.171  53.123  1
57682  93.459  -79.166  53.111  1
57683  93.473  -79.161  53.102  1
57684  93.488  -79.156  53.093  1
57685  93.502  -79.151  53.086  1
57686  93.516  -79.147  53.081  1
57687  93.531  -79.141  53.075  1
57688  93.546  -79.137  53.068  1
57689  93.560  -79.131  53.058  1
57690  93.573  -79.128  53.047  1
57691  93.585  -79.127  53.038  1
57692  93.598  -79.125  53.030  1
57693  93.610  -79.124  53.023  1
57694  93.622  -79.122  53.016  1
57695  93.634  -79.121  53.010  1
57696  93.646  -79.119  53.007  1
57697  93.658  -79.118  53.001  1
57698  93.666  -79.123  52.995  1
57699  93.679  -79.125  52.988  1
57700  93.695  -79.125  52.980  1
57701  93.710  -79.125  52.971  1
57702  93.725  -79.125  52.960  1
57703  93.740  -79.124  52.950  1
57704  93.755  -79.124  52.939  1
57705  93.769  -79.123  52.928  1
57706  93.784  -79.123  52.916  1
57707  93.798  -79.123  52.905  1
57708  93.813  -79.123  52.892  1
57709  93.828  -79.122  52.880  1
57710  93.842  -79.122  52.869  1
57711  93.840  -79.119  52.856  1
57712  93.839  -79.117  52.843  1
57713  93.844  -79.116  52.827  1
57714  93.848  -79.115  52.810  1
57715  93.853  -79.114  52.792  1
57716  93.857  -79.112  52.774  1
57717  93.862  -79.112  52.755  1
57718  93.881  -79.112  52.736  1
57719  93.890  -79.115  52.718  1
57720  93.897  -79.118  52.701  1
57721  93.905  -79.120  52.688  1
57722  93.912  -79.122  52.675  1
57723  93.919  -79.125  52.665  1
57724  93.921  -79.130  52.652  1
57725  93.923  -79.134  52.639  1
57726  93.925  -79.138  52.626  1
57727  93.927  -79.143  52.614  1
57728  93.929  -79.147  52.601  1
57729  93.931  -79.151  52.587  1
57730  93.933  -79.156  52.574  1
57731  93.935  -79.158  52.561  1
57732  93.939  -79.160  52.547  1
57733  93.942  -79.163  52.532  1
57734  93.946  -79.169  52.518  1
57735  93.953  -79.168  52.503  1
57736  93.960  -79.167  52.488  1
57737  93.967  -79.165  52.476  1
57738  93.973  -79.164  52.463  1
57739  93.980  -79.160  52.451  1
57740  93.986  -79.157  52.441  1
57741  93.992  -79.153  52.427  1
57742  93.999  -79.151  52.409  1
57743  94.003  -79.156  52.388  1
57744  94.004  -79.156  52.365  1
57745  94.003  -79.160  52.341  1
57746  94.002  -79.163  52.314  1
57747  94.001  -79.166  52.288  1
57748  94.001  -79.168  52.263  1
57749  94.001  -79.169  52.237  1
57750  94.002  -79.170  52.209  1
57751  94.002  -79.172  52.183  1
57752  94.002  -79.173  52.156  1
57753  94.002  -79.175  52.129  1
57754  94.010  -79.173  52.103  1
57755  94.019  -79.171  52.076  1
57756  94.030  -79.169  52.048  1
57757  94.041  -79.169  52.017  1
57758  94.052  -79.168  51.989  1
57759  94.063  -79.166  51.960  1
57760  94.074  -79.165  51.932  1
57761  94.073  -79.162  51.908  1
57762  94.072  -79.158  51.888  1
57763  94.070  -79.155  51.869  1
57764  94.069  -79.151  51.851  1
57765  94.082  -79.131  51.834  1
57766  94.101  -79.106  51.814  1
57767  94.122  -79.084  51.792  1
57768  94.143  -79.062  51.772  1
57769  94.165  -79.037  51.753  1
57770  94.187  -79.012  51.734  1
57771  94.209  -78.987  51.713  1
57772  94.231  -78.961  51.691  1
57773  94.257  -78.961  51.665  1
57774  94.267  -78.940  51.636  1
57775  94.286  -78.949  51.599  1
57776  94.306  -78.959  51.560  1
57777  94.326  -78.968  51.519  1
57778  94.346  -78.978  51.476  1
57779  94.366  -78.988  51.435  1
57780  94.386  -78.998  51.394  1
57781  94.406  -79.007  51.354  1
57782  94.426  -79.017  51.317  1
57783  94.447  -79.023  51.281  1
57784  94.469  -79.015  51.247  1
57785  94.492  -79.007  51.212  1
57786  94.514  -78.996  51.176  1
57787  94.535  -78.970  51.139  1
57788  94.553  -78.971  51.100  1
57789  94.563  -78.964  51.060  1
57790  94.574  -78.959  51.020  1
57791  94.586  -78.955  50.980  1
57792  94.597  -78.952  50.941  1
57793  94.609  -78.948  50.902  1
57794  94.620  -78.944  50.864  1
57795  94.631  -78.940  50.825  1
57796  94.642  -78.937  50.787  1
57797  94.653  -78.933  50.749  1
57798  94.665  -78.930  50.710  1
57799  94.676  -78.926  50.672  1
57800  94.687  -78.922  50.634  1
57801  94.699  -78.918  50.596  1
57802  94.710  -78.915  50.558  1
57803  94.718  -78.921  50.521  1
57804  94.727  -78.927  50.482  1
57805  94.735  -78.935  50.443  1
57806  94.744  -78.943  50.405  1
57807  94.752  -78.950  50.367  1
57808  94.760  -78.958  50.329  1
57809  94.768  -78.965  50.292  1
57810  94.777  -78.973  50.253  1
57811  94.785  -78.980  50.215  1
57812  94.793  -78.987  50.178  1
57813  94.802  -78.995  50.139  1
57814  94.810  -79.002  50.101  1
57815  94.818  -79.010  50.065  1
57816  94.826  -79.018  50.027  1
57817  94.835  -79.025  49.990  1
57818  94.843  -79.032  49.953  1
57819  94.851  -79.040  49.915  1
57820  94.859  -79.047  49.877  1
57821  94.868  -79.055  49.840  1
57822  94.876  -79.062  49.802  1
57823  94.884  -79.070  49.765  1
57824  94.893  -79.078  49.727  1
57825  94.901  -79.085  49.689  1
57826  94.909  -79.092  49.650  1
57827  94.917  -79.100  49.612  1
57828  94.926  -79.107  49.575  1
57829  94.934  -79.115  49.538  1
57830  94.943  -79.122  49.501  1
57831  94.951  -79.130  49.463  1
57832  94.959  -79.137  49.424  1
57833  94.967  -79.144  49.387  1
57834  94.979  -79.160  49.351  1
57835  94.991  -79.178  49.315  1
57836  95.003  -79.197  49.279  1
57837  95.016  -79.215  49.243  1
57838  95.028  -79.233  49.208  1
57839  95.040  -79.251  49.173  1
57840  95.052  -79.270  49.138  1
57841  95.062  -79.286  49.104  1
57842  95.069  -79.299  49.069  1
57843  95.075  -79.311  49.035  1
57844  95.082  -79.324  49.001  1
57845  95.096  -79.337  48.967  1
57846  95.114  -79.345  48.933  1
57847  95.129  -79.348  48.897  1
57848  95.141  -79.350  48.861  1
57849  95.153  -79.351  48.823  1
57850  95.164  -79.353  48.785  1
57851  95.187  -79.357  48.748  1
57852  95.212  -79.362  48.710  1
57853  95.237  -79.366  48.672  1
57854  95.261  -79.371  48.634  1
57855  95.286  -79.376  48.597  1
57856  95.311  -79.381  48.558  1
57857  95.336  -79.385  48.520  1
57858  95.361  -79.390  48.483  1
57859  95.386  -79.395  48.445  1
57860  95.410  -79.400  48.409  1
57861  95.430  -79.400  48.373  1
57862  95.461  -79.408  48.337  1
57863  95.500  -79.413  48.298  1
57864  95.540  -79.416  48.259  1
57865  95.569  -79.412  48.221  1
57866  95.583  -79.404  48.182  1
57867  95.593  -79.399  48.143  1
57868  95.603  -79.394  48.105  1
57869  95.613  -79.388  48.068  1
57870  95.623  -79.382  48.035  1
57871  95.633  -79.377  48.002  1
57872  95.644  -79.372  47.968  1
57873  95.654  -79.366  47.935  1
57874  95.664  -79.360  47.902  1
57875  95.674  -79.355  47.869  1
57876  95.684  -79.347  47.836  1
57877  95.693  -79.338  47.802  1
57878  95.702  -79.338  47.767  1
57879  95.712  -79.349  47.731  1
57880  95.721  -79.359  47.697  1
57881  95.731  -79.369  47.663  1
57882  95.741  -79.379  47.628  1
57883  95.751  -79.389  47.593  1
57884  95.774  -79.395  47.557  1
57885  95.827  -79.391  47.520  1
57886  95.879  -79.386  47.482  1
57887  95.932  -79.382  47.442  1
57888  95.961  -79.378  47.403  1
57889  95.981  -79.386  47.365  1
57890  96.002  -79.394  47.329  1
57891  96.022  -79.402  47.295  1
57892  96.042  -79.410  47.261  1
57893  96.062  -79.419  47.228  1
57894  96.082  -79.431  47.194  1
57895  96.101  -79.441  47.161  1
57896  96.121  -79.453  47.128  1
57897  96.141  -79.463  47.096  1
57898  96.160  -79.475  47.063  1
57899  96.180  -79.485  47.031  1
57900  96.199  -79.497  47.000  1
57901  96.219  -79.507  46.968  1
57902  96.243  -79.510  46.937  1
57903  96.268  -79.513  46.905  1
57904  96.294  -79.515  46.873  1
57905  96.319  -79.517  46.843  1
57906  96.344  -79.520  46.813  1
57907  96.369  -79.523  46.782  1
57908  96.394  -79.525  46.752  1
57909  96.419  -79.527  46.722  1
57910  96.444  -79.529  46.691  1
57911  96.469  -79.532  46.660  1
57912  96.495  -79.534  46.632  1
57913  96.520  -79.537  46.605  1
57914  96.545  -79.539  46.578  1
57915  96.570  -79.541  46.553  1
57916  96.595  -79.544  46.528  1
57917  96.620  -79.546  46.502  1
57918  96.645  -79.548  46.477  1
57919  96.670  -79.551  46.454  1
57920  96.695  -79.554  46.432  1
57921  96.721  -79.556  46.409  1
57922  96.746  -79.558  46.386  1
57923  96.771  -79.560  46.362  1
57924  96.796  -79.563  46.338  1
57925  96.821  -79.565  46.313  1
57926  96.851  -79.563  46.291  1
57927  96.877  -79.558  46.270  1
57928  96.897  -79.554  46.249  1
57929  96.910  -79.563  46.228  1
57930  96.921  -79.576  46.206  1
57931  96.936  -79.586  46.182  1
57932  96.978  -79.582  46.159  1
57933  97.000  -79.579  46.135  1
57934  97.021  -79.575  46.113  1
57935  97.045  -79.570  46.091  1
57936  97.073  -79.564  46.069  1
57937  97.100  -79.557  46.047  1
57938  97.127  -79.551  46.023  1
57939  97.155  -79.544  45.998  1
57940  97.182  -79.532  45.972  1
57941  97.199  -79.530  45.944  1
57942  97.214  -79.536  45.915  1
57943  97.213  -79.541  45.888  1
57944  97.187  -79.578  45.862  1
57945  97.161  -79.616  45.838  1
57946  97.153  -79.638  45.813  1
57947  97.160  -79.645  45.789  1
57948  97.167  -79.653  45.766  1
57949  97.174  -79.661  45.745  1
57950  97.181  -79.668  45.724  1
57951  97.188  -79.676  45.702  1
57952  97.195  -79.683  45.681  1
57953  97.203  -79.691  45.660  1
57954  97.210  -79.698  45.640  1
57955  97.217  -79.707  45.622  1
57956  97.224  -79.714  45.604  1
57957  97.231  -79.722  45.585  1
58362  93.188  -79.328  53.417  1
58363  93.202  -79.316  53.404  1
58364  93.216  -79.304  53.389  1
58365  93.230  -79.292  53.375  1
58366  93.245  -79.280  53.361  1
58367  93.259  -79.268  53.347  1
58368  93.273  -79.256  53.332  1
58369  93.287  -79.244  53.317  1
58370  93.305  -79.235  53.302  1
58371  93.314  -79.233  53.288  1
58372  93.324  -79.231  53.273  1
58373  93.334  -79.228  53.260  1
58374  93.344  -79.225  53.247  1
58375  93.353  -79.222  53.233  1
58376  93.365  -79.212  53.219  1
58377  93.376  -79.202  53.205  1
58378  93.388  -79.191  53.191  1
58379  93.398  -79.182  53.178  1
58380  93.406  -79.178  53.165  1
58381  93.417  -79.175  53.153  1
58382  93.436  -79.162  53.142  1
58383  93.453  -79.153  53.130  1
58384  93.468  -79.149  53.120  1
58385  93.482  -79.143  53.111  1
58386  93.496  -79.139  53.104  1
58387  93.511  -79.134  53.099  1
58388  93.525  -79.129  53.095  1
58389  93.540  -79.125  53.091  1
58390  93.554  -79.119  53.083  1
58391  93.569  -79.115  53.074  1
58392  93.581  -79.113  53.065  1
58393  93.593  -79.112  53.058  1
58394  93.605  -79.110  53.051  1
58395  93.617  -79.109  53.045  1
58396  93.630  -79.107  53.039  1
58397  93.642  -79.106  53.034  1
58398  93.649  -79.110  53.029  1
58399  93.657  -79.115  53.023  1
58400  93.671  -79.117  53.016  1
58401  93.688  -79.116  53.007  1
58402  93.703  -79.116  52.997  1
58403  93.718  -79.116  52.987  1
58404  93.733  -79.115  52.976  1
58405  93.748  -79.115  52.966  1
58406  93.763  -79.115  52.955  1
58407  93.777  -79.115  52.943  1
58408  93.792  -79.114  52.931  1
58409  93.807  -79.114  52.919  1
58410  93.822  -79.113  52.906  1
58411  93.837  -79.113  52.894  1
58412  93.840  -79.112  52.882  1
58413  93.845  -79.110  52.869  1
58414  93.849  -79.109  52.855  1
58415  93.854  -79.108  52.838  1
58416  93.858  -79.107  52.819  1
58417  93.863  -79.106  52.800  1
58418  93.867  -79.105  52.781  1
58419  93.872  -79.104  52.762  1
58420  93.880  -79.106  52.743  1
58421  93.887  -79.109  52.727  1
58422  93.894  -79.112  52.713  1
58423  93.902  -79.114  52.701  1
58424  93.909  -79.117  52.689  1
58425  93.912  -79.121  52.677  1
58426  93.914  -79.125  52.663  1
58427  93.915  -79.130  52.649  1
58428  93.918  -79.133  52.637  1
58429  93.921  -79.135  52.624  1
58430  93.924  -79.137  52.611  1
58431  93.928  -79.140  52.599  1
58432  93.931  -79.142  52.586  1
58433  93.934  -79.144  52.573  1
58434  93.937  -79.147  52.559  1
58435  93.941  -79.155  52.546  1
58436  93.946  -79.160  52.531  1
58437  93.953  -79.159  52.516  1
58438  93.960  -79.158  52.504  1
58439  93.966  -79.157  52.492  1
58440  93.973  -79.156  52.479  1
58441  93.980  -79.154  52.468  1
58442  93.987  -79.153  52.453  1
58443  93.994  -79.152  52.436  1
58444  94.000  -79.151  52.414  1
58445  94.000  -79.153  52.391  1
58446  94.000  -79.154  52.366  1
58447  94.000  -79.156  52.339  1
58448  94.000  -79.157  52.312  1
58449  94.000  -79.159  52.285  1
58450  94.000  -79.159  52.258  1
58451  94.000  -79.161  52.228  1
58452  94.001  -79.162  52.201  1
58453  94.001  -79.164  52.172  1
58454  94.002  -79.165  52.143  1
58455  94.010  -79.163  52.116  1
58456  94.019  -79.161  52.089  1
58457  94.028  -79.159  52.060  1
58458  94.037  -79.158  52.030  1
58459  94.048  -79.156  52.003  1
58460  94.059  -79.156  51.976  1
58461  94.070  -79.155  51.949  1
58462  94.074  -79.152  51.928  1
58463  94.073  -79.148  51.910  1
58464  94.071  -79.144  51.893  1
58465  94.076  -79.134  51.875  1
58466  94.095  -79.108  51.856  1
58467  94.113  -79.081  51.836  1
58468  94.133  -79.057  51.813  1
58469  94.154  -79.035  51.792  1
58470  94.176  -79.013  51.773  1
58471  94.197  -78.991  51.754  1
58472  94.218  -78.969  51.732  1
58473  94.240  -78.944  51.708  1
58474  94.260  -78.929  51.681  1
58475  94.278  -78.935  51.649  1
58476  94.298  -78.945  51.611  1
58477  94.319  -78.954  51.571  1
58478  94.338  -78.964  51.531  1
58479  94.358  -78.974  51.488  1
58480  94.378  -78.984  51.447  1
58481  94.398  -78.993  51.406  1
58482  94.418  -79.003  51.367  1
58483  94.438  -79.013  51.331  1
58484  94.458  -79.023  51.297  1
58485  94.478  -79.030  51.264  1
58486  94.495  -78.984  51.229  1
58487  94.516  -78.968  51.194  1
58488  94.538  -78.959  51.157  1
58489  94.556  -78.961  51.118  1
58490  94.570  -78.962  51.078  1
58491  94.581  -78.955  51.037  1
58492  94.592  -78.949  50.998  1
58493  94.603  -78.943  50.958  1
58494  94.614  -78.939  50.918  1
58495  94.625  -78.935  50.879  1
58496  94.636  -78.931  50.840  1
58497  94.647  -78.927  50.801  1
58498  94.659  -78.924  50.763  1
58499  94.670  -78.920  50.725  1
58500  94.682  -78.917  50.687  1
58501  94.693  -78.913  50.648  1
58502  94.704  -78.909  50.610  1
58503  94.715  -78.905  50.572  1
58504  94.726  -78.902  50.535  1
58505  94.736  -78.908  50.496  1
58506  94.744  -78.915  50.456  1
58507  94.752  -78.922  50.418  1
58508  94.760  -78.930  50.380  1
58509  94.768  -78.937  50.342  1
58510  94.777  -78.945  50.305  1
58511  94.785  -78.952  50.267  1
58512  94.793  -78.960  50.229  1
58513  94.802  -78.968  50.191  1
58514  94.810  -78.974  50.153  1
58515  94.818  -78.982  50.115  1
58516  94.827  -78.990  50.078  1
58517  94.835  -78.997  50.041  1
58518  94.843  -79.005  50.003  1
58519  94.851  -79.012  49.966  1
58520  94.859  -79.020  49.928  1
58521  94.868  -79.027  49.890  1
58522  94.876  -79.034  49.852  1
58523  94.885  -79.042  49.816  1
58524  94.893  -79.049  49.778  1
58525  94.901  -79.057  49.740  1
58526  94.909  -79.065  49.702  1
58527  94.917  -79.072  49.663  1
58528  94.926  -79.079  49.625  1
58529  94.934  -79.087  49.588  1
58530  94.943  -79.094  49.551  1
58531  94.951  -79.102  49.512  1
58532  94.961  -79.115  49.474  1
58533  94.974  -79.134  49.437  1
58534  94.986  -79.152  49.400  1
58535  94.998  -79.170  49.364  1
58536  95.011  -79.188  49.328  1
58537  95.023  -79.207  49.292  1
58538  95.034  -79.225  49.256  1
58539  95.041  -79.237  49.221  1
58540  95.047  -79.250  49.187  1
58541  95.054  -79.263  49.153  1
58542  95.060  -79.275  49.119  1
58543  95.066  -79.288  49.085  1
58544  95.074  -79.300  49.051  1
58545  95.089  -79.313  49.017  1
58546  95.103  -79.325  48.983  1
58547  95.122  -79.333  48.948  1
58548  95.142  -79.338  48.912  1
58549  95.154  -79.340  48.875  1
58550  95.166  -79.341  48.837  1
58551  95.178  -79.343  48.801  1
58552  95.199  -79.347  48.764  1
58553  95.225  -79.352  48.726  1
58554  95.249  -79.357  48.689  1
58555  95.274  -79.361  48.652  1
58556  95.299  -79.366  48.614  1
58557  95.324  -79.371  48.576  1
58558  95.348  -79.375  48.539  1
58559  95.373  -79.381  48.502  1
58560  95.398  -79.385  48.465  1
58561  95.416  -79.380  48.427  1
58562  95.431  -79.388  48.389  1
58563  95.458  -79.397  48.350  1
58564  95.497  -79.401  48.311  1
58565  95.537  -79.406  48.271  1
58566  95.566  -79.400  48.232  1
58567  95.585  -79.390  48.193  1
58568  95.595  -79.384  48.153  1
58569  95.606  -79.379  48.113  1
58570  95.616  -79.373  48.074  1
58571  95.626  -79.368  48.039  1
58572  95.636  -79.362  48.004  1
58573  95.647  -79.357  47.969  1
58574  95.657  -79.351  47.935  1
58575  95.667  -79.346  47.903  1
58576  95.677  -79.340  47.870  1
58577  95.687  -79.335  47.836  1
58578  95.697  -79.329  47.800  1
58579  95.713  -79.332  47.764  1
58580  95.724  -79.344  47.728  1
58581  95.734  -79.354  47.695  1
58582  95.744  -79.365  47.660  1
58583  95.754  -79.375  47.625  1
58584  95.764  -79.385  47.589  1
58585  95.789  -79.390  47.553  1
58586  95.841  -79.385  47.516  1
58587  95.894  -79.381  47.478  1
58588  95.923  -79.360  47.439  1
58589  95.942  -79.344  47.401  1
58590  95.989  -79.366  47.364  1
58591  96.014  -79.375  47.328  1
58592  96.034  -79.384  47.293  1
58593  96.054  -79.392  47.259  1
58594  96.075  -79.400  47.226  1
58595  96.095  -79.408  47.192  1
58596  96.116  -79.416  47.159  1
58597  96.136  -79.425  47.126  1
58598  96.157  -79.432  47.093  1
58599  96.177  -79.441  47.061  1
58600  96.197  -79.449  47.029  1
58601  96.218  -79.457  46.997  1
58602  96.238  -79.465  46.966  1
58603  96.258  -79.475  46.934  1
58604  96.277  -79.485  46.902  1
58605  96.297  -79.497  46.871  1
58606  96.316  -79.507  46.840  1
58607  96.336  -79.519  46.809  1
58608  96.356  -79.529  46.779  1
58609  96.378  -79.535  46.748  1
58610  96.403  -79.538  46.717  1
58611  96.429  -79.541  46.687  1
58612  96.454  -79.543  46.656  1
58613  96.478  -79.545  46.629  1
58614  96.504  -79.548  46.602  1
58615  96.529  -79.550  46.575  1
58616  96.554  -79.552  46.550  1
58617  96.579  -79.555  46.525  1
58618  96.604  -79.557  46.500  1
58619  96.629  -79.560  46.476  1
58620  96.655  -79.562  46.453  1
58621  96.680  -79.564  46.431  1
58622  96.704  -79.567  46.408  1
58623  96.730  -79.569  46.386  1
58624  96.755  -79.572  46.363  1
58625  96.780  -79.574  46.341  1
58626  96.811  -79.571  46.316  1
58627  96.844  -79.566  46.294  1
58628  96.869  -79.561  46.274  1
58629  96.888  -79.557  46.252  1
58630  96.908  -79.553  46.230  1
58631  96.925  -79.554  46.208  1
58632  96.948  -79.560  46.184  1
58633  96.970  -79.556  46.158  1
58634  96.998  -79.550  46.133  1
58635  97.025  -79.544  46.110  1
58636  97.053  -79.537  46.086  1
58637  97.081  -79.531  46.063  1
58638  97.108  -79.525  46.040  1
58639  97.136  -79.518  46.016  1
58640  97.163  -79.507  45.991  1
58641  97.183  -79.502  45.966  1
58642  97.196  -79.505  45.940  1
58643  97.208  -79.508  45.913  1
58644  97.223  -79.517  45.887  1
58645  97.222  -79.522  45.862  1
58646  97.220  -79.527  45.837  1
58647  97.193  -79.566  45.812  1
58648  97.167  -79.604  45.788  1
58649  97.167  -79.618  45.765  1
58650  97.174  -79.626  45.743  1
58651  97.181  -79.634  45.721  1
58652  97.188  -79.642  45.700  1
58653  97.195  -79.649  45.679  1
58654  97.203  -79.657  45.658  1
58655  97.210  -79.664  45.638  1
58656  97.217  -79.672  45.620  1
58657  97.224  -79.679  45.602  1
58658  97.231  -79.687  45.584  1
58659  97.238  -79.695  45.566  1
58673  97.337  -79.802  45.313  1
59064  93.201  -79.306  53.429  1
59065  93.215  -79.294  53.415  1
59066  93.229  -79.281  53.401  1
59067  93.243  -79.269  53.386  1
59068  93.258  -79.257  53.372  1
59069  93.272  -79.245  53.357  1
59070  93.286  -79.233  53.342  1
59071  93.305  -79.225  53.327  1
59072  93.314  -79.222  53.312  1
59073  93.325  -79.219  53.297  1
59074  93.334  -79.217  53.284  1
59075  93.344  -79.215  53.270  1
59076  93.353  -79.212  53.257  1
59077  93.363  -79.208  53.243  1
59078  93.375  -79.198  53.228  1
59079  93.387  -79.187  53.214  1
59080  93.398  -79.177  53.200  1
59081  93.407  -79.169  53.187  1
59082  93.416  -79.162  53.174  1
59083  93.422  -79.165  53.161  1
59084  93.438  -79.156  53.150  1
59085  93.457  -79.143  53.140  1
59086  93.476  -79.131  53.130  1
59087  93.490  -79.126  53.122  1
59088  93.505  -79.122  53.117  1
59089  93.519  -79.117  53.115  1
59090  93.534  -79.112  53.113  1
59091  93.548  -79.107  53.109  1
59092  93.563  -79.102  53.101  1
59093  93.576  -79.099  53.094  1
59094  93.588  -79.097  53.086  1
59095  93.601  -79.096  53.080  1
59096  93.613  -79.094  53.074  1
59097  93.625  -79.093  53.068  1
59098  93.633  -79.097  53.063  1
59099  93.640  -79.102  53.057  1
59100  93.648  -79.107  53.051  1
59101  93.663  -79.108  53.043  1
59102  93.681  -79.108  53.034  1
59103  93.697  -79.108  53.025  1
59104  93.711  -79.107  53.015  1
59105  93.726  -79.107  53.005  1
59106  93.741  -79.106  52.994  1
59107  93.756  -79.106  52.984  1
59108  93.771  -79.106  52.972  1
59109  93.786  -79.106  52.959  1
59110  93.800  -79.106  52.947  1
59111  93.816  -79.105  52.934  1
59112  93.830  -79.103  52.921  1
59113  93.837  -79.101  52.908  1
59114  93.841  -79.100  52.894  1
59115  93.845  -79.099  52.880  1
59116  93.849  -79.097  52.864  1
59117  93.853  -79.096  52.845  1
59118  93.856  -79.094  52.827  1
59119  93.860  -79.093  52.808  1
59120  93.868  -79.090  52.788  1
59121  93.875  -79.092  52.769  1
59122  93.882  -79.096  52.753  1
59123  93.888  -79.100  52.739  1
59124  93.894  -79.103  52.726  1
59125  93.900  -79.106  52.714  1
59126  93.904  -79.109  52.700  1
59127  93.907  -79.112  52.686  1
59128  93.910  -79.114  52.672  1
59129  93.914  -79.116  52.661  1
59130  93.917  -79.118  52.648  1
59131  93.920  -79.122  52.636  1
59132  93.923  -79.124  52.623  1
59133  93.926  -79.126  52.611  1
59134  93.929  -79.128  52.599  1
59135  93.933  -79.131  52.586  1
59136  93.936  -79.140  52.573  1
59137  93.940  -79.148  52.560  1
59138  93.946  -79.152  52.545  1
59139  93.953  -79.150  52.533  1
59140  93.960  -79.150  52.521  1
59141  93.966  -79.148  52.508  1
59142  93.973  -79.147  52.495  1
59143  93.980  -79.146  52.480  1
59144  93.993  -79.140  52.461  1
59145  94.000  -79.139  52.440  1
59146  94.000  -79.141  52.416  1
59147  93.999  -79.143  52.390  1
59148  93.999  -79.146  52.362  1
59149  93.999  -79.148  52.334  1
59150  93.999  -79.149  52.306  1
59151  93.999  -79.150  52.276  1
59152  93.999  -79.152  52.244  1
59153  93.999  -79.153  52.215  1
59154  94.000  -79.155  52.185  1
59155  94.002  -79.156  52.155  1
59156  94.010  -79.153  52.127  1
59157  94.019  -79.152  52.100  1
59158  94.028  -79.150  52.072  1
59159  94.036  -79.148  52.043  1
59160  94.045  -79.146  52.017  1
59161  94.056  -79.144  51.993  1
59162  94.067  -79.143  51.970  1
59163  94.075  -79.142  51.951  1
59164  94.074  -79.138  51.934  1
59165  94.072  -79.134  51.917  1
59166  94.088  -79.111  51.899  1
59167  94.107  -79.084  51.879  1
59168  94.126  -79.057  51.856  1
59169  94.144  -79.031  51.832  1
59170  94.165  -79.009  51.811  1
59171  94.186  -78.987  51.791  1
59172  94.207  -78.965  51.772  1
59173  94.228  -78.943  51.750  1
59174  94.250  -78.921  51.724  1
59175  94.266  -78.911  51.694  1
59176  94.285  -78.919  51.660  1
59177  94.304  -78.927  51.620  1
59178  94.324  -78.937  51.580  1
59179  94.343  -78.945  51.541  1
59180  94.362  -78.953  51.500  1
59181  94.382  -78.962  51.460  1
59182  94.401  -78.971  51.419  1
59183  94.420  -78.979  51.381  1
59184  94.439  -78.987  51.346  1
59185  94.459  -78.996  51.313  1
59186  94.476  -78.971  51.281  1
59187  94.498  -78.965  51.247  1
59188  94.520  -78.956  51.212  1
59189  94.542  -78.949  51.175  1
59190  94.559  -78.951  51.136  1
59191  94.575  -78.956  51.095  1
59192  94.588  -78.953  51.055  1
59193  94.599  -78.947  51.016  1
59194  94.609  -78.940  50.976  1
59195  94.620  -78.934  50.936  1
59196  94.631  -78.927  50.895  1
59197  94.642  -78.922  50.856  1
59198  94.653  -78.918  50.817  1
59199  94.664  -78.915  50.778  1
59200  94.676  -78.911  50.740  1
59201  94.687  -78.908  50.702  1
59202  94.698  -78.904  50.663  1
59203  94.709  -78.900  50.625  1
59204  94.720  -78.896  50.587  1
59205  94.732  -78.893  50.549  1
59206  94.743  -78.889  50.511  1
59207  94.752  -78.895  50.471  1
59208  94.760  -78.902  50.433  1
59209  94.769  -78.909  50.395  1
59210  94.777  -78.917  50.356  1
59211  94.785  -78.924  50.318  1
59212  94.793  -78.932  50.281  1
59213  94.802  -78.940  50.243  1
59214  94.810  -78.947  50.204  1
59215  94.818  -78.955  50.167  1
59216  94.827  -78.962  50.129  1
59217  94.835  -78.969  50.092  1
59218  94.843  -78.977  50.054  1
59219  94.851  -78.984  50.017  1
59220  94.859  -78.992  49.979  1
59221  94.868  -78.999  49.942  1
59222  94.876  -79.007  49.904  1
59223  94.885  -79.015  49.866  1
59224  94.893  -79.021  49.830  1
59225  94.901  -79.029  49.792  1
59226  94.909  -79.037  49.754  1
59227  94.918  -79.044  49.715  1
59228  94.926  -79.052  49.677  1
59229  94.934  -79.059  49.639  1
59230  94.944  -79.071  49.601  1
59231  94.957  -79.089  49.564  1
59232  94.969  -79.107  49.525  1
59233  94.981  -79.125  49.487  1
59234  94.993  -79.143  49.450  1
59235  95.005  -79.162  49.413  1
59236  95.013  -79.176  49.377  1
59237  95.020  -79.188  49.341  1
59238  95.026  -79.201  49.305  1
59239  95.032  -79.214  49.271  1
59240  95.039  -79.227  49.237  1
59241  95.045  -79.239  49.202  1
59242  95.051  -79.252  49.169  1
59243  95.058  -79.265  49.136  1
59244  95.067  -79.277  49.102  1
59245  95.082  -79.290  49.068  1
59246  95.096  -79.303  49.033  1
59247  95.111  -79.315  48.999  1
59248  95.131  -79.321  48.963  1
59249  95.151  -79.326  48.926  1
59250  95.168  -79.331  48.889  1
59251  95.179  -79.332  48.852  1
59252  95.191  -79.333  48.816  1
59253  95.212  -79.338  48.780  1
59254  95.237  -79.342  48.743  1
59255  95.262  -79.347  48.705  1
59256  95.286  -79.351  48.667  1
59257  95.311  -79.357  48.630  1
59258  95.336  -79.361  48.592  1
59259  95.361  -79.366  48.553  1
59260  95.384  -79.368  48.515  1
59261  95.402  -79.362  48.476  1
59262  95.419  -79.360  48.436  1
59263  95.432  -79.375  48.396  1
59264  95.456  -79.386  48.356  1
59265  95.495  -79.391  48.316  1
59266  95.534  -79.394  48.276  1
59267  95.563  -79.389  48.237  1
59268  95.586  -79.375  48.197  1
59269  95.598  -79.369  48.156  1
59270  95.608  -79.364  48.116  1
59271  95.618  -79.358  48.075  1
59272  95.628  -79.353  48.038  1
59273  95.639  -79.347  48.002  1
59274  95.649  -79.342  47.966  1
59275  95.659  -79.336  47.932  1
59276  95.670  -79.331  47.899  1
59277  95.680  -79.325  47.865  1
59278  95.690  -79.320  47.831  1
59279  95.700  -79.314  47.794  1
59280  95.723  -79.317  47.757  1
59281  95.736  -79.340  47.721  1
59282  95.746  -79.350  47.687  1
59283  95.757  -79.360  47.652  1
59284  95.767  -79.370  47.616  1
59285  95.777  -79.381  47.581  1
59286  95.804  -79.385  47.544  1
59287  95.856  -79.380  47.508  1
59288  95.909  -79.375  47.470  1
59289  95.912  -79.337  47.433  1
59290  95.922  -79.310  47.396  1
59291  95.970  -79.332  47.359  1
59292  96.018  -79.353  47.324  1
59293  96.046  -79.366  47.289  1
59294  96.066  -79.373  47.255  1
59295  96.087  -79.382  47.222  1
59296  96.107  -79.390  47.188  1
59297  96.128  -79.398  47.155  1
59298  96.148  -79.407  47.122  1
59299  96.169  -79.414  47.088  1
59300  96.189  -79.422  47.056  1
59301  96.209  -79.431  47.024  1
59302  96.230  -79.439  46.993  1
59303  96.250  -79.447  46.962  1
59304  96.270  -79.455  46.929  1
59305  96.291  -79.463  46.897  1
59306  96.311  -79.472  46.865  1
59307  96.331  -79.479  46.835  1
59308  96.352  -79.488  46.804  1
59309  96.372  -79.496  46.774  1
59310  96.393  -79.504  46.743  1
59311  96.413  -79.512  46.713  1
59312  96.434  -79.520  46.682  1
59313  96.453  -79.530  46.652  1
59314  96.473  -79.541  46.625  1
59315  96.493  -79.552  46.598  1
59316  96.513  -79.561  46.571  1
59317  96.538  -79.563  46.546  1
59318  96.563  -79.566  46.521  1
59319  96.588  -79.568  46.497  1
59320  96.613  -79.571  46.473  1
59321  96.639  -79.573  46.450  1
59322  96.664  -79.576  46.428  1
59323  96.689  -79.578  46.407  1
59324  96.714  -79.580  46.386  1
59325  96.739  -79.582  46.365  1
59326  96.770  -79.579  46.344  1
59327  96.804  -79.574  46.321  1
59328  96.837  -79.568  46.300  1
59329  96.860  -79.564  46.279  1
59330  96.880  -79.560  46.256  1
59331  96.900  -79.554  46.233  1
59332  96.925  -79.543  46.209  1
59333  96.951  -79.529  46.185  1
59334  96.978  -79.523  46.156  1
59335  97.006  -79.516  46.130  1
59336  97.033  -79.510  46.107  1
59337  97.061  -79.504  46.081  1
59338  97.089  -79.498  46.057  1
59339  97.116  -79.491  46.034  1
59340  97.144  -79.483  46.010  1
59341  97.168  -79.475  45.986  1
59342  97.180  -79.477  45.962  1
59343  97.192  -79.480  45.937  1
59344  97.205  -79.483  45.911  1
59345  97.217  -79.486  45.886  1
59346  97.232  -79.498  45.860  1
59347  97.231  -79.503  45.835  1
59348  97.230  -79.508  45.810  1
59349  97.226  -79.516  45.786  1
59350  97.200  -79.554  45.764  1
59351  97.174  -79.592  45.741  1
59352  97.182  -79.599  45.719  1
59353  97.189  -79.607  45.697  1
59354  97.196  -79.614  45.677  1
59355  97.203  -79.622  45.656  1
59356  97.210  -79.629  45.637  1
59357  97.217  -79.637  45.618  1
59358  97.224  -79.645  45.601  1
59359  97.231  -79.653  45.583  1
59360  97.238  -79.661  45.564  1
59361  97.245  -79.668  45.547  1
59362  97.252  -79.676  45.528  1
59363  97.259  -79.683  45.509  1
59364  97.266  -79.691  45.492  1
59365  97.274  -79.698  45.474  1
59366  97.281  -79.706  45.456  1
59367  97.288  -79.714  45.438  1
59368  97.295  -79.721  45.419  1
59369  97.302  -79.729  45.400  1
59370  97.309  -79.736  45.382  1
59371  97.316  -79.744  45.365  1
59372  97.323  -79.751  45.348  1
59373  97.330  -79.760  45.331  1
59374  97.337  -79.767  45.314  1
59375  97.345  -79.775  45.296  1
59766  93.214  -79.284  53.440  1
59767  93.228  -79.272  53.426  1
59768  93.242  -79.259  53.411  1
59769  93.257  -79.247  53.397  1
59770  93.271  -79.235  53.382  1
59771  93.286  -79.223  53.368  1
59772  93.305  -79.214  53.353  1
59773  93.315  -79.211  53.337  1
59774  93.325  -79.209  53.322  1
59775  93.334  -79.206  53.308  1
59776  93.344  -79.204  53.295  1
59777  93.354  -79.201  53.281  1
59778  93.363  -79.199  53.267  1
59779  93.373  -79.194  53.252  1
59780  93.385  -79.184  53.238  1
59781  93.397  -79.173  53.224  1
59782  93.408  -79.163  53.210  1
59783  93.417  -79.156  53.197  1
59784  93.425  -79.148  53.184  1
59785  93.432  -79.148  53.172  1
59786  93.439  -79.150  53.161  1
59787  93.459  -79.138  53.150  1
59788  93.478  -79.125  53.141  1
59789  93.497  -79.112  53.137  1
59790  93.513  -79.104  53.135  1
59791  93.528  -79.100  53.134  1
59792  93.543  -79.094  53.133  1
59793  93.557  -79.090  53.129  1
59794  93.571  -79.085  53.123  1
59795  93.583  -79.084  53.116  1
59796  93.595  -79.082  53.110  1
59797  93.608  -79.081  53.104  1
59798  93.616  -79.084  53.097  1
59799  93.624  -79.090  53.092  1
59800  93.631  -79.094  53.086  1
59801  93.639  -79.099  53.079  1
59802  93.656  -79.100  53.071  1
59803  93.674  -79.100  53.062  1
59804  93.690  -79.100  53.053  1
59805  93.705  -79.099  53.043  1
59806  93.719  -79.099  53.034  1
59807  93.734  -79.098  53.023  1
59808  93.749  -79.098  53.012  1
59809  93.764  -79.097  53.000  1
59810  93.779  -79.097  52.987  1
59811  93.794  -79.096  52.974  1
59812  93.808  -79.095  52.960  1
59813  93.823  -79.091  52.946  1
59814  93.830  -79.090  52.932  1
59815  93.834  -79.088  52.918  1
59816  93.838  -79.087  52.904  1
59817  93.841  -79.085  52.888  1
59818  93.845  -79.084  52.870  1
59819  93.849  -79.083  52.850  1
59820  93.856  -79.081  52.831  1
59821  93.864  -79.078  52.813  1
59822  93.872  -79.075  52.794  1
59823  93.878  -79.079  52.778  1
59824  93.885  -79.083  52.765  1
59825  93.891  -79.087  52.752  1
59826  93.897  -79.090  52.739  1
59827  93.900  -79.093  52.726  1
59828  93.903  -79.096  52.713  1
59829  93.906  -79.098  52.701  1
59830  93.909  -79.100  52.689  1
59831  93.912  -79.103  52.676  1
59832  93.915  -79.105  52.662  1
59833  93.918  -79.107  52.650  1
59834  93.921  -79.110  52.638  1
59835  93.925  -79.112  52.625  1
59836  93.928  -79.116  52.612  1
59837  93.932  -79.125  52.600  1
59838  93.936  -79.132  52.588  1
59839  93.940  -79.140  52.574  1
59840  93.945  -79.143  52.562  1
59841  93.953  -79.142  52.550  1
59842  93.959  -79.140  52.536  1
59843  93.966  -79.140  52.522  1
59844  93.981  -79.134  52.506  1
59845  93.998  -79.126  52.486  1
59846  94.001  -79.127  52.464  1
59847  94.001  -79.129  52.440  1
59848  94.000  -79.131  52.413  1
59849  94.000  -79.134  52.385  1
59850  93.999  -79.137  52.354  1
59851  93.999  -79.139  52.324  1
59852  93.998  -79.141  52.293  1
59853  93.998  -79.143  52.260  1
59854  93.998  -79.144  52.228  1
59855  93.998  -79.146  52.196  1
59856  94.002  -79.146  52.166  1
59857  94.010  -79.144  52.138  1
59858  94.019  -79.142  52.111  1
59859  94.028  -79.140  52.084  1
59860  94.036  -79.138  52.057  1
59861  94.045  -79.136  52.033  1
59862  94.053  -79.134  52.011  1
59863  94.063  -79.133  51.992  1
59864  94.074  -79.131  51.975  1
59865  94.075  -79.128  51.958  1
59866  94.082  -79.114  51.941  1
59867  94.101  -79.087  51.921  1
59868  94.120  -79.060  51.899  1
59869  94.138  -79.034  51.875  1
59870  94.156  -79.007  51.850  1
59871  94.176  -78.982  51.829  1
59872  94.197  -78.960  51.809  1
59873  94.218  -78.938  51.789  1
59874  94.240  -78.916  51.765  1
59875  94.261  -78.894  51.736  1
59876  94.274  -78.895  51.704  1
59877  94.285  -78.891  51.668  1
59878  94.304  -78.900  51.630  1
59879  94.324  -78.908  51.591  1
59880  94.343  -78.917  51.552  1
59881  94.362  -78.926  51.512  1
59882  94.382  -78.934  51.472  1
59883  94.401  -78.943  51.433  1
59884  94.420  -78.951  51.395  1
59885  94.439  -78.960  51.361  1
59886  94.458  -78.954  51.329  1
59887  94.478  -78.942  51.298  1
59888  94.501  -78.952  51.265  1
59889  94.524  -78.946  51.230  1
59890  94.546  -78.937  51.193  1
59891  94.562  -78.942  51.154  1
59892  94.578  -78.946  51.114  1
59893  94.595  -78.952  51.074  1
59894  94.605  -78.945  51.033  1
59895  94.616  -78.939  50.995  1
59896  94.627  -78.932  50.955  1
59897  94.637  -78.926  50.914  1
59898  94.648  -78.919  50.874  1
59899  94.659  -78.913  50.834  1
59900  94.670  -78.906  50.795  1
59901  94.681  -78.902  50.757  1
59902  94.692  -78.899  50.718  1
59903  94.703  -78.895  50.680  1
59904  94.715  -78.891  50.641  1
59905  94.726  -78.887  50.603  1
59906  94.737  -78.883  50.565  1
59907  94.749  -78.880  50.526  1
59908  94.760  -78.877  50.486  1
59909  94.769  -78.882  50.448  1
59910  94.777  -78.890  50.409  1
59911  94.785  -78.897  50.371  1
59912  94.793  -78.904  50.332  1
59913  94.802  -78.912  50.294  1
59914  94.810  -78.919  50.257  1
59915  94.818  -78.927  50.218  1
59916  94.827  -78.934  50.180  1
59917  94.835  -78.942  50.143  1
59918  94.843  -78.949  50.106  1
59919  94.851  -78.956  50.068  1
59920  94.860  -78.964  50.031  1
59921  94.868  -78.971  49.993  1
59922  94.877  -78.979  49.956  1
59923  94.885  -78.987  49.919  1
59924  94.893  -78.994  49.881  1
59925  94.901  -79.002  49.844  1
59926  94.909  -79.009  49.806  1
59927  94.918  -79.016  49.768  1
59928  94.927  -79.026  49.729  1
59929  94.939  -79.044  49.691  1
59930  94.952  -79.062  49.653  1
59931  94.964  -79.081  49.615  1
59932  94.976  -79.100  49.577  1
59933  94.985  -79.115  49.539  1
59934  94.991  -79.127  49.501  1
59935  94.998  -79.140  49.463  1
59936  95.004  -79.153  49.427  1
59937  95.011  -79.165  49.391  1
59938  95.017  -79.178  49.355  1
59939  95.024  -79.190  49.320  1
59940  95.030  -79.203  49.287  1
59941  95.037  -79.216  49.254  1
59942  95.043  -79.228  49.220  1
59943  95.049  -79.241  49.188  1
59944  95.060  -79.254  49.155  1
59945  95.074  -79.266  49.121  1
59946  95.089  -79.279  49.086  1
59947  95.103  -79.291  49.050  1
59948  95.119  -79.303  49.015  1
59949  95.139  -79.308  48.979  1
59950  95.160  -79.314  48.942  1
59951  95.180  -79.320  48.905  1
59952  95.192  -79.322  48.868  1
59953  95.204  -79.324  48.832  1
59954  95.225  -79.328  48.796  1
59955  95.249  -79.332  48.760  1
59956  95.274  -79.337  48.721  1
59957  95.299  -79.341  48.682  1
59958  95.324  -79.347  48.644  1
59959  95.348  -79.351  48.605  1
59960  95.370  -79.350  48.565  1
59961  95.388  -79.344  48.524  1
59962  95.405  -79.338  48.484  1
59963  95.420  -79.347  48.442  1
59964  95.433  -79.362  48.401  1
59965  95.453  -79.375  48.360  1
59966  95.492  -79.379  48.320  1
59967  95.531  -79.384  48.279  1
59968  95.560  -79.378  48.239  1
59969  95.583  -79.365  48.199  1
59970  95.601  -79.354  48.158  1
59971  95.611  -79.349  48.117  1
59972  95.621  -79.344  48.077  1
59973  95.631  -79.338  48.038  1
59974  95.641  -79.332  48.000  1
59975  95.652  -79.327  47.964  1
59976  95.662  -79.322  47.930  1
59977  95.672  -79.316  47.895  1
59978  95.682  -79.310  47.860  1
59979  95.692  -79.305  47.825  1
59980  95.703  -79.300  47.788  1
59981  95.730  -79.305  47.752  1
59982  95.750  -79.325  47.715  1
59983  95.759  -79.346  47.679  1
59984  95.769  -79.356  47.644  1
59985  95.779  -79.366  47.609  1
59986  95.790  -79.376  47.573  1
59987  95.819  -79.380  47.536  1
59988  95.872  -79.375  47.500  1
59989  95.905  -79.357  47.463  1
59990  95.901  -79.313  47.427  1
59991  95.903  -79.277  47.391  1
59992  95.951  -79.298  47.355  1
59993  95.999  -79.319  47.320  1
59994  96.046  -79.341  47.285  1
59995  96.079  -79.355  47.251  1
59996  96.099  -79.363  47.218  1
59997  96.120  -79.372  47.185  1
59998  96.140  -79.380  47.151  1
59999  96.160  -79.388  47.117  1
60000  96.181  -79.396  47.084  1
60001  96.201  -79.404  47.051  1
60002  96.222  -79.413  47.020  1
60003  96.242  -79.420  46.988  1
60004  96.262  -79.429  46.956  1
60005  96.283  -79.437  46.924  1
60006  96.303  -79.445  46.891  1
60007  96.323  -79.453  46.859  1
60008  96.344  -79.461  46.829  1
60009  96.364  -79.469  46.799  1
60010  96.384  -79.478  46.769  1
60011  96.405  -79.485  46.738  1
60012  96.425  -79.494  46.708  1
60013  96.446  -79.502  46.677  1
60014  96.466  -79.510  46.647  1
60015  96.486  -79.518  46.620  1
60016  96.507  -79.526  46.595  1
60017  96.527  -79.535  46.569  1
60018  96.547  -79.543  46.543  1
60019  96.568  -79.551  46.518  1
60020  96.588  -79.559  46.493  1
60021  96.608  -79.567  46.469  1
60022  96.629  -79.576  46.447  1
60023  96.649  -79.585  46.426  1
60024  96.673  -79.589  46.406  1
60025  96.698  -79.592  46.387  1
60026  96.730  -79.588  46.367  1
60027  96.763  -79.582  46.346  1
60028  96.796  -79.573  46.324  1
60029  96.829  -79.563  46.303  1
60030  96.859  -79.555  46.282  1
60031  96.883  -79.544  46.258  1
60032  96.907  -79.532  46.234  1
60033  96.932  -79.521  46.209  1
60034  96.957  -79.507  46.183  1
60035  96.986  -79.490  46.153  1
60036  97.014  -79.483  46.126  1
60037  97.042  -79.477  46.102  1
60038  97.069  -79.470  46.077  1
60039  97.097  -79.464  46.052  1
60040  97.124  -79.458  46.028  1
60041  97.152  -79.447  46.005  1
60042  97.164  -79.450  45.982  1
60043  97.176  -79.452  45.958  1
60044  97.188  -79.455  45.933  1
60045  97.201  -79.458  45.909  1
60046  97.213  -79.461  45.885  1
60047  97.231  -79.469  45.859  1
60048  97.241  -79.479  45.833  1
60049  97.240  -79.484  45.808  1
60050  97.239  -79.488  45.784  1
60051  97.237  -79.494  45.761  1
60052  97.232  -79.504  45.740  1
60053  97.206  -79.542  45.717  1
60054  97.189  -79.573  45.695  1
60055  97.196  -79.580  45.675  1
60056  97.203  -79.588  45.654  1
60057  97.210  -79.595  45.634  1
60058  97.217  -79.603  45.617  1
60059  97.224  -79.610  45.598  1
60060  97.231  -79.618  45.580  1
60061  97.238  -79.626  45.563  1
60062  97.245  -79.633  45.545  1
60063  97.253  -79.641  45.527  1
60064  97.260  -79.648  45.509  1
60065  97.267  -79.656  45.491  1
60066  97.274  -79.664  45.474  1
60067  97.281  -79.672  45.456  1
60068  97.288  -79.679  45.437  1
60069  97.295  -79.687  45.419  1
60070  97.302  -79.695  45.401  1
60071  97.309  -79.702  45.382  1
60072  97.316  -79.710  45.366  1
60073  97.323  -79.717  45.349  1
60074  97.330  -79.725  45.332  1
60075  97.337  -79.733  45.315  1
60076  97.345  -79.740  45.297  1
60077  97.352  -79.748  45.280  1
60469  93.241  -79.249  53.436  1
60470  93.256  -79.237  53.421  1
60471  93.270  -79.225  53.407  1
60472  93.285  -79.212  53.393  1
60473  93.305  -79.203  53.378  1
60474  93.315  -79.200  53.363  1
60475  93.325  -79.198  53.348  1
60476  93.335  -79.195  53.333  1
60477  93.344  -79.193  53.319  1
60478  93.354  -79.190  53.305  1
60479  93.364  -79.188  53.290  1
60480  93.373  -79.185  53.277  1
60481  93.383  -79.180  53.262  1
60482  93.395  -79.169  53.248  1
60483  93.407  -79.159  53.234  1
60484  93.418  -79.149  53.220  1
60485  93.426  -79.142  53.207  1
60486  93.434  -79.135  53.195  1
60487  93.442  -79.131  53.183  1
60488  93.447  -79.136  53.172  1
60489  93.460  -79.132  53.163  1
60490  93.480  -79.119  53.157  1
60491  93.499  -79.106  53.155  1
60492  93.518  -79.093  53.154  1
60493  93.537  -79.082  53.155  1
60494  93.551  -79.077  53.153  1
60495  93.565  -79.072  53.150  1
60496  93.578  -79.069  53.145  1
60497  93.590  -79.068  53.139  1
60498  93.599  -79.071  53.134  1
60499  93.607  -79.077  53.128  1
60500  93.615  -79.081  53.122  1
60501  93.622  -79.087  53.116  1
60502  93.630  -79.091  53.109  1
60503  93.648  -79.091  53.101  1
60504  93.666  -79.091  53.092  1
60505  93.683  -79.090  53.082  1
60506  93.698  -79.090  53.072  1
60507  93.713  -79.090  53.063  1
60508  93.727  -79.090  53.053  1
60509  93.743  -79.089  53.041  1
60510  93.757  -79.089  53.029  1
60511  93.772  -79.089  53.015  1
60512  93.787  -79.087  53.001  1
60513  93.801  -79.083  52.985  1
60514  93.817  -79.079  52.970  1
60515  93.823  -79.078  52.956  1
60516  93.827  -79.076  52.941  1
60517  93.830  -79.075  52.927  1
60518  93.834  -79.074  52.911  1
60519  93.838  -79.072  52.894  1
60520  93.844  -79.070  52.874  1
60521  93.852  -79.068  52.855  1
60522  93.860  -79.065  52.837  1
60523  93.868  -79.062  52.820  1
60524  93.875  -79.063  52.805  1
60525  93.881  -79.067  52.792  1
60526  93.888  -79.071  52.779  1
60527  93.894  -79.075  52.765  1
60528  93.896  -79.077  52.752  1
60529  93.898  -79.080  52.740  1
60530  93.901  -79.082  52.730  1
60531  93.904  -79.084  52.718  1
60532  93.907  -79.087  52.705  1
60533  93.911  -79.089  52.691  1
60534  93.914  -79.091  52.679  1
60535  93.917  -79.093  52.666  1
60536  93.920  -79.096  52.653  1
60537  93.923  -79.101  52.640  1
60538  93.927  -79.109  52.627  1
60539  93.931  -79.117  52.615  1
60540  93.935  -79.125  52.603  1
60541  93.939  -79.134  52.591  1
60542  93.945  -79.134  52.579  1
60543  93.953  -79.133  52.565  1
60544  93.969  -79.126  52.549  1
60545  93.986  -79.119  52.531  1
60546  94.002  -79.112  52.511  1
60547  94.002  -79.115  52.488  1
60548  94.001  -79.117  52.462  1
60549  94.001  -79.119  52.434  1
60550  94.000  -79.122  52.405  1
60551  94.000  -79.125  52.375  1
60552  93.999  -79.127  52.343  1
60553  93.999  -79.129  52.309  1
60554  93.998  -79.132  52.275  1
60555  93.998  -79.134  52.241  1
60556  93.997  -79.137  52.209  1
60557  94.002  -79.136  52.179  1
60558  94.010  -79.134  52.150  1
60559  94.019  -79.132  52.123  1
60560  94.028  -79.131  52.098  1
60561  94.036  -79.128  52.074  1
60562  94.045  -79.127  52.051  1
60563  94.053  -79.125  52.031  1
60564  94.062  -79.122  52.014  1
60565  94.071  -79.121  51.998  1
60566  94.076  -79.118  51.981  1
60567  94.095  -79.090  51.964  1
60568  94.114  -79.064  51.942  1
60569  94.132  -79.037  51.918  1
60570  94.150  -79.010  51.894  1
60571  94.169  -78.984  51.869  1
60572  94.188  -78.956  51.847  1
60573  94.208  -78.933  51.826  1
60574  94.229  -78.911  51.806  1
60575  94.250  -78.889  51.778  1
60576  94.269  -78.876  51.747  1
60577  94.282  -78.878  51.712  1
60578  94.294  -78.882  51.676  1
60579  94.304  -78.872  51.639  1
60580  94.324  -78.880  51.601  1
60581  94.343  -78.890  51.564  1
60582  94.362  -78.898  51.524  1
60583  94.382  -78.906  51.485  1
60584  94.401  -78.915  51.446  1
60585  94.420  -78.924  51.410  1
60586  94.439  -78.932  51.377  1
60587  94.458  -78.912  51.345  1
60588  94.481  -78.921  51.314  1
60589  94.504  -78.931  51.282  1
60590  94.527  -78.935  51.248  1
60591  94.549  -78.927  51.211  1
60592  94.565  -78.932  51.172  1
60593  94.581  -78.937  51.132  1
60594  94.598  -78.942  51.092  1
60595  94.612  -78.943  51.053  1
60596  94.623  -78.937  51.014  1
60597  94.633  -78.930  50.975  1
60598  94.644  -78.924  50.934  1
60599  94.655  -78.918  50.893  1
60600  94.666  -78.911  50.853  1
60601  94.677  -78.904  50.814  1
60602  94.687  -78.898  50.775  1
60603  94.698  -78.891  50.736  1
60604  94.709  -78.886  50.697  1
60605  94.720  -78.882  50.658  1
60606  94.732  -78.878  50.620  1
60607  94.743  -78.874  50.581  1
60608  94.754  -78.871  50.542  1
60609  94.765  -78.868  50.502  1
60610  94.776  -78.864  50.464  1
60611  94.785  -78.869  50.425  1
60612  94.793  -78.877  50.387  1
60613  94.802  -78.884  50.348  1
60614  94.810  -78.891  50.310  1
60615  94.819  -78.899  50.271  1
60616  94.827  -78.906  50.233  1
60617  94.835  -78.914  50.196  1
60618  94.843  -78.921  50.159  1
60619  94.851  -78.929  50.122  1
60620  94.860  -78.937  50.084  1
60621  94.868  -78.944  50.047  1
60622  94.877  -78.951  50.009  1
60623  94.885  -78.959  49.971  1
60624  94.893  -78.966  49.933  1
60625  94.901  -78.974  49.896  1
60626  94.910  -78.981  49.858  1
60627  94.922  -78.999  49.821  1
60628  94.934  -79.018  49.783  1
60629  94.947  -79.036  49.743  1
60630  94.957  -79.053  49.705  1
60631  94.964  -79.065  49.667  1
60632  94.970  -79.078  49.629  1
60633  94.976  -79.091  49.592  1
60634  94.983  -79.104  49.554  1
60635  94.989  -79.116  49.516  1
60636  94.996  -79.129  49.479  1
60637  95.002  -79.142  49.442  1
60638  95.008  -79.155  49.406  1
60639  95.015  -79.167  49.371  1
60640  95.022  -79.180  49.338  1
60641  95.028  -79.193  49.305  1
60642  95.034  -79.205  49.274  1
60643  95.041  -79.218  49.244  1
60644  95.053  -79.231  49.211  1
60645  95.067  -79.243  49.177  1
60646  95.082  -79.256  49.142  1
60647  95.096  -79.268  49.106  1
60648  95.110  -79.281  49.070  1
60649  95.127  -79.290  49.035  1
60650  95.148  -79.296  48.997  1
60651  95.168  -79.302  48.960  1
60652  95.188  -79.308  48.923  1
60653  95.206  -79.313  48.886  1
60654  95.217  -79.314  48.850  1
60655  95.237  -79.318  48.814  1
60656  95.262  -79.322  48.777  1
60657  95.286  -79.327  48.738  1
60658  95.312  -79.332  48.697  1
60659  95.336  -79.337  48.656  1
60660  95.355  -79.332  48.614  1
60661  95.373  -79.326  48.573  1
60662  95.391  -79.320  48.531  1
60663  95.408  -79.318  48.488  1
60664  95.421  -79.334  48.446  1
60665  95.434  -79.350  48.404  1
60666  95.450  -79.364  48.363  1
60667  95.489  -79.368  48.321  1
60668  95.528  -79.372  48.280  1
60669  95.558  -79.366  48.239  1
60670  95.580  -79.353  48.199  1
60671  95.603  -79.340  48.158  1
60672  95.613  -79.335  48.118  1
60673  95.624  -79.328  48.079  1
60674  95.634  -79.323  48.038  1
60675  95.644  -79.318  48.001  1
60676  95.654  -79.313  47.964  1
60677  95.665  -79.306  47.928  1
60678  95.675  -79.301  47.891  1
60679  95.685  -79.296  47.855  1
60680  95.695  -79.291  47.819  1
60681  95.705  -79.285  47.783  1
60682  95.737  -79.293  47.748  1
60683  95.763  -79.308  47.711  1
60684  95.772  -79.336  47.674  1
60685  95.782  -79.351  47.638  1
60686  95.792  -79.362  47.602  1
60687  95.802  -79.372  47.566  1
60688  95.834  -79.375  47.529  1
60689  95.886  -79.370  47.493  1
60690  95.894  -79.334  47.458  1
60691  95.890  -79.290  47.421  1
60692  95.886  -79.246  47.386  1
60693  95.932  -79.265  47.351  1
60694  95.979  -79.286  47.316  1
60695  96.027  -79.307  47.281  1
60696  96.075  -79.329  47.248  1
60697  96.111  -79.345  47.215  1
60698  96.132  -79.353  47.181  1
60699  96.152  -79.361  47.147  1
60700  96.173  -79.369  47.112  1
60701  96.193  -79.378  47.079  1
60702  96.214  -79.386  47.047  1
60703  96.234  -79.394  47.015  1
60704  96.254  -79.402  46.982  1
60705  96.274  -79.410  46.950  1
60706  96.295  -79.419  46.918  1
60707  96.315  -79.427  46.886  1
60708  96.335  -79.435  46.854  1
60709  96.356  -79.443  46.823  1
60710  96.376  -79.451  46.793  1
60711  96.397  -79.460  46.763  1
60712  96.417  -79.467  46.733  1
60713  96.438  -79.476  46.702  1
60714  96.458  -79.484  46.672  1
60715  96.478  -79.492  46.642  1
60716  96.499  -79.500  46.616  1
60717  96.519  -79.508  46.592  1
60718  96.539  -79.516  46.568  1
60719  96.559  -79.525  46.542  1
60720  96.580  -79.532  46.515  1
60721  96.600  -79.541  46.490  1
60722  96.621  -79.549  46.466  1
60723  96.641  -79.557  46.445  1
60724  96.662  -79.566  46.425  1
60725  96.681  -79.576  46.407  1
60726  96.699  -79.576  46.386  1
60727  96.719  -79.555  46.365  1
60728  96.752  -79.545  46.342  1
60729  96.785  -79.535  46.320  1
60730  96.818  -79.525  46.299  1
60731  96.851  -79.515  46.278  1
60732  96.891  -79.522  46.253  1
60733  96.915  -79.510  46.228  1
60734  96.940  -79.498  46.202  1
60735  96.964  -79.487  46.178  1
60736  96.994  -79.463  46.148  1
60737  97.022  -79.450  46.121  1
60738  97.050  -79.444  46.097  1
60739  97.078  -79.438  46.072  1
60740  97.105  -79.431  46.048  1
60741  97.133  -79.422  46.024  1
60742  97.148  -79.422  46.000  1
60743  97.161  -79.425  45.976  1
60744  97.173  -79.427  45.953  1
60745  97.185  -79.430  45.928  1
60746  97.198  -79.435  45.905  1
60747  97.215  -79.439  45.882  1
60748  97.232  -79.446  45.858  1
60749  97.248  -79.454  45.833  1
60750  97.250  -79.460  45.808  1
60751  97.249  -79.464  45.783  1
60752  97.248  -79.469  45.759  1
60753  97.247  -79.475  45.737  1
60754  97.245  -79.479  45.715  1
60755  97.239  -79.492  45.693  1
60756  97.212  -79.531  45.672  1
60757  97.203  -79.553  45.652  1
60758  97.210  -79.560  45.632  1
60759  97.217  -79.568  45.615  1
60760  97.225  -79.576  45.597  1
60761  97.232  -79.583  45.579  1
60762  97.239  -79.592  45.561  1
60763  97.246  -79.599  45.544  1
60764  97.253  -79.607  45.526  1
60765  97.260  -79.614  45.508  1
60766  97.267  -79.622  45.491  1
60767  97.274  -79.629  45.473  1
60768  97.281  -79.637  45.455  1
60769  97.288  -79.645  45.437  1
60770  97.295  -79.652  45.419  1
60771  97.302  -79.660  45.401  1
60772  97.309  -79.667  45.383  1
60773  97.316  -79.675  45.367  1
60774  97.324  -79.683  45.349  1
60775  97.331  -79.690  45.332  1
60776  97.338  -79.698  45.316  1
60777  97.345  -79.706  45.298  1
60778  97.352  -79.714  45.281  1
60779  97.371  -79.729  45.265  1
60835  98.445  -80.585  44.578  1
60836  98.464  -80.600  44.572  1
60837  98.487  -80.607  44.565  1
60838  98.512  -80.609  44.558  1
61172  93.269  -79.214  53.433  1
61173  93.285  -79.202  53.418  1
61174  93.306  -79.192  53.402  1
61175  93.315  -79.190  53.388  1
61176  93.325  -79.187  53.373  1
61177  93.335  -79.184  53.358  1
61178  93.345  -79.182  53.344  1
61179  93.354  -79.180  53.330  1
61180  93.364  -79.177  53.315  1
61181  93.373  -79.175  53.300  1
61182  93.383  -79.172  53.286  1
61183  93.394  -79.165  53.272  1
61184  93.405  -79.155  53.258  1
61185  93.417  -79.145  53.244  1
61186  93.427  -79.135  53.231  1
61187  93.436  -79.128  53.219  1
61188  93.444  -79.122  53.207  1
61189  93.452  -79.115  53.195  1
61190  93.458  -79.119  53.185  1
61191  93.464  -79.125  53.178  1
61192  93.481  -79.113  53.174  1
61193  93.500  -79.100  53.173  1
61194  93.519  -79.088  53.175  1
61195  93.539  -79.075  53.176  1
61196  93.558  -79.062  53.175  1
61197  93.574  -79.056  53.172  1
61198  93.582  -79.059  53.167  1
61199  93.590  -79.064  53.162  1
61200  93.598  -79.068  53.157  1
61201  93.606  -79.074  53.152  1
61202  93.613  -79.078  53.145  1
61203  93.623  -79.082  53.139  1
61204  93.640  -79.082  53.130  1
61205  93.658  -79.082  53.121  1
61206  93.676  -79.082  53.112  1
61207  93.691  -79.082  53.102  1
61208  93.706  -79.081  53.091  1
61209  93.721  -79.081  53.080  1
61210  93.736  -79.081  53.068  1
61211  93.751  -79.081  53.054  1
61212  93.765  -79.078  53.039  1
61213  93.780  -79.075  53.024  1
61214  93.795  -79.071  53.008  1
61215  93.809  -79.068  52.993  1
61216  93.815  -79.065  52.978  1
61217  93.819  -79.065  52.964  1
61218  93.823  -79.063  52.949  1
61219  93.827  -79.062  52.934  1
61220  93.832  -79.060  52.917  1
61221  93.840  -79.057  52.898  1
61222  93.848  -79.054  52.879  1
61223  93.856  -79.052  52.862  1
61224  93.864  -79.049  52.847  1
61225  93.871  -79.047  52.834  1
61226  93.878  -79.051  52.821  1
61227  93.884  -79.054  52.808  1
61228  93.891  -79.058  52.792  1
61229  93.893  -79.061  52.780  1
61230  93.894  -79.063  52.769  1
61231  93.896  -79.065  52.758  1
61232  93.900  -79.068  52.747  1
61233  93.903  -79.071  52.735  1
61234  93.906  -79.073  52.720  1
61235  93.909  -79.075  52.707  1
61236  93.912  -79.078  52.694  1
61237  93.915  -79.080  52.680  1
61238  93.919  -79.085  52.666  1
61239  93.923  -79.093  52.653  1
61240  93.927  -79.102  52.641  1
61241  93.931  -79.110  52.629  1
61242  93.935  -79.118  52.619  1
61243  93.939  -79.125  52.606  1
61244  93.957  -79.119  52.591  1
61245  93.974  -79.112  52.574  1
61246  93.991  -79.105  52.556  1
61247  94.003  -79.100  52.535  1
61248  94.003  -79.103  52.510  1
61249  94.002  -79.105  52.483  1
61250  94.002  -79.108  52.454  1
61251  94.001  -79.110  52.424  1
61252  94.001  -79.112  52.392  1
61253  94.000  -79.115  52.359  1
61254  94.000  -79.117  52.324  1
61255  93.999  -79.120  52.288  1
61256  94.000  -79.117  52.254  1
61257  94.001  -79.114  52.222  1
61258  94.006  -79.112  52.191  1
61259  94.014  -79.110  52.164  1
61260  94.023  -79.109  52.138  1
61261  94.032  -79.107  52.114  1
61262  94.040  -79.106  52.091  1
61263  94.048  -79.104  52.070  1
61264  94.057  -79.103  52.051  1
61265  94.065  -79.102  52.035  1
61266  94.074  -79.100  52.018  1
61267  94.086  -79.095  52.001  1
61268  94.107  -79.068  51.982  1
61269  94.126  -79.040  51.958  1
61270  94.145  -79.013  51.933  1
61271  94.163  -78.987  51.908  1
61272  94.182  -78.959  51.883  1
61273  94.200  -78.933  51.862  1
61274  94.219  -78.906  51.841  1
61275  94.240  -78.884  51.820  1
61276  94.261  -78.862  51.790  1
61277  94.277  -78.858  51.756  1
61278  94.290  -78.861  51.721  1
61279  94.303  -78.864  51.686  1
61280  94.314  -78.867  51.649  1
61281  94.324  -78.853  51.612  1
61282  94.343  -78.861  51.575  1
61283  94.362  -78.870  51.536  1
61284  94.382  -78.879  51.497  1
61285  94.401  -78.887  51.460  1
61286  94.420  -78.896  51.425  1
61287  94.438  -78.880  51.392  1
61288  94.461  -78.890  51.360  1
61289  94.484  -78.901  51.330  1
61290  94.507  -78.911  51.298  1
61291  94.531  -78.921  51.264  1
61292  94.552  -78.918  51.230  1
61293  94.568  -78.922  51.190  1
61294  94.584  -78.927  51.151  1
61295  94.601  -78.932  51.111  1
61296  94.617  -78.937  51.073  1
61297  94.629  -78.935  51.035  1
61298  94.640  -78.928  50.996  1
61299  94.651  -78.922  50.957  1
61300  94.662  -78.915  50.915  1
61301  94.672  -78.909  50.874  1
61302  94.683  -78.902  50.835  1
61303  94.694  -78.896  50.795  1
61304  94.705  -78.890  50.756  1
61305  94.715  -78.883  50.717  1
61306  94.726  -78.877  50.678  1
61307  94.737  -78.870  50.639  1
61308  94.748  -78.865  50.600  1
61309  94.759  -78.861  50.560  1
61310  94.771  -78.858  50.521  1
61311  94.782  -78.855  50.481  1
61312  94.793  -78.851  50.442  1
61313  94.802  -78.856  50.404  1
61314  94.810  -78.864  50.365  1
61315  94.819  -78.871  50.326  1
61316  94.827  -78.879  50.287  1
61317  94.835  -78.886  50.249  1
61318  94.843  -78.893  50.212  1
61319  94.852  -78.901  50.175  1
61320  94.860  -78.908  50.138  1
61321  94.868  -78.916  50.100  1
61322  94.877  -78.924  50.063  1
61323  94.885  -78.931  50.025  1
61324  94.893  -78.938  49.987  1
61325  94.905  -78.955  49.949  1
61326  94.917  -78.973  49.912  1
61327  94.929  -78.992  49.874  1
61328  94.936  -79.004  49.836  1
61329  94.942  -79.017  49.798  1
61330  94.949  -79.030  49.759  1
61331  94.955  -79.043  49.720  1
61332  94.962  -79.055  49.682  1
61333  94.968  -79.068  49.644  1
61334  94.974  -79.081  49.607  1
61335  94.981  -79.093  49.569  1
61336  94.987  -79.106  49.532  1
61337  94.993  -79.118  49.495  1
61338  95.000  -79.131  49.459  1
61339  95.006  -79.143  49.423  1
61340  95.013  -79.156  49.390  1
61341  95.016  -79.165  49.359  1
61342  95.019  -79.174  49.328  1
61343  95.025  -79.193  49.298  1
61344  95.044  -79.203  49.267  1
61345  95.059  -79.218  49.234  1
61346  95.075  -79.232  49.201  1
61347  95.089  -79.245  49.166  1
61348  95.103  -79.257  49.130  1
61349  95.118  -79.270  49.093  1
61350  95.136  -79.278  49.056  1
61351  95.156  -79.284  49.018  1
61352  95.177  -79.290  48.979  1
61353  95.197  -79.296  48.941  1
61354  95.217  -79.302  48.903  1
61355  95.231  -79.304  48.865  1
61356  95.250  -79.308  48.827  1
61357  95.274  -79.313  48.788  1
61358  95.299  -79.317  48.747  1
61359  95.323  -79.321  48.705  1
61360  95.341  -79.315  48.663  1
61361  95.359  -79.309  48.620  1
61362  95.377  -79.303  48.577  1
61363  95.395  -79.297  48.535  1
61364  95.409  -79.306  48.492  1
61365  95.422  -79.321  48.448  1
61366  95.435  -79.337  48.406  1
61367  95.448  -79.353  48.364  1
61368  95.486  -79.357  48.323  1
61369  95.526  -79.362  48.282  1
61370  95.555  -79.355  48.240  1
61371  95.577  -79.342  48.200  1
61372  95.600  -79.328  48.159  1
61373  95.616  -79.319  48.119  1
61374  95.626  -79.314  48.079  1
61375  95.636  -79.309  48.040  1
61376  95.647  -79.303  48.002  1
61377  95.657  -79.297  47.965  1
61378  95.667  -79.292  47.928  1
61379  95.677  -79.287  47.891  1
61380  95.687  -79.281  47.854  1
61381  95.698  -79.275  47.817  1
61382  95.709  -79.271  47.780  1
61383  95.743  -79.281  47.744  1
61384  95.776  -79.291  47.708  1
61385  95.785  -79.319  47.671  1
61386  95.795  -79.347  47.634  1
61387  95.805  -79.357  47.598  1
61388  95.815  -79.367  47.562  1
61389  95.849  -79.369  47.525  1
61390  95.887  -79.355  47.490  1
61391  95.883  -79.311  47.455  1
61392  95.879  -79.267  47.419  1
61393  95.875  -79.223  47.383  1
61394  95.912  -79.231  47.347  1
61395  95.960  -79.253  47.312  1
61396  96.008  -79.274  47.278  1
61397  96.055  -79.295  47.244  1
61398  96.103  -79.317  47.210  1
61399  96.144  -79.335  47.176  1
61400  96.164  -79.343  47.142  1
61401  96.185  -79.351  47.108  1
61402  96.205  -79.360  47.074  1
61403  96.226  -79.368  47.041  1
61404  96.246  -79.375  47.009  1
61405  96.266  -79.384  46.977  1
61406  96.287  -79.392  46.945  1
61407  96.307  -79.400  46.913  1
61408  96.327  -79.408  46.881  1
61409  96.347  -79.416  46.849  1
61410  96.368  -79.425  46.818  1
61411  96.388  -79.433  46.787  1
61412  96.409  -79.441  46.757  1
61413  96.429  -79.449  46.727  1
61414  96.450  -79.457  46.697  1
61415  96.470  -79.466  46.667  1
61416  96.490  -79.473  46.637  1
61417  96.511  -79.482  46.610  1
61418  96.531  -79.490  46.585  1
61419  96.551  -79.498  46.560  1
61420  96.572  -79.506  46.535  1
61421  96.592  -79.514  46.510  1
61422  96.613  -79.523  46.484  1
61423  96.633  -79.534  46.460  1
61424  96.654  -79.544  46.439  1
61425  96.670  -79.549  46.419  1
61426  96.684  -79.548  46.399  1
61427  96.707  -79.551  46.377  1
61428  96.726  -79.531  46.354  1
61429  96.744  -79.510  46.331  1
61430  96.773  -79.497  46.309  1
61431  96.806  -79.487  46.289  1
61432  96.839  -79.476  46.269  1
61433  96.875  -79.472  46.245  1
61434  96.920  -79.485  46.220  1
61435  96.947  -79.476  46.194  1
61436  96.971  -79.464  46.169  1
61437  97.000  -79.444  46.141  1
61438  97.030  -79.418  46.116  1
61439  97.058  -79.410  46.093  1
61440  97.086  -79.404  46.069  1
61441  97.113  -79.397  46.045  1
61442  97.133  -79.394  46.021  1
61443  97.145  -79.397  45.997  1
61444  97.157  -79.399  45.973  1
61445  97.170  -79.404  45.950  1
61446  97.184  -79.408  45.927  1
61447  97.198  -79.413  45.904  1
61448  97.220  -79.416  45.880  1
61449  97.235  -79.424  45.855  1
61450  97.255  -79.432  45.830  1
61451  97.261  -79.441  45.805  1
61452  97.257  -79.446  45.781  1
61453  97.258  -79.445  45.756  1
61454  97.257  -79.451  45.734  1
61455  97.256  -79.455  45.713  1
61456  97.254  -79.460  45.692  1
61457  97.253  -79.466  45.671  1
61458  97.245  -79.480  45.650  1
61459  97.218  -79.519  45.631  1
61460  97.218  -79.534  45.613  1
61461  97.225  -79.541  45.596  1
61462  97.232  -79.549  45.578  1
61463  97.239  -79.557  45.560  1
61464  97.246  -79.564  45.543  1
61465  97.253  -79.572  45.525  1
61466  97.260  -79.579  45.507  1
61467  97.267  -79.587  45.490  1
61468  97.274  -79.595  45.473  1
61469  97.281  -79.602  45.455  1
61470  97.288  -79.610  45.438  1
61471  97.296  -79.618  45.419  1
61472  97.303  -79.626  45.401  1
61473  97.310  -79.633  45.384  1
61474  97.317  -79.641  45.368  1
61475  97.324  -79.648  45.350  1
61476  97.331  -79.656  45.333  1
61477  97.338  -79.664  45.317  1
61478  97.345  -79.671  45.299  1
61479  97.358  -79.683  45.282  1
61480  97.377  -79.698  45.266  1
61481  97.396  -79.713  45.251  1
61534  98.412  -80.522  44.601  1
61535  98.431  -80.538  44.592  1
61536  98.450  -80.554  44.586  1
61537  98.469  -80.569  44.579  1
61538  98.492  -80.576  44.572  1
61539  98.517  -80.578  44.566  1
61540  98.542  -80.581  44.559  1
61541  98.567  -80.583  44.551  1
61542  98.591  -80.585  44.543  1
61543  98.616  -80.588  44.535  1
61544  98.641  -80.591  44.528  1
61545  98.665  -80.593  44.522  1
61546  98.690  -80.596  44.515  1
61547  98.715  -80.599  44.507  1
61548  98.741  -80.604  44.500  1
61549  98.767  -80.607  44.495  1
61550  98.792  -80.611  44.488  1
61551  98.817  -80.615  44.481  1
61552  98.843  -80.620  44.476  1
61553  98.867  -80.627  44.471  1
61874  93.284  -79.192  53.443  1
61875  93.306  -79.181  53.427  1
61876  93.315  -79.178  53.413  1
61877  93.326  -79.176  53.398  1
61878  93.335  -79.174  53.384  1
61879  93.345  -79.171  53.369  1
61880  93.354  -79.169  53.355  1
61881  93.364  -79.166  53.340  1
61882  93.374  -79.164  53.326  1
61883  93.383  -79.161  53.311  1
61884  93.393  -79.159  53.296  1
61885  93.404  -79.151  53.282  1
61886  93.415  -79.141  53.268  1
61887  93.427  -79.131  53.255  1
61888  93.437  -79.122  53.242  1
61889  93.445  -79.115  53.229  1
61890  93.453  -79.108  53.217  1
61891  93.462  -79.101  53.207  1
61892  93.468  -79.102  53.199  1
61893  93.474  -79.107  53.195  1
61894  93.483  -79.108  53.192  1
61895  93.502  -79.095  53.195  1
61896  93.521  -79.082  53.197  1
61897  93.541  -79.069  53.198  1
61898  93.560  -79.056  53.196  1
61899  93.573  -79.053  53.193  1
61900  93.581  -79.056  53.190  1
61901  93.588  -79.061  53.185  1
61902  93.596  -79.065  53.180  1
61903  93.604  -79.071  53.174  1
61904  93.615  -79.074  53.168  1
61905  93.633  -79.074  53.159  1
61906  93.650  -79.074  53.150  1
61907  93.668  -79.074  53.140  1
61908  93.685  -79.073  53.130  1
61909  93.699  -79.073  53.118  1
61910  93.714  -79.073  53.105  1
61911  93.729  -79.072  53.093  1
61912  93.744  -79.069  53.078  1
61913  93.759  -79.066  53.063  1
61914  93.773  -79.062  53.047  1
61915  93.788  -79.059  53.031  1
61916  93.802  -79.056  53.016  1
61917  93.808  -79.054  53.001  1
61918  93.812  -79.053  52.986  1
61919  93.816  -79.051  52.972  1
61920  93.820  -79.049  52.957  1
61921  93.828  -79.047  52.940  1
61922  93.836  -79.044  52.922  1
61923  93.844  -79.041  52.905  1
61924  93.852  -79.039  52.889  1
61925  93.860  -79.036  52.874  1
61926  93.868  -79.033  52.862  1
61927  93.874  -79.034  52.850  1
61928  93.881  -79.038  52.837  1
61929  93.887  -79.042  52.823  1
61930  93.890  -79.045  52.809  1
61931  93.891  -79.047  52.797  1
61932  93.892  -79.049  52.785  1
61933  93.895  -79.052  52.775  1
61934  93.898  -79.054  52.763  1
61935  93.901  -79.057  52.749  1
61936  93.904  -79.059  52.734  1
61937  93.908  -79.062  52.719  1
61938  93.911  -79.064  52.704  1
61939  93.914  -79.070  52.689  1
61940  93.918  -79.078  52.677  1
61941  93.922  -79.087  52.666  1
61942  93.926  -79.094  52.654  1
61943  93.930  -79.103  52.643  1
61944  93.936  -79.103  52.630  1
61945  93.962  -79.105  52.614  1
61946  93.979  -79.098  52.598  1
61947  93.995  -79.090  52.579  1
61948  94.004  -79.088  52.557  1
61949  94.003  -79.090  52.530  1
61950  94.003  -79.093  52.502  1
61951  94.002  -79.096  52.472  1
61952  94.002  -79.098  52.441  1
61953  94.001  -79.100  52.408  1
61954  94.002  -79.099  52.374  1
61955  94.003  -79.095  52.339  1
61956  94.004  -79.092  52.302  1
61957  94.005  -79.088  52.268  1
61958  94.006  -79.085  52.235  1
61959  94.012  -79.083  52.204  1
61960  94.020  -79.081  52.178  1
61961  94.029  -79.080  52.154  1
61962  94.037  -79.078  52.131  1
61963  94.046  -79.077  52.110  1
61964  94.054  -79.075  52.090  1
61965  94.062  -79.074  52.071  1
61966  94.071  -79.072  52.054  1
61967  94.080  -79.071  52.036  1
61968  94.095  -79.063  52.017  1
61969  94.112  -79.053  51.997  1
61970  94.132  -79.025  51.972  1
61971  94.153  -78.995  51.947  1
61972  94.175  -78.965  51.923  1
61973  94.194  -78.936  51.899  1
61974  94.213  -78.909  51.878  1
61975  94.231  -78.882  51.857  1
61976  94.251  -78.858  51.833  1
61977  94.271  -78.839  51.802  1
61978  94.285  -78.841  51.768  1
61979  94.298  -78.843  51.733  1
61980  94.312  -78.846  51.697  1
61981  94.323  -78.851  51.660  1
61982  94.330  -78.840  51.623  1
61983  94.343  -78.834  51.587  1
61984  94.362  -78.843  51.548  1
61985  94.382  -78.851  51.510  1
61986  94.401  -78.859  51.474  1
61987  94.420  -78.861  51.439  1
61988  94.441  -78.860  51.407  1
61989  94.465  -78.870  51.376  1
61990  94.487  -78.880  51.346  1
61991  94.510  -78.890  51.314  1
61992  94.534  -78.900  51.282  1
61993  94.555  -78.908  51.248  1
61994  94.571  -78.912  51.209  1
61995  94.588  -78.918  51.170  1
61996  94.604  -78.923  51.132  1
61997  94.620  -78.927  51.094  1
61998  94.636  -78.933  51.057  1
61999  94.647  -78.927  51.019  1
62000  94.657  -78.920  50.982  1
62001  94.668  -78.914  50.939  1
62002  94.679  -78.907  50.899  1
62003  94.690  -78.901  50.859  1
62004  94.700  -78.894  50.821  1
62005  94.711  -78.887  50.781  1
62006  94.722  -78.881  50.741  1
62007  94.733  -78.874  50.701  1
62008  94.744  -78.868  50.661  1
62009  94.754  -78.861  50.622  1
62010  94.765  -78.855  50.583  1
62011  94.776  -78.849  50.542  1
62012  94.787  -78.846  50.501  1
62013  94.799  -78.842  50.461  1
62014  94.810  -78.838  50.422  1
62015  94.819  -78.843  50.382  1
62016  94.827  -78.851  50.343  1
62017  94.835  -78.858  50.305  1
62018  94.843  -78.866  50.266  1
62019  94.852  -78.874  50.228  1
62020  94.860  -78.880  50.191  1
62021  94.868  -78.888  50.154  1
62022  94.877  -78.896  50.116  1
62023  94.888  -78.910  50.079  1
62024  94.900  -78.929  50.041  1
62025  94.908  -78.943  50.003  1
62026  94.914  -78.955  49.965  1
62027  94.921  -78.968  49.928  1
62028  94.927  -78.981  49.890  1
62029  94.933  -78.993  49.853  1
62030  94.940  -79.006  49.814  1
62031  94.947  -79.019  49.775  1
62032  94.953  -79.031  49.736  1
62033  94.959  -79.044  49.698  1
62034  94.963  -79.053  49.660  1
62035  94.965  -79.062  49.622  1
62036  94.968  -79.070  49.585  1
62037  94.970  -79.078  49.548  1
62038  94.973  -79.087  49.511  1
62039  94.975  -79.095  49.476  1
62040  94.978  -79.103  49.442  1
62041  94.979  -79.117  49.410  1
62042  94.975  -79.158  49.380  1
62043  95.007  -79.165  49.350  1
62044  95.029  -79.173  49.320  1
62045  95.045  -79.182  49.288  1
62046  95.061  -79.197  49.255  1
62047  95.076  -79.211  49.221  1
62048  95.092  -79.225  49.187  1
62049  95.108  -79.241  49.152  1
62050  95.123  -79.255  49.114  1
62051  95.144  -79.265  49.075  1
62052  95.165  -79.272  49.036  1
62053  95.185  -79.278  48.996  1
62054  95.205  -79.284  48.957  1
62055  95.226  -79.290  48.917  1
62056  95.244  -79.295  48.877  1
62057  95.262  -79.298  48.837  1
62058  95.287  -79.303  48.796  1
62059  95.309  -79.303  48.754  1
62060  95.327  -79.297  48.712  1
62061  95.344  -79.291  48.669  1
62062  95.362  -79.285  48.625  1
62063  95.380  -79.279  48.582  1
62064  95.397  -79.277  48.539  1
62065  95.410  -79.293  48.496  1
62066  95.423  -79.309  48.452  1
62067  95.436  -79.324  48.409  1
62068  95.449  -79.340  48.368  1
62069  95.483  -79.346  48.327  1
62070  95.523  -79.350  48.285  1
62071  95.552  -79.344  48.243  1
62072  95.574  -79.331  48.202  1
62073  95.597  -79.318  48.162  1
62074  95.619  -79.305  48.122  1
62075  95.629  -79.299  48.082  1
62076  95.639  -79.294  48.043  1
62077  95.650  -79.288  48.005  1
62078  95.660  -79.283  47.967  1
62079  95.670  -79.277  47.929  1
62080  95.680  -79.272  47.892  1
62081  95.690  -79.266  47.854  1
62082  95.700  -79.261  47.817  1
62083  95.716  -79.259  47.779  1
62084  95.750  -79.268  47.742  1
62085  95.783  -79.278  47.706  1
62086  95.799  -79.301  47.669  1
62087  95.808  -79.329  47.632  1
62088  95.818  -79.353  47.596  1
62089  95.828  -79.363  47.559  1
62090  95.864  -79.364  47.522  1
62091  95.876  -79.332  47.487  1
62092  95.872  -79.288  47.451  1
62093  95.868  -79.244  47.416  1
62094  95.864  -79.200  47.380  1
62095  95.893  -79.197  47.344  1
62096  95.941  -79.219  47.309  1
62097  95.988  -79.241  47.274  1
62098  96.036  -79.262  47.240  1
62099  96.084  -79.283  47.205  1
62100  96.131  -79.305  47.171  1
62101  96.177  -79.325  47.137  1
62102  96.197  -79.333  47.103  1
62103  96.217  -79.341  47.069  1
62104  96.238  -79.349  47.036  1
62105  96.258  -79.357  47.003  1
62106  96.278  -79.366  46.971  1
62107  96.299  -79.374  46.939  1
62108  96.319  -79.382  46.907  1
62109  96.339  -79.390  46.875  1
62110  96.360  -79.398  46.843  1
62111  96.380  -79.407  46.812  1
62112  96.400  -79.414  46.781  1
62113  96.421  -79.422  46.751  1
62114  96.441  -79.431  46.721  1
62115  96.462  -79.439  46.691  1
62116  96.482  -79.447  46.661  1
62117  96.503  -79.455  46.631  1
62118  96.523  -79.463  46.604  1
62119  96.543  -79.472  46.578  1
62120  96.564  -79.481  46.552  1
62121  96.585  -79.491  46.528  1
62122  96.605  -79.501  46.503  1
62123  96.626  -79.512  46.477  1
62124  96.647  -79.523  46.453  1
62125  96.658  -79.523  46.431  1
62126  96.669  -79.521  46.410  1
62127  96.692  -79.523  46.388  1
62128  96.715  -79.526  46.365  1
62129  96.734  -79.507  46.341  1
62130  96.752  -79.486  46.317  1
62131  96.771  -79.465  46.295  1
62132  96.795  -79.448  46.275  1
62133  96.827  -79.438  46.256  1
62134  96.861  -79.428  46.234  1
62135  96.899  -79.429  46.210  1
62136  96.945  -79.442  46.185  1
62137  96.979  -79.442  46.159  1
62138  97.005  -79.427  46.133  1
62139  97.036  -79.400  46.109  1
62140  97.066  -79.377  46.087  1
62141  97.094  -79.371  46.065  1
62142  97.116  -79.366  46.042  1
62143  97.129  -79.369  46.018  1
62144  97.143  -79.373  45.995  1
62145  97.156  -79.378  45.971  1
62146  97.170  -79.382  45.948  1
62147  97.184  -79.386  45.927  1
62148  97.203  -79.391  45.904  1
62149  97.223  -79.395  45.877  1
62150  97.239  -79.403  45.850  1
62151  97.268  -79.410  45.825  1
62152  97.279  -79.419  45.801  1
62153  97.272  -79.429  45.777  1
62154  97.264  -79.438  45.755  1
62155  97.261  -79.441  45.733  1
62156  97.266  -79.432  45.711  1
62157  97.265  -79.436  45.690  1
62158  97.263  -79.441  45.670  1
62159  97.262  -79.447  45.650  1
62160  97.261  -79.451  45.631  1
62161  97.251  -79.469  45.614  1
62162  97.225  -79.507  45.596  1
62163  97.232  -79.514  45.578  1
62164  97.239  -79.522  45.561  1
62165  97.246  -79.529  45.543  1
62166  97.253  -79.538  45.525  1
62167  97.260  -79.545  45.507  1
62168  97.267  -79.553  45.490  1
62169  97.275  -79.560  45.473  1
62170  97.282  -79.568  45.456  1
62171  97.289  -79.576  45.438  1
62172  97.296  -79.583  45.420  1
62173  97.303  -79.591  45.402  1
62174  97.310  -79.598  45.385  1
62175  97.317  -79.606  45.369  1
62176  97.324  -79.614  45.352  1
62177  97.331  -79.621  45.335  1
62178  97.338  -79.629  45.319  1
62179  97.345  -79.637  45.301  1
62180  97.363  -79.651  45.285  1
62181  97.382  -79.667  45.269  1
62182  97.401  -79.682  45.254  1
62233  98.379  -80.461  44.623  1
62234  98.398  -80.476  44.616  1
62235  98.417  -80.491  44.609  1
62236  98.436  -80.507  44.601  1
62237  98.455  -80.522  44.594  1
62238  98.475  -80.538  44.587  1
62239  98.498  -80.544  44.581  1
62240  98.522  -80.547  44.574  1
62241  98.547  -80.549  44.566  1
62242  98.572  -80.552  44.559  1
62243  98.597  -80.554  44.552  1
62244  98.622  -80.557  44.543  1
62245  98.646  -80.560  44.536  1
62246  98.671  -80.562  44.530  1
62247  98.696  -80.565  44.523  1
62248  98.721  -80.568  44.516  1
62249  98.746  -80.572  44.508  1
62250  98.772  -80.576  44.501  1
62251  98.797  -80.580  44.495  1
62252  98.823  -80.584  44.489  1
62253  98.848  -80.589  44.484  1
62254  98.871  -80.600  44.478  1
62577  93.316  -79.168  53.438  1
62578  93.326  -79.165  53.423  1
62579  93.335  -79.162  53.409  1
62580  93.345  -79.160  53.395  1
62581  93.355  -79.158  53.379  1
62582  93.364  -79.156  53.365  1
62583  93.374  -79.153  53.351  1
62584  93.384  -79.150  53.336  1
62585  93.394  -79.148  53.321  1
62586  93.403  -79.146  53.306  1
62587  93.414  -79.137  53.292  1
62588  93.425  -79.127  53.278  1
62589  93.437  -79.116  53.265  1
62590  93.446  -79.109  53.252  1
62591  93.454  -79.101  53.239  1
62592  93.463  -79.094  53.229  1
62593  93.471  -79.087  53.221  1
62594  93.479  -79.085  53.214  1
62595  93.484  -79.090  53.210  1
62596  93.490  -79.095  53.211  1
62597  93.504  -79.089  53.212  1
62598  93.523  -79.076  53.213  1
62599  93.542  -79.063  53.213  1
62600  93.561  -79.051  53.212  1
62601  93.572  -79.051  53.210  1
62602  93.579  -79.056  53.207  1
62603  93.587  -79.059  53.203  1
62604  93.595  -79.064  53.198  1
62605  93.608  -79.065  53.192  1
62606  93.625  -79.065  53.185  1
62607  93.643  -79.065  53.176  1
62608  93.660  -79.065  53.166  1
62609  93.678  -79.065  53.156  1
62610  93.693  -79.065  53.143  1
62611  93.707  -79.064  53.129  1
62612  93.722  -79.061  53.115  1
62613  93.737  -79.057  53.101  1
62614  93.752  -79.054  53.085  1
62615  93.766  -79.050  53.069  1
62616  93.781  -79.047  53.054  1
62617  93.795  -79.043  53.039  1
62618  93.800  -79.042  53.024  1
62619  93.804  -79.040  53.009  1
62620  93.808  -79.039  52.995  1
62621  93.816  -79.037  52.980  1
62622  93.824  -79.034  52.964  1
62623  93.832  -79.031  52.947  1
62624  93.840  -79.028  52.931  1
62625  93.848  -79.025  52.916  1
62626  93.856  -79.023  52.902  1
62627  93.863  -79.020  52.891  1
62628  93.871  -79.018  52.880  1
62629  93.877  -79.022  52.867  1
62630  93.884  -79.026  52.853  1
62631  93.887  -79.028  52.839  1
62632  93.888  -79.031  52.825  1
62633  93.889  -79.034  52.813  1
62634  93.890  -79.036  52.802  1
62635  93.893  -79.038  52.789  1
62636  93.897  -79.040  52.774  1
62637  93.900  -79.043  52.759  1
62638  93.903  -79.045  52.743  1
62639  93.906  -79.048  52.727  1
62640  93.910  -79.055  52.712  1
62641  93.914  -79.063  52.700  1
62642  93.918  -79.071  52.687  1
62643  93.922  -79.079  52.674  1
62644  93.922  -79.080  52.662  1
62645  93.933  -79.080  52.649  1
62646  93.959  -79.082  52.634  1
62647  93.984  -79.084  52.616  1
62648  94.000  -79.076  52.596  1
62649  94.005  -79.076  52.573  1
62650  94.004  -79.078  52.547  1
62651  94.004  -79.081  52.519  1
62652  94.004  -79.081  52.489  1
62653  94.005  -79.077  52.457  1
62654  94.006  -79.074  52.423  1
62655  94.007  -79.070  52.389  1
62656  94.008  -79.066  52.355  1
62657  94.010  -79.063  52.318  1
62658  94.011  -79.059  52.282  1
62659  94.012  -79.056  52.249  1
62660  94.017  -79.054  52.218  1
62661  94.026  -79.053  52.193  1
62662  94.034  -79.051  52.171  1
62663  94.043  -79.049  52.150  1
62664  94.051  -79.048  52.130  1
62665  94.060  -79.046  52.111  1
62666  94.069  -79.045  52.092  1
62667  94.078  -79.043  52.072  1
62668  94.087  -79.041  52.052  1
62669  94.104  -79.031  52.031  1
62670  94.120  -79.021  52.009  1
62671  94.137  -79.012  51.984  1
62672  94.158  -78.983  51.960  1
62673  94.179  -78.952  51.937  1
62674  94.200  -78.921  51.916  1
62675  94.221  -78.891  51.894  1
62676  94.243  -78.861  51.872  1
62677  94.262  -78.832  51.847  1
62678  94.279  -78.821  51.815  1
62679  94.292  -78.824  51.780  1
62680  94.306  -78.826  51.745  1
62681  94.320  -78.829  51.708  1
62682  94.332  -78.833  51.671  1
62683  94.343  -78.838  51.635  1
62684  94.346  -78.814  51.600  1
62685  94.362  -78.814  51.562  1
62686  94.382  -78.824  51.525  1
62687  94.401  -78.832  51.489  1
62688  94.421  -78.829  51.454  1
62689  94.445  -78.839  51.422  1
62690  94.468  -78.849  51.391  1
62691  94.491  -78.859  51.361  1
62692  94.515  -78.876  51.330  1
62693  94.536  -78.893  51.298  1
62694  94.550  -78.901  51.265  1
62695  94.569  -78.906  51.228  1
62696  94.591  -78.908  51.190  1
62697  94.607  -78.913  51.151  1
62698  94.623  -78.918  51.114  1
62699  94.639  -78.923  51.077  1
62700  94.653  -78.924  51.041  1
62701  94.664  -78.918  51.005  1
62702  94.675  -78.912  50.964  1
62703  94.686  -78.905  50.924  1
62704  94.696  -78.899  50.886  1
62705  94.707  -78.893  50.849  1
62706  94.718  -78.886  50.811  1
62707  94.729  -78.879  50.771  1
62708  94.740  -78.873  50.731  1
62709  94.750  -78.866  50.690  1
62710  94.761  -78.860  50.650  1
62711  94.772  -78.853  50.609  1
62712  94.782  -78.847  50.568  1
62713  94.793  -78.840  50.525  1
62714  94.804  -78.833  50.483  1
62715  94.815  -78.829  50.443  1
62716  94.826  -78.825  50.402  1
62717  94.835  -78.830  50.363  1
62718  94.844  -78.838  50.325  1
62719  94.852  -78.846  50.286  1
62720  94.860  -78.853  50.248  1
62721  94.871  -78.865  50.210  1
62722  94.880  -78.881  50.172  1
62723  94.887  -78.894  50.134  1
62724  94.893  -78.907  50.096  1
62725  94.899  -78.919  50.058  1
62726  94.906  -78.932  50.020  1
62727  94.909  -78.942  49.982  1
62728  94.912  -78.950  49.945  1
62729  94.914  -78.959  49.907  1
62730  94.917  -78.966  49.869  1
62731  94.919  -78.974  49.831  1
62732  94.922  -78.983  49.791  1
62733  94.924  -78.991  49.753  1
62734  94.927  -78.999  49.715  1
62735  94.929  -79.008  49.677  1
62736  94.932  -79.016  49.639  1
62737  94.934  -79.024  49.602  1
62738  94.936  -79.032  49.566  1
62739  94.939  -79.040  49.530  1
62740  94.935  -79.076  49.496  1
62741  94.929  -79.118  49.464  1
62742  94.957  -79.129  49.432  1
62743  94.989  -79.136  49.400  1
62744  95.013  -79.143  49.368  1
62745  95.030  -79.153  49.335  1
62746  95.047  -79.162  49.302  1
62747  95.063  -79.175  49.269  1
62748  95.078  -79.190  49.235  1
62749  95.094  -79.204  49.201  1
62750  95.109  -79.219  49.166  1
62751  95.126  -79.231  49.129  1
62752  95.148  -79.241  49.090  1
62753  95.170  -79.250  49.050  1
62754  95.191  -79.259  49.009  1
62755  95.212  -79.269  48.968  1
62756  95.234  -79.278  48.928  1
62757  95.254  -79.284  48.887  1
62758  95.274  -79.288  48.845  1
62759  95.294  -79.285  48.802  1
62760  95.312  -79.279  48.759  1
62761  95.330  -79.273  48.717  1
62762  95.348  -79.267  48.674  1
62763  95.366  -79.261  48.632  1
62764  95.384  -79.255  48.588  1
62765  95.398  -79.265  48.544  1
62766  95.411  -79.280  48.501  1
62767  95.424  -79.296  48.458  1
62768  95.437  -79.312  48.416  1
62769  95.450  -79.327  48.374  1
62770  95.481  -79.335  48.331  1
62771  95.520  -79.339  48.289  1
62772  95.549  -79.332  48.247  1
62773  95.571  -79.319  48.205  1
62774  95.594  -79.306  48.166  1
62775  95.616  -79.293  48.127  1
62776  95.631  -79.285  48.087  1
62777  95.641  -79.279  48.049  1
62778  95.652  -79.273  48.010  1
62779  95.662  -79.268  47.971  1
62780  95.672  -79.263  47.932  1
62781  95.683  -79.257  47.895  1
62782  95.693  -79.251  47.857  1
62783  95.703  -79.246  47.819  1
62784  95.723  -79.247  47.780  1
62785  95.757  -79.256  47.742  1
62786  95.790  -79.266  47.705  1
62787  95.812  -79.284  47.668  1
62788  95.821  -79.312  47.632  1
62789  95.831  -79.341  47.595  1
62790  95.840  -79.359  47.557  1
62791  95.869  -79.352  47.521  1
62792  95.865  -79.308  47.485  1
62793  95.861  -79.264  47.449  1
62794  95.857  -79.220  47.413  1
62795  95.853  -79.176  47.376  1
62796  95.874  -79.164  47.341  1
62797  95.921  -79.185  47.305  1
62798  95.969  -79.206  47.270  1
62799  96.017  -79.228  47.236  1
62800  96.064  -79.250  47.201  1
62801  96.112  -79.271  47.166  1
62802  96.160  -79.293  47.132  1
62803  96.207  -79.314  47.097  1
62804  96.230  -79.322  47.062  1
62805  96.250  -79.331  47.030  1
62806  96.270  -79.339  46.997  1
62807  96.291  -79.347  46.965  1
62808  96.311  -79.356  46.932  1
62809  96.331  -79.363  46.900  1
62810  96.352  -79.372  46.868  1
62811  96.372  -79.380  46.835  1
62812  96.392  -79.388  46.805  1
62813  96.413  -79.396  46.775  1
62814  96.433  -79.404  46.745  1
62815  96.454  -79.413  46.714  1
62816  96.474  -79.421  46.684  1
62817  96.494  -79.429  46.655  1
62818  96.515  -79.438  46.626  1
62819  96.536  -79.448  46.598  1
62820  96.556  -79.459  46.571  1
62821  96.577  -79.469  46.545  1
62822  96.598  -79.479  46.519  1
62823  96.619  -79.490  46.494  1
62824  96.637  -79.498  46.470  1
62825  96.646  -79.496  46.445  1
62826  96.655  -79.494  46.422  1
62827  96.677  -79.496  46.399  1
62828  96.699  -79.498  46.376  1
62829  96.722  -79.501  46.352  1
62830  96.742  -79.484  46.328  1
62831  96.760  -79.463  46.305  1
62832  96.779  -79.442  46.281  1
62833  96.798  -79.421  46.259  1
62834  96.816  -79.400  46.239  1
62835  96.849  -79.390  46.217  1
62836  96.882  -79.379  46.195  1
62837  96.924  -79.387  46.173  1
62838  96.969  -79.400  46.148  1
62839  97.011  -79.408  46.122  1
62840  97.041  -79.382  46.098  1
62841  97.072  -79.356  46.077  1
62842  97.101  -79.338  46.056  1
62843  97.114  -79.342  46.034  1
62844  97.128  -79.347  46.011  1
62845  97.142  -79.351  45.987  1
62846  97.156  -79.356  45.963  1
62847  97.169  -79.360  45.941  1
62848  97.186  -79.364  45.919  1
62849  97.208  -79.368  45.894  1
62850  97.226  -79.374  45.870  1
62851  97.251  -79.382  45.845  1
62852  97.281  -79.389  45.820  1
62853  97.296  -79.398  45.797  1
62854  97.289  -79.407  45.774  1
62855  97.282  -79.417  45.752  1
62856  97.275  -79.427  45.731  1
62857  97.267  -79.437  45.710  1
62858  97.265  -79.437  45.689  1
62859  97.271  -79.424  45.669  1
62860  97.273  -79.422  45.649  1
62861  97.272  -79.427  45.630  1
62862  97.271  -79.432  45.613  1
62863  97.269  -79.438  45.596  1
62864  97.257  -79.457  45.578  1
62865  97.239  -79.488  45.560  1
62866  97.246  -79.495  45.543  1
62867  97.253  -79.503  45.525  1
62868  97.260  -79.510  45.507  1
62869  97.267  -79.518  45.490  1
62870  97.275  -79.526  45.473  1
62871  97.282  -79.533  45.456  1
62872  97.289  -79.541  45.438  1
62873  97.296  -79.548  45.421  1
62874  97.303  -79.557  45.403  1
62875  97.310  -79.564  45.386  1
62876  97.317  -79.572  45.369  1
62877  97.324  -79.579  45.353  1
62878  97.331  -79.587  45.337  1
62879  97.338  -79.595  45.320  1
62880  97.349  -79.604  45.304  1
62881  97.368  -79.620  45.288  1
62882  97.387  -79.635  45.272  1
62883  97.406  -79.651  45.256  1
62884  97.426  -79.666  45.241  1
62931  98.327  -80.384  44.654  1
62932  98.346  -80.399  44.646  1
62933  98.365  -80.415  44.639  1
62934  98.384  -80.430  44.632  1
62935  98.404  -80.445  44.625  1
62936  98.423  -80.460  44.618  1
62937  98.442  -80.475  44.610  1
62938  98.461  -80.491  44.603  1
62939  98.480  -80.506  44.596  1
62940  98.503  -80.513  44.590  1
62941  98.528  -80.516  44.583  1
62942  98.553  -80.518  44.576  1
62943  98.577  -80.520  44.568  1
62944  98.602  -80.523  44.560  1
62945  98.627  -80.526  44.551  1
62946  98.652  -80.529  44.544  1
62947  98.676  -80.531  44.538  1
62948  98.701  -80.533  44.531  1
62949  98.726  -80.537  44.524  1
62950  98.751  -80.541  44.516  1
62951  98.777  -80.544  44.509  1
62952  98.803  -80.548  44.503  1
62953  98.828  -80.553  44.498  1
62954  98.852  -80.562  44.492  1
62955  98.875  -80.573  44.486  1
62956  98.899  -80.583  44.481  1
63280  93.336  -79.152  53.433  1
63281  93.345  -79.150  53.418  1
63282  93.355  -79.147  53.403  1
63283  93.365  -79.144  53.389  1
63284  93.374  -79.142  53.374  1
63285  93.384  -79.140  53.359  1
63286  93.394  -79.137  53.343  1
63287  93.404  -79.134  53.330  1
63288  93.413  -79.132  53.316  1
63289  93.424  -79.123  53.301  1
63290  93.436  -79.112  53.289  1
63291  93.447  -79.102  53.275  1
63292  93.455  -79.095  53.262  1
63293  93.464  -79.088  53.251  1
63294  93.472  -79.081  53.241  1
63295  93.481  -79.074  53.234  1
63296  93.489  -79.068  53.228  1
63297  93.494  -79.073  53.226  1
63298  93.500  -79.078  53.225  1
63299  93.505  -79.083  53.226  1
63300  93.524  -79.070  53.227  1
63301  93.544  -79.058  53.227  1
63302  93.562  -79.046  53.227  1
63303  93.570  -79.050  53.225  1
63304  93.578  -79.054  53.222  1
63305  93.586  -79.059  53.218  1
63306  93.601  -79.059  53.213  1
63307  93.618  -79.058  53.206  1
63308  93.635  -79.057  53.197  1
63309  93.653  -79.056  53.187  1
63310  93.671  -79.056  53.178  1
63311  93.686  -79.056  53.164  1
63312  93.701  -79.053  53.150  1
63313  93.715  -79.049  53.135  1
63314  93.730  -79.046  53.121  1
63315  93.745  -79.042  53.106  1
63316  93.759  -79.038  53.090  1
63317  93.774  -79.035  53.077  1
63318  93.788  -79.031  53.063  1
63319  93.793  -79.030  53.049  1
63320  93.797  -79.029  53.034  1
63321  93.803  -79.027  53.021  1
63322  93.812  -79.024  53.006  1
63323  93.820  -79.021  52.990  1
63324  93.828  -79.018  52.974  1
63325  93.836  -79.015  52.958  1
63326  93.844  -79.012  52.944  1
63327  93.851  -79.010  52.931  1
63328  93.859  -79.007  52.921  1
63329  93.867  -79.004  52.910  1
63330  93.874  -79.006  52.897  1
63331  93.880  -79.009  52.883  1
63332  93.883  -79.012  52.869  1
63333  93.884  -79.015  52.855  1
63334  93.885  -79.017  52.842  1
63335  93.887  -79.020  52.828  1
63336  93.889  -79.022  52.814  1
63337  93.892  -79.024  52.799  1
63338  93.895  -79.027  52.783  1
63339  93.898  -79.029  52.767  1
63340  93.901  -79.031  52.751  1
63341  93.905  -79.040  52.735  1
63342  93.909  -79.047  52.721  1
63343  93.913  -79.056  52.708  1
63344  93.915  -79.059  52.693  1
63345  93.913  -79.056  52.680  1
63346  93.929  -79.057  52.666  1
63347  93.956  -79.059  52.651  1
63348  93.981  -79.062  52.632  1
63349  94.005  -79.062  52.612  1
63350  94.006  -79.062  52.589  1
63351  94.007  -79.059  52.562  1
63352  94.008  -79.055  52.533  1
63353  94.009  -79.052  52.504  1
63354  94.010  -79.048  52.473  1
63355  94.012  -79.044  52.439  1
63356  94.013  -79.041  52.406  1
63357  94.014  -79.037  52.372  1
63358  94.015  -79.034  52.334  1
63359  94.016  -79.031  52.300  1
63360  94.017  -79.028  52.268  1
63361  94.023  -79.024  52.238  1
63362  94.031  -79.024  52.213  1
63363  94.040  -79.022  52.191  1
63364  94.048  -79.021  52.171  1
63365  94.057  -79.018  52.149  1
63366  94.067  -79.017  52.129  1
63367  94.076  -79.015  52.109  1
63368  94.085  -79.013  52.088  1
63369  94.096  -79.009  52.066  1
63370  94.113  -78.999  52.045  1
63371  94.129  -78.990  52.024  1
63372  94.146  -78.981  52.001  1
63373  94.162  -78.971  51.977  1
63374  94.183  -78.940  51.954  1
63375  94.204  -78.909  51.932  1
63376  94.226  -78.879  51.911  1
63377  94.247  -78.849  51.888  1
63378  94.268  -78.818  51.862  1
63379  94.285  -78.808  51.828  1
63380  94.300  -78.806  51.793  1
63381  94.314  -78.809  51.757  1
63382  94.327  -78.811  51.720  1
63383  94.340  -78.814  51.684  1
63384  94.352  -78.820  51.648  1
63385  94.363  -78.824  51.613  1
63386  94.363  -78.788  51.577  1
63387  94.382  -78.796  51.540  1
63388  94.402  -78.798  51.504  1
63389  94.424  -78.808  51.470  1
63390  94.448  -78.820  51.437  1
63391  94.474  -78.845  51.406  1
63392  94.500  -78.869  51.377  1
63393  94.515  -78.877  51.346  1
63394  94.530  -78.886  51.314  1
63395  94.544  -78.894  51.281  1
63396  94.558  -78.902  51.247  1
63397  94.578  -78.906  51.210  1
63398  94.601  -78.908  51.171  1
63399  94.623  -78.910  51.134  1
63400  94.642  -78.914  51.097  1
63401  94.658  -78.918  51.062  1
63402  94.671  -78.916  51.027  1
63403  94.682  -78.910  50.988  1
63404  94.692  -78.903  50.950  1
63405  94.703  -78.897  50.912  1
63406  94.714  -78.890  50.877  1
63407  94.724  -78.884  50.839  1
63408  94.736  -78.877  50.800  1
63409  94.746  -78.871  50.760  1
63410  94.757  -78.865  50.719  1
63411  94.768  -78.858  50.677  1
63412  94.778  -78.852  50.635  1
63413  94.789  -78.845  50.593  1
63414  94.800  -78.838  50.549  1
63415  94.811  -78.832  50.505  1
63416  94.822  -78.825  50.464  1
63417  94.832  -78.819  50.425  1
63418  94.843  -78.812  50.387  1
63419  94.852  -78.820  50.349  1
63420  94.856  -78.830  50.311  1
63421  94.858  -78.838  50.272  1
63422  94.861  -78.846  50.233  1
63423  94.863  -78.855  50.194  1
63424  94.866  -78.863  50.154  1
63425  94.868  -78.871  50.115  1
63426  94.871  -78.879  50.076  1
63427  94.874  -78.887  50.037  1
63428  94.876  -78.896  49.999  1
63429  94.879  -78.904  49.962  1
63430  94.881  -78.912  49.924  1
63431  94.884  -78.921  49.886  1
63432  94.886  -78.929  49.848  1
63433  94.888  -78.937  49.809  1
63434  94.891  -78.945  49.770  1
63435  94.893  -78.953  49.732  1
63436  94.896  -78.962  49.694  1
63437  94.898  -78.970  49.657  1
63438  94.897  -78.992  49.620  1
63439  94.892  -79.034  49.585  1
63440  94.886  -79.077  49.549  1
63441  94.907  -79.093  49.515  1
63442  94.939  -79.100  49.482  1
63443  94.972  -79.107  49.449  1
63444  94.997  -79.115  49.415  1
63445  95.014  -79.124  49.382  1
63446  95.031  -79.134  49.349  1
63447  95.048  -79.143  49.315  1
63448  95.064  -79.153  49.282  1
63449  95.079  -79.168  49.249  1
63450  95.095  -79.182  49.215  1
63451  95.111  -79.197  49.178  1
63452  95.130  -79.208  49.141  1
63453  95.152  -79.217  49.102  1
63454  95.174  -79.226  49.062  1
63455  95.195  -79.235  49.021  1
63456  95.216  -79.245  48.979  1
63457  95.238  -79.254  48.938  1
63458  95.261  -79.262  48.895  1
63459  95.281  -79.266  48.853  1
63460  95.298  -79.261  48.810  1
63461  95.316  -79.255  48.766  1
63462  95.334  -79.250  48.723  1
63463  95.351  -79.244  48.680  1
63464  95.370  -79.237  48.637  1
63465  95.386  -79.236  48.593  1
63466  95.399  -79.252  48.550  1
63467  95.412  -79.267  48.507  1
63468  95.425  -79.283  48.463  1
63469  95.438  -79.299  48.420  1
63470  95.451  -79.314  48.378  1
63471  95.478  -79.324  48.335  1
63472  95.517  -79.328  48.293  1
63473  95.546  -79.322  48.252  1
63474  95.568  -79.308  48.212  1
63475  95.591  -79.295  48.172  1
63476  95.613  -79.281  48.133  1
63477  95.634  -79.269  48.093  1
63478  95.644  -79.264  48.053  1
63479  95.655  -79.259  48.014  1
63480  95.665  -79.253  47.975  1
63481  95.675  -79.247  47.936  1
63482  95.685  -79.242  47.898  1
63483  95.695  -79.237  47.859  1
63484  95.705  -79.231  47.821  1
63485  95.730  -79.234  47.782  1
63486  95.763  -79.244  47.744  1
63487  95.797  -79.253  47.707  1
63488  95.825  -79.266  47.669  1
63489  95.835  -79.294  47.632  1
63490  95.844  -79.323  47.594  1
63491  95.853  -79.351  47.556  1
63492  95.858  -79.328  47.520  1
63493  95.853  -79.285  47.483  1
63494  95.849  -79.241  47.447  1
63495  95.846  -79.197  47.411  1
63496  95.842  -79.153  47.375  1
63497  95.855  -79.130  47.339  1
63498  95.902  -79.152  47.303  1
63499  95.950  -79.173  47.267  1
63500  95.997  -79.194  47.232  1
63501  96.045  -79.216  47.197  1
63502  96.093  -79.237  47.162  1
63503  96.141  -79.259  47.128  1
63504  96.188  -79.280  47.093  1
63505  96.236  -79.302  47.058  1
63506  96.262  -79.313  47.025  1
63507  96.283  -79.321  46.993  1
63508  96.303  -79.329  46.960  1
63509  96.323  -79.337  46.927  1
63510  96.343  -79.345  46.895  1
63511  96.364  -79.353  46.863  1
63512  96.384  -79.362  46.831  1
63513  96.404  -79.369  46.800  1
63514  96.425  -79.378  46.770  1
63515  96.445  -79.386  46.740  1
63516  96.466  -79.395  46.710  1
63517  96.486  -79.406  46.680  1
63518  96.508  -79.416  46.650  1
63519  96.528  -79.426  46.621  1
63520  96.549  -79.437  46.593  1
63521  96.570  -79.447  46.565  1
63522  96.591  -79.457  46.538  1
63523  96.611  -79.468  46.512  1
63524  96.625  -79.471  46.487  1
63525  96.635  -79.469  46.462  1
63526  96.644  -79.467  46.435  1
63527  96.662  -79.468  46.411  1
63528  96.684  -79.471  46.389  1
63529  96.707  -79.473  46.365  1
63530  96.730  -79.476  46.341  1
63531  96.750  -79.460  46.316  1
63532  96.768  -79.439  46.292  1
63533  96.787  -79.419  46.268  1
63534  96.806  -79.397  46.246  1
63535  96.824  -79.376  46.225  1
63536  96.843  -79.355  46.203  1
63537  96.870  -79.341  46.181  1
63538  96.903  -79.332  46.159  1
63539  96.949  -79.344  46.136  1
63540  96.994  -79.357  46.111  1
63541  97.043  -79.347  46.088  1
63542  97.058  -79.307  46.067  1
63543  97.098  -79.323  46.047  1
63544  97.113  -79.324  46.025  1
63545  97.127  -79.325  46.002  1
63546  97.141  -79.329  45.978  1
63547  97.155  -79.334  45.954  1
63548  97.169  -79.338  45.932  1
63549  97.191  -79.342  45.912  1
63550  97.213  -79.346  45.887  1
63551  97.234  -79.353  45.864  1
63552  97.264  -79.360  45.841  1
63553  97.290  -79.371  45.817  1
63554  97.307  -79.375  45.793  1
63555  97.306  -79.386  45.771  1
63556  97.299  -79.396  45.749  1
63557  97.292  -79.406  45.729  1
63558  97.285  -79.415  45.708  1
63559  97.278  -79.425  45.688  1
63560  97.271  -79.435  45.668  1
63561  97.270  -79.432  45.648  1
63562  97.276  -79.419  45.630  1
63563  97.281  -79.408  45.613  1
63564  97.280  -79.413  45.595  1
63565  97.278  -79.418  45.577  1
63566  97.277  -79.423  45.559  1
63567  97.263  -79.445  45.542  1
63568  97.253  -79.468  45.524  1
63569  97.260  -79.476  45.507  1
63570  97.267  -79.484  45.490  1
63571  97.275  -79.491  45.473  1
63572  97.282  -79.499  45.456  1
63573  97.289  -79.507  45.439  1
63574  97.296  -79.514  45.422  1
63575  97.303  -79.522  45.404  1
63576  97.310  -79.529  45.386  1
63577  97.317  -79.537  45.370  1
63578  97.324  -79.545  45.354  1
63579  97.331  -79.552  45.338  1
63580  97.338  -79.560  45.322  1
63581  97.355  -79.573  45.306  1
63582  97.374  -79.588  45.290  1
63583  97.393  -79.604  45.274  1
63584  97.412  -79.619  45.259  1
63585  97.431  -79.635  45.244  1
63586  97.450  -79.650  45.229  1
63587  97.469  -79.665  45.213  1
63588  97.489  -79.680  45.198  1
63630  98.294  -80.322  44.680  1
63631  98.313  -80.337  44.672  1
63632  98.332  -80.353  44.662  1
63633  98.351  -80.368  44.655  1
63634  98.370  -80.383  44.648  1
63635  98.390  -80.398  44.641  1
63636  98.409  -80.414  44.634  1
63637  98.428  -80.429  44.627  1
63638  98.447  -80.444  44.619  1
63639  98.466  -80.460  44.612  1
63640  98.486  -80.475  44.605  1
63641  98.508  -80.482  44.599  1
63642  98.533  -80.484  44.592  1
63643  98.558  -80.487  44.585  1
63644  98.583  -80.489  44.578  1
63645  98.607  -80.492  44.569  1
63646  98.632  -80.494  44.560  1
63647  98.657  -80.497  44.553  1
63648  98.682  -80.500  44.547  1
63649  98.707  -80.502  44.539  1
63650  98.731  -80.505  44.532  1
63651  98.757  -80.509  44.525  1
63652  98.783  -80.513  44.518  1
63653  98.808  -80.517  44.512  1
63654  98.833  -80.524  44.506  1
63655  98.856  -80.535  44.502  1
63656  98.879  -80.545  44.496  1
63657  98.903  -80.556  44.491  1
63658  98.926  -80.566  44.485  1
63983  93.355  -79.136  53.426  1
63984  93.365  -79.134  53.412  1
63985  93.374  -79.131  53.397  1
63986  93.384  -79.128  53.382  1
63987  93.394  -79.126  53.367  1
63988  93.404  -79.124  53.353  1
63989  93.413  -79.122  53.338  1
63990  93.423  -79.118  53.325  1
63991  93.434  -79.109  53.311  1
63992  93.446  -79.098  53.297  1
63993  93.457  -79.088  53.284  1
63994  93.465  -79.081  53.272  1
63995  93.474  -79.075  53.261  1
63996  93.482  -79.068  53.252  1
63997  93.490  -79.061  53.246  1
63998  93.498  -79.053  53.240  1
63999  93.505  -79.056  53.237  1
64000  93.510  -79.061  53.237  1
64001  93.515  -79.066  53.238  1
64002  93.526  -79.065  53.239  1
64003  93.546  -79.052  53.240  1
64004  93.561  -79.044  53.240  1
64005  93.569  -79.049  53.238  1
64006  93.577  -79.053  53.235  1
64007  93.594  -79.052  53.232  1
64008  93.612  -79.051  53.225  1
64009  93.629  -79.050  53.217  1
64010  93.646  -79.049  53.207  1
64011  93.664  -79.046  53.198  1
64012  93.680  -79.043  53.185  1
64013  93.694  -79.040  53.171  1
64014  93.708  -79.037  53.155  1
64015  93.723  -79.034  53.142  1
64016  93.737  -79.030  53.128  1
64017  93.752  -79.027  53.113  1
64018  93.767  -79.023  53.101  1
64019  93.782  -79.020  53.088  1
64020  93.786  -79.018  53.075  1
64021  93.791  -79.016  53.060  1
64022  93.799  -79.014  53.046  1
64023  93.807  -79.011  53.032  1
64024  93.816  -79.008  53.017  1
64025  93.824  -79.005  53.001  1
64026  93.832  -79.002  52.987  1
64027  93.839  -78.999  52.974  1
64028  93.847  -78.996  52.961  1
64029  93.855  -78.994  52.951  1
64030  93.863  -78.991  52.941  1
64031  93.871  -78.990  52.928  1
64032  93.877  -78.993  52.914  1
64033  93.880  -78.996  52.900  1
64034  93.881  -78.999  52.885  1
64035  93.882  -79.001  52.872  1
64036  93.883  -79.003  52.858  1
64037  93.884  -79.006  52.843  1
64038  93.887  -79.009  52.826  1
64039  93.890  -79.011  52.809  1
64040  93.894  -79.013  52.791  1
64041  93.897  -79.016  52.775  1
64042  93.901  -79.024  52.758  1
64043  93.905  -79.032  52.743  1
64044  93.908  -79.039  52.727  1
64045  93.906  -79.036  52.712  1
64046  93.905  -79.033  52.697  1
64047  93.926  -79.034  52.681  1
64048  93.952  -79.037  52.665  1
64049  93.978  -79.039  52.646  1
64050  93.997  -79.043  52.626  1
64051  94.008  -79.044  52.603  1
64052  94.010  -79.038  52.576  1
64053  94.012  -79.032  52.546  1
64054  94.014  -79.026  52.517  1
64055  94.016  -79.020  52.489  1
64056  94.017  -79.015  52.456  1
64057  94.018  -79.012  52.423  1
64058  94.019  -79.009  52.388  1
64059  94.020  -79.006  52.352  1
64060  94.022  -79.002  52.319  1
64061  94.023  -78.999  52.289  1
64062  94.028  -78.996  52.260  1
64063  94.037  -78.995  52.236  1
64064  94.046  -78.993  52.214  1
64065  94.055  -78.991  52.193  1
64066  94.064  -78.989  52.170  1
64067  94.073  -78.987  52.148  1
64068  94.082  -78.986  52.126  1
64069  94.092  -78.984  52.105  1
64070  94.105  -78.977  52.083  1
64071  94.121  -78.968  52.062  1
64072  94.138  -78.959  52.042  1
64073  94.154  -78.949  52.018  1
64074  94.171  -78.939  51.995  1
64075  94.188  -78.927  51.973  1
64076  94.209  -78.897  51.951  1
64077  94.230  -78.867  51.928  1
64078  94.251  -78.836  51.903  1
64079  94.272  -78.805  51.875  1
64080  94.289  -78.800  51.842  1
64081  94.305  -78.797  51.807  1
64082  94.321  -78.795  51.770  1
64083  94.335  -78.794  51.733  1
64084  94.348  -78.797  51.698  1
64085  94.360  -78.802  51.663  1
64086  94.372  -78.807  51.628  1
64087  94.380  -78.799  51.593  1
64088  94.382  -78.767  51.557  1
64089  94.407  -78.789  51.520  1
64090  94.433  -78.814  51.487  1
64091  94.460  -78.838  51.454  1
64092  94.480  -78.854  51.422  1
64093  94.494  -78.862  51.392  1
64094  94.509  -78.871  51.361  1
64095  94.525  -78.877  51.330  1
64096  94.543  -78.881  51.298  1
64097  94.562  -78.885  51.265  1
64098  94.581  -78.890  51.228  1
64099  94.600  -78.895  51.190  1
64100  94.619  -78.899  51.153  1
64101  94.638  -78.904  51.118  1
64102  94.657  -78.909  51.083  1
64103  94.677  -78.914  51.050  1
64104  94.688  -78.907  51.012  1
64105  94.698  -78.899  50.973  1
64106  94.709  -78.892  50.934  1
64107  94.719  -78.884  50.898  1
64108  94.730  -78.877  50.862  1
64109  94.741  -78.869  50.824  1
64110  94.751  -78.861  50.784  1
64111  94.762  -78.854  50.743  1
64112  94.772  -78.846  50.701  1
64113  94.782  -78.839  50.660  1
64114  94.793  -78.831  50.617  1
64115  94.804  -78.824  50.573  1
64116  94.814  -78.816  50.529  1
64117  94.821  -78.812  50.487  1
64118  94.825  -78.811  50.450  1
64119  94.834  -78.812  50.414  1
64120  94.857  -78.814  50.378  1
64121  94.855  -78.815  50.339  1
64122  94.849  -78.814  50.299  1
64123  94.843  -78.814  50.259  1
64124  94.836  -78.814  50.217  1
64125  94.833  -78.817  50.176  1
64126  94.835  -78.825  50.135  1
64127  94.838  -78.833  50.095  1
64128  94.840  -78.842  50.056  1
64129  94.842  -78.849  50.017  1
64130  94.845  -78.858  49.980  1
64131  94.847  -78.866  49.943  1
64132  94.850  -78.874  49.904  1
64133  94.852  -78.883  49.865  1
64134  94.855  -78.891  49.827  1
64135  94.857  -78.899  49.788  1
64136  94.859  -78.908  49.750  1
64137  94.854  -78.950  49.712  1
64138  94.848  -78.993  49.675  1
64139  94.845  -79.032  49.638  1
64140  94.854  -79.059  49.603  1
64141  94.889  -79.065  49.569  1
64142  94.922  -79.071  49.534  1
64143  94.954  -79.078  49.499  1
64144  94.982  -79.085  49.465  1
64145  94.998  -79.095  49.431  1
64146  95.016  -79.104  49.398  1
64147  95.032  -79.114  49.365  1
64148  95.049  -79.124  49.331  1
64149  95.065  -79.133  49.297  1
64150  95.081  -79.146  49.263  1
64151  95.097  -79.161  49.229  1
64152  95.113  -79.175  49.192  1
64153  95.134  -79.184  49.153  1
64154  95.156  -79.194  49.114  1
64155  95.177  -79.203  49.074  1
64156  95.199  -79.212  49.032  1
64157  95.222  -79.220  48.990  1
64158  95.247  -79.225  48.947  1
64159  95.273  -79.228  48.904  1
64160  95.296  -79.233  48.861  1
64161  95.301  -79.237  48.817  1
64162  95.319  -79.231  48.773  1
64163  95.337  -79.225  48.730  1
64164  95.355  -79.219  48.686  1
64165  95.373  -79.213  48.643  1
64166  95.387  -79.223  48.599  1
64167  95.400  -79.239  48.555  1
64168  95.413  -79.255  48.512  1
64169  95.426  -79.270  48.468  1
64170  95.439  -79.286  48.425  1
64171  95.452  -79.302  48.383  1
64172  95.475  -79.313  48.340  1
64173  95.515  -79.317  48.299  1
64174  95.543  -79.310  48.258  1
64175  95.565  -79.297  48.219  1
64176  95.588  -79.284  48.178  1
64177  95.610  -79.271  48.138  1
64178  95.633  -79.257  48.097  1
64179  95.647  -79.250  48.057  1
64180  95.657  -79.244  48.018  1
64181  95.667  -79.238  47.979  1
64182  95.678  -79.233  47.940  1
64183  95.688  -79.228  47.901  1
64184  95.698  -79.222  47.862  1
64185  95.708  -79.216  47.823  1
64186  95.736  -79.222  47.785  1
64187  95.770  -79.231  47.746  1
64188  95.804  -79.241  47.708  1
64189  95.837  -79.250  47.670  1
64190  95.848  -79.278  47.632  1
64191  95.858  -79.306  47.594  1
64192  95.866  -79.332  47.556  1
64193  95.861  -79.310  47.519  1
64194  95.843  -79.262  47.483  1
64195  95.838  -79.218  47.446  1
64196  95.835  -79.174  47.411  1
64197  95.831  -79.130  47.375  1
64198  95.835  -79.096  47.339  1
64199  95.883  -79.118  47.302  1
64200  95.931  -79.140  47.266  1
64201  95.978  -79.161  47.230  1
64202  96.026  -79.182  47.195  1
64203  96.074  -79.204  47.159  1
64204  96.121  -79.225  47.124  1
64205  96.169  -79.247  47.089  1
64206  96.217  -79.268  47.055  1
64207  96.264  -79.290  47.021  1
64208  96.295  -79.303  46.988  1
64209  96.315  -79.310  46.955  1
64210  96.335  -79.319  46.922  1
64211  96.356  -79.327  46.890  1
64212  96.376  -79.335  46.858  1
64213  96.396  -79.343  46.826  1
64214  96.417  -79.353  46.795  1
64215  96.438  -79.363  46.765  1
64216  96.459  -79.373  46.735  1
64217  96.479  -79.384  46.705  1
64218  96.500  -79.394  46.675  1
64219  96.521  -79.404  46.645  1
64220  96.542  -79.415  46.616  1
64221  96.562  -79.426  46.588  1
64222  96.583  -79.435  46.560  1
64223  96.604  -79.446  46.532  1
64224  96.614  -79.444  46.506  1
64225  96.623  -79.443  46.479  1
64226  96.631  -79.441  46.454  1
64227  96.647  -79.441  46.426  1
64228  96.669  -79.443  46.402  1
64229  96.692  -79.445  46.379  1
64230  96.715  -79.448  46.355  1
64231  96.738  -79.451  46.331  1
64232  96.758  -79.437  46.306  1
64233  96.777  -79.416  46.280  1
64234  96.795  -79.395  46.256  1
64235  96.814  -79.374  46.233  1
64236  96.832  -79.353  46.212  1
64237  96.851  -79.332  46.190  1
64238  96.870  -79.311  46.168  1
64239  96.892  -79.293  46.147  1
64240  96.928  -79.289  46.125  1
64241  96.974  -79.301  46.100  1
64242  97.007  -79.277  46.078  1
64243  97.056  -79.294  46.058  1
64244  97.094  -79.312  46.037  1
64245  97.109  -79.313  46.015  1
64246  97.124  -79.313  45.992  1
64247  97.139  -79.314  45.968  1
64248  97.154  -79.315  45.945  1
64249  97.174  -79.316  45.924  1
64250  97.196  -79.320  45.904  1
64251  97.218  -79.324  45.880  1
64252  97.220  -79.350  45.859  1
64253  97.209  -79.381  45.837  1
64254  97.246  -79.363  45.814  1
64255  97.280  -79.353  45.790  1
64256  97.296  -79.357  45.768  1
64257  97.300  -79.370  45.747  1
64258  97.304  -79.382  45.726  1
64259  97.302  -79.394  45.707  1
64260  97.295  -79.404  45.687  1
64261  97.288  -79.413  45.667  1
64262  97.281  -79.422  45.647  1
64263  97.274  -79.432  45.629  1
64264  97.274  -79.428  45.613  1
64265  97.280  -79.415  45.595  1
64266  97.285  -79.403  45.577  1
64267  97.288  -79.399  45.559  1
64268  97.286  -79.404  45.542  1
64269  97.285  -79.409  45.524  1
64270  97.269  -79.434  45.506  1
64271  97.267  -79.449  45.490  1
64272  97.275  -79.457  45.473  1
64273  97.282  -79.464  45.456  1
64274  97.289  -79.472  45.439  1
64275  97.296  -79.479  45.422  1
64276  97.303  -79.487  45.405  1
64277  97.310  -79.494  45.387  1
64278  97.317  -79.503  45.372  1
64279  97.324  -79.510  45.355  1
64280  97.331  -79.518  45.339  1
64281  97.341  -79.527  45.325  1
64282  97.360  -79.542  45.308  1
64283  97.379  -79.557  45.292  1
64284  97.398  -79.573  45.277  1
64285  97.418  -79.588  45.261  1
64286  97.437  -79.603  45.247  1
64287  97.456  -79.618  45.232  1
64288  97.475  -79.634  45.216  1
64289  97.494  -79.649  45.202  1
64290  97.513  -79.664  45.187  1
64291  97.532  -79.679  45.172  1
64292  97.551  -79.695  45.158  1
64329  98.261  -80.260  44.706  1
64330  98.280  -80.275  44.697  1
64331  98.299  -80.291  44.689  1
64332  98.318  -80.306  44.680  1
64333  98.338  -80.322  44.671  1
64334  98.357  -80.337  44.664  1
64335  98.376  -80.352  44.657  1
64336  98.395  -80.367  44.650  1
64337  98.414  -80.382  44.643  1
64338  98.433  -80.398  44.636  1
64339  98.452  -80.413  44.629  1
64340  98.472  -80.428  44.621  1
64341  98.491  -80.444  44.615  1
64342  98.514  -80.450  44.609  1
64343  98.538  -80.453  44.602  1
64344  98.564  -80.455  44.595  1
64345  98.588  -80.458  44.587  1
64346  98.613  -80.460  44.578  1
64347  98.638  -80.463  44.569  1
64348  98.662  -80.466  44.562  1
64349  98.687  -80.468  44.556  1
64350  98.712  -80.471  44.549  1
64351  98.737  -80.474  44.542  1
64352  98.763  -80.478  44.535  1
64353  98.788  -80.482  44.528  1
64354  98.813  -80.486  44.521  1
64355  98.837  -80.497  44.515  1
64356  98.860  -80.507  44.510  1
64357  98.883  -80.518  44.505  1
64358  98.907  -80.529  44.499  1
64359  98.930  -80.539  44.493  1
64360  98.953  -80.549  44.488  1
64686  93.375  -79.120  53.420  1
64687  93.384  -79.118  53.405  1
64688  93.394  -79.115  53.390  1
64689  93.404  -79.112  53.376  1
64690  93.414  -79.110  53.362  1
64691  93.423  -79.108  53.348  1
64692  93.433  -79.105  53.333  1
64693  93.444  -79.094  53.319  1
64694  93.456  -79.084  53.306  1
64695  93.466  -79.075  53.294  1
64696  93.475  -79.068  53.283  1
64697  93.483  -79.061  53.273  1
64698  93.491  -79.054  53.265  1
64699  93.500  -79.047  53.258  1
64700  93.508  -79.040  53.253  1
64701  93.515  -79.039  53.250  1
64702  93.520  -79.044  53.249  1
64703  93.526  -79.049  53.249  1
64704  93.532  -79.054  53.251  1
64705  93.547  -79.046  53.253  1
64706  93.560  -79.043  53.254  1
64707  93.570  -79.046  53.253  1
64708  93.587  -79.045  53.250  1
64709  93.605  -79.044  53.243  1
64710  93.624  -79.040  53.235  1
64711  93.643  -79.034  53.226  1
64712  93.661  -79.030  53.217  1
64713  93.675  -79.028  53.205  1
64714  93.689  -79.025  53.191  1
64715  93.703  -79.023  53.176  1
64716  93.716  -79.021  53.164  1
64717  93.730  -79.018  53.151  1
64718  93.746  -79.015  53.138  1
64719  93.760  -79.011  53.126  1
64720  93.775  -79.008  53.114  1
64721  93.779  -79.006  53.101  1
64722  93.787  -79.003  53.087  1
64723  93.795  -79.000  53.073  1
64724  93.803  -78.998  53.058  1
64725  93.812  -78.995  53.044  1
64726  93.820  -78.992  53.029  1
64727  93.827  -78.990  53.016  1
64728  93.835  -78.987  53.004  1
64729  93.843  -78.984  52.992  1
64730  93.851  -78.981  52.982  1
64731  93.859  -78.978  52.971  1
64732  93.867  -78.975  52.959  1
64733  93.874  -78.977  52.945  1
64734  93.876  -78.980  52.931  1
64735  93.877  -78.983  52.916  1
64736  93.879  -78.985  52.901  1
64737  93.880  -78.987  52.887  1
64738  93.881  -78.990  52.872  1
64739  93.883  -78.992  52.855  1
64740  93.886  -78.995  52.837  1
64741  93.889  -78.997  52.819  1
64742  93.892  -79.001  52.802  1
64743  93.896  -79.009  52.784  1
64744  93.900  -79.017  52.766  1
64745  93.899  -79.015  52.749  1
64746  93.898  -79.012  52.731  1
64747  93.897  -79.009  52.714  1
64748  93.923  -79.012  52.696  1
64749  93.949  -79.014  52.677  1
64750  93.968  -79.019  52.658  1
64751  93.985  -79.024  52.637  1
64752  94.003  -79.029  52.615  1
64753  94.009  -79.027  52.588  1
64754  94.011  -79.021  52.559  1
64755  94.013  -79.015  52.530  1
64756  94.015  -79.009  52.502  1
64757  94.017  -79.002  52.471  1
64758  94.019  -78.996  52.439  1
64759  94.022  -78.990  52.406  1
64760  94.024  -78.984  52.372  1
64761  94.026  -78.978  52.341  1
64762  94.028  -78.972  52.311  1
64763  94.034  -78.967  52.284  1
64764  94.044  -78.965  52.261  1
64765  94.053  -78.963  52.239  1
64766  94.062  -78.962  52.216  1
64767  94.071  -78.959  52.192  1
64768  94.080  -78.958  52.168  1
64769  94.089  -78.956  52.144  1
64770  94.099  -78.954  52.123  1
64771  94.114  -78.946  52.102  1
64772  94.130  -78.937  52.081  1
64773  94.146  -78.927  52.061  1
64774  94.163  -78.917  52.037  1
64775  94.180  -78.907  52.014  1
64776  94.196  -78.897  51.993  1
64777  94.213  -78.885  51.969  1
64778  94.235  -78.855  51.945  1
64779  94.256  -78.824  51.919  1
64780  94.276  -78.796  51.889  1
64781  94.292  -78.793  51.856  1
64782  94.308  -78.789  51.821  1
64783  94.324  -78.786  51.784  1
64784  94.340  -78.784  51.748  1
64785  94.356  -78.781  51.714  1
64786  94.368  -78.786  51.680  1
64787  94.379  -78.793  51.646  1
64788  94.391  -78.802  51.610  1
64789  94.395  -78.786  51.574  1
64790  94.419  -78.807  51.538  1
64791  94.445  -78.830  51.503  1
64792  94.459  -78.839  51.470  1
64793  94.475  -78.845  51.439  1
64794  94.494  -78.849  51.408  1
64795  94.512  -78.853  51.377  1
64796  94.531  -78.857  51.346  1
64797  94.550  -78.861  51.315  1
64798  94.568  -78.865  51.282  1
64799  94.587  -78.870  51.246  1
64800  94.607  -78.874  51.209  1
64801  94.626  -78.880  51.172  1
64802  94.645  -78.884  51.137  1
64803  94.663  -78.888  51.103  1
64804  94.677  -78.889  51.070  1
64805  94.690  -78.885  51.034  1
64806  94.700  -78.877  50.995  1
64807  94.711  -78.870  50.957  1
64808  94.721  -78.862  50.921  1
64809  94.732  -78.855  50.885  1
64810  94.742  -78.847  50.847  1
64811  94.753  -78.839  50.807  1
64812  94.763  -78.832  50.765  1
64813  94.774  -78.824  50.723  1
64814  94.784  -78.817  50.681  1
64815  94.789  -78.815  50.638  1
64816  94.793  -78.814  50.594  1
64817  94.797  -78.814  50.550  1
64818  94.801  -78.813  50.507  1
64819  94.805  -78.813  50.469  1
64820  94.827  -78.815  50.434  1
64821  94.850  -78.818  50.399  1
64822  94.874  -78.821  50.362  1
64823  94.871  -78.821  50.324  1
64824  94.864  -78.821  50.285  1
64825  94.858  -78.821  50.243  1
64826  94.851  -78.821  50.200  1
64827  94.845  -78.820  50.158  1
64828  94.839  -78.820  50.116  1
64829  94.832  -78.820  50.076  1
64830  94.826  -78.820  50.037  1
64831  94.820  -78.820  49.999  1
64832  94.814  -78.820  49.961  1
64833  94.817  -78.828  49.924  1
64834  94.819  -78.836  49.886  1
64835  94.817  -78.866  49.847  1
64836  94.824  -78.895  49.809  1
64837  94.832  -78.923  49.771  1
64838  94.840  -78.951  49.733  1
64839  94.848  -78.979  49.694  1
64840  94.856  -79.007  49.658  1
64841  94.863  -79.035  49.623  1
64842  94.896  -79.045  49.588  1
64843  94.935  -79.049  49.553  1
64844  94.966  -79.056  49.518  1
64845  94.983  -79.065  49.485  1
64846  95.000  -79.075  49.452  1
64847  95.017  -79.085  49.419  1
64848  95.033  -79.094  49.386  1
64849  95.050  -79.104  49.352  1
64850  95.066  -79.113  49.316  1
64851  95.083  -79.125  49.280  1
64852  95.098  -79.139  49.243  1
64853  95.117  -79.151  49.206  1
64854  95.138  -79.160  49.167  1
64855  95.160  -79.169  49.126  1
64856  95.182  -79.178  49.085  1
64857  95.207  -79.183  49.043  1
64858  95.233  -79.187  49.000  1
64859  95.259  -79.191  48.957  1
64860  95.284  -79.196  48.913  1
64861  95.310  -79.200  48.869  1
64862  95.314  -79.206  48.824  1
64863  95.323  -79.208  48.781  1
64864  95.341  -79.202  48.737  1
64865  95.358  -79.196  48.694  1
64866  95.376  -79.195  48.650  1
64867  95.388  -79.211  48.606  1
64868  95.401  -79.226  48.562  1
64869  95.414  -79.242  48.517  1
64870  95.427  -79.258  48.474  1
64871  95.440  -79.273  48.431  1
64872  95.453  -79.289  48.389  1
64873  95.472  -79.302  48.348  1
64874  95.512  -79.306  48.306  1
64875  95.540  -79.299  48.265  1
64876  95.562  -79.285  48.225  1
64877  95.585  -79.272  48.184  1
64878  95.607  -79.259  48.142  1
64879  95.630  -79.246  48.100  1
64880  95.650  -79.234  48.060  1
64881  95.660  -79.229  48.020  1
64882  95.670  -79.224  47.981  1
64883  95.680  -79.218  47.943  1
64884  95.690  -79.212  47.904  1
64885  95.700  -79.207  47.865  1
64886  95.711  -79.202  47.826  1
64887  95.743  -79.210  47.787  1
64888  95.776  -79.219  47.748  1
64889  95.810  -79.228  47.710  1
64890  95.844  -79.238  47.672  1
64891  95.862  -79.260  47.634  1
64892  95.871  -79.288  47.595  1
64893  95.875  -79.297  47.557  1
64894  95.870  -79.278  47.520  1
64895  95.861  -79.247  47.484  1
64896  95.843  -79.200  47.448  1
64897  95.825  -79.151  47.412  1
64898  95.820  -79.106  47.376  1
64899  95.816  -79.063  47.340  1
64900  95.864  -79.084  47.303  1
64901  95.911  -79.106  47.266  1
64902  95.959  -79.128  47.230  1
64903  96.007  -79.149  47.194  1
64904  96.054  -79.170  47.158  1
64905  96.102  -79.192  47.122  1
64906  96.150  -79.213  47.087  1
64907  96.197  -79.234  47.052  1
64908  96.245  -79.256  47.017  1
64909  96.293  -79.278  46.984  1
64910  96.327  -79.292  46.951  1
64911  96.347  -79.300  46.918  1
64912  96.368  -79.310  46.885  1
64913  96.389  -79.320  46.853  1
64914  96.409  -79.331  46.821  1
64915  96.431  -79.341  46.791  1
64916  96.451  -79.351  46.760  1
64917  96.472  -79.362  46.730  1
64918  96.493  -79.372  46.700  1
64919  96.514  -79.382  46.671  1
64920  96.534  -79.393  46.641  1
64921  96.555  -79.404  46.612  1
64922  96.576  -79.414  46.584  1
64923  96.593  -79.420  46.556  1
64924  96.602  -79.418  46.527  1
64925  96.611  -79.416  46.500  1
64926  96.620  -79.414  46.473  1
64927  96.631  -79.413  46.445  1
64928  96.654  -79.416  46.418  1
64929  96.677  -79.418  46.393  1
64930  96.700  -79.420  46.369  1
64931  96.723  -79.423  46.345  1
64932  96.745  -79.426  46.321  1
64933  96.765  -79.413  46.297  1
64934  96.784  -79.393  46.271  1
64935  96.803  -79.372  46.246  1
64936  96.821  -79.350  46.223  1
64937  96.840  -79.329  46.201  1
64938  96.859  -79.309  46.179  1
64939  96.877  -79.288  46.159  1
64940  96.896  -79.266  46.137  1
64941  96.914  -79.245  46.115  1
64942  96.955  -79.245  46.091  1
64943  97.000  -79.255  46.069  1
64944  97.058  -79.287  46.047  1
64945  97.091  -79.300  46.026  1
64946  97.105  -79.301  46.005  1
64947  97.120  -79.302  45.983  1
64948  97.135  -79.303  45.961  1
64949  97.157  -79.304  45.939  1
64950  97.179  -79.306  45.919  1
64951  97.197  -79.307  45.898  1
64952  97.205  -79.313  45.875  1
64953  97.171  -79.351  45.854  1
64954  97.180  -79.355  45.832  1
64955  97.215  -79.345  45.809  1
64956  97.249  -79.335  45.786  1
64957  97.282  -79.327  45.764  1
64958  97.286  -79.340  45.744  1
64959  97.290  -79.352  45.724  1
64960  97.294  -79.365  45.705  1
64961  97.298  -79.378  45.685  1
64962  97.302  -79.391  45.666  1
64963  97.298  -79.401  45.647  1
64964  97.291  -79.411  45.629  1
64965  97.284  -79.420  45.612  1
64966  97.277  -79.430  45.594  1
64967  97.279  -79.423  45.576  1
64968  97.284  -79.410  45.560  1
64969  97.290  -79.398  45.542  1
64970  97.295  -79.385  45.524  1
64971  97.294  -79.390  45.507  1
64972  97.293  -79.395  45.489  1
64973  97.276  -79.422  45.474  1
64974  97.282  -79.430  45.457  1
64975  97.289  -79.438  45.440  1
64976  97.296  -79.445  45.423  1
64977  97.303  -79.453  45.405  1
64978  97.310  -79.460  45.389  1
64979  97.317  -79.468  45.373  1
64980  97.324  -79.476  45.357  1
64981  97.331  -79.483  45.341  1
64982  97.346  -79.495  45.326  1
64983  97.365  -79.511  45.311  1
64984  97.384  -79.526  45.295  1
64985  97.403  -79.541  45.280  1
64986  97.423  -79.557  45.265  1
64987  97.442  -79.572  45.250  1
64988  97.461  -79.587  45.235  1
64989  97.480  -79.602  45.220  1
64990  97.500  -79.618  45.205  1
64991  97.519  -79.633  45.191  1
64992  97.538  -79.648  45.176  1
64993  97.557  -79.664  45.163  1
64994  97.576  -79.679  45.149  1
64995  97.595  -79.694  45.135  1
64996  97.614  -79.710  45.121  1
64997  97.634  -79.725  45.107  1
65028  98.228  -80.199  44.732  1
65029  98.247  -80.214  44.724  1
65030  98.266  -80.229  44.714  1
65031  98.286  -80.244  44.706  1
65032  98.305  -80.259  44.697  1
65033  98.324  -80.275  44.689  1
65034  98.343  -80.290  44.681  1
65035  98.362  -80.306  44.673  1
65036  98.381  -80.321  44.666  1
65037  98.401  -80.336  44.659  1
65038  98.420  -80.351  44.653  1
65039  98.439  -80.366  44.646  1
65040  98.458  -80.382  44.638  1
65041  98.477  -80.397  44.631  1
65042  98.496  -80.413  44.625  1
65043  98.519  -80.419  44.618  1
65044  98.544  -80.422  44.611  1
65045  98.569  -80.424  44.604  1
65046  98.593  -80.427  44.597  1
65047  98.619  -80.429  44.588  1
65048  98.643  -80.431  44.579  1
65049  98.668  -80.435  44.572  1
65050  98.693  -80.437  44.565  1
65051  98.717  -80.440  44.558  1
65052  98.742  -80.442  44.551  1
65053  98.768  -80.447  44.544  1
65054  98.793  -80.450  44.538  1
65055  98.817  -80.459  44.531  1
65056  98.841  -80.469  44.525  1
65057  98.864  -80.480  44.519  1
65058  98.887  -80.491  44.514  1
65059  98.911  -80.501  44.508  1
65060  98.934  -80.512  44.503  1
65061  98.957  -80.522  44.497  1
65062  98.981  -80.532  44.491  1
65388  93.385  -79.106  53.428  1
65389  93.395  -79.104  53.413  1
65390  93.404  -79.102  53.399  1
65391  93.414  -79.100  53.385  1
65392  93.424  -79.096  53.371  1
65393  93.433  -79.094  53.356  1
65394  93.443  -79.090  53.342  1
65395  93.454  -79.080  53.329  1
65396  93.466  -79.070  53.316  1
65397  93.476  -79.062  53.305  1
65398  93.484  -79.055  53.294  1
65399  93.492  -79.047  53.285  1
65400  93.501  -79.040  53.277  1
65401  93.509  -79.034  53.270  1
65402  93.517  -79.027  53.266  1
65403  93.525  -79.022  53.263  1
65404  93.531  -79.027  53.263  1
65405  93.536  -79.032  53.264  1
65406  93.542  -79.037  53.268  1
65407  93.549  -79.040  53.270  1
65408  93.564  -79.039  53.271  1
65409  93.583  -79.034  53.268  1
65410  93.602  -79.028  53.262  1
65411  93.621  -79.024  53.254  1
65412  93.640  -79.018  53.244  1
65413  93.656  -79.015  53.235  1
65414  93.671  -79.012  53.223  1
65415  93.684  -79.010  53.211  1
65416  93.698  -79.008  53.199  1
65417  93.712  -79.006  53.187  1
65418  93.726  -79.003  53.176  1
65419  93.740  -79.001  53.164  1
65420  93.754  -78.999  53.153  1
65421  93.768  -78.996  53.141  1
65422  93.775  -78.993  53.128  1
65423  93.783  -78.990  53.114  1
65424  93.791  -78.987  53.101  1
65425  93.799  -78.985  53.087  1
65426  93.807  -78.982  53.072  1
65427  93.815  -78.979  53.058  1
65428  93.823  -78.977  53.046  1
65429  93.831  -78.974  53.035  1
65430  93.839  -78.971  53.024  1
65431  93.847  -78.968  53.013  1
65432  93.855  -78.965  53.001  1
65433  93.863  -78.962  52.989  1
65434  93.871  -78.961  52.976  1
65435  93.873  -78.964  52.962  1
65436  93.874  -78.966  52.947  1
65437  93.875  -78.968  52.931  1
65438  93.876  -78.971  52.917  1
65439  93.877  -78.974  52.902  1
65440  93.878  -78.976  52.884  1
65441  93.881  -78.978  52.866  1
65442  93.884  -78.981  52.848  1
65443  93.888  -78.985  52.830  1
65444  93.892  -78.993  52.810  1
65445  93.892  -78.994  52.791  1
65446  93.890  -78.991  52.771  1
65447  93.889  -78.988  52.751  1
65448  93.894  -78.987  52.731  1
65449  93.920  -78.989  52.710  1
65450  93.938  -78.994  52.689  1
65451  93.956  -78.999  52.668  1
65452  93.973  -79.004  52.647  1
65453  93.991  -79.009  52.624  1
65454  94.009  -79.015  52.598  1
65455  94.011  -79.009  52.571  1
65456  94.013  -79.002  52.542  1
65457  94.015  -78.997  52.514  1
65458  94.017  -78.991  52.484  1
65459  94.019  -78.985  52.454  1
65460  94.022  -78.979  52.424  1
65461  94.023  -78.973  52.392  1
65462  94.027  -78.965  52.363  1
65463  94.037  -78.955  52.335  1
65464  94.045  -78.944  52.310  1
65465  94.053  -78.940  52.286  1
65466  94.060  -78.934  52.263  1
65467  94.068  -78.932  52.241  1
65468  94.078  -78.930  52.216  1
65469  94.087  -78.928  52.191  1
65470  94.096  -78.927  52.168  1
65471  94.106  -78.924  52.145  1
65472  94.122  -78.915  52.123  1
65473  94.139  -78.905  52.101  1
65474  94.155  -78.895  52.080  1
65475  94.172  -78.885  52.056  1
65476  94.188  -78.875  52.033  1
65477  94.205  -78.866  52.010  1
65478  94.221  -78.856  51.986  1
65479  94.239  -78.843  51.962  1
65480  94.260  -78.811  51.935  1
65481  94.280  -78.788  51.905  1
65482  94.296  -78.785  51.871  1
65483  94.312  -78.782  51.836  1
65484  94.328  -78.780  51.801  1
65485  94.343  -78.780  51.765  1
65486  94.359  -78.781  51.731  1
65487  94.374  -78.776  51.699  1
65488  94.386  -78.782  51.665  1
65489  94.397  -78.791  51.629  1
65490  94.409  -78.805  51.592  1
65491  94.426  -78.813  51.557  1
65492  94.445  -78.817  51.521  1
65493  94.463  -78.821  51.487  1
65494  94.482  -78.825  51.455  1
65495  94.500  -78.829  51.424  1
65496  94.519  -78.833  51.393  1
65497  94.538  -78.837  51.361  1
65498  94.556  -78.841  51.331  1
65499  94.575  -78.846  51.298  1
65500  94.594  -78.849  51.264  1
65501  94.613  -78.855  51.228  1
65502  94.632  -78.859  51.190  1
65503  94.648  -78.861  51.155  1
65504  94.663  -78.862  51.121  1
65505  94.678  -78.863  51.089  1
65506  94.691  -78.862  51.054  1
65507  94.702  -78.855  51.017  1
65508  94.712  -78.847  50.979  1
65509  94.723  -78.839  50.943  1
65510  94.734  -78.832  50.907  1
65511  94.744  -78.824  50.869  1
65512  94.753  -78.818  50.827  1
65513  94.757  -78.818  50.786  1
65514  94.761  -78.818  50.743  1
65515  94.765  -78.817  50.699  1
65516  94.769  -78.816  50.656  1
65517  94.773  -78.815  50.612  1
65518  94.777  -78.814  50.569  1
65519  94.781  -78.814  50.525  1
65520  94.796  -78.816  50.487  1
65521  94.820  -78.818  50.451  1
65522  94.843  -78.821  50.417  1
65523  94.866  -78.824  50.382  1
65524  94.890  -78.827  50.345  1
65525  94.886  -78.827  50.307  1
65526  94.880  -78.827  50.266  1
65527  94.873  -78.826  50.223  1
65528  94.864  -78.826  50.181  1
65529  94.857  -78.825  50.139  1
65530  94.849  -78.825  50.097  1
65531  94.841  -78.824  50.058  1
65532  94.833  -78.824  50.020  1
65533  94.825  -78.824  49.983  1
65534  94.817  -78.823  49.946  1
65535  94.816  -78.824  49.908  1
65536  94.827  -78.842  49.867  1
65537  94.835  -78.870  49.829  1
65538  94.843  -78.898  49.790  1
65539  94.850  -78.926  49.750  1
65540  94.858  -78.954  49.711  1
65541  94.866  -78.982  49.674  1
65542  94.874  -79.010  49.638  1
65543  94.898  -79.026  49.604  1
65544  94.937  -79.031  49.569  1
65545  94.968  -79.037  49.534  1
65546  94.985  -79.046  49.501  1
65547  95.001  -79.056  49.469  1
65548  95.018  -79.065  49.436  1
65549  95.034  -79.075  49.404  1
65550  95.051  -79.084  49.370  1
65551  95.067  -79.093  49.333  1
65552  95.084  -79.103  49.296  1
65553  95.100  -79.117  49.258  1
65554  95.120  -79.128  49.219  1
65555  95.142  -79.137  49.178  1
65556  95.168  -79.141  49.137  1
65557  95.193  -79.146  49.095  1
65558  95.219  -79.150  49.052  1
65559  95.245  -79.154  49.009  1
65560  95.270  -79.159  48.965  1
65561  95.296  -79.163  48.922  1
65562  95.321  -79.167  48.878  1
65563  95.329  -79.173  48.835  1
65564  95.332  -79.179  48.791  1
65565  95.344  -79.178  48.747  1
65566  95.362  -79.172  48.703  1
65567  95.377  -79.182  48.660  1
65568  95.389  -79.198  48.616  1
65569  95.402  -79.214  48.571  1
65570  95.415  -79.229  48.526  1
65571  95.428  -79.245  48.483  1
65572  95.441  -79.261  48.441  1
65573  95.454  -79.276  48.398  1
65574  95.470  -79.291  48.356  1
65575  95.509  -79.295  48.314  1
65576  95.537  -79.288  48.272  1
65577  95.559  -79.275  48.230  1
65578  95.582  -79.261  48.189  1
65579  95.604  -79.248  48.147  1
65580  95.627  -79.234  48.105  1
65581  95.649  -79.222  48.065  1
65582  95.663  -79.214  48.025  1
65583  95.673  -79.209  47.986  1
65584  95.683  -79.203  47.947  1
65585  95.693  -79.198  47.907  1
65586  95.703  -79.192  47.868  1
65587  95.716  -79.188  47.829  1
65588  95.750  -79.198  47.790  1
65589  95.783  -79.207  47.751  1
65590  95.817  -79.216  47.712  1
65591  95.850  -79.225  47.673  1
65592  95.875  -79.243  47.635  1
65593  95.884  -79.271  47.596  1
65594  95.883  -79.262  47.558  1
65595  95.878  -79.242  47.520  1
65596  95.873  -79.222  47.484  1
65597  95.861  -79.185  47.449  1
65598  95.843  -79.137  47.413  1
65599  95.826  -79.089  47.377  1
65600  95.808  -79.040  47.340  1
65601  95.848  -79.058  47.303  1
65602  95.898  -79.082  47.266  1
65603  95.948  -79.106  47.229  1
65604  95.997  -79.131  47.192  1
65605  96.046  -79.156  47.157  1
65606  96.096  -79.180  47.120  1
65607  96.145  -79.204  47.084  1
65608  96.194  -79.229  47.049  1
65609  96.244  -79.253  47.014  1
65610  96.294  -79.278  46.980  1
65611  96.325  -79.235  46.947  1
65612  96.356  -79.283  46.915  1
65613  96.381  -79.298  46.882  1
65614  96.402  -79.309  46.850  1
65615  96.423  -79.319  46.819  1
65616  96.444  -79.329  46.789  1
65617  96.465  -79.340  46.758  1
65618  96.485  -79.350  46.728  1
65619  96.506  -79.361  46.699  1
65620  96.527  -79.371  46.669  1
65621  96.548  -79.382  46.639  1
65622  96.569  -79.392  46.609  1
65623  96.581  -79.394  46.580  1
65624  96.590  -79.391  46.552  1
65625  96.599  -79.390  46.524  1
65626  96.608  -79.388  46.496  1
65627  96.617  -79.385  46.468  1
65628  96.639  -79.388  46.440  1
65629  96.662  -79.391  46.413  1
65630  96.685  -79.393  46.387  1
65631  96.708  -79.395  46.362  1
65632  96.730  -79.398  46.337  1
65633  96.753  -79.400  46.313  1
65634  96.773  -79.391  46.288  1
65635  96.792  -79.369  46.262  1
65636  96.811  -79.348  46.237  1
65637  96.829  -79.327  46.215  1
65638  96.848  -79.306  46.193  1
65639  96.867  -79.285  46.172  1
65640  96.885  -79.264  46.150  1
65641  96.904  -79.243  46.129  1
65642  96.923  -79.222  46.107  1
65643  96.950  -79.216  46.084  1
65644  97.002  -79.247  46.061  1
65645  97.060  -79.279  46.040  1
65646  97.087  -79.289  46.019  1
65647  97.102  -79.290  45.998  1
65648  97.117  -79.291  45.976  1
65649  97.140  -79.292  45.954  1
65650  97.159  -79.294  45.932  1
65651  97.173  -79.294  45.911  1
65652  97.188  -79.294  45.890  1
65653  97.197  -79.298  45.869  1
65654  97.163  -79.338  45.848  1
65655  97.164  -79.336  45.826  1
65656  97.183  -79.327  45.804  1
65657  97.218  -79.317  45.782  1
65658  97.252  -79.307  45.761  1
65659  97.271  -79.310  45.742  1
65660  97.275  -79.322  45.723  1
65661  97.279  -79.335  45.703  1
65662  97.283  -79.347  45.684  1
65663  97.287  -79.360  45.665  1
65664  97.291  -79.373  45.647  1
65665  97.295  -79.385  45.629  1
65666  97.299  -79.398  45.611  1
65667  97.294  -79.409  45.594  1
65668  97.287  -79.418  45.577  1
65669  97.280  -79.428  45.560  1
65670  97.283  -79.419  45.542  1
65671  97.288  -79.407  45.524  1
65672  97.294  -79.394  45.507  1
65673  97.300  -79.381  45.490  1
65674  97.302  -79.376  45.474  1
65675  97.301  -79.381  45.458  1
65676  97.289  -79.403  45.441  1
65677  97.296  -79.410  45.424  1
65678  97.303  -79.418  45.407  1
65679  97.310  -79.426  45.390  1
65680  97.318  -79.433  45.374  1
65681  97.325  -79.441  45.359  1
65682  97.332  -79.449  45.343  1
65683  97.352  -79.464  45.328  1
65684  97.371  -79.479  45.313  1
65685  97.390  -79.495  45.298  1
65686  97.409  -79.510  45.283  1
65687  97.428  -79.526  45.268  1
65688  97.447  -79.541  45.253  1
65689  97.466  -79.556  45.238  1
65690  97.486  -79.571  45.224  1
65691  97.505  -79.586  45.209  1
65692  97.524  -79.602  45.195  1
65693  97.543  -79.617  45.181  1
65694  97.563  -79.632  45.167  1
65695  97.582  -79.648  45.153  1
65696  97.601  -79.663  45.139  1
65697  97.620  -79.678  45.126  1
65698  97.639  -79.694  45.112  1
65699  97.658  -79.709  45.099  1
65700  97.677  -79.724  45.085  1
65701  97.697  -79.739  45.073  1
65702  97.716  -79.755  45.060  1
65703  97.735  -79.770  45.046  1
65704  97.754  -79.786  45.034  1
65705  97.773  -79.801  45.021  1
65724  98.138  -80.091  44.788  1
65725  98.157  -80.106  44.779  1
65726  98.176  -80.121  44.769  1
65727  98.195  -80.137  44.759  1
65728  98.214  -80.152  44.750  1
65729  98.233  -80.168  44.741  1
65730  98.252  -80.183  44.732  1
65731  98.272  -80.198  44.723  1
65732  98.291  -80.213  44.715  1
65733  98.310  -80.228  44.707  1
65734  98.329  -80.243  44.698  1
65735  98.348  -80.259  44.690  1
65736  98.367  -80.275  44.683  1
65737  98.387  -80.290  44.676  1
65738  98.406  -80.305  44.669  1
65739  98.425  -80.320  44.662  1
65740  98.444  -80.335  44.655  1
65741  98.463  -80.350  44.648  1
65742  98.483  -80.366  44.641  1
65743  98.502  -80.381  44.635  1
65744  98.525  -80.388  44.628  1
65745  98.550  -80.391  44.621  1
65746  98.574  -80.393  44.614  1
65747  98.599  -80.395  44.607  1
65748  98.624  -80.398  44.598  1
65749  98.649  -80.400  44.590  1
65750  98.673  -80.403  44.582  1
65751  98.698  -80.406  44.575  1
65752  98.723  -80.408  44.568  1
65753  98.747  -80.411  44.561  1
65754  98.773  -80.415  44.554  1
65755  98.798  -80.421  44.547  1
65756  98.821  -80.431  44.540  1
65757  98.845  -80.442  44.534  1
65758  98.868  -80.453  44.528  1
65759  98.891  -80.463  44.523  1
65760  98.915  -80.474  44.518  1
65761  98.938  -80.485  44.513  1
65762  98.961  -80.495  44.507  1
65763  98.985  -80.505  44.501  1
65764  99.008  -80.516  44.496  1
66091  93.405  -79.091  53.422  1
66092  93.414  -79.088  53.408  1
66093  93.424  -79.086  53.393  1
66094  93.433  -79.084  53.379  1
66095  93.443  -79.081  53.366  1
66096  93.453  -79.076  53.352  1
66097  93.465  -79.066  53.340  1
66098  93.476  -79.056  53.328  1
66099  93.485  -79.048  53.317  1
66100  93.493  -79.041  53.307  1
66101  93.502  -79.034  53.298  1
66102  93.510  -79.027  53.290  1
66103  93.518  -79.020  53.285  1
66104  93.527  -79.013  53.280  1
66105  93.535  -79.006  53.279  1
66106  93.541  -79.010  53.279  1
66107  93.547  -79.015  53.283  1
66108  93.552  -79.020  53.286  1
66109  93.561  -79.022  53.287  1
66110  93.580  -79.017  53.285  1
66111  93.599  -79.012  53.279  1
66112  93.618  -79.007  53.272  1
66113  93.637  -79.002  53.263  1
66114  93.652  -78.999  53.253  1
66115  93.666  -78.997  53.243  1
66116  93.680  -78.995  53.232  1
66117  93.694  -78.993  53.222  1
66118  93.707  -78.990  53.211  1
66119  93.721  -78.988  53.199  1
66120  93.735  -78.986  53.188  1
66121  93.751  -78.983  53.178  1
66122  93.763  -78.981  53.166  1
66123  93.770  -78.981  53.154  1
66124  93.777  -78.981  53.141  1
66125  93.785  -78.978  53.128  1
66126  93.793  -78.974  53.114  1
66127  93.801  -78.971  53.099  1
66128  93.810  -78.968  53.085  1
66129  93.818  -78.965  53.074  1
66130  93.826  -78.962  53.064  1
66131  93.834  -78.959  53.053  1
66132  93.843  -78.956  53.042  1
66133  93.851  -78.952  53.031  1
66134  93.859  -78.949  53.019  1
66135  93.867  -78.946  53.006  1
66136  93.870  -78.948  52.992  1
66137  93.871  -78.950  52.978  1
66138  93.872  -78.952  52.962  1
66139  93.873  -78.955  52.947  1
66140  93.874  -78.958  52.932  1
66141  93.875  -78.960  52.915  1
66142  93.876  -78.962  52.896  1
66143  93.880  -78.965  52.877  1
66144  93.883  -78.970  52.858  1
66145  93.885  -78.974  52.837  1
66146  93.883  -78.971  52.816  1
66147  93.882  -78.968  52.794  1
66148  93.880  -78.965  52.772  1
66149  93.891  -78.965  52.749  1
66150  93.908  -78.969  52.725  1
66151  93.926  -78.974  52.701  1
66152  93.944  -78.980  52.679  1
66153  93.962  -78.984  52.656  1
66154  93.979  -78.990  52.633  1
66155  93.997  -78.995  52.607  1
66156  94.011  -78.997  52.580  1
66157  94.013  -78.991  52.553  1
66158  94.015  -78.985  52.525  1
66159  94.017  -78.979  52.496  1
66160  94.019  -78.973  52.468  1
66161  94.021  -78.967  52.440  1
66162  94.029  -78.957  52.411  1
66163  94.038  -78.946  52.384  1
66164  94.047  -78.937  52.358  1
66165  94.056  -78.926  52.333  1
66166  94.064  -78.918  52.309  1
66167  94.072  -78.913  52.285  1
66168  94.079  -78.908  52.263  1
66169  94.086  -78.903  52.237  1
66170  94.094  -78.899  52.213  1
66171  94.103  -78.897  52.189  1
66172  94.115  -78.893  52.166  1
66173  94.131  -78.883  52.142  1
66174  94.147  -78.873  52.119  1
66175  94.164  -78.863  52.097  1
66176  94.181  -78.854  52.072  1
66177  94.197  -78.844  52.048  1
66178  94.214  -78.834  52.025  1
66179  94.230  -78.824  52.002  1
66180  94.247  -78.814  51.977  1
66181  94.264  -78.799  51.950  1
66182  94.283  -78.780  51.920  1
66183  94.299  -78.777  51.886  1
66184  94.315  -78.778  51.851  1
66185  94.331  -78.779  51.816  1
66186  94.346  -78.780  51.781  1
66187  94.362  -78.781  51.749  1
66188  94.378  -78.782  51.717  1
66189  94.393  -78.771  51.683  1
66190  94.404  -78.780  51.647  1
66191  94.419  -78.788  51.610  1
66192  94.437  -78.793  51.573  1
66193  94.455  -78.796  51.538  1
66194  94.472  -78.801  51.503  1
66195  94.490  -78.805  51.470  1
66196  94.507  -78.809  51.440  1
66197  94.526  -78.813  51.408  1
66198  94.544  -78.818  51.376  1
66199  94.563  -78.821  51.345  1
66200  94.581  -78.826  51.313  1
66201  94.600  -78.830  51.280  1
66202  94.619  -78.834  51.245  1
66203  94.634  -78.835  51.207  1
66204  94.648  -78.836  51.171  1
66205  94.663  -78.837  51.137  1
66206  94.678  -78.838  51.105  1
66207  94.692  -78.839  51.073  1
66208  94.703  -78.833  51.037  1
66209  94.714  -78.825  50.999  1
66210  94.721  -78.821  50.964  1
66211  94.725  -78.821  50.927  1
66212  94.729  -78.821  50.887  1
66213  94.733  -78.820  50.846  1
66214  94.737  -78.819  50.803  1
66215  94.741  -78.818  50.759  1
66216  94.745  -78.818  50.714  1
66217  94.749  -78.817  50.672  1
66218  94.753  -78.817  50.629  1
66219  94.757  -78.816  50.585  1
66220  94.766  -78.816  50.541  1
66221  94.790  -78.819  50.503  1
66222  94.813  -78.821  50.467  1
66223  94.836  -78.824  50.433  1
66224  94.860  -78.827  50.398  1
66225  94.889  -78.821  50.363  1
66226  94.893  -78.830  50.327  1
66227  94.885  -78.829  50.287  1
66228  94.878  -78.829  50.245  1
66229  94.870  -78.828  50.203  1
66230  94.861  -78.828  50.162  1
66231  94.853  -78.827  50.119  1
66232  94.845  -78.827  50.078  1
66233  94.838  -78.827  50.041  1
66234  94.830  -78.826  50.005  1
66235  94.822  -78.825  49.968  1
66236  94.817  -78.825  49.929  1
66237  94.833  -78.828  49.887  1
66238  94.845  -78.845  49.847  1
66239  94.853  -78.873  49.807  1
66240  94.861  -78.901  49.766  1
66241  94.868  -78.929  49.727  1
66242  94.877  -78.957  49.689  1
66243  94.885  -78.985  49.653  1
66244  94.900  -79.007  49.618  1
66245  94.939  -79.012  49.583  1
66246  94.971  -79.018  49.549  1
66247  94.987  -79.028  49.516  1
66248  95.003  -79.037  49.484  1
66249  95.020  -79.046  49.452  1
66250  95.036  -79.056  49.420  1
66251  95.052  -79.065  49.385  1
66252  95.069  -79.075  49.348  1
66253  95.085  -79.084  49.310  1
66254  95.103  -79.094  49.271  1
66255  95.128  -79.100  49.230  1
66256  95.154  -79.104  49.188  1
66257  95.179  -79.108  49.146  1
66258  95.205  -79.112  49.104  1
66259  95.231  -79.117  49.061  1
66260  95.256  -79.122  49.018  1
66261  95.282  -79.125  48.975  1
66262  95.307  -79.130  48.931  1
66263  95.333  -79.134  48.888  1
66264  95.345  -79.140  48.845  1
66265  95.347  -79.146  48.801  1
66266  95.350  -79.153  48.757  1
66267  95.365  -79.154  48.713  1
66268  95.378  -79.169  48.670  1
66269  95.390  -79.185  48.625  1
66270  95.403  -79.201  48.580  1
66271  95.416  -79.217  48.535  1
66272  95.429  -79.232  48.492  1
66273  95.442  -79.248  48.449  1
66274  95.455  -79.264  48.406  1
66275  95.468  -79.279  48.364  1
66276  95.506  -79.285  48.322  1
66277  95.534  -79.276  48.280  1
66278  95.556  -79.263  48.237  1
66279  95.579  -79.250  48.195  1
66280  95.601  -79.237  48.153  1
66281  95.624  -79.224  48.112  1
66282  95.646  -79.210  48.071  1
66283  95.665  -79.200  48.031  1
66284  95.675  -79.194  47.991  1
66285  95.685  -79.188  47.952  1
66286  95.696  -79.183  47.912  1
66287  95.706  -79.178  47.873  1
66288  95.723  -79.176  47.834  1
66289  95.756  -79.185  47.794  1
66290  95.790  -79.195  47.755  1
66291  95.824  -79.204  47.716  1
66292  95.857  -79.213  47.676  1
66293  95.888  -79.225  47.637  1
66294  95.895  -79.247  47.599  1
66295  95.891  -79.227  47.560  1
66296  95.886  -79.207  47.522  1
66297  95.881  -79.187  47.486  1
66298  95.877  -79.167  47.450  1
66299  95.863  -79.130  47.414  1
66300  95.849  -79.093  47.377  1
66301  95.836  -79.057  47.340  1
66302  95.867  -79.069  47.303  1
66303  95.917  -79.103  47.265  1
66304  95.969  -79.136  47.228  1
66305  96.019  -79.169  47.191  1
66306  96.068  -79.193  47.155  1
66307  96.118  -79.217  47.119  1
66308  96.168  -79.241  47.082  1
66309  96.217  -79.266  47.046  1
66310  96.252  -79.239  47.012  1
66311  96.281  -79.188  46.978  1
66312  96.310  -79.137  46.945  1
66313  96.341  -79.176  46.913  1
66314  96.372  -79.235  46.881  1
66315  96.403  -79.285  46.849  1
66316  96.431  -79.303  46.818  1
66317  96.457  -79.318  46.788  1
66318  96.478  -79.328  46.758  1
66319  96.499  -79.339  46.728  1
66320  96.520  -79.349  46.698  1
66321  96.540  -79.360  46.667  1
66322  96.560  -79.369  46.637  1
66323  96.570  -79.367  46.606  1
66324  96.579  -79.365  46.577  1
66325  96.588  -79.363  46.549  1
66326  96.596  -79.361  46.521  1
66327  96.605  -79.359  46.492  1
66328  96.624  -79.360  46.464  1
66329  96.647  -79.363  46.436  1
66330  96.670  -79.365  46.408  1
66331  96.692  -79.368  46.382  1
66332  96.715  -79.370  46.356  1
66333  96.738  -79.372  46.331  1
66334  96.761  -79.375  46.306  1
66335  96.782  -79.367  46.280  1
66336  96.800  -79.346  46.255  1
66337  96.819  -79.325  46.230  1
66338  96.837  -79.303  46.207  1
66339  96.856  -79.283  46.186  1
66340  96.875  -79.262  46.164  1
66341  96.893  -79.241  46.142  1
66342  96.912  -79.219  46.121  1
66343  96.934  -79.203  46.099  1
66344  96.971  -79.214  46.077  1
66345  97.004  -79.240  46.055  1
66346  97.062  -79.272  46.034  1
66347  97.083  -79.278  46.014  1
66348  97.100  -79.278  45.992  1
66349  97.120  -79.280  45.970  1
66350  97.135  -79.280  45.948  1
66351  97.150  -79.281  45.925  1
66352  97.165  -79.281  45.904  1
66353  97.179  -79.281  45.883  1
66354  97.190  -79.284  45.864  1
66355  97.156  -79.323  45.842  1
66356  97.164  -79.315  45.821  1
66357  97.166  -79.308  45.800  1
66358  97.186  -79.300  45.779  1
66359  97.221  -79.289  45.759  1
66360  97.255  -79.279  45.740  1
66361  97.260  -79.291  45.721  1
66362  97.264  -79.304  45.702  1
66363  97.268  -79.317  45.683  1
66364  97.272  -79.330  45.665  1
66365  97.276  -79.343  45.646  1
66366  97.280  -79.355  45.629  1
66367  97.284  -79.368  45.612  1
66368  97.288  -79.381  45.595  1
66369  97.292  -79.394  45.578  1
66370  97.296  -79.407  45.560  1
66371  97.290  -79.416  45.543  1
66372  97.283  -79.425  45.525  1
66373  97.287  -79.414  45.508  1
66374  97.293  -79.402  45.491  1
66375  97.298  -79.389  45.476  1
66376  97.304  -79.376  45.460  1
66377  97.309  -79.363  45.443  1
66378  97.309  -79.367  45.426  1
66379  97.304  -79.384  45.410  1
66380  97.311  -79.391  45.393  1
66381  97.318  -79.399  45.377  1
66382  97.325  -79.407  45.362  1
66383  97.337  -79.418  45.347  1
66384  97.357  -79.433  45.331  1
66385  97.376  -79.448  45.316  1
66386  97.395  -79.463  45.301  1
66387  97.415  -79.479  45.286  1
66388  97.434  -79.494  45.272  1
66389  97.453  -79.510  45.258  1
66390  97.472  -79.525  45.243  1
66391  97.491  -79.540  45.228  1
66392  97.510  -79.555  45.214  1
66393  97.529  -79.570  45.200  1
66394  97.548  -79.586  45.186  1
66395  97.568  -79.601  45.172  1
66396  97.587  -79.617  45.158  1
66397  97.606  -79.632  45.145  1
66398  97.625  -79.647  45.132  1
66399  97.645  -79.662  45.119  1
66400  97.664  -79.678  45.105  1
66401  97.683  -79.693  45.092  1
66402  97.702  -79.708  45.080  1
66403  97.721  -79.723  45.067  1
66404  97.740  -79.739  45.054  1
66405  97.759  -79.754  45.041  1
66406  97.779  -79.770  45.028  1
66407  97.798  -79.785  45.016  1
66408  97.817  -79.800  45.003  1
66409  97.836  -79.815  44.990  1
66410  97.855  -79.830  44.977  1
66411  97.874  -79.845  44.963  1
66412  97.893  -79.861  44.950  1
66413  97.913  -79.877  44.936  1
66414  97.932  -79.892  44.923  1
66415  97.951  -79.907  44.910  1
66416  97.970  -79.922  44.898  1
66417  97.990  -79.937  44.886  1
66418  98.009  -79.952  44.874  1
66419  98.028  -79.968  44.862  1
66420  98.047  -79.983  44.850  1
66421  98.066  -79.999  44.839  1
66422  98.085  -80.014  44.828  1
66423  98.104  -80.029  44.818  1
66424  98.124  -80.044  44.807  1
66425  98.143  -80.060  44.797  1
66426  98.162  -80.075  44.788  1
66427  98.181  -80.090  44.778  1
66428  98.201  -80.106  44.768  1
66429  98.220  -80.121  44.759  1
66430  98.239  -80.136  44.750  1
66431  98.258  -80.152  44.742  1
66432  98.277  -80.167  44.733  1
66433  98.296  -80.182  44.725  1
66434  98.315  -80.197  44.716  1
66435  98.335  -80.212  44.708  1
66436  98.354  -80.228  44.700  1
66437  98.373  -80.243  44.692  1
66438  98.392  -80.259  44.685  1
66439  98.411  -80.274  44.678  1
66440  98.430  -80.289  44.672  1
66441  98.449  -80.304  44.665  1
66442  98.469  -80.319  44.658  1
66443  98.488  -80.334  44.652  1
66444  98.507  -80.350  44.645  1
66445  98.530  -80.356  44.639  1
66446  98.555  -80.359  44.633  1
66447  98.580  -80.362  44.625  1
66448  98.604  -80.364  44.617  1
66449  98.629  -80.366  44.609  1
66450  98.654  -80.369  44.600  1
66451  98.678  -80.372  44.593  1
66452  98.704  -80.375  44.585  1
66453  98.728  -80.377  44.578  1
66454  98.753  -80.380  44.571  1
66455  98.779  -80.384  44.564  1
66456  98.802  -80.394  44.557  1
66457  98.826  -80.404  44.550  1
66458  98.849  -80.415  44.544  1
66459  98.872  -80.425  44.539  1
66460  98.896  -80.436  44.533  1
66461  98.919  -80.447  44.527  1
66462  98.942  -80.457  44.522  1
66463  98.966  -80.468  44.517  1
66464  98.989  -80.478  44.510  1
66465  99.012  -80.488  44.505  1
66466  99.035  -80.499  44.501  1
66794  93.424  -79.075  53.416  1
66795  93.434  -79.072  53.402  1
66796  93.443  -79.070  53.389  1
66797  93.453  -79.068  53.376  1
66798  93.464  -79.062  53.363  1
66799  93.475  -79.052  53.351  1
66800  93.486  -79.041  53.340  1
66801  93.495  -79.034  53.329  1
66802  93.503  -79.028  53.320  1
66803  93.511  -79.021  53.312  1
66804  93.519  -79.014  53.304  1
66805  93.528  -79.007  53.299  1
66806  93.536  -78.999  53.296  1
66807  93.545  -78.993  53.294  1
66808  93.551  -78.993  53.295  1
66809  93.557  -78.998  53.298  1
66810  93.562  -79.002  53.300  1
66811  93.577  -79.001  53.299  1
66812  93.596  -78.996  53.295  1
66813  93.615  -78.991  53.289  1
66814  93.633  -78.986  53.282  1
66815  93.647  -78.984  53.273  1
66816  93.661  -78.981  53.263  1
66817  93.675  -78.979  53.253  1
66818  93.689  -78.977  53.245  1
66819  93.703  -78.974  53.234  1
66820  93.717  -78.972  53.222  1
66821  93.734  -78.970  53.212  1
66822  93.750  -78.968  53.202  1
66823  93.759  -78.967  53.191  1
66824  93.766  -78.967  53.179  1
66825  93.773  -78.967  53.166  1
66826  93.780  -78.967  53.153  1
66827  93.786  -78.967  53.139  1
66828  93.794  -78.964  53.124  1
66829  93.802  -78.961  53.111  1
66830  93.811  -78.958  53.100  1
66831  93.819  -78.954  53.090  1
66832  93.827  -78.951  53.080  1
66833  93.836  -78.948  53.069  1
66834  93.844  -78.945  53.057  1
66835  93.852  -78.942  53.045  1
66836  93.862  -78.933  53.032  1
66837  93.865  -78.933  53.018  1
66838  93.866  -78.936  53.004  1
66839  93.868  -78.937  52.989  1
66840  93.869  -78.939  52.974  1
66841  93.871  -78.941  52.959  1
66842  93.872  -78.943  52.942  1
66843  93.873  -78.946  52.923  1
66844  93.875  -78.949  52.904  1
66845  93.877  -78.953  52.884  1
66846  93.876  -78.950  52.861  1
66847  93.874  -78.947  52.838  1
66848  93.872  -78.944  52.815  1
66849  93.869  -78.940  52.791  1
66850  93.880  -78.943  52.765  1
66851  93.897  -78.949  52.740  1
66852  93.914  -78.955  52.715  1
66853  93.932  -78.960  52.690  1
66854  93.949  -78.965  52.665  1
66855  93.967  -78.970  52.640  1
66856  93.985  -78.975  52.614  1
66857  94.003  -78.981  52.588  1
66858  94.013  -78.980  52.561  1
66859  94.015  -78.974  52.534  1
66860  94.017  -78.968  52.506  1
66861  94.022  -78.960  52.479  1
66862  94.031  -78.949  52.454  1
66863  94.040  -78.939  52.428  1
66864  94.049  -78.928  52.402  1
66865  94.058  -78.918  52.376  1
66866  94.067  -78.907  52.353  1
66867  94.076  -78.896  52.329  1
66868  94.083  -78.892  52.306  1
66869  94.091  -78.886  52.283  1
66870  94.098  -78.882  52.257  1
66871  94.105  -78.877  52.232  1
66872  94.113  -78.872  52.209  1
66873  94.125  -78.866  52.185  1
66874  94.142  -78.856  52.161  1
66875  94.158  -78.846  52.137  1
66876  94.175  -78.836  52.113  1
66877  94.191  -78.826  52.087  1
66878  94.207  -78.816  52.062  1
66879  94.224  -78.806  52.039  1
66880  94.241  -78.796  52.015  1
66881  94.257  -78.786  51.990  1
66882  94.273  -78.777  51.963  1
66883  94.287  -78.774  51.933  1
66884  94.302  -78.776  51.899  1
66885  94.318  -78.778  51.865  1
66886  94.334  -78.779  51.829  1
66887  94.349  -78.780  51.796  1
66888  94.365  -78.781  51.764  1
66889  94.381  -78.782  51.733  1
66890  94.397  -78.774  51.700  1
66891  94.413  -78.765  51.664  1
66892  94.430  -78.770  51.626  1
66893  94.448  -78.774  51.589  1
66894  94.466  -78.778  51.553  1
66895  94.483  -78.783  51.518  1
66896  94.500  -78.787  51.485  1
66897  94.518  -78.791  51.454  1
66898  94.535  -78.796  51.422  1
66899  94.553  -78.800  51.390  1
66900  94.570  -78.805  51.359  1
66901  94.588  -78.808  51.327  1
66902  94.608  -78.814  51.295  1
66903  94.626  -78.816  51.260  1
66904  94.640  -78.818  51.223  1
66905  94.655  -78.819  51.186  1
66906  94.671  -78.820  51.151  1
66907  94.685  -78.821  51.119  1
66908  94.700  -78.822  51.088  1
66909  94.698  -78.826  51.054  1
66910  94.697  -78.823  51.018  1
66911  94.701  -78.823  50.983  1
66912  94.705  -78.822  50.944  1
66913  94.709  -78.821  50.904  1
66914  94.713  -78.821  50.861  1
66915  94.717  -78.820  50.817  1
66916  94.721  -78.819  50.773  1
66917  94.725  -78.819  50.729  1
66918  94.729  -78.818  50.687  1
66919  94.733  -78.818  50.643  1
66920  94.737  -78.817  50.599  1
66921  94.760  -78.819  50.558  1
66922  94.783  -78.822  50.518  1
66923  94.806  -78.825  50.481  1
66924  94.833  -78.822  50.447  1
66925  94.864  -78.814  50.413  1
66926  94.887  -78.809  50.379  1
66927  94.892  -78.818  50.344  1
66928  94.890  -78.832  50.305  1
66929  94.882  -78.831  50.264  1
66930  94.874  -78.831  50.222  1
66931  94.866  -78.830  50.182  1
66932  94.858  -78.830  50.139  1
66933  94.850  -78.830  50.097  1
66934  94.842  -78.829  50.058  1
66935  94.834  -78.828  50.020  1
66936  94.826  -78.828  49.983  1
66937  94.819  -78.827  49.944  1
66938  94.834  -78.830  49.902  1
66939  94.851  -78.833  49.863  1
66940  94.863  -78.848  49.822  1
66941  94.872  -78.876  49.779  1
66942  94.879  -78.904  49.741  1
66943  94.887  -78.932  49.703  1
66944  94.895  -78.961  49.666  1
66945  94.903  -78.989  49.631  1
66946  94.942  -78.993  49.596  1
66947  94.973  -78.999  49.561  1
66948  94.990  -79.009  49.528  1
66949  95.006  -79.018  49.498  1
66950  95.023  -79.028  49.466  1
66951  95.039  -79.037  49.434  1
66952  95.055  -79.046  49.398  1
66953  95.071  -79.056  49.360  1
66954  95.089  -79.065  49.321  1
66955  95.119  -79.071  49.281  1
66956  95.143  -79.074  49.240  1
66957  95.168  -79.076  49.198  1
66958  95.192  -79.078  49.155  1
66959  95.217  -79.081  49.112  1
66960  95.242  -79.084  49.070  1
66961  95.268  -79.088  49.027  1
66962  95.293  -79.093  48.985  1
66963  95.319  -79.097  48.942  1
66964  95.344  -79.101  48.898  1
66965  95.360  -79.106  48.854  1
66966  95.362  -79.113  48.811  1
66967  95.365  -79.125  48.768  1
66968  95.368  -79.141  48.724  1
66969  95.379  -79.157  48.679  1
66970  95.391  -79.172  48.633  1
66971  95.404  -79.188  48.589  1
66972  95.417  -79.204  48.545  1
66973  95.430  -79.219  48.501  1
66974  95.443  -79.235  48.457  1
66975  95.456  -79.251  48.413  1
66976  95.469  -79.266  48.372  1
66977  95.503  -79.273  48.329  1
66978  95.531  -79.265  48.287  1
66979  95.553  -79.252  48.245  1
66980  95.576  -79.238  48.203  1
66981  95.598  -79.225  48.162  1
66982  95.621  -79.212  48.120  1
66983  95.643  -79.199  48.079  1
66984  95.666  -79.186  48.038  1
66985  95.678  -79.179  47.998  1
66986  95.688  -79.174  47.957  1
66987  95.698  -79.169  47.918  1
66988  95.708  -79.162  47.879  1
66989  95.729  -79.164  47.840  1
66990  95.763  -79.173  47.800  1
66991  95.797  -79.183  47.761  1
66992  95.830  -79.192  47.722  1
66993  95.864  -79.201  47.682  1
66994  95.898  -79.210  47.641  1
66995  95.903  -79.211  47.602  1
66996  95.899  -79.191  47.563  1
66997  95.894  -79.182  47.525  1
66998  95.890  -79.173  47.487  1
66999  95.886  -79.164  47.451  1
67000  95.891  -79.147  47.414  1
67001  95.878  -79.110  47.378  1
67002  95.864  -79.074  47.341  1
67003  95.884  -79.074  47.303  1
67004  95.935  -79.108  47.265  1
67005  95.986  -79.141  47.227  1
67006  96.037  -79.175  47.190  1
67007  96.088  -79.209  47.153  1
67008  96.138  -79.243  47.117  1
67009  96.182  -79.247  47.080  1
67010  96.209  -79.194  47.044  1
67011  96.238  -79.141  47.010  1
67012  96.266  -79.090  46.977  1
67013  96.295  -79.039  46.945  1
67014  96.326  -79.068  46.912  1
67015  96.357  -79.128  46.880  1
67016  96.388  -79.187  46.849  1
67017  96.420  -79.246  46.818  1
67018  96.450  -79.288  46.788  1
67019  96.478  -79.304  46.758  1
67020  96.506  -79.322  46.729  1
67021  96.533  -79.338  46.698  1
67022  96.549  -79.343  46.667  1
67023  96.558  -79.341  46.635  1
67024  96.567  -79.338  46.605  1
67025  96.576  -79.337  46.576  1
67026  96.585  -79.335  46.547  1
67027  96.594  -79.332  46.517  1
67028  96.609  -79.332  46.489  1
67029  96.631  -79.335  46.461  1
67030  96.655  -79.338  46.432  1
67031  96.677  -79.340  46.404  1
67032  96.700  -79.343  46.378  1
67033  96.723  -79.345  46.352  1
67034  96.746  -79.347  46.327  1
67035  96.768  -79.350  46.301  1
67036  96.790  -79.344  46.274  1
67037  96.808  -79.322  46.248  1
67038  96.827  -79.301  46.224  1
67039  96.846  -79.280  46.201  1
67040  96.864  -79.259  46.179  1
67041  96.883  -79.238  46.156  1
67042  96.901  -79.217  46.135  1
67043  96.920  -79.196  46.114  1
67044  96.955  -79.203  46.092  1
67045  96.992  -79.212  46.071  1
67046  97.029  -79.223  46.050  1
67047  97.064  -79.265  46.029  1
67048  97.082  -79.266  46.010  1
67049  97.097  -79.266  45.988  1
67050  97.112  -79.267  45.965  1
67051  97.126  -79.267  45.943  1
67052  97.141  -79.267  45.921  1
67053  97.156  -79.267  45.900  1
67054  97.171  -79.267  45.880  1
67055  97.183  -79.269  45.861  1
67056  97.152  -79.306  45.840  1
67057  97.165  -79.294  45.819  1
67058  97.166  -79.287  45.798  1
67059  97.168  -79.280  45.777  1
67060  97.190  -79.272  45.758  1
67061  97.224  -79.261  45.740  1
67062  97.245  -79.261  45.722  1
67063  97.249  -79.274  45.703  1
67064  97.253  -79.287  45.685  1
67065  97.257  -79.300  45.666  1
67066  97.261  -79.313  45.647  1
67067  97.265  -79.325  45.629  1
67068  97.270  -79.338  45.613  1
67069  97.274  -79.350  45.597  1
67070  97.278  -79.363  45.580  1
67071  97.282  -79.376  45.562  1
67072  97.286  -79.388  45.544  1
67073  97.290  -79.401  45.527  1
67074  97.293  -79.414  45.510  1
67075  97.286  -79.422  45.494  1
67076  97.291  -79.410  45.478  1
67077  97.297  -79.397  45.462  1
67078  97.303  -79.385  45.446  1
67079  97.308  -79.372  45.429  1
67080  97.314  -79.359  45.413  1
67081  97.317  -79.353  45.397  1
67082  97.318  -79.364  45.381  1
67083  97.325  -79.372  45.366  1
67084  97.343  -79.387  45.351  1
67085  97.362  -79.402  45.336  1
67086  97.381  -79.417  45.320  1
67087  97.400  -79.432  45.305  1
67088  97.420  -79.447  45.290  1
67089  97.439  -79.463  45.276  1
67090  97.458  -79.479  45.262  1
67091  97.477  -79.494  45.248  1
67092  97.497  -79.509  45.233  1
67093  97.516  -79.524  45.219  1
67094  97.535  -79.539  45.206  1
67095  97.554  -79.554  45.192  1
67096  97.573  -79.570  45.178  1
67097  97.592  -79.585  45.165  1
67098  97.611  -79.601  45.152  1
67099  97.631  -79.616  45.139  1
67100  97.650  -79.631  45.125  1
67101  97.669  -79.646  45.112  1
67102  97.688  -79.662  45.100  1
67103  97.707  -79.677  45.087  1
67104  97.727  -79.692  45.074  1
67105  97.746  -79.708  45.061  1
67106  97.765  -79.723  45.049  1
67107  97.784  -79.738  45.036  1
67108  97.803  -79.754  45.024  1
67109  97.822  -79.769  45.011  1
67110  97.842  -79.784  44.999  1
67111  97.861  -79.799  44.986  1
67112  97.880  -79.814  44.973  1
67113  97.899  -79.830  44.959  1
67114  97.918  -79.845  44.945  1
67115  97.937  -79.861  44.932  1
67116  97.956  -79.876  44.919  1
67117  97.975  -79.891  44.907  1
67118  97.995  -79.906  44.894  1
67119  98.014  -79.921  44.882  1
67120  98.033  -79.936  44.870  1
67121  98.053  -79.952  44.859  1
67122  98.072  -79.968  44.848  1
67123  98.091  -79.983  44.837  1
67124  98.110  -79.998  44.827  1
67125  98.129  -80.013  44.816  1
67126  98.148  -80.028  44.806  1
67127  98.167  -80.044  44.797  1
67128  98.186  -80.059  44.787  1
67129  98.206  -80.074  44.778  1
67130  98.225  -80.090  44.769  1
67131  98.244  -80.105  44.761  1
67132  98.263  -80.120  44.752  1
67133  98.283  -80.135  44.743  1
67134  98.302  -80.151  44.735  1
67135  98.321  -80.166  44.727  1
67136  98.340  -80.181  44.719  1
67137  98.359  -80.196  44.711  1
67138  98.378  -80.212  44.703  1
67139  98.397  -80.227  44.696  1
67140  98.417  -80.243  44.690  1
67141  98.436  -80.258  44.683  1
67142  98.455  -80.273  44.676  1
67143  98.474  -80.288  44.669  1
67144  98.493  -80.303  44.662  1
67145  98.512  -80.319  44.656  1
67146  98.535  -80.325  44.650  1
67147  98.560  -80.328  44.644  1
67148  98.585  -80.330  44.636  1
67149  98.610  -80.333  44.629  1
67150  98.635  -80.335  44.621  1
67151  98.659  -80.338  44.612  1
67152  98.684  -80.341  44.605  1
67153  98.709  -80.343  44.598  1
67154  98.734  -80.346  44.591  1
67155  98.759  -80.348  44.583  1
67156  98.783  -80.356  44.576  1
67157  98.806  -80.366  44.568  1
67158  98.830  -80.377  44.560  1
67159  98.853  -80.388  44.554  1
67160  98.876  -80.398  44.549  1
67161  98.900  -80.409  44.543  1
67162  98.923  -80.419  44.537  1
67163  98.946  -80.430  44.532  1
67164  98.970  -80.441  44.526  1
67165  98.993  -80.451  44.520  1
67166  99.016  -80.461  44.515  1
67167  99.039  -80.472  44.510  1
67168  99.063  -80.482  44.506  1
67496  93.434  -79.062  53.425  1
67497  93.444  -79.059  53.412  1
67498  93.453  -79.057  53.399  1
67499  93.463  -79.054  53.386  1
67500  93.474  -79.048  53.374  1
67501  93.485  -79.037  53.363  1
67502  93.496  -79.028  53.352  1
67503  93.504  -79.021  53.342  1
67504  93.512  -79.014  53.333  1
67505  93.521  -79.007  53.325  1
67506  93.529  -79.000  53.319  1
67507  93.538  -78.993  53.314  1
67508  93.546  -78.987  53.310  1
67509  93.554  -78.979  53.309  1
67510  93.562  -78.976  53.310  1
67511  93.567  -78.981  53.313  1
67512  93.574  -78.985  53.313  1
67513  93.593  -78.980  53.309  1
67514  93.612  -78.974  53.304  1
67515  93.629  -78.971  53.299  1
67516  93.643  -78.968  53.291  1
67517  93.656  -78.966  53.281  1
67518  93.671  -78.964  53.272  1
67519  93.685  -78.962  53.264  1
67520  93.701  -78.959  53.254  1
67521  93.718  -78.957  53.244  1
67522  93.735  -78.955  53.233  1
67523  93.745  -78.953  53.223  1
67524  93.755  -78.952  53.212  1
67525  93.763  -78.952  53.200  1
67526  93.769  -78.952  53.188  1
67527  93.776  -78.952  53.176  1
67528  93.782  -78.952  53.162  1
67529  93.789  -78.952  53.147  1
67530  93.796  -78.952  53.135  1
67531  93.803  -78.949  53.124  1
67532  93.812  -78.946  53.114  1
67533  93.820  -78.943  53.104  1
67534  93.828  -78.940  53.093  1
67535  93.837  -78.937  53.081  1
67536  93.846  -78.929  53.068  1
67537  93.857  -78.918  53.055  1
67538  93.859  -78.920  53.041  1
67539  93.860  -78.922  53.028  1
67540  93.862  -78.924  53.014  1
67541  93.863  -78.926  52.999  1
67542  93.865  -78.927  52.983  1
67543  93.867  -78.929  52.966  1
67544  93.868  -78.931  52.947  1
67545  93.870  -78.933  52.927  1
67546  93.866  -78.929  52.906  1
67547  93.863  -78.925  52.881  1
67548  93.860  -78.922  52.857  1
67549  93.857  -78.919  52.833  1
67550  93.855  -78.916  52.807  1
67551  93.872  -78.922  52.780  1
67552  93.889  -78.927  52.754  1
67553  93.906  -78.933  52.728  1
67554  93.923  -78.938  52.701  1
67555  93.940  -78.944  52.675  1
67556  93.957  -78.949  52.650  1
67557  93.974  -78.955  52.623  1
67558  93.991  -78.961  52.596  1
67559  94.008  -78.965  52.570  1
67560  94.014  -78.962  52.544  1
67561  94.024  -78.952  52.517  1
67562  94.033  -78.941  52.491  1
67563  94.042  -78.930  52.468  1
67564  94.051  -78.920  52.443  1
67565  94.060  -78.909  52.418  1
67566  94.069  -78.899  52.393  1
67567  94.078  -78.888  52.370  1
67568  94.087  -78.878  52.346  1
67569  94.096  -78.871  52.323  1
67570  94.103  -78.865  52.299  1
67571  94.110  -78.861  52.273  1
67572  94.117  -78.855  52.248  1
67573  94.125  -78.851  52.223  1
67574  94.139  -78.848  52.199  1
67575  94.155  -78.838  52.175  1
67576  94.172  -78.828  52.150  1
67577  94.189  -78.818  52.126  1
67578  94.205  -78.808  52.100  1
67579  94.221  -78.798  52.074  1
67580  94.238  -78.788  52.049  1
67581  94.254  -78.778  52.025  1
67582  94.271  -78.768  52.000  1
67583  94.282  -78.763  51.972  1
67584  94.292  -78.761  51.943  1
67585  94.308  -78.763  51.909  1
67586  94.323  -78.765  51.875  1
67587  94.339  -78.767  51.840  1
67588  94.354  -78.770  51.807  1
67589  94.369  -78.771  51.777  1
67590  94.385  -78.774  51.747  1
67591  94.400  -78.773  51.715  1
67592  94.416  -78.757  51.679  1
67593  94.433  -78.761  51.641  1
67594  94.451  -78.765  51.603  1
67595  94.468  -78.770  51.567  1
67596  94.486  -78.774  51.533  1
67597  94.503  -78.778  51.499  1
67598  94.521  -78.783  51.468  1
67599  94.538  -78.787  51.436  1
67600  94.555  -78.791  51.403  1
67601  94.573  -78.796  51.372  1
67602  94.593  -78.801  51.341  1
67603  94.620  -78.808  51.309  1
67604  94.646  -78.814  51.275  1
67605  94.661  -78.815  51.238  1
67606  94.676  -78.817  51.200  1
67607  94.691  -78.818  51.164  1
67608  94.706  -78.819  51.132  1
67609  94.718  -78.821  51.102  1
67610  94.716  -78.830  51.070  1
67611  94.712  -78.837  51.035  1
67612  94.690  -78.827  50.999  1
67613  94.685  -78.823  50.961  1
67614  94.689  -78.822  50.920  1
67615  94.693  -78.821  50.876  1
67616  94.697  -78.821  50.831  1
67617  94.701  -78.821  50.787  1
67618  94.705  -78.820  50.744  1
67619  94.709  -78.819  50.702  1
67620  94.713  -78.818  50.658  1
67621  94.729  -78.820  50.614  1
67622  94.753  -78.823  50.574  1
67623  94.777  -78.824  50.534  1
67624  94.808  -78.816  50.495  1
67625  94.839  -78.808  50.460  1
67626  94.866  -78.802  50.426  1
67627  94.885  -78.798  50.393  1
67628  94.891  -78.807  50.359  1
67629  94.890  -78.822  50.321  1
67630  94.887  -78.834  50.281  1
67631  94.879  -78.833  50.239  1
67632  94.871  -78.833  50.198  1
67633  94.863  -78.833  50.155  1
67634  94.855  -78.832  50.113  1
67635  94.847  -78.832  50.073  1
67636  94.839  -78.831  50.033  1
67637  94.831  -78.830  49.995  1
67638  94.823  -78.830  49.956  1
67639  94.835  -78.833  49.916  1
67640  94.852  -78.836  49.875  1
67641  94.868  -78.839  49.834  1
67642  94.882  -78.851  49.792  1
67643  94.890  -78.879  49.755  1
67644  94.897  -78.908  49.717  1
67645  94.905  -78.936  49.680  1
67646  94.913  -78.964  49.644  1
67647  94.944  -78.974  49.609  1
67648  94.976  -78.981  49.574  1
67649  94.992  -78.990  49.541  1
67650  95.008  -78.999  49.510  1
67651  95.025  -79.009  49.477  1
67652  95.041  -79.018  49.444  1
67653  95.057  -79.028  49.407  1
67654  95.076  -79.036  49.369  1
67655  95.106  -79.043  49.329  1
67656  95.135  -79.049  49.289  1
67657  95.162  -79.055  49.248  1
67658  95.187  -79.057  49.206  1
67659  95.211  -79.059  49.164  1
67660  95.236  -79.062  49.122  1
67661  95.260  -79.064  49.080  1
67662  95.285  -79.066  49.038  1
67663  95.309  -79.068  48.996  1
67664  95.334  -79.071  48.952  1
67665  95.358  -79.073  48.909  1
67666  95.375  -79.080  48.865  1
67667  95.378  -79.096  48.822  1
67668  95.380  -79.112  48.778  1
67669  95.382  -79.128  48.733  1
67670  95.385  -79.144  48.688  1
67671  95.392  -79.160  48.643  1
67672  95.405  -79.175  48.598  1
67673  95.418  -79.191  48.554  1
67674  95.431  -79.207  48.510  1
67675  95.444  -79.222  48.467  1
67676  95.457  -79.238  48.424  1
67677  95.470  -79.254  48.381  1
67678  95.500  -79.262  48.338  1
67679  95.528  -79.253  48.296  1
67680  95.550  -79.241  48.254  1
67681  95.572  -79.228  48.211  1
67682  95.595  -79.214  48.169  1
67683  95.618  -79.201  48.127  1
67684  95.640  -79.187  48.086  1
67685  95.663  -79.175  48.045  1
67686  95.680  -79.165  48.004  1
67687  95.691  -79.159  47.964  1
67688  95.701  -79.153  47.925  1
67689  95.711  -79.148  47.886  1
67690  95.736  -79.152  47.847  1
67691  95.769  -79.161  47.807  1
67692  95.803  -79.170  47.767  1
67693  95.837  -79.180  47.727  1
67694  95.871  -79.189  47.687  1
67695  95.899  -79.197  47.647  1
67696  95.912  -79.202  47.608  1
67697  95.908  -79.193  47.567  1
67698  95.903  -79.184  47.529  1
67699  95.899  -79.175  47.491  1
67700  95.895  -79.166  47.453  1
67701  95.893  -79.157  47.415  1
67702  95.905  -79.128  47.377  1
67703  95.892  -79.091  47.339  1
67704  95.901  -79.079  47.301  1
67705  95.952  -79.113  47.263  1
67706  96.003  -79.147  47.225  1
67707  96.054  -79.181  47.188  1
67708  96.105  -79.214  47.151  1
67709  96.151  -79.231  47.114  1
67710  96.179  -79.178  47.079  1
67711  96.207  -79.125  47.044  1
67712  96.235  -79.071  47.010  1
67713  96.263  -79.021  46.977  1
67714  96.297  -79.008  46.944  1
67715  96.327  -79.037  46.911  1
67716  96.356  -79.083  46.880  1
67717  96.384  -79.128  46.849  1
67718  96.412  -79.175  46.818  1
67719  96.441  -79.220  46.788  1
67720  96.469  -79.266  46.758  1
67721  96.496  -79.288  46.728  1
67722  96.523  -79.303  46.698  1
67723  96.546  -79.314  46.667  1
67724  96.555  -79.312  46.635  1
67725  96.564  -79.310  46.604  1
67726  96.573  -79.308  46.574  1
67727  96.582  -79.306  46.545  1
67728  96.594  -79.305  46.516  1
67729  96.616  -79.307  46.487  1
67730  96.640  -79.310  46.458  1
67731  96.662  -79.313  46.429  1
67732  96.685  -79.315  46.401  1
67733  96.708  -79.318  46.374  1
67734  96.731  -79.320  46.348  1
67735  96.753  -79.322  46.322  1
67736  96.776  -79.325  46.296  1
67737  96.798  -79.320  46.271  1
67738  96.816  -79.299  46.245  1
67739  96.835  -79.278  46.219  1
67740  96.854  -79.257  46.196  1
67741  96.872  -79.236  46.174  1
67742  96.891  -79.215  46.152  1
67743  96.909  -79.194  46.130  1
67744  96.939  -79.190  46.108  1
67745  96.976  -79.201  46.087  1
67746  97.013  -79.211  46.066  1
67747  97.050  -79.222  46.045  1
67748  97.076  -79.228  46.024  1
67749  97.074  -79.253  46.004  1
67750  97.088  -79.253  45.982  1
67751  97.103  -79.253  45.960  1
67752  97.117  -79.253  45.938  1
67753  97.133  -79.254  45.917  1
67754  97.147  -79.254  45.897  1
67755  97.162  -79.254  45.878  1
67756  97.175  -79.256  45.858  1
67757  97.151  -79.285  45.838  1
67758  97.165  -79.273  45.818  1
67759  97.167  -79.266  45.797  1
67760  97.168  -79.259  45.777  1
67761  97.170  -79.252  45.758  1
67762  97.193  -79.244  45.740  1
67763  97.228  -79.233  45.722  1
67764  97.235  -79.244  45.704  1
67765  97.239  -79.256  45.686  1
67766  97.243  -79.269  45.667  1
67767  97.247  -79.282  45.648  1
67768  97.251  -79.294  45.631  1
67769  97.255  -79.307  45.615  1
67770  97.259  -79.320  45.598  1
67771  97.263  -79.333  45.581  1
67772  97.267  -79.346  45.564  1
67773  97.271  -79.358  45.546  1
67774  97.275  -79.371  45.529  1
67775  97.279  -79.384  45.512  1
67776  97.283  -79.397  45.496  1
67777  97.287  -79.410  45.480  1
67778  97.290  -79.418  45.464  1
67779  97.296  -79.406  45.449  1
67780  97.302  -79.392  45.433  1
67781  97.309  -79.379  45.417  1
67782  97.317  -79.364  45.401  1
67783  97.325  -79.350  45.386  1
67784  97.329  -79.341  45.371  1
67785  97.349  -79.355  45.356  1
67786  97.368  -79.370  45.341  1
67787  97.387  -79.386  45.325  1
67788  97.406  -79.401  45.310  1
67789  97.425  -79.416  45.295  1
67790  97.444  -79.432  45.281  1
67791  97.463  -79.447  45.267  1
67792  97.483  -79.463  45.253  1
67793  97.502  -79.478  45.239  1
67794  97.521  -79.493  45.225  1
67795  97.540  -79.508  45.212  1
67796  97.560  -79.523  45.198  1
67797  97.579  -79.538  45.185  1
67798  97.598  -79.554  45.172  1
67799  97.617  -79.570  45.159  1
67800  97.636  -79.585  45.145  1
67801  97.655  -79.600  45.132  1
67802  97.674  -79.615  45.119  1
67803  97.693  -79.630  45.107  1
67804  97.713  -79.646  45.095  1
67805  97.732  -79.661  45.082  1
67806  97.751  -79.676  45.070  1
67807  97.770  -79.692  45.058  1
67808  97.789  -79.707  45.045  1
67809  97.809  -79.722  45.033  1
67810  97.828  -79.737  45.020  1
67811  97.847  -79.753  45.008  1
67812  97.866  -79.768  44.995  1
67813  97.885  -79.783  44.982  1
67814  97.904  -79.798  44.968  1
67815  97.924  -79.814  44.955  1
67816  97.943  -79.829  44.942  1
67817  97.962  -79.845  44.930  1
67818  97.981  -79.860  44.917  1
67819  98.000  -79.875  44.904  1
67820  98.019  -79.890  44.891  1
67821  98.038  -79.905  44.880  1
67822  98.058  -79.921  44.869  1
67823  98.077  -79.936  44.858  1
67824  98.096  -79.952  44.846  1
67825  98.115  -79.967  44.837  1
67826  98.135  -79.982  44.827  1
67827  98.154  -79.997  44.817  1
67828  98.173  -80.012  44.808  1
67829  98.192  -80.028  44.798  1
67830  98.211  -80.043  44.788  1
67831  98.230  -80.059  44.779  1
67832  98.249  -80.074  44.771  1
67833  98.269  -80.089  44.762  1
67834  98.288  -80.104  44.754  1
67835  98.307  -80.119  44.745  1
67836  98.326  -80.135  44.738  1
67837  98.345  -80.150  44.730  1
67838  98.365  -80.165  44.723  1
67839  98.384  -80.181  44.715  1
67840  98.403  -80.196  44.708  1
67841  98.422  -80.211  44.701  1
67842  98.441  -80.227  44.695  1
67843  98.460  -80.242  44.688  1
67844  98.480  -80.257  44.681  1
67845  98.499  -80.272  44.674  1
67846  98.518  -80.287  44.668  1
67847  98.541  -80.294  44.662  1
67848  98.566  -80.297  44.656  1
67849  98.590  -80.299  44.648  1
67850  98.616  -80.302  44.641  1
67851  98.640  -80.304  44.634  1
67852  98.665  -80.306  44.626  1
67853  98.690  -80.309  44.619  1
67854  98.714  -80.312  44.613  1
67855  98.739  -80.314  44.606  1
67856  98.762  -80.319  44.597  1
67857  98.787  -80.328  44.589  1
67858  98.810  -80.339  44.581  1
67859  98.834  -80.350  44.572  1
67860  98.857  -80.360  44.564  1
67861  98.880  -80.371  44.558  1
67862  98.904  -80.381  44.554  1
67863  98.927  -80.392  44.548  1
67864  98.950  -80.403  44.542  1
67865  98.974  -80.413  44.535  1
67866  98.997  -80.424  44.530  1
67867  99.020  -80.435  44.525  1
67868  99.043  -80.444  44.519  1
67869  99.067  -80.455  44.514  1
67870  99.090  -80.466  44.510  1
67871  99.113  -80.476  44.506  1
68198  93.444  -79.048  53.434  1
68199  93.453  -79.046  53.421  1
68200  93.464  -79.043  53.408  1
68201  93.473  -79.041  53.396  1
68202  93.484  -79.034  53.385  1
68203  93.495  -79.023  53.375  1
68204  93.505  -79.015  53.364  1
68205  93.513  -79.008  53.355  1
68206  93.522  -79.001  53.346  1
68207  93.530  -78.993  53.340  1
68208  93.539  -78.987  53.333  1
68209  93.547  -78.980  53.328  1
68210  93.555  -78.973  53.324  1
68211  93.564  -78.966  53.324  1
68212  93.572  -78.959  53.325  1
68213  93.577  -78.964  53.325  1
68214  93.590  -78.963  53.323  1
68215  93.609  -78.959  53.319  1
68216  93.624  -78.955  53.314  1
68217  93.638  -78.953  53.306  1
68218  93.652  -78.951  53.297  1
68219  93.669  -78.949  53.288  1
68220  93.685  -78.946  53.280  1
68221  93.702  -78.943  53.272  1
68222  93.719  -78.941  53.262  1
68223  93.731  -78.940  53.251  1
68224  93.741  -78.939  53.242  1
68225  93.751  -78.937  53.231  1
68226  93.759  -78.937  53.219  1
68227  93.765  -78.937  53.207  1
68228  93.772  -78.937  53.195  1
68229  93.779  -78.937  53.182  1
68230  93.785  -78.937  53.168  1
68231  93.792  -78.937  53.157  1
68232  93.798  -78.937  53.146  1
68233  93.805  -78.937  53.136  1
68234  93.813  -78.935  53.126  1
68235  93.821  -78.932  53.115  1
68236  93.831  -78.924  53.102  1
68237  93.842  -78.913  53.089  1
68238  93.851  -78.905  53.075  1
68239  93.853  -78.906  53.062  1
68240  93.854  -78.908  53.048  1
68241  93.856  -78.910  53.034  1
68242  93.857  -78.912  53.020  1
68243  93.859  -78.914  53.005  1
68244  93.861  -78.916  52.987  1
68245  93.861  -78.916  52.967  1
68246  93.857  -78.911  52.946  1
68247  93.852  -78.905  52.922  1
68248  93.848  -78.901  52.897  1
68249  93.845  -78.897  52.872  1
68250  93.842  -78.894  52.848  1
68251  93.847  -78.894  52.820  1
68252  93.864  -78.900  52.793  1
68253  93.881  -78.905  52.767  1
68254  93.898  -78.911  52.741  1
68255  93.915  -78.917  52.714  1
68256  93.932  -78.922  52.687  1
68257  93.948  -78.927  52.661  1
68258  93.968  -78.931  52.632  1
68259  93.988  -78.933  52.605  1
68260  94.008  -78.936  52.580  1
68261  94.024  -78.936  52.554  1
68262  94.034  -78.932  52.529  1
68263  94.044  -78.923  52.505  1
68264  94.053  -78.912  52.482  1
68265  94.062  -78.902  52.458  1
68266  94.071  -78.891  52.434  1
68267  94.080  -78.880  52.409  1
68268  94.089  -78.870  52.386  1
68269  94.099  -78.859  52.363  1
68270  94.108  -78.849  52.339  1
68271  94.115  -78.844  52.314  1
68272  94.122  -78.839  52.289  1
68273  94.129  -78.834  52.262  1
68274  94.140  -78.830  52.236  1
68275  94.154  -78.828  52.211  1
68276  94.170  -78.820  52.187  1
68277  94.186  -78.810  52.162  1
68278  94.202  -78.800  52.137  1
68279  94.219  -78.790  52.110  1
68280  94.236  -78.780  52.084  1
68281  94.252  -78.770  52.057  1
68282  94.268  -78.760  52.032  1
68283  94.281  -78.754  52.005  1
68284  94.290  -78.752  51.977  1
68285  94.298  -78.749  51.947  1
68286  94.313  -78.750  51.915  1
68287  94.328  -78.752  51.882  1
68288  94.343  -78.755  51.847  1
68289  94.359  -78.757  51.815  1
68290  94.374  -78.758  51.784  1
68291  94.390  -78.761  51.754  1
68292  94.403  -78.766  51.722  1
68293  94.418  -78.748  51.688  1
68294  94.436  -78.752  51.652  1
68295  94.454  -78.756  51.615  1
68296  94.471  -78.761  51.581  1
68297  94.488  -78.765  51.547  1
68298  94.506  -78.770  51.514  1
68299  94.523  -78.774  51.483  1
68300  94.541  -78.778  51.450  1
68301  94.558  -78.783  51.418  1
68302  94.577  -78.787  51.386  1
68303  94.604  -78.794  51.354  1
68304  94.631  -78.801  51.322  1
68305  94.659  -78.808  51.288  1
68306  94.682  -78.813  51.251  1
68307  94.696  -78.814  51.214  1
68308  94.711  -78.815  51.178  1
68309  94.726  -78.817  51.145  1
68310  94.733  -78.822  51.114  1
68311  94.730  -78.831  51.082  1
68312  94.728  -78.840  51.049  1
68313  94.725  -78.849  51.014  1
68314  94.704  -78.839  50.975  1
68315  94.683  -78.828  50.934  1
68316  94.673  -78.823  50.890  1
68317  94.677  -78.822  50.847  1
68318  94.681  -78.821  50.804  1
68319  94.685  -78.821  50.761  1
68320  94.689  -78.820  50.718  1
68321  94.699  -78.821  50.675  1
68322  94.722  -78.823  50.632  1
68323  94.751  -78.818  50.590  1
68324  94.782  -78.811  50.549  1
68325  94.813  -78.802  50.509  1
68326  94.844  -78.795  50.471  1
68327  94.864  -78.790  50.438  1
68328  94.883  -78.787  50.405  1
68329  94.889  -78.795  50.372  1
68330  94.888  -78.811  50.335  1
68331  94.887  -78.826  50.296  1
68332  94.884  -78.836  50.255  1
68333  94.876  -78.836  50.211  1
68334  94.867  -78.835  50.170  1
68335  94.859  -78.835  50.129  1
68336  94.852  -78.834  50.088  1
68337  94.844  -78.833  50.046  1
68338  94.836  -78.833  50.006  1
68339  94.828  -78.833  49.967  1
68340  94.836  -78.834  49.928  1
68341  94.852  -78.837  49.887  1
68342  94.870  -78.840  49.846  1
68343  94.886  -78.843  49.806  1
68344  94.900  -78.855  49.768  1
68345  94.908  -78.883  49.730  1
68346  94.916  -78.911  49.692  1
68347  94.923  -78.939  49.657  1
68348  94.946  -78.955  49.622  1
68349  94.978  -78.962  49.587  1
68350  94.995  -78.971  49.554  1
68351  95.011  -78.981  49.521  1
68352  95.028  -78.990  49.487  1
68353  95.044  -78.999  49.453  1
68354  95.063  -79.008  49.415  1
68355  95.093  -79.015  49.376  1
68356  95.122  -79.021  49.336  1
68357  95.151  -79.028  49.297  1
68358  95.181  -79.035  49.256  1
68359  95.205  -79.037  49.215  1
68360  95.230  -79.040  49.174  1
68361  95.255  -79.042  49.132  1
68362  95.279  -79.044  49.091  1
68363  95.304  -79.046  49.049  1
68364  95.328  -79.049  49.006  1
68365  95.353  -79.051  48.963  1
68366  95.376  -79.054  48.919  1
68367  95.385  -79.059  48.876  1
68368  95.390  -79.078  48.832  1
68369  95.394  -79.099  48.787  1
68370  95.397  -79.115  48.742  1
68371  95.399  -79.131  48.698  1
68372  95.402  -79.147  48.653  1
68373  95.406  -79.163  48.608  1
68374  95.419  -79.178  48.564  1
68375  95.432  -79.194  48.520  1
68376  95.445  -79.210  48.477  1
68377  95.458  -79.225  48.434  1
68378  95.471  -79.241  48.391  1
68379  95.497  -79.251  48.347  1
68380  95.525  -79.242  48.304  1
68381  95.547  -79.229  48.261  1
68382  95.569  -79.216  48.219  1
68383  95.592  -79.203  48.177  1
68384  95.615  -79.190  48.135  1
68385  95.637  -79.177  48.093  1
68386  95.660  -79.163  48.051  1
68387  95.682  -79.150  48.010  1
68388  95.693  -79.144  47.970  1
68389  95.703  -79.139  47.930  1
68390  95.713  -79.133  47.891  1
68391  95.743  -79.140  47.852  1
68392  95.776  -79.149  47.811  1
68393  95.810  -79.158  47.771  1
68394  95.843  -79.168  47.731  1
68395  95.871  -79.174  47.690  1
68396  95.883  -79.175  47.651  1
68397  95.895  -79.175  47.611  1
68398  95.912  -79.189  47.571  1
68399  95.912  -79.186  47.531  1
68400  95.908  -79.178  47.492  1
68401  95.903  -79.169  47.454  1
68402  95.899  -79.159  47.415  1
68403  95.933  -79.144  47.376  1
68404  95.919  -79.108  47.337  1
68405  95.918  -79.084  47.298  1
68406  95.969  -79.118  47.260  1
68407  96.020  -79.152  47.223  1
68408  96.071  -79.186  47.186  1
68409  96.121  -79.216  47.149  1
68410  96.149  -79.162  47.113  1
68411  96.176  -79.109  47.078  1
68412  96.204  -79.056  47.043  1
68413  96.237  -79.032  47.009  1
68414  96.271  -79.019  46.976  1
68415  96.305  -79.006  46.943  1
68416  96.335  -79.037  46.911  1
68417  96.364  -79.082  46.880  1
68418  96.392  -79.128  46.849  1
68419  96.420  -79.174  46.818  1
68420  96.449  -79.219  46.788  1
68421  96.475  -79.256  46.758  1
68422  96.489  -79.257  46.727  1
68423  96.511  -79.265  46.697  1
68424  96.537  -79.280  46.666  1
68425  96.552  -79.284  46.634  1
68426  96.561  -79.281  46.603  1
68427  96.570  -79.279  46.573  1
68428  96.579  -79.278  46.543  1
68429  96.601  -79.280  46.514  1
68430  96.624  -79.282  46.485  1
68431  96.647  -79.285  46.456  1
68432  96.670  -79.288  46.427  1
68433  96.693  -79.290  46.399  1
68434  96.716  -79.292  46.372  1
68435  96.738  -79.295  46.345  1
68436  96.761  -79.297  46.319  1
68437  96.784  -79.300  46.294  1
68438  96.806  -79.297  46.268  1
68439  96.824  -79.275  46.242  1
68440  96.843  -79.254  46.216  1
68441  96.862  -79.234  46.193  1
68442  96.880  -79.212  46.171  1
68443  96.899  -79.191  46.149  1
68444  96.923  -79.179  46.126  1
68445  96.960  -79.190  46.104  1
68446  96.997  -79.200  46.082  1
68447  97.034  -79.210  46.061  1
68448  97.051  -79.213  46.040  1
68449  97.079  -79.218  46.020  1
68450  97.080  -79.219  45.999  1
68451  97.079  -79.240  45.978  1
68452  97.094  -79.241  45.957  1
68453  97.109  -79.241  45.935  1
68454  97.123  -79.241  45.914  1
68455  97.139  -79.241  45.895  1
68456  97.153  -79.241  45.876  1
68457  97.168  -79.241  45.857  1
68458  97.150  -79.265  45.837  1
68459  97.166  -79.252  45.817  1
68460  97.167  -79.245  45.796  1
68461  97.169  -79.238  45.777  1
68462  97.171  -79.231  45.759  1
68463  97.172  -79.225  45.741  1
68464  97.196  -79.216  45.723  1
68465  97.220  -79.213  45.705  1
68466  97.224  -79.226  45.687  1
68467  97.228  -79.239  45.669  1
68468  97.232  -79.252  45.650  1
68469  97.236  -79.264  45.632  1
68470  97.240  -79.277  45.616  1
68471  97.244  -79.290  45.600  1
68472  97.248  -79.303  45.583  1
68473  97.252  -79.316  45.566  1
68474  97.256  -79.328  45.549  1
68475  97.260  -79.341  45.531  1
68476  97.264  -79.353  45.514  1
68477  97.277  -79.370  45.499  1
68478  97.291  -79.387  45.484  1
68479  97.293  -79.405  45.468  1
68480  97.321  -79.393  45.452  1
68481  97.346  -79.379  45.437  1
68482  97.354  -79.364  45.421  1
68483  97.360  -79.352  45.405  1
68484  97.366  -79.339  45.390  1
68485  97.372  -79.327  45.375  1
68486  97.374  -79.325  45.360  1
68487  97.361  -79.356  45.346  1
68488  97.395  -79.351  45.330  1
68489  97.415  -79.366  45.315  1
68490  97.434  -79.382  45.300  1
68491  97.453  -79.397  45.286  1
68492  97.472  -79.413  45.273  1
68493  97.491  -79.428  45.259  1
68494  97.510  -79.444  45.244  1
68495  97.529  -79.459  45.231  1
68496  97.548  -79.474  45.217  1
68497  97.567  -79.490  45.204  1
68498  97.586  -79.505  45.191  1
68499  97.605  -79.520  45.178  1
68500  97.625  -79.536  45.165  1
68501  97.644  -79.551  45.152  1
68502  97.662  -79.567  45.139  1
68503  97.681  -79.582  45.127  1
68504  97.701  -79.598  45.115  1
68505  97.720  -79.613  45.102  1
68506  97.739  -79.628  45.090  1
68507  97.758  -79.644  45.078  1
68508  97.777  -79.659  45.066  1
68509  97.796  -79.674  45.054  1
68510  97.815  -79.690  45.042  1
68511  97.834  -79.705  45.029  1
68512  97.853  -79.720  45.017  1
68513  97.872  -79.736  45.005  1
68514  97.891  -79.751  44.991  1
68515  97.911  -79.767  44.978  1
68516  97.930  -79.783  44.965  1
68517  97.948  -79.798  44.952  1
68518  97.967  -79.813  44.939  1
68519  97.987  -79.828  44.926  1
68520  98.006  -79.844  44.913  1
68521  98.025  -79.859  44.901  1
68522  98.044  -79.874  44.890  1
68523  98.063  -79.889  44.879  1
68524  98.082  -79.905  44.868  1
68525  98.101  -79.921  44.856  1
68526  98.121  -79.936  44.847  1
68527  98.140  -79.951  44.838  1
68528  98.159  -79.966  44.828  1
68529  98.178  -79.981  44.818  1
68530  98.198  -79.996  44.808  1
68531  98.217  -80.012  44.799  1
68532  98.236  -80.027  44.789  1
68533  98.255  -80.043  44.781  1
68534  98.274  -80.058  44.773  1
68535  98.293  -80.073  44.765  1
68536  98.312  -80.088  44.757  1
68537  98.332  -80.103  44.749  1
68538  98.351  -80.119  44.742  1
68539  98.370  -80.134  44.734  1
68540  98.389  -80.149  44.728  1
68541  98.408  -80.165  44.721  1
68542  98.427  -80.180  44.713  1
68543  98.447  -80.195  44.707  1
68544  98.466  -80.211  44.700  1
68545  98.485  -80.226  44.693  1
68546  98.504  -80.241  44.686  1
68547  98.523  -80.256  44.680  1
68548  98.547  -80.262  44.674  1
68549  98.571  -80.265  44.668  1
68550  98.596  -80.268  44.662  1
68551  98.621  -80.270  44.655  1
68552  98.644  -80.274  44.649  1
68553  98.666  -80.278  44.643  1
68554  98.688  -80.282  44.638  1
68555  98.709  -80.287  44.633  1
68556  98.730  -80.291  44.626  1
68557  98.752  -80.297  44.617  1
68558  98.773  -80.307  44.606  1
68559  98.814  -80.312  44.594  1
68560  98.838  -80.322  44.584  1
68561  98.861  -80.333  44.576  1
68562  98.884  -80.344  44.570  1
68563  98.908  -80.354  44.564  1
68564  98.931  -80.365  44.558  1
68565  98.954  -80.375  44.552  1
68566  98.977  -80.386  44.546  1
68567  99.001  -80.397  44.540  1
68568  99.024  -80.407  44.534  1
68569  99.047  -80.417  44.529  1
68570  99.071  -80.428  44.524  1
68571  99.094  -80.438  44.520  1
68572  99.117  -80.449  44.515  1
68573  99.141  -80.460  44.510  1
68574  99.164  -80.470  44.505  1
68575  99.187  -80.481  44.501  1
68900  93.454  -79.035  53.442  1
68901  93.464  -79.033  53.429  1
68902  93.473  -79.030  53.417  1
68903  93.483  -79.028  53.406  1
68904  93.494  -79.019  53.395  1
68905  93.505  -79.009  53.385  1
68906  93.514  -79.001  53.375  1
68907  93.523  -78.994  53.365  1
68908  93.532  -78.987  53.358  1
68909  93.540  -78.981  53.352  1
68910  93.548  -78.973  53.345  1
68911  93.556  -78.966  53.341  1
68912  93.565  -78.959  53.338  1
68913  93.573  -78.952  53.337  1
68914  93.581  -78.946  53.336  1
68915  93.588  -78.946  53.335  1
68916  93.606  -78.942  53.333  1
68917  93.620  -78.940  53.327  1
68918  93.635  -78.937  53.319  1
68919  93.652  -78.935  53.311  1
68920  93.669  -78.933  53.303  1
68921  93.686  -78.930  53.294  1
68922  93.703  -78.928  53.286  1
68923  93.718  -78.926  53.278  1
68924  93.727  -78.925  53.268  1
68925  93.737  -78.924  53.259  1
68926  93.747  -78.923  53.249  1
68927  93.755  -78.922  53.237  1
68928  93.762  -78.922  53.225  1
68929  93.768  -78.922  53.213  1
68930  93.775  -78.922  53.201  1
68931  93.781  -78.922  53.189  1
68932  93.788  -78.922  53.177  1
68933  93.795  -78.922  53.167  1
68934  93.801  -78.922  53.156  1
68935  93.808  -78.922  53.146  1
68936  93.815  -78.921  53.135  1
68937  93.827  -78.908  53.123  1
68938  93.838  -78.897  53.109  1
68939  93.845  -78.891  53.095  1
68940  93.846  -78.893  53.081  1
68941  93.848  -78.895  53.067  1
68942  93.850  -78.896  53.053  1
68943  93.851  -78.899  53.038  1
68944  93.853  -78.900  53.023  1
68945  93.852  -78.899  53.003  1
68946  93.848  -78.893  52.982  1
68947  93.843  -78.889  52.959  1
68948  93.839  -78.883  52.935  1
68949  93.834  -78.878  52.910  1
68950  93.830  -78.873  52.885  1
68951  93.827  -78.869  52.860  1
68952  93.839  -78.873  52.832  1
68953  93.856  -78.878  52.805  1
68954  93.873  -78.883  52.779  1
68955  93.893  -78.886  52.753  1
68956  93.913  -78.888  52.726  1
68957  93.934  -78.890  52.699  1
68958  93.954  -78.893  52.672  1
68959  93.974  -78.895  52.644  1
68960  93.995  -78.897  52.617  1
68961  94.015  -78.899  52.591  1
68962  94.033  -78.899  52.567  1
68963  94.043  -78.896  52.543  1
68964  94.053  -78.892  52.520  1
68965  94.063  -78.888  52.497  1
68966  94.073  -78.883  52.473  1
68967  94.082  -78.872  52.448  1
68968  94.091  -78.861  52.424  1
68969  94.100  -78.851  52.401  1
68970  94.109  -78.840  52.378  1
68971  94.118  -78.830  52.354  1
68972  94.127  -78.823  52.329  1
68973  94.134  -78.818  52.303  1
68974  94.141  -78.813  52.276  1
68975  94.154  -78.810  52.247  1
68976  94.169  -78.808  52.222  1
68977  94.184  -78.802  52.197  1
68978  94.200  -78.792  52.172  1
68979  94.216  -78.782  52.147  1
68980  94.233  -78.772  52.120  1
68981  94.249  -78.762  52.092  1
68982  94.266  -78.752  52.064  1
68983  94.280  -78.744  52.037  1
68984  94.288  -78.742  52.009  1
68985  94.297  -78.740  51.981  1
68986  94.306  -78.738  51.951  1
68987  94.317  -78.737  51.920  1
68988  94.333  -78.739  51.888  1
68989  94.348  -78.742  51.855  1
68990  94.364  -78.743  51.823  1
68991  94.379  -78.745  51.792  1
68992  94.393  -78.749  51.761  1
68993  94.406  -78.755  51.729  1
68994  94.421  -78.741  51.696  1
68995  94.438  -78.743  51.663  1
68996  94.456  -78.748  51.627  1
68997  94.473  -78.752  51.595  1
68998  94.491  -78.756  51.562  1
68999  94.508  -78.761  51.530  1
69000  94.526  -78.765  51.498  1
69001  94.543  -78.770  51.465  1
69002  94.561  -78.774  51.433  1
69003  94.588  -78.781  51.400  1
69004  94.615  -78.788  51.367  1
69005  94.642  -78.795  51.334  1
69006  94.670  -78.802  51.300  1
69007  94.697  -78.808  51.264  1
69008  94.717  -78.812  51.227  1
69009  94.732  -78.813  51.191  1
69010  94.747  -78.814  51.157  1
69011  94.747  -78.823  51.125  1
69012  94.744  -78.831  51.092  1
69013  94.742  -78.840  51.059  1
69014  94.740  -78.849  51.025  1
69015  94.737  -78.858  50.988  1
69016  94.718  -78.851  50.949  1
69017  94.697  -78.840  50.907  1
69018  94.675  -78.830  50.864  1
69019  94.661  -78.822  50.821  1
69020  94.665  -78.821  50.778  1
69021  94.669  -78.821  50.735  1
69022  94.694  -78.821  50.692  1
69023  94.725  -78.813  50.649  1
69024  94.756  -78.805  50.608  1
69025  94.787  -78.797  50.566  1
69026  94.818  -78.789  50.525  1
69027  94.844  -78.783  50.484  1
69028  94.862  -78.779  50.448  1
69029  94.881  -78.776  50.413  1
69030  94.888  -78.783  50.379  1
69031  94.887  -78.799  50.344  1
69032  94.886  -78.814  50.307  1
69033  94.884  -78.830  50.268  1
69034  94.880  -78.838  50.227  1
69035  94.872  -78.838  50.186  1
69036  94.864  -78.837  50.145  1
69037  94.856  -78.836  50.103  1
69038  94.848  -78.836  50.060  1
69039  94.840  -78.836  50.019  1
69040  94.833  -78.835  49.978  1
69041  94.837  -78.836  49.939  1
69042  94.853  -78.839  49.899  1
69043  94.870  -78.843  49.859  1
69044  94.887  -78.846  49.821  1
69045  94.904  -78.849  49.781  1
69046  94.918  -78.858  49.743  1
69047  94.926  -78.886  49.705  1
69048  94.934  -78.914  49.670  1
69049  94.949  -78.937  49.635  1
69050  94.981  -78.943  49.600  1
69051  94.997  -78.952  49.567  1
69052  95.014  -78.962  49.531  1
69053  95.030  -78.971  49.496  1
69054  95.050  -78.980  49.461  1
69055  95.079  -78.987  49.422  1
69056  95.109  -78.993  49.383  1
69057  95.138  -79.000  49.343  1
69058  95.168  -79.007  49.303  1
69059  95.197  -79.014  49.263  1
69060  95.225  -79.018  49.224  1
69061  95.249  -79.021  49.185  1
69062  95.273  -79.023  49.143  1
69063  95.298  -79.025  49.101  1
69064  95.323  -79.028  49.059  1
69065  95.347  -79.030  49.017  1
69066  95.372  -79.032  48.974  1
69067  95.385  -79.037  48.931  1
69068  95.394  -79.043  48.886  1
69069  95.400  -79.057  48.842  1
69070  95.404  -79.077  48.796  1
69071  95.409  -79.097  48.750  1
69072  95.414  -79.118  48.707  1
69073  95.416  -79.134  48.663  1
69074  95.419  -79.150  48.619  1
69075  95.421  -79.166  48.575  1
69076  95.433  -79.181  48.531  1
69077  95.446  -79.197  48.487  1
69078  95.459  -79.213  48.444  1
69079  95.472  -79.228  48.401  1
69080  95.495  -79.240  48.357  1
69081  95.522  -79.231  48.312  1
69082  95.544  -79.218  48.267  1
69083  95.566  -79.205  48.227  1
69084  95.589  -79.191  48.185  1
69085  95.612  -79.178  48.142  1
69086  95.634  -79.165  48.099  1
69087  95.657  -79.152  48.057  1
69088  95.679  -79.139  48.016  1
69089  95.696  -79.129  47.976  1
69090  95.706  -79.124  47.935  1
69091  95.716  -79.118  47.894  1
69092  95.749  -79.128  47.855  1
69093  95.783  -79.137  47.813  1
69094  95.817  -79.146  47.772  1
69095  95.842  -79.152  47.732  1
69096  95.854  -79.153  47.692  1
69097  95.867  -79.153  47.652  1
69098  95.879  -79.154  47.612  1
69099  95.891  -79.155  47.573  1
69100  95.909  -79.174  47.532  1
69101  95.917  -79.179  47.492  1
69102  95.912  -79.171  47.453  1
69103  95.908  -79.162  47.414  1
69104  95.919  -79.150  47.374  1
69105  95.947  -79.125  47.335  1
69106  95.935  -79.090  47.296  1
69107  95.986  -79.124  47.258  1
69108  96.037  -79.157  47.221  1
69109  96.088  -79.190  47.184  1
69110  96.118  -79.147  47.148  1
69111  96.146  -79.093  47.112  1
69112  96.176  -79.056  47.077  1
69113  96.210  -79.043  47.042  1
69114  96.245  -79.031  47.008  1
69115  96.279  -79.018  46.975  1
69116  96.313  -79.005  46.943  1
69117  96.343  -79.036  46.911  1
69118  96.372  -79.082  46.880  1
69119  96.400  -79.128  46.849  1
69120  96.429  -79.173  46.819  1
69121  96.457  -79.219  46.788  1
69122  96.477  -79.236  46.758  1
69123  96.491  -79.237  46.727  1
69124  96.506  -79.237  46.696  1
69125  96.525  -79.243  46.664  1
69126  96.549  -79.255  46.632  1
69127  96.558  -79.253  46.601  1
69128  96.568  -79.251  46.572  1
69129  96.586  -79.252  46.542  1
69130  96.609  -79.255  46.512  1
69131  96.632  -79.257  46.483  1
69132  96.655  -79.259  46.454  1
69133  96.678  -79.263  46.426  1
69134  96.700  -79.265  46.397  1
69135  96.723  -79.267  46.370  1
69136  96.746  -79.270  46.343  1
69137  96.769  -79.272  46.318  1
69138  96.792  -79.275  46.292  1
69139  96.814  -79.273  46.266  1
69140  96.832  -79.252  46.240  1
69141  96.851  -79.231  46.215  1
69142  96.870  -79.210  46.191  1
69143  96.888  -79.189  46.168  1
69144  96.907  -79.168  46.145  1
69145  96.944  -79.178  46.123  1
69146  96.981  -79.188  46.101  1
69147  97.018  -79.198  46.078  1
69148  97.021  -79.213  46.056  1
69149  97.056  -79.179  46.035  1
69150  97.081  -79.208  46.015  1
69151  97.077  -79.209  45.996  1
69152  97.085  -79.209  45.975  1
69153  97.085  -79.227  45.955  1
69154  97.100  -79.227  45.934  1
69155  97.115  -79.227  45.913  1
69156  97.130  -79.228  45.893  1
69157  97.145  -79.228  45.874  1
69158  97.159  -79.228  45.856  1
69159  97.149  -79.244  45.837  1
69160  97.166  -79.231  45.817  1
69161  97.168  -79.225  45.797  1
69162  97.169  -79.217  45.778  1
69163  97.171  -79.210  45.759  1
69164  97.173  -79.203  45.742  1
69165  97.174  -79.197  45.724  1
69166  97.199  -79.187  45.706  1
69167  97.210  -79.196  45.688  1
69168  97.214  -79.209  45.669  1
69169  97.218  -79.222  45.652  1
69170  97.221  -79.234  45.635  1
69171  97.225  -79.247  45.619  1
69172  97.229  -79.259  45.602  1
69173  97.233  -79.272  45.585  1
69174  97.237  -79.285  45.568  1
69175  97.251  -79.302  45.551  1
69176  97.265  -79.319  45.534  1
69177  97.280  -79.335  45.518  1
69178  97.294  -79.353  45.503  1
69179  97.308  -79.369  45.488  1
69180  97.297  -79.388  45.472  1
69181  97.318  -79.380  45.456  1
69182  97.353  -79.366  45.441  1
69183  97.374  -79.353  45.425  1
69184  97.387  -79.341  45.409  1
69185  97.400  -79.329  45.394  1
69186  97.412  -79.317  45.379  1
69187  97.418  -79.305  45.365  1
69188  97.418  -79.307  45.350  1
69189  97.404  -79.339  45.335  1
69190  97.391  -79.370  45.320  1
69191  97.433  -79.357  45.306  1
69192  97.461  -79.363  45.292  1
69193  97.480  -79.378  45.278  1
69194  97.500  -79.394  45.265  1
69195  97.519  -79.409  45.250  1
69196  97.537  -79.424  45.237  1
69197  97.557  -79.440  45.224  1
69198  97.576  -79.455  45.210  1
69199  97.595  -79.470  45.198  1
69200  97.614  -79.486  45.185  1
69201  97.633  -79.501  45.172  1
69202  97.652  -79.516  45.160  1
69203  97.671  -79.532  45.147  1
69204  97.690  -79.548  45.135  1
69205  97.709  -79.563  45.122  1
69206  97.728  -79.578  45.110  1
69207  97.747  -79.594  45.098  1
69208  97.767  -79.609  45.086  1
69209  97.786  -79.624  45.074  1
69210  97.805  -79.640  45.062  1
69211  97.823  -79.655  45.050  1
69212  97.843  -79.670  45.038  1
69213  97.862  -79.686  45.027  1
69214  97.881  -79.701  45.014  1
69215  97.900  -79.717  45.001  1
69216  97.919  -79.733  44.987  1
69217  97.938  -79.748  44.974  1
69218  97.957  -79.763  44.961  1
69219  97.976  -79.778  44.948  1
69220  97.995  -79.794  44.935  1
69221  98.014  -79.809  44.923  1
69222  98.033  -79.824  44.911  1
69223  98.053  -79.840  44.899  1
69224  98.072  -79.855  44.888  1
69225  98.090  -79.871  44.877  1
69226  98.109  -79.886  44.867  1
69227  98.129  -79.902  44.857  1
69228  98.148  -79.917  44.848  1
69229  98.167  -79.933  44.839  1
69230  98.186  -79.948  44.829  1
69231  98.205  -79.963  44.819  1
69232  98.224  -79.978  44.810  1
69233  98.243  -79.994  44.800  1
69234  98.262  -80.009  44.793  1
69235  98.281  -80.024  44.785  1
69236  98.300  -80.040  44.777  1
69237  98.319  -80.055  44.769  1
69238  98.339  -80.071  44.762  1
69239  98.357  -80.087  44.754  1
69240  98.376  -80.102  44.746  1
69241  98.395  -80.117  44.739  1
69242  98.415  -80.133  44.732  1
69243  98.434  -80.148  44.725  1
69244  98.453  -80.163  44.719  1
69245  98.472  -80.178  44.713  1
69246  98.491  -80.194  44.706  1
69247  98.508  -80.211  44.700  1
69248  98.526  -80.227  44.695  1
69249  98.550  -80.233  44.689  1
69250  98.570  -80.237  44.683  1
69251  98.591  -80.242  44.678  1
69252  98.613  -80.247  44.673  1
69253  98.635  -80.251  44.668  1
69254  98.656  -80.255  44.662  1
69255  98.678  -80.259  44.656  1
69256  98.700  -80.264  44.650  1
69257  98.721  -80.269  44.644  1
69258  98.742  -80.275  44.633  1
69259  98.762  -80.286  44.621  1
69260  98.786  -80.294  44.607  1
69261  98.836  -80.293  44.596  1
69262  98.865  -80.306  44.588  1
69263  98.888  -80.316  44.581  1
69264  98.912  -80.327  44.574  1
69265  98.935  -80.337  44.568  1
69266  98.958  -80.348  44.562  1
69267  98.981  -80.359  44.557  1
69268  99.005  -80.369  44.550  1
69269  99.028  -80.380  44.544  1
69270  99.051  -80.391  44.539  1
69271  99.075  -80.400  44.535  1
69272  99.098  -80.411  44.530  1
69273  99.121  -80.422  44.525  1
69274  99.144  -80.432  44.520  1
69275  99.168  -80.443  44.514  1
69276  99.191  -80.453  44.510  1
69277  99.214  -80.464  44.507  1
69278  99.238  -80.475  44.503  1
69602  93.464  -79.021  53.450  1
69603  93.474  -79.019  53.438  1
69604  93.483  -79.017  53.426  1
69605  93.493  -79.014  53.415  1
69606  93.504  -79.006  53.405  1
69607  93.515  -78.995  53.395  1
69608  93.524  -78.987  53.385  1
69609  93.533  -78.981  53.377  1
69610  93.541  -78.974  53.370  1
69611  93.549  -78.967  53.363  1
69612  93.557  -78.960  53.357  1
69613  93.566  -78.953  53.353  1
69614  93.574  -78.946  53.349  1
69615  93.582  -78.939  53.347  1
69616  93.591  -78.932  53.345  1
69617  93.602  -78.927  53.342  1
69618  93.619  -78.924  53.337  1
69619  93.636  -78.922  53.330  1
69620  93.653  -78.920  53.323  1
69621  93.670  -78.918  53.315  1
69622  93.687  -78.915  53.307  1
69623  93.704  -78.912  53.299  1
69624  93.713  -78.912  53.291  1
69625  93.723  -78.910  53.282  1
69626  93.733  -78.909  53.274  1
69627  93.743  -78.908  53.265  1
69628  93.751  -78.907  53.255  1
69629  93.758  -78.907  53.243  1
69630  93.764  -78.907  53.231  1
69631  93.771  -78.907  53.219  1
69632  93.778  -78.907  53.209  1
69633  93.784  -78.907  53.198  1
69634  93.791  -78.908  53.187  1
69635  93.798  -78.907  53.175  1
69636  93.805  -78.905  53.165  1
69637  93.812  -78.902  53.155  1
69638  93.822  -78.893  53.144  1
69639  93.833  -78.881  53.129  1
69640  93.839  -78.877  53.115  1
69641  93.840  -78.879  53.100  1
69642  93.842  -78.881  53.085  1
69643  93.844  -78.883  53.069  1
69644  93.845  -78.885  53.054  1
69645  93.843  -78.882  53.038  1
69646  93.839  -78.877  53.017  1
69647  93.834  -78.871  52.994  1
69648  93.830  -78.866  52.971  1
69649  93.825  -78.861  52.947  1
69650  93.821  -78.855  52.921  1
69651  93.817  -78.850  52.896  1
69652  93.821  -78.846  52.871  1
69653  93.839  -78.843  52.843  1
69654  93.859  -78.845  52.816  1
69655  93.880  -78.847  52.790  1
69656  93.900  -78.849  52.764  1
69657  93.920  -78.852  52.737  1
69658  93.940  -78.854  52.710  1
69659  93.961  -78.856  52.683  1
69660  93.981  -78.858  52.656  1
69661  94.002  -78.860  52.629  1
69662  94.022  -78.862  52.604  1
69663  94.041  -78.864  52.580  1
69664  94.051  -78.860  52.556  1
69665  94.061  -78.856  52.533  1
69666  94.071  -78.852  52.510  1
69667  94.081  -78.849  52.486  1
69668  94.091  -78.845  52.462  1
69669  94.102  -78.840  52.438  1
69670  94.111  -78.833  52.414  1
69671  94.120  -78.822  52.390  1
69672  94.129  -78.811  52.366  1
69673  94.138  -78.801  52.342  1
69674  94.145  -78.796  52.315  1
69675  94.155  -78.793  52.288  1
69676  94.170  -78.789  52.260  1
69677  94.183  -78.787  52.233  1
69678  94.197  -78.783  52.207  1
69679  94.214  -78.774  52.182  1
69680  94.230  -78.764  52.156  1
69681  94.247  -78.754  52.128  1
69682  94.263  -78.744  52.099  1
69683  94.278  -78.735  52.071  1
69684  94.287  -78.733  52.042  1
69685  94.296  -78.730  52.013  1
69686  94.305  -78.728  51.984  1
69687  94.313  -78.727  51.955  1
69688  94.322  -78.724  51.924  1
69689  94.338  -78.727  51.893  1
69690  94.353  -78.729  51.862  1
69691  94.368  -78.730  51.831  1
69692  94.384  -78.733  51.800  1
69693  94.397  -78.738  51.769  1
69694  94.410  -78.742  51.736  1
69695  94.424  -78.737  51.705  1
69696  94.441  -78.735  51.674  1
69697  94.459  -78.739  51.642  1
69698  94.476  -78.743  51.609  1
69699  94.493  -78.748  51.578  1
69700  94.511  -78.752  51.548  1
69701  94.529  -78.756  51.514  1
69702  94.546  -78.761  51.481  1
69703  94.572  -78.767  51.447  1
69704  94.600  -78.774  51.413  1
69705  94.627  -78.781  51.380  1
69706  94.654  -78.788  51.347  1
69707  94.681  -78.795  51.313  1
69708  94.708  -78.802  51.277  1
69709  94.736  -78.809  51.241  1
69710  94.752  -78.811  51.205  1
69711  94.763  -78.814  51.170  1
69712  94.761  -78.823  51.136  1
69713  94.759  -78.832  51.102  1
69714  94.756  -78.841  51.069  1
69715  94.754  -78.850  51.035  1
69716  94.752  -78.859  50.999  1
69717  94.748  -78.863  50.962  1
69718  94.728  -78.853  50.922  1
69719  94.706  -78.843  50.879  1
69720  94.684  -78.832  50.836  1
69721  94.662  -78.821  50.793  1
69722  94.668  -78.815  50.750  1
69723  94.699  -78.807  50.708  1
69724  94.731  -78.799  50.665  1
69725  94.762  -78.791  50.623  1
69726  94.792  -78.783  50.581  1
69727  94.824  -78.775  50.539  1
69728  94.843  -78.771  50.497  1
69729  94.861  -78.768  50.458  1
69730  94.879  -78.764  50.421  1
69731  94.887  -78.771  50.386  1
69732  94.885  -78.787  50.352  1
69733  94.884  -78.802  50.316  1
69734  94.883  -78.818  50.279  1
69735  94.882  -78.833  50.240  1
69736  94.877  -78.840  50.200  1
69737  94.869  -78.839  50.159  1
69738  94.861  -78.839  50.117  1
69739  94.853  -78.839  50.074  1
69740  94.845  -78.838  50.032  1
69741  94.837  -78.838  49.991  1
69742  94.837  -78.839  49.952  1
69743  94.854  -78.842  49.913  1
69744  94.871  -78.845  49.873  1
69745  94.888  -78.848  49.835  1
69746  94.904  -78.851  49.795  1
69747  94.921  -78.854  49.756  1
69748  94.936  -78.861  49.719  1
69749  94.945  -78.889  49.683  1
69750  94.952  -78.917  49.648  1
69751  94.983  -78.924  49.612  1
69752  95.000  -78.933  49.578  1
69753  95.016  -78.943  49.544  1
69754  95.037  -78.951  49.508  1
69755  95.066  -78.958  49.471  1
69756  95.096  -78.965  49.432  1
69757  95.125  -78.971  49.392  1
69758  95.155  -78.978  49.351  1
69759  95.184  -78.985  49.311  1
69760  95.213  -78.992  49.272  1
69761  95.243  -78.999  49.233  1
69762  95.268  -79.002  49.194  1
69763  95.293  -79.004  49.152  1
69764  95.317  -79.006  49.111  1
69765  95.341  -79.009  49.069  1
69766  95.366  -79.011  49.026  1
69767  95.386  -79.014  48.983  1
69768  95.394  -79.020  48.939  1
69769  95.403  -79.026  48.895  1
69770  95.410  -79.035  48.851  1
69771  95.415  -79.056  48.807  1
69772  95.419  -79.076  48.762  1
69773  95.424  -79.096  48.718  1
69774  95.428  -79.116  48.675  1
69775  95.433  -79.136  48.631  1
69776  95.436  -79.153  48.585  1
69777  95.439  -79.169  48.542  1
69778  95.447  -79.184  48.498  1
69779  95.460  -79.200  48.455  1
69780  95.473  -79.216  48.412  1
69781  95.492  -79.229  48.368  1
69782  95.519  -79.220  48.324  1
69783  95.541  -79.206  48.279  1
69784  95.563  -79.194  48.237  1
69785  95.586  -79.181  48.194  1
69786  95.609  -79.167  48.151  1
69787  95.631  -79.154  48.108  1
69788  95.654  -79.140  48.066  1
69789  95.676  -79.128  48.023  1
69790  95.698  -79.115  47.981  1
69791  95.709  -79.109  47.939  1
69792  95.723  -79.106  47.898  1
69793  95.756  -79.115  47.856  1
69794  95.790  -79.125  47.815  1
69795  95.813  -79.130  47.774  1
69796  95.826  -79.131  47.732  1
69797  95.838  -79.131  47.692  1
69798  95.850  -79.132  47.651  1
69799  95.862  -79.133  47.611  1
69800  95.875  -79.134  47.572  1
69801  95.888  -79.137  47.531  1
69802  95.907  -79.158  47.491  1
69803  95.921  -79.172  47.451  1
69804  95.917  -79.164  47.412  1
69805  95.913  -79.155  47.373  1
69806  95.960  -79.137  47.335  1
69807  95.961  -79.105  47.297  1
69808  96.003  -79.129  47.258  1
69809  96.054  -79.162  47.221  1
69810  96.088  -79.131  47.184  1
69811  96.116  -79.080  47.148  1
69812  96.150  -79.068  47.111  1
69813  96.184  -79.055  47.075  1
69814  96.219  -79.042  47.041  1
69815  96.253  -79.029  47.008  1
69816  96.287  -79.016  46.975  1
69817  96.321  -79.003  46.942  1
69818  96.352  -79.035  46.912  1
69819  96.380  -79.081  46.881  1
69820  96.408  -79.127  46.850  1
69821  96.437  -79.172  46.819  1
69822  96.464  -79.215  46.789  1
69823  96.479  -79.216  46.758  1
69824  96.493  -79.216  46.728  1
69825  96.508  -79.216  46.695  1
69826  96.523  -79.217  46.663  1
69827  96.540  -79.220  46.631  1
69828  96.555  -79.225  46.601  1
69829  96.572  -79.225  46.571  1
69830  96.594  -79.227  46.541  1
69831  96.617  -79.230  46.511  1
69832  96.640  -79.232  46.482  1
69833  96.663  -79.234  46.454  1
69834  96.685  -79.237  46.427  1
69835  96.708  -79.240  46.398  1
69836  96.731  -79.242  46.370  1
69837  96.754  -79.245  46.344  1
69838  96.777  -79.247  46.318  1
69839  96.799  -79.250  46.292  1
69840  96.822  -79.250  46.266  1
69841  96.840  -79.228  46.240  1
69842  96.859  -79.208  46.214  1
69843  96.878  -79.187  46.191  1
69844  96.896  -79.165  46.168  1
69845  96.928  -79.166  46.145  1
69846  96.965  -79.177  46.122  1
69847  96.999  -79.189  46.099  1
69848  96.991  -79.213  46.076  1
69849  97.026  -79.177  46.054  1
69850  97.064  -79.174  46.033  1
69851  97.084  -79.198  46.014  1
69852  97.080  -79.199  45.994  1
69853  97.081  -79.200  45.974  1
69854  97.090  -79.200  45.954  1
69855  97.099  -79.200  45.933  1
69856  97.106  -79.214  45.913  1
69857  97.121  -79.214  45.894  1
69858  97.136  -79.214  45.875  1
69859  97.151  -79.215  45.856  1
69860  97.148  -79.224  45.837  1
69861  97.167  -79.210  45.818  1
69862  97.168  -79.203  45.799  1
69863  97.170  -79.197  45.779  1
69864  97.172  -79.190  45.761  1
69865  97.173  -79.182  45.743  1
69866  97.175  -79.175  45.726  1
69867  97.177  -79.169  45.708  1
69868  97.194  -79.165  45.690  1
69869  97.198  -79.178  45.672  1
69870  97.203  -79.191  45.654  1
69871  97.207  -79.203  45.637  1
69872  97.212  -79.217  45.621  1
69873  97.226  -79.234  45.604  1
69874  97.240  -79.250  45.588  1
69875  97.254  -79.268  45.571  1
69876  97.268  -79.285  45.554  1
69877  97.283  -79.301  45.537  1
69878  97.297  -79.319  45.522  1
69879  97.311  -79.335  45.507  1
69880  97.316  -79.356  45.491  1
69881  97.300  -79.372  45.476  1
69882  97.316  -79.366  45.460  1
69883  97.350  -79.352  45.445  1
69884  97.373  -79.339  45.429  1
69885  97.386  -79.327  45.413  1
69886  97.399  -79.316  45.398  1
69887  97.412  -79.303  45.384  1
69888  97.425  -79.292  45.370  1
69889  97.447  -79.312  45.355  1
69890  97.475  -79.402  45.340  1
69891  97.461  -79.400  45.325  1
69892  97.443  -79.396  45.312  1
69893  97.424  -79.392  45.297  1
69894  97.461  -79.374  45.284  1
69895  97.508  -79.359  45.270  1
69896  97.527  -79.374  45.257  1
69897  97.546  -79.390  45.244  1
69898  97.565  -79.405  45.230  1
69899  97.584  -79.420  45.217  1
69900  97.603  -79.436  45.204  1
69901  97.623  -79.451  45.192  1
69902  97.642  -79.466  45.180  1
69903  97.661  -79.482  45.167  1
69904  97.680  -79.498  45.155  1
69905  97.699  -79.513  45.142  1
69906  97.718  -79.529  45.130  1
69907  97.737  -79.544  45.118  1
69908  97.756  -79.559  45.106  1
69909  97.775  -79.574  45.094  1
69910  97.794  -79.590  45.082  1
69911  97.813  -79.605  45.071  1
69912  97.832  -79.620  45.059  1
69913  97.851  -79.636  45.047  1
69914  97.870  -79.651  45.035  1
69915  97.889  -79.667  45.022  1
69916  97.909  -79.683  45.009  1
69917  97.928  -79.698  44.996  1
69918  97.947  -79.713  44.983  1
69919  97.965  -79.729  44.970  1
69920  97.985  -79.744  44.957  1
69921  98.004  -79.759  44.945  1
69922  98.023  -79.774  44.933  1
69923  98.042  -79.790  44.921  1
69924  98.061  -79.805  44.909  1
69925  98.080  -79.820  44.899  1
69926  98.098  -79.837  44.888  1
69927  98.114  -79.855  44.878  1
69928  98.132  -79.871  44.869  1
69929  98.149  -79.889  44.859  1
69930  98.166  -79.905  44.849  1
69931  98.182  -79.923  44.840  1
69932  98.200  -79.940  44.831  1
69933  98.217  -79.957  44.822  1
69934  98.233  -79.974  44.813  1
69935  98.250  -79.991  44.805  1
69936  98.268  -80.008  44.797  1
69937  98.285  -80.025  44.789  1
69938  98.302  -80.042  44.781  1
69939  98.319  -80.058  44.774  1
69940  98.336  -80.074  44.767  1
69941  98.354  -80.090  44.758  1
69942  98.371  -80.106  44.751  1
69943  98.388  -80.121  44.744  1
69944  98.406  -80.137  44.738  1
69945  98.423  -80.153  44.732  1
69946  98.446  -80.168  44.726  1
69947  98.469  -80.182  44.719  1
69948  98.503  -80.179  44.713  1
69949  98.530  -80.194  44.709  1
69950  98.557  -80.206  44.704  1
69951  98.577  -80.211  44.698  1
69952  98.598  -80.215  44.693  1
69953  98.620  -80.220  44.689  1
69954  98.640  -80.225  44.685  1
69955  98.661  -80.229  44.679  1
69956  98.683  -80.234  44.673  1
69957  98.704  -80.237  44.666  1
69958  98.728  -80.240  44.659  1
69959  98.754  -80.249  44.648  1
69960  98.779  -80.260  44.634  1
69961  98.790  -80.269  44.620  1
69962  98.797  -80.275  44.608  1
69963  98.845  -80.275  44.600  1
69964  98.892  -80.289  44.592  1
69965  98.915  -80.300  44.585  1
69966  98.939  -80.310  44.579  1
69967  98.962  -80.321  44.572  1
69968  98.985  -80.331  44.566  1
69969  99.009  -80.342  44.559  1
69970  99.032  -80.353  44.554  1
69971  99.055  -80.363  44.549  1
69972  99.079  -80.374  44.544  1
69973  99.102  -80.384  44.539  1
69974  99.125  -80.394  44.534  1
69975  99.148  -80.405  44.529  1
69976  99.172  -80.416  44.524  1
69977  99.195  -80.426  44.520  1
69978  99.218  -80.437  44.516  1
69979  99.242  -80.447  44.512  1
69980  99.265  -80.458  44.509  1
69981  99.288  -80.469  44.505  1
69982  99.311  -80.479  44.501  1
70304  93.474  -79.009  53.458  1
70305  93.484  -79.006  53.446  1
70306  93.493  -79.003  53.435  1
70307  93.503  -79.001  53.425  1
70308  93.514  -78.991  53.415  1
70309  93.525  -78.981  53.406  1
70310  93.534  -78.974  53.397  1
70311  93.542  -78.967  53.388  1
70312  93.550  -78.960  53.380  1
70313  93.559  -78.953  53.374  1
70314  93.567  -78.946  53.368  1
70315  93.575  -78.940  53.361  1
70316  93.583  -78.933  53.358  1
70317  93.592  -78.925  53.355  1
70318  93.609  -78.915  53.351  1
70319  93.620  -78.908  53.346  1
70320  93.637  -78.906  53.340  1
70321  93.654  -78.904  53.333  1
70322  93.671  -78.902  53.326  1
70323  93.688  -78.899  53.318  1
70324  93.700  -78.898  53.311  1
70325  93.709  -78.896  53.304  1
70326  93.719  -78.896  53.296  1
70327  93.729  -78.894  53.289  1
70328  93.739  -78.893  53.280  1
70329  93.747  -78.893  53.271  1
70330  93.754  -78.893  53.260  1
70331  93.761  -78.893  53.249  1
70332  93.767  -78.893  53.239  1
70333  93.774  -78.893  53.227  1
70334  93.781  -78.893  53.216  1
70335  93.787  -78.890  53.206  1
70336  93.794  -78.888  53.195  1
70337  93.801  -78.886  53.184  1
70338  93.808  -78.883  53.173  1
70339  93.818  -78.877  53.161  1
70340  93.829  -78.865  53.147  1
70341  93.833  -78.864  53.133  1
70342  93.834  -78.866  53.118  1
70343  93.836  -78.868  53.101  1
70344  93.838  -78.869  53.084  1
70345  93.834  -78.865  53.068  1
70346  93.830  -78.860  53.050  1
70347  93.825  -78.855  53.028  1
70348  93.821  -78.849  53.005  1
70349  93.816  -78.844  52.981  1
70350  93.817  -78.839  52.955  1
70351  93.822  -78.834  52.930  1
70352  93.828  -78.830  52.906  1
70353  93.837  -78.825  52.882  1
70354  93.852  -78.819  52.854  1
70355  93.868  -78.812  52.826  1
70356  93.887  -78.811  52.800  1
70357  93.907  -78.813  52.774  1
70358  93.927  -78.814  52.747  1
70359  93.947  -78.817  52.721  1
70360  93.968  -78.819  52.694  1
70361  93.988  -78.821  52.667  1
70362  94.009  -78.824  52.642  1
70363  94.029  -78.826  52.618  1
70364  94.049  -78.828  52.593  1
70365  94.059  -78.824  52.569  1
70366  94.069  -78.821  52.546  1
70367  94.079  -78.816  52.523  1
70368  94.090  -78.812  52.500  1
70369  94.100  -78.808  52.475  1
70370  94.110  -78.805  52.451  1
70371  94.120  -78.801  52.426  1
70372  94.130  -78.797  52.401  1
70373  94.140  -78.793  52.378  1
70374  94.149  -78.782  52.354  1
70375  94.157  -78.775  52.327  1
70376  94.171  -78.772  52.300  1
70377  94.184  -78.769  52.273  1
70378  94.198  -78.767  52.245  1
70379  94.212  -78.764  52.219  1
70380  94.228  -78.755  52.194  1
70381  94.244  -78.745  52.168  1
70382  94.261  -78.736  52.139  1
70383  94.277  -78.726  52.110  1
70384  94.286  -78.724  52.081  1
70385  94.294  -78.721  52.052  1
70386  94.303  -78.719  52.023  1
70387  94.312  -78.717  51.994  1
70388  94.320  -78.714  51.965  1
70389  94.329  -78.712  51.935  1
70390  94.343  -78.714  51.904  1
70391  94.358  -78.715  51.873  1
70392  94.373  -78.717  51.842  1
70393  94.387  -78.722  51.812  1
70394  94.400  -78.727  51.781  1
70395  94.414  -78.731  51.750  1
70396  94.427  -78.733  51.718  1
70397  94.443  -78.726  51.687  1
70398  94.461  -78.730  51.656  1
70399  94.479  -78.735  51.625  1
70400  94.496  -78.739  51.595  1
70401  94.513  -78.743  51.565  1
70402  94.531  -78.748  51.533  1
70403  94.557  -78.755  51.498  1
70404  94.584  -78.761  51.462  1
70405  94.611  -78.768  51.427  1
70406  94.638  -78.775  51.393  1
70407  94.666  -78.782  51.359  1
70408  94.693  -78.789  51.325  1
70409  94.720  -78.796  51.290  1
70410  94.747  -78.802  51.255  1
70411  94.773  -78.809  51.219  1
70412  94.777  -78.814  51.183  1
70413  94.775  -78.824  51.148  1
70414  94.771  -78.826  51.113  1
70415  94.768  -78.827  51.079  1
70416  94.764  -78.828  51.044  1
70417  94.760  -78.830  51.009  1
70418  94.756  -78.830  50.973  1
70419  94.737  -78.821  50.934  1
70420  94.715  -78.811  50.893  1
70421  94.693  -78.800  50.851  1
70422  94.676  -78.801  50.807  1
70423  94.679  -78.803  50.765  1
70424  94.705  -78.793  50.723  1
70425  94.736  -78.785  50.681  1
70426  94.767  -78.777  50.637  1
70427  94.798  -78.769  50.594  1
70428  94.823  -78.764  50.551  1
70429  94.841  -78.760  50.510  1
70430  94.859  -78.757  50.470  1
70431  94.877  -78.754  50.431  1
70432  94.885  -78.760  50.394  1
70433  94.884  -78.775  50.360  1
70434  94.883  -78.791  50.324  1
70435  94.882  -78.806  50.287  1
70436  94.881  -78.822  50.251  1
70437  94.879  -78.837  50.211  1
70438  94.874  -78.843  50.171  1
70439  94.866  -78.842  50.130  1
70440  94.858  -78.841  50.088  1
70441  94.850  -78.841  50.047  1
70442  94.842  -78.840  50.006  1
70443  94.838  -78.840  49.967  1
70444  94.855  -78.843  49.928  1
70445  94.872  -78.846  49.888  1
70446  94.889  -78.849  49.849  1
70447  94.905  -78.852  49.808  1
70448  94.922  -78.855  49.769  1
70449  94.939  -78.858  49.732  1
70450  94.955  -78.864  49.696  1
70451  94.963  -78.892  49.660  1
70452  94.986  -78.905  49.625  1
70453  95.002  -78.915  49.590  1
70454  95.024  -78.923  49.555  1
70455  95.054  -78.930  49.518  1
70456  95.083  -78.937  49.481  1
70457  95.112  -78.943  49.441  1
70458  95.142  -78.950  49.400  1
70459  95.171  -78.957  49.359  1
70460  95.200  -78.964  49.318  1
70461  95.230  -78.971  49.280  1
70462  95.259  -78.977  49.242  1
70463  95.287  -78.983  49.202  1
70464  95.311  -78.985  49.160  1
70465  95.336  -78.987  49.120  1
70466  95.360  -78.990  49.079  1
70467  95.385  -78.992  49.036  1
70468  95.395  -78.997  48.992  1
70469  95.403  -79.003  48.949  1
70470  95.412  -79.009  48.905  1
70471  95.420  -79.015  48.861  1
70472  95.425  -79.034  48.817  1
70473  95.429  -79.054  48.773  1
70474  95.434  -79.075  48.729  1
70475  95.439  -79.094  48.686  1
70476  95.444  -79.115  48.642  1
70477  95.448  -79.134  48.596  1
70478  95.453  -79.155  48.553  1
70479  95.456  -79.172  48.510  1
70480  95.461  -79.187  48.467  1
70481  95.474  -79.203  48.423  1
70482  95.489  -79.218  48.379  1
70483  95.516  -79.209  48.335  1
70484  95.538  -79.195  48.291  1
70485  95.560  -79.182  48.247  1
70486  95.583  -79.169  48.203  1
70487  95.606  -79.156  48.161  1
70488  95.628  -79.143  48.117  1
70489  95.651  -79.130  48.074  1
70490  95.673  -79.116  48.031  1
70491  95.696  -79.103  47.988  1
70492  95.711  -79.094  47.944  1
70493  95.729  -79.093  47.901  1
70494  95.763  -79.103  47.859  1
70495  95.784  -79.108  47.817  1
70496  95.797  -79.109  47.776  1
70497  95.809  -79.109  47.734  1
70498  95.821  -79.110  47.693  1
70499  95.834  -79.111  47.652  1
70500  95.846  -79.112  47.611  1
70501  95.858  -79.112  47.571  1
70502  95.871  -79.113  47.532  1
70503  95.886  -79.122  47.491  1
70504  95.905  -79.143  47.451  1
70505  95.925  -79.165  47.412  1
70506  95.921  -79.157  47.373  1
70507  95.945  -79.143  47.335  1
70508  95.989  -79.122  47.297  1
70509  96.020  -79.134  47.259  1
70510  96.057  -79.115  47.221  1
70511  96.090  -79.091  47.184  1
70512  96.124  -79.079  47.148  1
70513  96.158  -79.066  47.111  1
70514  96.192  -79.053  47.076  1
70515  96.227  -79.040  47.042  1
70516  96.261  -79.028  47.009  1
70517  96.295  -79.015  46.976  1
70518  96.329  -79.002  46.943  1
70519  96.359  -79.035  46.913  1
70520  96.388  -79.081  46.882  1
70521  96.416  -79.126  46.851  1
70522  96.445  -79.172  46.819  1
70523  96.466  -79.194  46.788  1
70524  96.480  -79.195  46.757  1
70525  96.496  -79.195  46.726  1
70526  96.510  -79.196  46.694  1
70527  96.525  -79.196  46.662  1
70528  96.540  -79.197  46.631  1
70529  96.554  -79.197  46.602  1
70530  96.579  -79.200  46.571  1
70531  96.602  -79.202  46.541  1
70532  96.624  -79.204  46.512  1
70533  96.648  -79.207  46.483  1
70534  96.670  -79.209  46.455  1
70535  96.693  -79.212  46.427  1
70536  96.716  -79.215  46.399  1
70537  96.739  -79.217  46.372  1
70538  96.761  -79.219  46.345  1
70539  96.784  -79.222  46.318  1
70540  96.807  -79.225  46.293  1
70541  96.830  -79.226  46.267  1
70542  96.849  -79.205  46.241  1
70543  96.867  -79.184  46.215  1
70544  96.886  -79.163  46.191  1
70545  96.912  -79.155  46.168  1
70546  96.949  -79.165  46.145  1
70547  96.972  -79.184  46.122  1
70548  96.960  -79.212  46.098  1
70549  96.996  -79.177  46.075  1
70550  97.031  -79.140  46.053  1
70551  97.072  -79.169  46.032  1
70552  97.087  -79.188  46.013  1
70553  97.083  -79.189  45.993  1
70554  97.078  -79.190  45.974  1
70555  97.086  -79.190  45.954  1
70556  97.095  -79.191  45.933  1
70557  97.104  -79.191  45.913  1
70558  97.112  -79.201  45.895  1
70559  97.127  -79.201  45.877  1
70560  97.142  -79.201  45.857  1
70561  97.147  -79.203  45.838  1
70562  97.167  -79.190  45.820  1
70563  97.169  -79.182  45.801  1
70564  97.171  -79.175  45.781  1
70565  97.172  -79.169  45.763  1
70566  97.174  -79.162  45.745  1
70567  97.175  -79.155  45.728  1
70568  97.177  -79.147  45.710  1
70569  97.179  -79.140  45.693  1
70570  97.186  -79.149  45.675  1
70571  97.201  -79.165  45.657  1
70572  97.215  -79.183  45.640  1
70573  97.229  -79.200  45.624  1
70574  97.243  -79.216  45.607  1
70575  97.257  -79.234  45.591  1
70576  97.272  -79.250  45.574  1
70577  97.286  -79.267  45.557  1
70578  97.300  -79.284  45.541  1
70579  97.314  -79.301  45.526  1
70580  97.328  -79.318  45.511  1
70581  97.306  -79.350  45.495  1
70582  97.304  -79.357  45.479  1
70583  97.319  -79.350  45.464  1
70584  97.347  -79.338  45.449  1
70585  97.373  -79.325  45.433  1
70586  97.385  -79.313  45.418  1
70587  97.398  -79.302  45.404  1
70588  97.412  -79.290  45.389  1
70589  97.428  -79.285  45.374  1
70590  97.458  -79.342  45.360  1
70591  97.475  -79.388  45.345  1
70592  97.482  -79.397  45.331  1
70593  97.478  -79.400  45.317  1
70594  97.460  -79.397  45.303  1
70595  97.471  -79.390  45.290  1
70596  97.496  -79.382  45.276  1
70597  97.520  -79.375  45.263  1
70598  97.543  -79.368  45.250  1
70599  97.574  -79.370  45.237  1
70600  97.593  -79.386  45.224  1
70601  97.612  -79.401  45.212  1
70602  97.631  -79.416  45.199  1
70603  97.650  -79.432  45.187  1
70604  97.669  -79.447  45.174  1
70605  97.687  -79.463  45.162  1
70606  97.704  -79.481  45.150  1
70607  97.721  -79.498  45.138  1
70608  97.738  -79.515  45.126  1
70609  97.755  -79.532  45.114  1
70610  97.772  -79.549  45.103  1
70611  97.789  -79.567  45.091  1
70612  97.806  -79.583  45.080  1
70613  97.823  -79.601  45.068  1
70614  97.840  -79.617  45.056  1
70615  97.857  -79.635  45.044  1
70616  97.874  -79.652  45.031  1
70617  97.891  -79.669  45.018  1
70618  97.908  -79.686  45.006  1
70619  97.925  -79.703  44.992  1
70620  97.942  -79.720  44.980  1
70621  97.959  -79.737  44.967  1
70622  97.976  -79.755  44.955  1
70623  97.993  -79.771  44.942  1
70624  98.010  -79.789  44.931  1
70625  98.027  -79.806  44.919  1
70626  98.043  -79.823  44.909  1
70627  98.061  -79.840  44.899  1
70628  98.078  -79.856  44.889  1
70629  98.095  -79.872  44.879  1
70630  98.112  -79.888  44.870  1
70631  98.130  -79.905  44.860  1
70632  98.147  -79.921  44.852  1
70633  98.164  -79.936  44.843  1
70634  98.181  -79.952  44.834  1
70635  98.199  -79.968  44.825  1
70636  98.216  -79.984  44.817  1
70637  98.233  -80.000  44.809  1
70638  98.251  -80.016  44.801  1
70639  98.268  -80.032  44.794  1
70640  98.285  -80.048  44.787  1
70641  98.303  -80.064  44.780  1
70642  98.320  -80.080  44.772  1
70643  98.342  -80.095  44.764  1
70644  98.366  -80.109  44.758  1
70645  98.389  -80.123  44.751  1
70646  98.414  -80.137  44.745  1
70647  98.449  -80.125  44.739  1
70648  98.480  -80.133  44.733  1
70649  98.507  -80.148  44.726  1
70650  98.534  -80.162  44.722  1
70651  98.562  -80.178  44.717  1
70652  98.585  -80.184  44.711  1
70653  98.605  -80.189  44.707  1
70654  98.627  -80.193  44.702  1
70655  98.648  -80.198  44.697  1
70656  98.672  -80.201  44.692  1
70657  98.696  -80.203  44.688  1
70658  98.720  -80.206  44.682  1
70659  98.745  -80.213  44.674  1
70660  98.772  -80.224  44.659  1
70661  98.797  -80.234  44.645  1
70662  98.803  -80.240  44.632  1
70663  98.805  -80.243  44.619  1
70664  98.821  -80.253  44.611  1
70665  98.858  -80.262  44.603  1
70666  98.917  -80.271  44.595  1
70667  98.943  -80.283  44.589  1
70668  98.966  -80.294  44.582  1
70669  98.989  -80.304  44.575  1
70670  99.013  -80.315  44.569  1
70671  99.036  -80.325  44.564  1
70672  99.059  -80.336  44.559  1
70673  99.082  -80.347  44.554  1
70674  99.106  -80.356  44.549  1
70675  99.129  -80.367  44.544  1
70676  99.152  -80.378  44.538  1
70677  99.176  -80.388  44.533  1
70678  99.199  -80.399  44.529  1
70679  99.222  -80.410  44.525  1
70680  99.246  -80.420  44.521  1
70681  99.269  -80.431  44.518  1
70682  99.292  -80.441  44.514  1
70683  99.315  -80.452  44.510  1
70684  99.342  -80.461  44.507  1
70685  99.381  -80.465  44.503  1
71006  93.484  -78.995  53.465  1
71007  93.493  -78.993  53.454  1
71008  93.503  -78.990  53.444  1
71009  93.513  -78.987  53.434  1
71010  93.524  -78.977  53.424  1
71011  93.535  -78.968  53.415  1
71012  93.543  -78.961  53.406  1
71013  93.551  -78.954  53.397  1
71014  93.560  -78.946  53.390  1
71015  93.568  -78.940  53.383  1
71016  93.576  -78.933  53.377  1
71017  93.585  -78.926  53.371  1
71018  93.593  -78.919  53.365  1
71019  93.602  -78.912  53.359  1
71020  93.622  -78.893  53.353  1
71021  93.638  -78.891  53.348  1
71022  93.654  -78.889  53.343  1
71023  93.672  -78.886  53.338  1
71024  93.686  -78.884  53.329  1
71025  93.696  -78.883  53.322  1
71026  93.705  -78.882  53.316  1
71027  93.715  -78.880  53.311  1
71028  93.725  -78.880  53.304  1
71029  93.734  -78.878  53.296  1
71030  93.744  -78.877  53.287  1
71031  93.750  -78.877  53.278  1
71032  93.757  -78.877  53.268  1
71033  93.764  -78.877  53.258  1
71034  93.770  -78.877  53.246  1
71035  93.777  -78.874  53.235  1
71036  93.784  -78.872  53.224  1
71037  93.791  -78.870  53.213  1
71038  93.798  -78.868  53.202  1
71039  93.805  -78.865  53.190  1
71040  93.813  -78.861  53.178  1
71041  93.825  -78.849  53.163  1
71042  93.827  -78.850  53.148  1
71043  93.828  -78.852  53.133  1
71044  93.829  -78.853  53.116  1
71045  93.825  -78.848  53.098  1
71046  93.821  -78.843  53.080  1
71047  93.816  -78.837  53.061  1
71048  93.814  -78.832  53.038  1
71049  93.819  -78.827  53.014  1
71050  93.824  -78.824  52.990  1
71051  93.830  -78.819  52.964  1
71052  93.835  -78.814  52.939  1
71053  93.840  -78.810  52.914  1
71054  93.852  -78.805  52.889  1
71055  93.868  -78.798  52.861  1
71056  93.884  -78.792  52.834  1
71057  93.900  -78.786  52.808  1
71058  93.916  -78.780  52.783  1
71059  93.934  -78.778  52.756  1
71060  93.955  -78.780  52.730  1
71061  93.975  -78.783  52.704  1
71062  93.995  -78.785  52.677  1
71063  94.015  -78.787  52.653  1
71064  94.036  -78.789  52.630  1
71065  94.056  -78.792  52.606  1
71066  94.068  -78.788  52.583  1
71067  94.078  -78.784  52.560  1
71068  94.088  -78.780  52.537  1
71069  94.098  -78.777  52.513  1
71070  94.108  -78.773  52.489  1
71071  94.118  -78.769  52.463  1
71072  94.128  -78.765  52.437  1
71073  94.138  -78.761  52.413  1
71074  94.149  -78.758  52.389  1
71075  94.159  -78.753  52.366  1
71076  94.173  -78.754  52.339  1
71077  94.185  -78.752  52.312  1
71078  94.199  -78.749  52.286  1
71079  94.213  -78.746  52.258  1
71080  94.226  -78.744  52.233  1
71081  94.242  -78.737  52.207  1
71082  94.258  -78.727  52.181  1
71083  94.275  -78.717  52.152  1
71084  94.284  -78.714  52.123  1
71085  94.293  -78.712  52.094  1
71086  94.301  -78.710  52.064  1
71087  94.310  -78.708  52.035  1
71088  94.319  -78.705  52.007  1
71089  94.328  -78.703  51.979  1
71090  94.336  -78.701  51.949  1
71091  94.347  -78.701  51.918  1
71092  94.363  -78.702  51.888  1
71093  94.378  -78.705  51.857  1
71094  94.391  -78.710  51.826  1
71095  94.404  -78.715  51.795  1
71096  94.417  -78.720  51.764  1
71097  94.430  -78.724  51.733  1
71098  94.447  -78.717  51.702  1
71099  94.464  -78.721  51.671  1
71100  94.481  -78.726  51.641  1
71101  94.499  -78.730  51.611  1
71102  94.516  -78.735  51.581  1
71103  94.541  -78.741  51.549  1
71104  94.568  -78.748  51.514  1
71105  94.596  -78.755  51.477  1
71106  94.623  -78.761  51.441  1
71107  94.650  -78.768  51.406  1
71108  94.677  -78.775  51.372  1
71109  94.704  -78.783  51.338  1
71110  94.732  -78.789  51.304  1
71111  94.755  -78.795  51.270  1
71112  94.773  -78.796  51.234  1
71113  94.784  -78.795  51.198  1
71114  94.783  -78.792  51.162  1
71115  94.779  -78.793  51.126  1
71116  94.775  -78.794  51.091  1
71117  94.771  -78.796  51.055  1
71118  94.768  -78.796  51.020  1
71119  94.764  -78.798  50.984  1
71120  94.747  -78.789  50.946  1
71121  94.724  -78.779  50.906  1
71122  94.705  -78.773  50.865  1
71123  94.693  -78.790  50.822  1
71124  94.695  -78.793  50.781  1
71125  94.714  -78.781  50.739  1
71126  94.741  -78.771  50.696  1
71127  94.772  -78.763  50.653  1
71128  94.803  -78.755  50.610  1
71129  94.821  -78.752  50.567  1
71130  94.839  -78.749  50.527  1
71131  94.857  -78.745  50.485  1
71132  94.875  -78.742  50.444  1
71133  94.884  -78.749  50.404  1
71134  94.883  -78.764  50.367  1
71135  94.882  -78.779  50.330  1
71136  94.880  -78.795  50.293  1
71137  94.879  -78.810  50.256  1
71138  94.878  -78.826  50.217  1
71139  94.877  -78.841  50.179  1
71140  94.871  -78.845  50.141  1
71141  94.862  -78.844  50.102  1
71142  94.854  -78.843  50.062  1
71143  94.847  -78.843  50.023  1
71144  94.839  -78.843  49.984  1
71145  94.856  -78.846  49.944  1
71146  94.873  -78.849  49.903  1
71147  94.890  -78.852  49.863  1
71148  94.906  -78.855  49.821  1
71149  94.923  -78.858  49.781  1
71150  94.939  -78.861  49.744  1
71151  94.957  -78.864  49.708  1
71152  94.973  -78.868  49.674  1
71153  94.989  -78.886  49.639  1
71154  95.012  -78.895  49.603  1
71155  95.041  -78.902  49.565  1
71156  95.070  -78.908  49.527  1
71157  95.100  -78.915  49.490  1
71158  95.129  -78.922  49.449  1
71159  95.158  -78.929  49.408  1
71160  95.188  -78.936  49.366  1
71161  95.217  -78.943  49.325  1
71162  95.246  -78.949  49.288  1
71163  95.276  -78.956  49.250  1
71164  95.305  -78.963  49.210  1
71165  95.330  -78.965  49.168  1
71166  95.355  -78.968  49.127  1
71167  95.379  -78.970  49.086  1
71168  95.395  -78.974  49.044  1
71169  95.404  -78.981  49.001  1
71170  95.412  -78.986  48.958  1
71171  95.421  -78.992  48.915  1
71172  95.429  -78.998  48.871  1
71173  95.435  -79.012  48.827  1
71174  95.440  -79.033  48.784  1
71175  95.445  -79.053  48.740  1
71176  95.449  -79.073  48.697  1
71177  95.454  -79.093  48.653  1
71178  95.458  -79.113  48.608  1
71179  95.463  -79.133  48.566  1
71180  95.467  -79.153  48.523  1
71181  95.472  -79.173  48.479  1
71182  95.475  -79.190  48.435  1
71183  95.488  -79.206  48.391  1
71184  95.513  -79.197  48.347  1
71185  95.535  -79.184  48.302  1
71186  95.557  -79.171  48.257  1
71187  95.580  -79.158  48.213  1
71188  95.603  -79.144  48.170  1
71189  95.625  -79.131  48.127  1
71190  95.648  -79.118  48.083  1
71191  95.670  -79.105  48.039  1
71192  95.693  -79.092  47.995  1
71193  95.714  -79.080  47.949  1
71194  95.736  -79.081  47.905  1
71195  95.756  -79.085  47.862  1
71196  95.768  -79.086  47.820  1
71197  95.780  -79.087  47.778  1
71198  95.793  -79.087  47.736  1
71199  95.805  -79.088  47.695  1
71200  95.817  -79.089  47.654  1
71201  95.830  -79.090  47.613  1
71202  95.842  -79.090  47.572  1
71203  95.854  -79.091  47.533  1
71204  95.867  -79.092  47.494  1
71205  95.883  -79.106  47.453  1
71206  95.903  -79.128  47.414  1
71207  95.923  -79.149  47.375  1
71208  95.930  -79.150  47.336  1
71209  95.986  -79.131  47.298  1
71210  96.029  -79.115  47.260  1
71211  96.063  -79.103  47.222  1
71212  96.098  -79.090  47.184  1
71213  96.132  -79.078  47.148  1
71214  96.166  -79.065  47.112  1
71215  96.200  -79.052  47.077  1
71216  96.235  -79.039  47.043  1
71217  96.269  -79.026  47.010  1
71218  96.303  -79.014  46.977  1
71219  96.337  -79.001  46.944  1
71220  96.367  -79.034  46.914  1
71221  96.396  -79.080  46.883  1
71222  96.424  -79.126  46.851  1
71223  96.453  -79.172  46.819  1
71224  96.468  -79.174  46.788  1
71225  96.482  -79.174  46.756  1
71226  96.498  -79.175  46.724  1
71227  96.512  -79.175  46.693  1
71228  96.527  -79.175  46.662  1
71229  96.544  -79.180  46.632  1
71230  96.568  -79.191  46.602  1
71231  96.573  -79.181  46.571  1
71232  96.600  -79.178  46.541  1
71233  96.632  -79.179  46.513  1
71234  96.655  -79.182  46.483  1
71235  96.678  -79.184  46.455  1
71236  96.701  -79.187  46.428  1
71237  96.724  -79.190  46.400  1
71238  96.746  -79.192  46.374  1
71239  96.769  -79.194  46.348  1
71240  96.792  -79.197  46.320  1
71241  96.815  -79.200  46.295  1
71242  96.837  -79.202  46.269  1
71243  96.857  -79.182  46.243  1
71244  96.875  -79.161  46.218  1
71245  96.896  -79.143  46.193  1
71246  96.933  -79.153  46.169  1
71247  96.945  -79.178  46.146  1
71248  96.930  -79.212  46.123  1
71249  96.965  -79.176  46.099  1
71250  97.001  -79.140  46.075  1
71251  97.037  -79.118  46.053  1
71252  97.079  -79.163  46.033  1
71253  97.090  -79.178  46.014  1
71254  97.085  -79.179  45.994  1
71255  97.081  -79.180  45.974  1
71256  97.081  -79.181  45.955  1
71257  97.091  -79.181  45.935  1
71258  97.100  -79.181  45.916  1
71259  97.109  -79.182  45.897  1
71260  97.118  -79.187  45.879  1
71261  97.133  -79.187  45.859  1
71262  97.146  -79.184  45.840  1
71263  97.168  -79.169  45.822  1
71264  97.169  -79.162  45.804  1
71265  97.171  -79.155  45.784  1
71266  97.173  -79.147  45.766  1
71267  97.174  -79.145  45.749  1
71268  97.175  -79.144  45.731  1
71269  97.176  -79.143  45.714  1
71270  97.177  -79.142  45.696  1
71271  97.195  -79.138  45.679  1
71272  97.218  -79.148  45.660  1
71273  97.232  -79.165  45.643  1
71274  97.246  -79.182  45.627  1
71275  97.260  -79.199  45.611  1
71276  97.275  -79.216  45.595  1
71277  97.289  -79.233  45.578  1
71278  97.303  -79.250  45.562  1
71279  97.317  -79.266  45.546  1
71280  97.331  -79.284  45.530  1
71281  97.346  -79.300  45.515  1
71282  97.296  -79.344  45.500  1
71283  97.308  -79.340  45.485  1
71284  97.323  -79.334  45.469  1
71285  97.344  -79.325  45.454  1
71286  97.372  -79.311  45.438  1
71287  97.385  -79.300  45.424  1
71288  97.397  -79.288  45.409  1
71289  97.411  -79.277  45.395  1
71290  97.438  -79.288  45.381  1
71291  97.469  -79.368  45.367  1
71292  97.474  -79.375  45.352  1
71293  97.480  -79.383  45.338  1
71294  97.489  -79.392  45.324  1
71295  97.496  -79.400  45.310  1
71296  97.505  -79.394  45.297  1
71297  97.527  -79.385  45.284  1
71298  97.543  -79.373  45.270  1
71299  97.558  -79.361  45.258  1
71300  97.562  -79.357  45.245  1
71301  97.567  -79.367  45.232  1
71302  97.582  -79.398  45.220  1
71303  97.599  -79.415  45.207  1
71304  97.616  -79.432  45.195  1
71305  97.633  -79.449  45.182  1
71306  97.650  -79.466  45.170  1
71307  97.667  -79.483  45.158  1
71308  97.684  -79.501  45.146  1
71309  97.701  -79.518  45.135  1
71310  97.718  -79.535  45.123  1
71311  97.735  -79.552  45.112  1
71312  97.752  -79.569  45.101  1
71313  97.769  -79.586  45.089  1
71314  97.786  -79.603  45.077  1
71315  97.803  -79.620  45.064  1
71316  97.820  -79.637  45.052  1
71317  97.837  -79.654  45.040  1
71318  97.854  -79.671  45.027  1
71319  97.871  -79.687  45.016  1
71320  97.888  -79.703  45.002  1
71321  97.906  -79.719  44.989  1
71322  97.923  -79.735  44.977  1
71323  97.941  -79.751  44.964  1
71324  97.958  -79.767  44.952  1
71325  97.975  -79.783  44.941  1
71326  97.993  -79.798  44.930  1
71327  98.010  -79.814  44.920  1
71328  98.027  -79.830  44.910  1
71329  98.044  -79.846  44.900  1
71330  98.062  -79.863  44.890  1
71331  98.079  -79.879  44.881  1
71332  98.096  -79.895  44.872  1
71333  98.113  -79.911  44.863  1
71334  98.131  -79.927  44.854  1
71335  98.148  -79.943  44.845  1
71336  98.165  -79.958  44.837  1
71337  98.182  -79.974  44.830  1
71338  98.200  -79.990  44.823  1
71339  98.217  -80.006  44.815  1
71340  98.238  -80.021  44.807  1
71341  98.262  -80.036  44.800  1
71342  98.286  -80.050  44.793  1
71343  98.309  -80.065  44.786  1
71344  98.333  -80.078  44.780  1
71345  98.357  -80.093  44.774  1
71346  98.385  -80.098  44.768  1
71347  98.429  -80.071  44.760  1
71348  98.456  -80.087  44.753  1
71349  98.484  -80.102  44.747  1
71350  98.511  -80.116  44.741  1
71351  98.538  -80.131  44.737  1
71352  98.566  -80.146  44.731  1
71353  98.592  -80.158  44.725  1
71354  98.615  -80.161  44.719  1
71355  98.640  -80.164  44.715  1
71356  98.664  -80.167  44.710  1
71357  98.688  -80.169  44.705  1
71358  98.712  -80.172  44.700  1
71359  98.737  -80.178  44.694  1
71360  98.763  -80.187  44.685  1
71361  98.789  -80.198  44.670  1
71362  98.810  -80.209  44.655  1
71363  98.819  -80.210  44.642  1
71364  98.822  -80.212  44.630  1
71365  98.834  -80.221  44.622  1
71366  98.850  -80.232  44.614  1
71367  98.869  -80.243  44.606  1
71368  98.917  -80.243  44.599  1
71369  98.970  -80.266  44.592  1
71370  98.993  -80.277  44.585  1
71371  99.017  -80.287  44.580  1
71372  99.040  -80.298  44.574  1
71373  99.063  -80.309  44.568  1
71374  99.086  -80.319  44.564  1
71375  99.110  -80.330  44.558  1
71376  99.133  -80.340  44.553  1
71377  99.156  -80.350  44.548  1
71378  99.180  -80.361  44.542  1
71379  99.203  -80.372  44.538  1
71380  99.226  -80.382  44.534  1
71381  99.250  -80.393  44.530  1
71382  99.273  -80.403  44.528  1
71383  99.296  -80.414  44.525  1
71384  99.320  -80.425  44.521  1
71385  99.353  -80.431  44.516  1
71386  99.392  -80.435  44.513  1
71387  99.430  -80.438  44.509  1
71388  99.469  -80.442  44.506  1
71708  93.494  -78.981  53.473  1
71709  93.503  -78.979  53.462  1
71710  93.513  -78.977  53.452  1
71711  93.523  -78.973  53.442  1
71712  93.535  -78.962  53.433  1
71713  93.544  -78.954  53.424  1
71714  93.552  -78.947  53.415  1
71715  93.561  -78.940  53.407  1
71716  93.569  -78.933  53.399  1
71717  93.577  -78.927  53.392  1
71718  93.586  -78.919  53.385  1
71719  93.594  -78.912  53.378  1
71720  93.603  -78.905  53.371  1
71721  93.655  -78.879  53.365  1
71722  93.638  -78.875  53.359  1
71723  93.655  -78.873  53.354  1
71724  93.672  -78.871  53.349  1
71725  93.682  -78.869  53.342  1
71726  93.692  -78.868  53.336  1
71727  93.701  -78.868  53.331  1
71728  93.711  -78.866  53.325  1
71729  93.720  -78.865  53.320  1
71730  93.730  -78.864  53.314  1
71731  93.740  -78.863  53.305  1
71732  93.746  -78.863  53.297  1
71733  93.753  -78.863  53.287  1
71734  93.760  -78.861  53.277  1
71735  93.767  -78.858  53.265  1
71736  93.774  -78.855  53.254  1
71737  93.781  -78.853  53.242  1
71738  93.788  -78.851  53.230  1
71739  93.795  -78.849  53.219  1
71740  93.802  -78.846  53.207  1
71741  93.809  -78.844  53.194  1
71742  93.819  -78.835  53.178  1
71743  93.821  -78.836  53.162  1
71744  93.820  -78.836  53.147  1
71745  93.816  -78.831  53.130  1
71746  93.812  -78.826  53.111  1
71747  93.816  -78.821  53.091  1
71748  93.821  -78.817  53.071  1
71749  93.826  -78.812  53.048  1
71750  93.831  -78.808  53.023  1
71751  93.837  -78.803  52.999  1
71752  93.842  -78.799  52.973  1
71753  93.847  -78.795  52.947  1
71754  93.852  -78.790  52.922  1
71755  93.867  -78.784  52.897  1
71756  93.884  -78.777  52.869  1
71757  93.899  -78.771  52.842  1
71758  93.915  -78.765  52.815  1
71759  93.931  -78.758  52.790  1
71760  93.947  -78.752  52.764  1
71761  93.963  -78.746  52.738  1
71762  93.982  -78.746  52.714  1
71763  94.002  -78.748  52.688  1
71764  94.023  -78.750  52.664  1
71765  94.043  -78.752  52.642  1
71766  94.063  -78.755  52.618  1
71767  94.076  -78.752  52.595  1
71768  94.086  -78.749  52.573  1
71769  94.097  -78.745  52.551  1
71770  94.107  -78.741  52.527  1
71771  94.117  -78.737  52.503  1
71772  94.127  -78.733  52.477  1
71773  94.137  -78.729  52.451  1
71774  94.145  -78.730  52.426  1
71775  94.149  -78.737  52.402  1
71776  94.169  -78.730  52.379  1
71777  94.196  -78.734  52.352  1
71778  94.206  -78.731  52.325  1
71779  94.216  -78.729  52.298  1
71780  94.227  -78.726  52.272  1
71781  94.242  -78.724  52.247  1
71782  94.256  -78.720  52.222  1
71783  94.272  -78.709  52.195  1
71784  94.283  -78.705  52.167  1
71785  94.291  -78.703  52.139  1
71786  94.300  -78.701  52.109  1
71787  94.309  -78.698  52.079  1
71788  94.318  -78.696  52.051  1
71789  94.326  -78.694  52.023  1
71790  94.335  -78.692  51.996  1
71791  94.343  -78.689  51.966  1
71792  94.352  -78.687  51.936  1
71793  94.368  -78.689  51.905  1
71794  94.382  -78.694  51.874  1
71795  94.395  -78.698  51.842  1
71796  94.408  -78.703  51.811  1
71797  94.421  -78.708  51.781  1
71798  94.434  -78.713  51.750  1
71799  94.449  -78.708  51.718  1
71800  94.467  -78.713  51.687  1
71801  94.484  -78.717  51.656  1
71802  94.501  -78.721  51.626  1
71803  94.526  -78.727  51.596  1
71804  94.553  -78.734  51.564  1
71805  94.580  -78.742  51.528  1
71806  94.607  -78.749  51.491  1
71807  94.634  -78.755  51.454  1
71808  94.662  -78.762  51.419  1
71809  94.687  -78.768  51.385  1
71810  94.705  -78.771  51.352  1
71811  94.723  -78.772  51.318  1
71812  94.741  -78.774  51.284  1
71813  94.759  -78.777  51.250  1
71814  94.770  -78.779  51.215  1
71815  94.778  -78.774  51.178  1
71816  94.784  -78.764  51.142  1
71817  94.783  -78.761  51.106  1
71818  94.779  -78.762  51.069  1
71819  94.775  -78.764  51.032  1
71820  94.772  -78.764  50.995  1
71821  94.756  -78.758  50.957  1
71822  94.734  -78.747  50.918  1
71823  94.721  -78.762  50.878  1
71824  94.710  -78.779  50.836  1
71825  94.711  -78.783  50.796  1
71826  94.730  -78.771  50.753  1
71827  94.749  -78.758  50.709  1
71828  94.777  -78.749  50.667  1
71829  94.801  -78.745  50.625  1
71830  94.819  -78.741  50.582  1
71831  94.837  -78.738  50.541  1
71832  94.855  -78.735  50.499  1
71833  94.873  -78.731  50.457  1
71834  94.883  -78.736  50.415  1
71835  94.881  -78.752  50.375  1
71836  94.880  -78.767  50.336  1
71837  94.879  -78.783  50.299  1
71838  94.878  -78.799  50.263  1
71839  94.877  -78.814  50.226  1
71840  94.876  -78.830  50.188  1
71841  94.874  -78.845  50.152  1
71842  94.867  -78.846  50.114  1
71843  94.859  -78.846  50.076  1
71844  94.851  -78.846  50.037  1
71845  94.843  -78.845  49.998  1
71846  94.857  -78.848  49.958  1
71847  94.874  -78.851  49.917  1
71848  94.890  -78.854  49.876  1
71849  94.907  -78.857  49.834  1
71850  94.924  -78.860  49.793  1
71851  94.941  -78.863  49.755  1
71852  94.957  -78.866  49.719  1
71853  94.974  -78.869  49.685  1
71854  94.998  -78.868  49.650  1
71855  95.028  -78.874  49.614  1
71856  95.057  -78.880  49.575  1
71857  95.087  -78.886  49.537  1
71858  95.116  -78.893  49.498  1
71859  95.145  -78.900  49.456  1
71860  95.175  -78.907  49.415  1
71861  95.204  -78.914  49.374  1
71862  95.234  -78.921  49.334  1
71863  95.263  -78.927  49.295  1
71864  95.292  -78.934  49.257  1
71865  95.322  -78.941  49.217  1
71866  95.349  -78.946  49.176  1
71867  95.374  -78.949  49.135  1
71868  95.396  -78.952  49.095  1
71869  95.404  -78.958  49.051  1
71870  95.413  -78.963  49.009  1
71871  95.421  -78.969  48.967  1
71872  95.429  -78.975  48.924  1
71873  95.438  -78.981  48.880  1
71874  95.446  -78.991  48.837  1
71875  95.450  -79.011  48.795  1
71876  95.455  -79.031  48.753  1
71877  95.459  -79.051  48.710  1
71878  95.464  -79.071  48.666  1
71879  95.468  -79.091  48.622  1
71880  95.473  -79.112  48.578  1
71881  95.478  -79.131  48.535  1
71882  95.482  -79.152  48.492  1
71883  95.487  -79.172  48.447  1
71884  95.491  -79.192  48.403  1
71885  95.511  -79.187  48.358  1
71886  95.533  -79.173  48.313  1
71887  95.556  -79.160  48.268  1
71888  95.578  -79.147  48.223  1
71889  95.601  -79.134  48.179  1
71890  95.623  -79.120  48.134  1
71891  95.645  -79.107  48.090  1
71892  95.668  -79.094  48.045  1
71893  95.690  -79.081  48.000  1
71894  95.712  -79.068  47.955  1
71895  95.728  -79.063  47.911  1
71896  95.740  -79.064  47.867  1
71897  95.752  -79.065  47.824  1
71898  95.764  -79.065  47.782  1
71899  95.776  -79.066  47.741  1
71900  95.789  -79.067  47.699  1
71901  95.801  -79.068  47.657  1
71902  95.813  -79.068  47.616  1
71903  95.825  -79.069  47.575  1
71904  95.838  -79.070  47.537  1
71905  95.850  -79.071  47.497  1
71906  95.862  -79.071  47.457  1
71907  95.881  -79.090  47.418  1
71908  95.901  -79.112  47.378  1
71909  95.921  -79.134  47.338  1
71910  95.947  -79.106  47.300  1
71911  96.035  -79.106  47.261  1
71912  96.072  -79.101  47.223  1
71913  96.106  -79.089  47.186  1
71914  96.140  -79.076  47.149  1
71915  96.174  -79.063  47.114  1
71916  96.208  -79.050  47.079  1
71917  96.243  -79.037  47.043  1
71918  96.277  -79.024  47.011  1
71919  96.311  -79.012  46.978  1
71920  96.345  -78.999  46.945  1
71921  96.375  -79.034  46.914  1
71922  96.404  -79.079  46.883  1
71923  96.432  -79.125  46.852  1
71924  96.455  -79.153  46.820  1
71925  96.470  -79.153  46.789  1
71926  96.484  -79.153  46.758  1
71927  96.499  -79.154  46.726  1
71928  96.514  -79.154  46.696  1
71929  96.532  -79.159  46.664  1
71930  96.556  -79.172  46.632  1
71931  96.580  -79.183  46.601  1
71932  96.593  -79.184  46.570  1
71933  96.591  -79.166  46.541  1
71934  96.608  -79.159  46.514  1
71935  96.645  -79.159  46.484  1
71936  96.681  -79.160  46.457  1
71937  96.709  -79.162  46.430  1
71938  96.731  -79.165  46.402  1
71939  96.754  -79.167  46.376  1
71940  96.777  -79.169  46.350  1
71941  96.800  -79.172  46.323  1
71942  96.822  -79.175  46.297  1
71943  96.846  -79.177  46.271  1
71944  96.865  -79.159  46.245  1
71945  96.883  -79.137  46.220  1
71946  96.916  -79.142  46.196  1
71947  96.919  -79.173  46.172  1
71948  96.899  -79.212  46.149  1
71949  96.935  -79.176  46.126  1
71950  96.970  -79.140  46.103  1
71951  97.006  -79.103  46.079  1
71952  97.044  -79.112  46.056  1
71953  97.087  -79.158  46.036  1
71954  97.093  -79.169  46.016  1
71955  97.088  -79.169  45.996  1
71956  97.084  -79.170  45.977  1
71957  97.080  -79.171  45.958  1
71958  97.086  -79.172  45.939  1
71959  97.096  -79.172  45.919  1
71960  97.105  -79.172  45.901  1
71961  97.114  -79.173  45.883  1
71962  97.124  -79.175  45.864  1
71963  97.145  -79.163  45.845  1
71964  97.164  -79.151  45.826  1
71965  97.171  -79.142  45.808  1
71966  97.171  -79.143  45.788  1
71967  97.172  -79.143  45.770  1
71968  97.173  -79.143  45.753  1
71969  97.173  -79.144  45.737  1
71970  97.174  -79.145  45.719  1
71971  97.175  -79.148  45.702  1
71972  97.185  -79.143  45.684  1
71973  97.223  -79.141  45.665  1
71974  97.249  -79.148  45.648  1
71975  97.263  -79.165  45.633  1
71976  97.278  -79.181  45.617  1
71977  97.292  -79.199  45.600  1
71978  97.306  -79.216  45.584  1
71979  97.320  -79.232  45.568  1
71980  97.334  -79.250  45.552  1
71981  97.349  -79.266  45.536  1
71982  97.341  -79.292  45.521  1
71983  97.296  -79.330  45.506  1
71984  97.312  -79.324  45.491  1
71985  97.327  -79.317  45.475  1
71986  97.343  -79.311  45.460  1
71987  97.371  -79.297  45.445  1
71988  97.384  -79.286  45.430  1
71989  97.397  -79.274  45.416  1
71990  97.421  -79.281  45.402  1
71991  97.449  -79.298  45.388  1
71992  97.468  -79.354  45.374  1
71993  97.474  -79.363  45.359  1
71994  97.479  -79.370  45.345  1
71995  97.486  -79.379  45.331  1
71996  97.495  -79.388  45.317  1
71997  97.510  -79.380  45.305  1
71998  97.526  -79.368  45.292  1
71999  97.536  -79.359  45.278  1
72000  97.540  -79.354  45.266  1
72001  97.544  -79.350  45.253  1
72002  97.547  -79.345  45.240  1
72003  97.551  -79.341  45.228  1
72004  97.559  -79.438  45.215  1
72005  97.575  -79.462  45.203  1
72006  97.596  -79.452  45.191  1
72007  97.613  -79.469  45.178  1
72008  97.630  -79.485  45.167  1
72009  97.648  -79.501  45.155  1
72010  97.665  -79.517  45.144  1
72011  97.682  -79.534  45.134  1
72012  97.700  -79.550  45.122  1
72013  97.717  -79.566  45.110  1
72014  97.734  -79.582  45.098  1
72015  97.751  -79.598  45.086  1
72016  97.769  -79.614  45.074  1
72017  97.786  -79.629  45.062  1
72018  97.803  -79.645  45.049  1
72019  97.820  -79.661  45.037  1
72020  97.838  -79.677  45.025  1
72021  97.855  -79.693  45.011  1
72022  97.872  -79.709  44.999  1
72023  97.890  -79.725  44.988  1
72024  97.907  -79.741  44.975  1
72025  97.924  -79.757  44.963  1
72026  97.942  -79.773  44.952  1
72027  97.959  -79.789  44.941  1
72028  97.976  -79.805  44.931  1
72029  97.994  -79.821  44.921  1
72030  98.011  -79.837  44.912  1
72031  98.028  -79.853  44.903  1
72032  98.045  -79.869  44.893  1
72033  98.063  -79.885  44.884  1
72034  98.080  -79.901  44.877  1
72035  98.097  -79.917  44.868  1
72036  98.114  -79.933  44.860  1
72037  98.134  -79.948  44.852  1
72038  98.158  -79.962  44.845  1
72039  98.181  -79.977  44.838  1
72040  98.205  -79.991  44.831  1
72041  98.229  -80.005  44.823  1
72042  98.253  -80.020  44.817  1
72043  98.276  -80.034  44.810  1
72044  98.302  -80.047  44.804  1
72045  98.334  -80.046  44.796  1
72046  98.346  -80.048  44.790  1
72047  98.387  -80.033  44.783  1
72048  98.434  -80.044  44.775  1
72049  98.462  -80.059  44.768  1
72050  98.489  -80.074  44.762  1
72051  98.517  -80.089  44.757  1
72052  98.544  -80.104  44.752  1
72053  98.572  -80.119  44.746  1
72054  98.600  -80.127  44.739  1
72055  98.630  -80.130  44.731  1
72056  98.655  -80.133  44.727  1
72057  98.679  -80.135  44.723  1
72058  98.704  -80.138  44.717  1
72059  98.728  -80.142  44.711  1
72060  98.754  -80.152  44.704  1
72061  98.776  -80.163  44.694  1
72062  98.789  -80.177  44.679  1
72063  98.808  -80.188  44.665  1
72064  98.831  -80.187  44.652  1
72065  98.839  -80.182  44.641  1
72066  98.847  -80.188  44.632  1
72067  98.863  -80.200  44.624  1
72068  98.880  -80.211  44.616  1
72069  98.896  -80.222  44.609  1
72070  98.929  -80.231  44.602  1
72071  98.997  -80.250  44.596  1
72072  99.021  -80.260  44.590  1
72073  99.044  -80.271  44.584  1
72074  99.067  -80.281  44.579  1
72075  99.090  -80.292  44.573  1
72076  99.114  -80.303  44.568  1
72077  99.137  -80.312  44.563  1
72078  99.160  -80.323  44.557  1
72079  99.184  -80.334  44.552  1
72080  99.207  -80.344  44.548  1
72081  99.230  -80.355  44.544  1
72082  99.254  -80.366  44.540  1
72083  99.277  -80.376  44.537  1
72084  99.300  -80.387  44.534  1
72085  99.326  -80.397  44.530  1
72086  99.364  -80.400  44.526  1
72087  99.403  -80.404  44.523  1
72088  99.441  -80.408  44.520  1
72089  99.480  -80.413  44.516  1
72090  99.518  -80.416  44.512  1
72091  99.557  -80.420  44.509  1
72410  93.504  -78.968  53.481  1
72411  93.513  -78.965  53.470  1
72412  93.523  -78.963  53.460  1
72413  93.533  -78.959  53.450  1
72414  93.545  -78.949  53.441  1
72415  93.554  -78.940  53.432  1
72416  93.562  -78.933  53.423  1
72417  93.570  -78.927  53.415  1
72418  93.578  -78.920  53.408  1
72419  93.587  -78.913  53.399  1
72420  93.595  -78.906  53.391  1
72421  93.604  -78.899  53.384  1
72422  93.643  -78.878  53.377  1
72423  93.660  -78.860  53.371  1
72424  93.656  -78.858  53.366  1
72425  93.668  -78.856  53.361  1
72426  93.678  -78.855  53.356  1
72427  93.688  -78.854  53.351  1
72428  93.697  -78.852  53.346  1
72429  93.707  -78.852  53.341  1
72430  93.716  -78.850  53.336  1
72431  93.726  -78.849  53.330  1
72432  93.736  -78.848  53.322  1
72433  93.743  -78.846  53.313  1
72434  93.750  -78.844  53.304  1
72435  93.757  -78.842  53.295  1
72436  93.764  -78.839  53.283  1
72437  93.771  -78.837  53.271  1
72438  93.778  -78.835  53.259  1
72439  93.785  -78.833  53.247  1
72440  93.792  -78.830  53.236  1
72441  93.799  -78.827  53.223  1
72442  93.806  -78.825  53.209  1
72443  93.813  -78.821  53.193  1
72444  93.811  -78.819  53.176  1
72445  93.812  -78.814  53.157  1
72446  93.818  -78.810  53.140  1
72447  93.823  -78.805  53.120  1
72448  93.828  -78.801  53.101  1
72449  93.833  -78.796  53.081  1
72450  93.839  -78.793  53.057  1
72451  93.844  -78.788  53.033  1
72452  93.849  -78.783  53.007  1
72453  93.854  -78.779  52.981  1
72454  93.860  -78.774  52.954  1
72455  93.867  -78.770  52.929  1
72456  93.883  -78.764  52.904  1
72457  93.899  -78.757  52.876  1
72458  93.915  -78.751  52.849  1
72459  93.930  -78.745  52.822  1
72460  93.946  -78.738  52.797  1
72461  93.963  -78.732  52.772  1
72462  93.978  -78.726  52.747  1
72463  93.994  -78.719  52.723  1
72464  94.010  -78.713  52.699  1
72465  94.030  -78.714  52.675  1
72466  94.050  -78.716  52.653  1
72467  94.070  -78.718  52.630  1
72468  94.084  -78.717  52.607  1
72469  94.095  -78.713  52.585  1
72470  94.105  -78.709  52.563  1
72471  94.115  -78.705  52.540  1
72472  94.125  -78.701  52.516  1
72473  94.130  -78.707  52.491  1
72474  94.134  -78.715  52.465  1
72475  94.139  -78.723  52.439  1
72476  94.153  -78.702  52.414  1
72477  94.205  -78.715  52.391  1
72478  94.219  -78.714  52.365  1
72479  94.229  -78.711  52.338  1
72480  94.239  -78.708  52.311  1
72481  94.249  -78.706  52.286  1
72482  94.259  -78.703  52.262  1
72483  94.270  -78.701  52.238  1
72484  94.281  -78.696  52.212  1
72485  94.290  -78.694  52.183  1
72486  94.299  -78.692  52.154  1
72487  94.308  -78.689  52.125  1
72488  94.316  -78.687  52.096  1
72489  94.325  -78.685  52.069  1
72490  94.334  -78.683  52.042  1
72491  94.342  -78.680  52.014  1
72492  94.351  -78.678  51.986  1
72493  94.359  -78.676  51.956  1
72494  94.372  -78.677  51.927  1
72495  94.385  -78.683  51.895  1
72496  94.398  -78.687  51.863  1
72497  94.411  -78.692  51.831  1
72498  94.424  -78.696  51.799  1
72499  94.437  -78.702  51.769  1
72500  94.452  -78.700  51.739  1
72501  94.469  -78.704  51.708  1
72502  94.486  -78.708  51.675  1
72503  94.509  -78.714  51.642  1
72504  94.537  -78.721  51.609  1
72505  94.564  -78.728  51.576  1
72506  94.591  -78.735  51.541  1
72507  94.618  -78.742  51.503  1
72508  94.636  -78.744  51.467  1
72509  94.654  -78.745  51.432  1
72510  94.672  -78.748  51.398  1
72511  94.690  -78.750  51.364  1
72512  94.708  -78.752  51.332  1
72513  94.726  -78.755  51.298  1
72514  94.745  -78.757  51.265  1
72515  94.755  -78.759  51.232  1
72516  94.766  -78.761  51.196  1
72517  94.773  -78.754  51.159  1
72518  94.779  -78.744  51.124  1
72519  94.784  -78.733  51.085  1
72520  94.783  -78.730  51.046  1
72521  94.779  -78.732  51.006  1
72522  94.765  -78.726  50.968  1
72523  94.750  -78.734  50.930  1
72524  94.739  -78.751  50.891  1
72525  94.727  -78.767  50.850  1
72526  94.726  -78.774  50.810  1
72527  94.745  -78.761  50.767  1
72528  94.764  -78.749  50.722  1
72529  94.781  -78.736  50.680  1
72530  94.799  -78.733  50.638  1
72531  94.817  -78.730  50.596  1
72532  94.835  -78.727  50.555  1
72533  94.853  -78.724  50.513  1
72534  94.872  -78.720  50.471  1
72535  94.881  -78.725  50.427  1
72536  94.880  -78.740  50.384  1
72537  94.879  -78.756  50.344  1
72538  94.878  -78.771  50.306  1
72539  94.877  -78.786  50.271  1
72540  94.875  -78.802  50.234  1
72541  94.874  -78.818  50.198  1
72542  94.873  -78.833  50.161  1
72543  94.872  -78.849  50.124  1
72544  94.864  -78.849  50.087  1
72545  94.856  -78.848  50.048  1
72546  94.848  -78.848  50.008  1
72547  94.857  -78.849  49.969  1
72548  94.875  -78.852  49.929  1
72549  94.891  -78.855  49.888  1
72550  94.908  -78.858  49.846  1
72551  94.924  -78.861  49.805  1
72552  94.942  -78.865  49.767  1
72553  94.958  -78.868  49.731  1
72554  94.987  -78.863  49.696  1
72555  95.016  -78.858  49.660  1
72556  95.045  -78.858  49.623  1
72557  95.074  -78.865  49.584  1
72558  95.103  -78.870  49.544  1
72559  95.132  -78.876  49.505  1
72560  95.162  -78.881  49.462  1
72561  95.191  -78.887  49.421  1
72562  95.220  -78.893  49.380  1
72563  95.250  -78.899  49.341  1
72564  95.279  -78.906  49.302  1
72565  95.309  -78.913  49.263  1
72566  95.338  -78.920  49.224  1
72567  95.368  -78.927  49.183  1
72568  95.393  -78.930  49.142  1
72569  95.405  -78.935  49.101  1
72570  95.413  -78.940  49.057  1
72571  95.421  -78.946  49.016  1
72572  95.430  -78.952  48.975  1
72573  95.439  -78.958  48.932  1
72574  95.447  -78.964  48.889  1
72575  95.456  -78.970  48.847  1
72576  95.460  -78.990  48.805  1
72577  95.465  -79.009  48.763  1
72578  95.469  -79.030  48.721  1
72579  95.474  -79.049  48.677  1
72580  95.479  -79.070  48.633  1
72581  95.483  -79.090  48.589  1
72582  95.488  -79.110  48.546  1
72583  95.492  -79.130  48.503  1
72584  95.497  -79.150  48.458  1
72585  95.511  -79.165  48.414  1
72586  95.526  -79.178  48.370  1
72587  95.548  -79.166  48.324  1
72588  95.570  -79.153  48.278  1
72589  95.593  -79.140  48.232  1
72590  95.615  -79.127  48.186  1
72591  95.637  -79.114  48.141  1
72592  95.660  -79.100  48.095  1
72593  95.682  -79.087  48.050  1
72594  95.705  -79.074  48.004  1
72595  95.725  -79.062  47.960  1
72596  95.734  -79.059  47.916  1
72597  95.741  -79.056  47.872  1
72598  95.747  -79.052  47.830  1
72599  95.753  -79.048  47.788  1
72600  95.760  -79.045  47.747  1
72601  95.772  -79.046  47.704  1
72602  95.784  -79.046  47.662  1
72603  95.797  -79.047  47.620  1
72604  95.809  -79.048  47.579  1
72605  95.821  -79.049  47.540  1
72606  95.834  -79.049  47.500  1
72607  95.846  -79.050  47.460  1
72608  95.859  -79.054  47.420  1
72609  95.879  -79.075  47.380  1
72610  95.899  -79.093  47.340  1
72611  95.941  -79.084  47.302  1
72612  96.037  -79.088  47.263  1
72613  96.077  -79.091  47.225  1
72614  96.114  -79.087  47.188  1
72615  96.148  -79.075  47.151  1
72616  96.182  -79.062  47.116  1
72617  96.217  -79.049  47.081  1
72618  96.251  -79.036  47.044  1
72619  96.285  -79.024  47.012  1
72620  96.320  -79.011  46.979  1
72621  96.354  -78.998  46.947  1
72622  96.383  -79.033  46.915  1
72623  96.412  -79.079  46.884  1
72624  96.440  -79.125  46.853  1
72625  96.457  -79.132  46.822  1
72626  96.472  -79.132  46.790  1
72627  96.486  -79.133  46.759  1
72628  96.501  -79.134  46.728  1
72629  96.520  -79.139  46.697  1
72630  96.544  -79.151  46.665  1
72631  96.568  -79.162  46.633  1
72632  96.591  -79.175  46.601  1
72633  96.614  -79.185  46.571  1
72634  96.612  -79.169  46.541  1
72635  96.610  -79.152  46.514  1
72636  96.617  -79.138  46.486  1
72637  96.653  -79.139  46.458  1
72638  96.690  -79.140  46.431  1
72639  96.726  -79.141  46.403  1
72640  96.762  -79.142  46.377  1
72641  96.785  -79.144  46.351  1
72642  96.807  -79.147  46.326  1
72643  96.830  -79.150  46.299  1
72644  96.853  -79.152  46.274  1
72645  96.872  -79.135  46.249  1
72646  96.901  -79.131  46.224  1
72647  96.892  -79.168  46.200  1
72648  96.869  -79.212  46.177  1
72649  96.904  -79.175  46.154  1
72650  96.940  -79.140  46.130  1
72651  96.975  -79.103  46.106  1
72652  97.011  -79.067  46.082  1
72653  97.052  -79.107  46.060  1
72654  97.094  -79.152  46.040  1
72655  97.095  -79.158  46.020  1
72656  97.091  -79.159  46.000  1
72657  97.087  -79.160  45.981  1
72658  97.082  -79.161  45.962  1
72659  97.082  -79.162  45.944  1
72660  97.091  -79.162  45.924  1
72661  97.100  -79.163  45.905  1
72662  97.104  -79.171  45.887  1
72663  97.108  -79.174  45.869  1
72664  97.124  -79.161  45.850  1
72665  97.145  -79.146  45.831  1
72666  97.168  -79.127  45.812  1
72667  97.184  -79.219  45.793  1
72668  97.181  -79.128  45.775  1
72669  97.180  -79.098  45.759  1
72670  97.181  -79.099  45.743  1
72671  97.170  -79.112  45.725  1
72672  97.168  -79.148  45.708  1
72673  97.178  -79.147  45.690  1
72674  97.213  -79.146  45.671  1
72675  97.250  -79.144  45.655  1
72676  97.281  -79.147  45.639  1
72677  97.295  -79.165  45.623  1
72678  97.309  -79.181  45.607  1
72679  97.323  -79.198  45.591  1
72680  97.337  -79.215  45.575  1
72681  97.352  -79.232  45.559  1
72682  97.366  -79.249  45.544  1
72683  97.330  -79.286  45.529  1
72684  97.300  -79.314  45.513  1
72685  97.315  -79.307  45.498  1
72686  97.331  -79.301  45.483  1
72687  97.347  -79.294  45.468  1
72688  97.370  -79.284  45.452  1
72689  97.383  -79.272  45.438  1
72690  97.404  -79.273  45.425  1
72691  97.432  -79.285  45.410  1
72692  97.461  -79.328  45.396  1
72693  97.468  -79.341  45.382  1
72694  97.473  -79.349  45.368  1
72695  97.479  -79.357  45.353  1
72696  97.485  -79.365  45.339  1
72697  97.493  -79.374  45.325  1
72698  97.508  -79.363  45.313  1
72699  97.514  -79.357  45.300  1
72700  97.518  -79.352  45.287  1
72701  97.522  -79.347  45.274  1
72702  97.525  -79.343  45.262  1
72703  97.529  -79.338  45.250  1
72704  97.533  -79.334  45.237  1
72705  97.537  -79.329  45.225  1
72706  97.543  -79.410  45.213  1
72707  97.566  -79.400  45.200  1
72708  97.585  -79.435  45.188  1
72709  97.605  -79.469  45.177  1
72710  97.620  -79.523  45.166  1
72711  97.635  -79.524  45.154  1
72712  97.649  -79.525  45.143  1
72713  97.666  -79.540  45.131  1
72714  97.683  -79.556  45.120  1
72715  97.701  -79.572  45.108  1
72716  97.718  -79.588  45.097  1
72717  97.735  -79.604  45.085  1
72718  97.752  -79.620  45.073  1
72719  97.770  -79.636  45.061  1
72720  97.787  -79.651  45.048  1
72721  97.804  -79.667  45.036  1
72722  97.821  -79.683  45.023  1
72723  97.839  -79.699  45.010  1
72724  97.856  -79.715  44.998  1
72725  97.873  -79.731  44.987  1
72726  97.891  -79.747  44.975  1
72727  97.908  -79.763  44.964  1
72728  97.925  -79.779  44.954  1
72729  97.943  -79.795  44.944  1
72730  97.960  -79.811  44.934  1
72731  97.977  -79.827  44.925  1
72732  97.995  -79.843  44.916  1
72733  98.012  -79.859  44.907  1
72734  98.029  -79.875  44.898  1
72735  98.054  -79.889  44.891  1
72736  98.077  -79.903  44.883  1
72737  98.101  -79.918  44.875  1
72738  98.125  -79.932  44.868  1
72739  98.148  -79.947  44.861  1
72740  98.171  -79.961  44.855  1
72741  98.196  -79.974  44.849  1
72742  98.222  -79.987  44.842  1
72743  98.253  -79.991  44.836  1
72744  98.266  -79.993  44.829  1
72745  98.278  -79.994  44.821  1
72746  98.290  -79.996  44.813  1
72747  98.319  -80.002  44.805  1
72748  98.371  -80.012  44.797  1
72749  98.423  -80.021  44.790  1
72750  98.467  -80.032  44.783  1
72751  98.495  -80.047  44.778  1
72752  98.522  -80.062  44.774  1
72753  98.550  -80.077  44.767  1
72754  98.578  -80.091  44.760  1
72755  98.607  -80.094  44.752  1
72756  98.637  -80.098  44.744  1
72757  98.667  -80.101  44.739  1
72758  98.696  -80.104  44.736  1
72759  98.720  -80.107  44.731  1
72760  98.742  -80.117  44.722  1
72761  98.756  -80.131  44.712  1
72762  98.769  -80.144  44.702  1
72763  98.782  -80.157  44.687  1
72764  98.807  -80.168  44.674  1
72765  98.833  -80.175  44.662  1
72766  98.849  -80.159  44.652  1
72767  98.859  -80.156  44.643  1
72768  98.876  -80.167  44.634  1
72769  98.892  -80.178  44.627  1
72770  98.909  -80.190  44.620  1
72771  98.926  -80.201  44.613  1
72772  98.942  -80.212  44.606  1
72773  98.995  -80.219  44.600  1
72774  99.048  -80.243  44.594  1
72775  99.071  -80.254  44.589  1
72776  99.094  -80.265  44.584  1
72777  99.118  -80.275  44.578  1
72778  99.141  -80.286  44.572  1
72779  99.164  -80.296  44.567  1
72780  99.188  -80.306  44.562  1
72781  99.211  -80.317  44.558  1
72782  99.234  -80.328  44.554  1
72783  99.258  -80.338  44.550  1
72784  99.281  -80.349  44.546  1
72785  99.304  -80.359  44.543  1
72786  99.336  -80.366  44.540  1
72787  99.375  -80.370  44.536  1
72788  99.413  -80.374  44.533  1
72789  99.452  -80.378  44.529  1
72790  99.491  -80.382  44.525  1
72791  99.529  -80.386  44.521  1
72792  99.564  -80.391  44.518  1
72793  99.567  -80.414  44.514  1
72794  99.570  -80.436  44.510  1
72795  99.574  -80.458  44.506  1
73112  93.513  -78.955  53.486  1
73113  93.523  -78.952  53.475  1
73114  93.533  -78.949  53.465  1
73115  93.543  -78.944  53.455  1
73116  93.555  -78.934  53.447  1
73117  93.563  -78.927  53.439  1
73118  93.571  -78.921  53.430  1
73119  93.580  -78.913  53.421  1
73120  93.588  -78.906  53.413  1
73121  93.596  -78.899  53.405  1
73122  93.605  -78.893  53.397  1
73123  93.631  -78.877  53.389  1
73124  93.697  -78.845  53.383  1
73125  93.666  -78.841  53.378  1
73126  93.662  -78.836  53.374  1
73127  93.672  -78.833  53.369  1
73128  93.682  -78.832  53.365  1
73129  93.691  -78.830  53.362  1
73130  93.700  -78.828  53.357  1
73131  93.710  -78.827  53.352  1
73132  93.721  -78.830  53.345  1
73133  93.732  -78.839  53.337  1
73134  93.739  -78.836  53.329  1
73135  93.746  -78.833  53.320  1
73136  93.753  -78.830  53.311  1
73137  93.760  -78.827  53.298  1
73138  93.767  -78.825  53.286  1
73139  93.774  -78.822  53.274  1
73140  93.781  -78.819  53.262  1
73141  93.788  -78.816  53.250  1
73142  93.795  -78.814  53.237  1
73143  93.802  -78.811  53.223  1
73144  93.814  -78.803  53.206  1
73145  93.820  -78.799  53.187  1
73146  93.825  -78.794  53.168  1
73147  93.830  -78.789  53.149  1
73148  93.835  -78.786  53.128  1
73149  93.841  -78.781  53.107  1
73150  93.846  -78.777  53.087  1
73151  93.851  -78.772  53.063  1
73152  93.856  -78.767  53.039  1
73153  93.862  -78.763  53.014  1
73154  93.867  -78.759  52.988  1
73155  93.872  -78.755  52.962  1
73156  93.883  -78.749  52.936  1
73157  93.898  -78.742  52.910  1
73158  93.914  -78.736  52.883  1
73159  93.930  -78.730  52.856  1
73160  93.946  -78.724  52.830  1
73161  93.962  -78.717  52.805  1
73162  93.978  -78.711  52.779  1
73163  93.994  -78.705  52.755  1
73164  94.009  -78.698  52.732  1
73165  94.026  -78.692  52.708  1
73166  94.041  -78.686  52.685  1
73167  94.057  -78.680  52.664  1
73168  94.077  -78.681  52.641  1
73169  94.092  -78.681  52.619  1
73170  94.103  -78.677  52.596  1
73171  94.111  -78.677  52.573  1
73172  94.115  -78.685  52.551  1
73173  94.120  -78.692  52.528  1
73174  94.124  -78.700  52.504  1
73175  94.128  -78.708  52.478  1
73176  94.144  -78.684  52.452  1
73177  94.189  -78.686  52.426  1
73178  94.232  -78.696  52.402  1
73179  94.242  -78.694  52.377  1
73180  94.252  -78.691  52.351  1
73181  94.262  -78.689  52.325  1
73182  94.272  -78.686  52.300  1
73183  94.281  -78.683  52.277  1
73184  94.282  -78.688  52.254  1
73185  94.290  -78.685  52.228  1
73186  94.299  -78.683  52.199  1
73187  94.308  -78.680  52.170  1
73188  94.316  -78.678  52.142  1
73189  94.325  -78.676  52.114  1
73190  94.333  -78.673  52.087  1
73191  94.342  -78.671  52.061  1
73192  94.351  -78.669  52.034  1
73193  94.359  -78.667  52.006  1
73194  94.368  -78.664  51.977  1
73195  94.380  -78.665  51.948  1
73196  94.390  -78.670  51.917  1
73197  94.402  -78.676  51.885  1
73198  94.415  -78.680  51.853  1
73199  94.428  -78.685  51.820  1
73200  94.441  -78.690  51.790  1
73201  94.455  -78.694  51.760  1
73202  94.472  -78.695  51.729  1
73203  94.494  -78.701  51.696  1
73204  94.521  -78.708  51.661  1
73205  94.548  -78.714  51.625  1
73206  94.567  -78.717  51.590  1
73207  94.585  -78.720  51.553  1
73208  94.603  -78.721  51.515  1
73209  94.621  -78.724  51.479  1
73210  94.639  -78.726  51.444  1
73211  94.657  -78.728  51.411  1
73212  94.676  -78.730  51.378  1
73213  94.694  -78.733  51.346  1
73214  94.712  -78.735  51.314  1
73215  94.730  -78.737  51.282  1
73216  94.740  -78.739  51.250  1
73217  94.751  -78.741  51.215  1
73218  94.762  -78.743  51.178  1
73219  94.768  -78.733  51.141  1
73220  94.773  -78.724  51.102  1
73221  94.779  -78.713  51.062  1
73222  94.784  -78.702  51.022  1
73223  94.779  -78.706  50.983  1
73224  94.767  -78.723  50.944  1
73225  94.756  -78.739  50.905  1
73226  94.744  -78.756  50.865  1
73227  94.742  -78.764  50.823  1
73228  94.761  -78.751  50.780  1
73229  94.778  -78.739  50.735  1
73230  94.787  -78.730  50.692  1
73231  94.796  -78.722  50.651  1
73232  94.815  -78.719  50.610  1
73233  94.833  -78.715  50.569  1
73234  94.851  -78.712  50.528  1
73235  94.870  -78.709  50.485  1
73236  94.880  -78.713  50.440  1
73237  94.879  -78.729  50.397  1
73238  94.878  -78.744  50.355  1
73239  94.876  -78.760  50.315  1
73240  94.875  -78.775  50.278  1
73241  94.874  -78.790  50.241  1
73242  94.873  -78.806  50.204  1
73243  94.872  -78.821  50.167  1
73244  94.871  -78.837  50.130  1
73245  94.868  -78.851  50.092  1
73246  94.860  -78.851  50.052  1
73247  94.853  -78.850  50.014  1
73248  94.858  -78.852  49.975  1
73249  94.875  -78.855  49.935  1
73250  94.892  -78.858  49.895  1
73251  94.909  -78.861  49.855  1
73252  94.925  -78.864  49.817  1
73253  94.947  -78.864  49.781  1
73254  94.975  -78.859  49.745  1
73255  95.004  -78.855  49.708  1
73256  95.033  -78.850  49.670  1
73257  95.061  -78.846  49.632  1
73258  95.091  -78.849  49.591  1
73259  95.120  -78.855  49.550  1
73260  95.149  -78.861  49.509  1
73261  95.179  -78.867  49.467  1
73262  95.208  -78.872  49.426  1
73263  95.237  -78.878  49.386  1
73264  95.266  -78.883  49.346  1
73265  95.296  -78.890  49.307  1
73266  95.325  -78.895  49.268  1
73267  95.354  -78.901  49.230  1
73268  95.384  -78.906  49.190  1
73269  95.405  -78.912  49.149  1
73270  95.414  -78.918  49.106  1
73271  95.422  -78.924  49.063  1
73272  95.430  -78.930  49.022  1
73273  95.439  -78.935  48.981  1
73274  95.448  -78.941  48.939  1
73275  95.456  -78.947  48.897  1
73276  95.465  -78.952  48.855  1
73277  95.471  -78.968  48.813  1
73278  95.475  -78.988  48.771  1
73279  95.480  -79.008  48.729  1
73280  95.484  -79.028  48.686  1
73281  95.489  -79.048  48.640  1
73282  95.493  -79.068  48.598  1
73283  95.498  -79.088  48.556  1
73284  95.502  -79.109  48.513  1
73285  95.516  -79.123  48.469  1
73286  95.531  -79.137  48.425  1
73287  95.546  -79.150  48.380  1
73288  95.562  -79.160  48.334  1
73289  95.585  -79.147  48.286  1
73290  95.607  -79.134  48.239  1
73291  95.629  -79.120  48.192  1
73292  95.652  -79.107  48.146  1
73293  95.674  -79.094  48.100  1
73294  95.697  -79.081  48.055  1
73295  95.719  -79.068  48.009  1
73296  95.733  -79.061  47.964  1
73297  95.742  -79.057  47.920  1
73298  95.750  -79.053  47.877  1
73299  95.756  -79.049  47.836  1
73300  95.763  -79.046  47.795  1
73301  95.769  -79.043  47.753  1
73302  95.776  -79.039  47.711  1
73303  95.782  -79.035  47.667  1
73304  95.789  -79.031  47.625  1
73305  95.795  -79.028  47.583  1
73306  95.805  -79.027  47.543  1
73307  95.817  -79.028  47.502  1
73308  95.830  -79.028  47.462  1
73309  95.842  -79.029  47.422  1
73310  95.857  -79.038  47.382  1
73311  95.877  -79.043  47.343  1
73312  95.943  -79.061  47.304  1
73313  96.030  -79.071  47.266  1
73314  96.079  -79.073  47.228  1
73315  96.118  -79.076  47.190  1
73316  96.156  -79.073  47.153  1
73317  96.190  -79.060  47.118  1
73318  96.225  -79.047  47.083  1
73319  96.259  -79.035  47.047  1
73320  96.294  -79.022  47.013  1
73321  96.328  -79.009  46.981  1
73322  96.362  -78.996  46.949  1
73323  96.391  -79.033  46.918  1
73324  96.419  -79.078  46.887  1
73325  96.444  -79.111  46.856  1
73326  96.459  -79.112  46.824  1
73327  96.474  -79.112  46.792  1
73328  96.488  -79.112  46.760  1
73329  96.508  -79.119  46.729  1
73330  96.532  -79.131  46.697  1
73331  96.555  -79.143  46.666  1
73332  96.579  -79.154  46.635  1
73333  96.603  -79.166  46.603  1
73334  96.626  -79.178  46.572  1
73335  96.633  -79.170  46.543  1
73336  96.631  -79.153  46.515  1
73337  96.629  -79.137  46.488  1
73338  96.627  -79.120  46.460  1
73339  96.662  -79.119  46.433  1
73340  96.698  -79.120  46.406  1
73341  96.735  -79.121  46.379  1
73342  96.771  -79.122  46.353  1
73343  96.808  -79.123  46.328  1
73344  96.838  -79.125  46.304  1
73345  96.861  -79.127  46.279  1
73346  96.885  -79.118  46.254  1
73347  96.865  -79.162  46.229  1
73348  96.840  -79.209  46.206  1
73349  96.874  -79.175  46.183  1
73350  96.909  -79.139  46.160  1
73351  96.945  -79.103  46.135  1
73352  96.980  -79.067  46.110  1
73353  97.018  -79.057  46.086  1
73354  97.060  -79.102  46.065  1
73355  97.102  -79.147  46.045  1
73356  97.098  -79.148  46.026  1
73357  97.094  -79.150  46.006  1
73358  97.090  -79.150  45.986  1
73359  97.085  -79.151  45.967  1
73360  97.074  -79.146  45.948  1
73361  97.076  -79.167  45.929  1
73362  97.079  -79.175  45.910  1
73363  97.082  -79.184  45.892  1
73364  97.088  -79.173  45.874  1
73365  97.104  -79.159  45.856  1
73366  97.126  -79.140  45.837  1
73367  97.149  -79.118  45.818  1
73368  97.171  -79.127  45.800  1
73369  97.191  -79.244  45.782  1
73370  97.196  -79.235  45.766  1
73371  97.197  -79.145  45.750  1
73372  97.170  -79.119  45.732  1
73373  97.149  -79.137  45.714  1
73374  97.176  -79.153  45.696  1
73375  97.203  -79.150  45.679  1
73376  97.240  -79.148  45.662  1
73377  97.278  -79.147  45.646  1
73378  97.312  -79.147  45.630  1
73379  97.326  -79.164  45.615  1
73380  97.341  -79.181  45.599  1
73381  97.355  -79.198  45.583  1
73382  97.369  -79.215  45.567  1
73383  97.375  -79.235  45.551  1
73384  97.320  -79.280  45.537  1
73385  97.304  -79.297  45.521  1
73386  97.319  -79.291  45.506  1
73387  97.334  -79.285  45.491  1
73388  97.350  -79.278  45.477  1
73389  97.369  -79.270  45.462  1
73390  97.387  -79.266  45.447  1
73391  97.414  -79.277  45.434  1
73392  97.442  -79.289  45.419  1
73393  97.462  -79.320  45.405  1
73394  97.467  -79.328  45.391  1
73395  97.473  -79.336  45.376  1
73396  97.478  -79.344  45.362  1
73397  97.484  -79.352  45.349  1
73398  97.491  -79.360  45.335  1
73399  97.495  -79.356  45.322  1
73400  97.499  -79.352  45.309  1
73401  97.503  -79.347  45.297  1
73402  97.507  -79.343  45.284  1
73403  97.511  -79.338  45.271  1
73404  97.515  -79.334  45.259  1
73405  97.519  -79.330  45.247  1
73406  97.523  -79.325  45.234  1
73407  97.527  -79.321  45.222  1
73408  97.540  -79.342  45.210  1
73409  97.557  -79.372  45.198  1
73410  97.576  -79.407  45.187  1
73411  97.595  -79.441  45.176  1
73412  97.614  -79.476  45.164  1
73413  97.634  -79.520  45.153  1
73414  97.648  -79.607  45.142  1
73415  97.662  -79.607  45.130  1
73416  97.676  -79.609  45.119  1
73417  97.691  -79.610  45.107  1
73418  97.705  -79.611  45.096  1
73419  97.719  -79.612  45.084  1
73420  97.736  -79.626  45.072  1
73421  97.753  -79.642  45.060  1
73422  97.771  -79.657  45.047  1
73423  97.788  -79.673  45.035  1
73424  97.805  -79.689  45.022  1
73425  97.822  -79.705  45.010  1
73426  97.840  -79.721  44.999  1
73427  97.857  -79.737  44.988  1
73428  97.874  -79.754  44.977  1
73429  97.892  -79.770  44.967  1
73430  97.909  -79.786  44.958  1
73431  97.926  -79.802  44.948  1
73432  97.949  -79.816  44.939  1
73433  97.973  -79.830  44.931  1
73434  97.997  -79.845  44.922  1
73435  98.020  -79.859  44.913  1
73436  98.043  -79.874  44.906  1
73437  98.066  -79.889  44.899  1
73438  98.090  -79.902  44.892  1
73439  98.116  -79.914  44.886  1
73440  98.143  -79.927  44.880  1
73441  98.171  -79.935  44.874  1
73442  98.184  -79.936  44.868  1
73443  98.199  -79.939  44.862  1
73444  98.222  -79.948  44.855  1
73445  98.246  -79.955  44.847  1
73446  98.270  -79.964  44.838  1
73447  98.295  -79.969  44.828  1
73448  98.324  -79.977  44.819  1
73449  98.362  -79.989  44.811  1
73450  98.406  -79.999  44.804  1
73451  98.458  -80.009  44.798  1
73452  98.501  -80.021  44.794  1
73453  98.528  -80.036  44.790  1
73454  98.556  -80.051  44.783  1
73455  98.585  -80.059  44.775  1
73456  98.614  -80.062  44.765  1
73457  98.644  -80.065  44.755  1
73458  98.673  -80.068  44.748  1
73459  98.703  -80.073  44.743  1
73460  98.723  -80.083  44.737  1
73461  98.735  -80.098  44.727  1
73462  98.748  -80.112  44.717  1
73463  98.761  -80.124  44.706  1
73464  98.779  -80.137  44.693  1
73465  98.805  -80.147  44.682  1
73466  98.833  -80.156  44.672  1
73467  98.861  -80.145  44.662  1
73468  98.875  -80.131  44.653  1
73469  98.889  -80.135  44.645  1
73470  98.905  -80.146  44.638  1
73471  98.922  -80.157  44.631  1
73472  98.938  -80.168  44.624  1
73473  98.955  -80.180  44.617  1
73474  98.971  -80.191  44.610  1
73475  99.001  -80.199  44.604  1
73476  99.075  -80.227  44.599  1
73477  99.098  -80.237  44.594  1
73478  99.122  -80.248  44.588  1
73479  99.145  -80.259  44.582  1
73480  99.168  -80.269  44.577  1
73481  99.192  -80.279  44.572  1
73482  99.215  -80.290  44.568  1
73483  99.238  -80.300  44.563  1
73484  99.262  -80.311  44.559  1
73485  99.285  -80.322  44.556  1
73486  99.308  -80.332  44.552  1
73487  99.347  -80.336  44.549  1
73488  99.385  -80.340  44.546  1
73489  99.424  -80.344  44.542  1
73490  99.463  -80.348  44.538  1
73491  99.501  -80.352  44.535  1
73492  99.540  -80.356  44.531  1
73493  99.561  -80.369  44.527  1
73494  99.564  -80.391  44.524  1
73495  99.567  -80.413  44.519  1
73496  99.570  -80.435  44.515  1
73497  99.573  -80.457  44.510  1
73498  99.577  -80.479  44.505  1
73814  93.523  -78.941  53.490  1
73815  93.533  -78.939  53.479  1
73816  93.543  -78.937  53.470  1
73817  93.553  -78.930  53.461  1
73818  93.564  -78.921  53.452  1
73819  93.572  -78.914  53.443  1
73820  93.581  -78.907  53.435  1
73821  93.589  -78.900  53.426  1
73822  93.597  -78.893  53.418  1
73823  93.606  -78.886  53.410  1
73824  93.619  -78.877  53.403  1
73825  93.688  -78.843  53.397  1
73826  93.703  -78.826  53.391  1
73827  93.699  -78.820  53.386  1
73828  93.695  -78.814  53.383  1
73829  93.691  -78.808  53.380  1
73830  93.687  -78.802  53.377  1
73831  93.694  -78.805  53.372  1
73832  93.707  -78.818  53.367  1
73833  93.720  -78.830  53.361  1
73834  93.728  -78.831  53.352  1
73835  93.735  -78.829  53.343  1
73836  93.742  -78.826  53.335  1
73837  93.749  -78.823  53.325  1
73838  93.756  -78.821  53.313  1
73839  93.763  -78.818  53.300  1
73840  93.770  -78.814  53.288  1
73841  93.777  -78.811  53.275  1
73842  93.784  -78.809  53.262  1
73843  93.791  -78.806  53.248  1
73844  93.807  -78.797  53.235  1
73845  93.813  -78.789  53.216  1
73846  93.827  -78.781  53.197  1
73847  93.837  -78.774  53.177  1
73848  93.843  -78.770  53.157  1
73849  93.848  -78.765  53.136  1
73850  93.853  -78.761  53.114  1
73851  93.858  -78.757  53.093  1
73852  93.863  -78.752  53.069  1
73853  93.869  -78.748  53.045  1
73854  93.874  -78.743  53.020  1
73855  93.880  -78.739  52.995  1
73856  93.885  -78.734  52.969  1
73857  93.898  -78.729  52.943  1
73858  93.914  -78.722  52.918  1
73859  93.930  -78.716  52.890  1
73860  93.945  -78.710  52.864  1
73861  93.962  -78.703  52.839  1
73862  93.977  -78.697  52.813  1
73863  93.993  -78.691  52.788  1
73864  94.009  -78.685  52.764  1
73865  94.025  -78.678  52.742  1
73866  94.041  -78.672  52.718  1
73867  94.057  -78.666  52.696  1
73868  94.073  -78.659  52.675  1
73869  94.088  -78.653  52.653  1
73870  94.097  -78.655  52.631  1
73871  94.101  -78.662  52.608  1
73872  94.105  -78.670  52.585  1
73873  94.109  -78.678  52.561  1
73874  94.114  -78.686  52.537  1
73875  94.118  -78.694  52.512  1
73876  94.135  -78.665  52.488  1
73877  94.174  -78.658  52.463  1
73878  94.225  -78.671  52.438  1
73879  94.255  -78.677  52.414  1
73880  94.265  -78.673  52.389  1
73881  94.275  -78.671  52.364  1
73882  94.285  -78.668  52.339  1
73883  94.294  -78.666  52.315  1
73884  94.296  -78.670  52.292  1
73885  94.288  -78.682  52.269  1
73886  94.293  -78.681  52.244  1
73887  94.308  -78.671  52.215  1
73888  94.317  -78.669  52.186  1
73889  94.325  -78.667  52.159  1
73890  94.334  -78.664  52.132  1
73891  94.343  -78.662  52.105  1
73892  94.351  -78.660  52.079  1
73893  94.360  -78.658  52.054  1
73894  94.368  -78.655  52.026  1
73895  94.377  -78.653  51.998  1
73896  94.391  -78.652  51.969  1
73897  94.403  -78.658  51.939  1
73898  94.413  -78.662  51.907  1
73899  94.424  -78.667  51.874  1
73900  94.435  -78.673  51.842  1
73901  94.445  -78.678  51.811  1
73902  94.458  -78.683  51.781  1
73903  94.478  -78.688  51.750  1
73904  94.498  -78.691  51.716  1
73905  94.516  -78.693  51.680  1
73906  94.534  -78.695  51.642  1
73907  94.552  -78.697  51.604  1
73908  94.570  -78.699  51.566  1
73909  94.589  -78.702  51.528  1
73910  94.607  -78.704  51.492  1
73911  94.625  -78.706  51.458  1
73912  94.643  -78.708  51.425  1
73913  94.661  -78.711  51.392  1
73914  94.679  -78.712  51.360  1
73915  94.697  -78.714  51.330  1
73916  94.714  -78.717  51.299  1
73917  94.725  -78.719  51.266  1
73918  94.736  -78.721  51.232  1
73919  94.747  -78.724  51.197  1
73920  94.757  -78.724  51.159  1
73921  94.762  -78.714  51.119  1
73922  94.768  -78.703  51.079  1
73923  94.773  -78.696  51.038  1
73924  94.776  -78.705  50.998  1
73925  94.780  -78.714  50.957  1
73926  94.773  -78.728  50.918  1
73927  94.761  -78.745  50.879  1
73928  94.758  -78.754  50.837  1
73929  94.776  -78.741  50.793  1
73930  94.785  -78.733  50.748  1
73931  94.794  -78.724  50.705  1
73932  94.803  -78.716  50.663  1
73933  94.813  -78.708  50.623  1
73934  94.831  -78.705  50.583  1
73935  94.849  -78.701  50.540  1
73936  94.867  -78.698  50.497  1
73937  94.879  -78.702  50.452  1
73938  94.877  -78.717  50.408  1
73939  94.876  -78.733  50.365  1
73940  94.875  -78.748  50.323  1
73941  94.874  -78.764  50.285  1
73942  94.873  -78.779  50.247  1
73943  94.872  -78.794  50.209  1
73944  94.870  -78.810  50.172  1
73945  94.869  -78.825  50.134  1
73946  94.867  -78.841  50.095  1
73947  94.865  -78.853  50.056  1
73948  94.857  -78.853  50.017  1
73949  94.859  -78.854  49.977  1
73950  94.876  -78.857  49.938  1
73951  94.893  -78.860  49.899  1
73952  94.910  -78.863  49.860  1
73953  94.935  -78.860  49.822  1
73954  94.964  -78.855  49.785  1
73955  94.992  -78.851  49.748  1
73956  95.021  -78.846  49.710  1
73957  95.050  -78.842  49.672  1
73958  95.078  -78.837  49.632  1
73959  95.107  -78.835  49.591  1
73960  95.137  -78.840  49.550  1
73961  95.166  -78.846  49.510  1
73962  95.195  -78.852  49.470  1
73963  95.225  -78.858  49.430  1
73964  95.254  -78.863  49.389  1
73965  95.283  -78.869  49.349  1
73966  95.313  -78.874  49.308  1
73967  95.342  -78.880  49.268  1
73968  95.370  -78.886  49.227  1
73969  95.389  -78.899  49.189  1
73970  95.407  -78.905  49.149  1
73971  95.421  -78.903  49.109  1
73972  95.431  -78.907  49.067  1
73973  95.440  -78.912  49.026  1
73974  95.448  -78.918  48.984  1
73975  95.457  -78.924  48.941  1
73976  95.465  -78.930  48.900  1
73977  95.473  -78.936  48.857  1
73978  95.481  -78.946  48.815  1
73979  95.485  -78.966  48.774  1
73980  95.490  -78.987  48.732  1
73981  95.494  -79.006  48.689  1
73982  95.499  -79.027  48.646  1
73983  95.503  -79.046  48.606  1
73984  95.509  -79.067  48.565  1
73985  95.521  -79.082  48.522  1
73986  95.536  -79.095  48.478  1
73987  95.551  -79.109  48.433  1
73988  95.566  -79.122  48.387  1
73989  95.582  -79.134  48.341  1
73990  95.599  -79.140  48.293  1
73991  95.621  -79.127  48.245  1
73992  95.644  -79.114  48.199  1
73993  95.666  -79.100  48.153  1
73994  95.689  -79.087  48.107  1
73995  95.711  -79.074  48.061  1
73996  95.731  -79.062  48.014  1
73997  95.740  -79.059  47.970  1
73998  95.749  -79.055  47.927  1
73999  95.758  -79.051  47.884  1
74000  95.766  -79.048  47.842  1
74001  95.772  -79.044  47.800  1
74002  95.779  -79.040  47.758  1
74003  95.785  -79.037  47.715  1
74004  95.792  -79.033  47.672  1
74005  95.798  -79.030  47.630  1
74006  95.805  -79.026  47.588  1
74007  95.811  -79.022  47.547  1
74008  95.817  -79.018  47.507  1
74009  95.824  -79.015  47.466  1
74010  95.830  -79.012  47.426  1
74011  95.838  -79.009  47.386  1
74012  95.877  -79.019  47.347  1
74013  95.944  -79.037  47.306  1
74014  96.017  -79.053  47.268  1
74015  96.081  -79.055  47.230  1
74016  96.120  -79.058  47.193  1
74017  96.160  -79.060  47.157  1
74018  96.198  -79.059  47.122  1
74019  96.233  -79.046  47.086  1
74020  96.267  -79.034  47.051  1
74021  96.302  -79.021  47.016  1
74022  96.336  -79.008  46.984  1
74023  96.370  -78.995  46.953  1
74024  96.399  -79.032  46.922  1
74025  96.428  -79.078  46.891  1
74026  96.446  -79.090  46.859  1
74027  96.461  -79.091  46.827  1
74028  96.476  -79.091  46.795  1
74029  96.496  -79.099  46.763  1
74030  96.520  -79.110  46.732  1
74031  96.543  -79.122  46.699  1
74032  96.567  -79.134  46.668  1
74033  96.590  -79.146  46.637  1
74034  96.614  -79.158  46.605  1
74035  96.638  -79.169  46.575  1
74036  96.654  -79.172  46.547  1
74037  96.652  -79.156  46.519  1
74038  96.650  -79.138  46.491  1
74039  96.648  -79.122  46.463  1
74040  96.646  -79.105  46.435  1
74041  96.670  -79.100  46.408  1
74042  96.707  -79.100  46.381  1
74043  96.743  -79.101  46.355  1
74044  96.780  -79.102  46.331  1
74045  96.816  -79.103  46.307  1
74046  96.863  -79.106  46.282  1
74047  96.838  -79.157  46.258  1
74048  96.813  -79.204  46.233  1
74049  96.844  -79.175  46.210  1
74050  96.879  -79.139  46.187  1
74051  96.914  -79.103  46.162  1
74052  96.950  -79.066  46.138  1
74053  96.985  -79.030  46.114  1
74054  97.025  -79.052  46.092  1
74055  97.068  -79.096  46.070  1
74056  97.105  -79.137  46.050  1
74057  97.101  -79.138  46.031  1
74058  97.097  -79.140  46.013  1
74059  97.092  -79.140  45.993  1
74060  97.060  -79.115  45.974  1
74061  97.068  -79.181  45.954  1
74062  97.064  -79.186  45.935  1
74063  97.060  -79.190  45.917  1
74064  97.060  -79.197  45.899  1
74065  97.068  -79.172  45.881  1
74066  97.084  -79.156  45.863  1
74067  97.107  -79.134  45.844  1
74068  97.130  -79.113  45.825  1
74069  97.153  -79.092  45.807  1
74070  97.174  -79.126  45.790  1
74071  97.173  -79.229  45.774  1
74072  97.225  -79.238  45.757  1
74073  97.277  -79.247  45.740  1
74074  97.233  -79.188  45.722  1
74075  97.165  -79.149  45.705  1
74076  97.193  -79.154  45.688  1
74077  97.231  -79.153  45.671  1
74078  97.267  -79.151  45.654  1
74079  97.305  -79.150  45.638  1
74080  97.342  -79.148  45.622  1
74081  97.358  -79.163  45.606  1
74082  97.372  -79.181  45.591  1
74083  97.386  -79.197  45.575  1
74084  97.365  -79.229  45.559  1
74085  97.311  -79.274  45.545  1
74086  97.307  -79.281  45.530  1
74087  97.323  -79.275  45.515  1
74088  97.338  -79.269  45.501  1
74089  97.354  -79.262  45.486  1
74090  97.364  -79.258  45.471  1
74091  97.397  -79.269  45.457  1
74092  97.425  -79.281  45.443  1
74093  97.452  -79.293  45.429  1
74094  97.461  -79.307  45.415  1
74095  97.460  -79.318  45.401  1
74096  97.454  -79.331  45.385  1
74097  97.463  -79.338  45.371  1
74098  97.477  -79.344  45.358  1
74099  97.491  -79.350  45.345  1
74100  97.508  -79.361  45.332  1
74101  97.522  -79.369  45.319  1
74102  97.526  -79.365  45.306  1
74103  97.530  -79.360  45.294  1
74104  97.534  -79.356  45.281  1
74105  97.538  -79.351  45.268  1
74106  97.542  -79.347  45.256  1
74107  97.546  -79.343  45.243  1
74108  97.550  -79.338  45.231  1
74109  97.564  -79.362  45.219  1
74110  97.579  -79.390  45.208  1
74111  97.594  -79.417  45.197  1
74112  97.608  -79.445  45.186  1
74113  97.624  -79.473  45.174  1
74114  97.639  -79.501  45.165  1
74115  97.647  -79.513  45.154  1
74116  97.658  -79.598  45.141  1
74117  97.672  -79.648  45.129  1
74118  97.684  -79.654  45.117  1
74119  97.698  -79.662  45.106  1
74120  97.710  -79.669  45.094  1
74121  97.723  -79.676  45.082  1
74122  97.736  -79.683  45.070  1
74123  97.748  -79.691  45.058  1
74124  97.761  -79.697  45.046  1
74125  97.776  -79.698  45.034  1
74126  97.790  -79.699  45.023  1
74127  97.806  -79.712  45.013  1
74128  97.823  -79.728  45.002  1
74129  97.845  -79.742  44.991  1
74130  97.868  -79.758  44.981  1
74131  97.891  -79.772  44.972  1
74132  97.915  -79.786  44.962  1
74133  97.938  -79.801  44.954  1
74134  97.961  -79.816  44.946  1
74135  97.985  -79.830  44.938  1
74136  98.011  -79.842  44.931  1
74137  98.037  -79.855  44.925  1
74138  98.064  -79.867  44.920  1
74139  98.090  -79.879  44.914  1
74140  98.113  -79.886  44.908  1
74141  98.137  -79.894  44.901  1
74142  98.160  -79.902  44.894  1
74143  98.184  -79.911  44.887  1
74144  98.208  -79.919  44.880  1
74145  98.231  -79.927  44.872  1
74146  98.256  -79.933  44.862  1
74147  98.282  -79.939  44.852  1
74148  98.307  -79.944  44.841  1
74149  98.335  -79.951  44.832  1
74150  98.373  -79.963  44.825  1
74151  98.411  -79.974  44.820  1
74152  98.449  -79.987  44.815  1
74153  98.493  -79.997  44.809  1
74154  98.534  -80.009  44.804  1
74155  98.562  -80.024  44.797  1
74156  98.591  -80.027  44.787  1
74157  98.621  -80.030  44.776  1
74158  98.650  -80.035  44.764  1
74159  98.679  -80.040  44.756  1
74160  98.708  -80.045  44.749  1
74161  98.719  -80.060  44.742  1
74162  98.731  -80.074  44.732  1
74163  98.743  -80.090  44.721  1
74164  98.755  -80.105  44.711  1
74165  98.786  -80.108  44.700  1
74166  98.821  -80.108  44.691  1
74167  98.857  -80.107  44.682  1
74168  98.882  -80.117  44.673  1
74169  98.896  -80.118  44.664  1
74170  98.905  -80.116  44.656  1
74171  98.921  -80.121  44.649  1
74172  98.936  -80.127  44.641  1
74173  98.951  -80.136  44.634  1
74174  98.968  -80.147  44.627  1
74175  98.984  -80.158  44.620  1
74176  99.001  -80.169  44.615  1
74177  99.017  -80.181  44.610  1
74178  99.075  -80.197  44.604  1
74179  99.126  -80.221  44.599  1
74180  99.149  -80.231  44.593  1
74181  99.172  -80.242  44.587  1
74182  99.196  -80.252  44.582  1
74183  99.219  -80.262  44.579  1
74184  99.242  -80.273  44.575  1
74185  99.266  -80.284  44.570  1
74186  99.289  -80.294  44.566  1
74187  99.320  -80.302  44.562  1
74188  99.358  -80.306  44.559  1
74189  99.397  -80.309  44.555  1
74190  99.435  -80.314  44.551  1
74191  99.474  -80.318  44.548  1
74192  99.512  -80.322  44.545  1
74193  99.551  -80.325  44.541  1
74194  99.557  -80.346  44.537  1
74195  99.560  -80.368  44.532  1
74196  99.563  -80.391  44.528  1
74197  99.567  -80.413  44.523  1
74198  99.570  -80.435  44.519  1
74199  99.573  -80.457  44.513  1
74200  99.576  -80.478  44.508  1
74516  93.534  -78.928  53.494  1
74517  93.543  -78.925  53.484  1
74518  93.553  -78.923  53.474  1
74519  93.563  -78.916  53.465  1
74520  93.573  -78.907  53.456  1
74521  93.582  -78.900  53.448  1
74522  93.590  -78.893  53.439  1
74523  93.599  -78.886  53.431  1
74524  93.607  -78.880  53.423  1
74525  93.615  -78.873  53.416  1
74526  93.677  -78.842  53.410  1
74527  93.736  -78.812  53.404  1
74528  93.725  -78.809  53.400  1
74529  93.714  -78.805  53.397  1
74530  93.704  -78.802  53.394  1
74531  93.693  -78.799  53.392  1
74532  93.693  -78.804  53.388  1
74533  93.706  -78.817  53.383  1
74534  93.717  -78.824  53.376  1
74535  93.724  -78.824  53.367  1
74536  93.731  -78.821  53.358  1
74537  93.738  -78.818  53.349  1
74538  93.745  -78.816  53.338  1
74539  93.752  -78.813  53.327  1
74540  93.759  -78.810  53.314  1
74541  93.766  -78.808  53.300  1
74542  93.773  -78.805  53.288  1
74543  93.780  -78.802  53.273  1
74544  93.795  -78.794  53.258  1
74545  93.809  -78.783  53.244  1
74546  93.813  -78.774  53.225  1
74547  93.826  -78.767  53.205  1
74548  93.840  -78.758  53.184  1
74549  93.854  -78.750  53.165  1
74550  93.860  -78.745  53.143  1
74551  93.865  -78.741  53.122  1
74552  93.871  -78.736  53.101  1
74553  93.876  -78.732  53.076  1
74554  93.882  -78.727  53.051  1
74555  93.887  -78.724  53.025  1
74556  93.892  -78.719  53.000  1
74557  93.898  -78.714  52.976  1
74558  93.913  -78.708  52.951  1
74559  93.929  -78.702  52.926  1
74560  93.945  -78.695  52.898  1
74561  93.961  -78.689  52.872  1
74562  93.977  -78.683  52.848  1
74563  93.993  -78.677  52.822  1
74564  94.009  -78.670  52.798  1
74565  94.025  -78.664  52.774  1
74566  94.041  -78.658  52.752  1
74567  94.056  -78.651  52.730  1
74568  94.069  -78.648  52.708  1
74569  94.079  -78.646  52.687  1
74570  94.089  -78.645  52.665  1
74571  94.091  -78.648  52.642  1
74572  94.095  -78.655  52.620  1
74573  94.099  -78.664  52.596  1
74574  94.103  -78.671  52.572  1
74575  94.107  -78.679  52.547  1
74576  94.126  -78.647  52.522  1
74577  94.158  -78.630  52.498  1
74578  94.209  -78.643  52.474  1
74579  94.261  -78.656  52.450  1
74580  94.278  -78.656  52.427  1
74581  94.288  -78.654  52.403  1
74582  94.298  -78.651  52.378  1
74583  94.308  -78.648  52.355  1
74584  94.310  -78.652  52.332  1
74585  94.302  -78.664  52.308  1
74586  94.294  -78.676  52.285  1
74587  94.295  -78.680  52.260  1
74588  94.312  -78.667  52.233  1
74589  94.326  -78.658  52.204  1
74590  94.335  -78.655  52.178  1
74591  94.343  -78.653  52.151  1
74592  94.352  -78.651  52.125  1
74593  94.360  -78.648  52.098  1
74594  94.369  -78.646  52.072  1
74595  94.378  -78.644  52.045  1
74596  94.387  -78.642  52.017  1
74597  94.400  -78.642  51.987  1
74598  94.415  -78.644  51.957  1
74599  94.425  -78.649  51.925  1
74600  94.436  -78.655  51.892  1
74601  94.447  -78.660  51.859  1
74602  94.458  -78.665  51.829  1
74603  94.468  -78.672  51.799  1
74604  94.482  -78.683  51.767  1
74605  94.497  -78.683  51.733  1
74606  94.511  -78.683  51.696  1
74607  94.527  -78.682  51.658  1
74608  94.542  -78.681  51.619  1
74609  94.557  -78.680  51.580  1
74610  94.574  -78.682  51.542  1
74611  94.592  -78.684  51.506  1
74612  94.610  -78.686  51.472  1
74613  94.628  -78.688  51.439  1
74614  94.646  -78.690  51.406  1
74615  94.665  -78.692  51.376  1
74616  94.683  -78.695  51.345  1
74617  94.699  -78.697  51.314  1
74618  94.710  -78.699  51.282  1
74619  94.720  -78.702  51.249  1
74620  94.732  -78.704  51.214  1
74621  94.742  -78.706  51.177  1
74622  94.751  -78.704  51.136  1
74623  94.757  -78.693  51.095  1
74624  94.760  -78.702  51.053  1
74625  94.764  -78.710  51.012  1
74626  94.767  -78.718  50.971  1
74627  94.771  -78.727  50.930  1
74628  94.774  -78.736  50.892  1
74629  94.773  -78.744  50.850  1
74630  94.783  -78.735  50.807  1
74631  94.792  -78.727  50.762  1
74632  94.801  -78.717  50.718  1
74633  94.810  -78.709  50.676  1
74634  94.819  -78.701  50.636  1
74635  94.829  -78.693  50.596  1
74636  94.847  -78.690  50.552  1
74637  94.865  -78.686  50.508  1
74638  94.877  -78.690  50.463  1
74639  94.876  -78.705  50.419  1
74640  94.875  -78.720  50.375  1
74641  94.874  -78.736  50.332  1
74642  94.873  -78.752  50.292  1
74643  94.871  -78.767  50.253  1
74644  94.870  -78.783  50.214  1
74645  94.868  -78.798  50.177  1
74646  94.867  -78.814  50.138  1
74647  94.866  -78.829  50.099  1
74648  94.865  -78.845  50.059  1
74649  94.862  -78.855  50.019  1
74650  94.860  -78.856  49.980  1
74651  94.877  -78.859  49.941  1
74652  94.895  -78.861  49.902  1
74653  94.923  -78.856  49.863  1
74654  94.952  -78.852  49.824  1
74655  94.981  -78.847  49.786  1
74656  95.010  -78.843  49.749  1
74657  95.038  -78.838  49.710  1
74658  95.067  -78.833  49.670  1
74659  95.096  -78.829  49.629  1
74660  95.124  -78.824  49.588  1
74661  95.154  -78.826  49.548  1
74662  95.183  -78.831  49.509  1
74663  95.212  -78.837  49.469  1
74664  95.242  -78.843  49.430  1
74665  95.271  -78.849  49.389  1
74666  95.300  -78.854  49.349  1
74667  95.329  -78.860  49.307  1
74668  95.350  -78.871  49.266  1
74669  95.370  -78.882  49.224  1
74670  95.390  -78.894  49.186  1
74671  95.407  -78.902  49.148  1
74672  95.421  -78.899  49.108  1
74673  95.435  -78.897  49.067  1
74674  95.449  -78.896  49.026  1
74675  95.457  -78.902  48.984  1
74676  95.466  -78.907  48.941  1
74677  95.474  -78.913  48.900  1
74678  95.482  -78.919  48.858  1
74679  95.491  -78.925  48.816  1
74680  95.495  -78.945  48.775  1
74681  95.500  -78.965  48.734  1
74682  95.505  -78.985  48.692  1
74683  95.510  -79.005  48.651  1
74684  95.514  -79.025  48.612  1
74685  95.526  -79.040  48.571  1
74686  95.541  -79.053  48.529  1
74687  95.556  -79.067  48.484  1
74688  95.571  -79.080  48.439  1
74689  95.587  -79.093  48.393  1
74690  95.602  -79.106  48.346  1
74691  95.617  -79.120  48.298  1
74692  95.636  -79.120  48.251  1
74693  95.659  -79.107  48.204  1
74694  95.681  -79.093  48.158  1
74695  95.703  -79.081  48.111  1
74696  95.726  -79.068  48.065  1
74697  95.739  -79.061  48.020  1
74698  95.748  -79.057  47.977  1
74699  95.757  -79.053  47.934  1
74700  95.766  -79.049  47.891  1
74701  95.775  -79.046  47.849  1
74702  95.782  -79.042  47.806  1
74703  95.789  -79.038  47.763  1
74704  95.795  -79.035  47.720  1
74705  95.801  -79.031  47.677  1
74706  95.808  -79.028  47.635  1
74707  95.814  -79.024  47.594  1
74708  95.821  -79.021  47.553  1
74709  95.827  -79.017  47.512  1
74710  95.833  -79.013  47.472  1
74711  95.840  -79.009  47.431  1
74712  95.851  -79.006  47.391  1
74713  95.888  -79.002  47.351  1
74714  95.946  -79.014  47.310  1
74715  96.012  -79.031  47.272  1
74716  96.083  -79.037  47.234  1
74717  96.123  -79.040  47.197  1
74718  96.163  -79.042  47.161  1
74719  96.202  -79.045  47.125  1
74720  96.241  -79.045  47.090  1
74721  96.275  -79.032  47.054  1
74722  96.310  -79.019  47.020  1
74723  96.344  -79.006  46.988  1
74724  96.378  -78.993  46.957  1
74725  96.407  -79.031  46.927  1
74726  96.434  -79.069  46.896  1
74727  96.448  -79.070  46.864  1
74728  96.463  -79.070  46.832  1
74729  96.484  -79.078  46.799  1
74730  96.508  -79.090  46.767  1
74731  96.531  -79.102  46.736  1
74732  96.554  -79.114  46.703  1
74733  96.578  -79.125  46.672  1
74734  96.602  -79.137  46.641  1
74735  96.625  -79.149  46.609  1
74736  96.649  -79.161  46.580  1
74737  96.673  -79.172  46.551  1
74738  96.672  -79.157  46.524  1
74739  96.671  -79.140  46.495  1
74740  96.669  -79.123  46.467  1
74741  96.667  -79.106  46.439  1
74742  96.665  -79.090  46.411  1
74743  96.679  -79.080  46.384  1
74744  96.716  -79.081  46.358  1
74745  96.768  -79.085  46.334  1
74746  96.827  -79.090  46.310  1
74747  96.885  -79.095  46.285  1
74748  96.832  -79.167  46.261  1
74749  96.814  -79.175  46.236  1
74750  96.849  -79.138  46.213  1
74751  96.884  -79.103  46.189  1
74752  96.920  -79.066  46.165  1
74753  96.955  -79.030  46.141  1
74754  96.991  -79.001  46.119  1
74755  97.033  -79.046  46.097  1
74756  97.075  -79.091  46.076  1
74757  97.108  -79.128  46.056  1
74758  97.104  -79.128  46.038  1
74759  97.085  -79.115  46.020  1
74760  97.050  -79.087  46.001  1
74761  97.020  -79.062  45.981  1
74762  97.058  -79.201  45.961  1
74763  97.054  -79.206  45.942  1
74764  97.050  -79.210  45.924  1
74765  97.049  -79.194  45.906  1
74766  97.049  -79.171  45.889  1
74767  97.065  -79.150  45.871  1
74768  97.066  -79.140  45.853  1
74769  97.076  -79.130  45.834  1
74770  97.087  -79.118  45.816  1
74771  97.097  -79.107  45.799  1
74772  97.119  -79.096  45.783  1
74773  97.169  -79.121  45.767  1
74774  97.219  -79.146  45.749  1
74775  97.268  -79.171  45.732  1
74776  97.221  -79.158  45.715  1
74777  97.187  -79.158  45.697  1
74778  97.221  -79.157  45.680  1
74779  97.258  -79.156  45.664  1
74780  97.295  -79.154  45.647  1
74781  97.332  -79.153  45.631  1
74782  97.369  -79.151  45.615  1
74783  97.389  -79.163  45.599  1
74784  97.403  -79.180  45.583  1
74785  97.355  -79.222  45.568  1
74786  97.301  -79.268  45.554  1
74787  97.311  -79.265  45.539  1
74788  97.327  -79.259  45.525  1
74789  97.331  -79.256  45.510  1
74790  97.330  -79.258  45.495  1
74791  97.354  -79.259  45.480  1
74792  97.394  -79.263  45.466  1
74793  97.412  -79.279  45.452  1
74794  97.424  -79.300  45.439  1
74795  97.423  -79.311  45.424  1
74796  97.436  -79.317  45.410  1
74797  97.450  -79.322  45.395  1
74798  97.463  -79.328  45.380  1
74799  97.477  -79.334  45.367  1
74800  97.491  -79.340  45.354  1
74801  97.506  -79.348  45.341  1
74802  97.524  -79.362  45.328  1
74803  97.543  -79.376  45.315  1
74804  97.552  -79.378  45.303  1
74805  97.557  -79.373  45.290  1
74806  97.561  -79.369  45.277  1
74807  97.565  -79.365  45.264  1
74808  97.569  -79.360  45.252  1
74809  97.573  -79.356  45.241  1
74810  97.587  -79.382  45.229  1
74811  97.602  -79.410  45.217  1
74812  97.617  -79.438  45.206  1
74813  97.632  -79.465  45.196  1
74814  97.645  -79.488  45.185  1
74815  97.651  -79.494  45.175  1
74816  97.657  -79.499  45.165  1
74817  97.668  -79.578  45.154  1
74818  97.683  -79.623  45.142  1
74819  97.696  -79.630  45.130  1
74820  97.709  -79.638  45.119  1
74821  97.721  -79.645  45.108  1
74822  97.734  -79.651  45.096  1
74823  97.747  -79.659  45.085  1
74824  97.759  -79.666  45.073  1
74825  97.773  -79.673  45.061  1
74826  97.785  -79.680  45.049  1
74827  97.798  -79.688  45.037  1
74828  97.811  -79.697  45.026  1
74829  97.828  -79.709  45.016  1
74830  97.850  -79.723  45.006  1
74831  97.872  -79.738  44.997  1
74832  97.894  -79.753  44.987  1
74833  97.916  -79.768  44.978  1
74834  97.941  -79.789  44.970  1
74835  97.975  -79.818  44.962  1
74836  98.004  -79.833  44.956  1
74837  98.032  -79.849  44.949  1
74838  98.058  -79.856  44.943  1
74839  98.078  -79.852  44.938  1
74840  98.099  -79.853  44.933  1
74841  98.123  -79.863  44.928  1
74842  98.146  -79.873  44.921  1
74843  98.169  -79.882  44.913  1
74844  98.193  -79.889  44.905  1
74845  98.218  -79.896  44.897  1
74846  98.243  -79.902  44.887  1
74847  98.269  -79.908  44.876  1
74848  98.294  -79.913  44.865  1
74849  98.319  -79.919  44.852  1
74850  98.346  -79.926  44.845  1
74851  98.384  -79.937  44.839  1
74852  98.422  -79.949  44.835  1
74853  98.459  -79.961  44.831  1
74854  98.497  -79.972  44.824  1
74855  98.535  -79.984  44.816  1
74856  98.568  -79.992  44.808  1
74857  98.598  -79.996  44.797  1
74858  98.627  -80.002  44.784  1
74859  98.656  -80.006  44.771  1
74860  98.686  -80.011  44.761  1
74861  98.704  -80.021  44.752  1
74862  98.716  -80.037  44.745  1
74863  98.727  -80.052  44.737  1
74864  98.743  -80.065  44.727  1
74865  98.769  -80.073  44.717  1
74866  98.799  -80.077  44.708  1
74867  98.834  -80.077  44.700  1
74868  98.866  -80.080  44.691  1
74869  98.887  -80.089  44.683  1
74870  98.910  -80.099  44.674  1
74871  98.921  -80.098  44.666  1
74872  98.937  -80.102  44.659  1
74873  98.953  -80.108  44.652  1
74874  98.969  -80.112  44.645  1
74875  98.984  -80.120  44.638  1
74876  98.999  -80.128  44.632  1
74877  99.013  -80.137  44.626  1
74878  99.030  -80.148  44.620  1
74879  99.047  -80.159  44.615  1
74880  99.073  -80.167  44.610  1
74881  99.153  -80.204  44.605  1
74882  99.177  -80.215  44.599  1
74883  99.200  -80.225  44.593  1
74884  99.223  -80.235  44.589  1
74885  99.246  -80.246  44.585  1
74886  99.270  -80.256  44.580  1
74887  99.293  -80.267  44.577  1
74888  99.330  -80.272  44.573  1
74889  99.369  -80.275  44.569  1
74890  99.407  -80.279  44.565  1
74891  99.446  -80.284  44.562  1
74892  99.485  -80.287  44.558  1
74893  99.523  -80.291  44.555  1
74894  99.550  -80.301  44.550  1
74895  99.554  -80.323  44.546  1
74896  99.557  -80.345  44.541  1
74897  99.560  -80.367  44.536  1
74898  99.563  -80.390  44.531  1
74899  99.566  -80.412  44.526  1
74900  99.570  -80.434  44.522  1
74901  99.573  -80.456  44.516  1
74902  99.576  -80.478  44.510  1
75218  93.544  -78.915  53.497  1
75219  93.553  -78.912  53.488  1
75220  93.563  -78.910  53.478  1
75221  93.574  -78.902  53.469  1
75222  93.583  -78.894  53.461  1
75223  93.591  -78.886  53.452  1
75224  93.600  -78.880  53.443  1
75225  93.608  -78.873  53.437  1
75226  93.616  -78.866  53.429  1
75227  93.664  -78.842  53.423  1
75228  93.725  -78.810  53.417  1
75229  93.723  -78.808  53.414  1
75230  93.714  -78.805  53.412  1
75231  93.703  -78.802  53.410  1
75232  93.692  -78.799  53.407  1
75233  93.692  -78.803  53.404  1
75234  93.705  -78.816  53.398  1
75235  93.713  -78.817  53.391  1
75236  93.720  -78.816  53.382  1
75237  93.727  -78.814  53.373  1
75238  93.734  -78.811  53.363  1
75239  93.741  -78.808  53.352  1
75240  93.748  -78.805  53.341  1
75241  93.755  -78.803  53.327  1
75242  93.762  -78.800  53.314  1
75243  93.769  -78.797  53.301  1
75244  93.781  -78.791  53.286  1
75245  93.806  -78.777  53.270  1
75246  93.810  -78.768  53.254  1
75247  93.814  -78.760  53.235  1
75248  93.825  -78.752  53.214  1
75249  93.839  -78.744  53.193  1
75250  93.853  -78.736  53.172  1
75251  93.867  -78.728  53.151  1
75252  93.878  -78.721  53.130  1
75253  93.884  -78.717  53.109  1
75254  93.889  -78.712  53.085  1
75255  93.894  -78.708  53.060  1
75256  93.899  -78.703  53.034  1
75257  93.905  -78.698  53.009  1
75258  93.913  -78.694  52.984  1
75259  93.929  -78.687  52.958  1
75260  93.944  -78.681  52.933  1
75261  93.961  -78.675  52.907  1
75262  93.976  -78.669  52.881  1
75263  93.992  -78.662  52.855  1
75264  94.008  -78.656  52.831  1
75265  94.024  -78.650  52.808  1
75266  94.039  -78.645  52.787  1
75267  94.048  -78.643  52.765  1
75268  94.058  -78.642  52.743  1
75269  94.068  -78.639  52.721  1
75270  94.078  -78.638  52.700  1
75271  94.088  -78.636  52.677  1
75272  94.088  -78.642  52.654  1
75273  94.088  -78.649  52.631  1
75274  94.092  -78.657  52.608  1
75275  94.097  -78.664  52.583  1
75276  94.117  -78.629  52.558  1
75277  94.142  -78.601  52.533  1
75278  94.194  -78.614  52.509  1
75279  94.246  -78.628  52.486  1
75280  94.291  -78.639  52.463  1
75281  94.301  -78.636  52.440  1
75282  94.311  -78.633  52.417  1
75283  94.321  -78.631  52.393  1
75284  94.324  -78.634  52.371  1
75285  94.316  -78.646  52.349  1
75286  94.309  -78.658  52.326  1
75287  94.300  -78.670  52.302  1
75288  94.297  -78.677  52.278  1
75289  94.314  -78.665  52.251  1
75290  94.330  -78.653  52.224  1
75291  94.344  -78.644  52.197  1
75292  94.352  -78.642  52.172  1
75293  94.361  -78.639  52.145  1
75294  94.370  -78.637  52.117  1
75295  94.379  -78.636  52.091  1
75296  94.387  -78.633  52.064  1
75297  94.396  -78.631  52.036  1
75298  94.410  -78.630  52.005  1
75299  94.427  -78.631  51.974  1
75300  94.438  -78.636  51.942  1
75301  94.449  -78.642  51.909  1
75302  94.459  -78.647  51.876  1
75303  94.470  -78.651  51.846  1
75304  94.480  -78.675  51.815  1
75305  94.493  -78.688  51.781  1
75306  94.508  -78.687  51.746  1
75307  94.524  -78.686  51.710  1
75308  94.539  -78.686  51.672  1
75309  94.553  -78.686  51.632  1
75310  94.568  -78.685  51.593  1
75311  94.583  -78.684  51.555  1
75312  94.599  -78.683  51.519  1
75313  94.614  -78.683  51.484  1
75314  94.629  -78.682  51.452  1
75315  94.643  -78.681  51.420  1
75316  94.659  -78.680  51.390  1
75317  94.674  -78.680  51.361  1
75318  94.686  -78.679  51.331  1
75319  94.697  -78.681  51.297  1
75320  94.708  -78.683  51.262  1
75321  94.718  -78.686  51.226  1
75322  94.730  -78.688  51.189  1
75323  94.740  -78.690  51.149  1
75324  94.748  -78.695  51.109  1
75325  94.754  -78.703  51.067  1
75326  94.760  -78.711  51.026  1
75327  94.765  -78.718  50.984  1
75328  94.771  -78.726  50.942  1
75329  94.776  -78.733  50.903  1
75330  94.783  -78.733  50.862  1
75331  94.791  -78.724  50.819  1
75332  94.799  -78.720  50.774  1
75333  94.807  -78.711  50.730  1
75334  94.816  -78.703  50.689  1
75335  94.825  -78.695  50.649  1
75336  94.834  -78.686  50.608  1
75337  94.845  -78.679  50.564  1
75338  94.863  -78.676  50.519  1
75339  94.876  -78.678  50.474  1
75340  94.875  -78.694  50.429  1
75341  94.874  -78.709  50.385  1
75342  94.872  -78.724  50.342  1
75343  94.871  -78.740  50.302  1
75344  94.870  -78.755  50.261  1
75345  94.868  -78.771  50.221  1
75346  94.867  -78.786  50.183  1
75347  94.866  -78.802  50.144  1
75348  94.865  -78.818  50.105  1
75349  94.864  -78.833  50.064  1
75350  94.862  -78.849  50.023  1
75351  94.861  -78.858  49.984  1
75352  94.883  -78.858  49.945  1
75353  94.912  -78.852  49.905  1
75354  94.941  -78.848  49.863  1
75355  94.969  -78.843  49.823  1
75356  94.998  -78.839  49.784  1
75357  95.027  -78.834  49.747  1
75358  95.055  -78.830  49.707  1
75359  95.084  -78.825  49.666  1
75360  95.113  -78.821  49.625  1
75361  95.141  -78.816  49.585  1
75362  95.170  -78.811  49.545  1
75363  95.200  -78.817  49.504  1
75364  95.229  -78.822  49.466  1
75365  95.258  -78.828  49.426  1
75366  95.287  -78.833  49.386  1
75367  95.312  -78.843  49.346  1
75368  95.331  -78.854  49.304  1
75369  95.351  -78.866  49.263  1
75370  95.370  -78.877  49.221  1
75371  95.390  -78.890  49.183  1
75372  95.408  -78.898  49.144  1
75373  95.422  -78.896  49.104  1
75374  95.436  -78.893  49.064  1
75375  95.450  -78.891  49.023  1
75376  95.464  -78.888  48.982  1
75377  95.474  -78.890  48.941  1
75378  95.483  -78.896  48.899  1
75379  95.491  -78.902  48.858  1
75380  95.500  -78.908  48.817  1
75381  95.506  -78.923  48.776  1
75382  95.511  -78.943  48.734  1
75383  95.515  -78.963  48.694  1
75384  95.520  -78.984  48.655  1
75385  95.531  -78.999  48.615  1
75386  95.546  -79.012  48.576  1
75387  95.562  -79.025  48.535  1
75388  95.577  -79.039  48.490  1
75389  95.592  -79.052  48.444  1
75390  95.607  -79.065  48.397  1
75391  95.622  -79.078  48.350  1
75392  95.637  -79.092  48.303  1
75393  95.653  -79.105  48.256  1
75394  95.673  -79.100  48.209  1
75395  95.695  -79.087  48.161  1
75396  95.718  -79.074  48.115  1
75397  95.737  -79.062  48.070  1
75398  95.746  -79.059  48.026  1
75399  95.755  -79.055  47.984  1
75400  95.765  -79.051  47.942  1
75401  95.774  -79.047  47.899  1
75402  95.783  -79.044  47.856  1
75403  95.792  -79.040  47.812  1
75404  95.798  -79.037  47.768  1
75405  95.805  -79.033  47.726  1
75406  95.811  -79.029  47.683  1
75407  95.817  -79.025  47.641  1
75408  95.824  -79.022  47.599  1
75409  95.830  -79.018  47.558  1
75410  95.836  -79.015  47.518  1
75411  95.843  -79.011  47.478  1
75412  95.849  -79.008  47.437  1
75413  95.882  -79.004  47.396  1
75414  95.918  -78.999  47.355  1
75415  95.955  -78.996  47.316  1
75416  96.014  -79.008  47.277  1
75417  96.085  -79.018  47.239  1
75418  96.125  -79.021  47.201  1
75419  96.165  -79.024  47.165  1
75420  96.204  -79.027  47.129  1
75421  96.244  -79.030  47.094  1
75422  96.284  -79.031  47.059  1
75423  96.318  -79.018  47.025  1
75424  96.352  -79.005  46.992  1
75425  96.386  -78.992  46.962  1
75426  96.415  -79.031  46.932  1
75427  96.435  -79.049  46.901  1
75428  96.450  -79.049  46.870  1
75429  96.471  -79.058  46.839  1
75430  96.495  -79.070  46.805  1
75431  96.519  -79.082  46.772  1
75432  96.542  -79.093  46.741  1
75433  96.566  -79.106  46.709  1
75434  96.590  -79.117  46.678  1
75435  96.613  -79.129  46.647  1
75436  96.637  -79.140  46.615  1
75437  96.661  -79.153  46.585  1
75438  96.684  -79.164  46.557  1
75439  96.693  -79.159  46.529  1
75440  96.691  -79.142  46.499  1
75441  96.689  -79.125  46.471  1
75442  96.687  -79.109  46.443  1
75443  96.688  -79.090  46.415  1
75444  96.690  -79.071  46.388  1
75445  96.751  -79.039  46.362  1
75446  96.791  -79.075  46.336  1
75447  96.849  -79.080  46.312  1
75448  96.908  -79.085  46.288  1
75449  96.876  -79.131  46.264  1
75450  96.853  -79.125  46.240  1
75451  96.876  -79.093  46.216  1
75452  96.900  -79.062  46.192  1
75453  96.925  -79.030  46.168  1
75454  96.960  -78.993  46.146  1
75455  96.999  -78.996  46.124  1
75456  97.041  -79.041  46.102  1
75457  97.083  -79.086  46.083  1
75458  97.110  -79.117  46.064  1
75459  97.075  -79.088  46.045  1
75460  97.040  -79.060  46.028  1
75461  97.005  -79.032  46.009  1
75462  97.011  -79.048  45.989  1
75463  97.049  -79.222  45.969  1
75464  97.045  -79.226  45.950  1
75465  97.043  -79.211  45.932  1
75466  97.044  -79.191  45.915  1
75467  97.050  -79.182  45.898  1
75468  97.058  -79.172  45.881  1
75469  97.069  -79.161  45.864  1
75470  97.080  -79.150  45.848  1
75471  97.091  -79.138  45.830  1
75472  97.100  -79.124  45.814  1
75473  97.104  -79.101  45.798  1
75474  97.124  -79.086  45.781  1
75475  97.162  -79.079  45.763  1
75476  97.207  -79.092  45.745  1
75477  97.224  -79.104  45.727  1
75478  97.214  -79.122  45.708  1
75479  97.231  -79.159  45.690  1
75480  97.262  -79.162  45.674  1
75481  97.296  -79.159  45.657  1
75482  97.329  -79.158  45.640  1
75483  97.363  -79.156  45.624  1
75484  97.397  -79.153  45.609  1
75485  97.399  -79.172  45.593  1
75486  97.345  -79.216  45.578  1
75487  97.300  -79.255  45.564  1
75488  97.309  -79.255  45.550  1
75489  97.320  -79.255  45.536  1
75490  97.331  -79.256  45.522  1
75491  97.343  -79.256  45.507  1
75492  97.373  -79.259  45.493  1
75493  97.404  -79.266  45.478  1
75494  97.402  -79.291  45.465  1
75495  97.410  -79.297  45.451  1
75496  97.423  -79.301  45.436  1
75497  97.436  -79.307  45.422  1
75498  97.450  -79.313  45.407  1
75499  97.463  -79.319  45.393  1
75500  97.477  -79.324  45.379  1
75501  97.490  -79.330  45.366  1
75502  97.504  -79.335  45.353  1
75503  97.522  -79.349  45.340  1
75504  97.541  -79.363  45.327  1
75505  97.560  -79.377  45.314  1
75506  97.579  -79.391  45.301  1
75507  97.583  -79.387  45.288  1
75508  97.587  -79.382  45.275  1
75509  97.591  -79.378  45.263  1
75510  97.595  -79.375  45.251  1
75511  97.610  -79.402  45.240  1
75512  97.626  -79.430  45.228  1
75513  97.640  -79.457  45.217  1
75514  97.649  -79.469  45.207  1
75515  97.655  -79.474  45.197  1
75516  97.661  -79.479  45.187  1
75517  97.667  -79.485  45.178  1
75518  97.677  -79.557  45.168  1
75519  97.693  -79.589  45.157  1
75520  97.707  -79.606  45.145  1
75521  97.720  -79.613  45.134  1
75522  97.733  -79.620  45.123  1
75523  97.745  -79.627  45.111  1
75524  97.758  -79.635  45.100  1
75525  97.771  -79.642  45.088  1
75526  97.784  -79.649  45.076  1
75527  97.796  -79.656  45.064  1
75528  97.810  -79.666  45.052  1
75529  97.825  -79.677  45.040  1
75530  97.841  -79.689  45.031  1
75531  97.862  -79.702  45.022  1
75532  97.883  -79.717  45.013  1
75533  97.906  -79.732  45.004  1
75534  97.927  -79.746  44.995  1
75535  97.964  -79.786  44.987  1
75536  98.003  -79.831  44.980  1
75537  98.027  -79.835  44.974  1
75538  98.047  -79.831  44.967  1
75539  98.068  -79.827  44.959  1
75540  98.088  -79.823  44.952  1
75541  98.110  -79.828  44.948  1
75542  98.133  -79.838  44.944  1
75543  98.157  -79.848  44.939  1
75544  98.180  -79.860  44.932  1
75545  98.205  -79.866  44.923  1
75546  98.230  -79.871  44.912  1
75547  98.255  -79.877  44.902  1
75548  98.281  -79.883  44.889  1
75549  98.306  -79.888  44.875  1
75550  98.331  -79.894  44.862  1
75551  98.357  -79.900  44.853  1
75552  98.395  -79.911  44.847  1
75553  98.433  -79.924  44.842  1
75554  98.471  -79.935  44.836  1
75555  98.508  -79.947  44.830  1
75556  98.542  -79.956  44.821  1
75557  98.574  -79.963  44.812  1
75558  98.603  -79.968  44.801  1
75559  98.633  -79.973  44.790  1
75560  98.662  -79.977  44.778  1
75561  98.689  -79.983  44.768  1
75562  98.701  -79.999  44.759  1
75563  98.712  -80.014  44.752  1
75564  98.733  -80.024  44.745  1
75565  98.759  -80.033  44.736  1
75566  98.784  -80.041  44.726  1
75567  98.812  -80.047  44.718  1
75568  98.847  -80.047  44.709  1
75569  98.874  -80.053  44.701  1
75570  98.895  -80.062  44.692  1
75571  98.916  -80.072  44.684  1
75572  98.938  -80.082  44.677  1
75573  98.952  -80.085  44.669  1
75574  98.969  -80.090  44.663  1
75575  98.985  -80.094  44.657  1
75576  99.001  -80.099  44.650  1
75577  99.017  -80.104  44.643  1
75578  99.031  -80.112  44.638  1
75579  99.046  -80.121  44.632  1
75580  99.061  -80.129  44.627  1
75581  99.076  -80.138  44.622  1
75582  99.092  -80.149  44.616  1
75583  99.156  -80.176  44.611  1
75584  99.204  -80.198  44.605  1
75585  99.227  -80.208  44.601  1
75586  99.251  -80.218  44.596  1
75587  99.274  -80.229  44.591  1
75588  99.302  -80.237  44.588  1
75589  99.341  -80.241  44.584  1
75590  99.379  -80.245  44.580  1
75591  99.418  -80.250  44.576  1
75592  99.457  -80.253  44.573  1
75593  99.495  -80.257  44.569  1
75594  99.534  -80.261  44.564  1
75595  99.547  -80.278  44.560  1
75596  99.550  -80.300  44.556  1
75597  99.553  -80.322  44.551  1
75598  99.556  -80.344  44.546  1
75599  99.560  -80.367  44.541  1
75600  99.563  -80.389  44.535  1
75601  99.566  -80.411  44.530  1
75602  99.569  -80.433  44.524  1
75603  99.572  -80.455  44.518  1
75604  99.576  -80.478  44.512  1
75605  99.579  -80.500  44.505  1
75606  99.582  -80.522  44.498  1
75607  99.585  -80.544  44.491  1
75608  99.588  -80.566  44.483  1
75609  99.592  -80.588  44.476  1
75610  99.595  -80.610  44.468  1
75611  99.598  -80.632  44.460  1
75612  99.602  -80.654  44.452  1
75613  99.605  -80.677  44.443  1
75614  99.608  -80.699  44.434  1
75615  99.611  -80.721  44.426  1
75616  99.615  -80.743  44.416  1
75617  99.632  -80.760  44.407  1
75919  93.544  -78.904  53.510  1
75920  93.553  -78.901  53.501  1
75921  93.563  -78.899  53.491  1
75922  93.573  -78.896  53.481  1
75923  93.584  -78.887  53.474  1
75924  93.592  -78.880  53.465  1
75925  93.601  -78.874  53.456  1
75926  93.609  -78.866  53.450  1
75927  93.618  -78.859  53.442  1
75928  93.652  -78.841  53.437  1
75929  93.717  -78.808  53.433  1
75930  93.712  -78.806  53.430  1
75931  93.710  -78.805  53.428  1
75932  93.703  -78.802  53.427  1
75933  93.692  -78.799  53.426  1
75934  93.691  -78.802  53.420  1
75935  93.702  -78.809  53.414  1
75936  93.709  -78.809  53.407  1
75937  93.716  -78.808  53.398  1
75938  93.723  -78.807  53.387  1
75939  93.730  -78.804  53.377  1
75940  93.737  -78.801  53.368  1
75941  93.744  -78.799  53.355  1
75942  93.751  -78.796  53.342  1
75943  93.758  -78.793  53.328  1
75944  93.768  -78.788  53.314  1
75945  93.793  -78.774  53.298  1
75946  93.808  -78.763  53.282  1
75947  93.812  -78.754  53.265  1
75948  93.815  -78.745  53.245  1
75949  93.824  -78.737  53.224  1
75950  93.838  -78.730  53.202  1
75951  93.852  -78.721  53.181  1
75952  93.866  -78.714  53.160  1
75953  93.880  -78.705  53.140  1
75954  93.894  -78.697  53.118  1
75955  93.901  -78.692  53.095  1
75956  93.906  -78.688  53.070  1
75957  93.912  -78.683  53.044  1
75958  93.917  -78.679  53.018  1
75959  93.928  -78.673  52.993  1
75960  93.944  -78.667  52.967  1
75961  93.960  -78.661  52.941  1
75962  93.976  -78.655  52.916  1
75963  93.992  -78.648  52.891  1
75964  94.008  -78.642  52.866  1
75965  94.018  -78.640  52.844  1
75966  94.028  -78.639  52.822  1
75967  94.038  -78.636  52.800  1
75968  94.048  -78.635  52.781  1
75969  94.058  -78.633  52.758  1
75970  94.067  -78.632  52.735  1
75971  94.077  -78.630  52.713  1
75972  94.085  -78.630  52.690  1
75973  94.084  -78.636  52.668  1
75974  94.083  -78.642  52.645  1
75975  94.088  -78.646  52.622  1
75976  94.108  -78.611  52.597  1
75977  94.128  -78.574  52.572  1
75978  94.179  -78.586  52.547  1
75979  94.230  -78.599  52.522  1
75980  94.282  -78.613  52.499  1
75981  94.314  -78.619  52.476  1
75982  94.324  -78.616  52.455  1
75983  94.334  -78.614  52.432  1
75984  94.338  -78.616  52.409  1
75985  94.330  -78.628  52.387  1
75986  94.322  -78.640  52.366  1
75987  94.315  -78.652  52.344  1
75988  94.307  -78.664  52.321  1
75989  94.299  -78.676  52.297  1
75990  94.316  -78.664  52.271  1
75991  94.332  -78.651  52.244  1
75992  94.349  -78.639  52.218  1
75993  94.362  -78.631  52.193  1
75994  94.370  -78.629  52.167  1
75995  94.379  -78.626  52.139  1
75996  94.388  -78.624  52.112  1
75997  94.396  -78.622  52.084  1
75998  94.405  -78.620  52.055  1
75999  94.419  -78.619  52.024  1
76000  94.437  -78.620  51.992  1
76001  94.450  -78.623  51.959  1
76002  94.461  -78.628  51.926  1
76003  94.472  -78.633  51.893  1
76004  94.482  -78.644  51.862  1
76005  94.492  -78.677  51.830  1
76006  94.505  -78.692  51.795  1
76007  94.520  -78.692  51.759  1
76008  94.535  -78.691  51.723  1
76009  94.550  -78.690  51.684  1
76010  94.565  -78.690  51.644  1
76011  94.580  -78.689  51.605  1
76012  94.596  -78.689  51.566  1
76013  94.610  -78.688  51.531  1
76014  94.625  -78.687  51.496  1
76015  94.640  -78.686  51.464  1
76016  94.653  -78.683  51.433  1
76017  94.665  -78.680  51.403  1
76018  94.677  -78.676  51.374  1
76019  94.688  -78.673  51.344  1
76020  94.699  -78.675  51.310  1
76021  94.710  -78.677  51.274  1
76022  94.720  -78.680  51.237  1
76023  94.732  -78.682  51.199  1
76024  94.744  -78.684  51.160  1
76025  94.758  -78.689  51.120  1
76026  94.764  -78.697  51.080  1
76027  94.769  -78.705  51.038  1
76028  94.775  -78.712  50.996  1
76029  94.780  -78.720  50.954  1
76030  94.786  -78.727  50.914  1
76031  94.793  -78.724  50.873  1
76032  94.803  -78.711  50.832  1
76033  94.812  -78.698  50.787  1
76034  94.819  -78.695  50.742  1
76035  94.825  -78.692  50.700  1
76036  94.832  -78.688  50.660  1
76037  94.841  -78.680  50.618  1
76038  94.849  -78.671  50.574  1
76039  94.862  -78.664  50.529  1
76040  94.875  -78.667  50.484  1
76041  94.873  -78.682  50.438  1
76042  94.872  -78.698  50.393  1
76043  94.871  -78.713  50.349  1
76044  94.870  -78.728  50.310  1
76045  94.868  -78.744  50.270  1
76046  94.867  -78.759  50.231  1
76047  94.866  -78.775  50.192  1
76048  94.865  -78.790  50.153  1
76049  94.867  -78.804  50.113  1
76050  94.868  -78.818  50.071  1
76051  94.871  -78.833  50.028  1
76052  94.876  -78.844  49.987  1
76053  94.896  -78.846  49.946  1
76054  94.926  -78.842  49.904  1
76055  94.956  -78.838  49.862  1
76056  94.986  -78.834  49.821  1
76057  95.015  -78.830  49.781  1
76058  95.044  -78.826  49.743  1
76059  95.072  -78.821  49.704  1
76060  95.101  -78.817  49.663  1
76061  95.130  -78.812  49.622  1
76062  95.159  -78.808  49.583  1
76063  95.187  -78.803  49.543  1
76064  95.216  -78.802  49.504  1
76065  95.246  -78.808  49.464  1
76066  95.273  -78.814  49.424  1
76067  95.293  -78.826  49.383  1
76068  95.312  -78.838  49.344  1
76069  95.331  -78.849  49.303  1
76070  95.351  -78.861  49.261  1
76071  95.371  -78.873  49.220  1
76072  95.390  -78.885  49.181  1
76073  95.408  -78.893  49.142  1
76074  95.422  -78.891  49.102  1
76075  95.436  -78.889  49.062  1
76076  95.450  -78.886  49.021  1
76077  95.464  -78.884  48.981  1
76078  95.478  -78.882  48.942  1
76079  95.492  -78.880  48.901  1
76080  95.500  -78.885  48.859  1
76081  95.509  -78.891  48.817  1
76082  95.516  -78.902  48.776  1
76083  95.521  -78.921  48.735  1
76084  95.525  -78.942  48.694  1
76085  95.537  -78.958  48.654  1
76086  95.552  -78.971  48.614  1
76087  95.567  -78.984  48.574  1
76088  95.582  -78.997  48.534  1
76089  95.597  -79.011  48.492  1
76090  95.612  -79.024  48.447  1
76091  95.627  -79.037  48.401  1
76092  95.643  -79.050  48.356  1
76093  95.658  -79.064  48.309  1
76094  95.673  -79.077  48.261  1
76095  95.688  -79.090  48.212  1
76096  95.710  -79.081  48.164  1
76097  95.732  -79.068  48.119  1
76098  95.745  -79.061  48.076  1
76099  95.754  -79.057  48.032  1
76100  95.763  -79.053  47.991  1
76101  95.772  -79.049  47.949  1
76102  95.781  -79.046  47.906  1
76103  95.791  -79.042  47.862  1
76104  95.800  -79.038  47.819  1
76105  95.808  -79.034  47.776  1
76106  95.814  -79.031  47.734  1
76107  95.820  -79.028  47.691  1
76108  95.827  -79.024  47.648  1
76109  95.833  -79.020  47.605  1
76110  95.840  -79.016  47.565  1
76111  95.846  -79.013  47.524  1
76112  95.852  -79.009  47.483  1
76113  95.877  -79.006  47.442  1
76114  95.913  -79.002  47.401  1
76115  95.950  -78.997  47.361  1
76116  95.986  -78.993  47.321  1
76117  96.023  -78.990  47.282  1
76118  96.087  -79.000  47.245  1
76119  96.127  -79.003  47.208  1
76120  96.167  -79.006  47.171  1
76121  96.206  -79.009  47.135  1
76122  96.246  -79.012  47.099  1
76123  96.286  -79.014  47.063  1
76124  96.326  -79.016  47.031  1
76125  96.360  -79.003  46.998  1
76126  96.394  -78.991  46.967  1
76127  96.422  -79.028  46.937  1
76128  96.437  -79.028  46.906  1
76129  96.459  -79.038  46.875  1
76130  96.483  -79.049  46.844  1
76131  96.507  -79.062  46.813  1
76132  96.530  -79.073  46.780  1
76133  96.554  -79.085  46.748  1
76134  96.578  -79.096  46.716  1
76135  96.601  -79.109  46.684  1
76136  96.625  -79.120  46.653  1
76137  96.649  -79.132  46.621  1
76138  96.672  -79.143  46.592  1
76139  96.696  -79.156  46.563  1
76140  96.714  -79.161  46.534  1
76141  96.716  -79.142  46.505  1
76142  96.718  -79.123  46.476  1
76143  96.720  -79.104  46.447  1
76144  96.722  -79.085  46.419  1
76145  96.724  -79.066  46.393  1
76146  96.788  -79.032  46.367  1
76147  96.862  -78.996  46.342  1
76148  96.915  -79.001  46.318  1
76149  96.949  -79.045  46.293  1
76150  96.938  -79.068  46.269  1
76151  96.911  -79.065  46.244  1
76152  96.915  -79.045  46.220  1
76153  96.939  -79.012  46.197  1
76154  96.958  -78.983  46.174  1
76155  96.970  -78.958  46.153  1
76156  96.978  -78.976  46.131  1
76157  96.979  -78.987  46.110  1
76158  97.012  -79.026  46.091  1
76159  97.034  -79.056  46.073  1
76160  96.991  -79.025  46.055  1
76161  96.979  -79.006  46.037  1
76162  96.976  -78.987  46.018  1
76163  97.007  -79.090  45.999  1
76164  97.039  -79.241  45.979  1
76165  97.038  -79.228  45.960  1
76166  97.043  -79.219  45.942  1
76167  97.049  -79.211  45.925  1
76168  97.055  -79.202  45.908  1
76169  97.063  -79.193  45.892  1
76170  97.074  -79.181  45.876  1
76171  97.085  -79.170  45.859  1
76172  97.095  -79.159  45.841  1
76173  97.101  -79.139  45.824  1
76174  97.106  -79.117  45.808  1
76175  97.110  -79.094  45.792  1
76176  97.131  -79.078  45.774  1
76177  97.168  -79.071  45.756  1
76178  97.205  -79.064  45.738  1
76179  97.230  -79.094  45.719  1
76180  97.254  -79.125  45.701  1
76181  97.275  -79.159  45.685  1
76182  97.303  -79.166  45.669  1
76183  97.334  -79.161  45.652  1
76184  97.366  -79.156  45.636  1
76185  97.397  -79.150  45.620  1
76186  97.407  -79.162  45.605  1
76187  97.401  -79.182  45.591  1
76188  97.349  -79.227  45.577  1
76189  97.322  -79.253  45.562  1
76190  97.333  -79.253  45.548  1
76191  97.344  -79.253  45.534  1
76192  97.355  -79.254  45.520  1
76193  97.392  -79.257  45.506  1
76194  97.399  -79.277  45.492  1
76195  97.404  -79.288  45.478  1
76196  97.414  -79.291  45.464  1
76197  97.425  -79.294  45.449  1
76198  97.436  -79.297  45.435  1
76199  97.450  -79.303  45.421  1
76200  97.463  -79.309  45.406  1
76201  97.476  -79.314  45.393  1
76202  97.490  -79.320  45.380  1
76203  97.504  -79.325  45.367  1
76204  97.520  -79.336  45.354  1
76205  97.539  -79.350  45.340  1
76206  97.558  -79.364  45.326  1
76207  97.577  -79.378  45.313  1
76208  97.596  -79.392  45.300  1
76209  97.609  -79.400  45.288  1
76210  97.613  -79.395  45.274  1
76211  97.619  -79.394  45.262  1
76212  97.634  -79.422  45.250  1
76213  97.647  -79.444  45.239  1
76214  97.653  -79.450  45.229  1
76215  97.658  -79.455  45.220  1
76216  97.664  -79.460  45.211  1
76217  97.670  -79.466  45.201  1
76218  97.676  -79.472  45.192  1
76219  97.687  -79.525  45.183  1
76220  97.703  -79.556  45.174  1
76221  97.719  -79.582  45.162  1
76222  97.731  -79.588  45.150  1
76223  97.744  -79.596  45.139  1
76224  97.757  -79.603  45.127  1
76225  97.770  -79.610  45.115  1
76226  97.782  -79.617  45.103  1
76227  97.795  -79.624  45.090  1
76228  97.809  -79.635  45.078  1
76229  97.823  -79.647  45.067  1
76230  97.838  -79.658  45.056  1
76231  97.853  -79.670  45.048  1
76232  97.874  -79.683  45.040  1
76233  97.895  -79.696  45.032  1
76234  97.917  -79.710  45.021  1
76235  97.947  -79.739  45.013  1
76236  97.961  -79.744  45.005  1
76237  97.971  -79.741  44.998  1
76238  97.996  -79.752  44.991  1
76239  98.030  -79.766  44.984  1
76240  98.064  -79.780  44.977  1
76241  98.097  -79.794  44.971  1
76242  98.121  -79.805  44.963  1
76243  98.144  -79.817  44.957  1
76244  98.167  -79.829  44.951  1
76245  98.192  -79.839  44.943  1
76246  98.217  -79.843  44.934  1
76247  98.242  -79.848  44.923  1
76248  98.267  -79.852  44.910  1
76249  98.293  -79.858  44.896  1
76250  98.318  -79.863  44.882  1
76251  98.343  -79.869  44.870  1
76252  98.368  -79.875  44.860  1
76253  98.406  -79.886  44.853  1
76254  98.443  -79.898  44.846  1
76255  98.481  -79.910  44.840  1
76256  98.515  -79.918  44.832  1
76257  98.547  -79.925  44.824  1
76258  98.578  -79.933  44.815  1
76259  98.609  -79.939  44.805  1
76260  98.639  -79.944  44.795  1
76261  98.668  -79.949  44.785  1
76262  98.685  -79.961  44.776  1
76263  98.698  -79.975  44.767  1
76264  98.723  -79.983  44.759  1
76265  98.748  -79.992  44.753  1
76266  98.774  -80.000  44.745  1
76267  98.799  -80.008  44.736  1
76268  98.825  -80.017  44.728  1
76269  98.860  -80.018  44.719  1
76270  98.881  -80.027  44.710  1
76271  98.903  -80.036  44.701  1
76272  98.924  -80.044  44.694  1
76273  98.944  -80.043  44.687  1
76274  98.961  -80.047  44.680  1
76275  98.981  -80.061  44.675  1
76276  99.000  -80.075  44.669  1
76277  99.016  -80.081  44.662  1
76278  99.032  -80.086  44.655  1
76279  99.049  -80.091  44.651  1
76280  99.065  -80.096  44.646  1
76281  99.079  -80.105  44.641  1
76282  99.093  -80.113  44.635  1
76283  99.108  -80.121  44.629  1
76284  99.123  -80.130  44.624  1
76285  99.153  -80.145  44.619  1
76286  99.231  -80.181  44.613  1
76287  99.255  -80.191  44.608  1
76288  99.278  -80.202  44.604  1
76289  99.313  -80.207  44.600  1
76290  99.352  -80.211  44.596  1
76291  99.391  -80.215  44.592  1
76292  99.429  -80.219  44.587  1
76293  99.468  -80.223  44.583  1
76294  99.506  -80.227  44.579  1
76295  99.540  -80.233  44.575  1
76296  99.543  -80.256  44.570  1
76297  99.547  -80.278  44.566  1
76298  99.550  -80.300  44.561  1
76299  99.553  -80.322  44.556  1
76300  99.556  -80.344  44.550  1
76301  99.559  -80.366  44.544  1
76302  99.563  -80.388  44.538  1
76303  99.566  -80.410  44.532  1
76304  99.569  -80.432  44.526  1
76305  99.572  -80.455  44.520  1
76306  99.575  -80.477  44.513  1
76307  99.579  -80.499  44.505  1
76308  99.582  -80.521  44.497  1
76309  99.585  -80.543  44.490  1
76310  99.588  -80.566  44.482  1
76311  99.591  -80.588  44.474  1
76312  99.595  -80.610  44.466  1
76313  99.598  -80.632  44.458  1
76314  99.601  -80.654  44.449  1
76315  99.605  -80.676  44.440  1
76316  99.608  -80.698  44.431  1
76317  99.611  -80.720  44.421  1
76318  99.640  -80.733  44.412  1
76319  99.688  -80.739  44.402  1
76320  99.736  -80.744  44.391  1
76321  99.784  -80.750  44.381  1
76620  93.544  -78.893  53.523  1
76621  93.554  -78.890  53.513  1
76622  93.563  -78.888  53.503  1
76623  93.573  -78.885  53.493  1
76624  93.582  -78.883  53.486  1
76625  93.593  -78.874  53.478  1
76626  93.602  -78.867  53.470  1
76627  93.610  -78.860  53.463  1
76628  93.619  -78.853  53.456  1
76629  93.641  -78.840  53.451  1
76630  93.709  -78.806  53.448  1
76631  93.700  -78.805  53.447  1
76632  93.698  -78.802  53.446  1
76633  93.697  -78.801  53.445  1
76634  93.692  -78.799  53.443  1
76635  93.690  -78.802  53.437  1
76636  93.698  -78.802  53.430  1
76637  93.705  -78.802  53.422  1
76638  93.711  -78.801  53.412  1
76639  93.718  -78.799  53.402  1
76640  93.726  -78.797  53.393  1
76641  93.733  -78.794  53.382  1
76642  93.740  -78.791  53.370  1
76643  93.747  -78.788  53.356  1
76644  93.755  -78.785  53.342  1
76645  93.779  -78.771  53.327  1
76646  93.804  -78.757  53.310  1
76647  93.809  -78.749  53.293  1
76648  93.813  -78.739  53.275  1
76649  93.816  -78.731  53.255  1
76650  93.823  -78.723  53.234  1
76651  93.837  -78.715  53.213  1
76652  93.851  -78.707  53.191  1
76653  93.865  -78.699  53.172  1
76654  93.879  -78.691  53.152  1
76655  93.893  -78.683  53.130  1
76656  93.907  -78.675  53.106  1
76657  93.919  -78.667  53.080  1
76658  93.924  -78.663  53.054  1
76659  93.929  -78.659  53.029  1
76660  93.943  -78.653  53.003  1
76661  93.960  -78.646  52.977  1
76662  93.976  -78.640  52.951  1
76663  93.987  -78.637  52.926  1
76664  93.997  -78.636  52.901  1
76665  94.007  -78.633  52.878  1
76666  94.017  -78.632  52.857  1
76667  94.027  -78.630  52.836  1
76668  94.037  -78.629  52.815  1
76669  94.047  -78.627  52.796  1
76670  94.057  -78.626  52.773  1
76671  94.067  -78.623  52.750  1
76672  94.077  -78.622  52.728  1
76673  94.082  -78.623  52.705  1
76674  94.081  -78.630  52.682  1
76675  94.079  -78.636  52.659  1
76676  94.099  -78.592  52.636  1
76677  94.119  -78.556  52.611  1
76678  94.163  -78.557  52.586  1
76679  94.214  -78.571  52.560  1
76680  94.266  -78.584  52.536  1
76681  94.318  -78.598  52.513  1
76682  94.337  -78.598  52.492  1
76683  94.347  -78.596  52.472  1
76684  94.351  -78.598  52.450  1
76685  94.344  -78.610  52.427  1
76686  94.336  -78.622  52.406  1
76687  94.328  -78.634  52.384  1
76688  94.321  -78.646  52.362  1
76689  94.313  -78.658  52.339  1
76690  94.305  -78.670  52.316  1
76691  94.318  -78.661  52.292  1
76692  94.334  -78.649  52.266  1
76693  94.351  -78.637  52.240  1
76694  94.367  -78.624  52.214  1
76695  94.380  -78.617  52.188  1
76696  94.388  -78.615  52.161  1
76697  94.397  -78.613  52.135  1
76698  94.405  -78.611  52.107  1
76699  94.414  -78.608  52.077  1
76700  94.428  -78.608  52.046  1
76701  94.447  -78.608  52.012  1
76702  94.462  -78.610  51.978  1
76703  94.473  -78.615  51.945  1
76704  94.484  -78.620  51.911  1
76705  94.494  -78.646  51.878  1
76706  94.504  -78.680  51.845  1
76707  94.517  -78.697  51.810  1
76708  94.532  -78.696  51.773  1
76709  94.547  -78.695  51.735  1
76710  94.562  -78.695  51.696  1
76711  94.577  -78.694  51.656  1
76712  94.592  -78.693  51.617  1
76713  94.607  -78.693  51.577  1
76714  94.620  -78.689  51.541  1
76715  94.631  -78.686  51.507  1
76716  94.643  -78.682  51.475  1
76717  94.655  -78.678  51.444  1
76718  94.667  -78.674  51.414  1
76719  94.679  -78.670  51.384  1
76720  94.690  -78.667  51.354  1
76721  94.701  -78.669  51.320  1
76722  94.712  -78.671  51.283  1
76723  94.723  -78.673  51.245  1
76724  94.734  -78.676  51.208  1
76725  94.751  -78.679  51.169  1
76726  94.768  -78.683  51.130  1
76727  94.773  -78.691  51.091  1
76728  94.779  -78.698  51.050  1
76729  94.784  -78.705  51.008  1
76730  94.790  -78.713  50.966  1
76731  94.795  -78.720  50.924  1
76732  94.804  -78.714  50.884  1
76733  94.813  -78.701  50.843  1
76734  94.822  -78.688  50.799  1
76735  94.832  -78.675  50.754  1
76736  94.839  -78.670  50.711  1
76737  94.845  -78.666  50.669  1
76738  94.852  -78.663  50.628  1
76739  94.858  -78.659  50.583  1
76740  94.865  -78.655  50.538  1
76741  94.873  -78.655  50.493  1
76742  94.872  -78.670  50.445  1
76743  94.873  -78.685  50.400  1
76744  94.875  -78.698  50.356  1
76745  94.877  -78.713  50.316  1
76746  94.879  -78.727  50.278  1
76747  94.881  -78.741  50.240  1
76748  94.882  -78.755  50.200  1
76749  94.884  -78.769  50.161  1
76750  94.886  -78.783  50.120  1
76751  94.888  -78.797  50.076  1
76752  94.890  -78.811  50.032  1
76753  94.900  -78.819  49.989  1
76754  94.914  -78.824  49.946  1
76755  94.934  -78.825  49.903  1
76756  94.964  -78.822  49.860  1
76757  94.993  -78.818  49.819  1
76758  95.024  -78.814  49.779  1
76759  95.053  -78.811  49.740  1
76760  95.083  -78.807  49.701  1
76761  95.113  -78.804  49.662  1
76762  95.143  -78.800  49.622  1
76763  95.173  -78.796  49.582  1
76764  95.202  -78.793  49.543  1
76765  95.233  -78.789  49.504  1
76766  95.254  -78.798  49.463  1
76767  95.273  -78.810  49.423  1
76768  95.293  -78.821  49.382  1
76769  95.312  -78.833  49.342  1
76770  95.332  -78.845  49.302  1
76771  95.351  -78.857  49.261  1
76772  95.371  -78.868  49.220  1
76773  95.390  -78.880  49.182  1
76774  95.409  -78.890  49.142  1
76775  95.422  -78.887  49.102  1
76776  95.437  -78.885  49.061  1
76777  95.451  -78.883  49.021  1
76778  95.464  -78.880  48.982  1
76779  95.478  -78.878  48.943  1
76780  95.492  -78.876  48.902  1
76781  95.506  -78.873  48.860  1
76782  95.518  -78.874  48.818  1
76783  95.526  -78.880  48.777  1
76784  95.531  -78.900  48.736  1
76785  95.542  -78.916  48.695  1
76786  95.557  -78.930  48.654  1
76787  95.572  -78.943  48.613  1
76788  95.587  -78.956  48.573  1
76789  95.602  -78.969  48.532  1
76790  95.618  -78.983  48.492  1
76791  95.633  -78.996  48.450  1
76792  95.648  -79.009  48.406  1
76793  95.663  -79.022  48.360  1
76794  95.678  -79.035  48.312  1
76795  95.693  -79.049  48.264  1
76796  95.708  -79.062  48.216  1
76797  95.724  -79.074  48.170  1
76798  95.744  -79.063  48.126  1
76799  95.753  -79.059  48.083  1
76800  95.762  -79.056  48.039  1
76801  95.771  -79.052  47.998  1
76802  95.780  -79.048  47.956  1
76803  95.789  -79.044  47.912  1
76804  95.798  -79.040  47.869  1
76805  95.807  -79.037  47.827  1
76806  95.816  -79.033  47.785  1
76807  95.824  -79.029  47.742  1
76808  95.830  -79.025  47.699  1
76809  95.836  -79.021  47.656  1
76810  95.843  -79.018  47.612  1
76811  95.849  -79.015  47.572  1
76812  95.855  -79.011  47.530  1
76813  95.871  -79.007  47.489  1
76814  95.907  -79.003  47.448  1
76815  95.944  -78.999  47.408  1
76816  95.980  -78.996  47.368  1
76817  96.017  -78.991  47.328  1
76818  96.053  -78.987  47.289  1
76819  96.090  -78.984  47.251  1
76820  96.129  -78.985  47.214  1
76821  96.169  -78.987  47.177  1
76822  96.208  -78.990  47.141  1
76823  96.248  -78.993  47.105  1
76824  96.288  -78.996  47.070  1
76825  96.328  -78.999  47.037  1
76826  96.368  -79.001  47.005  1
76827  96.402  -78.990  46.974  1
76828  96.425  -79.007  46.943  1
76829  96.447  -79.018  46.913  1
76830  96.471  -79.030  46.882  1
76831  96.495  -79.041  46.851  1
76832  96.518  -79.053  46.820  1
76833  96.542  -79.065  46.789  1
76834  96.566  -79.077  46.757  1
76835  96.584  -79.086  46.724  1
76836  96.603  -79.096  46.691  1
76837  96.621  -79.105  46.660  1
76838  96.640  -79.115  46.629  1
76839  96.658  -79.124  46.599  1
76840  96.677  -79.134  46.570  1
76841  96.707  -79.138  46.539  1
76842  96.743  -79.134  46.510  1
76843  96.752  -79.118  46.481  1
76844  96.754  -79.099  46.452  1
76845  96.756  -79.080  46.425  1
76846  96.758  -79.061  46.398  1
76847  96.823  -79.027  46.373  1
76848  96.897  -78.990  46.348  1
76849  96.972  -78.954  46.324  1
76850  96.989  -78.949  46.299  1
76851  96.965  -78.977  46.274  1
76852  96.942  -79.006  46.249  1
76853  96.935  -79.006  46.226  1
76854  96.946  -78.981  46.204  1
76855  96.958  -78.955  46.182  1
76856  96.969  -78.943  46.161  1
76857  96.977  -78.963  46.140  1
76858  96.985  -78.993  46.119  1
76859  96.993  -79.021  46.100  1
76860  96.983  -79.019  46.082  1
76861  96.959  -79.006  46.065  1
76862  96.976  -78.987  46.046  1
76863  96.994  -78.979  46.027  1
76864  97.045  -79.140  46.008  1
76865  97.037  -79.256  45.989  1
76866  97.043  -79.247  45.970  1
76867  97.048  -79.239  45.953  1
76868  97.054  -79.231  45.936  1
76869  97.061  -79.222  45.918  1
76870  97.068  -79.213  45.902  1
76871  97.078  -79.202  45.886  1
76872  97.089  -79.190  45.869  1
76873  97.099  -79.177  45.850  1
76874  97.103  -79.154  45.833  1
76875  97.107  -79.132  45.817  1
76876  97.112  -79.109  45.801  1
76877  97.116  -79.087  45.785  1
76878  97.137  -79.071  45.767  1
76879  97.169  -79.078  45.749  1
76880  97.193  -79.109  45.730  1
76881  97.229  -79.134  45.713  1
76882  97.268  -79.156  45.697  1
76883  97.301  -79.159  45.682  1
76884  97.332  -79.153  45.666  1
76885  97.364  -79.148  45.650  1
76886  97.385  -79.151  45.633  1
76887  97.391  -79.165  45.619  1
76888  97.398  -79.179  45.605  1
76889  97.404  -79.193  45.590  1
76890  97.362  -79.232  45.576  1
76891  97.346  -79.251  45.562  1
76892  97.357  -79.252  45.548  1
76893  97.371  -79.253  45.533  1
76894  97.397  -79.263  45.520  1
76895  97.400  -79.276  45.505  1
76896  97.407  -79.282  45.491  1
76897  97.417  -79.286  45.478  1
76898  97.428  -79.288  45.464  1
76899  97.439  -79.291  45.450  1
76900  97.450  -79.294  45.436  1
76901  97.463  -79.299  45.422  1
76902  97.476  -79.304  45.409  1
76903  97.490  -79.310  45.396  1
76904  97.504  -79.316  45.383  1
76905  97.518  -79.322  45.369  1
76906  97.537  -79.337  45.356  1
76907  97.556  -79.350  45.342  1
76908  97.575  -79.365  45.329  1
76909  97.594  -79.379  45.315  1
76910  97.612  -79.393  45.301  1
76911  97.632  -79.407  45.288  1
76912  97.642  -79.414  45.275  1
76913  97.650  -79.425  45.262  1
76914  97.656  -79.431  45.251  1
76915  97.662  -79.436  45.243  1
76916  97.668  -79.441  45.234  1
76917  97.674  -79.447  45.225  1
76918  97.680  -79.452  45.214  1
76919  97.686  -79.457  45.205  1
76920  97.697  -79.491  45.196  1
76921  97.713  -79.523  45.185  1
76922  97.729  -79.554  45.174  1
76923  97.743  -79.564  45.163  1
76924  97.755  -79.571  45.153  1
76925  97.768  -79.579  45.141  1
76926  97.781  -79.585  45.129  1
76927  97.794  -79.593  45.117  1
76928  97.808  -79.604  45.104  1
76929  97.822  -79.616  45.091  1
76930  97.837  -79.627  45.080  1
76931  97.852  -79.639  45.072  1
76932  97.866  -79.651  45.065  1
76933  97.886  -79.664  45.057  1
76934  97.908  -79.676  45.048  1
76935  97.928  -79.689  45.039  1
76936  97.943  -79.695  45.031  1
76937  97.956  -79.701  45.024  1
76938  97.973  -79.709  45.016  1
76939  97.981  -79.733  45.007  1
76940  98.026  -79.735  45.000  1
76941  98.066  -79.752  44.992  1
76942  98.105  -79.773  44.985  1
76943  98.132  -79.786  44.977  1
76944  98.155  -79.798  44.969  1
76945  98.178  -79.811  44.961  1
76946  98.204  -79.817  44.952  1
76947  98.229  -79.820  44.943  1
76948  98.254  -79.825  44.932  1
76949  98.279  -79.829  44.917  1
76950  98.304  -79.833  44.902  1
76951  98.330  -79.838  44.889  1
76952  98.355  -79.844  44.877  1
76953  98.380  -79.850  44.868  1
76954  98.417  -79.861  44.859  1
76955  98.454  -79.872  44.851  1
76956  98.487  -79.880  44.843  1
76957  98.519  -79.888  44.835  1
76958  98.551  -79.895  44.826  1
76959  98.582  -79.902  44.818  1
76960  98.614  -79.909  44.809  1
76961  98.644  -79.915  44.800  1
76962  98.670  -79.922  44.793  1
76963  98.688  -79.935  44.784  1
76964  98.713  -79.943  44.775  1
76965  98.738  -79.952  44.767  1
76966  98.764  -79.960  44.761  1
76967  98.789  -79.968  44.754  1
76968  98.814  -79.977  44.746  1
76969  98.840  -79.985  44.738  1
76970  98.867  -79.991  44.729  1
76971  98.888  -79.996  44.721  1
76972  98.909  -79.996  44.712  1
76973  98.929  -79.994  44.705  1
76974  98.950  -79.993  44.698  1
76975  98.964  -79.988  44.692  1
76976  98.983  -80.002  44.687  1
76977  99.002  -80.016  44.681  1
76978  99.021  -80.030  44.675  1
76979  99.040  -80.044  44.668  1
76980  99.059  -80.059  44.664  1
76981  99.078  -80.072  44.659  1
76982  99.096  -80.083  44.654  1
76983  99.112  -80.088  44.649  1
76984  99.127  -80.097  44.643  1
76985  99.209  -80.128  44.638  1
76986  99.214  -80.128  44.632  1
76987  99.219  -80.129  44.627  1
76988  99.243  -80.153  44.622  1
76989  99.286  -80.173  44.617  1
76990  99.324  -80.177  44.613  1
76991  99.363  -80.181  44.609  1
76992  99.402  -80.185  44.605  1
76993  99.440  -80.189  44.599  1
76994  99.479  -80.193  44.595  1
76995  99.517  -80.196  44.591  1
76996  99.537  -80.210  44.586  1
76997  99.540  -80.232  44.581  1
76998  99.543  -80.255  44.576  1
76999  99.546  -80.277  44.571  1
77000  99.550  -80.299  44.565  1
77001  99.553  -80.321  44.559  1
77002  99.556  -80.344  44.553  1
77003  99.559  -80.366  44.546  1
77004  99.562  -80.388  44.540  1
77005  99.566  -80.410  44.534  1
77006  99.569  -80.431  44.527  1
77007  99.572  -80.454  44.520  1
77008  99.575  -80.476  44.512  1
77009  99.578  -80.498  44.504  1
77010  99.581  -80.520  44.496  1
77011  99.585  -80.542  44.489  1
77012  99.588  -80.565  44.481  1
77013  99.591  -80.587  44.472  1
77014  99.594  -80.609  44.464  1
77015  99.597  -80.631  44.455  1
77016  99.601  -80.654  44.445  1
77017  99.604  -80.676  44.436  1
77018  99.608  -80.698  44.426  1
77019  99.648  -80.706  44.416  1
77020  99.697  -80.711  44.406  1
77021  99.745  -80.717  44.396  1
77022  99.792  -80.723  44.386  1
77023  99.840  -80.728  44.375  1
77024  99.888  -80.734  44.363  1
77025  99.936  -80.739  44.353  1
77321  93.544  -78.882  53.534  1
77322  93.554  -78.880  53.525  1
77323  93.564  -78.877  53.515  1
77324  93.573  -78.874  53.506  1
77325  93.583  -78.872  53.498  1
77326  93.592  -78.870  53.490  1
77327  93.603  -78.860  53.483  1
77328  93.611  -78.853  53.476  1
77329  93.620  -78.846  53.469  1
77330  93.629  -78.839  53.465  1
77331  93.698  -78.805  53.463  1
77332  93.688  -78.802  53.464  1
77333  93.687  -78.801  53.464  1
77334  93.685  -78.799  53.462  1
77335  93.684  -78.797  53.459  1
77336  93.687  -78.795  53.453  1
77337  93.694  -78.795  53.446  1
77338  93.701  -78.794  53.438  1
77339  93.707  -78.793  53.427  1
77340  93.714  -78.793  53.417  1
77341  93.721  -78.789  53.407  1
77342  93.728  -78.786  53.396  1
77343  93.736  -78.783  53.383  1
77344  93.743  -78.781  53.370  1
77345  93.766  -78.768  53.355  1
77346  93.791  -78.754  53.338  1
77347  93.807  -78.742  53.321  1
77348  93.811  -78.734  53.303  1
77349  93.814  -78.725  53.285  1
77350  93.817  -78.717  53.265  1
77351  93.822  -78.708  53.244  1
77352  93.836  -78.701  53.223  1
77353  93.850  -78.692  53.202  1
77354  93.864  -78.684  53.182  1
77355  93.878  -78.677  53.163  1
77356  93.892  -78.668  53.141  1
77357  93.906  -78.661  53.117  1
77358  93.920  -78.652  53.091  1
77359  93.934  -78.645  53.065  1
77360  93.943  -78.639  53.040  1
77361  93.957  -78.634  53.013  1
77362  93.967  -78.633  52.986  1
77363  93.977  -78.631  52.960  1
77364  93.987  -78.629  52.936  1
77365  93.996  -78.627  52.913  1
77366  94.006  -78.626  52.890  1
77367  94.016  -78.624  52.869  1
77368  94.027  -78.623  52.849  1
77369  94.036  -78.620  52.830  1
77370  94.046  -78.619  52.810  1
77371  94.056  -78.617  52.788  1
77372  94.066  -78.616  52.765  1
77373  94.076  -78.614  52.742  1
77374  94.079  -78.617  52.720  1
77375  94.077  -78.624  52.697  1
77376  94.076  -78.606  52.674  1
77377  94.105  -78.551  52.650  1
77378  94.147  -78.529  52.625  1
77379  94.199  -78.542  52.599  1
77380  94.251  -78.556  52.573  1
77381  94.302  -78.570  52.551  1
77382  94.350  -78.582  52.529  1
77383  94.360  -78.579  52.508  1
77384  94.365  -78.580  52.489  1
77385  94.357  -78.592  52.467  1
77386  94.350  -78.604  52.445  1
77387  94.342  -78.617  52.424  1
77388  94.334  -78.628  52.402  1
77389  94.327  -78.640  52.380  1
77390  94.319  -78.652  52.357  1
77391  94.312  -78.664  52.335  1
77392  94.320  -78.660  52.312  1
77393  94.336  -78.647  52.288  1
77394  94.353  -78.635  52.261  1
77395  94.369  -78.623  52.235  1
77396  94.386  -78.611  52.209  1
77397  94.397  -78.604  52.184  1
77398  94.406  -78.601  52.158  1
77399  94.415  -78.599  52.129  1
77400  94.423  -78.597  52.098  1
77401  94.437  -78.596  52.065  1
77402  94.456  -78.597  52.030  1
77403  94.474  -78.598  51.996  1
77404  94.485  -78.602  51.964  1
77405  94.496  -78.616  51.929  1
77406  94.506  -78.649  51.894  1
77407  94.517  -78.683  51.859  1
77408  94.529  -78.702  51.825  1
77409  94.544  -78.701  51.787  1
77410  94.559  -78.700  51.748  1
77411  94.574  -78.699  51.708  1
77412  94.586  -78.696  51.668  1
77413  94.598  -78.692  51.629  1
77414  94.610  -78.689  51.589  1
77415  94.622  -78.685  51.554  1
77416  94.633  -78.680  51.520  1
77417  94.645  -78.677  51.486  1
77418  94.657  -78.673  51.455  1
77419  94.669  -78.669  51.423  1
77420  94.681  -78.665  51.392  1
77421  94.692  -78.661  51.361  1
77422  94.703  -78.663  51.325  1
77423  94.714  -78.665  51.288  1
77424  94.725  -78.667  51.251  1
77425  94.739  -78.670  51.214  1
77426  94.757  -78.673  51.176  1
77427  94.776  -78.677  51.138  1
77428  94.783  -78.684  51.099  1
77429  94.788  -78.692  51.059  1
77430  94.794  -78.699  51.018  1
77431  94.800  -78.707  50.977  1
77432  94.806  -78.714  50.935  1
77433  94.814  -78.704  50.894  1
77434  94.824  -78.691  50.853  1
77435  94.833  -78.678  50.809  1
77436  94.842  -78.665  50.764  1
77437  94.851  -78.652  50.720  1
77438  94.859  -78.645  50.677  1
77439  94.865  -78.641  50.636  1
77440  94.872  -78.637  50.591  1
77441  94.879  -78.634  50.546  1
77442  94.886  -78.638  50.500  1
77443  94.891  -78.649  50.452  1
77444  94.892  -78.664  50.405  1
77445  94.894  -78.677  50.361  1
77446  94.896  -78.692  50.322  1
77447  94.898  -78.705  50.284  1
77448  94.899  -78.720  50.246  1
77449  94.901  -78.733  50.206  1
77450  94.903  -78.748  50.166  1
77451  94.905  -78.762  50.124  1
77452  94.907  -78.776  50.080  1
77453  94.909  -78.789  50.034  1
77454  94.923  -78.794  49.989  1
77455  94.938  -78.799  49.945  1
77456  94.953  -78.803  49.902  1
77457  94.972  -78.805  49.860  1
77458  95.001  -78.802  49.819  1
77459  95.031  -78.799  49.779  1
77460  95.061  -78.795  49.738  1
77461  95.091  -78.791  49.700  1
77462  95.121  -78.787  49.662  1
77463  95.151  -78.783  49.623  1
77464  95.181  -78.780  49.584  1
77465  95.210  -78.777  49.544  1
77466  95.232  -78.774  49.504  1
77467  95.252  -78.793  49.464  1
77468  95.273  -78.805  49.423  1
77469  95.293  -78.817  49.383  1
77470  95.312  -78.829  49.341  1
77471  95.332  -78.840  49.301  1
77472  95.351  -78.852  49.262  1
77473  95.371  -78.864  49.222  1
77474  95.390  -78.876  49.183  1
77475  95.409  -78.886  49.143  1
77476  95.423  -78.883  49.103  1
77477  95.437  -78.881  49.062  1
77478  95.451  -78.878  49.023  1
77479  95.465  -78.876  48.983  1
77480  95.479  -78.874  48.943  1
77481  95.492  -78.871  48.903  1
77482  95.507  -78.869  48.862  1
77483  95.520  -78.867  48.820  1
77484  95.534  -78.865  48.779  1
77485  95.547  -78.875  48.737  1
77486  95.562  -78.888  48.696  1
77487  95.577  -78.902  48.655  1
77488  95.592  -78.915  48.613  1
77489  95.606  -78.928  48.572  1
77490  95.620  -78.941  48.531  1
77491  95.633  -78.955  48.492  1
77492  95.648  -78.968  48.451  1
77493  95.662  -78.981  48.408  1
77494  95.675  -78.994  48.362  1
77495  95.689  -79.008  48.313  1
77496  95.703  -79.021  48.265  1
77497  95.717  -79.034  48.219  1
77498  95.731  -79.048  48.176  1
77499  95.747  -79.056  48.133  1
77500  95.760  -79.057  48.090  1
77501  95.769  -79.053  48.046  1
77502  95.778  -79.049  48.005  1
77503  95.788  -79.046  47.963  1
77504  95.797  -79.042  47.919  1
77505  95.806  -79.038  47.877  1
77506  95.815  -79.034  47.835  1
77507  95.824  -79.031  47.793  1
77508  95.833  -79.027  47.750  1
77509  95.839  -79.023  47.707  1
77510  95.846  -79.020  47.664  1
77511  95.852  -79.016  47.620  1
77512  95.859  -79.012  47.578  1
77513  95.866  -79.009  47.537  1
77514  95.902  -79.005  47.496  1
77515  95.939  -79.001  47.456  1
77516  95.975  -78.997  47.416  1
77517  96.012  -78.993  47.376  1
77518  96.048  -78.990  47.336  1
77519  96.072  -78.984  47.297  1
77520  96.095  -78.977  47.259  1
77521  96.129  -78.976  47.222  1
77522  96.169  -78.977  47.184  1
77523  96.209  -78.979  47.148  1
77524  96.249  -78.981  47.112  1
77525  96.290  -78.982  47.078  1
77526  96.329  -78.984  47.044  1
77527  96.370  -78.985  47.012  1
77528  96.409  -78.987  46.981  1
77529  96.429  -78.995  46.950  1
77530  96.447  -79.004  46.920  1
77531  96.466  -79.014  46.890  1
77532  96.484  -79.023  46.858  1
77533  96.503  -79.033  46.828  1
77534  96.522  -79.042  46.797  1
77535  96.540  -79.052  46.766  1
77536  96.559  -79.061  46.732  1
77537  96.578  -79.071  46.700  1
77538  96.596  -79.080  46.668  1
77539  96.615  -79.090  46.637  1
77540  96.633  -79.100  46.607  1
77541  96.648  -79.106  46.576  1
77542  96.687  -79.109  46.545  1
77543  96.735  -79.111  46.516  1
77544  96.764  -79.103  46.487  1
77545  96.788  -79.093  46.459  1
77546  96.790  -79.075  46.431  1
77547  96.792  -79.056  46.405  1
77548  96.859  -79.021  46.380  1
77549  96.929  -78.984  46.355  1
77550  96.961  -78.938  46.330  1
77551  96.981  -78.954  46.305  1
77552  96.953  -78.981  46.280  1
77553  96.930  -79.009  46.255  1
77554  96.934  -78.979  46.233  1
77555  96.946  -78.954  46.212  1
77556  96.957  -78.928  46.191  1
77557  96.967  -78.933  46.170  1
77558  96.975  -78.952  46.149  1
77559  96.983  -78.980  46.129  1
77560  96.991  -79.009  46.108  1
77561  96.999  -79.037  46.091  1
77562  96.984  -79.002  46.074  1
77563  96.967  -78.962  46.056  1
77564  97.006  -78.972  46.037  1
77565  97.014  -79.100  46.019  1
77566  97.029  -79.228  46.000  1
77567  97.048  -79.267  45.982  1
77568  97.054  -79.259  45.965  1
77569  97.060  -79.250  45.948  1
77570  97.066  -79.242  45.928  1
77571  97.072  -79.234  45.911  1
77572  97.083  -79.222  45.895  1
77573  97.093  -79.211  45.878  1
77574  97.100  -79.192  45.859  1
77575  97.105  -79.170  45.843  1
77576  97.109  -79.147  45.828  1
77577  97.114  -79.125  45.811  1
77578  97.118  -79.102  45.796  1
77579  97.123  -79.079  45.779  1
77580  97.150  -79.084  45.761  1
77581  97.189  -79.106  45.742  1
77582  97.228  -79.129  45.726  1
77583  97.267  -79.152  45.711  1
77584  97.299  -79.151  45.695  1
77585  97.330  -79.146  45.680  1
77586  97.362  -79.140  45.664  1
77587  97.369  -79.154  45.649  1
77588  97.375  -79.169  45.634  1
77589  97.382  -79.182  45.621  1
77590  97.388  -79.197  45.609  1
77591  97.395  -79.210  45.596  1
77592  97.375  -79.237  45.582  1
77593  97.369  -79.250  45.567  1
77594  97.391  -79.251  45.552  1
77595  97.396  -79.265  45.537  1
77596  97.403  -79.271  45.523  1
77597  97.410  -79.278  45.509  1
77598  97.421  -79.280  45.496  1
77599  97.432  -79.283  45.483  1
77600  97.443  -79.286  45.469  1
77601  97.454  -79.288  45.455  1
77602  97.465  -79.291  45.441  1
77603  97.476  -79.294  45.427  1
77604  97.490  -79.300  45.414  1
77605  97.504  -79.306  45.400  1
77606  97.517  -79.312  45.387  1
77607  97.535  -79.324  45.373  1
77608  97.554  -79.338  45.358  1
77609  97.573  -79.352  45.344  1
77610  97.592  -79.366  45.330  1
77611  97.610  -79.380  45.317  1
77612  97.630  -79.393  45.303  1
77613  97.648  -79.400  45.288  1
77614  97.661  -79.407  45.275  1
77615  97.667  -79.413  45.264  1
77616  97.672  -79.419  45.256  1
77617  97.678  -79.424  45.247  1
77618  97.684  -79.430  45.239  1
77619  97.690  -79.436  45.229  1
77620  97.696  -79.442  45.219  1
77621  97.707  -79.457  45.209  1
77622  97.723  -79.488  45.198  1
77623  97.739  -79.520  45.187  1
77624  97.754  -79.540  45.176  1
77625  97.767  -79.547  45.168  1
77626  97.780  -79.554  45.155  1
77627  97.793  -79.562  45.142  1
77628  97.807  -79.573  45.129  1
77629  97.821  -79.585  45.115  1
77630  97.836  -79.597  45.102  1
77631  97.851  -79.608  45.092  1
77632  97.865  -79.620  45.087  1
77633  97.879  -79.632  45.081  1
77634  97.898  -79.644  45.074  1
77635  97.919  -79.656  45.065  1
77636  97.940  -79.667  45.057  1
77637  97.956  -79.675  45.049  1
77638  97.968  -79.679  45.041  1
77639  97.981  -79.684  45.033  1
77640  98.000  -79.693  45.023  1
77641  98.035  -79.711  45.013  1
77642  98.074  -79.732  45.005  1
77643  98.112  -79.752  44.997  1
77644  98.143  -79.767  44.989  1
77645  98.166  -79.780  44.980  1
77646  98.190  -79.789  44.970  1
77647  98.215  -79.793  44.960  1
77648  98.241  -79.798  44.949  1
77649  98.266  -79.802  44.937  1
77650  98.291  -79.806  44.923  1
77651  98.316  -79.811  44.910  1
77652  98.342  -79.815  44.898  1
77653  98.367  -79.819  44.887  1
77654  98.392  -79.825  44.880  1
77655  98.427  -79.835  44.871  1
77656  98.460  -79.843  44.862  1
77657  98.492  -79.850  44.851  1
77658  98.523  -79.858  44.841  1
77659  98.555  -79.864  44.832  1
77660  98.586  -79.872  44.824  1
77661  98.618  -79.879  44.816  1
77662  98.650  -79.886  44.809  1
77663  98.675  -79.895  44.802  1
77664  98.700  -79.903  44.794  1
77665  98.724  -79.912  44.785  1
77666  98.749  -79.921  44.777  1
77667  98.773  -79.930  44.770  1
77668  98.798  -79.938  44.764  1
77669  98.822  -79.947  44.757  1
77670  98.847  -79.955  44.749  1
77671  98.870  -79.956  44.740  1
77672  98.892  -79.952  44.731  1
77673  98.914  -79.947  44.724  1
77674  98.935  -79.943  44.717  1
77675  98.956  -79.942  44.711  1
77676  98.966  -79.930  44.705  1
77677  98.985  -79.943  44.700  1
77678  99.005  -79.960  44.694  1
77679  99.024  -79.977  44.688  1
77680  99.044  -79.994  44.682  1
77681  99.063  -80.012  44.677  1
77682  99.082  -80.028  44.672  1
77683  99.101  -80.046  44.667  1
77684  99.121  -80.062  44.663  1
77685  99.147  -80.077  44.657  1
77686  99.211  -80.102  44.652  1
77687  99.248  -80.121  44.646  1
77688  99.255  -80.126  44.640  1
77689  99.267  -80.126  44.635  1
77690  99.297  -80.150  44.631  1
77691  99.337  -80.151  44.628  1
77692  99.373  -80.151  44.623  1
77693  99.412  -80.155  44.617  1
77694  99.451  -80.159  44.613  1
77695  99.489  -80.162  44.608  1
77696  99.528  -80.166  44.602  1
77697  99.533  -80.187  44.597  1
77698  99.536  -80.209  44.592  1
77699  99.540  -80.231  44.586  1
77700  99.543  -80.254  44.581  1
77701  99.546  -80.276  44.575  1
77702  99.549  -80.298  44.567  1
77703  99.552  -80.320  44.561  1
77704  99.556  -80.343  44.555  1
77705  99.559  -80.365  44.548  1
77706  99.562  -80.387  44.540  1
77707  99.565  -80.409  44.533  1
77708  99.568  -80.431  44.527  1
77709  99.572  -80.453  44.519  1
77710  99.575  -80.475  44.510  1
77711  99.578  -80.497  44.503  1
77712  99.581  -80.519  44.495  1
77713  99.584  -80.542  44.487  1
77714  99.588  -80.564  44.478  1
77715  99.591  -80.586  44.469  1
77716  99.594  -80.608  44.460  1
77717  99.597  -80.630  44.451  1
77718  99.600  -80.653  44.441  1
77719  99.609  -80.673  44.431  1
77720  99.657  -80.679  44.421  1
77721  99.705  -80.684  44.411  1
77722  99.753  -80.690  44.402  1
77723  99.800  -80.695  44.390  1
77724  99.849  -80.701  44.379  1
77725  99.897  -80.707  44.367  1
77726  99.944  -80.712  44.356  1
77727  99.992  -80.718  44.346  1
77728  100.040  -80.723  44.335  1
78022  93.545  -78.871  53.545  1
78023  93.554  -78.868  53.536  1
78024  93.564  -78.866  53.527  1
78025  93.573  -78.864  53.518  1
78026  93.583  -78.861  53.509  1
78027  93.593  -78.858  53.501  1
78028  93.603  -78.855  53.494  1
78029  93.613  -78.847  53.488  1
78030  93.621  -78.840  53.481  1
78031  93.629  -78.833  53.478  1
78032  93.686  -78.805  53.477  1
78033  93.676  -78.801  53.478  1
78034  93.675  -78.799  53.478  1
78035  93.674  -78.797  53.477  1
78036  93.678  -78.795  53.474  1
78037  93.683  -78.790  53.468  1
78038  93.690  -78.787  53.461  1
78039  93.697  -78.786  53.453  1
78040  93.703  -78.786  53.443  1
78041  93.710  -78.785  53.432  1
78042  93.717  -78.782  53.421  1
78043  93.724  -78.780  53.410  1
78044  93.731  -78.777  53.397  1
78045  93.753  -78.765  53.382  1
78046  93.777  -78.751  53.366  1
78047  93.802  -78.737  53.349  1
78048  93.808  -78.728  53.331  1
78049  93.812  -78.720  53.313  1
78050  93.815  -78.711  53.295  1
78051  93.819  -78.702  53.274  1
78052  93.822  -78.694  53.254  1
78053  93.835  -78.686  53.233  1
78054  93.849  -78.678  53.212  1
78055  93.863  -78.670  53.192  1
78056  93.877  -78.662  53.172  1
78057  93.891  -78.654  53.150  1
78058  93.905  -78.646  53.126  1
78059  93.919  -78.638  53.101  1
78060  93.933  -78.630  53.075  1
78061  93.945  -78.619  53.048  1
78062  93.956  -78.625  53.021  1
78063  93.966  -78.624  52.995  1
78064  93.976  -78.623  52.970  1
78065  93.986  -78.621  52.946  1
78066  93.996  -78.620  52.923  1
78067  94.006  -78.617  52.900  1
78068  94.016  -78.616  52.881  1
78069  94.026  -78.614  52.862  1
78070  94.036  -78.613  52.843  1
78071  94.046  -78.611  52.824  1
78072  94.055  -78.610  52.802  1
78073  94.065  -78.608  52.778  1
78074  94.075  -78.606  52.754  1
78075  94.075  -78.611  52.731  1
78076  94.073  -78.616  52.708  1
78077  94.081  -78.567  52.685  1
78078  94.115  -78.522  52.661  1
78079  94.176  -78.524  52.636  1
78080  94.235  -78.527  52.610  1
78081  94.287  -78.541  52.586  1
78082  94.339  -78.554  52.565  1
78083  94.373  -78.561  52.544  1
78084  94.379  -78.562  52.525  1
78085  94.371  -78.574  52.506  1
78086  94.363  -78.586  52.485  1
78087  94.356  -78.598  52.463  1
78088  94.348  -78.611  52.441  1
78089  94.340  -78.623  52.419  1
78090  94.333  -78.634  52.397  1
78091  94.325  -78.646  52.374  1
78092  94.318  -78.658  52.355  1
78093  94.322  -78.658  52.332  1
78094  94.339  -78.645  52.308  1
78095  94.355  -78.633  52.282  1
78096  94.371  -78.620  52.256  1
78097  94.388  -78.608  52.231  1
78098  94.404  -78.596  52.207  1
78099  94.415  -78.590  52.179  1
78100  94.424  -78.588  52.150  1
78101  94.432  -78.586  52.118  1
78102  94.447  -78.585  52.083  1
78103  94.465  -78.586  52.049  1
78104  94.483  -78.586  52.015  1
78105  94.497  -78.589  51.982  1
78106  94.508  -78.618  51.946  1
78107  94.519  -78.651  51.909  1
78108  94.529  -78.685  51.872  1
78109  94.541  -78.706  51.839  1
78110  94.553  -78.702  51.801  1
78111  94.564  -78.698  51.761  1
78112  94.576  -78.695  51.720  1
78113  94.588  -78.691  51.681  1
78114  94.600  -78.687  51.641  1
78115  94.612  -78.683  51.602  1
78116  94.624  -78.680  51.566  1
78117  94.635  -78.676  51.532  1
78118  94.647  -78.672  51.498  1
78119  94.659  -78.668  51.465  1
78120  94.671  -78.664  51.432  1
78121  94.683  -78.660  51.399  1
78122  94.694  -78.656  51.366  1
78123  94.705  -78.657  51.331  1
78124  94.716  -78.659  51.295  1
78125  94.727  -78.661  51.258  1
78126  94.745  -78.664  51.221  1
78127  94.764  -78.668  51.183  1
78128  94.782  -78.672  51.145  1
78129  94.792  -78.678  51.105  1
78130  94.798  -78.686  51.066  1
78131  94.804  -78.693  51.026  1
78132  94.810  -78.701  50.986  1
78133  94.815  -78.706  50.944  1
78134  94.825  -78.693  50.903  1
78135  94.834  -78.680  50.861  1
78136  94.843  -78.667  50.818  1
78137  94.852  -78.655  50.773  1
78138  94.861  -78.642  50.728  1
78139  94.871  -78.629  50.684  1
78140  94.879  -78.619  50.642  1
78141  94.886  -78.616  50.597  1
78142  94.893  -78.612  50.550  1
78143  94.899  -78.622  50.503  1
78144  94.906  -78.631  50.455  1
78145  94.911  -78.642  50.409  1
78146  94.913  -78.656  50.364  1
78147  94.915  -78.670  50.324  1
78148  94.917  -78.684  50.285  1
78149  94.918  -78.698  50.246  1
78150  94.920  -78.713  50.205  1
78151  94.922  -78.727  50.164  1
78152  94.924  -78.741  50.121  1
78153  94.926  -78.755  50.078  1
78154  94.933  -78.765  50.032  1
78155  94.948  -78.769  49.988  1
78156  94.962  -78.774  49.945  1
78157  94.977  -78.778  49.902  1
78158  94.992  -78.783  49.860  1
78159  95.010  -78.786  49.819  1
78160  95.039  -78.782  49.779  1
78161  95.069  -78.778  49.739  1
78162  95.099  -78.775  49.700  1
78163  95.129  -78.771  49.662  1
78164  95.159  -78.767  49.624  1
78165  95.189  -78.764  49.586  1
78166  95.218  -78.760  49.546  1
78167  95.215  -78.761  49.505  1
78168  95.244  -78.780  49.465  1
78169  95.273  -78.800  49.424  1
78170  95.293  -78.812  49.384  1
78171  95.313  -78.824  49.343  1
78172  95.332  -78.836  49.303  1
78173  95.351  -78.848  49.263  1
78174  95.371  -78.859  49.223  1
78175  95.391  -78.871  49.185  1
78176  95.409  -78.881  49.146  1
78177  95.423  -78.879  49.106  1
78178  95.438  -78.877  49.066  1
78179  95.451  -78.874  49.025  1
78180  95.465  -78.872  48.986  1
78181  95.479  -78.870  48.946  1
78182  95.493  -78.868  48.905  1
78183  95.507  -78.865  48.864  1
78184  95.521  -78.863  48.823  1
78185  95.529  -78.855  48.781  1
78186  95.545  -78.852  48.739  1
78187  95.551  -78.863  48.698  1
78188  95.562  -78.875  48.657  1
78189  95.576  -78.888  48.614  1
78190  95.590  -78.902  48.572  1
78191  95.604  -78.915  48.530  1
78192  95.617  -78.928  48.488  1
78193  95.631  -78.942  48.445  1
78194  95.645  -78.955  48.401  1
78195  95.659  -78.968  48.357  1
78196  95.673  -78.981  48.310  1
78197  95.687  -78.995  48.265  1
78198  95.701  -79.008  48.222  1
78199  95.715  -79.021  48.181  1
78200  95.730  -79.031  48.140  1
78201  95.747  -79.034  48.097  1
78202  95.764  -79.038  48.054  1
78203  95.780  -79.042  48.013  1
78204  95.796  -79.044  47.970  1
78205  95.805  -79.040  47.928  1
78206  95.814  -79.037  47.884  1
78207  95.823  -79.033  47.842  1
78208  95.832  -79.029  47.800  1
78209  95.841  -79.025  47.757  1
78210  95.849  -79.021  47.714  1
78211  95.855  -79.018  47.672  1
78212  95.862  -79.014  47.628  1
78213  95.869  -79.010  47.586  1
78214  95.897  -79.006  47.545  1
78215  95.933  -79.002  47.504  1
78216  95.970  -78.999  47.465  1
78217  96.005  -78.995  47.425  1
78218  96.028  -78.989  47.385  1
78219  96.051  -78.983  47.345  1
78220  96.075  -78.976  47.307  1
78221  96.098  -78.970  47.268  1
78222  96.129  -78.968  47.231  1
78223  96.169  -78.969  47.193  1
78224  96.209  -78.971  47.157  1
78225  96.249  -78.972  47.120  1
78226  96.289  -78.974  47.085  1
78227  96.329  -78.975  47.050  1
78228  96.369  -78.977  47.018  1
78229  96.404  -78.971  46.988  1
78230  96.416  -78.971  46.957  1
78231  96.422  -78.979  46.926  1
78232  96.441  -78.989  46.896  1
78233  96.460  -78.998  46.865  1
78234  96.478  -79.008  46.835  1
78235  96.497  -79.018  46.804  1
78236  96.516  -79.027  46.773  1
78237  96.534  -79.037  46.741  1
78238  96.553  -79.046  46.709  1
78239  96.572  -79.056  46.677  1
78240  96.590  -79.065  46.645  1
78241  96.605  -79.072  46.614  1
78242  96.620  -79.079  46.583  1
78243  96.668  -79.081  46.552  1
78244  96.717  -79.083  46.522  1
78245  96.756  -79.081  46.494  1
78246  96.785  -79.072  46.466  1
78247  96.814  -79.065  46.438  1
78248  96.826  -79.050  46.412  1
78249  96.879  -79.011  46.386  1
78250  96.911  -78.963  46.361  1
78251  96.937  -78.947  46.336  1
78252  96.957  -78.963  46.311  1
78253  96.946  -78.985  46.287  1
78254  96.924  -78.996  46.263  1
78255  96.934  -78.953  46.242  1
78256  96.945  -78.927  46.221  1
78257  96.956  -78.905  46.201  1
78258  96.965  -78.924  46.181  1
78259  96.974  -78.942  46.161  1
78260  96.982  -78.967  46.141  1
78261  96.990  -78.996  46.120  1
78262  96.990  -79.002  46.101  1
78263  96.974  -78.964  46.083  1
78264  96.970  -78.967  46.065  1
78265  96.945  -79.078  46.046  1
78266  97.004  -79.047  46.028  1
78267  97.019  -79.192  46.009  1
78268  97.037  -79.231  45.992  1
78269  97.056  -79.269  45.976  1
78270  97.065  -79.270  45.959  1
78271  97.071  -79.262  45.941  1
78272  97.077  -79.253  45.924  1
78273  97.087  -79.242  45.907  1
78274  97.097  -79.230  45.890  1
78275  97.102  -79.207  45.871  1
78276  97.106  -79.185  45.855  1
78277  97.111  -79.162  45.839  1
78278  97.115  -79.140  45.823  1
78279  97.124  -79.109  45.807  1
78280  97.133  -79.078  45.791  1
78281  97.149  -79.079  45.774  1
78282  97.188  -79.102  45.757  1
78283  97.227  -79.125  45.741  1
78284  97.265  -79.147  45.726  1
78285  97.297  -79.143  45.710  1
78286  97.328  -79.138  45.696  1
78287  97.346  -79.144  45.680  1
78288  97.353  -79.158  45.664  1
78289  97.359  -79.172  45.650  1
78290  97.366  -79.186  45.637  1
78291  97.372  -79.200  45.625  1
78292  97.379  -79.214  45.613  1
78293  97.385  -79.228  45.600  1
78294  97.388  -79.244  45.586  1
78295  97.393  -79.253  45.571  1
78296  97.399  -79.259  45.555  1
78297  97.406  -79.266  45.540  1
78298  97.414  -79.272  45.527  1
78299  97.425  -79.275  45.515  1
78300  97.436  -79.278  45.502  1
78301  97.447  -79.280  45.489  1
78302  97.457  -79.283  45.475  1
78303  97.468  -79.285  45.460  1
78304  97.479  -79.288  45.446  1
78305  97.491  -79.291  45.433  1
78306  97.504  -79.296  45.419  1
78307  97.517  -79.302  45.405  1
78308  97.532  -79.310  45.390  1
78309  97.551  -79.325  45.374  1
78310  97.571  -79.338  45.359  1
78311  97.589  -79.353  45.346  1
78312  97.608  -79.363  45.333  1
78313  97.627  -79.370  45.317  1
78314  97.646  -79.378  45.301  1
78315  97.664  -79.385  45.287  1
78316  97.677  -79.391  45.277  1
78317  97.683  -79.397  45.268  1
78318  97.689  -79.404  45.260  1
78319  97.695  -79.410  45.252  1
78320  97.703  -79.418  45.243  1
78321  97.714  -79.433  45.233  1
78322  97.725  -79.448  45.221  1
78323  97.736  -79.463  45.211  1
78324  97.749  -79.486  45.200  1
78325  97.766  -79.515  45.191  1
78326  97.778  -79.523  45.182  1
78327  97.791  -79.531  45.171  1
78328  97.806  -79.542  45.156  1
78329  97.820  -79.554  45.140  1
78330  97.835  -79.566  45.125  1
78331  97.849  -79.577  45.112  1
78332  97.864  -79.589  45.103  1
78333  97.878  -79.601  45.099  1
78334  97.892  -79.613  45.095  1
78335  97.909  -79.625  45.089  1
78336  97.930  -79.636  45.081  1
78337  97.950  -79.647  45.074  1
78338  97.973  -79.657  45.065  1
78339  97.992  -79.667  45.056  1
78340  98.012  -79.676  45.046  1
78341  98.031  -79.686  45.037  1
78342  98.051  -79.695  45.028  1
78343  98.082  -79.711  45.020  1
78344  98.121  -79.732  45.012  1
78345  98.154  -79.749  45.003  1
78346  98.177  -79.761  44.993  1
78347  98.202  -79.767  44.981  1
78348  98.227  -79.770  44.972  1
78349  98.252  -79.775  44.960  1
78350  98.278  -79.780  44.948  1
78351  98.303  -79.783  44.935  1
78352  98.329  -79.788  44.922  1
78353  98.354  -79.792  44.908  1
78354  98.379  -79.796  44.898  1
78355  98.405  -79.802  44.890  1
78356  98.435  -79.811  44.882  1
78357  98.468  -79.820  44.871  1
78358  98.501  -79.830  44.860  1
78359  98.533  -79.839  44.849  1
78360  98.566  -79.848  44.840  1
78361  98.598  -79.857  44.832  1
78362  98.631  -79.867  44.825  1
78363  98.662  -79.874  44.818  1
78364  98.679  -79.872  44.811  1
78365  98.700  -79.880  44.803  1
78366  98.721  -79.887  44.795  1
78367  98.743  -79.896  44.788  1
78368  98.768  -79.904  44.781  1
78369  98.793  -79.913  44.774  1
78370  98.817  -79.921  44.768  1
78371  98.842  -79.930  44.760  1
78372  98.865  -79.931  44.751  1
78373  98.887  -79.927  44.743  1
78374  98.909  -79.922  44.736  1
78375  98.932  -79.918  44.730  1
78376  98.957  -79.919  44.724  1
78377  98.973  -79.914  44.718  1
78378  98.992  -79.926  44.713  1
78379  99.011  -79.943  44.707  1
78380  99.030  -79.960  44.701  1
78381  99.050  -79.977  44.696  1
78382  99.069  -79.994  44.691  1
78383  99.089  -80.011  44.686  1
78384  99.108  -80.028  44.681  1
78385  99.128  -80.045  44.675  1
78386  99.157  -80.059  44.669  1
78387  99.189  -80.071  44.664  1
78388  99.243  -80.093  44.658  1
78389  99.272  -80.109  44.653  1
78390  99.277  -80.118  44.650  1
78391  99.305  -80.127  44.647  1
78392  99.353  -80.137  44.644  1
78393  99.396  -80.142  44.639  1
78394  99.425  -80.128  44.634  1
78395  99.462  -80.128  44.631  1
78396  99.500  -80.132  44.626  1
78397  99.526  -80.143  44.620  1
78398  99.529  -80.165  44.612  1
78399  99.533  -80.187  44.604  1
78400  99.536  -80.209  44.597  1
78401  99.539  -80.231  44.590  1
78402  99.543  -80.253  44.583  1
78403  99.546  -80.275  44.575  1
78404  99.549  -80.297  44.568  1
78405  99.552  -80.319  44.562  1
78406  99.555  -80.342  44.555  1
78407  99.559  -80.364  44.547  1
78408  99.562  -80.386  44.539  1
78409  99.565  -80.408  44.533  1
78410  99.568  -80.431  44.524  1
78411  99.571  -80.453  44.516  1
78412  99.575  -80.475  44.509  1
78413  99.578  -80.497  44.501  1
78414  99.581  -80.519  44.492  1
78415  99.584  -80.541  44.484  1
78416  99.587  -80.563  44.475  1
78417  99.591  -80.585  44.466  1
78418  99.594  -80.607  44.457  1
78419  99.597  -80.630  44.446  1
78420  99.617  -80.646  44.436  1
78421  99.665  -80.651  44.427  1
78422  99.713  -80.657  44.417  1
78423  99.761  -80.663  44.406  1
78424  99.809  -80.668  44.394  1
78425  99.857  -80.674  44.383  1
78426  99.905  -80.679  44.372  1
78427  99.952  -80.685  44.361  1
78428  100.001  -80.691  44.350  1
78429  100.049  -80.696  44.339  1
78430  100.097  -80.701  44.328  1
78724  93.554  -78.858  53.546  1
78725  93.564  -78.855  53.537  1
78726  93.574  -78.852  53.528  1
78727  93.583  -78.850  53.520  1
78728  93.593  -78.848  53.512  1
78729  93.603  -78.846  53.504  1
78730  93.613  -78.841  53.499  1
78731  93.622  -78.833  53.493  1
78732  93.630  -78.827  53.490  1
78733  93.674  -78.804  53.490  1
78734  93.664  -78.799  53.492  1
78735  93.665  -78.796  53.491  1
78736  93.670  -78.794  53.490  1
78737  93.675  -78.791  53.487  1
78738  93.680  -78.786  53.482  1
78739  93.686  -78.782  53.475  1
78740  93.692  -78.779  53.467  1
78741  93.699  -78.779  53.457  1
78742  93.706  -78.777  53.446  1
78743  93.713  -78.775  53.435  1
78744  93.720  -78.772  53.423  1
78745  93.739  -78.762  53.409  1
78746  93.764  -78.748  53.393  1
78747  93.788  -78.734  53.377  1
78748  93.806  -78.722  53.360  1
78749  93.809  -78.714  53.342  1
78750  93.813  -78.705  53.324  1
78751  93.816  -78.697  53.306  1
78752  93.820  -78.688  53.285  1
78753  93.823  -78.680  53.263  1
78754  93.834  -78.671  53.242  1
78755  93.848  -78.664  53.221  1
78756  93.862  -78.655  53.200  1
78757  93.876  -78.648  53.180  1
78758  93.890  -78.639  53.159  1
78759  93.904  -78.632  53.135  1
78760  93.918  -78.622  53.110  1
78761  93.930  -78.609  53.083  1
78762  93.943  -78.596  53.056  1
78763  93.954  -78.601  53.029  1
78764  93.965  -78.608  53.003  1
78765  93.975  -78.614  52.979  1
78766  93.985  -78.613  52.956  1
78767  93.995  -78.611  52.933  1
78768  94.005  -78.610  52.911  1
78769  94.015  -78.608  52.892  1
78770  94.025  -78.607  52.874  1
78771  94.035  -78.604  52.855  1
78772  94.045  -78.603  52.837  1
78773  94.055  -78.601  52.815  1
78774  94.065  -78.600  52.791  1
78775  94.073  -78.599  52.766  1
78776  94.072  -78.606  52.743  1
78777  94.065  -78.582  52.720  1
78778  94.085  -78.529  52.696  1
78779  94.140  -78.520  52.672  1
78780  94.201  -78.523  52.647  1
78781  94.262  -78.525  52.622  1
78782  94.323  -78.526  52.599  1
78783  94.374  -78.539  52.579  1
78784  94.393  -78.544  52.560  1
78785  94.385  -78.556  52.541  1
78786  94.378  -78.568  52.522  1
78787  94.369  -78.580  52.502  1
78788  94.362  -78.592  52.480  1
78789  94.354  -78.604  52.458  1
78790  94.347  -78.617  52.435  1
78791  94.339  -78.629  52.414  1
78792  94.331  -78.640  52.392  1
78793  94.324  -78.652  52.372  1
78794  94.324  -78.656  52.350  1
78795  94.341  -78.644  52.325  1
78796  94.357  -78.631  52.301  1
78797  94.373  -78.619  52.276  1
78798  94.390  -78.607  52.251  1
78799  94.406  -78.594  52.227  1
78800  94.422  -78.582  52.199  1
78801  94.433  -78.576  52.169  1
78802  94.442  -78.575  52.137  1
78803  94.456  -78.574  52.102  1
78804  94.474  -78.574  52.068  1
78805  94.492  -78.575  52.034  1
78806  94.506  -78.580  51.998  1
78807  94.515  -78.611  51.961  1
78808  94.524  -78.642  51.924  1
78809  94.533  -78.673  51.886  1
78810  94.542  -78.692  51.850  1
78811  94.554  -78.692  51.813  1
78812  94.566  -78.691  51.774  1
78813  94.578  -78.689  51.733  1
78814  94.590  -78.686  51.693  1
78815  94.602  -78.682  51.654  1
78816  94.614  -78.678  51.615  1
78817  94.626  -78.674  51.578  1
78818  94.637  -78.670  51.543  1
78819  94.649  -78.667  51.509  1
78820  94.661  -78.663  51.474  1
78821  94.673  -78.659  51.440  1
78822  94.685  -78.655  51.406  1
78823  94.696  -78.651  51.372  1
78824  94.708  -78.651  51.338  1
78825  94.718  -78.653  51.302  1
78826  94.733  -78.656  51.265  1
78827  94.751  -78.659  51.227  1
78828  94.770  -78.663  51.190  1
78829  94.789  -78.667  51.151  1
78830  94.802  -78.672  51.111  1
78831  94.808  -78.680  51.073  1
78832  94.814  -78.687  51.034  1
78833  94.819  -78.694  50.993  1
78834  94.826  -78.696  50.953  1
78835  94.835  -78.683  50.911  1
78836  94.844  -78.670  50.869  1
78837  94.853  -78.658  50.827  1
78838  94.862  -78.645  50.781  1
78839  94.872  -78.632  50.735  1
78840  94.881  -78.619  50.691  1
78841  94.890  -78.606  50.647  1
78842  94.899  -78.594  50.601  1
78843  94.906  -78.596  50.554  1
78844  94.913  -78.605  50.506  1
78845  94.920  -78.615  50.458  1
78846  94.927  -78.624  50.411  1
78847  94.932  -78.635  50.366  1
78848  94.934  -78.649  50.325  1
78849  94.935  -78.664  50.284  1
78850  94.937  -78.677  50.244  1
78851  94.939  -78.692  50.202  1
78852  94.941  -78.705  50.160  1
78853  94.943  -78.720  50.118  1
78854  94.945  -78.733  50.074  1
78855  94.957  -78.740  50.030  1
78856  94.972  -78.745  49.987  1
78857  94.986  -78.749  49.944  1
78858  95.001  -78.753  49.902  1
78859  95.016  -78.758  49.860  1
78860  95.031  -78.762  49.819  1
78861  95.047  -78.766  49.779  1
78862  95.077  -78.762  49.741  1
78863  95.107  -78.758  49.702  1
78864  95.137  -78.755  49.664  1
78865  95.167  -78.751  49.627  1
78866  95.196  -78.748  49.589  1
78867  95.227  -78.744  49.549  1
78868  95.207  -78.749  49.507  1
78869  95.236  -78.769  49.466  1
78870  95.265  -78.789  49.426  1
78871  95.294  -78.808  49.386  1
78872  95.313  -78.820  49.345  1
78873  95.332  -78.831  49.306  1
78874  95.352  -78.843  49.267  1
78875  95.371  -78.855  49.228  1
78876  95.391  -78.866  49.189  1
78877  95.410  -78.877  49.149  1
78878  95.424  -78.875  49.109  1
78879  95.438  -78.873  49.069  1
78880  95.452  -78.871  49.029  1
78881  95.466  -78.868  48.989  1
78882  95.479  -78.866  48.949  1
78883  95.493  -78.864  48.908  1
78884  95.508  -78.861  48.867  1
78885  95.516  -78.854  48.825  1
78886  95.520  -78.843  48.783  1
78887  95.535  -78.839  48.741  1
78888  95.554  -78.843  48.699  1
78889  95.559  -78.854  48.657  1
78890  95.565  -78.864  48.615  1
78891  95.573  -78.875  48.572  1
78892  95.588  -78.889  48.530  1
78893  95.601  -78.902  48.487  1
78894  95.615  -78.915  48.443  1
78895  95.629  -78.928  48.399  1
78896  95.643  -78.942  48.355  1
78897  95.657  -78.955  48.312  1
78898  95.671  -78.968  48.270  1
78899  95.685  -78.982  48.228  1
78900  95.699  -78.995  48.188  1
78901  95.714  -79.006  48.146  1
78902  95.731  -79.009  48.105  1
78903  95.747  -79.013  48.063  1
78904  95.764  -79.017  48.021  1
78905  95.781  -79.021  47.979  1
78906  95.798  -79.024  47.935  1
78907  95.815  -79.028  47.893  1
78908  95.830  -79.031  47.850  1
78909  95.839  -79.027  47.807  1
78910  95.848  -79.023  47.764  1
78911  95.858  -79.019  47.721  1
78912  95.865  -79.015  47.679  1
78913  95.872  -79.012  47.636  1
78914  95.891  -79.009  47.595  1
78915  95.927  -79.005  47.554  1
78916  95.961  -79.000  47.513  1
78917  95.984  -78.994  47.474  1
78918  96.007  -78.987  47.433  1
78919  96.030  -78.981  47.393  1
78920  96.053  -78.975  47.354  1
78921  96.077  -78.969  47.315  1
78922  96.100  -78.963  47.277  1
78923  96.129  -78.960  47.240  1
78924  96.169  -78.962  47.201  1
78925  96.209  -78.963  47.165  1
78926  96.249  -78.965  47.129  1
78927  96.289  -78.966  47.092  1
78928  96.329  -78.968  47.058  1
78929  96.365  -78.964  47.026  1
78930  96.398  -78.956  46.995  1
78931  96.424  -78.951  46.964  1
78932  96.419  -78.957  46.933  1
78933  96.416  -78.964  46.902  1
78934  96.435  -78.974  46.872  1
78935  96.454  -78.983  46.842  1
78936  96.472  -78.993  46.812  1
78937  96.491  -79.002  46.780  1
78938  96.510  -79.012  46.749  1
78939  96.528  -79.021  46.717  1
78940  96.547  -79.031  46.685  1
78941  96.562  -79.038  46.653  1
78942  96.576  -79.045  46.621  1
78943  96.601  -79.050  46.589  1
78944  96.649  -79.052  46.558  1
78945  96.697  -79.054  46.529  1
78946  96.745  -79.056  46.500  1
78947  96.778  -79.049  46.472  1
78948  96.806  -79.042  46.444  1
78949  96.844  -79.036  46.418  1
78950  96.861  -78.990  46.392  1
78951  96.892  -78.943  46.367  1
78952  96.913  -78.956  46.342  1
78953  96.933  -78.972  46.318  1
78954  96.942  -78.990  46.294  1
78955  96.939  -78.993  46.271  1
78956  96.934  -78.929  46.251  1
78957  96.945  -78.899  46.231  1
78958  96.955  -78.895  46.212  1
78959  96.963  -78.914  46.193  1
78960  96.972  -78.932  46.173  1
78961  96.980  -78.954  46.153  1
78962  96.988  -78.983  46.131  1
78963  96.979  -78.964  46.112  1
78964  96.973  -78.959  46.093  1
78965  96.973  -78.974  46.074  1
78966  96.973  -78.990  46.056  1
78967  96.997  -79.008  46.038  1
78968  97.008  -79.155  46.020  1
78969  97.027  -79.194  46.003  1
78970  97.046  -79.233  45.987  1
78971  97.065  -79.272  45.971  1
78972  97.076  -79.281  45.955  1
78973  97.082  -79.273  45.937  1
78974  97.092  -79.263  45.919  1
78975  97.099  -79.245  45.901  1
78976  97.103  -79.223  45.883  1
78977  97.108  -79.200  45.867  1
78978  97.116  -79.171  45.852  1
78979  97.125  -79.140  45.836  1
78980  97.134  -79.109  45.820  1
78981  97.143  -79.078  45.804  1
78982  97.158  -79.081  45.788  1
78983  97.186  -79.097  45.771  1
78984  97.226  -79.120  45.756  1
78985  97.264  -79.141  45.741  1
78986  97.295  -79.136  45.726  1
78987  97.323  -79.134  45.712  1
78988  97.330  -79.147  45.697  1
78989  97.336  -79.162  45.681  1
78990  97.343  -79.175  45.666  1
78991  97.350  -79.190  45.653  1
78992  97.356  -79.203  45.639  1
78993  97.363  -79.217  45.626  1
78994  97.371  -79.231  45.616  1
78995  97.384  -79.240  45.604  1
78996  97.395  -79.248  45.590  1
78997  97.402  -79.255  45.572  1
78998  97.409  -79.261  45.557  1
78999  97.417  -79.266  45.546  1
79000  97.428  -79.269  45.536  1
79001  97.439  -79.272  45.523  1
79002  97.450  -79.275  45.509  1
79003  97.461  -79.278  45.495  1
79004  97.472  -79.280  45.481  1
79005  97.483  -79.283  45.467  1
79006  97.494  -79.285  45.452  1
79007  97.505  -79.288  45.437  1
79008  97.517  -79.292  45.422  1
79009  97.530  -79.297  45.407  1
79010  97.549  -79.311  45.393  1
79011  97.568  -79.325  45.376  1
79012  97.587  -79.334  45.361  1
79013  97.606  -79.341  45.345  1
79014  97.625  -79.348  45.328  1
79015  97.643  -79.355  45.312  1
79016  97.662  -79.363  45.299  1
79017  97.681  -79.370  45.291  1
79018  97.694  -79.376  45.282  1
79019  97.700  -79.382  45.274  1
79020  97.710  -79.395  45.266  1
79021  97.721  -79.410  45.257  1
79022  97.732  -79.426  45.247  1
79023  97.743  -79.441  45.236  1
79024  97.754  -79.456  45.224  1
79025  97.766  -79.471  45.212  1
79026  97.777  -79.486  45.202  1
79027  97.790  -79.500  45.193  1
79028  97.804  -79.513  45.177  1
79029  97.817  -79.527  45.161  1
79030  97.831  -79.541  45.145  1
79031  97.845  -79.554  45.131  1
79032  97.858  -79.569  45.118  1
79033  97.871  -79.582  45.109  1
79034  97.885  -79.596  45.104  1
79035  97.897  -79.608  45.098  1
79036  97.911  -79.620  45.092  1
79037  97.931  -79.631  45.086  1
79038  97.952  -79.642  45.079  1
79039  97.975  -79.652  45.073  1
79040  98.004  -79.661  45.066  1
79041  98.032  -79.670  45.057  1
79042  98.061  -79.679  45.049  1
79043  98.083  -79.689  45.041  1
79044  98.102  -79.698  45.033  1
79045  98.129  -79.711  45.025  1
79046  98.165  -79.730  45.016  1
79047  98.189  -79.739  45.006  1
79048  98.214  -79.744  44.995  1
79049  98.239  -79.748  44.984  1
79050  98.265  -79.752  44.972  1
79051  98.290  -79.757  44.959  1
79052  98.316  -79.763  44.946  1
79053  98.343  -79.770  44.931  1
79054  98.369  -79.776  44.918  1
79055  98.395  -79.783  44.907  1
79056  98.422  -79.789  44.899  1
79057  98.449  -79.800  44.890  1
79058  98.482  -79.809  44.879  1
79059  98.515  -79.818  44.869  1
79060  98.548  -79.828  44.858  1
79061  98.580  -79.837  44.849  1
79062  98.613  -79.846  44.841  1
79063  98.646  -79.855  44.834  1
79064  98.670  -79.858  44.827  1
79065  98.685  -79.852  44.821  1
79066  98.706  -79.858  44.812  1
79067  98.727  -79.866  44.806  1
79068  98.748  -79.874  44.799  1
79069  98.769  -79.880  44.793  1
79070  98.790  -79.888  44.785  1
79071  98.812  -79.896  44.779  1
79072  98.837  -79.905  44.772  1
79073  98.860  -79.906  44.764  1
79074  98.883  -79.904  44.757  1
79075  98.908  -79.904  44.751  1
79076  98.934  -79.905  44.744  1
79077  98.959  -79.905  44.739  1
79078  98.981  -79.904  44.734  1
79079  98.998  -79.909  44.728  1
79080  99.018  -79.926  44.721  1
79081  99.038  -79.943  44.714  1
79082  99.057  -79.960  44.708  1
79083  99.076  -79.977  44.704  1
79084  99.095  -79.994  44.699  1
79085  99.115  -80.011  44.694  1
79086  99.135  -80.027  44.689  1
79087  99.167  -80.040  44.682  1
79088  99.199  -80.052  44.676  1
79089  99.231  -80.065  44.671  1
79090  99.276  -80.083  44.667  1
79091  99.296  -80.096  44.664  1
79092  99.303  -80.098  44.661  1
79093  99.349  -80.108  44.658  1
79094  99.404  -80.122  44.654  1
79095  99.454  -80.133  44.650  1
79096  99.484  -80.119  44.647  1
79097  99.513  -80.106  44.642  1
79098  99.523  -80.120  44.635  1
79099  99.526  -80.142  44.627  1
79100  99.529  -80.164  44.617  1
79101  99.533  -80.186  44.608  1
79102  99.536  -80.208  44.599  1
79103  99.539  -80.231  44.591  1
79104  99.542  -80.253  44.583  1
79105  99.545  -80.275  44.576  1
79106  99.549  -80.297  44.569  1
79107  99.552  -80.319  44.561  1
79108  99.555  -80.341  44.554  1
79109  99.558  -80.363  44.546  1
79110  99.561  -80.385  44.539  1
79111  99.565  -80.407  44.530  1
79112  99.568  -80.430  44.521  1
79113  99.571  -80.452  44.513  1
79114  99.574  -80.474  44.506  1
79115  99.577  -80.496  44.498  1
79116  99.581  -80.519  44.489  1
79117  99.584  -80.541  44.481  1
79118  99.587  -80.563  44.471  1
79119  99.590  -80.585  44.462  1
79120  99.593  -80.607  44.451  1
79121  99.625  -80.619  44.441  1
79122  99.674  -80.624  44.431  1
79123  99.721  -80.629  44.421  1
79124  99.769  -80.635  44.410  1
79125  99.817  -80.641  44.399  1
79126  99.865  -80.647  44.387  1
79127  99.913  -80.652  44.376  1
79128  99.961  -80.657  44.365  1
79129  100.009  -80.663  44.353  1
79130  100.057  -80.669  44.342  1
79131  100.105  -80.675  44.331  1
79425  93.555  -78.846  53.555  1
79426  93.564  -78.844  53.545  1
79427  93.574  -78.842  53.537  1
79428  93.584  -78.839  53.529  1
79429  93.593  -78.836  53.521  1
79430  93.603  -78.834  53.514  1
79431  93.613  -78.832  53.510  1
79432  93.623  -78.827  53.505  1
79433  93.631  -78.820  53.502  1
79434  93.662  -78.803  53.503  1
79435  93.658  -78.796  53.505  1
79436  93.662  -78.794  53.504  1
79437  93.666  -78.791  53.502  1
79438  93.672  -78.788  53.499  1
79439  93.677  -78.783  53.495  1
79440  93.683  -78.778  53.489  1
79441  93.689  -78.774  53.481  1
79442  93.695  -78.771  53.471  1
79443  93.702  -78.771  53.460  1
79444  93.709  -78.767  53.448  1
79445  93.726  -78.759  53.435  1
79446  93.751  -78.745  53.420  1
79447  93.775  -78.731  53.404  1
79448  93.800  -78.717  53.388  1
79449  93.807  -78.708  53.370  1
79450  93.811  -78.699  53.352  1
79451  93.814  -78.691  53.333  1
79452  93.818  -78.683  53.315  1
79453  93.821  -78.673  53.294  1
79454  93.824  -78.665  53.272  1
79455  93.833  -78.657  53.251  1
79456  93.847  -78.649  53.230  1
79457  93.861  -78.641  53.209  1
79458  93.875  -78.633  53.188  1
79459  93.889  -78.625  53.167  1
79460  93.903  -78.614  53.143  1
79461  93.915  -78.601  53.118  1
79462  93.928  -78.588  53.091  1
79463  93.940  -78.575  53.064  1
79464  93.952  -78.579  53.038  1
79465  93.963  -78.585  53.013  1
79466  93.973  -78.592  52.990  1
79467  93.984  -78.598  52.967  1
79468  93.994  -78.604  52.944  1
79469  94.004  -78.601  52.923  1
79470  94.014  -78.600  52.904  1
79471  94.024  -78.598  52.886  1
79472  94.034  -78.597  52.868  1
79473  94.044  -78.595  52.848  1
79474  94.054  -78.594  52.827  1
79475  94.064  -78.592  52.804  1
79476  94.070  -78.593  52.779  1
79477  94.067  -78.590  52.755  1
79478  94.062  -78.546  52.731  1
79479  94.105  -78.517  52.707  1
79480  94.166  -78.520  52.682  1
79481  94.226  -78.521  52.658  1
79482  94.287  -78.523  52.634  1
79483  94.348  -78.526  52.612  1
79484  94.400  -78.521  52.594  1
79485  94.399  -78.539  52.575  1
79486  94.391  -78.550  52.556  1
79487  94.384  -78.562  52.538  1
79488  94.376  -78.574  52.518  1
79489  94.368  -78.586  52.496  1
79490  94.360  -78.598  52.474  1
79491  94.353  -78.611  52.451  1
79492  94.345  -78.623  52.430  1
79493  94.337  -78.635  52.409  1
79494  94.330  -78.646  52.389  1
79495  94.326  -78.655  52.366  1
79496  94.343  -78.642  52.343  1
79497  94.359  -78.630  52.319  1
79498  94.376  -78.617  52.295  1
79499  94.392  -78.604  52.271  1
79500  94.408  -78.592  52.245  1
79501  94.424  -78.580  52.217  1
79502  94.441  -78.567  52.187  1
79503  94.451  -78.564  52.155  1
79504  94.465  -78.563  52.121  1
79505  94.483  -78.563  52.086  1
79506  94.495  -78.570  52.051  1
79507  94.507  -78.578  52.014  1
79508  94.518  -78.594  51.976  1
79509  94.527  -78.624  51.937  1
79510  94.536  -78.655  51.899  1
79511  94.544  -78.673  51.862  1
79512  94.555  -78.675  51.824  1
79513  94.567  -78.674  51.786  1
79514  94.579  -78.673  51.747  1
79515  94.591  -78.673  51.708  1
79516  94.604  -78.673  51.670  1
79517  94.616  -78.672  51.631  1
79518  94.628  -78.669  51.593  1
79519  94.639  -78.665  51.557  1
79520  94.651  -78.661  51.521  1
79521  94.663  -78.658  51.486  1
79522  94.675  -78.654  51.450  1
79523  94.687  -78.650  51.414  1
79524  94.698  -78.646  51.378  1
79525  94.710  -78.645  51.344  1
79526  94.720  -78.647  51.308  1
79527  94.739  -78.651  51.271  1
79528  94.758  -78.654  51.232  1
79529  94.777  -78.658  51.194  1
79530  94.795  -78.661  51.156  1
79531  94.812  -78.665  51.116  1
79532  94.818  -78.673  51.078  1
79533  94.823  -78.680  51.039  1
79534  94.829  -78.688  50.999  1
79535  94.836  -78.686  50.959  1
79536  94.845  -78.673  50.918  1
79537  94.854  -78.661  50.876  1
79538  94.864  -78.648  50.833  1
79539  94.873  -78.635  50.787  1
79540  94.882  -78.622  50.742  1
79541  94.892  -78.609  50.697  1
79542  94.901  -78.596  50.652  1
79543  94.919  -78.587  50.606  1
79544  94.929  -78.586  50.558  1
79545  94.927  -78.589  50.510  1
79546  94.934  -78.598  50.461  1
79547  94.941  -78.608  50.413  1
79548  94.948  -78.617  50.365  1
79549  94.953  -78.628  50.322  1
79550  94.955  -78.642  50.281  1
79551  94.957  -78.656  50.240  1
79552  94.958  -78.670  50.199  1
79553  94.960  -78.684  50.157  1
79554  94.962  -78.698  50.114  1
79555  94.966  -78.711  50.071  1
79556  94.981  -78.715  50.028  1
79557  94.995  -78.720  49.985  1
79558  95.011  -78.724  49.943  1
79559  95.025  -78.728  49.900  1
79560  95.040  -78.733  49.860  1
79561  95.055  -78.737  49.820  1
79562  95.069  -78.742  49.781  1
79563  95.085  -78.745  49.744  1
79564  95.115  -78.742  49.706  1
79565  95.144  -78.739  49.668  1
79566  95.175  -78.735  49.631  1
79567  95.204  -78.731  49.592  1
79568  95.226  -78.729  49.551  1
79569  95.199  -78.738  49.510  1
79570  95.228  -78.758  49.468  1
79571  95.257  -78.777  49.428  1
79572  95.286  -78.797  49.388  1
79573  95.313  -78.815  49.348  1
79574  95.332  -78.827  49.310  1
79575  95.352  -78.838  49.272  1
79576  95.372  -78.850  49.234  1
79577  95.391  -78.861  49.194  1
79578  95.410  -78.874  49.154  1
79579  95.424  -78.871  49.114  1
79580  95.438  -78.868  49.073  1
79581  95.452  -78.866  49.034  1
79582  95.466  -78.864  48.994  1
79583  95.480  -78.861  48.953  1
79584  95.494  -78.859  48.912  1
79585  95.502  -78.852  48.870  1
79586  95.507  -78.841  48.828  1
79587  95.510  -78.830  48.786  1
79588  95.525  -78.825  48.743  1
79589  95.548  -78.827  48.700  1
79590  95.562  -78.834  48.658  1
79591  95.568  -78.844  48.616  1
79592  95.574  -78.855  48.573  1
79593  95.580  -78.865  48.530  1
79594  95.586  -78.876  48.486  1
79595  95.599  -78.889  48.443  1
79596  95.613  -78.902  48.399  1
79597  95.627  -78.915  48.356  1
79598  95.641  -78.929  48.316  1
79599  95.655  -78.942  48.276  1
79600  95.669  -78.955  48.235  1
79601  95.683  -78.968  48.194  1
79602  95.697  -78.980  48.154  1
79603  95.714  -78.984  48.113  1
79604  95.731  -78.987  48.072  1
79605  95.748  -78.991  48.030  1
79606  95.765  -78.995  47.987  1
79607  95.781  -78.999  47.943  1
79608  95.799  -79.002  47.901  1
79609  95.815  -79.006  47.858  1
79610  95.832  -79.010  47.814  1
79611  95.849  -79.014  47.772  1
79612  95.866  -79.018  47.730  1
79613  95.875  -79.014  47.687  1
79614  95.886  -79.010  47.645  1
79615  95.916  -79.006  47.605  1
79616  95.940  -78.999  47.564  1
79617  95.963  -78.993  47.523  1
79618  95.986  -78.987  47.482  1
79619  96.009  -78.981  47.442  1
79620  96.032  -78.974  47.402  1
79621  96.055  -78.968  47.362  1
79622  96.079  -78.962  47.323  1
79623  96.102  -78.956  47.285  1
79624  96.129  -78.952  47.248  1
79625  96.169  -78.953  47.209  1
79626  96.209  -78.955  47.172  1
79627  96.249  -78.956  47.136  1
79628  96.289  -78.958  47.100  1
79629  96.326  -78.956  47.066  1
79630  96.359  -78.948  47.033  1
79631  96.392  -78.940  47.003  1
79632  96.425  -78.933  46.971  1
79633  96.427  -78.937  46.939  1
79634  96.422  -78.943  46.909  1
79635  96.417  -78.949  46.879  1
79636  96.429  -78.959  46.849  1
79637  96.447  -78.968  46.819  1
79638  96.466  -78.977  46.788  1
79639  96.484  -78.987  46.757  1
79640  96.503  -78.996  46.724  1
79641  96.519  -79.004  46.692  1
79642  96.533  -79.011  46.660  1
79643  96.547  -79.018  46.627  1
79644  96.582  -79.021  46.595  1
79645  96.630  -79.024  46.564  1
79646  96.678  -79.025  46.535  1
79647  96.726  -79.028  46.506  1
79648  96.773  -79.030  46.477  1
79649  96.806  -79.049  46.450  1
79650  96.825  -79.057  46.423  1
79651  96.845  -78.996  46.397  1
79652  96.871  -78.946  46.373  1
79653  96.892  -78.961  46.349  1
79654  96.912  -78.976  46.325  1
79655  96.931  -78.986  46.302  1
79656  96.937  -78.968  46.280  1
79657  96.933  -78.905  46.260  1
79658  96.944  -78.872  46.241  1
79659  96.953  -78.885  46.223  1
79660  96.961  -78.904  46.204  1
79661  96.970  -78.923  46.185  1
79662  96.979  -78.941  46.164  1
79663  96.984  -78.965  46.142  1
79664  96.976  -78.951  46.122  1
79665  96.976  -78.967  46.103  1
79666  96.976  -78.983  46.084  1
79667  96.976  -78.999  46.066  1
79668  96.974  -79.024  46.048  1
79669  96.999  -79.103  46.031  1
79670  97.017  -79.159  46.014  1
79671  97.036  -79.197  45.997  1
79672  97.055  -79.235  45.982  1
79673  97.074  -79.274  45.968  1
79674  97.088  -79.293  45.950  1
79675  97.096  -79.283  45.932  1
79676  97.101  -79.260  45.912  1
79677  97.108  -79.232  45.895  1
79678  97.117  -79.201  45.880  1
79679  97.126  -79.170  45.865  1
79680  97.136  -79.139  45.849  1
79681  97.145  -79.109  45.833  1
79682  97.154  -79.078  45.818  1
79683  97.168  -79.084  45.803  1
79684  97.185  -79.093  45.786  1
79685  97.224  -79.115  45.770  1
79686  97.262  -79.134  45.755  1
79687  97.293  -79.129  45.741  1
79688  97.307  -79.137  45.727  1
79689  97.314  -79.151  45.713  1
79690  97.320  -79.165  45.698  1
79691  97.327  -79.179  45.684  1
79692  97.333  -79.193  45.669  1
79693  97.343  -79.205  45.656  1
79694  97.357  -79.215  45.643  1
79695  97.371  -79.224  45.630  1
79696  97.385  -79.234  45.617  1
79697  97.398  -79.244  45.603  1
79698  97.405  -79.250  45.587  1
79699  97.412  -79.256  45.572  1
79700  97.421  -79.261  45.559  1
79701  97.432  -79.263  45.547  1
79702  97.443  -79.266  45.534  1
79703  97.454  -79.269  45.521  1
79704  97.465  -79.272  45.507  1
79705  97.476  -79.275  45.494  1
79706  97.487  -79.277  45.480  1
79707  97.498  -79.280  45.467  1
79708  97.509  -79.283  45.454  1
79709  97.520  -79.285  45.440  1
79710  97.531  -79.288  45.425  1
79711  97.547  -79.297  45.409  1
79712  97.566  -79.304  45.392  1
79713  97.585  -79.311  45.374  1
79714  97.603  -79.319  45.355  1
79715  97.624  -79.327  45.336  1
79716  97.643  -79.335  45.320  1
79717  97.663  -79.344  45.307  1
79718  97.683  -79.353  45.299  1
79719  97.700  -79.360  45.291  1
79720  97.713  -79.374  45.283  1
79721  97.723  -79.390  45.274  1
79722  97.733  -79.405  45.264  1
79723  97.744  -79.420  45.254  1
79724  97.754  -79.435  45.242  1
79725  97.764  -79.451  45.230  1
79726  97.775  -79.466  45.218  1
79727  97.785  -79.482  45.208  1
79728  97.797  -79.497  45.197  1
79729  97.810  -79.510  45.181  1
79730  97.823  -79.524  45.166  1
79731  97.837  -79.538  45.151  1
79732  97.851  -79.551  45.137  1
79733  97.864  -79.566  45.125  1
79734  97.877  -79.579  45.115  1
79735  97.889  -79.592  45.107  1
79736  97.901  -79.604  45.100  1
79737  97.913  -79.615  45.093  1
79738  97.933  -79.626  45.087  1
79739  97.953  -79.637  45.080  1
79740  97.978  -79.647  45.076  1
79741  98.006  -79.656  45.072  1
79742  98.034  -79.665  45.066  1
79743  98.063  -79.674  45.058  1
79744  98.091  -79.683  45.051  1
79745  98.120  -79.692  45.045  1
79746  98.148  -79.701  45.036  1
79747  98.175  -79.711  45.027  1
79748  98.201  -79.717  45.018  1
79749  98.227  -79.724  45.009  1
79750  98.253  -79.730  44.997  1
79751  98.280  -79.737  44.984  1
79752  98.306  -79.743  44.969  1
79753  98.333  -79.750  44.953  1
79754  98.359  -79.756  44.938  1
79755  98.385  -79.763  44.924  1
79756  98.412  -79.770  44.913  1
79757  98.438  -79.778  44.904  1
79758  98.465  -79.789  44.895  1
79759  98.496  -79.798  44.887  1
79760  98.529  -79.808  44.877  1
79761  98.562  -79.817  44.867  1
79762  98.594  -79.826  44.858  1
79763  98.627  -79.836  44.851  1
79764  98.660  -79.845  44.845  1
79765  98.678  -79.842  44.839  1
79766  98.693  -79.835  44.833  1
79767  98.711  -79.836  44.826  1
79768  98.732  -79.844  44.819  1
79769  98.754  -79.852  44.812  1
79770  98.775  -79.859  44.806  1
79771  98.796  -79.867  44.799  1
79772  98.817  -79.874  44.792  1
79773  98.838  -79.882  44.785  1
79774  98.860  -79.889  44.779  1
79775  98.885  -79.890  44.773  1
79776  98.911  -79.890  44.766  1
79777  98.936  -79.891  44.759  1
79778  98.961  -79.892  44.753  1
79779  98.987  -79.892  44.748  1
79780  99.002  -79.893  44.741  1
79781  99.024  -79.908  44.734  1
79782  99.044  -79.925  44.727  1
79783  99.063  -79.943  44.721  1
79784  99.083  -79.959  44.717  1
79785  99.102  -79.977  44.713  1
79786  99.122  -79.993  44.708  1
79787  99.145  -80.008  44.702  1
79788  99.178  -80.021  44.695  1
79789  99.209  -80.034  44.689  1
79790  99.241  -80.046  44.684  1
79791  99.273  -80.059  44.681  1
79792  99.308  -80.073  44.678  1
79793  99.322  -80.077  44.675  1
79794  99.336  -80.074  44.671  1
79795  99.381  -80.087  44.668  1
79796  99.427  -80.099  44.664  1
79797  99.472  -80.111  44.660  1
79798  99.502  -80.103  44.655  1
79799  99.526  -80.090  44.648  1
79800  99.526  -80.113  44.639  1
79801  99.526  -80.141  44.628  1
79802  99.529  -80.163  44.618  1
79803  99.532  -80.185  44.608  1
79804  99.536  -80.208  44.599  1
79805  99.539  -80.230  44.590  1
79806  99.542  -80.252  44.583  1
79807  99.545  -80.274  44.575  1
79808  99.548  -80.296  44.567  1
79809  99.552  -80.319  44.559  1
79810  99.555  -80.341  44.552  1
79811  99.558  -80.363  44.545  1
79812  99.561  -80.385  44.536  1
79813  99.564  -80.407  44.527  1
79814  99.568  -80.429  44.519  1
79815  99.571  -80.451  44.511  1
79816  99.574  -80.473  44.503  1
79817  99.577  -80.495  44.494  1
79818  99.580  -80.518  44.486  1
79819  99.584  -80.540  44.476  1
79820  99.587  -80.562  44.467  1
79821  99.590  -80.584  44.456  1
79822  99.634  -80.591  44.445  1
79823  99.682  -80.597  44.435  1
79824  99.729  -80.603  44.425  1
79825  99.777  -80.608  44.415  1
79826  99.826  -80.613  44.403  1
79827  99.873  -80.620  44.391  1
79828  99.921  -80.625  44.380  1
79829  99.969  -80.631  44.368  1
79830  100.017  -80.636  44.357  1
79831  100.065  -80.641  44.345  1
79832  100.113  -80.648  44.334  1
80126  93.555  -78.836  53.563  1
80127  93.565  -78.833  53.554  1
80128  93.574  -78.831  53.546  1
80129  93.584  -78.828  53.538  1
80130  93.593  -78.826  53.531  1
80131  93.604  -78.824  53.524  1
80132  93.613  -78.821  53.519  1
80133  93.623  -78.818  53.515  1
80134  93.632  -78.814  53.513  1
80135  93.650  -78.802  53.515  1
80136  93.654  -78.794  53.518  1
80137  93.658  -78.791  53.518  1
80138  93.663  -78.789  53.517  1
80139  93.669  -78.784  53.514  1
80140  93.674  -78.780  53.510  1
80141  93.680  -78.775  53.503  1
80142  93.686  -78.770  53.494  1
80143  93.692  -78.765  53.485  1
80144  93.698  -78.763  53.474  1
80145  93.712  -78.756  53.461  1
80146  93.737  -78.742  53.448  1
80147  93.762  -78.728  53.432  1
80148  93.786  -78.714  53.415  1
80149  93.805  -78.702  53.399  1
80150  93.808  -78.693  53.381  1
80151  93.812  -78.685  53.362  1
80152  93.815  -78.677  53.343  1
80153  93.819  -78.668  53.323  1
80154  93.822  -78.659  53.302  1
80155  93.826  -78.651  53.281  1
80156  93.832  -78.642  53.261  1
80157  93.846  -78.635  53.240  1
80158  93.860  -78.626  53.218  1
80159  93.874  -78.618  53.196  1
80160  93.887  -78.606  53.175  1
80161  93.900  -78.593  53.151  1
80162  93.913  -78.580  53.126  1
80163  93.925  -78.567  53.099  1
80164  93.938  -78.554  53.073  1
80165  93.949  -78.555  53.048  1
80166  93.960  -78.562  53.023  1
80167  93.971  -78.568  53.001  1
80168  93.982  -78.575  52.978  1
80169  93.992  -78.581  52.955  1
80170  94.003  -78.588  52.935  1
80171  94.013  -78.592  52.917  1
80172  94.024  -78.591  52.899  1
80173  94.034  -78.589  52.881  1
80174  94.043  -78.587  52.861  1
80175  94.053  -78.586  52.839  1
80176  94.063  -78.584  52.815  1
80177  94.066  -78.587  52.791  1
80178  94.058  -78.557  52.766  1
80179  94.070  -78.514  52.741  1
80180  94.131  -78.517  52.717  1
80181  94.192  -78.518  52.692  1
80182  94.245  -78.515  52.668  1
80183  94.290  -78.506  52.646  1
80184  94.334  -78.496  52.626  1
80185  94.379  -78.487  52.607  1
80186  94.390  -78.535  52.589  1
80187  94.397  -78.545  52.571  1
80188  94.390  -78.557  52.553  1
80189  94.382  -78.568  52.533  1
80190  94.374  -78.580  52.511  1
80191  94.366  -78.592  52.488  1
80192  94.359  -78.604  52.466  1
80193  94.351  -78.617  52.445  1
80194  94.343  -78.629  52.425  1
80195  94.336  -78.641  52.404  1
80196  94.328  -78.652  52.383  1
80197  94.345  -78.640  52.360  1
80198  94.361  -78.627  52.336  1
80199  94.378  -78.615  52.313  1
80200  94.394  -78.603  52.289  1
80201  94.410  -78.590  52.263  1
80202  94.426  -78.578  52.233  1
80203  94.443  -78.566  52.203  1
80204  94.459  -78.554  52.172  1
80205  94.473  -78.552  52.138  1
80206  94.485  -78.560  52.103  1
80207  94.496  -78.568  52.067  1
80208  94.507  -78.576  52.029  1
80209  94.519  -78.583  51.990  1
80210  94.529  -78.608  51.951  1
80211  94.538  -78.638  51.913  1
80212  94.546  -78.652  51.875  1
80213  94.555  -78.658  51.838  1
80214  94.567  -78.658  51.801  1
80215  94.579  -78.657  51.764  1
80216  94.592  -78.656  51.726  1
80217  94.604  -78.656  51.687  1
80218  94.616  -78.655  51.649  1
80219  94.628  -78.655  51.609  1
80220  94.641  -78.655  51.572  1
80221  94.653  -78.654  51.535  1
80222  94.665  -78.652  51.499  1
80223  94.677  -78.648  51.461  1
80224  94.689  -78.645  51.424  1
80225  94.700  -78.641  51.386  1
80226  94.712  -78.639  51.351  1
80227  94.726  -78.642  51.314  1
80228  94.746  -78.645  51.276  1
80229  94.764  -78.648  51.237  1
80230  94.783  -78.652  51.199  1
80231  94.802  -78.656  51.160  1
80232  94.821  -78.659  51.121  1
80233  94.827  -78.667  51.083  1
80234  94.833  -78.674  51.044  1
80235  94.838  -78.682  51.004  1
80236  94.846  -78.676  50.965  1
80237  94.855  -78.664  50.924  1
80238  94.865  -78.651  50.881  1
80239  94.874  -78.638  50.838  1
80240  94.883  -78.625  50.793  1
80241  94.893  -78.612  50.747  1
80242  94.902  -78.599  50.702  1
80243  94.923  -78.592  50.656  1
80244  94.961  -78.590  50.608  1
80245  94.972  -78.589  50.559  1
80246  94.964  -78.589  50.509  1
80247  94.956  -78.588  50.460  1
80248  94.955  -78.592  50.413  1
80249  94.962  -78.601  50.366  1
80250  94.969  -78.610  50.323  1
80251  94.974  -78.621  50.281  1
80252  94.976  -78.635  50.239  1
80253  94.977  -78.649  50.197  1
80254  94.979  -78.663  50.155  1
80255  94.981  -78.677  50.112  1
80256  94.990  -78.686  50.069  1
80257  95.005  -78.690  50.026  1
80258  95.020  -78.695  49.984  1
80259  95.035  -78.699  49.941  1
80260  95.049  -78.704  49.900  1
80261  95.064  -78.708  49.861  1
80262  95.079  -78.712  49.823  1
80263  95.094  -78.717  49.786  1
80264  95.109  -78.721  49.749  1
80265  95.123  -78.726  49.712  1
80266  95.153  -78.722  49.674  1
80267  95.183  -78.718  49.635  1
80268  95.212  -78.715  49.595  1
80269  95.209  -78.715  49.554  1
80270  95.191  -78.726  49.513  1
80271  95.219  -78.745  49.472  1
80272  95.249  -78.766  49.431  1
80273  95.278  -78.786  49.391  1
80274  95.307  -78.805  49.351  1
80275  95.333  -78.822  49.313  1
80276  95.352  -78.833  49.276  1
80277  95.372  -78.846  49.239  1
80278  95.391  -78.857  49.200  1
80279  95.411  -78.869  49.160  1
80280  95.425  -78.867  49.120  1
80281  95.439  -78.865  49.080  1
80282  95.453  -78.862  49.039  1
80283  95.466  -78.860  48.999  1
80284  95.480  -78.858  48.959  1
80285  95.489  -78.851  48.917  1
80286  95.493  -78.839  48.874  1
80287  95.497  -78.828  48.831  1
80288  95.500  -78.817  48.789  1
80289  95.515  -78.812  48.745  1
80290  95.538  -78.814  48.702  1
80291  95.561  -78.816  48.661  1
80292  95.570  -78.824  48.617  1
80293  95.577  -78.835  48.574  1
80294  95.582  -78.846  48.530  1
80295  95.588  -78.856  48.488  1
80296  95.594  -78.867  48.445  1
80297  95.600  -78.877  48.402  1
80298  95.611  -78.889  48.360  1
80299  95.625  -78.902  48.320  1
80300  95.639  -78.916  48.281  1
80301  95.653  -78.929  48.241  1
80302  95.667  -78.943  48.202  1
80303  95.681  -78.954  48.163  1
80304  95.698  -78.958  48.124  1
80305  95.715  -78.962  48.082  1
80306  95.732  -78.965  48.040  1
80307  95.748  -78.970  47.997  1
80308  95.765  -78.974  47.953  1
80309  95.782  -78.977  47.910  1
80310  95.799  -78.981  47.867  1
80311  95.816  -78.985  47.824  1
80312  95.832  -78.989  47.781  1
80313  95.852  -78.993  47.739  1
80314  95.876  -78.999  47.698  1
80315  95.895  -79.003  47.656  1
80316  95.918  -78.998  47.615  1
80317  95.942  -78.992  47.574  1
80318  95.965  -78.986  47.532  1
80319  95.988  -78.980  47.491  1
80320  96.012  -78.974  47.451  1
80321  96.035  -78.968  47.411  1
80322  96.058  -78.962  47.370  1
80323  96.081  -78.955  47.332  1
80324  96.104  -78.949  47.294  1
80325  96.128  -78.943  47.255  1
80326  96.169  -78.945  47.217  1
80327  96.208  -78.946  47.180  1
80328  96.249  -78.948  47.143  1
80329  96.288  -78.949  47.107  1
80330  96.321  -78.940  47.073  1
80331  96.354  -78.933  47.041  1
80332  96.386  -78.925  47.009  1
80333  96.417  -78.917  46.979  1
80334  96.430  -78.916  46.948  1
80335  96.430  -78.922  46.917  1
80336  96.425  -78.929  46.886  1
80337  96.420  -78.936  46.856  1
80338  96.422  -78.943  46.826  1
80339  96.441  -78.952  46.795  1
80340  96.460  -78.962  46.762  1
80341  96.476  -78.970  46.730  1
80342  96.490  -78.977  46.697  1
80343  96.504  -78.984  46.664  1
80344  96.518  -78.990  46.632  1
80345  96.562  -78.993  46.602  1
80346  96.610  -78.995  46.572  1
80347  96.659  -78.996  46.542  1
80348  96.704  -79.028  46.514  1
80349  96.739  -79.048  46.485  1
80350  96.764  -79.046  46.457  1
80351  96.790  -79.045  46.431  1
80352  96.814  -79.043  46.405  1
80353  96.853  -78.967  46.381  1
80354  96.884  -78.946  46.358  1
80355  96.900  -78.949  46.335  1
80356  96.910  -78.937  46.313  1
80357  96.922  -78.929  46.290  1
80358  96.933  -78.917  46.270  1
80359  96.943  -78.857  46.252  1
80360  96.951  -78.876  46.234  1
80361  96.960  -78.894  46.216  1
80362  96.968  -78.913  46.196  1
80363  96.977  -78.931  46.176  1
80364  96.979  -78.943  46.153  1
80365  96.979  -78.959  46.133  1
80366  96.979  -78.974  46.114  1
80367  96.979  -78.990  46.096  1
80368  96.979  -79.006  46.078  1
80369  96.979  -79.022  46.061  1
80370  96.989  -79.049  46.043  1
80371  97.007  -79.122  46.026  1
80372  97.026  -79.161  46.010  1
80373  97.045  -79.199  45.995  1
80374  97.064  -79.237  45.978  1
80375  97.083  -79.276  45.962  1
80376  97.100  -79.294  45.945  1
80377  97.109  -79.263  45.926  1
80378  97.118  -79.231  45.909  1
80379  97.127  -79.200  45.895  1
80380  97.137  -79.169  45.880  1
80381  97.146  -79.139  45.864  1
80382  97.155  -79.108  45.850  1
80383  97.164  -79.079  45.835  1
80384  97.179  -79.087  45.819  1
80385  97.194  -79.095  45.803  1
80386  97.223  -79.112  45.787  1
80387  97.260  -79.127  45.772  1
80388  97.285  -79.126  45.757  1
80389  97.291  -79.140  45.742  1
80390  97.298  -79.154  45.728  1
80391  97.304  -79.169  45.714  1
80392  97.315  -79.179  45.699  1
80393  97.329  -79.189  45.685  1
80394  97.343  -79.199  45.671  1
80395  97.357  -79.209  45.658  1
80396  97.371  -79.218  45.644  1
80397  97.385  -79.228  45.630  1
80398  97.398  -79.237  45.616  1
80399  97.408  -79.245  45.601  1
80400  97.415  -79.251  45.586  1
80401  97.424  -79.255  45.572  1
80402  97.435  -79.258  45.559  1
80403  97.446  -79.261  45.546  1
80404  97.457  -79.263  45.533  1
80405  97.468  -79.266  45.520  1
80406  97.479  -79.269  45.506  1
80407  97.491  -79.272  45.493  1
80408  97.502  -79.275  45.481  1
80409  97.513  -79.277  45.468  1
80410  97.526  -79.280  45.454  1
80411  97.541  -79.283  45.438  1
80412  97.560  -79.290  45.421  1
80413  97.579  -79.299  45.402  1
80414  97.599  -79.307  45.383  1
80415  97.619  -79.316  45.362  1
80416  97.639  -79.324  45.342  1
80417  97.659  -79.332  45.326  1
80418  97.678  -79.341  45.314  1
80419  97.691  -79.346  45.304  1
80420  97.691  -79.346  45.296  1
80421  97.706  -79.362  45.287  1
80422  97.724  -79.382  45.277  1
80423  97.740  -79.401  45.267  1
80424  97.750  -79.416  45.255  1
80425  97.761  -79.432  45.243  1
80426  97.771  -79.447  45.231  1
80427  97.782  -79.463  45.220  1
80428  97.792  -79.478  45.208  1
80429  97.802  -79.494  45.196  1
80430  97.816  -79.507  45.183  1
80431  97.829  -79.521  45.170  1
80432  97.843  -79.535  45.158  1
80433  97.856  -79.548  45.144  1
80434  97.870  -79.563  45.131  1
80435  97.882  -79.575  45.120  1
80436  97.893  -79.586  45.112  1
80437  97.905  -79.598  45.103  1
80438  97.917  -79.610  45.096  1
80439  97.934  -79.621  45.090  1
80440  97.955  -79.632  45.084  1
80441  97.980  -79.642  45.078  1
80442  98.008  -79.651  45.074  1
80443  98.036  -79.660  45.070  1
80444  98.065  -79.669  45.064  1
80445  98.093  -79.678  45.057  1
80446  98.122  -79.686  45.049  1
80447  98.150  -79.695  45.040  1
80448  98.186  -79.689  45.030  1
80449  98.218  -79.704  45.020  1
80450  98.244  -79.711  45.009  1
80451  98.270  -79.717  44.997  1
80452  98.296  -79.724  44.985  1
80453  98.323  -79.730  44.972  1
80454  98.349  -79.737  44.957  1
80455  98.375  -79.743  44.944  1
80456  98.402  -79.750  44.931  1
80457  98.428  -79.757  44.921  1
80458  98.455  -79.767  44.911  1
80459  98.483  -79.777  44.903  1
80460  98.511  -79.787  44.895  1
80461  98.544  -79.797  44.886  1
80462  98.576  -79.806  44.878  1
80463  98.609  -79.815  44.870  1
80464  98.641  -79.824  44.863  1
80465  98.672  -79.832  44.857  1
80466  98.687  -79.825  44.852  1
80467  98.701  -79.818  44.846  1
80468  98.717  -79.815  44.839  1
80469  98.738  -79.823  44.832  1
80470  98.759  -79.830  44.825  1
80471  98.780  -79.837  44.820  1
80472  98.801  -79.845  44.813  1
80473  98.822  -79.852  44.806  1
80474  98.844  -79.860  44.800  1
80475  98.865  -79.868  44.794  1
80476  98.887  -79.876  44.788  1
80477  98.913  -79.877  44.782  1
80478  98.938  -79.877  44.775  1
80479  98.963  -79.878  44.768  1
80480  98.989  -79.879  44.761  1
80481  99.005  -79.878  44.753  1
80482  99.029  -79.892  44.746  1
80483  99.051  -79.908  44.741  1
80484  99.070  -79.925  44.736  1
80485  99.089  -79.942  44.730  1
80486  99.109  -79.959  44.726  1
80487  99.128  -79.976  44.721  1
80488  99.155  -79.990  44.714  1
80489  99.188  -80.002  44.707  1
80490  99.219  -80.015  44.703  1
80491  99.251  -80.027  44.699  1
80492  99.283  -80.040  44.696  1
80493  99.314  -80.052  44.692  1
80494  99.337  -80.057  44.687  1
80495  99.360  -80.062  44.681  1
80496  99.372  -80.060  44.675  1
80497  99.385  -80.059  44.669  1
80498  99.429  -80.070  44.663  1
80499  99.474  -80.082  44.657  1
80500  99.514  -80.087  44.651  1
80501  99.538  -80.072  44.643  1
80502  99.540  -80.095  44.634  1
80503  99.531  -80.133  44.624  1
80504  99.528  -80.162  44.615  1
80505  99.532  -80.184  44.605  1
80506  99.535  -80.207  44.597  1
80507  99.539  -80.229  44.589  1
80508  99.542  -80.251  44.581  1
80509  99.545  -80.273  44.573  1
80510  99.548  -80.295  44.564  1
80511  99.551  -80.318  44.557  1
80512  99.554  -80.340  44.549  1
80513  99.558  -80.362  44.541  1
80514  99.561  -80.384  44.533  1
80515  99.564  -80.406  44.525  1
80516  99.567  -80.428  44.516  1
80517  99.570  -80.450  44.508  1
80518  99.574  -80.472  44.499  1
80519  99.577  -80.494  44.491  1
80520  99.580  -80.517  44.481  1
80521  99.583  -80.539  44.472  1
80522  99.594  -80.559  44.461  1
80523  99.642  -80.564  44.450  1
80524  99.690  -80.569  44.440  1
80525  99.738  -80.576  44.430  1
80526  99.786  -80.581  44.419  1
80527  99.834  -80.586  44.407  1
80528  99.881  -80.592  44.395  1
80529  99.929  -80.598  44.383  1
80530  99.978  -80.604  44.372  1
80531  100.025  -80.609  44.361  1
80532  100.073  -80.614  44.350  1
80533  100.121  -80.620  44.338  1
80827  93.555  -78.825  53.571  1
80828  93.565  -78.822  53.563  1
80829  93.574  -78.820  53.555  1
80830  93.584  -78.818  53.547  1
80831  93.594  -78.815  53.540  1
80832  93.604  -78.812  53.534  1
80833  93.613  -78.810  53.529  1
80834  93.623  -78.808  53.525  1
80835  93.633  -78.805  53.524  1
80836  93.642  -78.800  53.526  1
80837  93.651  -78.792  53.529  1
80838  93.655  -78.789  53.530  1
80839  93.659  -78.785  53.529  1
80840  93.665  -78.780  53.527  1
80841  93.672  -78.776  53.522  1
80842  93.677  -78.771  53.516  1
80843  93.683  -78.767  53.508  1
80844  93.689  -78.762  53.498  1
80845  93.699  -78.755  53.486  1
80846  93.724  -78.739  53.474  1
80847  93.749  -78.725  53.460  1
80848  93.773  -78.711  53.444  1
80849  93.798  -78.697  53.427  1
80850  93.806  -78.687  53.410  1
80851  93.809  -78.679  53.391  1
80852  93.813  -78.670  53.371  1
80853  93.817  -78.662  53.351  1
80854  93.820  -78.654  53.331  1
80855  93.823  -78.645  53.311  1
80856  93.827  -78.636  53.290  1
80857  93.832  -78.628  53.270  1
80858  93.845  -78.620  53.249  1
80859  93.859  -78.611  53.227  1
80860  93.872  -78.598  53.204  1
80861  93.885  -78.586  53.182  1
80862  93.898  -78.573  53.159  1
80863  93.910  -78.560  53.134  1
80864  93.923  -78.547  53.108  1
80865  93.935  -78.534  53.083  1
80866  93.947  -78.532  53.059  1
80867  93.958  -78.539  53.033  1
80868  93.969  -78.545  53.011  1
80869  93.979  -78.551  52.988  1
80870  93.990  -78.557  52.966  1
80871  94.001  -78.564  52.947  1
80872  94.011  -78.570  52.929  1
80873  94.023  -78.577  52.911  1
80874  94.033  -78.581  52.893  1
80875  94.043  -78.579  52.873  1
80876  94.053  -78.577  52.851  1
80877  94.062  -78.576  52.826  1
80878  94.060  -78.565  52.802  1
80879  94.050  -78.523  52.777  1
80880  94.090  -78.509  52.752  1
80881  94.135  -78.500  52.727  1
80882  94.180  -78.491  52.703  1
80883  94.224  -78.481  52.680  1
80884  94.269  -78.472  52.660  1
80885  94.313  -78.462  52.641  1
80886  94.357  -78.454  52.622  1
80887  94.365  -78.537  52.604  1
80888  94.380  -78.544  52.587  1
80889  94.395  -78.551  52.569  1
80890  94.388  -78.563  52.549  1
80891  94.381  -78.574  52.527  1
80892  94.372  -78.586  52.505  1
80893  94.365  -78.598  52.483  1
80894  94.357  -78.611  52.461  1
80895  94.350  -78.623  52.440  1
80896  94.342  -78.635  52.420  1
80897  94.334  -78.647  52.399  1
80898  94.347  -78.638  52.376  1
80899  94.363  -78.626  52.352  1
80900  94.380  -78.614  52.329  1
80901  94.396  -78.601  52.305  1
80902  94.412  -78.589  52.279  1
80903  94.428  -78.576  52.251  1
80904  94.445  -78.564  52.222  1
80905  94.460  -78.551  52.190  1
80906  94.471  -78.552  52.156  1
80907  94.484  -78.558  52.120  1
80908  94.497  -78.566  52.083  1
80909  94.508  -78.573  52.044  1
80910  94.520  -78.581  52.006  1
80911  94.531  -78.590  51.968  1
80912  94.540  -78.620  51.930  1
80913  94.548  -78.632  51.893  1
80914  94.556  -78.641  51.857  1
80915  94.568  -78.641  51.820  1
80916  94.580  -78.640  51.782  1
80917  94.592  -78.639  51.745  1
80918  94.605  -78.639  51.706  1
80919  94.617  -78.639  51.668  1
80920  94.629  -78.638  51.628  1
80921  94.641  -78.637  51.588  1
80922  94.653  -78.637  51.550  1
80923  94.666  -78.636  51.512  1
80924  94.678  -78.636  51.474  1
80925  94.690  -78.635  51.435  1
80926  94.702  -78.635  51.396  1
80927  94.714  -78.633  51.359  1
80928  94.733  -78.636  51.321  1
80929  94.752  -78.640  51.282  1
80930  94.771  -78.643  51.243  1
80931  94.789  -78.647  51.204  1
80932  94.809  -78.651  51.165  1
80933  94.827  -78.654  51.127  1
80934  94.837  -78.661  51.088  1
80935  94.842  -78.668  51.049  1
80936  94.848  -78.676  51.009  1
80937  94.857  -78.666  50.970  1
80938  94.866  -78.653  50.929  1
80939  94.875  -78.640  50.886  1
80940  94.885  -78.627  50.842  1
80941  94.894  -78.614  50.798  1
80942  94.903  -78.601  50.752  1
80943  94.928  -78.595  50.706  1
80944  94.965  -78.595  50.658  1
80945  95.002  -78.593  50.608  1
80946  95.014  -78.592  50.558  1
80947  95.006  -78.592  50.507  1
80948  94.998  -78.591  50.459  1
80949  94.991  -78.591  50.412  1
80950  94.983  -78.590  50.366  1
80951  94.982  -78.594  50.323  1
80952  94.989  -78.603  50.280  1
80953  94.994  -78.614  50.237  1
80954  94.996  -78.628  50.196  1
80955  94.998  -78.642  50.154  1
80956  95.000  -78.656  50.111  1
80957  95.014  -78.661  50.068  1
80958  95.029  -78.665  50.026  1
80959  95.044  -78.670  49.984  1
80960  95.058  -78.674  49.941  1
80961  95.073  -78.679  49.901  1
80962  95.088  -78.683  49.863  1
80963  95.103  -78.687  49.826  1
80964  95.118  -78.692  49.790  1
80965  95.132  -78.696  49.753  1
80966  95.147  -78.701  49.716  1
80967  95.162  -78.705  49.678  1
80968  95.190  -78.702  49.638  1
80969  95.220  -78.698  49.598  1
80970  95.192  -78.702  49.557  1
80971  95.182  -78.714  49.516  1
80972  95.211  -78.734  49.476  1
80973  95.241  -78.754  49.436  1
80974  95.270  -78.774  49.396  1
80975  95.299  -78.793  49.357  1
80976  95.328  -78.813  49.318  1
80977  95.352  -78.829  49.280  1
80978  95.372  -78.841  49.242  1
80979  95.391  -78.852  49.204  1
80980  95.411  -78.865  49.165  1
80981  95.425  -78.863  49.126  1
80982  95.439  -78.861  49.086  1
80983  95.453  -78.858  49.046  1
80984  95.467  -78.856  49.005  1
80985  95.476  -78.849  48.965  1
80986  95.479  -78.838  48.923  1
80987  95.483  -78.827  48.880  1
80988  95.487  -78.815  48.836  1
80989  95.491  -78.804  48.793  1
80990  95.504  -78.799  48.749  1
80991  95.528  -78.800  48.705  1
80992  95.551  -78.802  48.664  1
80993  95.573  -78.805  48.620  1
80994  95.579  -78.815  48.576  1
80995  95.585  -78.826  48.533  1
80996  95.591  -78.836  48.492  1
80997  95.597  -78.847  48.449  1
80998  95.603  -78.857  48.406  1
80999  95.609  -78.868  48.365  1
81000  95.614  -78.878  48.325  1
81001  95.623  -78.890  48.286  1
81002  95.637  -78.902  48.247  1
81003  95.651  -78.916  48.209  1
81004  95.665  -78.929  48.171  1
81005  95.682  -78.933  48.133  1
81006  95.698  -78.937  48.092  1
81007  95.716  -78.940  48.050  1
81008  95.732  -78.944  48.008  1
81009  95.749  -78.948  47.964  1
81010  95.768  -78.952  47.920  1
81011  95.792  -78.958  47.877  1
81012  95.816  -78.963  47.834  1
81013  95.839  -78.968  47.791  1
81014  95.864  -78.974  47.749  1
81015  95.875  -78.988  47.708  1
81016  95.894  -78.991  47.666  1
81017  95.918  -78.987  47.625  1
81018  95.943  -78.983  47.584  1
81019  95.967  -78.979  47.543  1
81020  95.990  -78.973  47.501  1
81021  96.014  -78.967  47.461  1
81022  96.037  -78.961  47.421  1
81023  96.060  -78.954  47.381  1
81024  96.083  -78.948  47.342  1
81025  96.106  -78.942  47.303  1
81026  96.129  -78.936  47.263  1
81027  96.168  -78.937  47.225  1
81028  96.208  -78.939  47.188  1
81029  96.249  -78.940  47.151  1
81030  96.282  -78.933  47.115  1
81031  96.315  -78.925  47.081  1
81032  96.347  -78.917  47.048  1
81033  96.373  -78.908  47.017  1
81034  96.398  -78.899  46.986  1
81035  96.414  -78.896  46.956  1
81036  96.415  -78.902  46.925  1
81037  96.416  -78.908  46.894  1
81038  96.418  -78.915  46.864  1
81039  96.419  -78.921  46.833  1
81040  96.418  -78.928  46.802  1
81041  96.433  -78.936  46.769  1
81042  96.447  -78.943  46.737  1
81043  96.461  -78.949  46.704  1
81044  96.475  -78.956  46.670  1
81045  96.495  -78.963  46.639  1
81046  96.543  -78.965  46.609  1
81047  96.589  -78.986  46.579  1
81048  96.632  -78.986  46.551  1
81049  96.675  -78.978  46.522  1
81050  96.717  -78.971  46.494  1
81051  96.759  -78.962  46.465  1
81052  96.802  -78.955  46.440  1
81053  96.839  -78.949  46.415  1
81054  96.855  -78.940  46.392  1
81055  96.866  -78.943  46.369  1
81056  96.889  -78.932  46.347  1
81057  96.901  -78.926  46.325  1
81058  96.913  -78.919  46.302  1
81059  96.925  -78.910  46.282  1
81060  96.927  -78.857  46.263  1
81061  96.916  -78.865  46.245  1
81062  96.924  -78.882  46.227  1
81063  96.939  -78.902  46.207  1
81064  96.967  -78.924  46.186  1
81065  96.986  -78.945  46.165  1
81066  96.985  -78.962  46.145  1
81067  96.984  -78.980  46.126  1
81068  96.984  -78.996  46.108  1
81069  96.983  -79.014  46.091  1
81070  96.982  -79.031  46.073  1
81071  96.982  -79.046  46.056  1
81072  96.997  -79.086  46.039  1
81073  97.017  -79.129  46.023  1
81074  97.038  -79.176  46.007  1
81075  97.059  -79.222  45.990  1
81076  97.080  -79.269  45.975  1
81077  97.100  -79.269  45.959  1
81078  97.119  -79.262  45.942  1
81079  97.129  -79.231  45.926  1
81080  97.138  -79.200  45.911  1
81081  97.147  -79.169  45.896  1
81082  97.156  -79.138  45.881  1
81083  97.165  -79.107  45.867  1
81084  97.175  -79.082  45.852  1
81085  97.189  -79.090  45.837  1
81086  97.205  -79.097  45.820  1
81087  97.222  -79.107  45.805  1
81088  97.258  -79.119  45.790  1
81089  97.268  -79.130  45.773  1
81090  97.275  -79.143  45.757  1
81091  97.288  -79.154  45.743  1
81092  97.302  -79.164  45.730  1
81093  97.316  -79.173  45.714  1
81094  97.329  -79.183  45.700  1
81095  97.344  -79.193  45.687  1
81096  97.357  -79.202  45.673  1
81097  97.371  -79.212  45.659  1
81098  97.385  -79.222  45.644  1
81099  97.398  -79.231  45.629  1
81100  97.411  -79.240  45.614  1
81101  97.418  -79.247  45.600  1
81102  97.428  -79.250  45.587  1
81103  97.439  -79.253  45.573  1
81104  97.450  -79.255  45.558  1
81105  97.461  -79.258  45.545  1
81106  97.472  -79.261  45.533  1
81107  97.483  -79.263  45.519  1
81108  97.496  -79.266  45.507  1
81109  97.511  -79.269  45.495  1
81110  97.525  -79.272  45.479  1
81111  97.540  -79.275  45.462  1
81112  97.555  -79.278  45.444  1
81113  97.575  -79.287  45.424  1
81114  97.595  -79.295  45.404  1
81115  97.615  -79.304  45.384  1
81116  97.635  -79.313  45.366  1
81117  97.654  -79.321  45.346  1
81118  97.674  -79.329  45.332  1
81119  97.682  -79.332  45.319  1
81120  97.682  -79.332  45.307  1
81121  97.682  -79.332  45.296  1
81122  97.698  -79.349  45.286  1
81123  97.717  -79.369  45.277  1
81124  97.735  -79.390  45.268  1
81125  97.753  -79.410  45.257  1
81126  97.768  -79.429  45.246  1
81127  97.778  -79.444  45.236  1
81128  97.789  -79.459  45.224  1
81129  97.799  -79.475  45.212  1
81130  97.809  -79.490  45.199  1
81131  97.822  -79.504  45.187  1
81132  97.836  -79.518  45.175  1
81133  97.849  -79.532  45.162  1
81134  97.862  -79.545  45.149  1
81135  97.874  -79.558  45.137  1
81136  97.886  -79.570  45.127  1
81137  97.897  -79.582  45.118  1
81138  97.909  -79.593  45.109  1
81139  97.921  -79.605  45.102  1
81140  97.936  -79.617  45.095  1
81141  97.956  -79.627  45.088  1
81142  97.982  -79.637  45.081  1
81143  98.010  -79.646  45.075  1
81144  98.038  -79.655  45.071  1
81145  98.067  -79.664  45.065  1
81146  98.095  -79.673  45.058  1
81147  98.124  -79.682  45.050  1
81148  98.160  -79.674  45.041  1
81149  98.197  -79.665  45.031  1
81150  98.231  -79.686  45.021  1
81151  98.261  -79.698  45.010  1
81152  98.287  -79.704  44.999  1
81153  98.313  -79.711  44.987  1
81154  98.340  -79.717  44.975  1
81155  98.366  -79.724  44.962  1
81156  98.392  -79.730  44.951  1
81157  98.418  -79.737  44.940  1
81158  98.445  -79.745  44.929  1
81159  98.472  -79.755  44.920  1
81160  98.499  -79.766  44.912  1
81161  98.526  -79.776  44.904  1
81162  98.558  -79.786  44.896  1
81163  98.590  -79.795  44.889  1
81164  98.623  -79.805  44.883  1
81165  98.656  -79.814  44.876  1
81166  98.680  -79.816  44.871  1
81167  98.695  -79.809  44.865  1
81168  98.709  -79.802  44.860  1
81169  98.723  -79.795  44.853  1
81170  98.743  -79.801  44.846  1
81171  98.765  -79.808  44.840  1
81172  98.786  -79.816  44.834  1
81173  98.807  -79.824  44.828  1
81174  98.828  -79.831  44.822  1
81175  98.849  -79.839  44.815  1
81176  98.871  -79.847  44.810  1
81177  98.893  -79.855  44.804  1
81178  98.915  -79.863  44.797  1
81179  98.940  -79.864  44.789  1
81180  98.965  -79.864  44.782  1
81181  98.991  -79.865  44.775  1
81182  99.009  -79.863  44.768  1
81183  99.033  -79.877  44.761  1
81184  99.057  -79.891  44.755  1
81185  99.077  -79.908  44.749  1
81186  99.096  -79.925  44.745  1
81187  99.116  -79.942  44.740  1
81188  99.135  -79.958  44.734  1
81189  99.166  -79.971  44.727  1
81190  99.198  -79.984  44.720  1
81191  99.229  -79.996  44.714  1
81192  99.261  -80.009  44.709  1
81193  99.290  -80.019  44.705  1
81194  99.313  -80.024  44.699  1
81195  99.337  -80.028  44.693  1
81196  99.360  -80.034  44.687  1
81197  99.383  -80.038  44.679  1
81198  99.406  -80.043  44.673  1
81199  99.426  -80.046  44.667  1
81200  99.439  -80.044  44.660  1
81201  99.476  -80.053  44.654  1
81202  99.521  -80.065  44.647  1
81203  99.550  -80.055  44.638  1
81204  99.552  -80.077  44.630  1
81205  99.544  -80.115  44.621  1
81206  99.536  -80.152  44.611  1
81207  99.532  -80.184  44.602  1
81208  99.535  -80.206  44.594  1
81209  99.538  -80.228  44.586  1
81210  99.541  -80.250  44.578  1
81211  99.545  -80.272  44.570  1
81212  99.548  -80.295  44.561  1
81213  99.551  -80.317  44.553  1
81214  99.554  -80.339  44.546  1
81215  99.557  -80.361  44.538  1
81216  99.561  -80.383  44.530  1
81217  99.564  -80.406  44.522  1
81218  99.567  -80.428  44.513  1
81219  99.570  -80.450  44.505  1
81220  99.573  -80.472  44.496  1
81221  99.577  -80.494  44.486  1
81222  99.580  -80.516  44.476  1
81223  99.603  -80.532  44.466  1
81224  99.650  -80.537  44.456  1
81225  99.698  -80.542  44.445  1
81226  99.746  -80.548  44.435  1
81227  99.794  -80.554  44.424  1
81228  99.842  -80.560  44.412  1
81229  99.890  -80.565  44.400  1
81230  99.938  -80.570  44.388  1
81231  99.986  -80.576  44.376  1
81232  100.034  -80.582  44.365  1
81233  100.081  -80.588  44.353  1
81234  100.130  -80.593  44.341  1
81528  93.556  -78.814  53.581  1
81529  93.565  -78.811  53.571  1
81530  93.575  -78.809  53.563  1
81531  93.584  -78.807  53.556  1
81532  93.594  -78.804  53.549  1
81533  93.604  -78.802  53.543  1
81534  93.614  -78.799  53.539  1
81535  93.623  -78.797  53.535  1
81536  93.633  -78.794  53.534  1
81537  93.642  -78.792  53.535  1
81538  93.647  -78.789  53.539  1
81539  93.650  -78.784  53.541  1
81540  93.654  -78.780  53.540  1
81541  93.663  -78.778  53.538  1
81542  93.669  -78.774  53.534  1
81543  93.675  -78.769  53.528  1
81544  93.680  -78.764  53.519  1
81545  93.688  -78.759  53.509  1
81546  93.712  -78.742  53.498  1
81547  93.736  -78.727  53.485  1
81548  93.760  -78.710  53.470  1
81549  93.784  -78.694  53.454  1
81550  93.804  -78.682  53.437  1
81551  93.807  -78.673  53.419  1
81552  93.811  -78.664  53.399  1
81553  93.814  -78.656  53.379  1
81554  93.818  -78.648  53.359  1
81555  93.821  -78.639  53.339  1
81556  93.825  -78.630  53.319  1
81557  93.828  -78.622  53.298  1
81558  93.831  -78.614  53.277  1
81559  93.844  -78.604  53.255  1
81560  93.857  -78.591  53.232  1
81561  93.869  -78.578  53.210  1
81562  93.882  -78.565  53.187  1
81563  93.895  -78.552  53.164  1
81564  93.908  -78.539  53.140  1
81565  93.920  -78.526  53.115  1
81566  93.933  -78.514  53.090  1
81567  93.945  -78.509  53.066  1
81568  93.956  -78.515  53.041  1
81569  93.967  -78.522  53.018  1
81570  93.977  -78.528  52.996  1
81571  93.988  -78.535  52.975  1
81572  93.999  -78.541  52.957  1
81573  94.009  -78.548  52.939  1
81574  94.020  -78.554  52.921  1
81575  94.031  -78.561  52.903  1
81576  94.042  -78.567  52.885  1
81577  94.052  -78.570  52.863  1
81578  94.060  -78.569  52.838  1
81579  94.055  -78.535  52.813  1
81580  94.060  -78.511  52.788  1
81581  94.074  -78.480  52.762  1
81582  94.114  -78.466  52.736  1
81583  94.158  -78.456  52.714  1
81584  94.203  -78.447  52.693  1
81585  94.248  -78.438  52.674  1
81586  94.292  -78.428  52.656  1
81587  94.336  -78.421  52.637  1
81588  94.343  -78.511  52.619  1
81589  94.355  -78.545  52.602  1
81590  94.370  -78.552  52.584  1
81591  94.385  -78.559  52.565  1
81592  94.387  -78.569  52.544  1
81593  94.379  -78.580  52.521  1
81594  94.371  -78.592  52.499  1
81595  94.363  -78.604  52.478  1
81596  94.356  -78.617  52.456  1
81597  94.348  -78.629  52.436  1
81598  94.340  -78.641  52.414  1
81599  94.349  -78.636  52.390  1
81600  94.365  -78.624  52.367  1
81601  94.382  -78.611  52.343  1
81602  94.398  -78.599  52.319  1
81603  94.414  -78.587  52.294  1
81604  94.430  -78.574  52.268  1
81605  94.445  -78.561  52.239  1
81606  94.453  -78.547  52.208  1
81607  94.466  -78.553  52.173  1
81608  94.479  -78.560  52.137  1
81609  94.493  -78.566  52.100  1
81610  94.506  -78.573  52.062  1
81611  94.520  -78.579  52.024  1
81612  94.532  -78.586  51.987  1
81613  94.542  -78.602  51.951  1
81614  94.550  -78.611  51.915  1
81615  94.558  -78.620  51.878  1
81616  94.568  -78.623  51.841  1
81617  94.580  -78.623  51.804  1
81618  94.593  -78.623  51.767  1
81619  94.605  -78.622  51.729  1
81620  94.617  -78.621  51.690  1
81621  94.629  -78.621  51.648  1
81622  94.642  -78.620  51.606  1
81623  94.654  -78.620  51.566  1
81624  94.666  -78.620  51.527  1
81625  94.679  -78.620  51.488  1
81626  94.692  -78.623  51.448  1
81627  94.705  -78.624  51.409  1
81628  94.718  -78.626  51.371  1
81629  94.740  -78.631  51.332  1
81630  94.758  -78.634  51.293  1
81631  94.777  -78.638  51.253  1
81632  94.796  -78.642  51.214  1
81633  94.815  -78.645  51.174  1
81634  94.834  -78.648  51.133  1
81635  94.846  -78.654  51.093  1
81636  94.852  -78.661  51.053  1
81637  94.858  -78.669  51.013  1
81638  94.867  -78.656  50.974  1
81639  94.876  -78.643  50.933  1
81640  94.886  -78.630  50.891  1
81641  94.895  -78.617  50.847  1
81642  94.904  -78.604  50.802  1
81643  94.932  -78.600  50.756  1
81644  94.970  -78.598  50.708  1
81645  95.007  -78.598  50.659  1
81646  95.044  -78.596  50.608  1
81647  95.056  -78.595  50.556  1
81648  95.048  -78.595  50.507  1
81649  95.041  -78.595  50.459  1
81650  95.033  -78.594  50.412  1
81651  95.025  -78.593  50.366  1
81652  95.018  -78.592  50.323  1
81653  95.010  -78.592  50.280  1
81654  95.010  -78.596  50.237  1
81655  95.016  -78.607  50.194  1
81656  95.017  -78.620  50.153  1
81657  95.023  -78.632  50.111  1
81658  95.038  -78.636  50.069  1
81659  95.053  -78.640  50.027  1
81660  95.068  -78.645  49.985  1
81661  95.083  -78.649  49.944  1
81662  95.097  -78.654  49.903  1
81663  95.112  -78.658  49.865  1
81664  95.127  -78.663  49.829  1
81665  95.142  -78.667  49.793  1
81666  95.157  -78.671  49.757  1
81667  95.171  -78.676  49.719  1
81668  95.186  -78.680  49.680  1
81669  95.201  -78.685  49.640  1
81670  95.219  -78.683  49.600  1
81671  95.176  -78.689  49.560  1
81672  95.174  -78.703  49.521  1
81673  95.203  -78.723  49.480  1
81674  95.233  -78.742  49.440  1
81675  95.262  -78.762  49.401  1
81676  95.290  -78.782  49.363  1
81677  95.320  -78.802  49.324  1
81678  95.349  -78.821  49.284  1
81679  95.372  -78.836  49.245  1
81680  95.392  -78.848  49.207  1
81681  95.411  -78.860  49.169  1
81682  95.425  -78.858  49.130  1
81683  95.440  -78.856  49.091  1
81684  95.453  -78.854  49.051  1
81685  95.462  -78.847  49.011  1
81686  95.466  -78.836  48.971  1
81687  95.470  -78.824  48.929  1
81688  95.474  -78.813  48.886  1
81689  95.478  -78.802  48.841  1
81690  95.482  -78.790  48.798  1
81691  95.494  -78.785  48.754  1
81692  95.517  -78.787  48.710  1
81693  95.541  -78.789  48.667  1
81694  95.564  -78.791  48.624  1
81695  95.581  -78.796  48.581  1
81696  95.587  -78.806  48.538  1
81697  95.593  -78.817  48.496  1
81698  95.599  -78.827  48.454  1
81699  95.605  -78.837  48.411  1
81700  95.611  -78.848  48.371  1
81701  95.617  -78.858  48.331  1
81702  95.623  -78.869  48.292  1
81703  95.629  -78.879  48.254  1
81704  95.635  -78.890  48.217  1
81705  95.649  -78.903  48.180  1
81706  95.665  -78.907  48.143  1
81707  95.683  -78.912  48.102  1
81708  95.707  -78.917  48.061  1
81709  95.731  -78.922  48.019  1
81710  95.755  -78.927  47.976  1
81711  95.779  -78.933  47.932  1
81712  95.803  -78.938  47.888  1
81713  95.827  -78.943  47.845  1
81714  95.850  -78.949  47.802  1
81715  95.862  -78.963  47.760  1
81716  95.874  -78.978  47.718  1
81717  95.894  -78.980  47.676  1
81718  95.918  -78.975  47.636  1
81719  95.943  -78.971  47.595  1
81720  95.967  -78.967  47.554  1
81721  95.991  -78.963  47.513  1
81722  96.016  -78.959  47.473  1
81723  96.039  -78.953  47.433  1
81724  96.062  -78.947  47.392  1
81725  96.085  -78.941  47.352  1
81726  96.108  -78.935  47.312  1
81727  96.131  -78.929  47.273  1
81728  96.168  -78.929  47.234  1
81729  96.208  -78.930  47.197  1
81730  96.243  -78.925  47.160  1
81731  96.276  -78.918  47.124  1
81732  96.304  -78.908  47.090  1
81733  96.329  -78.899  47.057  1
81734  96.354  -78.890  47.025  1
81735  96.379  -78.881  46.994  1
81736  96.398  -78.877  46.963  1
81737  96.399  -78.883  46.932  1
81738  96.401  -78.889  46.902  1
81739  96.402  -78.896  46.871  1
81740  96.403  -78.902  46.841  1
81741  96.406  -78.910  46.810  1
81742  96.417  -78.921  46.777  1
81743  96.427  -78.924  46.744  1
81744  96.437  -78.927  46.712  1
81745  96.446  -78.930  46.678  1
81746  96.474  -78.935  46.647  1
81747  96.518  -78.930  46.617  1
81748  96.563  -78.930  46.587  1
81749  96.608  -78.930  46.560  1
81750  96.654  -78.930  46.531  1
81751  96.699  -78.930  46.503  1
81752  96.744  -78.930  46.475  1
81753  96.790  -78.930  46.450  1
81754  96.832  -78.927  46.427  1
81755  96.851  -78.923  46.404  1
81756  96.861  -78.922  46.382  1
81757  96.871  -78.926  46.360  1
81758  96.892  -78.916  46.338  1
81759  96.904  -78.909  46.316  1
81760  96.916  -78.902  46.295  1
81761  96.915  -78.864  46.275  1
81762  96.905  -78.871  46.256  1
81763  96.907  -78.878  46.237  1
81764  96.938  -78.899  46.217  1
81765  96.966  -78.921  46.196  1
81766  96.995  -78.943  46.176  1
81767  96.996  -78.961  46.157  1
81768  96.995  -78.978  46.138  1
81769  96.994  -78.995  46.121  1
81770  96.993  -79.012  46.103  1
81771  96.990  -79.028  46.086  1
81772  96.983  -79.043  46.069  1
81773  96.994  -79.077  46.051  1
81774  97.015  -79.123  46.035  1
81775  97.036  -79.170  46.019  1
81776  97.057  -79.216  46.003  1
81777  97.078  -79.245  45.989  1
81778  97.098  -79.240  45.974  1
81779  97.118  -79.234  45.959  1
81780  97.139  -79.229  45.944  1
81781  97.148  -79.200  45.928  1
81782  97.157  -79.169  45.913  1
81783  97.166  -79.137  45.900  1
81784  97.175  -79.107  45.885  1
81785  97.185  -79.085  45.869  1
81786  97.201  -79.093  45.854  1
81787  97.215  -79.100  45.837  1
81788  97.230  -79.109  45.823  1
81789  97.247  -79.119  45.808  1
81790  97.260  -79.128  45.791  1
81791  97.275  -79.138  45.774  1
81792  97.288  -79.148  45.759  1
81793  97.302  -79.157  45.745  1
81794  97.316  -79.167  45.728  1
81795  97.329  -79.177  45.714  1
81796  97.344  -79.187  45.701  1
81797  97.357  -79.196  45.687  1
81798  97.371  -79.206  45.673  1
81799  97.385  -79.216  45.658  1
81800  97.399  -79.225  45.642  1
81801  97.413  -79.234  45.627  1
81802  97.421  -79.241  45.613  1
81803  97.432  -79.244  45.600  1
81804  97.443  -79.247  45.585  1
81805  97.454  -79.250  45.572  1
81806  97.465  -79.253  45.559  1
81807  97.480  -79.256  45.546  1
81808  97.495  -79.258  45.532  1
81809  97.510  -79.261  45.519  1
81810  97.524  -79.264  45.505  1
81811  97.539  -79.267  45.488  1
81812  97.554  -79.270  45.470  1
81813  97.571  -79.275  45.450  1
81814  97.591  -79.284  45.428  1
81815  97.610  -79.292  45.407  1
81816  97.630  -79.300  45.388  1
81817  97.650  -79.309  45.370  1
81818  97.670  -79.318  45.353  1
81819  97.674  -79.319  45.339  1
81820  97.674  -79.319  45.325  1
81821  97.674  -79.318  45.312  1
81822  97.674  -79.318  45.301  1
81823  97.690  -79.336  45.290  1
81824  97.709  -79.357  45.280  1
81825  97.727  -79.377  45.270  1
81826  97.745  -79.397  45.261  1
81827  97.764  -79.418  45.251  1
81828  97.782  -79.438  45.241  1
81829  97.796  -79.456  45.229  1
81830  97.806  -79.471  45.216  1
81831  97.816  -79.486  45.205  1
81832  97.828  -79.501  45.192  1
81833  97.842  -79.515  45.180  1
81834  97.855  -79.529  45.168  1
81835  97.867  -79.541  45.155  1
81836  97.878  -79.553  45.144  1
81837  97.890  -79.564  45.134  1
81838  97.901  -79.576  45.125  1
81839  97.913  -79.588  45.116  1
81840  97.925  -79.600  45.109  1
81841  97.937  -79.611  45.101  1
81842  97.958  -79.623  45.093  1
81843  97.984  -79.632  45.085  1
81844  98.012  -79.641  45.077  1
81845  98.040  -79.650  45.071  1
81846  98.069  -79.659  45.065  1
81847  98.097  -79.667  45.057  1
81848  98.134  -79.659  45.049  1
81849  98.171  -79.650  45.041  1
81850  98.208  -79.641  45.032  1
81851  98.241  -79.661  45.022  1
81852  98.277  -79.685  45.012  1
81853  98.303  -79.692  45.002  1
81854  98.329  -79.698  44.991  1
81855  98.356  -79.704  44.981  1
81856  98.382  -79.711  44.969  1
81857  98.409  -79.717  44.960  1
81858  98.435  -79.724  44.950  1
81859  98.462  -79.734  44.940  1
81860  98.489  -79.745  44.930  1
81861  98.516  -79.755  44.922  1
81862  98.544  -79.765  44.914  1
81863  98.572  -79.775  44.908  1
81864  98.604  -79.784  44.902  1
81865  98.637  -79.794  44.896  1
81866  98.670  -79.803  44.889  1
81867  98.688  -79.799  44.884  1
81868  98.703  -79.792  44.879  1
81869  98.717  -79.786  44.873  1
81870  98.731  -79.779  44.867  1
81871  98.749  -79.780  44.861  1
81872  98.770  -79.787  44.854  1
81873  98.791  -79.794  44.849  1
81874  98.812  -79.802  44.843  1
81875  98.833  -79.809  44.837  1
81876  98.855  -79.817  44.830  1
81877  98.877  -79.825  44.824  1
81878  98.899  -79.833  44.818  1
81879  98.920  -79.842  44.812  1
81880  98.942  -79.849  44.804  1
81881  98.968  -79.851  44.797  1
81882  98.993  -79.852  44.790  1
81883  99.015  -79.851  44.783  1
81884  99.037  -79.861  44.776  1
81885  99.061  -79.875  44.769  1
81886  99.083  -79.890  44.763  1
81887  99.102  -79.908  44.758  1
81888  99.122  -79.924  44.752  1
81889  99.144  -79.940  44.746  1
81890  99.176  -79.953  44.739  1
81891  99.208  -79.965  44.731  1
81892  99.239  -79.978  44.724  1
81893  99.266  -79.986  44.718  1
81894  99.289  -79.990  44.711  1
81895  99.312  -79.996  44.704  1
81896  99.336  -80.000  44.697  1
81897  99.359  -80.005  44.689  1
81898  99.382  -80.009  44.683  1
81899  99.406  -80.015  44.676  1
81900  99.429  -80.019  44.670  1
81901  99.452  -80.024  44.664  1
81902  99.475  -80.028  44.658  1
81903  99.493  -80.030  44.650  1
81904  99.523  -80.036  44.642  1
81905  99.562  -80.039  44.634  1
81906  99.565  -80.059  44.625  1
81907  99.556  -80.096  44.616  1
81908  99.548  -80.134  44.608  1
81909  99.540  -80.171  44.598  1
81910  99.535  -80.206  44.590  1
81911  99.538  -80.228  44.583  1
81912  99.541  -80.250  44.574  1
81913  99.544  -80.272  44.566  1
81914  99.548  -80.294  44.558  1
81915  99.551  -80.316  44.551  1
81916  99.554  -80.338  44.543  1
81917  99.557  -80.360  44.535  1
81918  99.560  -80.383  44.527  1
81919  99.564  -80.405  44.518  1
81920  99.567  -80.427  44.510  1
81921  99.570  -80.449  44.501  1
81922  99.573  -80.471  44.491  1
81923  99.576  -80.494  44.481  1
81924  99.611  -80.504  44.471  1
81925  99.658  -80.510  44.462  1
81926  99.706  -80.516  44.451  1
81927  99.755  -80.521  44.439  1
81928  99.802  -80.526  44.428  1
81929  99.850  -80.532  44.416  1
81930  99.898  -80.538  44.404  1
81931  99.946  -80.543  44.393  1
81932  99.994  -80.549  44.380  1
81933  100.042  -80.554  44.369  1
81934  100.092  -80.565  44.357  1
81935  100.143  -80.578  44.344  1
82229  93.556  -78.803  53.589  1
82230  93.565  -78.801  53.581  1
82231  93.575  -78.798  53.572  1
82232  93.585  -78.796  53.565  1
82233  93.594  -78.793  53.558  1
82234  93.604  -78.791  53.552  1
82235  93.614  -78.788  53.547  1
82236  93.624  -78.786  53.544  1
82237  93.633  -78.783  53.542  1
82238  93.641  -78.780  53.541  1
82239  93.641  -78.783  53.545  1
82240  93.644  -78.778  53.547  1
82241  93.648  -78.774  53.547  1
82242  93.658  -78.774  53.548  1
82243  93.666  -78.772  53.544  1
82244  93.672  -78.767  53.537  1
82245  93.678  -78.763  53.529  1
82246  93.700  -78.747  53.520  1
82247  93.724  -78.731  53.508  1
82248  93.749  -78.714  53.494  1
82249  93.770  -78.698  53.478  1
82250  93.789  -78.681  53.462  1
82251  93.801  -78.667  53.444  1
82252  93.804  -78.659  53.425  1
82253  93.808  -78.651  53.406  1
82254  93.812  -78.642  53.387  1
82255  93.815  -78.634  53.367  1
82256  93.818  -78.625  53.347  1
82257  93.822  -78.617  53.326  1
82258  93.825  -78.608  53.304  1
82259  93.828  -78.596  53.282  1
82260  93.840  -78.589  53.259  1
82261  93.852  -78.577  53.236  1
82262  93.865  -78.564  53.214  1
82263  93.878  -78.551  53.191  1
82264  93.891  -78.539  53.167  1
82265  93.903  -78.526  53.143  1
82266  93.916  -78.514  53.119  1
82267  93.928  -78.501  53.094  1
82268  93.950  -78.498  53.070  1
82269  93.960  -78.504  53.046  1
82270  93.970  -78.510  53.025  1
82271  93.980  -78.516  53.004  1
82272  93.991  -78.521  52.983  1
82273  94.001  -78.527  52.965  1
82274  94.011  -78.532  52.946  1
82275  94.022  -78.539  52.928  1
82276  94.032  -78.545  52.911  1
82277  94.043  -78.550  52.892  1
82278  94.053  -78.556  52.871  1
82279  94.066  -78.556  52.847  1
82280  94.072  -78.532  52.822  1
82281  94.077  -78.509  52.797  1
82282  94.087  -78.481  52.771  1
82283  94.107  -78.445  52.745  1
82284  94.137  -78.422  52.724  1
82285  94.182  -78.413  52.704  1
82286  94.226  -78.403  52.685  1
82287  94.271  -78.394  52.668  1
82288  94.314  -78.388  52.650  1
82289  94.321  -78.479  52.632  1
82290  94.330  -78.547  52.616  1
82291  94.345  -78.554  52.598  1
82292  94.360  -78.560  52.578  1
82293  94.375  -78.567  52.557  1
82294  94.385  -78.575  52.536  1
82295  94.377  -78.586  52.515  1
82296  94.369  -78.598  52.494  1
82297  94.362  -78.611  52.473  1
82298  94.354  -78.623  52.451  1
82299  94.346  -78.635  52.428  1
82300  94.351  -78.634  52.404  1
82301  94.367  -78.622  52.381  1
82302  94.384  -78.610  52.357  1
82303  94.400  -78.598  52.333  1
82304  94.416  -78.585  52.309  1
82305  94.431  -78.572  52.284  1
82306  94.439  -78.557  52.255  1
82307  94.448  -78.548  52.224  1
82308  94.461  -78.554  52.189  1
82309  94.474  -78.561  52.154  1
82310  94.488  -78.567  52.118  1
82311  94.501  -78.574  52.080  1
82312  94.514  -78.580  52.043  1
82313  94.530  -78.585  52.006  1
82314  94.546  -78.589  51.973  1
82315  94.552  -78.592  51.937  1
82316  94.560  -78.600  51.901  1
82317  94.569  -78.607  51.864  1
82318  94.581  -78.606  51.826  1
82319  94.593  -78.606  51.789  1
82320  94.606  -78.605  51.751  1
82321  94.618  -78.604  51.712  1
82322  94.630  -78.606  51.668  1
82323  94.643  -78.608  51.624  1
82324  94.657  -78.611  51.581  1
82325  94.670  -78.612  51.541  1
82326  94.683  -78.614  51.500  1
82327  94.695  -78.617  51.460  1
82328  94.708  -78.618  51.419  1
82329  94.722  -78.620  51.380  1
82330  94.743  -78.625  51.341  1
82331  94.764  -78.629  51.301  1
82332  94.784  -78.633  51.260  1
82333  94.803  -78.636  51.219  1
82334  94.821  -78.640  51.179  1
82335  94.840  -78.643  51.137  1
82336  94.856  -78.648  51.095  1
82337  94.862  -78.655  51.054  1
82338  94.868  -78.659  51.013  1
82339  94.878  -78.646  50.973  1
82340  94.887  -78.633  50.931  1
82341  94.896  -78.620  50.889  1
82342  94.905  -78.608  50.846  1
82343  94.937  -78.604  50.800  1
82344  94.974  -78.603  50.752  1
82345  95.012  -78.601  50.704  1
82346  95.049  -78.601  50.654  1
82347  95.086  -78.600  50.604  1
82348  95.098  -78.598  50.555  1
82349  95.091  -78.598  50.506  1
82350  95.083  -78.598  50.459  1
82351  95.075  -78.597  50.413  1
82352  95.067  -78.596  50.367  1
82353  95.060  -78.595  50.323  1
82354  95.052  -78.595  50.279  1
82355  95.044  -78.594  50.236  1
82356  95.037  -78.593  50.195  1
82357  95.036  -78.600  50.154  1
82358  95.047  -78.607  50.112  1
82359  95.062  -78.611  50.069  1
82360  95.077  -78.616  50.028  1
82361  95.092  -78.620  49.986  1
82362  95.107  -78.624  49.945  1
82363  95.121  -78.629  49.905  1
82364  95.131  -78.632  49.867  1
82365  95.140  -78.636  49.830  1
82366  95.149  -78.639  49.795  1
82367  95.159  -78.642  49.758  1
82368  95.169  -78.645  49.720  1
82369  95.178  -78.648  49.680  1
82370  95.188  -78.652  49.642  1
82371  95.196  -78.657  49.603  1
82372  95.177  -78.664  49.564  1
82373  95.192  -78.686  49.524  1
82374  95.208  -78.708  49.483  1
82375  95.225  -78.731  49.443  1
82376  95.253  -78.751  49.404  1
82377  95.282  -78.771  49.367  1
82378  95.312  -78.790  49.329  1
82379  95.341  -78.810  49.291  1
82380  95.370  -78.830  49.252  1
82381  95.392  -78.843  49.213  1
82382  95.411  -78.855  49.173  1
82383  95.426  -78.855  49.134  1
82384  95.440  -78.852  49.095  1
82385  95.449  -78.846  49.056  1
82386  95.453  -78.834  49.016  1
82387  95.457  -78.823  48.975  1
82388  95.460  -78.811  48.934  1
82389  95.464  -78.800  48.892  1
82390  95.468  -78.789  48.848  1
82391  95.472  -78.777  48.804  1
82392  95.483  -78.771  48.760  1
82393  95.507  -78.774  48.716  1
82394  95.530  -78.775  48.672  1
82395  95.554  -78.777  48.629  1
82396  95.577  -78.779  48.587  1
82397  95.590  -78.786  48.544  1
82398  95.596  -78.797  48.502  1
82399  95.602  -78.808  48.460  1
82400  95.607  -78.818  48.419  1
82401  95.613  -78.828  48.378  1
82402  95.619  -78.839  48.339  1
82403  95.625  -78.849  48.300  1
82404  95.631  -78.860  48.263  1
82405  95.637  -78.870  48.226  1
82406  95.645  -78.878  48.191  1
82407  95.670  -78.886  48.154  1
82408  95.694  -78.892  48.114  1
82409  95.718  -78.897  48.073  1
82410  95.742  -78.902  48.031  1
82411  95.766  -78.908  47.988  1
82412  95.790  -78.913  47.945  1
82413  95.814  -78.918  47.901  1
82414  95.837  -78.924  47.858  1
82415  95.849  -78.938  47.815  1
82416  95.861  -78.953  47.772  1
82417  95.872  -78.968  47.730  1
82418  95.893  -78.968  47.687  1
82419  95.918  -78.964  47.648  1
82420  95.942  -78.959  47.608  1
82421  95.966  -78.955  47.567  1
82422  95.990  -78.951  47.527  1
82423  96.015  -78.947  47.487  1
82424  96.039  -78.943  47.447  1
82425  96.063  -78.939  47.405  1
82426  96.088  -78.934  47.364  1
82427  96.111  -78.928  47.323  1
82428  96.134  -78.922  47.283  1
82429  96.168  -78.921  47.245  1
82430  96.204  -78.918  47.208  1
82431  96.234  -78.909  47.171  1
82432  96.259  -78.900  47.133  1
82433  96.285  -78.891  47.099  1
82434  96.310  -78.882  47.066  1
82435  96.335  -78.873  47.033  1
82436  96.360  -78.864  47.002  1
82437  96.382  -78.856  46.971  1
82438  96.384  -78.863  46.939  1
82439  96.385  -78.869  46.909  1
82440  96.386  -78.876  46.880  1
82441  96.388  -78.882  46.849  1
82442  96.397  -78.897  46.818  1
82443  96.408  -78.914  46.785  1
82444  96.418  -78.916  46.752  1
82445  96.428  -78.919  46.719  1
82446  96.437  -78.921  46.686  1
82447  96.466  -78.923  46.655  1
82448  96.512  -78.922  46.625  1
82449  96.557  -78.922  46.596  1
82450  96.602  -78.922  46.568  1
82451  96.648  -78.922  46.540  1
82452  96.693  -78.922  46.512  1
82453  96.738  -78.921  46.485  1
82454  96.781  -78.919  46.461  1
82455  96.822  -78.915  46.438  1
82456  96.847  -78.911  46.417  1
82457  96.858  -78.908  46.395  1
82458  96.868  -78.905  46.373  1
82459  96.878  -78.906  46.351  1
82460  96.895  -78.899  46.331  1
82461  96.907  -78.893  46.309  1
82462  96.904  -78.870  46.288  1
82463  96.909  -78.872  46.268  1
82464  96.918  -78.878  46.247  1
82465  96.934  -78.900  46.228  1
82466  96.964  -78.919  46.208  1
82467  96.995  -78.940  46.188  1
82468  97.006  -78.959  46.170  1
82469  97.005  -78.976  46.152  1
82470  96.999  -78.991  46.135  1
82471  96.993  -79.006  46.118  1
82472  96.986  -79.021  46.100  1
82473  96.980  -79.036  46.082  1
82474  96.991  -79.071  46.065  1
82475  97.012  -79.117  46.050  1
82476  97.033  -79.164  46.035  1
82477  97.054  -79.210  46.020  1
82478  97.075  -79.215  46.006  1
82479  97.095  -79.210  45.990  1
82480  97.115  -79.205  45.975  1
82481  97.136  -79.200  45.960  1
82482  97.156  -79.194  45.944  1
82483  97.167  -79.169  45.930  1
82484  97.176  -79.137  45.916  1
82485  97.185  -79.106  45.901  1
82486  97.196  -79.088  45.886  1
82487  97.211  -79.096  45.870  1
82488  97.226  -79.103  45.855  1
82489  97.238  -79.109  45.840  1
82490  97.248  -79.115  45.825  1
82491  97.261  -79.125  45.808  1
82492  97.275  -79.134  45.791  1
82493  97.289  -79.143  45.776  1
82494  97.303  -79.153  45.761  1
82495  97.316  -79.162  45.744  1
82496  97.330  -79.172  45.731  1
82497  97.344  -79.181  45.717  1
82498  97.358  -79.190  45.702  1
82499  97.371  -79.200  45.688  1
82500  97.385  -79.209  45.673  1
82501  97.399  -79.219  45.658  1
82502  97.413  -79.228  45.642  1
82503  97.424  -79.236  45.627  1
82504  97.435  -79.238  45.612  1
82505  97.450  -79.241  45.596  1
82506  97.465  -79.244  45.582  1
82507  97.479  -79.247  45.569  1
82508  97.494  -79.250  45.554  1
82509  97.509  -79.253  45.539  1
82510  97.523  -79.256  45.524  1
82511  97.538  -79.259  45.509  1
82512  97.553  -79.262  45.492  1
82513  97.568  -79.265  45.474  1
82514  97.586  -79.272  45.453  1
82515  97.606  -79.281  45.431  1
82516  97.626  -79.289  45.411  1
82517  97.646  -79.297  45.393  1
82518  97.665  -79.306  45.376  1
82519  97.665  -79.306  45.361  1
82520  97.665  -79.305  45.346  1
82521  97.665  -79.304  45.332  1
82522  97.665  -79.304  45.319  1
82523  97.665  -79.303  45.307  1
82524  97.682  -79.323  45.296  1
82525  97.701  -79.344  45.286  1
82526  97.719  -79.364  45.275  1
82527  97.737  -79.385  45.265  1
82528  97.756  -79.405  45.256  1
82529  97.774  -79.426  45.246  1
82530  97.792  -79.446  45.234  1
82531  97.811  -79.466  45.222  1
82532  97.823  -79.483  45.211  1
82533  97.834  -79.498  45.198  1
82534  97.847  -79.512  45.186  1
82535  97.860  -79.524  45.175  1
82536  97.871  -79.536  45.163  1
82537  97.882  -79.548  45.152  1
82538  97.894  -79.560  45.142  1
82539  97.906  -79.571  45.133  1
82540  97.917  -79.582  45.123  1
82541  97.929  -79.595  45.116  1
82542  97.940  -79.606  45.108  1
82543  97.959  -79.617  45.099  1
82544  97.986  -79.627  45.091  1
82545  98.014  -79.636  45.083  1
82546  98.042  -79.645  45.076  1
82547  98.071  -79.653  45.069  1
82548  98.108  -79.644  45.061  1
82549  98.145  -79.635  45.053  1
82550  98.182  -79.626  45.046  1
82551  98.218  -79.616  45.037  1
82552  98.251  -79.636  45.027  1
82553  98.287  -79.661  45.018  1
82554  98.320  -79.679  45.009  1
82555  98.346  -79.685  44.999  1
82556  98.372  -79.692  44.989  1
82557  98.398  -79.698  44.978  1
82558  98.425  -79.704  44.968  1
82559  98.451  -79.712  44.959  1
82560  98.479  -79.723  44.949  1
82561  98.506  -79.733  44.941  1
82562  98.533  -79.743  44.933  1
82563  98.560  -79.754  44.925  1
82564  98.587  -79.764  44.920  1
82565  98.619  -79.773  44.914  1
82566  98.652  -79.783  44.908  1
82567  98.681  -79.789  44.902  1
82568  98.696  -79.783  44.897  1
82569  98.710  -79.776  44.892  1
82570  98.725  -79.770  44.888  1
82571  98.739  -79.763  44.882  1
82572  98.755  -79.758  44.875  1
82573  98.776  -79.765  44.869  1
82574  98.796  -79.773  44.864  1
82575  98.817  -79.780  44.858  1
82576  98.839  -79.788  44.852  1
82577  98.861  -79.796  44.845  1
82578  98.882  -79.804  44.839  1
82579  98.905  -79.812  44.833  1
82580  98.926  -79.820  44.826  1
82581  98.948  -79.828  44.819  1
82582  98.970  -79.836  44.813  1
82583  98.995  -79.838  44.806  1
82584  99.020  -79.839  44.799  1
82585  99.041  -79.846  44.792  1
82586  99.065  -79.860  44.784  1
82587  99.089  -79.874  44.776  1
82588  99.110  -79.890  44.770  1
82589  99.129  -79.907  44.764  1
82590  99.154  -79.922  44.758  1
82591  99.186  -79.934  44.750  1
82592  99.218  -79.947  44.742  1
82593  99.242  -79.952  44.733  1
82594  99.265  -79.958  44.724  1
82595  99.288  -79.962  44.717  1
82596  99.311  -79.967  44.710  1
82597  99.335  -79.971  44.702  1
82598  99.358  -79.977  44.694  1
82599  99.381  -79.981  44.687  1
82600  99.405  -79.986  44.681  1
82601  99.428  -79.990  44.674  1
82602  99.451  -79.995  44.668  1
82603  99.474  -80.000  44.661  1
82604  99.497  -80.005  44.654  1
82605  99.521  -80.009  44.647  1
82606  99.544  -80.014  44.639  1
82607  99.571  -80.019  44.630  1
82608  99.577  -80.040  44.621  1
82609  99.569  -80.078  44.612  1
82610  99.561  -80.115  44.603  1
82611  99.553  -80.153  44.595  1
82612  99.544  -80.191  44.587  1
82613  99.538  -80.227  44.579  1
82614  99.541  -80.249  44.571  1
82615  99.544  -80.272  44.563  1
82616  99.547  -80.294  44.556  1
82617  99.550  -80.316  44.548  1
82618  99.554  -80.337  44.540  1
82619  99.557  -80.359  44.532  1
82620  99.560  -80.382  44.523  1
82621  99.563  -80.404  44.515  1
82622  99.566  -80.426  44.507  1
82623  99.570  -80.448  44.497  1
82624  99.573  -80.471  44.487  1
82625  99.619  -80.477  44.477  1
82626  99.667  -80.482  44.467  1
82627  99.715  -80.488  44.456  1
82628  99.763  -80.494  44.444  1
82629  99.810  -80.499  44.432  1
82630  99.858  -80.505  44.420  1
82631  99.906  -80.510  44.409  1
82632  99.955  -80.516  44.397  1
82633  100.005  -80.527  44.384  1
82634  100.056  -80.540  44.373  1
82635  100.107  -80.553  44.361  1
82636  100.158  -80.566  44.349  1
82930  93.556  -78.793  53.597  1
82931  93.566  -78.789  53.589  1
82932  93.575  -78.787  53.581  1
82933  93.585  -78.785  53.573  1
82934  93.594  -78.783  53.566  1
82935  93.605  -78.780  53.560  1
82936  93.614  -78.777  53.555  1
82937  93.624  -78.775  53.551  1
82938  93.633  -78.773  53.548  1
82939  93.638  -78.767  53.546  1
82940  93.637  -78.758  53.549  1
82941  93.638  -78.773  53.552  1
82942  93.642  -78.769  53.554  1
82943  93.652  -78.768  53.554  1
82944  93.661  -78.767  53.551  1
82945  93.669  -78.765  53.545  1
82946  93.689  -78.752  53.536  1
82947  93.708  -78.735  53.525  1
82948  93.727  -78.718  53.513  1
82949  93.747  -78.701  53.499  1
82950  93.766  -78.684  53.484  1
82951  93.785  -78.667  53.466  1
82952  93.796  -78.655  53.448  1
82953  93.799  -78.645  53.429  1
82954  93.803  -78.637  53.410  1
82955  93.806  -78.629  53.391  1
82956  93.809  -78.620  53.372  1
82957  93.813  -78.612  53.351  1
82958  93.817  -78.603  53.331  1
82959  93.819  -78.589  53.309  1
82960  93.822  -78.575  53.286  1
82961  93.835  -78.579  53.262  1
82962  93.847  -78.566  53.238  1
82963  93.860  -78.554  53.216  1
82964  93.873  -78.541  53.193  1
82965  93.886  -78.529  53.169  1
82966  93.898  -78.516  53.143  1
82967  93.911  -78.503  53.120  1
82968  93.939  -78.488  53.096  1
82969  93.960  -78.486  53.073  1
82970  93.964  -78.495  53.051  1
82971  93.974  -78.501  53.031  1
82972  93.985  -78.507  53.011  1
82973  93.995  -78.512  52.990  1
82974  94.005  -78.518  52.972  1
82975  94.016  -78.523  52.953  1
82976  94.027  -78.529  52.935  1
82977  94.037  -78.535  52.917  1
82978  94.048  -78.540  52.898  1
82979  94.062  -78.539  52.876  1
82980  94.077  -78.537  52.853  1
82981  94.089  -78.529  52.827  1
82982  94.094  -78.506  52.802  1
82983  94.100  -78.482  52.777  1
82984  94.119  -78.447  52.752  1
82985  94.139  -78.411  52.731  1
82986  94.161  -78.379  52.711  1
82987  94.205  -78.369  52.694  1
82988  94.250  -78.360  52.677  1
82989  94.292  -78.356  52.660  1
82990  94.299  -78.445  52.643  1
82991  94.307  -78.535  52.626  1
82992  94.321  -78.555  52.608  1
82993  94.335  -78.561  52.589  1
82994  94.350  -78.568  52.568  1
82995  94.365  -78.575  52.547  1
82996  94.380  -78.582  52.527  1
82997  94.376  -78.593  52.507  1
82998  94.368  -78.604  52.486  1
82999  94.360  -78.617  52.464  1
83000  94.352  -78.629  52.442  1
83001  94.353  -78.633  52.418  1
83002  94.369  -78.620  52.395  1
83003  94.386  -78.608  52.371  1
83004  94.402  -78.595  52.347  1
83005  94.418  -78.582  52.323  1
83006  94.425  -78.568  52.298  1
83007  94.432  -78.553  52.269  1
83008  94.442  -78.549  52.238  1
83009  94.456  -78.555  52.204  1
83010  94.470  -78.561  52.170  1
83011  94.485  -78.566  52.135  1
83012  94.501  -78.570  52.097  1
83013  94.517  -78.574  52.061  1
83014  94.532  -78.579  52.026  1
83015  94.548  -78.583  51.992  1
83016  94.557  -78.586  51.958  1
83017  94.563  -78.588  51.923  1
83018  94.570  -78.590  51.886  1
83019  94.582  -78.592  51.848  1
83020  94.595  -78.594  51.810  1
83021  94.608  -78.596  51.771  1
83022  94.621  -78.598  51.731  1
83023  94.634  -78.600  51.688  1
83024  94.647  -78.602  51.643  1
83025  94.660  -78.604  51.596  1
83026  94.673  -78.606  51.554  1
83027  94.686  -78.608  51.512  1
83028  94.699  -78.610  51.470  1
83029  94.712  -78.612  51.428  1
83030  94.725  -78.614  51.387  1
83031  94.747  -78.619  51.346  1
83032  94.768  -78.623  51.305  1
83033  94.789  -78.627  51.262  1
83034  94.809  -78.631  51.221  1
83035  94.828  -78.635  51.180  1
83036  94.846  -78.638  51.138  1
83037  94.865  -78.642  51.095  1
83038  94.872  -78.649  51.052  1
83039  94.879  -78.648  51.009  1
83040  94.888  -78.636  50.967  1
83041  94.897  -78.623  50.925  1
83042  94.906  -78.611  50.882  1
83043  94.942  -78.608  50.840  1
83044  94.979  -78.608  50.794  1
83045  95.016  -78.606  50.746  1
83046  95.053  -78.605  50.698  1
83047  95.072  -78.605  50.649  1
83048  95.075  -78.607  50.601  1
83049  95.069  -78.606  50.553  1
83050  95.064  -78.605  50.505  1
83051  95.058  -78.604  50.459  1
83052  95.052  -78.604  50.413  1
83053  95.047  -78.603  50.367  1
83054  95.041  -78.602  50.324  1
83055  95.036  -78.601  50.279  1
83056  95.030  -78.601  50.236  1
83057  95.030  -78.595  50.194  1
83058  95.046  -78.580  50.154  1
83059  95.061  -78.585  50.112  1
83060  95.072  -78.589  50.069  1
83061  95.083  -78.592  50.027  1
83062  95.094  -78.596  49.986  1
83063  95.104  -78.599  49.945  1
83064  95.115  -78.603  49.906  1
83065  95.126  -78.607  49.867  1
83066  95.136  -78.611  49.830  1
83067  95.147  -78.614  49.794  1
83068  95.158  -78.618  49.757  1
83069  95.168  -78.622  49.719  1
83070  95.179  -78.625  49.681  1
83071  95.190  -78.629  49.643  1
83072  95.214  -78.641  49.606  1
83073  95.224  -78.652  49.567  1
83074  95.232  -78.670  49.527  1
83075  95.246  -78.691  49.486  1
83076  95.259  -78.712  49.446  1
83077  95.274  -78.733  49.407  1
83078  95.290  -78.756  49.370  1
83079  95.305  -78.778  49.333  1
83080  95.333  -78.799  49.297  1
83081  95.361  -78.818  49.259  1
83082  95.391  -78.838  49.220  1
83083  95.411  -78.850  49.181  1
83084  95.426  -78.851  49.140  1
83085  95.436  -78.844  49.100  1
83086  95.439  -78.833  49.061  1
83087  95.443  -78.821  49.020  1
83088  95.447  -78.810  48.980  1
83089  95.451  -78.799  48.939  1
83090  95.455  -78.787  48.897  1
83091  95.459  -78.776  48.854  1
83092  95.463  -78.764  48.809  1
83093  95.473  -78.758  48.765  1
83094  95.496  -78.760  48.721  1
83095  95.520  -78.761  48.677  1
83096  95.543  -78.764  48.635  1
83097  95.567  -78.766  48.593  1
83098  95.590  -78.767  48.550  1
83099  95.598  -78.777  48.508  1
83100  95.604  -78.788  48.467  1
83101  95.610  -78.798  48.427  1
83102  95.616  -78.808  48.387  1
83103  95.622  -78.819  48.348  1
83104  95.628  -78.830  48.310  1
83105  95.633  -78.840  48.273  1
83106  95.641  -78.849  48.237  1
83107  95.654  -78.852  48.202  1
83108  95.678  -78.862  48.166  1
83109  95.705  -78.872  48.127  1
83110  95.729  -78.877  48.086  1
83111  95.753  -78.883  48.045  1
83112  95.777  -78.888  48.001  1
83113  95.801  -78.893  47.958  1
83114  95.825  -78.899  47.915  1
83115  95.837  -78.913  47.872  1
83116  95.848  -78.928  47.828  1
83117  95.859  -78.943  47.786  1
83118  95.873  -78.953  47.743  1
83119  95.894  -78.952  47.700  1
83120  95.918  -78.949  47.660  1
83121  95.942  -78.945  47.619  1
83122  95.966  -78.942  47.579  1
83123  95.990  -78.939  47.540  1
83124  96.015  -78.935  47.500  1
83125  96.039  -78.931  47.459  1
83126  96.063  -78.927  47.416  1
83127  96.088  -78.923  47.374  1
83128  96.112  -78.919  47.334  1
83129  96.136  -78.915  47.294  1
83130  96.165  -78.910  47.256  1
83131  96.190  -78.901  47.219  1
83132  96.215  -78.892  47.181  1
83133  96.240  -78.883  47.144  1
83134  96.265  -78.874  47.108  1
83135  96.291  -78.865  47.074  1
83136  96.316  -78.855  47.042  1
83137  96.340  -78.846  47.011  1
83138  96.366  -78.837  46.980  1
83139  96.368  -78.843  46.948  1
83140  96.369  -78.849  46.916  1
83141  96.371  -78.855  46.886  1
83142  96.376  -78.868  46.854  1
83143  96.388  -78.885  46.822  1
83144  96.399  -78.902  46.791  1
83145  96.409  -78.908  46.758  1
83146  96.418  -78.911  46.726  1
83147  96.429  -78.914  46.694  1
83148  96.461  -78.915  46.664  1
83149  96.506  -78.915  46.634  1
83150  96.551  -78.914  46.606  1
83151  96.596  -78.914  46.577  1
83152  96.642  -78.914  46.550  1
83153  96.687  -78.914  46.523  1
83154  96.731  -78.912  46.497  1
83155  96.771  -78.907  46.473  1
83156  96.812  -78.902  46.451  1
83157  96.844  -78.898  46.430  1
83158  96.854  -78.895  46.408  1
83159  96.864  -78.893  46.386  1
83160  96.874  -78.890  46.365  1
83161  96.885  -78.887  46.345  1
83162  96.898  -78.883  46.322  1
83163  96.901  -78.873  46.301  1
83164  96.922  -78.869  46.280  1
83165  96.929  -78.877  46.259  1
83166  96.929  -78.902  46.239  1
83167  96.960  -78.921  46.220  1
83168  96.990  -78.946  46.201  1
83169  97.008  -78.954  46.184  1
83170  97.002  -78.969  46.167  1
83171  96.996  -78.984  46.150  1
83172  96.990  -78.999  46.132  1
83173  96.983  -79.013  46.115  1
83174  96.977  -79.028  46.097  1
83175  96.989  -79.065  46.080  1
83176  97.010  -79.111  46.066  1
83177  97.031  -79.158  46.052  1
83178  97.052  -79.190  46.038  1
83179  97.073  -79.185  46.022  1
83180  97.093  -79.180  46.006  1
83181  97.113  -79.175  45.991  1
83182  97.133  -79.170  45.976  1
83183  97.153  -79.165  45.962  1
83184  97.174  -79.159  45.948  1
83185  97.186  -79.137  45.933  1
83186  97.195  -79.106  45.918  1
83187  97.207  -79.091  45.903  1
83188  97.222  -79.099  45.888  1
83189  97.232  -79.104  45.873  1
83190  97.239  -79.107  45.857  1
83191  97.249  -79.112  45.842  1
83192  97.262  -79.122  45.825  1
83193  97.277  -79.131  45.809  1
83194  97.290  -79.140  45.793  1
83195  97.304  -79.150  45.777  1
83196  97.317  -79.159  45.761  1
83197  97.331  -79.169  45.746  1
83198  97.345  -79.178  45.733  1
83199  97.359  -79.187  45.717  1
83200  97.372  -79.197  45.702  1
83201  97.386  -79.206  45.687  1
83202  97.401  -79.215  45.673  1
83203  97.416  -79.223  45.657  1
83204  97.429  -79.225  45.640  1
83205  97.449  -79.234  45.622  1
83206  97.464  -79.237  45.604  1
83207  97.478  -79.239  45.589  1
83208  97.493  -79.242  45.574  1
83209  97.508  -79.245  45.558  1
83210  97.523  -79.248  45.541  1
83211  97.537  -79.251  45.523  1
83212  97.552  -79.254  45.506  1
83213  97.567  -79.257  45.489  1
83214  97.582  -79.260  45.471  1
83215  97.602  -79.269  45.453  1
83216  97.621  -79.278  45.435  1
83217  97.642  -79.286  45.417  1
83218  97.657  -79.292  45.401  1
83219  97.657  -79.292  45.385  1
83220  97.657  -79.291  45.370  1
83221  97.657  -79.291  45.355  1
83222  97.656  -79.291  45.341  1
83223  97.656  -79.290  45.328  1
83224  97.657  -79.291  45.315  1
83225  97.675  -79.310  45.303  1
83226  97.693  -79.331  45.293  1
83227  97.712  -79.351  45.282  1
83228  97.730  -79.372  45.273  1
83229  97.748  -79.392  45.263  1
83230  97.767  -79.413  45.252  1
83231  97.785  -79.433  45.241  1
83232  97.803  -79.454  45.230  1
83233  97.821  -79.473  45.219  1
83234  97.840  -79.494  45.207  1
83235  97.852  -79.507  45.195  1
83236  97.863  -79.519  45.183  1
83237  97.875  -79.531  45.172  1
83238  97.886  -79.542  45.161  1
83239  97.898  -79.554  45.150  1
83240  97.910  -79.566  45.141  1
83241  97.921  -79.578  45.131  1
83242  97.933  -79.589  45.123  1
83243  97.944  -79.601  45.115  1
83244  97.961  -79.612  45.106  1
83245  97.988  -79.622  45.097  1
83246  98.016  -79.631  45.089  1
83247  98.045  -79.638  45.082  1
83248  98.082  -79.629  45.075  1
83249  98.119  -79.620  45.067  1
83250  98.156  -79.611  45.060  1
83251  98.194  -79.602  45.053  1
83252  98.229  -79.592  45.044  1
83253  98.262  -79.610  45.035  1
83254  98.298  -79.636  45.027  1
83255  98.334  -79.660  45.017  1
83256  98.363  -79.672  45.008  1
83257  98.389  -79.679  44.998  1
83258  98.415  -79.685  44.988  1
83259  98.441  -79.692  44.978  1
83260  98.468  -79.701  44.968  1
83261  98.496  -79.711  44.960  1
83262  98.523  -79.722  44.952  1
83263  98.550  -79.732  44.944  1
83264  98.577  -79.742  44.937  1
83265  98.604  -79.752  44.931  1
83266  98.633  -79.763  44.925  1
83267  98.666  -79.772  44.920  1
83268  98.690  -79.773  44.915  1
83269  98.704  -79.767  44.910  1
83270  98.718  -79.760  44.907  1
83271  98.733  -79.753  44.903  1
83272  98.747  -79.746  44.897  1
83273  98.762  -79.739  44.890  1
83274  98.781  -79.744  44.884  1
83275  98.802  -79.751  44.878  1
83276  98.823  -79.758  44.873  1
83277  98.845  -79.767  44.867  1
83278  98.867  -79.774  44.860  1
83279  98.888  -79.783  44.854  1
83280  98.910  -79.791  44.847  1
83281  98.932  -79.798  44.841  1
83282  98.954  -79.807  44.835  1
83283  98.976  -79.815  44.828  1
83284  98.997  -79.823  44.821  1
83285  99.022  -79.825  44.814  1
83286  99.045  -79.830  44.807  1
83287  99.069  -79.845  44.798  1
83288  99.093  -79.858  44.789  1
83289  99.116  -79.873  44.783  1
83290  99.135  -79.889  44.776  1
83291  99.164  -79.903  44.769  1
83292  99.195  -79.914  44.760  1
83293  99.218  -79.920  44.750  1
83294  99.241  -79.924  44.740  1
83295  99.264  -79.929  44.730  1
83296  99.287  -79.933  44.722  1
83297  99.311  -79.938  44.714  1
83298  99.334  -79.943  44.706  1
83299  99.357  -79.948  44.699  1
83300  99.380  -79.952  44.692  1
83301  99.404  -79.957  44.686  1
83302  99.427  -79.962  44.679  1
83303  99.450  -79.967  44.672  1
83304  99.474  -79.971  44.665  1
83305  99.497  -79.976  44.658  1
83306  99.520  -79.982  44.651  1
83307  99.544  -79.988  44.643  1
83308  99.568  -79.995  44.634  1
83309  99.588  -79.998  44.625  1
83310  99.587  -80.026  44.616  1
83311  99.582  -80.060  44.607  1
83312  99.573  -80.097  44.599  1
83313  99.565  -80.135  44.591  1
83314  99.557  -80.173  44.583  1
83315  99.549  -80.210  44.576  1
83316  99.541  -80.248  44.569  1
83317  99.544  -80.271  44.561  1
83318  99.547  -80.293  44.553  1
83319  99.550  -80.315  44.545  1
83320  99.553  -80.337  44.537  1
83321  99.557  -80.359  44.529  1
83322  99.560  -80.381  44.520  1
83323  99.563  -80.403  44.512  1
83324  99.566  -80.425  44.502  1
83325  99.579  -80.444  44.493  1
83326  99.627  -80.450  44.483  1
83327  99.675  -80.455  44.471  1
83328  99.723  -80.461  44.461  1
83329  99.771  -80.466  44.450  1
83330  99.819  -80.472  44.439  1
83331  99.867  -80.478  44.426  1
83332  99.917  -80.489  44.414  1
83333  99.969  -80.501  44.403  1
83334  100.020  -80.514  44.390  1
83335  100.071  -80.527  44.378  1
83336  100.122  -80.540  44.366  1
83337  100.174  -80.553  44.353  1
83632  93.566  -78.779  53.597  1
83633  93.576  -78.777  53.588  1
83634  93.585  -78.774  53.579  1
83635  93.595  -78.771  53.573  1
83636  93.605  -78.769  53.568  1
83637  93.614  -78.767  53.562  1
83638  93.624  -78.764  53.557  1
83639  93.634  -78.761  53.553  1
83640  93.635  -78.754  53.551  1
83641  93.633  -78.745  53.554  1
83642  93.632  -78.767  53.557  1
83643  93.636  -78.763  53.560  1
83644  93.645  -78.762  53.559  1
83645  93.655  -78.761  53.556  1
83646  93.667  -78.749  53.550  1
83647  93.685  -78.738  53.541  1
83648  93.704  -78.720  53.530  1
83649  93.723  -78.704  53.517  1
83650  93.743  -78.686  53.503  1
83651  93.762  -78.670  53.488  1
83652  93.781  -78.653  53.470  1
83653  93.791  -78.641  53.452  1
83654  93.794  -78.633  53.433  1
83655  93.797  -78.623  53.414  1
83656  93.801  -78.615  53.395  1
83657  93.804  -78.607  53.375  1
83658  93.807  -78.596  53.355  1
83659  93.811  -78.582  53.333  1
83660  93.813  -78.568  53.310  1
83661  93.816  -78.554  53.286  1
83662  93.824  -78.550  53.262  1
83663  93.842  -78.555  53.238  1
83664  93.855  -78.542  53.215  1
83665  93.868  -78.530  53.192  1
83666  93.880  -78.517  53.168  1
83667  93.893  -78.505  53.143  1
83668  93.908  -78.492  53.119  1
83669  93.952  -78.474  53.096  1
83670  93.970  -78.474  53.075  1
83671  93.971  -78.484  53.055  1
83672  93.979  -78.492  53.038  1
83673  93.989  -78.497  53.019  1
83674  94.000  -78.503  52.998  1
83675  94.010  -78.508  52.978  1
83676  94.020  -78.514  52.959  1
83677  94.031  -78.520  52.941  1
83678  94.043  -78.523  52.922  1
83679  94.058  -78.521  52.902  1
83680  94.072  -78.520  52.880  1
83681  94.087  -78.518  52.856  1
83682  94.102  -78.517  52.830  1
83683  94.111  -78.503  52.804  1
83684  94.117  -78.479  52.780  1
83685  94.132  -78.448  52.757  1
83686  94.151  -78.412  52.736  1
83687  94.171  -78.376  52.717  1
83688  94.190  -78.341  52.701  1
83689  94.229  -78.326  52.686  1
83690  94.271  -78.322  52.669  1
83691  94.278  -78.413  52.652  1
83692  94.285  -78.503  52.635  1
83693  94.295  -78.556  52.617  1
83694  94.311  -78.563  52.598  1
83695  94.325  -78.570  52.577  1
83696  94.340  -78.576  52.557  1
83697  94.355  -78.583  52.538  1
83698  94.370  -78.589  52.519  1
83699  94.374  -78.599  52.498  1
83700  94.366  -78.611  52.477  1
83701  94.359  -78.623  52.455  1
83702  94.355  -78.631  52.432  1
83703  94.371  -78.618  52.409  1
83704  94.388  -78.606  52.385  1
83705  94.404  -78.594  52.361  1
83706  94.411  -78.579  52.337  1
83707  94.418  -78.564  52.310  1
83708  94.427  -78.549  52.281  1
83709  94.441  -78.547  52.249  1
83710  94.457  -78.551  52.216  1
83711  94.472  -78.556  52.183  1
83712  94.488  -78.560  52.148  1
83713  94.503  -78.564  52.112  1
83714  94.519  -78.569  52.076  1
83715  94.535  -78.573  52.041  1
83716  94.550  -78.577  52.008  1
83717  94.563  -78.581  51.976  1
83718  94.569  -78.582  51.942  1
83719  94.575  -78.585  51.905  1
83720  94.585  -78.583  51.866  1
83721  94.599  -78.587  51.828  1
83722  94.612  -78.590  51.789  1
83723  94.625  -78.592  51.748  1
83724  94.638  -78.594  51.705  1
83725  94.651  -78.596  51.658  1
83726  94.664  -78.598  51.611  1
83727  94.677  -78.600  51.566  1
83728  94.690  -78.602  51.522  1
83729  94.703  -78.604  51.478  1
83730  94.716  -78.606  51.434  1
83731  94.729  -78.608  51.389  1
83732  94.750  -78.612  51.345  1
83733  94.771  -78.617  51.301  1
83734  94.792  -78.621  51.258  1
83735  94.814  -78.625  51.215  1
83736  94.834  -78.630  51.173  1
83737  94.853  -78.633  51.130  1
83738  94.872  -78.636  51.085  1
83739  94.881  -78.643  51.042  1
83740  94.889  -78.639  50.999  1
83741  94.898  -78.626  50.955  1
83742  94.909  -78.614  50.913  1
83743  94.946  -78.613  50.871  1
83744  94.983  -78.611  50.829  1
83745  95.021  -78.611  50.784  1
83746  95.030  -78.612  50.738  1
83747  95.034  -78.614  50.692  1
83748  95.039  -78.616  50.644  1
83749  95.034  -78.615  50.597  1
83750  95.029  -78.614  50.551  1
83751  95.023  -78.614  50.504  1
83752  95.017  -78.613  50.459  1
83753  95.012  -78.612  50.414  1
83754  95.006  -78.611  50.369  1
83755  95.000  -78.611  50.324  1
83756  95.006  -78.599  50.280  1
83757  95.021  -78.581  50.237  1
83758  95.035  -78.564  50.194  1
83759  95.054  -78.561  50.152  1
83760  95.074  -78.566  50.110  1
83761  95.086  -78.570  50.068  1
83762  95.097  -78.573  50.026  1
83763  95.108  -78.576  49.984  1
83764  95.118  -78.580  49.943  1
83765  95.129  -78.584  49.905  1
83766  95.139  -78.588  49.866  1
83767  95.150  -78.592  49.828  1
83768  95.161  -78.595  49.791  1
83769  95.172  -78.598  49.754  1
83770  95.182  -78.602  49.717  1
83771  95.193  -78.606  49.680  1
83772  95.208  -78.612  49.644  1
83773  95.241  -78.630  49.606  1
83774  95.274  -78.646  49.568  1
83775  95.275  -78.656  49.528  1
83776  95.289  -78.677  49.488  1
83777  95.303  -78.698  49.448  1
83778  95.317  -78.720  49.409  1
83779  95.331  -78.741  49.372  1
83780  95.345  -78.762  49.337  1
83781  95.358  -78.783  49.302  1
83782  95.373  -78.804  49.266  1
83783  95.387  -78.825  49.228  1
83784  95.412  -78.846  49.189  1
83785  95.422  -78.843  49.148  1
83786  95.426  -78.831  49.107  1
83787  95.429  -78.820  49.066  1
83788  95.433  -78.808  49.026  1
83789  95.438  -78.797  48.985  1
83790  95.442  -78.786  48.944  1
83791  95.445  -78.774  48.902  1
83792  95.449  -78.763  48.859  1
83793  95.453  -78.752  48.815  1
83794  95.463  -78.744  48.770  1
83795  95.486  -78.746  48.725  1
83796  95.510  -78.749  48.682  1
83797  95.533  -78.750  48.641  1
83798  95.556  -78.752  48.599  1
83799  95.580  -78.754  48.557  1
83800  95.600  -78.758  48.515  1
83801  95.606  -78.768  48.475  1
83802  95.612  -78.779  48.436  1
83803  95.618  -78.789  48.397  1
83804  95.624  -78.799  48.358  1
83805  95.630  -78.810  48.320  1
83806  95.637  -78.819  48.283  1
83807  95.650  -78.824  48.248  1
83808  95.661  -78.827  48.213  1
83809  95.684  -78.836  48.178  1
83810  95.713  -78.849  48.139  1
83811  95.740  -78.858  48.099  1
83812  95.764  -78.863  48.058  1
83813  95.788  -78.868  48.014  1
83814  95.812  -78.874  47.971  1
83815  95.824  -78.888  47.929  1
83816  95.835  -78.903  47.886  1
83817  95.850  -78.908  47.843  1
83818  95.868  -78.910  47.800  1
83819  95.883  -78.914  47.757  1
83820  95.896  -78.917  47.714  1
83821  95.920  -78.914  47.673  1
83822  95.945  -78.911  47.631  1
83823  95.969  -78.907  47.590  1
83824  95.993  -78.904  47.551  1
83825  96.017  -78.901  47.511  1
83826  96.041  -78.898  47.469  1
83827  96.065  -78.894  47.427  1
83828  96.090  -78.891  47.385  1
83829  96.114  -78.888  47.344  1
83830  96.138  -78.885  47.305  1
83831  96.156  -78.896  47.267  1
83832  96.172  -78.883  47.230  1
83833  96.196  -78.874  47.193  1
83834  96.221  -78.865  47.155  1
83835  96.246  -78.855  47.118  1
83836  96.271  -78.846  47.083  1
83837  96.297  -78.837  47.051  1
83838  96.321  -78.828  47.020  1
83839  96.346  -78.820  46.989  1
83840  96.352  -78.824  46.956  1
83841  96.353  -78.830  46.923  1
83842  96.356  -78.837  46.891  1
83843  96.367  -78.855  46.858  1
83844  96.378  -78.872  46.826  1
83845  96.389  -78.890  46.796  1
83846  96.400  -78.900  46.764  1
83847  96.410  -78.903  46.732  1
83848  96.419  -78.905  46.702  1
83849  96.455  -78.906  46.672  1
83850  96.500  -78.906  46.643  1
83851  96.545  -78.906  46.616  1
83852  96.591  -78.905  46.587  1
83853  96.636  -78.905  46.560  1
83854  96.680  -78.905  46.534  1
83855  96.721  -78.899  46.508  1
83856  96.761  -78.895  46.485  1
83857  96.802  -78.890  46.463  1
83858  96.840  -78.885  46.443  1
83859  96.851  -78.883  46.421  1
83860  96.861  -78.880  46.399  1
83861  96.871  -78.877  46.379  1
83862  96.881  -78.874  46.357  1
83863  96.891  -78.871  46.335  1
83864  96.911  -78.870  46.313  1
83865  96.932  -78.866  46.292  1
83866  96.938  -78.876  46.271  1
83867  96.925  -78.905  46.251  1
83868  96.954  -78.952  46.232  1
83869  96.982  -78.993  46.214  1
83870  96.995  -78.968  46.198  1
83871  96.999  -78.962  46.181  1
83872  96.992  -78.976  46.165  1
83873  96.986  -78.991  46.147  1
83874  96.979  -79.006  46.129  1
83875  96.973  -79.021  46.112  1
83876  96.987  -79.059  46.096  1
83877  97.008  -79.105  46.082  1
83878  97.029  -79.152  46.069  1
83879  97.049  -79.160  46.056  1
83880  97.070  -79.156  46.038  1
83881  97.090  -79.150  46.022  1
83882  97.110  -79.145  46.008  1
83883  97.131  -79.140  45.993  1
83884  97.151  -79.134  45.980  1
83885  97.171  -79.129  45.966  1
83886  97.191  -79.125  45.953  1
83887  97.206  -79.106  45.938  1
83888  97.218  -79.094  45.924  1
83889  97.227  -79.099  45.909  1
83890  97.234  -79.101  45.892  1
83891  97.240  -79.104  45.875  1
83892  97.250  -79.110  45.859  1
83893  97.264  -79.119  45.843  1
83894  97.278  -79.128  45.827  1
83895  97.292  -79.138  45.810  1
83896  97.305  -79.147  45.793  1
83897  97.319  -79.156  45.774  1
83898  97.333  -79.165  45.759  1
83899  97.348  -79.175  45.744  1
83900  97.363  -79.183  45.729  1
83901  97.378  -79.192  45.711  1
83902  97.393  -79.200  45.693  1
83903  97.408  -79.209  45.674  1
83904  97.419  -79.208  45.657  1
83905  97.431  -79.207  45.641  1
83906  97.452  -79.217  45.624  1
83907  97.474  -79.228  45.607  1
83908  97.492  -79.234  45.591  1
83909  97.507  -79.237  45.575  1
83910  97.522  -79.240  45.559  1
83911  97.536  -79.243  45.542  1
83912  97.551  -79.246  45.526  1
83913  97.566  -79.249  45.509  1
83914  97.580  -79.252  45.493  1
83915  97.597  -79.257  45.476  1
83916  97.617  -79.266  45.459  1
83917  97.637  -79.274  45.441  1
83918  97.648  -79.278  45.425  1
83919  97.648  -79.278  45.409  1
83920  97.648  -79.278  45.394  1
83921  97.648  -79.278  45.380  1
83922  97.648  -79.277  45.366  1
83923  97.648  -79.276  45.351  1
83924  97.648  -79.276  45.338  1
83925  97.649  -79.278  45.325  1
83926  97.667  -79.297  45.313  1
83927  97.685  -79.318  45.303  1
83928  97.704  -79.338  45.293  1
83929  97.722  -79.359  45.283  1
83930  97.740  -79.379  45.272  1
83931  97.758  -79.400  45.260  1
83932  97.777  -79.420  45.248  1
83933  97.795  -79.441  45.237  1
83934  97.813  -79.461  45.226  1
83935  97.840  -79.480  45.215  1
83936  97.854  -79.492  45.204  1
83937  97.866  -79.507  45.192  1
83938  97.878  -79.523  45.180  1
83939  97.890  -79.537  45.169  1
83940  97.902  -79.549  45.159  1
83941  97.914  -79.560  45.149  1
83942  97.925  -79.573  45.140  1
83943  97.937  -79.584  45.131  1
83944  97.948  -79.596  45.123  1
83945  97.962  -79.607  45.114  1
83946  97.989  -79.617  45.105  1
83947  98.019  -79.623  45.097  1
83948  98.056  -79.614  45.090  1
83949  98.093  -79.605  45.082  1
83950  98.130  -79.596  45.075  1
83951  98.167  -79.587  45.068  1
83952  98.205  -79.578  45.062  1
83953  98.239  -79.567  45.053  1
83954  98.272  -79.585  45.045  1
83955  98.308  -79.610  45.036  1
83956  98.344  -79.635  45.027  1
83957  98.379  -79.659  45.017  1
83958  98.406  -79.666  45.008  1
83959  98.432  -79.672  44.999  1
83960  98.458  -79.679  44.988  1
83961  98.486  -79.689  44.979  1
83962  98.512  -79.700  44.971  1
83963  98.539  -79.711  44.963  1
83964  98.567  -79.720  44.956  1
83965  98.594  -79.731  44.949  1
83966  98.621  -79.742  44.942  1
83967  98.648  -79.751  44.937  1
83968  98.680  -79.761  44.932  1
83969  98.698  -79.757  44.928  1
83970  98.712  -79.750  44.923  1
83971  98.726  -79.744  44.919  1
83972  98.741  -79.737  44.915  1
83973  98.755  -79.730  44.910  1
83974  98.770  -79.723  44.904  1
83975  98.786  -79.722  44.898  1
83976  98.807  -79.730  44.893  1
83977  98.829  -79.737  44.888  1
83978  98.851  -79.745  44.882  1
83979  98.872  -79.753  44.876  1
83980  98.894  -79.761  44.869  1
83981  98.916  -79.769  44.863  1
83982  98.938  -79.777  44.857  1
83983  98.959  -79.786  44.850  1
83984  98.981  -79.793  44.843  1
83985  99.003  -79.802  44.837  1
83986  99.025  -79.810  44.829  1
83987  99.049  -79.815  44.821  1
83988  99.072  -79.829  44.811  1
83989  99.096  -79.843  44.802  1
83990  99.121  -79.857  44.795  1
83991  99.142  -79.872  44.788  1
83992  99.170  -79.881  44.778  1
83993  99.194  -79.886  44.768  1
83994  99.217  -79.891  44.757  1
83995  99.240  -79.896  44.746  1
83996  99.264  -79.900  44.736  1
83997  99.287  -79.905  44.727  1
83998  99.310  -79.912  44.719  1
83999  99.334  -79.918  44.711  1
84000  99.358  -79.924  44.704  1
84001  99.382  -79.930  44.697  1
84002  99.406  -79.937  44.691  1
84003  99.429  -79.943  44.685  1
84004  99.453  -79.949  44.676  1
84005  99.477  -79.955  44.668  1
84006  99.500  -79.962  44.661  1
84007  99.524  -79.968  44.654  1
84008  99.548  -79.974  44.646  1
84009  99.570  -79.980  44.637  1
84010  99.584  -79.977  44.628  1
84011  99.582  -80.005  44.618  1
84012  99.581  -80.034  44.610  1
84013  99.580  -80.062  44.602  1
84014  99.579  -80.090  44.595  1
84015  99.577  -80.118  44.587  1
84016  99.570  -80.155  44.580  1
84017  99.561  -80.192  44.572  1
84018  99.553  -80.230  44.564  1
84019  99.545  -80.268  44.557  1
84020  99.547  -80.292  44.549  1
84021  99.550  -80.314  44.541  1
84022  99.553  -80.336  44.533  1
84023  99.556  -80.359  44.525  1
84024  99.559  -80.381  44.517  1
84025  99.563  -80.403  44.507  1
84026  99.587  -80.417  44.498  1
84027  99.635  -80.422  44.487  1
84028  99.683  -80.428  44.476  1
84029  99.731  -80.434  44.466  1
84030  99.779  -80.439  44.455  1
84031  99.830  -80.450  44.444  1
84032  99.881  -80.463  44.432  1
84033  99.932  -80.476  44.420  1
84034  99.984  -80.489  44.408  1
84035  100.035  -80.502  44.396  1
84036  100.086  -80.515  44.383  1
84037  100.137  -80.527  44.370  1
84038  100.189  -80.540  44.358  1
84039  100.240  -80.553  44.346  1
84333  93.566  -78.767  53.603  1
84334  93.576  -78.765  53.595  1
84335  93.585  -78.763  53.587  1
84336  93.595  -78.761  53.579  1
84337  93.605  -78.758  53.573  1
84338  93.615  -78.755  53.568  1
84339  93.624  -78.753  53.562  1
84340  93.633  -78.750  53.558  1
84341  93.631  -78.740  53.555  1
84342  93.630  -78.731  53.556  1
84343  93.628  -78.739  53.559  1
84344  93.630  -78.757  53.562  1
84345  93.639  -78.756  53.562  1
84346  93.650  -78.739  53.559  1
84347  93.665  -78.727  53.553  1
84348  93.683  -78.717  53.544  1
84349  93.700  -78.706  53.533  1
84350  93.719  -78.689  53.521  1
84351  93.739  -78.673  53.506  1
84352  93.758  -78.655  53.491  1
84353  93.777  -78.639  53.474  1
84354  93.785  -78.627  53.455  1
84355  93.789  -78.619  53.436  1
84356  93.792  -78.611  53.417  1
84357  93.796  -78.601  53.397  1
84358  93.799  -78.589  53.377  1
84359  93.801  -78.575  53.357  1
84360  93.804  -78.561  53.334  1
84361  93.807  -78.547  53.310  1
84362  93.809  -78.532  53.285  1
84363  93.812  -78.518  53.260  1
84364  93.837  -78.544  53.236  1
84365  93.850  -78.532  53.213  1
84366  93.863  -78.519  53.190  1
84367  93.875  -78.507  53.166  1
84368  93.888  -78.494  53.141  1
84369  93.921  -78.478  53.118  1
84370  93.965  -78.460  53.097  1
84371  93.980  -78.462  53.078  1
84372  93.981  -78.472  53.060  1
84373  93.984  -78.482  53.044  1
84374  93.994  -78.488  53.025  1
84375  94.004  -78.494  53.004  1
84376  94.015  -78.499  52.984  1
84377  94.025  -78.505  52.964  1
84378  94.039  -78.504  52.944  1
84379  94.054  -78.503  52.923  1
84380  94.068  -78.501  52.903  1
84381  94.082  -78.501  52.880  1
84382  94.097  -78.499  52.855  1
84383  94.112  -78.498  52.828  1
84384  94.126  -78.496  52.804  1
84385  94.133  -78.476  52.782  1
84386  94.144  -78.448  52.762  1
84387  94.164  -78.413  52.743  1
84388  94.183  -78.377  52.725  1
84389  94.203  -78.341  52.708  1
84390  94.222  -78.306  52.692  1
84391  94.249  -78.290  52.676  1
84392  94.256  -78.380  52.659  1
84393  94.263  -78.470  52.641  1
84394  94.271  -78.557  52.623  1
84395  94.286  -78.564  52.604  1
84396  94.300  -78.571  52.584  1
84397  94.316  -78.578  52.565  1
84398  94.330  -78.584  52.546  1
84399  94.345  -78.591  52.527  1
84400  94.360  -78.598  52.508  1
84401  94.372  -78.605  52.489  1
84402  94.365  -78.617  52.468  1
84403  94.357  -78.629  52.444  1
84404  94.373  -78.617  52.422  1
84405  94.390  -78.604  52.399  1
84406  94.397  -78.589  52.375  1
84407  94.406  -78.574  52.349  1
84408  94.423  -78.560  52.322  1
84409  94.441  -78.545  52.292  1
84410  94.450  -78.545  52.259  1
84411  94.460  -78.545  52.227  1
84412  94.475  -78.550  52.194  1
84413  94.490  -78.554  52.160  1
84414  94.506  -78.558  52.124  1
84415  94.522  -78.563  52.088  1
84416  94.537  -78.567  52.054  1
84417  94.553  -78.571  52.022  1
84418  94.568  -78.576  51.991  1
84419  94.574  -78.577  51.957  1
84420  94.580  -78.579  51.921  1
84421  94.591  -78.578  51.882  1
84422  94.601  -78.577  51.844  1
84423  94.615  -78.581  51.804  1
84424  94.628  -78.585  51.763  1
84425  94.641  -78.588  51.719  1
84426  94.654  -78.590  51.672  1
84427  94.668  -78.592  51.623  1
84428  94.680  -78.594  51.577  1
84429  94.693  -78.596  51.530  1
84430  94.706  -78.598  51.485  1
84431  94.719  -78.600  51.438  1
84432  94.733  -78.602  51.391  1
84433  94.754  -78.606  51.345  1
84434  94.775  -78.611  51.299  1
84435  94.796  -78.615  51.255  1
84436  94.817  -78.619  51.211  1
84437  94.839  -78.623  51.166  1
84438  94.859  -78.627  51.121  1
84439  94.878  -78.631  51.076  1
84440  94.891  -78.636  51.032  1
84441  94.899  -78.629  50.989  1
84442  94.913  -78.618  50.945  1
84443  94.951  -78.617  50.903  1
84444  94.982  -78.616  50.861  1
84445  94.987  -78.618  50.818  1
84446  94.991  -78.620  50.775  1
84447  94.996  -78.622  50.732  1
84448  95.000  -78.623  50.688  1
84449  94.999  -78.624  50.641  1
84450  94.993  -78.623  50.595  1
84451  94.987  -78.623  50.550  1
84452  94.982  -78.622  50.505  1
84453  94.976  -78.620  50.460  1
84454  94.971  -78.620  50.415  1
84455  94.983  -78.604  50.370  1
84456  94.997  -78.586  50.325  1
84457  95.012  -78.568  50.281  1
84458  95.026  -78.550  50.238  1
84459  95.041  -78.535  50.194  1
84460  95.062  -78.540  50.151  1
84461  95.082  -78.545  50.109  1
84462  95.100  -78.550  50.067  1
84463  95.111  -78.554  50.025  1
84464  95.121  -78.557  49.984  1
84465  95.132  -78.561  49.942  1
84466  95.143  -78.565  49.903  1
84467  95.154  -78.569  49.865  1
84468  95.164  -78.572  49.827  1
84469  95.175  -78.576  49.790  1
84470  95.186  -78.579  49.753  1
84471  95.196  -78.583  49.716  1
84472  95.207  -78.587  49.679  1
84473  95.235  -78.601  49.641  1
84474  95.268  -78.617  49.602  1
84475  95.301  -78.635  49.564  1
84476  95.333  -78.651  49.526  1
84477  95.333  -78.664  49.487  1
84478  95.346  -78.686  49.448  1
84479  95.360  -78.706  49.410  1
84480  95.375  -78.727  49.374  1
84481  95.388  -78.749  49.340  1
84482  95.402  -78.770  49.306  1
84483  95.416  -78.791  49.271  1
84484  95.430  -78.811  49.234  1
84485  95.438  -78.825  49.196  1
84486  95.429  -78.824  49.156  1
84487  95.416  -78.818  49.115  1
84488  95.420  -78.807  49.074  1
84489  95.424  -78.796  49.033  1
84490  95.428  -78.784  48.992  1
84491  95.432  -78.773  48.951  1
84492  95.436  -78.761  48.908  1
84493  95.440  -78.750  48.864  1
84494  95.444  -78.739  48.819  1
84495  95.453  -78.731  48.775  1
84496  95.476  -78.733  48.731  1
84497  95.499  -78.735  48.688  1
84498  95.523  -78.736  48.647  1
84499  95.546  -78.739  48.606  1
84500  95.570  -78.741  48.564  1
84501  95.593  -78.742  48.523  1
84502  95.609  -78.749  48.483  1
84503  95.615  -78.759  48.444  1
84504  95.621  -78.769  48.406  1
84505  95.626  -78.780  48.367  1
84506  95.633  -78.789  48.330  1
84507  95.645  -78.794  48.294  1
84508  95.657  -78.798  48.260  1
84509  95.669  -78.802  48.225  1
84510  95.690  -78.811  48.189  1
84511  95.719  -78.822  48.150  1
84512  95.748  -78.834  48.111  1
84513  95.775  -78.843  48.070  1
84514  95.799  -78.849  48.026  1
84515  95.812  -78.863  47.984  1
84516  95.828  -78.865  47.942  1
84517  95.845  -78.866  47.900  1
84518  95.863  -78.867  47.858  1
84519  95.879  -78.870  47.815  1
84520  95.894  -78.875  47.772  1
84521  95.901  -78.881  47.729  1
84522  95.923  -78.879  47.686  1
84523  95.948  -78.876  47.645  1
84524  95.972  -78.873  47.603  1
84525  95.996  -78.869  47.562  1
84526  96.020  -78.866  47.520  1
84527  96.044  -78.863  47.478  1
84528  96.068  -78.860  47.436  1
84529  96.093  -78.856  47.395  1
84530  96.117  -78.853  47.355  1
84531  96.137  -78.861  47.317  1
84532  96.155  -78.879  47.278  1
84533  96.172  -78.873  47.242  1
84534  96.188  -78.861  47.205  1
84535  96.205  -78.849  47.167  1
84536  96.227  -78.838  47.130  1
84537  96.252  -78.829  47.094  1
84538  96.277  -78.820  47.060  1
84539  96.302  -78.811  47.028  1
84540  96.327  -78.802  46.997  1
84541  96.336  -78.803  46.965  1
84542  96.337  -78.810  46.930  1
84543  96.346  -78.824  46.897  1
84544  96.358  -78.843  46.864  1
84545  96.369  -78.860  46.832  1
84546  96.380  -78.877  46.801  1
84547  96.391  -78.893  46.771  1
84548  96.401  -78.895  46.740  1
84549  96.410  -78.898  46.710  1
84550  96.449  -78.898  46.681  1
84551  96.494  -78.898  46.653  1
84552  96.539  -78.898  46.626  1
84553  96.585  -78.898  46.598  1
84554  96.629  -78.897  46.572  1
84555  96.670  -78.893  46.546  1
84556  96.711  -78.887  46.520  1
84557  96.751  -78.883  46.496  1
84558  96.791  -78.878  46.474  1
84559  96.832  -78.873  46.454  1
84560  96.848  -78.870  46.432  1
84561  96.858  -78.867  46.410  1
84562  96.868  -78.865  46.387  1
84563  96.878  -78.861  46.366  1
84564  96.890  -78.862  46.345  1
84565  96.911  -78.865  46.324  1
84566  96.932  -78.861  46.304  1
84567  96.940  -78.869  46.284  1
84568  96.930  -78.900  46.265  1
84569  96.956  -78.957  46.246  1
84570  96.971  -78.996  46.228  1
84571  96.980  -78.984  46.212  1
84572  96.993  -78.959  46.195  1
84573  96.989  -78.968  46.178  1
84574  96.982  -78.984  46.162  1
84575  96.976  -78.998  46.146  1
84576  96.970  -79.013  46.129  1
84577  96.984  -79.053  46.113  1
84578  97.006  -79.099  46.098  1
84579  97.027  -79.136  46.084  1
84580  97.047  -79.131  46.069  1
84581  97.067  -79.125  46.054  1
84582  97.087  -79.120  46.038  1
84583  97.108  -79.115  46.023  1
84584  97.128  -79.110  46.009  1
84585  97.148  -79.105  45.996  1
84586  97.168  -79.100  45.983  1
84587  97.188  -79.094  45.971  1
84588  97.209  -79.089  45.957  1
84589  97.223  -79.093  45.942  1
84590  97.229  -79.096  45.926  1
84591  97.235  -79.099  45.909  1
84592  97.242  -79.102  45.892  1
84593  97.251  -79.107  45.875  1
84594  97.265  -79.117  45.858  1
84595  97.280  -79.125  45.839  1
84596  97.295  -79.134  45.821  1
84597  97.310  -79.143  45.803  1
84598  97.325  -79.152  45.783  1
84599  97.341  -79.160  45.766  1
84600  97.356  -79.169  45.750  1
84601  97.371  -79.178  45.734  1
84602  97.385  -79.187  45.716  1
84603  97.400  -79.193  45.697  1
84604  97.411  -79.192  45.678  1
84605  97.423  -79.191  45.660  1
84606  97.434  -79.190  45.644  1
84607  97.453  -79.198  45.628  1
84608  97.475  -79.209  45.612  1
84609  97.498  -79.220  45.595  1
84610  97.520  -79.231  45.578  1
84611  97.535  -79.235  45.562  1
84612  97.550  -79.238  45.546  1
84613  97.565  -79.241  45.530  1
84614  97.580  -79.244  45.514  1
84615  97.594  -79.247  45.499  1
84616  97.613  -79.254  45.482  1
84617  97.633  -79.263  45.465  1
84618  97.640  -79.266  45.449  1
84619  97.640  -79.265  45.434  1
84620  97.640  -79.264  45.419  1
84621  97.639  -79.264  45.405  1
84622  97.639  -79.263  45.392  1
84623  97.639  -79.263  45.377  1
84624  97.639  -79.263  45.363  1
84625  97.639  -79.262  45.349  1
84626  97.641  -79.265  45.335  1
84627  97.659  -79.285  45.325  1
84628  97.678  -79.305  45.315  1
84629  97.696  -79.325  45.303  1
84630  97.714  -79.346  45.293  1
84631  97.733  -79.366  45.281  1
84632  97.751  -79.387  45.268  1
84633  97.769  -79.407  45.255  1
84634  97.788  -79.428  45.244  1
84635  97.816  -79.450  45.233  1
84636  97.840  -79.463  45.223  1
84637  97.855  -79.473  45.212  1
84638  97.867  -79.488  45.201  1
84639  97.879  -79.504  45.190  1
84640  97.892  -79.519  45.178  1
84641  97.904  -79.534  45.168  1
84642  97.916  -79.549  45.158  1
84643  97.929  -79.564  45.150  1
84644  97.941  -79.579  45.140  1
84645  97.952  -79.591  45.131  1
84646  97.964  -79.602  45.123  1
84647  97.993  -79.608  45.115  1
84648  98.030  -79.599  45.107  1
84649  98.067  -79.590  45.099  1
84650  98.104  -79.581  45.092  1
84651  98.142  -79.572  45.085  1
84652  98.178  -79.563  45.077  1
84653  98.216  -79.554  45.070  1
84654  98.249  -79.542  45.062  1
84655  98.282  -79.560  45.054  1
84656  98.318  -79.585  45.046  1
84657  98.354  -79.610  45.037  1
84658  98.389  -79.635  45.027  1
84659  98.422  -79.653  45.018  1
84660  98.448  -79.659  45.009  1
84661  98.475  -79.668  45.000  1
84662  98.502  -79.679  44.991  1
84663  98.529  -79.689  44.983  1
84664  98.557  -79.699  44.976  1
84665  98.584  -79.709  44.968  1
84666  98.611  -79.720  44.961  1
84667  98.638  -79.730  44.954  1
84668  98.665  -79.740  44.949  1
84669  98.692  -79.748  44.944  1
84670  98.706  -79.741  44.940  1
84671  98.720  -79.734  44.936  1
84672  98.734  -79.727  44.932  1
84673  98.749  -79.720  44.928  1
84674  98.763  -79.714  44.923  1
84675  98.778  -79.707  44.919  1
84676  98.792  -79.701  44.913  1
84677  98.813  -79.708  44.908  1
84678  98.835  -79.716  44.903  1
84679  98.856  -79.723  44.897  1
84680  98.878  -79.732  44.891  1
84681  98.900  -79.740  44.884  1
84682  98.922  -79.748  44.879  1
84683  98.943  -79.756  44.872  1
84684  98.966  -79.764  44.865  1
84685  98.987  -79.772  44.858  1
84686  99.008  -79.781  44.851  1
84687  99.027  -79.792  44.843  1
84688  99.058  -79.799  44.834  1
84689  99.082  -79.813  44.824  1
84690  99.106  -79.827  44.814  1
84691  99.130  -79.841  44.806  1
84692  99.148  -79.855  44.797  1
84693  99.172  -79.861  44.786  1
84694  99.196  -79.867  44.774  1
84695  99.219  -79.874  44.763  1
84696  99.243  -79.880  44.752  1
84697  99.267  -79.886  44.743  1
84698  99.291  -79.892  44.735  1
84699  99.314  -79.899  44.727  1
84700  99.338  -79.905  44.719  1
84701  99.362  -79.911  44.711  1
84702  99.385  -79.917  44.703  1
84703  99.409  -79.924  44.697  1
84704  99.433  -79.930  44.690  1
84705  99.457  -79.936  44.681  1
84706  99.481  -79.942  44.673  1
84707  99.504  -79.949  44.665  1
84708  99.528  -79.955  44.657  1
84709  99.552  -79.961  44.648  1
84710  99.567  -79.956  44.641  1
84711  99.579  -79.957  44.632  1
84712  99.578  -79.985  44.622  1
84713  99.576  -80.013  44.614  1
84714  99.575  -80.041  44.605  1
84715  99.574  -80.069  44.597  1
84716  99.573  -80.097  44.590  1
84717  99.571  -80.125  44.583  1
84718  99.570  -80.153  44.575  1
84719  99.569  -80.181  44.567  1
84720  99.566  -80.212  44.560  1
84721  99.558  -80.250  44.553  1
84722  99.549  -80.287  44.545  1
84723  99.550  -80.313  44.538  1
84724  99.553  -80.335  44.530  1
84725  99.556  -80.358  44.521  1
84726  99.559  -80.380  44.512  1
84727  99.595  -80.390  44.502  1
84728  99.644  -80.395  44.492  1
84729  99.692  -80.401  44.481  1
84730  99.742  -80.413  44.471  1
84731  99.793  -80.425  44.460  1
84732  99.845  -80.438  44.449  1
84733  99.896  -80.450  44.437  1
84734  99.947  -80.463  44.425  1
84735  99.999  -80.476  44.413  1
84736  100.050  -80.489  44.401  1
84737  100.101  -80.502  44.387  1
84738  100.152  -80.515  44.375  1
84739  100.198  -80.530  44.363  1
84740  100.243  -80.547  44.349  1
85034  93.566  -78.757  53.610  1
85035  93.576  -78.755  53.602  1
85036  93.586  -78.752  53.594  1
85037  93.595  -78.749  53.586  1
85038  93.605  -78.747  53.578  1
85039  93.615  -78.745  53.573  1
85040  93.625  -78.742  53.567  1
85041  93.629  -78.736  53.562  1
85042  93.628  -78.727  53.559  1
85043  93.627  -78.718  53.559  1
85044  93.625  -78.709  53.561  1
85045  93.624  -78.749  53.565  1
85046  93.635  -78.732  53.564  1
85047  93.646  -78.715  53.560  1
85048  93.663  -78.705  53.555  1
85049  93.681  -78.694  53.546  1
85050  93.698  -78.683  53.535  1
85051  93.716  -78.673  53.522  1
85052  93.734  -78.658  53.508  1
85053  93.754  -78.642  53.492  1
85054  93.773  -78.624  53.475  1
85055  93.780  -78.614  53.456  1
85056  93.784  -78.605  53.437  1
85057  93.787  -78.596  53.418  1
85058  93.790  -78.582  53.398  1
85059  93.792  -78.568  53.377  1
85060  93.795  -78.554  53.355  1
85061  93.798  -78.540  53.332  1
85062  93.800  -78.526  53.308  1
85063  93.803  -78.511  53.283  1
85064  93.806  -78.497  53.258  1
85065  93.827  -78.517  53.233  1
85066  93.845  -78.520  53.209  1
85067  93.858  -78.508  53.186  1
85068  93.870  -78.495  53.162  1
85069  93.889  -78.482  53.137  1
85070  93.933  -78.464  53.117  1
85071  93.977  -78.447  53.098  1
85072  93.990  -78.450  53.081  1
85073  93.991  -78.460  53.065  1
85074  93.992  -78.470  53.048  1
85075  93.998  -78.479  53.030  1
85076  94.009  -78.484  53.009  1
85077  94.020  -78.489  52.988  1
85078  94.035  -78.487  52.966  1
85079  94.049  -78.485  52.945  1
85080  94.064  -78.484  52.923  1
85081  94.078  -78.482  52.902  1
85082  94.093  -78.481  52.879  1
85083  94.108  -78.479  52.853  1
85084  94.122  -78.478  52.827  1
85085  94.137  -78.476  52.805  1
85086  94.150  -78.474  52.785  1
85087  94.157  -78.449  52.767  1
85088  94.177  -78.413  52.749  1
85089  94.196  -78.379  52.731  1
85090  94.215  -78.343  52.714  1
85091  94.233  -78.310  52.697  1
85092  94.236  -78.304  52.680  1
85093  94.237  -78.360  52.662  1
85094  94.242  -78.438  52.643  1
85095  94.249  -78.528  52.626  1
85096  94.261  -78.566  52.608  1
85097  94.276  -78.573  52.589  1
85098  94.290  -78.579  52.571  1
85099  94.306  -78.586  52.552  1
85100  94.321  -78.592  52.534  1
85101  94.335  -78.599  52.515  1
85102  94.350  -78.606  52.497  1
85103  94.365  -78.612  52.478  1
85104  94.363  -78.623  52.455  1
85105  94.376  -78.614  52.433  1
85106  94.385  -78.600  52.410  1
85107  94.402  -78.586  52.385  1
85108  94.420  -78.570  52.360  1
85109  94.437  -78.556  52.332  1
85110  94.453  -78.545  52.302  1
85111  94.462  -78.545  52.269  1
85112  94.471  -78.545  52.236  1
85113  94.480  -78.546  52.202  1
85114  94.493  -78.548  52.167  1
85115  94.508  -78.552  52.132  1
85116  94.524  -78.557  52.098  1
85117  94.540  -78.561  52.064  1
85118  94.555  -78.565  52.032  1
85119  94.571  -78.570  52.002  1
85120  94.579  -78.572  51.969  1
85121  94.586  -78.574  51.932  1
85122  94.596  -78.573  51.895  1
85123  94.607  -78.572  51.856  1
85124  94.617  -78.571  51.816  1
85125  94.631  -78.574  51.774  1
85126  94.644  -78.578  51.730  1
85127  94.657  -78.582  51.684  1
85128  94.671  -78.586  51.635  1
85129  94.684  -78.588  51.587  1
85130  94.697  -78.590  51.538  1
85131  94.710  -78.592  51.489  1
85132  94.723  -78.594  51.442  1
85133  94.736  -78.596  51.393  1
85134  94.757  -78.600  51.345  1
85135  94.778  -78.604  51.298  1
85136  94.800  -78.608  51.252  1
85137  94.821  -78.613  51.206  1
85138  94.842  -78.617  51.160  1
85139  94.863  -78.621  51.114  1
85140  94.885  -78.626  51.069  1
85141  94.901  -78.630  51.025  1
85142  94.918  -78.622  50.982  1
85143  94.939  -78.623  50.937  1
85144  94.944  -78.624  50.894  1
85145  94.949  -78.626  50.852  1
85146  94.953  -78.628  50.809  1
85147  94.958  -78.630  50.767  1
85148  94.962  -78.632  50.725  1
85149  94.964  -78.633  50.684  1
85150  94.958  -78.632  50.639  1
85151  94.952  -78.631  50.594  1
85152  94.947  -78.630  50.549  1
85153  94.945  -78.626  50.505  1
85154  94.959  -78.608  50.461  1
85155  94.974  -78.591  50.416  1
85156  94.988  -78.573  50.371  1
85157  95.002  -78.554  50.327  1
85158  95.017  -78.537  50.283  1
85159  95.031  -78.519  50.238  1
85160  95.049  -78.515  50.195  1
85161  95.069  -78.520  50.152  1
85162  95.090  -78.526  50.109  1
85163  95.111  -78.530  50.067  1
85164  95.125  -78.535  50.025  1
85165  95.135  -78.539  49.983  1
85166  95.146  -78.542  49.942  1
85167  95.157  -78.545  49.902  1
85168  95.168  -78.549  49.864  1
85169  95.178  -78.553  49.827  1
85170  95.189  -78.557  49.789  1
85171  95.199  -78.561  49.752  1
85172  95.210  -78.564  49.715  1
85173  95.229  -78.573  49.677  1
85174  95.261  -78.589  49.639  1
85175  95.295  -78.606  49.600  1
85176  95.328  -78.623  49.562  1
85177  95.360  -78.640  49.524  1
85178  95.381  -78.654  49.487  1
85179  95.390  -78.672  49.449  1
85180  95.404  -78.693  49.410  1
85181  95.418  -78.714  49.376  1
85182  95.432  -78.736  49.342  1
85183  95.446  -78.756  49.308  1
85184  95.460  -78.777  49.273  1
85185  95.471  -78.796  49.238  1
85186  95.465  -78.795  49.201  1
85187  95.460  -78.794  49.163  1
85188  95.450  -78.792  49.122  1
85189  95.432  -78.786  49.082  1
85190  95.415  -78.782  49.040  1
85191  95.418  -78.771  48.999  1
85192  95.422  -78.759  48.957  1
85193  95.426  -78.748  48.913  1
85194  95.430  -78.737  48.868  1
85195  95.434  -78.726  48.824  1
85196  95.443  -78.717  48.780  1
85197  95.466  -78.719  48.736  1
85198  95.489  -78.721  48.694  1
85199  95.513  -78.724  48.653  1
85200  95.536  -78.725  48.612  1
85201  95.559  -78.727  48.572  1
85202  95.583  -78.729  48.531  1
85203  95.606  -78.731  48.492  1
85204  95.617  -78.739  48.453  1
85205  95.623  -78.749  48.414  1
85206  95.629  -78.760  48.376  1
85207  95.641  -78.764  48.339  1
85208  95.653  -78.768  48.303  1
85209  95.665  -78.773  48.268  1
85210  95.677  -78.777  48.233  1
85211  95.695  -78.784  48.197  1
85212  95.725  -78.796  48.159  1
85213  95.753  -78.808  48.120  1
85214  95.782  -78.820  48.079  1
85215  95.806  -78.821  48.038  1
85216  95.823  -78.822  47.998  1
85217  95.841  -78.823  47.956  1
85218  95.858  -78.824  47.914  1
85219  95.875  -78.826  47.872  1
85220  95.890  -78.831  47.829  1
85221  95.904  -78.836  47.787  1
85222  95.911  -78.843  47.744  1
85223  95.926  -78.844  47.702  1
85224  95.950  -78.841  47.659  1
85225  95.974  -78.838  47.616  1
85226  95.999  -78.835  47.573  1
85227  96.023  -78.831  47.531  1
85228  96.047  -78.828  47.489  1
85229  96.071  -78.825  47.447  1
85230  96.095  -78.822  47.407  1
85231  96.119  -78.821  47.367  1
85232  96.136  -78.839  47.329  1
85233  96.154  -78.856  47.291  1
85234  96.171  -78.862  47.254  1
85235  96.188  -78.850  47.217  1
85236  96.204  -78.838  47.179  1
85237  96.221  -78.825  47.142  1
85238  96.237  -78.813  47.106  1
85239  96.258  -78.802  47.071  1
85240  96.283  -78.793  47.039  1
85241  96.308  -78.784  47.007  1
85242  96.320  -78.783  46.974  1
85243  96.325  -78.794  46.939  1
85244  96.337  -78.812  46.906  1
85245  96.348  -78.830  46.874  1
85246  96.360  -78.847  46.842  1
85247  96.371  -78.865  46.811  1
85248  96.382  -78.883  46.781  1
85249  96.392  -78.887  46.750  1
85250  96.401  -78.890  46.720  1
85251  96.443  -78.890  46.691  1
85252  96.488  -78.890  46.664  1
85253  96.533  -78.890  46.637  1
85254  96.579  -78.890  46.610  1
85255  96.619  -78.885  46.584  1
85256  96.660  -78.880  46.558  1
85257  96.700  -78.875  46.531  1
85258  96.741  -78.871  46.508  1
85259  96.781  -78.866  46.486  1
85260  96.822  -78.861  46.466  1
85261  96.844  -78.857  46.444  1
85262  96.855  -78.855  46.421  1
85263  96.865  -78.852  46.398  1
85264  96.875  -78.849  46.378  1
85265  96.890  -78.853  46.357  1
85266  96.910  -78.861  46.337  1
85267  96.931  -78.857  46.317  1
85268  96.941  -78.862  46.297  1
85269  96.934  -78.896  46.278  1
85270  96.960  -78.952  46.260  1
85271  96.971  -78.978  46.242  1
85272  96.966  -78.993  46.226  1
85273  96.977  -78.976  46.210  1
85274  96.985  -78.961  46.193  1
85275  96.979  -78.976  46.177  1
85276  96.973  -78.990  46.161  1
85277  96.966  -79.006  46.145  1
85278  96.982  -79.046  46.129  1
85279  97.004  -79.093  46.114  1
85280  97.024  -79.106  46.099  1
85281  97.044  -79.101  46.084  1
85282  97.065  -79.096  46.069  1
85283  97.085  -79.090  46.053  1
85284  97.105  -79.085  46.037  1
85285  97.125  -79.080  46.023  1
85286  97.146  -79.075  46.011  1
85287  97.166  -79.070  45.999  1
85288  97.189  -79.073  45.986  1
85289  97.213  -79.078  45.972  1
85290  97.230  -79.087  45.956  1
85291  97.237  -79.091  45.938  1
85292  97.243  -79.095  45.922  1
85293  97.248  -79.098  45.906  1
85294  97.257  -79.103  45.889  1
85295  97.272  -79.112  45.870  1
85296  97.287  -79.120  45.849  1
85297  97.302  -79.129  45.829  1
85298  97.317  -79.137  45.810  1
85299  97.332  -79.147  45.791  1
85300  97.348  -79.155  45.772  1
85301  97.363  -79.164  45.755  1
85302  97.378  -79.173  45.738  1
85303  97.391  -79.178  45.720  1
85304  97.403  -79.177  45.702  1
85305  97.414  -79.176  45.683  1
85306  97.426  -79.175  45.666  1
85307  97.437  -79.175  45.650  1
85308  97.454  -79.179  45.634  1
85309  97.476  -79.190  45.618  1
85310  97.498  -79.201  45.602  1
85311  97.520  -79.212  45.585  1
85312  97.542  -79.223  45.568  1
85313  97.564  -79.233  45.552  1
85314  97.579  -79.236  45.536  1
85315  97.593  -79.239  45.521  1
85316  97.608  -79.243  45.506  1
85317  97.629  -79.251  45.489  1
85318  97.631  -79.252  45.473  1
85319  97.631  -79.251  45.458  1
85320  97.631  -79.250  45.444  1
85321  97.631  -79.250  45.430  1
85322  97.631  -79.250  45.417  1
85323  97.631  -79.250  45.404  1
85324  97.630  -79.249  45.389  1
85325  97.630  -79.249  45.375  1
85326  97.630  -79.248  45.360  1
85327  97.634  -79.252  45.346  1
85328  97.652  -79.272  45.335  1
85329  97.670  -79.292  45.325  1
85330  97.688  -79.313  45.312  1
85331  97.707  -79.333  45.300  1
85332  97.725  -79.353  45.288  1
85333  97.743  -79.374  45.276  1
85334  97.761  -79.394  45.263  1
85335  97.788  -79.416  45.252  1
85336  97.823  -79.436  45.241  1
85337  97.840  -79.444  45.231  1
85338  97.856  -79.454  45.220  1
85339  97.868  -79.469  45.210  1
85340  97.880  -79.485  45.200  1
85341  97.892  -79.500  45.189  1
85342  97.905  -79.515  45.179  1
85343  97.917  -79.530  45.170  1
85344  97.930  -79.545  45.160  1
85345  97.942  -79.561  45.152  1
85346  97.954  -79.576  45.143  1
85347  97.967  -79.591  45.134  1
85348  97.995  -79.595  45.125  1
85349  98.041  -79.575  45.117  1
85350  98.078  -79.566  45.109  1
85351  98.115  -79.557  45.102  1
85352  98.153  -79.548  45.095  1
85353  98.190  -79.538  45.087  1
85354  98.227  -79.529  45.080  1
85355  98.260  -79.517  45.071  1
85356  98.293  -79.535  45.063  1
85357  98.329  -79.560  45.055  1
85358  98.364  -79.585  45.047  1
85359  98.400  -79.610  45.038  1
85360  98.436  -79.634  45.029  1
85361  98.465  -79.646  45.020  1
85362  98.492  -79.657  45.011  1
85363  98.519  -79.667  45.003  1
85364  98.546  -79.677  44.996  1
85365  98.573  -79.688  44.988  1
85366  98.598  -79.697  44.980  1
85367  98.624  -79.706  44.973  1
85368  98.649  -79.715  44.966  1
85369  98.675  -79.724  44.960  1
85370  98.690  -79.738  44.956  1
85371  98.707  -79.729  44.952  1
85372  98.724  -79.720  44.948  1
85373  98.741  -79.712  44.944  1
85374  98.757  -79.704  44.940  1
85375  98.771  -79.698  44.937  1
85376  98.786  -79.691  44.933  1
85377  98.800  -79.684  44.929  1
85378  98.818  -79.686  44.923  1
85379  98.841  -79.695  44.919  1
85380  98.862  -79.702  44.913  1
85381  98.884  -79.711  44.907  1
85382  98.905  -79.720  44.900  1
85383  98.924  -79.731  44.894  1
85384  98.944  -79.742  44.887  1
85385  98.963  -79.754  44.879  1
85386  98.982  -79.765  44.870  1
85387  99.001  -79.776  44.862  1
85388  99.037  -79.780  44.853  1
85389  99.076  -79.783  44.844  1
85390  99.100  -79.796  44.834  1
85391  99.125  -79.811  44.822  1
85392  99.148  -79.824  44.810  1
85393  99.157  -79.839  44.800  1
85394  99.176  -79.847  44.789  1
85395  99.200  -79.853  44.778  1
85396  99.223  -79.859  44.768  1
85397  99.247  -79.866  44.758  1
85398  99.271  -79.872  44.749  1
85399  99.294  -79.878  44.742  1
85400  99.319  -79.884  44.734  1
85401  99.342  -79.891  44.726  1
85402  99.366  -79.897  44.717  1
85403  99.390  -79.903  44.709  1
85404  99.413  -79.909  44.701  1
85405  99.437  -79.916  44.694  1
85406  99.461  -79.922  44.685  1
85407  99.484  -79.928  44.677  1
85408  99.508  -79.935  44.669  1
85409  99.532  -79.941  44.660  1
85410  99.549  -79.938  44.651  1
85411  99.564  -79.932  44.644  1
85412  99.574  -79.936  44.636  1
85413  99.573  -79.965  44.626  1
85414  99.572  -79.993  44.617  1
85415  99.571  -80.021  44.608  1
85416  99.569  -80.049  44.600  1
85417  99.568  -80.077  44.593  1
85418  99.567  -80.105  44.585  1
85419  99.566  -80.133  44.577  1
85420  99.564  -80.161  44.571  1
85421  99.563  -80.189  44.563  1
85422  99.562  -80.216  44.555  1
85423  99.561  -80.244  44.549  1
85424  99.559  -80.272  44.541  1
85425  99.554  -80.306  44.533  1
85426  99.553  -80.335  44.525  1
85427  99.556  -80.357  44.517  1
85428  99.604  -80.363  44.507  1
85429  99.655  -80.374  44.497  1
85430  99.706  -80.387  44.487  1
85431  99.757  -80.400  44.476  1
85432  99.808  -80.413  44.465  1
85433  99.860  -80.425  44.453  1
85434  99.911  -80.438  44.441  1
85435  99.963  -80.451  44.430  1
85436  100.014  -80.463  44.417  1
85437  100.065  -80.476  44.405  1
85438  100.112  -80.492  44.392  1
85439  100.156  -80.508  44.379  1
85440  100.201  -80.525  44.367  1
85441  100.245  -80.541  44.354  1
85735  93.567  -78.746  53.617  1
85736  93.576  -78.743  53.609  1
85737  93.586  -78.741  53.600  1
85738  93.596  -78.739  53.592  1
85739  93.606  -78.736  53.585  1
85740  93.615  -78.733  53.578  1
85741  93.625  -78.731  53.571  1
85742  93.626  -78.724  53.565  1
85743  93.625  -78.714  53.563  1
85744  93.623  -78.705  53.561  1
85745  93.622  -78.695  53.562  1
85746  93.620  -78.721  53.565  1
85747  93.630  -78.707  53.563  1
85748  93.644  -78.692  53.560  1
85749  93.661  -78.682  53.554  1
85750  93.679  -78.671  53.545  1
85751  93.697  -78.661  53.534  1
85752  93.714  -78.651  53.522  1
85753  93.731  -78.640  53.508  1
85754  93.750  -78.627  53.491  1
85755  93.769  -78.611  53.474  1
85756  93.775  -78.600  53.454  1
85757  93.778  -78.589  53.434  1
85758  93.781  -78.576  53.414  1
85759  93.784  -78.561  53.393  1
85760  93.786  -78.547  53.372  1
85761  93.789  -78.532  53.350  1
85762  93.792  -78.519  53.326  1
85763  93.794  -78.504  53.302  1
85764  93.797  -78.490  53.277  1
85765  93.800  -78.476  53.252  1
85766  93.815  -78.485  53.227  1
85767  93.840  -78.510  53.203  1
85768  93.853  -78.497  53.180  1
85769  93.865  -78.485  53.158  1
85770  93.902  -78.468  53.135  1
85771  93.945  -78.451  53.116  1
85772  93.989  -78.433  53.098  1
85773  94.000  -78.438  53.081  1
85774  94.001  -78.448  53.066  1
85775  94.002  -78.458  53.051  1
85776  94.004  -78.469  53.033  1
85777  94.015  -78.471  53.012  1
85778  94.030  -78.470  52.989  1
85779  94.045  -78.468  52.966  1
85780  94.059  -78.467  52.943  1
85781  94.074  -78.465  52.922  1
85782  94.088  -78.463  52.900  1
85783  94.103  -78.462  52.876  1
85784  94.118  -78.460  52.850  1
85785  94.132  -78.459  52.827  1
85786  94.147  -78.457  52.808  1
85787  94.161  -78.456  52.790  1
85788  94.173  -78.448  52.772  1
85789  94.189  -78.415  52.755  1
85790  94.208  -78.379  52.737  1
85791  94.220  -78.357  52.718  1
85792  94.222  -78.351  52.701  1
85793  94.225  -78.344  52.683  1
85794  94.227  -78.384  52.665  1
85795  94.228  -78.445  52.646  1
85796  94.229  -78.507  52.629  1
85797  94.236  -78.567  52.612  1
85798  94.251  -78.574  52.594  1
85799  94.266  -78.580  52.576  1
85800  94.281  -78.587  52.558  1
85801  94.296  -78.594  52.540  1
85802  94.312  -78.599  52.522  1
85803  94.328  -78.605  52.505  1
85804  94.345  -78.611  52.486  1
85805  94.361  -78.617  52.464  1
85806  94.381  -78.611  52.442  1
85807  94.399  -78.596  52.419  1
85808  94.416  -78.582  52.395  1
85809  94.433  -78.567  52.370  1
85810  94.451  -78.552  52.342  1
85811  94.464  -78.545  52.312  1
85812  94.473  -78.545  52.279  1
85813  94.483  -78.546  52.245  1
85814  94.492  -78.546  52.211  1
85815  94.501  -78.546  52.176  1
85816  94.510  -78.546  52.141  1
85817  94.526  -78.551  52.108  1
85818  94.542  -78.555  52.075  1
85819  94.557  -78.559  52.042  1
85820  94.573  -78.564  52.010  1
85821  94.585  -78.567  51.976  1
85822  94.591  -78.569  51.941  1
85823  94.602  -78.567  51.904  1
85824  94.612  -78.567  51.866  1
85825  94.622  -78.565  51.826  1
85826  94.633  -78.564  51.784  1
85827  94.647  -78.568  51.739  1
85828  94.660  -78.572  51.693  1
85829  94.674  -78.576  51.644  1
85830  94.687  -78.579  51.594  1
85831  94.700  -78.582  51.545  1
85832  94.713  -78.586  51.496  1
85833  94.726  -78.588  51.446  1
85834  94.740  -78.589  51.396  1
85835  94.761  -78.594  51.347  1
85836  94.782  -78.598  51.299  1
85837  94.803  -78.602  51.251  1
85838  94.824  -78.607  51.204  1
85839  94.845  -78.611  51.157  1
85840  94.867  -78.615  51.110  1
85841  94.888  -78.619  51.065  1
85842  94.904  -78.622  51.020  1
85843  94.901  -78.630  50.976  1
85844  94.906  -78.633  50.931  1
85845  94.910  -78.634  50.888  1
85846  94.915  -78.636  50.845  1
85847  94.919  -78.638  50.803  1
85848  94.924  -78.640  50.761  1
85849  94.928  -78.642  50.720  1
85850  94.922  -78.641  50.679  1
85851  94.917  -78.640  50.636  1
85852  94.921  -78.631  50.592  1
85853  94.935  -78.613  50.549  1
85854  94.950  -78.595  50.506  1
85855  94.964  -78.577  50.462  1
85856  94.979  -78.559  50.417  1
85857  94.993  -78.542  50.372  1
85858  95.007  -78.523  50.328  1
85859  95.022  -78.506  50.284  1
85860  95.037  -78.490  50.239  1
85861  95.057  -78.495  50.195  1
85862  95.077  -78.500  50.152  1
85863  95.098  -78.505  50.109  1
85864  95.118  -78.510  50.065  1
85865  95.139  -78.516  50.024  1
85866  95.149  -78.519  49.982  1
85867  95.160  -78.523  49.941  1
85868  95.171  -78.526  49.902  1
85869  95.181  -78.530  49.864  1
85870  95.192  -78.534  49.826  1
85871  95.203  -78.538  49.788  1
85872  95.213  -78.542  49.751  1
85873  95.224  -78.545  49.713  1
85874  95.255  -78.561  49.674  1
85875  95.288  -78.577  49.637  1
85876  95.321  -78.595  49.599  1
85877  95.354  -78.611  49.561  1
85878  95.387  -78.628  49.523  1
85879  95.420  -78.645  49.486  1
85880  95.433  -78.659  49.449  1
85881  95.448  -78.680  49.412  1
85882  95.462  -78.701  49.377  1
85883  95.475  -78.722  49.343  1
85884  95.489  -78.743  49.309  1
85885  95.503  -78.764  49.276  1
85886  95.498  -78.764  49.242  1
85887  95.493  -78.764  49.206  1
85888  95.488  -78.764  49.169  1
85889  95.483  -78.763  49.129  1
85890  95.469  -78.759  49.089  1
85891  95.452  -78.755  49.047  1
85892  95.435  -78.749  49.006  1
85893  95.418  -78.745  48.963  1
85894  95.416  -78.735  48.918  1
85895  95.420  -78.724  48.872  1
85896  95.424  -78.712  48.828  1
85897  95.432  -78.704  48.785  1
85898  95.456  -78.706  48.742  1
85899  95.479  -78.708  48.700  1
85900  95.502  -78.710  48.659  1
85901  95.526  -78.711  48.619  1
85902  95.549  -78.714  48.580  1
85903  95.572  -78.716  48.540  1
85904  95.596  -78.717  48.501  1
85905  95.619  -78.720  48.462  1
85906  95.625  -78.730  48.423  1
85907  95.637  -78.735  48.386  1
85908  95.649  -78.739  48.350  1
85909  95.661  -78.743  48.313  1
85910  95.673  -78.748  48.277  1
85911  95.685  -78.752  48.241  1
85912  95.701  -78.758  48.204  1
85913  95.730  -78.770  48.167  1
85914  95.759  -78.782  48.127  1
85915  95.788  -78.786  48.087  1
85916  95.818  -78.780  48.047  1
85917  95.836  -78.780  48.007  1
85918  95.853  -78.781  47.967  1
85919  95.870  -78.782  47.925  1
85920  95.886  -78.787  47.883  1
85921  95.901  -78.793  47.841  1
85922  95.914  -78.798  47.799  1
85923  95.921  -78.803  47.757  1
85924  95.930  -78.809  47.715  1
85925  95.953  -78.806  47.672  1
85926  95.977  -78.803  47.629  1
85927  96.002  -78.800  47.585  1
85928  96.026  -78.797  47.544  1
85929  96.050  -78.793  47.502  1
85930  96.074  -78.790  47.460  1
85931  96.098  -78.787  47.420  1
85932  96.117  -78.799  47.380  1
85933  96.135  -78.816  47.341  1
85934  96.153  -78.834  47.303  1
85935  96.171  -78.852  47.266  1
85936  96.187  -78.839  47.229  1
85937  96.203  -78.827  47.192  1
85938  96.220  -78.815  47.155  1
85939  96.237  -78.802  47.118  1
85940  96.253  -78.790  47.083  1
85941  96.269  -78.777  47.049  1
85942  96.289  -78.767  47.017  1
85943  96.305  -78.764  46.984  1
85944  96.316  -78.782  46.950  1
85945  96.327  -78.799  46.917  1
85946  96.339  -78.818  46.885  1
85947  96.350  -78.835  46.854  1
85948  96.361  -78.852  46.823  1
85949  96.373  -78.870  46.792  1
85950  96.383  -78.879  46.761  1
85951  96.393  -78.882  46.731  1
85952  96.437  -78.882  46.703  1
85953  96.482  -78.882  46.676  1
85954  96.527  -78.881  46.649  1
85955  96.569  -78.877  46.623  1
85956  96.609  -78.873  46.597  1
85957  96.650  -78.868  46.570  1
85958  96.690  -78.863  46.542  1
85959  96.731  -78.858  46.520  1
85960  96.771  -78.853  46.499  1
85961  96.812  -78.849  46.478  1
85962  96.841  -78.845  46.456  1
85963  96.851  -78.842  46.433  1
85964  96.861  -78.839  46.411  1
85965  96.871  -78.836  46.391  1
85966  96.889  -78.844  46.371  1
85967  96.909  -78.855  46.351  1
85968  96.930  -78.852  46.332  1
85969  96.943  -78.855  46.311  1
85970  96.938  -78.890  46.292  1
85971  96.965  -78.947  46.273  1
85972  96.971  -78.959  46.256  1
85973  96.958  -78.977  46.240  1
85974  96.963  -78.988  46.224  1
85975  96.975  -78.968  46.209  1
85976  96.975  -78.968  46.193  1
85977  96.969  -78.983  46.177  1
85978  96.963  -78.998  46.161  1
85979  96.980  -79.040  46.144  1
85980  97.001  -79.081  46.130  1
85981  97.022  -79.076  46.115  1
85982  97.042  -79.071  46.101  1
85983  97.062  -79.066  46.083  1
85984  97.082  -79.061  46.066  1
85985  97.102  -79.056  46.050  1
85986  97.122  -79.050  46.035  1
85987  97.146  -79.053  46.025  1
85988  97.169  -79.057  46.012  1
85989  97.193  -79.062  45.996  1
85990  97.216  -79.066  45.982  1
85991  97.232  -79.078  45.965  1
85992  97.246  -79.087  45.947  1
85993  97.251  -79.090  45.931  1
85994  97.257  -79.093  45.915  1
85995  97.264  -79.097  45.897  1
85996  97.280  -79.106  45.877  1
85997  97.295  -79.115  45.856  1
85998  97.310  -79.124  45.836  1
85999  97.325  -79.132  45.817  1
86000  97.340  -79.141  45.798  1
86001  97.355  -79.150  45.781  1
86002  97.370  -79.159  45.763  1
86003  97.383  -79.162  45.745  1
86004  97.394  -79.161  45.727  1
86005  97.406  -79.160  45.709  1
86006  97.417  -79.159  45.691  1
86007  97.429  -79.159  45.675  1
86008  97.440  -79.158  45.659  1
86009  97.454  -79.160  45.644  1
86010  97.476  -79.172  45.628  1
86011  97.499  -79.182  45.612  1
86012  97.521  -79.194  45.595  1
86013  97.543  -79.204  45.578  1
86014  97.566  -79.215  45.562  1
86015  97.588  -79.226  45.546  1
86016  97.607  -79.234  45.531  1
86017  97.623  -79.238  45.516  1
86018  97.623  -79.238  45.501  1
86019  97.623  -79.237  45.486  1
86020  97.622  -79.237  45.471  1
86021  97.622  -79.237  45.456  1
86022  97.622  -79.236  45.444  1
86023  97.622  -79.236  45.431  1
86024  97.621  -79.235  45.418  1
86025  97.621  -79.235  45.402  1
86026  97.621  -79.234  45.386  1
86027  97.621  -79.234  45.370  1
86028  97.626  -79.239  45.355  1
86029  97.644  -79.259  45.343  1
86030  97.662  -79.279  45.332  1
86031  97.680  -79.300  45.320  1
86032  97.699  -79.320  45.308  1
86033  97.717  -79.341  45.296  1
86034  97.735  -79.361  45.284  1
86035  97.759  -79.382  45.272  1
86036  97.799  -79.406  45.260  1
86037  97.823  -79.419  45.249  1
86038  97.840  -79.427  45.239  1
86039  97.856  -79.435  45.229  1
86040  97.869  -79.451  45.219  1
86041  97.881  -79.466  45.209  1
86042  97.893  -79.481  45.200  1
86043  97.906  -79.496  45.191  1
86044  97.918  -79.511  45.181  1
86045  97.931  -79.526  45.171  1
86046  97.943  -79.541  45.163  1
86047  97.955  -79.557  45.155  1
86048  97.975  -79.569  45.145  1
86049  97.999  -79.576  45.136  1
86050  98.024  -79.584  45.128  1
86051  98.055  -79.583  45.120  1
86052  98.108  -79.555  45.113  1
86053  98.161  -79.527  45.106  1
86054  98.201  -79.514  45.099  1
86055  98.238  -79.505  45.091  1
86056  98.271  -79.493  45.082  1
86057  98.303  -79.510  45.073  1
86058  98.339  -79.535  45.066  1
86059  98.374  -79.560  45.057  1
86060  98.414  -79.591  45.049  1
86061  98.444  -79.620  45.041  1
86062  98.476  -79.632  45.033  1
86063  98.502  -79.641  45.024  1
86064  98.527  -79.650  45.016  1
86065  98.553  -79.659  45.007  1
86066  98.578  -79.668  44.999  1
86067  98.604  -79.677  44.991  1
86068  98.629  -79.686  44.985  1
86069  98.655  -79.695  44.978  1
86070  98.680  -79.704  44.972  1
86071  98.691  -79.723  44.968  1
86072  98.701  -79.723  44.964  1
86073  98.718  -79.714  44.959  1
86074  98.735  -79.705  44.956  1
86075  98.752  -79.696  44.952  1
86076  98.770  -79.688  44.949  1
86077  98.787  -79.679  44.946  1
86078  98.803  -79.670  44.942  1
86079  98.821  -79.670  44.938  1
86080  98.840  -79.681  44.933  1
86081  98.860  -79.692  44.927  1
86082  98.879  -79.704  44.921  1
86083  98.898  -79.715  44.913  1
86084  98.917  -79.726  44.905  1
86085  98.936  -79.739  44.897  1
86086  98.955  -79.750  44.888  1
86087  98.975  -79.761  44.878  1
86088  99.013  -79.764  44.868  1
86089  99.055  -79.764  44.860  1
86090  99.094  -79.766  44.851  1
86091  99.119  -79.780  44.840  1
86092  99.143  -79.794  44.828  1
86093  99.164  -79.808  44.815  1
86094  99.168  -79.822  44.803  1
86095  99.180  -79.833  44.792  1
86096  99.204  -79.839  44.781  1
86097  99.227  -79.845  44.773  1
86098  99.251  -79.852  44.764  1
86099  99.275  -79.858  44.755  1
86100  99.298  -79.864  44.748  1
86101  99.322  -79.871  44.740  1
86102  99.346  -79.877  44.732  1
86103  99.369  -79.883  44.723  1
86104  99.394  -79.889  44.713  1
86105  99.417  -79.896  44.706  1
86106  99.441  -79.902  44.697  1
86107  99.465  -79.908  44.688  1
86108  99.488  -79.914  44.681  1
86109  99.512  -79.921  44.673  1
86110  99.531  -79.921  44.663  1
86111  99.546  -79.914  44.655  1
86112  99.561  -79.908  44.647  1
86113  99.570  -79.916  44.638  1
86114  99.568  -79.944  44.628  1
86115  99.567  -79.972  44.620  1
86116  99.566  -80.000  44.612  1
86117  99.565  -80.028  44.603  1
86118  99.564  -80.056  44.595  1
86119  99.562  -80.084  44.587  1
86120  99.561  -80.112  44.580  1
86121  99.560  -80.140  44.574  1
86122  99.559  -80.168  44.566  1
86123  99.557  -80.196  44.559  1
86124  99.556  -80.224  44.552  1
86125  99.555  -80.252  44.544  1
86126  99.554  -80.280  44.537  1
86127  99.552  -80.308  44.529  1
86128  99.567  -80.337  44.521  1
86129  99.619  -80.349  44.511  1
86130  99.669  -80.362  44.501  1
86131  99.721  -80.375  44.491  1
86132  99.772  -80.387  44.481  1
86133  99.824  -80.400  44.470  1
86134  99.875  -80.413  44.458  1
86135  99.926  -80.425  44.446  1
86136  99.978  -80.438  44.434  1
86137  100.025  -80.453  44.422  1
86138  100.069  -80.469  44.409  1
86139  100.114  -80.486  44.396  1
86140  100.158  -80.502  44.384  1
86141  100.203  -80.519  44.371  1
86142  100.248  -80.535  44.358  1
86436  93.567  -78.735  53.624  1
86437  93.577  -78.733  53.615  1
86438  93.586  -78.730  53.606  1
86439  93.596  -78.728  53.597  1
86440  93.606  -78.725  53.590  1
86441  93.616  -78.723  53.582  1
86442  93.624  -78.720  53.575  1
86443  93.623  -78.711  53.569  1
86444  93.621  -78.701  53.565  1
86445  93.620  -78.692  53.561  1
86446  93.619  -78.683  53.560  1
86447  93.617  -78.688  53.564  1
86448  93.625  -78.681  53.562  1
86449  93.642  -78.670  53.557  1
86450  93.659  -78.660  53.550  1
86451  93.677  -78.649  53.541  1
86452  93.695  -78.639  53.532  1
86453  93.712  -78.628  53.520  1
86454  93.729  -78.617  53.505  1
86455  93.747  -78.607  53.488  1
86456  93.765  -78.596  53.469  1
86457  93.770  -78.582  53.449  1
86458  93.772  -78.568  53.427  1
86459  93.775  -78.554  53.406  1
86460  93.778  -78.540  53.384  1
86461  93.780  -78.526  53.363  1
86462  93.783  -78.512  53.341  1
86463  93.786  -78.498  53.318  1
86464  93.788  -78.483  53.295  1
86465  93.791  -78.469  53.270  1
86466  93.794  -78.455  53.245  1
86467  93.803  -78.453  53.221  1
86468  93.830  -78.485  53.198  1
86469  93.848  -78.486  53.175  1
86470  93.870  -78.472  53.154  1
86471  93.914  -78.454  53.132  1
86472  93.958  -78.437  53.115  1
86473  94.002  -78.420  53.098  1
86474  94.010  -78.426  53.081  1
86475  94.011  -78.436  53.065  1
86476  94.012  -78.447  53.050  1
86477  94.008  -78.459  53.032  1
86478  94.018  -78.463  53.010  1
86479  94.034  -78.460  52.986  1
86480  94.049  -78.457  52.963  1
86481  94.065  -78.454  52.940  1
86482  94.080  -78.451  52.918  1
86483  94.096  -78.448  52.896  1
86484  94.112  -78.445  52.873  1
86485  94.127  -78.443  52.849  1
86486  94.142  -78.440  52.829  1
86487  94.157  -78.438  52.811  1
86488  94.172  -78.437  52.795  1
86489  94.186  -78.435  52.778  1
86490  94.202  -78.416  52.760  1
86491  94.207  -78.404  52.741  1
86492  94.209  -78.398  52.721  1
86493  94.212  -78.391  52.703  1
86494  94.215  -78.385  52.685  1
86495  94.217  -78.408  52.668  1
86496  94.218  -78.470  52.649  1
86497  94.219  -78.532  52.633  1
86498  94.231  -78.557  52.617  1
86499  94.247  -78.562  52.599  1
86500  94.263  -78.568  52.582  1
86501  94.280  -78.573  52.564  1
86502  94.296  -78.579  52.546  1
86503  94.312  -78.586  52.529  1
86504  94.329  -78.591  52.511  1
86505  94.345  -78.597  52.493  1
86506  94.362  -78.600  52.471  1
86507  94.386  -78.593  52.450  1
86508  94.408  -78.587  52.428  1
86509  94.429  -78.578  52.404  1
86510  94.447  -78.564  52.379  1
86511  94.464  -78.548  52.351  1
86512  94.476  -78.545  52.321  1
86513  94.485  -78.545  52.289  1
86514  94.494  -78.546  52.255  1
86515  94.503  -78.546  52.220  1
86516  94.513  -78.546  52.185  1
86517  94.522  -78.546  52.151  1
86518  94.532  -78.547  52.119  1
86519  94.544  -78.549  52.086  1
86520  94.560  -78.553  52.051  1
86521  94.575  -78.557  52.017  1
86522  94.590  -78.561  51.983  1
86523  94.597  -78.564  51.948  1
86524  94.607  -78.562  51.912  1
86525  94.617  -78.561  51.874  1
86526  94.628  -78.560  51.835  1
86527  94.638  -78.558  51.793  1
86528  94.649  -78.558  51.748  1
86529  94.663  -78.562  51.702  1
86530  94.676  -78.566  51.653  1
86531  94.690  -78.569  51.602  1
86532  94.703  -78.573  51.552  1
86533  94.716  -78.576  51.502  1
86534  94.730  -78.580  51.451  1
86535  94.743  -78.583  51.401  1
86536  94.764  -78.587  51.351  1
86537  94.784  -78.590  51.301  1
86538  94.806  -78.594  51.252  1
86539  94.827  -78.597  51.204  1
86540  94.847  -78.601  51.155  1
86541  94.868  -78.604  51.108  1
86542  94.889  -78.608  51.062  1
86543  94.893  -78.611  51.017  1
86544  94.896  -78.616  50.972  1
86545  94.890  -78.622  50.928  1
86546  94.886  -78.634  50.884  1
86547  94.881  -78.646  50.842  1
86548  94.886  -78.648  50.800  1
86549  94.890  -78.650  50.758  1
86550  94.887  -78.650  50.717  1
86551  94.898  -78.636  50.677  1
86552  94.912  -78.617  50.635  1
86553  94.926  -78.600  50.592  1
86554  94.941  -78.582  50.549  1
86555  94.955  -78.564  50.506  1
86556  94.969  -78.546  50.463  1
86557  94.984  -78.528  50.419  1
86558  94.998  -78.510  50.375  1
86559  95.013  -78.492  50.330  1
86560  95.027  -78.475  50.285  1
86561  95.045  -78.470  50.240  1
86562  95.065  -78.475  50.196  1
86563  95.086  -78.480  50.153  1
86564  95.106  -78.485  50.110  1
86565  95.126  -78.490  50.066  1
86566  95.147  -78.495  50.024  1
86567  95.163  -78.500  49.982  1
86568  95.174  -78.504  49.941  1
86569  95.185  -78.507  49.903  1
86570  95.195  -78.511  49.864  1
86571  95.206  -78.515  49.826  1
86572  95.217  -78.518  49.787  1
86573  95.228  -78.522  49.750  1
86574  95.249  -78.532  49.712  1
86575  95.282  -78.549  49.675  1
86576  95.315  -78.566  49.638  1
86577  95.348  -78.582  49.600  1
86578  95.381  -78.600  49.562  1
86579  95.414  -78.617  49.524  1
86580  95.447  -78.633  49.488  1
86581  95.480  -78.650  49.452  1
86582  95.491  -78.667  49.416  1
86583  95.505  -78.688  49.380  1
86584  95.519  -78.709  49.346  1
86585  95.533  -78.730  49.312  1
86586  95.532  -78.734  49.280  1
86587  95.527  -78.733  49.247  1
86588  95.522  -78.733  49.213  1
86589  95.516  -78.733  49.176  1
86590  95.511  -78.732  49.136  1
86591  95.506  -78.732  49.096  1
86592  95.489  -78.727  49.054  1
86593  95.472  -78.722  49.012  1
86594  95.455  -78.717  48.969  1
86595  95.438  -78.712  48.923  1
86596  95.421  -78.708  48.877  1
86597  95.415  -78.699  48.834  1
86598  95.422  -78.690  48.792  1
86599  95.445  -78.692  48.749  1
86600  95.469  -78.694  48.709  1
86601  95.492  -78.696  48.668  1
86602  95.516  -78.698  48.629  1
86603  95.539  -78.700  48.589  1
86604  95.563  -78.702  48.550  1
86605  95.588  -78.702  48.511  1
86606  95.613  -78.702  48.472  1
86607  95.632  -78.705  48.435  1
86608  95.644  -78.710  48.397  1
86609  95.657  -78.714  48.361  1
86610  95.669  -78.718  48.325  1
86611  95.681  -78.723  48.289  1
86612  95.692  -78.727  48.251  1
86613  95.707  -78.732  48.212  1
86614  95.736  -78.744  48.172  1
86615  95.765  -78.755  48.132  1
86616  95.794  -78.748  48.091  1
86617  95.824  -78.742  48.051  1
86618  95.848  -78.738  48.011  1
86619  95.866  -78.739  47.971  1
86620  95.881  -78.743  47.931  1
86621  95.896  -78.749  47.889  1
86622  95.911  -78.753  47.848  1
86623  95.924  -78.759  47.807  1
86624  95.932  -78.764  47.766  1
86625  95.940  -78.771  47.725  1
86626  95.956  -78.772  47.684  1
86627  95.980  -78.769  47.642  1
86628  96.004  -78.765  47.599  1
86629  96.028  -78.762  47.557  1
86630  96.052  -78.759  47.516  1
86631  96.077  -78.755  47.474  1
86632  96.099  -78.759  47.434  1
86633  96.116  -78.777  47.393  1
86634  96.134  -78.794  47.354  1
86635  96.152  -78.811  47.316  1
86636  96.170  -78.829  47.279  1
86637  96.186  -78.829  47.241  1
86638  96.203  -78.817  47.204  1
86639  96.220  -78.805  47.167  1
86640  96.236  -78.792  47.130  1
86641  96.252  -78.780  47.094  1
86642  96.269  -78.767  47.061  1
86643  96.286  -78.755  47.028  1
86644  96.297  -78.759  46.995  1
86645  96.307  -78.769  46.962  1
86646  96.318  -78.787  46.930  1
86647  96.329  -78.805  46.898  1
86648  96.340  -78.822  46.866  1
86649  96.352  -78.840  46.836  1
86650  96.363  -78.858  46.805  1
86651  96.374  -78.871  46.775  1
86652  96.385  -78.874  46.745  1
86653  96.431  -78.874  46.717  1
86654  96.476  -78.874  46.690  1
86655  96.518  -78.871  46.665  1
86656  96.559  -78.865  46.638  1
86657  96.599  -78.861  46.612  1
86658  96.640  -78.856  46.585  1
86659  96.680  -78.851  46.557  1
86660  96.721  -78.846  46.534  1
86661  96.761  -78.841  46.512  1
86662  96.802  -78.836  46.490  1
86663  96.837  -78.832  46.469  1
86664  96.848  -78.829  46.448  1
86665  96.858  -78.827  46.426  1
86666  96.869  -78.824  46.405  1
86667  96.889  -78.835  46.386  1
86668  96.909  -78.846  46.367  1
86669  96.930  -78.847  46.349  1
86670  96.945  -78.849  46.328  1
86671  96.943  -78.886  46.308  1
86672  96.966  -78.935  46.289  1
86673  96.971  -78.941  46.272  1
86674  96.958  -78.959  46.257  1
86675  96.952  -78.973  46.241  1
86676  96.960  -78.984  46.226  1
86677  96.972  -78.961  46.209  1
86678  96.966  -78.976  46.194  1
86679  96.959  -78.990  46.178  1
86680  96.978  -79.034  46.161  1
86681  96.999  -79.052  46.146  1
86682  97.019  -79.046  46.132  1
86683  97.039  -79.041  46.117  1
86684  97.060  -79.036  46.100  1
86685  97.080  -79.031  46.082  1
86686  97.102  -79.033  46.064  1
86687  97.126  -79.037  46.049  1
86688  97.150  -79.042  46.037  1
86689  97.173  -79.046  46.024  1
86690  97.197  -79.051  46.009  1
86691  97.219  -79.057  45.995  1
86692  97.234  -79.068  45.978  1
86693  97.250  -79.079  45.961  1
86694  97.260  -79.086  45.943  1
86695  97.266  -79.089  45.924  1
86696  97.272  -79.092  45.905  1
86697  97.287  -79.101  45.885  1
86698  97.302  -79.109  45.866  1
86699  97.317  -79.118  45.846  1
86700  97.332  -79.127  45.827  1
86701  97.348  -79.136  45.808  1
86702  97.363  -79.145  45.791  1
86703  97.375  -79.147  45.773  1
86704  97.386  -79.146  45.756  1
86705  97.398  -79.145  45.738  1
86706  97.409  -79.144  45.720  1
86707  97.421  -79.143  45.703  1
86708  97.432  -79.143  45.686  1
86709  97.443  -79.141  45.671  1
86710  97.455  -79.141  45.655  1
86711  97.477  -79.153  45.639  1
86712  97.500  -79.163  45.624  1
86713  97.522  -79.175  45.608  1
86714  97.544  -79.185  45.591  1
86715  97.566  -79.196  45.576  1
86716  97.588  -79.207  45.560  1
86717  97.610  -79.219  45.544  1
86718  97.614  -79.225  45.528  1
86719  97.613  -79.224  45.514  1
86720  97.613  -79.224  45.499  1
86721  97.613  -79.223  45.483  1
86722  97.613  -79.223  45.468  1
86723  97.613  -79.222  45.455  1
86724  97.613  -79.222  45.443  1
86725  97.613  -79.222  45.430  1
86726  97.613  -79.221  45.413  1
86727  97.612  -79.221  45.396  1
86728  97.612  -79.220  45.379  1
86729  97.618  -79.226  45.364  1
86730  97.636  -79.247  45.351  1
86731  97.655  -79.266  45.339  1
86732  97.673  -79.287  45.327  1
86733  97.691  -79.307  45.316  1
86734  97.709  -79.328  45.305  1
86735  97.731  -79.349  45.293  1
86736  97.771  -79.372  45.281  1
86737  97.806  -79.393  45.269  1
86738  97.823  -79.401  45.258  1
86739  97.840  -79.410  45.248  1
86740  97.856  -79.418  45.239  1
86741  97.870  -79.432  45.229  1
86742  97.882  -79.447  45.220  1
86743  97.894  -79.462  45.211  1
86744  97.907  -79.477  45.202  1
86745  97.919  -79.492  45.193  1
86746  97.932  -79.507  45.182  1
86747  97.944  -79.523  45.174  1
86748  97.959  -79.537  45.166  1
86749  97.982  -79.547  45.158  1
86750  98.006  -79.554  45.149  1
86751  98.031  -79.562  45.142  1
86752  98.056  -79.569  45.135  1
86753  98.080  -79.576  45.128  1
86754  98.114  -79.572  45.120  1
86755  98.167  -79.544  45.111  1
86756  98.220  -79.516  45.103  1
86757  98.283  -79.508  45.095  1
86758  98.329  -79.528  45.087  1
86759  98.354  -79.551  45.078  1
86760  98.379  -79.574  45.069  1
86761  98.406  -79.595  45.060  1
86762  98.439  -79.604  45.051  1
86763  98.472  -79.613  45.042  1
86764  98.505  -79.621  45.033  1
86765  98.533  -79.630  45.025  1
86766  98.558  -79.639  45.018  1
86767  98.584  -79.648  45.010  1
86768  98.609  -79.657  45.003  1
86769  98.634  -79.667  44.997  1
86770  98.660  -79.676  44.990  1
86771  98.685  -79.686  44.984  1
86772  98.692  -79.705  44.980  1
86773  98.696  -79.716  44.975  1
86774  98.713  -79.708  44.972  1
86775  98.730  -79.698  44.968  1
86776  98.747  -79.690  44.964  1
86777  98.764  -79.681  44.961  1
86778  98.781  -79.673  44.957  1
86779  98.798  -79.665  44.953  1
86780  98.814  -79.665  44.949  1
86781  98.833  -79.676  44.944  1
86782  98.852  -79.689  44.938  1
86783  98.872  -79.700  44.931  1
86784  98.891  -79.711  44.923  1
86785  98.910  -79.723  44.914  1
86786  98.929  -79.734  44.905  1
86787  98.949  -79.745  44.895  1
86788  98.990  -79.747  44.885  1
86789  99.031  -79.748  44.874  1
86790  99.072  -79.748  44.864  1
86791  99.113  -79.750  44.856  1
86792  99.137  -79.764  44.844  1
86793  99.161  -79.777  44.831  1
86794  99.175  -79.792  44.819  1
86795  99.179  -79.806  44.806  1
86796  99.184  -79.820  44.795  1
86797  99.207  -79.826  44.784  1
86798  99.231  -79.832  44.776  1
86799  99.255  -79.839  44.768  1
86800  99.279  -79.845  44.760  1
86801  99.302  -79.851  44.752  1
86802  99.326  -79.857  44.745  1
86803  99.350  -79.864  44.736  1
86804  99.373  -79.870  44.727  1
86805  99.397  -79.876  44.718  1
86806  99.421  -79.882  44.709  1
86807  99.445  -79.889  44.701  1
86808  99.469  -79.895  44.692  1
86809  99.492  -79.901  44.684  1
86810  99.512  -79.902  44.676  1
86811  99.527  -79.897  44.667  1
86812  99.543  -79.891  44.659  1
86813  99.558  -79.885  44.651  1
86814  99.565  -79.896  44.642  1
86815  99.564  -79.924  44.632  1
86816  99.563  -79.952  44.624  1
86817  99.561  -79.980  44.616  1
86818  99.560  -80.008  44.607  1
86819  99.559  -80.036  44.599  1
86820  99.558  -80.064  44.591  1
86821  99.556  -80.092  44.584  1
86822  99.555  -80.120  44.577  1
86823  99.554  -80.148  44.570  1
86824  99.553  -80.175  44.562  1
86825  99.551  -80.203  44.555  1
86826  99.550  -80.231  44.548  1
86827  99.549  -80.259  44.541  1
86828  99.565  -80.284  44.533  1
86829  99.590  -80.314  44.524  1
86830  99.628  -80.355  44.515  1
86831  99.685  -80.349  44.505  1
86832  99.736  -80.362  44.495  1
86833  99.787  -80.375  44.485  1
86834  99.839  -80.388  44.474  1
86835  99.890  -80.400  44.463  1
86836  99.938  -80.415  44.451  1
86837  99.982  -80.431  44.439  1
86838  100.027  -80.447  44.427  1
86839  100.071  -80.464  44.414  1
86840  100.116  -80.480  44.401  1
86841  100.160  -80.497  44.389  1
86842  100.205  -80.513  44.375  1
86843  100.250  -80.529  44.362  1
87137  93.567  -78.724  53.631  1
87138  93.577  -78.722  53.621  1
87139  93.586  -78.719  53.611  1
87140  93.596  -78.717  53.602  1
87141  93.606  -78.714  53.594  1
87142  93.616  -78.712  53.586  1
87143  93.620  -78.706  53.579  1
87144  93.619  -78.697  53.571  1
87145  93.618  -78.688  53.566  1
87146  93.617  -78.679  53.561  1
87147  93.615  -78.670  53.559  1
87148  93.614  -78.661  53.560  1
87149  93.623  -78.658  53.557  1
87150  93.640  -78.648  53.553  1
87151  93.658  -78.637  53.545  1
87152  93.675  -78.626  53.536  1
87153  93.694  -78.616  53.524  1
87154  93.713  -78.606  53.510  1
87155  93.733  -78.595  53.495  1
87156  93.753  -78.585  53.476  1
87157  93.767  -78.579  53.456  1
87158  93.775  -78.570  53.434  1
87159  93.774  -78.553  53.412  1
87160  93.772  -78.535  53.390  1
87161  93.771  -78.519  53.368  1
87162  93.774  -78.504  53.348  1
87163  93.777  -78.491  53.328  1
87164  93.779  -78.476  53.307  1
87165  93.782  -78.462  53.286  1
87166  93.785  -78.448  53.262  1
87167  93.787  -78.434  53.238  1
87168  93.791  -78.420  53.215  1
87169  93.818  -78.452  53.192  1
87170  93.843  -78.476  53.171  1
87171  93.883  -78.458  53.150  1
87172  93.926  -78.441  53.129  1
87173  93.970  -78.423  53.113  1
87174  94.014  -78.406  53.097  1
87175  94.019  -78.413  53.081  1
87176  94.018  -78.426  53.063  1
87177  94.014  -78.438  53.046  1
87178  94.010  -78.451  53.028  1
87179  94.019  -78.458  53.006  1
87180  94.033  -78.458  52.981  1
87181  94.049  -78.455  52.958  1
87182  94.064  -78.452  52.935  1
87183  94.080  -78.449  52.913  1
87184  94.096  -78.446  52.892  1
87185  94.111  -78.443  52.870  1
87186  94.127  -78.440  52.847  1
87187  94.142  -78.437  52.830  1
87188  94.158  -78.434  52.814  1
87189  94.174  -78.431  52.798  1
87190  94.189  -78.428  52.782  1
87191  94.196  -78.433  52.764  1
87192  94.197  -78.445  52.745  1
87193  94.199  -78.438  52.725  1
87194  94.202  -78.432  52.706  1
87195  94.204  -78.425  52.689  1
87196  94.206  -78.432  52.673  1
87197  94.208  -78.495  52.655  1
87198  94.214  -78.537  52.639  1
87199  94.231  -78.542  52.623  1
87200  94.248  -78.548  52.605  1
87201  94.264  -78.554  52.587  1
87202  94.280  -78.560  52.570  1
87203  94.296  -78.565  52.552  1
87204  94.313  -78.571  52.535  1
87205  94.329  -78.577  52.518  1
87206  94.345  -78.582  52.498  1
87207  94.365  -78.581  52.477  1
87208  94.388  -78.574  52.456  1
87209  94.411  -78.567  52.434  1
87210  94.434  -78.561  52.412  1
87211  94.457  -78.554  52.386  1
87212  94.478  -78.545  52.359  1
87213  94.487  -78.545  52.330  1
87214  94.496  -78.545  52.297  1
87215  94.506  -78.546  52.263  1
87216  94.515  -78.546  52.229  1
87217  94.525  -78.546  52.194  1
87218  94.534  -78.546  52.162  1
87219  94.543  -78.547  52.129  1
87220  94.552  -78.547  52.096  1
87221  94.562  -78.547  52.060  1
87222  94.578  -78.551  52.025  1
87223  94.594  -78.556  51.990  1
87224  94.602  -78.558  51.954  1
87225  94.613  -78.557  51.919  1
87226  94.623  -78.555  51.882  1
87227  94.633  -78.554  51.845  1
87228  94.643  -78.553  51.803  1
87229  94.654  -78.551  51.758  1
87230  94.666  -78.552  51.710  1
87231  94.679  -78.555  51.663  1
87232  94.692  -78.559  51.612  1
87233  94.705  -78.563  51.560  1
87234  94.719  -78.567  51.509  1
87235  94.733  -78.570  51.458  1
87236  94.747  -78.572  51.407  1
87237  94.765  -78.576  51.355  1
87238  94.786  -78.579  51.304  1
87239  94.807  -78.582  51.254  1
87240  94.828  -78.586  51.204  1
87241  94.849  -78.589  51.155  1
87242  94.870  -78.592  51.107  1
87243  94.879  -78.596  51.061  1
87244  94.882  -78.601  51.015  1
87245  94.885  -78.604  50.970  1
87246  94.888  -78.609  50.926  1
87247  94.880  -78.612  50.883  1
87248  94.875  -78.624  50.841  1
87249  94.871  -78.636  50.799  1
87250  94.874  -78.640  50.757  1
87251  94.888  -78.622  50.716  1
87252  94.903  -78.604  50.676  1
87253  94.917  -78.586  50.634  1
87254  94.931  -78.569  50.591  1
87255  94.946  -78.551  50.549  1
87256  94.960  -78.532  50.505  1
87257  94.974  -78.515  50.463  1
87258  94.989  -78.497  50.419  1
87259  95.003  -78.479  50.375  1
87260  95.018  -78.461  50.331  1
87261  95.032  -78.445  50.286  1
87262  95.053  -78.450  50.242  1
87263  95.073  -78.454  50.198  1
87264  95.094  -78.460  50.155  1
87265  95.114  -78.465  50.111  1
87266  95.134  -78.470  50.068  1
87267  95.155  -78.476  50.025  1
87268  95.175  -78.480  49.983  1
87269  95.188  -78.485  49.942  1
87270  95.199  -78.489  49.904  1
87271  95.209  -78.492  49.865  1
87272  95.220  -78.495  49.827  1
87273  95.231  -78.499  49.788  1
87274  95.243  -78.504  49.750  1
87275  95.276  -78.520  49.713  1
87276  95.309  -78.538  49.676  1
87277  95.342  -78.554  49.639  1
87278  95.375  -78.571  49.602  1
87279  95.408  -78.588  49.564  1
87280  95.441  -78.605  49.528  1
87281  95.474  -78.622  49.492  1
87282  95.507  -78.639  49.456  1
87283  95.538  -78.655  49.419  1
87284  95.549  -78.674  49.384  1
87285  95.562  -78.695  49.350  1
87286  95.565  -78.704  49.316  1
87287  95.560  -78.704  49.284  1
87288  95.555  -78.703  49.252  1
87289  95.549  -78.702  49.218  1
87290  95.544  -78.702  49.183  1
87291  95.539  -78.702  49.143  1
87292  95.534  -78.701  49.103  1
87293  95.526  -78.699  49.061  1
87294  95.509  -78.695  49.018  1
87295  95.492  -78.690  48.973  1
87296  95.475  -78.685  48.928  1
87297  95.458  -78.680  48.883  1
87298  95.441  -78.675  48.840  1
87299  95.421  -78.672  48.798  1
87300  95.442  -78.673  48.757  1
87301  95.467  -78.673  48.717  1
87302  95.491  -78.673  48.678  1
87303  95.517  -78.674  48.638  1
87304  95.541  -78.675  48.597  1
87305  95.566  -78.675  48.558  1
87306  95.591  -78.676  48.520  1
87307  95.616  -78.677  48.481  1
87308  95.633  -78.680  48.443  1
87309  95.649  -78.684  48.406  1
87310  95.663  -78.689  48.370  1
87311  95.676  -78.693  48.335  1
87312  95.688  -78.697  48.299  1
87313  95.700  -78.702  48.261  1
87314  95.713  -78.706  48.220  1
87315  95.742  -78.717  48.180  1
87316  95.771  -78.717  48.139  1
87317  95.800  -78.710  48.099  1
87318  95.830  -78.704  48.058  1
87319  95.859  -78.697  48.019  1
87320  95.877  -78.699  47.979  1
87321  95.892  -78.704  47.937  1
87322  95.907  -78.709  47.895  1
87323  95.922  -78.714  47.854  1
87324  95.934  -78.720  47.812  1
87325  95.942  -78.726  47.772  1
87326  95.950  -78.732  47.731  1
87327  95.958  -78.737  47.691  1
87328  95.982  -78.734  47.651  1
87329  96.007  -78.731  47.610  1
87330  96.031  -78.727  47.570  1
87331  96.055  -78.724  47.530  1
87332  96.079  -78.721  47.489  1
87333  96.098  -78.736  47.449  1
87334  96.115  -78.754  47.409  1
87335  96.133  -78.771  47.370  1
87336  96.151  -78.789  47.331  1
87337  96.168  -78.806  47.293  1
87338  96.186  -78.819  47.254  1
87339  96.202  -78.806  47.218  1
87340  96.219  -78.794  47.180  1
87341  96.235  -78.782  47.143  1
87342  96.252  -78.769  47.107  1
87343  96.268  -78.757  47.073  1
87344  96.280  -78.759  47.041  1
87345  96.290  -78.767  47.009  1
87346  96.300  -78.776  46.977  1
87347  96.310  -78.783  46.944  1
87348  96.320  -78.793  46.913  1
87349  96.331  -78.810  46.882  1
87350  96.342  -78.827  46.851  1
87351  96.354  -78.845  46.821  1
87352  96.365  -78.863  46.791  1
87353  96.379  -78.865  46.761  1
87354  96.425  -78.865  46.734  1
87355  96.468  -78.863  46.707  1
87356  96.508  -78.858  46.680  1
87357  96.549  -78.853  46.654  1
87358  96.589  -78.849  46.627  1
87359  96.629  -78.844  46.599  1
87360  96.670  -78.839  46.573  1
87361  96.711  -78.834  46.549  1
87362  96.751  -78.829  46.527  1
87363  96.792  -78.824  46.505  1
87364  96.832  -78.820  46.484  1
87365  96.844  -78.817  46.464  1
87366  96.855  -78.814  46.443  1
87367  96.868  -78.815  46.421  1
87368  96.888  -78.826  46.402  1
87369  96.908  -78.836  46.383  1
87370  96.929  -78.843  46.364  1
87371  96.946  -78.842  46.343  1
87372  96.947  -78.880  46.324  1
87373  96.965  -78.918  46.305  1
87374  96.969  -78.924  46.289  1
87375  96.958  -78.940  46.274  1
87376  96.944  -78.957  46.258  1
87377  96.950  -78.968  46.242  1
87378  96.958  -78.977  46.226  1
87379  96.962  -78.968  46.210  1
87380  96.956  -78.983  46.194  1
87381  96.976  -79.027  46.178  1
87382  96.996  -79.021  46.164  1
87383  97.016  -79.016  46.149  1
87384  97.036  -79.012  46.133  1
87385  97.059  -79.012  46.116  1
87386  97.083  -79.017  46.098  1
87387  97.106  -79.021  46.079  1
87388  97.130  -79.026  46.062  1
87389  97.154  -79.031  46.049  1
87390  97.177  -79.035  46.035  1
87391  97.201  -79.040  46.022  1
87392  97.221  -79.047  46.007  1
87393  97.237  -79.059  45.992  1
87394  97.252  -79.069  45.976  1
87395  97.268  -79.081  45.957  1
87396  97.275  -79.084  45.936  1
87397  97.280  -79.087  45.916  1
87398  97.295  -79.096  45.896  1
87399  97.310  -79.104  45.878  1
87400  97.325  -79.113  45.859  1
87401  97.340  -79.122  45.839  1
87402  97.355  -79.131  45.821  1
87403  97.367  -79.131  45.803  1
87404  97.378  -79.131  45.786  1
87405  97.389  -79.129  45.769  1
87406  97.401  -79.128  45.752  1
87407  97.412  -79.128  45.735  1
87408  97.424  -79.127  45.719  1
87409  97.435  -79.126  45.700  1
87410  97.446  -79.125  45.684  1
87411  97.457  -79.125  45.669  1
87412  97.478  -79.134  45.653  1
87413  97.500  -79.144  45.638  1
87414  97.522  -79.156  45.623  1
87415  97.544  -79.166  45.608  1
87416  97.567  -79.178  45.593  1
87417  97.588  -79.190  45.576  1
87418  97.610  -79.206  45.559  1
87419  97.612  -79.211  45.543  1
87420  97.607  -79.210  45.529  1
87421  97.605  -79.209  45.512  1
87422  97.605  -79.209  45.494  1
87423  97.604  -79.209  45.478  1
87424  97.604  -79.208  45.465  1
87425  97.604  -79.208  45.451  1
87426  97.604  -79.207  45.437  1
87427  97.604  -79.207  45.420  1
87428  97.604  -79.206  45.403  1
87429  97.604  -79.206  45.387  1
87430  97.610  -79.213  45.373  1
87431  97.629  -79.234  45.360  1
87432  97.647  -79.254  45.348  1
87433  97.665  -79.274  45.337  1
87434  97.683  -79.294  45.326  1
87435  97.703  -79.315  45.314  1
87436  97.743  -79.339  45.303  1
87437  97.783  -79.363  45.291  1
87438  97.806  -79.375  45.280  1
87439  97.823  -79.384  45.270  1
87440  97.840  -79.392  45.260  1
87441  97.856  -79.400  45.251  1
87442  97.871  -79.412  45.242  1
87443  97.883  -79.428  45.232  1
87444  97.895  -79.443  45.223  1
87445  97.908  -79.458  45.215  1
87446  97.920  -79.473  45.206  1
87447  97.933  -79.488  45.197  1
87448  97.945  -79.504  45.189  1
87449  97.966  -79.514  45.181  1
87450  97.990  -79.524  45.173  1
87451  98.014  -79.532  45.166  1
87452  98.038  -79.540  45.158  1
87453  98.063  -79.547  45.151  1
87454  98.087  -79.554  45.143  1
87455  98.112  -79.561  45.135  1
87456  98.137  -79.569  45.126  1
87457  98.179  -79.564  45.117  1
87458  98.249  -79.545  45.108  1
87459  98.314  -79.528  45.099  1
87460  98.340  -79.551  45.089  1
87461  98.369  -79.567  45.080  1
87462  98.402  -79.576  45.071  1
87463  98.435  -79.585  45.062  1
87464  98.468  -79.594  45.053  1
87465  98.502  -79.602  45.044  1
87466  98.535  -79.611  45.036  1
87467  98.563  -79.620  45.029  1
87468  98.589  -79.629  45.022  1
87469  98.614  -79.639  45.016  1
87470  98.640  -79.648  45.009  1
87471  98.665  -79.657  45.003  1
87472  98.691  -79.666  44.997  1
87473  98.694  -79.688  44.992  1
87474  98.690  -79.709  44.987  1
87475  98.707  -79.701  44.984  1
87476  98.724  -79.692  44.980  1
87477  98.741  -79.683  44.976  1
87478  98.758  -79.675  44.973  1
87479  98.775  -79.666  44.968  1
87480  98.791  -79.663  44.963  1
87481  98.807  -79.662  44.958  1
87482  98.826  -79.673  44.950  1
87483  98.845  -79.684  44.943  1
87484  98.864  -79.695  44.935  1
87485  98.884  -79.708  44.928  1
87486  98.903  -79.719  44.919  1
87487  98.925  -79.729  44.910  1
87488  98.966  -79.730  44.902  1
87489  99.007  -79.731  44.892  1
87490  99.048  -79.732  44.879  1
87491  99.089  -79.733  44.867  1
87492  99.131  -79.734  44.855  1
87493  99.155  -79.747  44.843  1
87494  99.180  -79.761  44.832  1
87495  99.185  -79.775  44.822  1
87496  99.189  -79.789  44.810  1
87497  99.192  -79.804  44.799  1
87498  99.211  -79.812  44.789  1
87499  99.235  -79.818  44.780  1
87500  99.259  -79.824  44.770  1
87501  99.282  -79.831  44.761  1
87502  99.306  -79.837  44.754  1
87503  99.330  -79.843  44.747  1
87504  99.354  -79.849  44.739  1
87505  99.377  -79.856  44.730  1
87506  99.401  -79.862  44.721  1
87507  99.425  -79.868  44.712  1
87508  99.448  -79.874  44.704  1
87509  99.472  -79.881  44.695  1
87510  99.494  -79.885  44.687  1
87511  99.509  -79.879  44.678  1
87512  99.524  -79.874  44.670  1
87513  99.540  -79.867  44.662  1
87514  99.555  -79.861  44.653  1
87515  99.561  -79.875  44.645  1
87516  99.559  -79.903  44.636  1
87517  99.558  -79.931  44.628  1
87518  99.557  -79.959  44.619  1
87519  99.556  -79.987  44.611  1
87520  99.554  -80.015  44.603  1
87521  99.553  -80.043  44.595  1
87522  99.552  -80.071  44.588  1
87523  99.551  -80.099  44.581  1
87524  99.549  -80.127  44.573  1
87525  99.548  -80.155  44.566  1
87526  99.547  -80.183  44.559  1
87527  99.548  -80.211  44.552  1
87528  99.567  -80.235  44.545  1
87529  99.587  -80.260  44.537  1
87530  99.613  -80.290  44.529  1
87531  99.651  -80.331  44.520  1
87532  99.690  -80.369  44.511  1
87533  99.751  -80.349  44.501  1
87534  99.802  -80.362  44.490  1
87535  99.851  -80.376  44.480  1
87536  99.896  -80.392  44.468  1
87537  99.940  -80.409  44.456  1
87538  99.985  -80.425  44.444  1
87539  100.029  -80.441  44.432  1
87540  100.074  -80.458  44.419  1
87541  100.118  -80.474  44.407  1
87542  100.163  -80.491  44.394  1
87543  100.207  -80.507  44.380  1
87544  100.252  -80.523  44.366  1
87838  93.567  -78.714  53.638  1
87839  93.577  -78.711  53.628  1
87840  93.587  -78.708  53.617  1
87841  93.596  -78.706  53.607  1
87842  93.606  -78.704  53.598  1
87843  93.616  -78.701  53.590  1
87844  93.617  -78.693  53.582  1
87845  93.616  -78.684  53.574  1
87846  93.615  -78.675  53.567  1
87847  93.613  -78.666  53.561  1
87848  93.612  -78.656  53.557  1
87849  93.611  -78.647  53.556  1
87850  93.624  -78.636  53.552  1
87851  93.644  -78.626  53.547  1
87852  93.663  -78.615  53.539  1
87853  93.683  -78.604  53.528  1
87854  93.703  -78.595  53.514  1
87855  93.722  -78.584  53.498  1
87856  93.741  -78.575  53.481  1
87857  93.755  -78.570  53.460  1
87858  93.770  -78.564  53.439  1
87859  93.784  -78.559  53.416  1
87860  93.786  -78.545  53.393  1
87861  93.784  -78.527  53.371  1
87862  93.783  -78.510  53.350  1
87863  93.781  -78.493  53.329  1
87864  93.779  -78.476  53.310  1
87865  93.778  -78.458  53.292  1
87866  93.776  -78.442  53.273  1
87867  93.779  -78.427  53.252  1
87868  93.781  -78.413  53.231  1
87869  93.784  -78.398  53.209  1
87870  93.806  -78.420  53.187  1
87871  93.844  -78.444  53.166  1
87872  93.891  -78.432  53.145  1
87873  93.935  -78.418  53.126  1
87874  93.981  -78.404  53.111  1
87875  94.024  -78.391  53.095  1
87876  94.024  -78.404  53.079  1
87877  94.020  -78.417  53.059  1
87878  94.016  -78.430  53.041  1
87879  94.012  -78.442  53.021  1
87880  94.021  -78.450  52.999  1
87881  94.033  -78.455  52.974  1
87882  94.048  -78.452  52.951  1
87883  94.064  -78.449  52.929  1
87884  94.079  -78.446  52.907  1
87885  94.095  -78.443  52.886  1
87886  94.111  -78.440  52.867  1
87887  94.126  -78.438  52.846  1
87888  94.141  -78.435  52.831  1
87889  94.157  -78.432  52.816  1
87890  94.172  -78.429  52.801  1
87891  94.185  -78.428  52.786  1
87892  94.190  -78.435  52.769  1
87893  94.190  -78.447  52.750  1
87894  94.191  -78.459  52.729  1
87895  94.191  -78.470  52.712  1
87896  94.194  -78.466  52.695  1
87897  94.196  -78.459  52.679  1
87898  94.198  -78.518  52.662  1
87899  94.214  -78.523  52.646  1
87900  94.231  -78.529  52.630  1
87901  94.248  -78.534  52.612  1
87902  94.264  -78.539  52.594  1
87903  94.280  -78.545  52.576  1
87904  94.296  -78.551  52.559  1
87905  94.313  -78.557  52.542  1
87906  94.329  -78.563  52.525  1
87907  94.346  -78.568  52.506  1
87908  94.368  -78.561  52.485  1
87909  94.391  -78.554  52.463  1
87910  94.414  -78.548  52.441  1
87911  94.437  -78.542  52.418  1
87912  94.460  -78.535  52.393  1
87913  94.470  -78.548  52.367  1
87914  94.484  -78.542  52.338  1
87915  94.497  -78.538  52.305  1
87916  94.509  -78.540  52.272  1
87917  94.522  -78.543  52.238  1
87918  94.535  -78.545  52.203  1
87919  94.545  -78.546  52.171  1
87920  94.555  -78.547  52.140  1
87921  94.564  -78.547  52.107  1
87922  94.573  -78.547  52.072  1
87923  94.582  -78.547  52.037  1
87924  94.596  -78.550  52.002  1
87925  94.608  -78.553  51.967  1
87926  94.618  -78.551  51.931  1
87927  94.628  -78.550  51.894  1
87928  94.639  -78.549  51.856  1
87929  94.649  -78.548  51.815  1
87930  94.660  -78.546  51.769  1
87931  94.670  -78.545  51.722  1
87932  94.681  -78.545  51.674  1
87933  94.695  -78.549  51.622  1
87934  94.708  -78.553  51.570  1
87935  94.722  -78.555  51.518  1
87936  94.737  -78.558  51.466  1
87937  94.751  -78.561  51.414  1
87938  94.767  -78.564  51.361  1
87939  94.788  -78.567  51.308  1
87940  94.809  -78.570  51.258  1
87941  94.830  -78.574  51.208  1
87942  94.851  -78.577  51.158  1
87943  94.865  -78.581  51.109  1
87944  94.868  -78.586  51.061  1
87945  94.871  -78.589  51.015  1
87946  94.874  -78.594  50.970  1
87947  94.877  -78.598  50.926  1
87948  94.879  -78.602  50.883  1
87949  94.872  -78.604  50.841  1
87950  94.869  -78.618  50.799  1
87951  94.881  -78.608  50.757  1
87952  94.893  -78.591  50.716  1
87953  94.908  -78.573  50.676  1
87954  94.922  -78.555  50.633  1
87955  94.936  -78.538  50.590  1
87956  94.951  -78.520  50.547  1
87957  94.965  -78.501  50.505  1
87958  94.979  -78.484  50.461  1
87959  94.994  -78.466  50.417  1
87960  95.008  -78.448  50.373  1
87961  95.023  -78.430  50.330  1
87962  95.040  -78.424  50.287  1
87963  95.061  -78.429  50.244  1
87964  95.081  -78.435  50.200  1
87965  95.102  -78.440  50.157  1
87966  95.122  -78.445  50.113  1
87967  95.142  -78.450  50.069  1
87968  95.163  -78.455  50.027  1
87969  95.183  -78.460  49.986  1
87970  95.202  -78.465  49.944  1
87971  95.212  -78.469  49.906  1
87972  95.224  -78.473  49.867  1
87973  95.234  -78.476  49.829  1
87974  95.245  -78.480  49.790  1
87975  95.269  -78.492  49.752  1
87976  95.303  -78.509  49.714  1
87977  95.335  -78.526  49.677  1
87978  95.369  -78.542  49.642  1
87979  95.401  -78.560  49.604  1
87980  95.435  -78.576  49.567  1
87981  95.467  -78.593  49.532  1
87982  95.500  -78.610  49.496  1
87983  95.533  -78.627  49.459  1
87984  95.566  -78.644  49.423  1
87985  95.592  -78.661  49.389  1
87986  95.599  -78.673  49.354  1
87987  95.593  -78.673  49.320  1
87988  95.588  -78.673  49.288  1
87989  95.583  -78.672  49.256  1
87990  95.578  -78.672  49.222  1
87991  95.572  -78.671  49.187  1
87992  95.567  -78.670  49.148  1
87993  95.561  -78.670  49.108  1
87994  95.556  -78.670  49.068  1
87995  95.546  -78.667  49.024  1
87996  95.529  -78.662  48.979  1
87997  95.512  -78.658  48.934  1
87998  95.495  -78.653  48.890  1
87999  95.478  -78.648  48.847  1
88000  95.454  -78.646  48.806  1
88001  95.445  -78.646  48.766  1
88002  95.470  -78.647  48.726  1
88003  95.495  -78.648  48.688  1
88004  95.520  -78.648  48.648  1
88005  95.544  -78.648  48.606  1
88006  95.569  -78.649  48.567  1
88007  95.594  -78.650  48.528  1
88008  95.619  -78.650  48.489  1
88009  95.635  -78.654  48.451  1
88010  95.650  -78.658  48.414  1
88011  95.665  -78.663  48.378  1
88012  95.680  -78.667  48.343  1
88013  95.694  -78.672  48.308  1
88014  95.708  -78.677  48.269  1
88015  95.720  -78.680  48.228  1
88016  95.748  -78.685  48.187  1
88017  95.777  -78.678  48.147  1
88018  95.806  -78.673  48.106  1
88019  95.834  -78.669  48.066  1
88020  95.862  -78.667  48.027  1
88021  95.883  -78.666  47.986  1
88022  95.903  -78.665  47.944  1
88023  95.918  -78.670  47.903  1
88024  95.933  -78.676  47.862  1
88025  95.944  -78.681  47.820  1
88026  95.952  -78.687  47.779  1
88027  95.960  -78.693  47.738  1
88028  95.967  -78.699  47.698  1
88029  95.985  -78.699  47.659  1
88030  96.010  -78.696  47.619  1
88031  96.034  -78.693  47.580  1
88032  96.058  -78.689  47.541  1
88033  96.079  -78.696  47.500  1
88034  96.097  -78.714  47.462  1
88035  96.114  -78.732  47.422  1
88036  96.132  -78.749  47.383  1
88037  96.150  -78.767  47.344  1
88038  96.167  -78.784  47.305  1
88039  96.185  -78.802  47.267  1
88040  96.202  -78.796  47.231  1
88041  96.218  -78.783  47.193  1
88042  96.235  -78.771  47.156  1
88043  96.251  -78.758  47.119  1
88044  96.264  -78.759  47.085  1
88045  96.273  -78.767  47.053  1
88046  96.284  -78.775  47.022  1
88047  96.294  -78.783  46.992  1
88048  96.304  -78.792  46.960  1
88049  96.313  -78.800  46.929  1
88050  96.323  -78.808  46.899  1
88051  96.333  -78.817  46.868  1
88052  96.344  -78.833  46.838  1
88053  96.356  -78.850  46.808  1
88054  96.374  -78.858  46.779  1
88055  96.417  -78.855  46.752  1
88056  96.458  -78.851  46.724  1
88057  96.498  -78.846  46.695  1
88058  96.538  -78.841  46.670  1
88059  96.579  -78.836  46.642  1
88060  96.619  -78.831  46.614  1
88061  96.660  -78.827  46.589  1
88062  96.700  -78.822  46.565  1
88063  96.741  -78.817  46.543  1
88064  96.782  -78.812  46.522  1
88065  96.822  -78.808  46.501  1
88066  96.841  -78.804  46.481  1
88067  96.852  -78.802  46.460  1
88068  96.868  -78.807  46.438  1
88069  96.888  -78.817  46.419  1
88070  96.908  -78.827  46.399  1
88071  96.928  -78.838  46.379  1
88072  96.948  -78.835  46.359  1
88073  96.952  -78.876  46.340  1
88074  96.964  -78.899  46.322  1
88075  96.968  -78.906  46.305  1
88076  96.958  -78.921  46.290  1
88077  96.944  -78.938  46.275  1
88078  96.939  -78.953  46.259  1
88079  96.947  -78.964  46.243  1
88080  96.955  -78.968  46.227  1
88081  96.953  -78.975  46.210  1
88082  96.973  -78.997  46.195  1
88083  96.994  -78.992  46.181  1
88084  97.016  -78.993  46.165  1
88085  97.039  -78.997  46.148  1
88086  97.063  -79.002  46.131  1
88087  97.087  -79.006  46.113  1
88088  97.110  -79.011  46.094  1
88089  97.134  -79.015  46.076  1
88090  97.158  -79.020  46.061  1
88091  97.181  -79.024  46.047  1
88092  97.205  -79.029  46.033  1
88093  97.223  -79.038  46.021  1
88094  97.239  -79.049  46.007  1
88095  97.254  -79.060  45.991  1
88096  97.271  -79.071  45.973  1
88097  97.283  -79.080  45.953  1
88098  97.289  -79.083  45.933  1
88099  97.302  -79.090  45.911  1
88100  97.317  -79.100  45.893  1
88101  97.332  -79.108  45.874  1
88102  97.348  -79.116  45.855  1
88103  97.359  -79.115  45.837  1
88104  97.370  -79.115  45.820  1
88105  97.381  -79.114  45.803  1
88106  97.392  -79.113  45.787  1
88107  97.404  -79.112  45.770  1
88108  97.415  -79.112  45.754  1
88109  97.427  -79.111  45.737  1
88110  97.438  -79.109  45.720  1
88111  97.449  -79.109  45.704  1
88112  97.460  -79.108  45.690  1
88113  97.478  -79.115  45.675  1
88114  97.501  -79.125  45.660  1
88115  97.523  -79.137  45.645  1
88116  97.544  -79.150  45.630  1
88117  97.566  -79.162  45.613  1
88118  97.587  -79.176  45.594  1
88119  97.611  -79.194  45.574  1
88120  97.610  -79.197  45.555  1
88121  97.605  -79.197  45.540  1
88122  97.600  -79.196  45.523  1
88123  97.596  -79.195  45.506  1
88124  97.596  -79.195  45.490  1
88125  97.596  -79.194  45.474  1
88126  97.595  -79.194  45.459  1
88127  97.595  -79.194  45.444  1
88128  97.595  -79.193  45.429  1
88129  97.595  -79.193  45.414  1
88130  97.595  -79.192  45.399  1
88131  97.602  -79.200  45.383  1
88132  97.620  -79.221  45.370  1
88133  97.639  -79.241  45.358  1
88134  97.657  -79.261  45.347  1
88135  97.675  -79.281  45.336  1
88136  97.714  -79.305  45.325  1
88137  97.754  -79.328  45.314  1
88138  97.789  -79.349  45.302  1
88139  97.806  -79.358  45.292  1
88140  97.823  -79.366  45.283  1
88141  97.840  -79.375  45.273  1
88142  97.856  -79.383  45.264  1
88143  97.872  -79.393  45.254  1
88144  97.884  -79.409  45.245  1
88145  97.896  -79.424  45.236  1
88146  97.909  -79.439  45.228  1
88147  97.921  -79.454  45.220  1
88148  97.934  -79.469  45.213  1
88149  97.951  -79.482  45.205  1
88150  97.973  -79.492  45.197  1
88151  97.997  -79.502  45.190  1
88152  98.021  -79.510  45.183  1
88153  98.045  -79.518  45.175  1
88154  98.070  -79.525  45.167  1
88155  98.095  -79.532  45.158  1
88156  98.119  -79.539  45.150  1
88157  98.144  -79.547  45.141  1
88158  98.183  -79.543  45.131  1
88159  98.238  -79.538  45.120  1
88160  98.293  -79.533  45.110  1
88161  98.332  -79.539  45.100  1
88162  98.365  -79.548  45.092  1
88163  98.398  -79.557  45.083  1
88164  98.432  -79.566  45.074  1
88165  98.465  -79.574  45.065  1
88166  98.499  -79.583  45.056  1
88167  98.532  -79.592  45.049  1
88168  98.565  -79.601  45.042  1
88169  98.594  -79.610  45.036  1
88170  98.620  -79.619  45.029  1
88171  98.645  -79.628  45.023  1
88172  98.670  -79.637  45.018  1
88173  98.696  -79.647  45.011  1
88174  98.695  -79.670  45.006  1
88175  98.687  -79.699  45.000  1
88176  98.701  -79.694  44.995  1
88177  98.718  -79.686  44.991  1
88178  98.735  -79.676  44.988  1
88179  98.752  -79.668  44.984  1
88180  98.769  -79.662  44.978  1
88181  98.785  -79.661  44.971  1
88182  98.800  -79.661  44.965  1
88183  98.819  -79.669  44.957  1
88184  98.838  -79.680  44.947  1
88185  98.857  -79.692  44.938  1
88186  98.876  -79.703  44.929  1
88187  98.902  -79.712  44.920  1
88188  98.942  -79.713  44.911  1
88189  98.984  -79.714  44.902  1
88190  99.025  -79.715  44.893  1
88191  99.066  -79.716  44.881  1
88192  99.107  -79.717  44.868  1
88193  99.148  -79.718  44.857  1
88194  99.174  -79.730  44.845  1
88195  99.192  -79.745  44.835  1
88196  99.196  -79.759  44.825  1
88197  99.199  -79.773  44.814  1
88198  99.203  -79.788  44.804  1
88199  99.215  -79.798  44.794  1
88200  99.239  -79.805  44.784  1
88201  99.263  -79.811  44.774  1
88202  99.286  -79.817  44.764  1
88203  99.310  -79.823  44.756  1
88204  99.334  -79.830  44.749  1
88205  99.357  -79.836  44.741  1
88206  99.381  -79.842  44.731  1
88207  99.405  -79.849  44.723  1
88208  99.429  -79.855  44.715  1
88209  99.452  -79.861  44.707  1
88210  99.476  -79.867  44.698  1
88211  99.491  -79.861  44.689  1
88212  99.506  -79.855  44.680  1
88213  99.521  -79.850  44.672  1
88214  99.537  -79.844  44.664  1
88215  99.552  -79.838  44.655  1
88216  99.556  -79.855  44.647  1
88217  99.555  -79.883  44.640  1
88218  99.553  -79.911  44.632  1
88219  99.552  -79.939  44.623  1
88220  99.551  -79.967  44.614  1
88221  99.550  -79.995  44.606  1
88222  99.548  -80.023  44.599  1
88223  99.547  -80.051  44.592  1
88224  99.546  -80.079  44.585  1
88225  99.545  -80.107  44.577  1
88226  99.543  -80.135  44.570  1
88227  99.550  -80.162  44.563  1
88228  99.569  -80.186  44.556  1
88229  99.589  -80.211  44.549  1
88230  99.609  -80.235  44.542  1
88231  99.636  -80.267  44.534  1
88232  99.674  -80.308  44.525  1
88233  99.712  -80.349  44.516  1
88234  99.747  -80.375  44.506  1
88235  99.809  -80.354  44.496  1
88236  99.853  -80.370  44.485  1
88237  99.898  -80.387  44.474  1
88238  99.942  -80.403  44.462  1
88239  99.987  -80.419  44.450  1
88240  100.031  -80.435  44.437  1
88241  100.076  -80.452  44.425  1
88242  100.121  -80.469  44.412  1
88243  100.165  -80.485  44.399  1
88244  100.210  -80.501  44.386  1
88245  100.255  -80.517  44.371  1
88246  100.299  -80.534  44.357  1
88247  100.344  -80.550  44.344  1
88248  100.388  -80.566  44.330  1
88539  93.568  -78.702  53.644  1
88540  93.577  -78.700  53.633  1
88541  93.587  -78.698  53.623  1
88542  93.597  -78.695  53.612  1
88543  93.607  -78.692  53.602  1
88544  93.615  -78.689  53.593  1
88545  93.614  -78.680  53.584  1
88546  93.612  -78.671  53.575  1
88547  93.611  -78.661  53.567  1
88548  93.610  -78.652  53.560  1
88549  93.609  -78.643  53.555  1
88550  93.608  -78.633  53.552  1
88551  93.631  -78.618  53.547  1
88552  93.653  -78.604  53.540  1
88553  93.673  -78.594  53.530  1
88554  93.692  -78.583  53.518  1
88555  93.712  -78.573  53.502  1
88556  93.729  -78.565  53.484  1
88557  93.744  -78.560  53.464  1
88558  93.758  -78.554  53.442  1
88559  93.773  -78.549  53.419  1
88560  93.787  -78.544  53.397  1
88561  93.798  -78.535  53.374  1
88562  93.796  -78.519  53.353  1
88563  93.795  -78.501  53.332  1
88564  93.793  -78.484  53.313  1
88565  93.791  -78.467  53.294  1
88566  93.790  -78.450  53.277  1
88567  93.788  -78.433  53.259  1
88568  93.787  -78.416  53.241  1
88569  93.785  -78.398  53.222  1
88570  93.783  -78.382  53.201  1
88571  93.799  -78.346  53.180  1
88572  93.847  -78.399  53.159  1
88573  93.895  -78.395  53.139  1
88574  93.940  -78.381  53.121  1
88575  93.980  -78.373  53.105  1
88576  94.007  -78.385  53.089  1
88577  94.026  -78.396  53.073  1
88578  94.022  -78.409  53.054  1
88579  94.018  -78.422  53.035  1
88580  94.014  -78.435  53.014  1
88581  94.023  -78.442  52.992  1
88582  94.035  -78.447  52.969  1
88583  94.048  -78.450  52.947  1
88584  94.063  -78.447  52.924  1
88585  94.078  -78.444  52.904  1
88586  94.094  -78.441  52.886  1
88587  94.110  -78.438  52.868  1
88588  94.125  -78.435  52.850  1
88589  94.141  -78.432  52.836  1
88590  94.155  -78.429  52.821  1
88591  94.168  -78.429  52.805  1
88592  94.181  -78.427  52.790  1
88593  94.184  -78.437  52.773  1
88594  94.184  -78.449  52.755  1
88595  94.185  -78.460  52.735  1
88596  94.185  -78.473  52.718  1
88597  94.186  -78.484  52.702  1
88598  94.186  -78.496  52.687  1
88599  94.198  -78.504  52.670  1
88600  94.214  -78.509  52.653  1
88601  94.231  -78.514  52.637  1
88602  94.248  -78.520  52.619  1
88603  94.264  -78.525  52.601  1
88604  94.280  -78.531  52.584  1
88605  94.297  -78.537  52.567  1
88606  94.313  -78.542  52.550  1
88607  94.329  -78.548  52.533  1
88608  94.348  -78.548  52.514  1
88609  94.371  -78.542  52.493  1
88610  94.394  -78.535  52.470  1
88611  94.417  -78.529  52.447  1
88612  94.439  -78.523  52.425  1
88613  94.449  -78.537  52.400  1
88614  94.459  -78.550  52.374  1
88615  94.472  -78.545  52.347  1
88616  94.486  -78.539  52.313  1
88617  94.500  -78.532  52.281  1
88618  94.513  -78.529  52.247  1
88619  94.526  -78.531  52.213  1
88620  94.538  -78.533  52.181  1
88621  94.551  -78.535  52.150  1
88622  94.563  -78.539  52.120  1
88623  94.576  -78.541  52.086  1
88624  94.589  -78.543  52.052  1
88625  94.601  -78.545  52.017  1
88626  94.613  -78.548  51.982  1
88627  94.623  -78.546  51.945  1
88628  94.634  -78.545  51.907  1
88629  94.644  -78.543  51.869  1
88630  94.654  -78.542  51.827  1
88631  94.665  -78.540  51.781  1
88632  94.675  -78.539  51.734  1
88633  94.685  -78.537  51.685  1
88634  94.698  -78.539  51.632  1
88635  94.712  -78.542  51.578  1
88636  94.726  -78.544  51.525  1
88637  94.740  -78.547  51.472  1
88638  94.754  -78.550  51.420  1
88639  94.769  -78.552  51.367  1
88640  94.789  -78.556  51.313  1
88641  94.811  -78.559  51.262  1
88642  94.832  -78.563  51.211  1
88643  94.851  -78.566  51.160  1
88644  94.854  -78.570  51.111  1
88645  94.857  -78.574  51.063  1
88646  94.860  -78.579  51.017  1
88647  94.862  -78.582  50.972  1
88648  94.865  -78.587  50.929  1
88649  94.868  -78.591  50.886  1
88650  94.871  -78.595  50.845  1
88651  94.876  -78.594  50.803  1
88652  94.887  -78.576  50.761  1
88653  94.899  -78.560  50.719  1
88654  94.913  -78.542  50.677  1
88655  94.927  -78.524  50.634  1
88656  94.942  -78.506  50.591  1
88657  94.956  -78.489  50.547  1
88658  94.970  -78.470  50.504  1
88659  94.985  -78.453  50.461  1
88660  94.999  -78.435  50.416  1
88661  95.014  -78.416  50.373  1
88662  95.028  -78.399  50.329  1
88663  95.048  -78.404  50.285  1
88664  95.068  -78.410  50.242  1
88665  95.089  -78.414  50.201  1
88666  95.110  -78.420  50.159  1
88667  95.130  -78.425  50.115  1
88668  95.150  -78.430  50.071  1
88669  95.171  -78.435  50.029  1
88670  95.191  -78.440  49.988  1
88671  95.212  -78.445  49.946  1
88672  95.227  -78.450  49.908  1
88673  95.237  -78.454  49.869  1
88674  95.248  -78.457  49.831  1
88675  95.263  -78.463  49.795  1
88676  95.296  -78.480  49.756  1
88677  95.329  -78.498  49.719  1
88678  95.362  -78.514  49.682  1
88679  95.395  -78.531  49.645  1
88680  95.428  -78.548  49.607  1
88681  95.461  -78.565  49.570  1
88682  95.494  -78.582  49.535  1
88683  95.527  -78.598  49.499  1
88684  95.560  -78.615  49.464  1
88685  95.589  -78.630  49.429  1
88686  95.612  -78.642  49.394  1
88687  95.620  -78.643  49.359  1
88688  95.621  -78.642  49.324  1
88689  95.616  -78.642  49.291  1
88690  95.611  -78.642  49.258  1
88691  95.605  -78.641  49.223  1
88692  95.600  -78.640  49.188  1
88693  95.595  -78.640  49.150  1
88694  95.590  -78.639  49.112  1
88695  95.584  -78.639  49.072  1
88696  95.579  -78.639  49.029  1
88697  95.566  -78.635  48.985  1
88698  95.549  -78.630  48.941  1
88699  95.532  -78.625  48.898  1
88700  95.514  -78.620  48.856  1
88701  95.487  -78.620  48.816  1
88702  95.461  -78.620  48.776  1
88703  95.473  -78.620  48.737  1
88704  95.498  -78.621  48.697  1
88705  95.523  -78.622  48.657  1
88706  95.548  -78.623  48.615  1
88707  95.572  -78.623  48.575  1
88708  95.597  -78.623  48.535  1
88709  95.621  -78.624  48.496  1
88710  95.636  -78.628  48.458  1
88711  95.652  -78.632  48.421  1
88712  95.666  -78.636  48.384  1
88713  95.681  -78.641  48.349  1
88714  95.696  -78.646  48.314  1
88715  95.711  -78.651  48.277  1
88716  95.726  -78.655  48.237  1
88717  95.752  -78.653  48.195  1
88718  95.780  -78.649  48.154  1
88719  95.808  -78.646  48.113  1
88720  95.837  -78.642  48.073  1
88721  95.859  -78.642  48.034  1
88722  95.881  -78.644  47.994  1
88723  95.902  -78.641  47.953  1
88724  95.923  -78.639  47.913  1
88725  95.944  -78.637  47.873  1
88726  95.954  -78.642  47.831  1
88727  95.962  -78.648  47.787  1
88728  95.970  -78.655  47.747  1
88729  95.977  -78.660  47.706  1
88730  95.988  -78.664  47.666  1
88731  96.012  -78.661  47.626  1
88732  96.036  -78.658  47.586  1
88733  96.060  -78.657  47.546  1
88734  96.078  -78.674  47.507  1
88735  96.096  -78.692  47.470  1
88736  96.113  -78.709  47.431  1
88737  96.131  -78.727  47.392  1
88738  96.149  -78.744  47.354  1
88739  96.166  -78.761  47.316  1
88740  96.184  -78.779  47.279  1
88741  96.201  -78.786  47.242  1
88742  96.218  -78.773  47.205  1
88743  96.234  -78.761  47.168  1
88744  96.247  -78.758  47.132  1
88745  96.257  -78.767  47.097  1
88746  96.267  -78.775  47.066  1
88747  96.277  -78.783  47.037  1
88748  96.287  -78.792  47.007  1
88749  96.297  -78.800  46.978  1
88750  96.307  -78.808  46.948  1
88751  96.317  -78.817  46.918  1
88752  96.327  -78.824  46.888  1
88753  96.337  -78.833  46.857  1
88754  96.346  -78.841  46.827  1
88755  96.367  -78.849  46.797  1
88756  96.407  -78.843  46.768  1
88757  96.448  -78.839  46.739  1
88758  96.488  -78.834  46.710  1
88759  96.528  -78.829  46.683  1
88760  96.569  -78.824  46.656  1
88761  96.609  -78.819  46.629  1
88762  96.650  -78.814  46.605  1
88763  96.690  -78.810  46.583  1
88764  96.731  -78.805  46.562  1
88765  96.771  -78.800  46.540  1
88766  96.812  -78.796  46.519  1
88767  96.838  -78.791  46.498  1
88768  96.848  -78.789  46.477  1
88769  96.867  -78.798  46.455  1
88770  96.887  -78.808  46.436  1
88771  96.907  -78.818  46.417  1
88772  96.928  -78.829  46.398  1
88773  96.948  -78.830  46.378  1
88774  96.956  -78.871  46.357  1
88775  96.963  -78.882  46.338  1
88776  96.967  -78.888  46.319  1
88777  96.958  -78.902  46.304  1
88778  96.944  -78.920  46.289  1
88779  96.931  -78.937  46.273  1
88780  96.936  -78.949  46.257  1
88781  96.944  -78.959  46.241  1
88782  96.950  -78.969  46.225  1
88783  96.972  -78.973  46.208  1
88784  96.996  -78.977  46.192  1
88785  97.020  -78.982  46.176  1
88786  97.043  -78.987  46.159  1
88787  97.067  -78.991  46.142  1
88788  97.091  -78.996  46.125  1
88789  97.114  -79.000  46.107  1
88790  97.138  -79.005  46.090  1
88791  97.162  -79.009  46.075  1
88792  97.185  -79.014  46.061  1
88793  97.209  -79.018  46.046  1
88794  97.226  -79.028  46.034  1
88795  97.241  -79.040  46.020  1
88796  97.257  -79.050  46.005  1
88797  97.273  -79.062  45.988  1
88798  97.289  -79.072  45.971  1
88799  97.298  -79.078  45.952  1
88800  97.310  -79.085  45.932  1
88801  97.325  -79.094  45.911  1
88802  97.339  -79.101  45.890  1
88803  97.351  -79.100  45.871  1
88804  97.362  -79.100  45.854  1
88805  97.373  -79.099  45.838  1
88806  97.384  -79.097  45.822  1
88807  97.396  -79.096  45.806  1
88808  97.407  -79.096  45.788  1
88809  97.418  -79.095  45.771  1
88810  97.430  -79.094  45.753  1
88811  97.441  -79.093  45.736  1
88812  97.452  -79.093  45.721  1
88813  97.463  -79.092  45.708  1
88814  97.479  -79.096  45.695  1
88815  97.501  -79.108  45.679  1
88816  97.522  -79.121  45.663  1
88817  97.543  -79.134  45.645  1
88818  97.565  -79.147  45.627  1
88819  97.586  -79.161  45.607  1
88820  97.612  -79.184  45.587  1
88821  97.607  -79.183  45.568  1
88822  97.603  -79.182  45.552  1
88823  97.598  -79.182  45.536  1
88824  97.593  -79.181  45.519  1
88825  97.588  -79.181  45.502  1
88826  97.587  -79.181  45.485  1
88827  97.587  -79.180  45.469  1
88828  97.587  -79.179  45.453  1
88829  97.586  -79.179  45.439  1
88830  97.586  -79.178  45.425  1
88831  97.586  -79.178  45.409  1
88832  97.595  -79.187  45.394  1
88833  97.613  -79.208  45.381  1
88834  97.631  -79.228  45.369  1
88835  97.650  -79.248  45.358  1
88836  97.686  -79.272  45.347  1
88837  97.726  -79.295  45.336  1
88838  97.766  -79.319  45.325  1
88839  97.789  -79.332  45.315  1
88840  97.806  -79.341  45.305  1
88841  97.823  -79.349  45.296  1
88842  97.840  -79.357  45.287  1
88843  97.856  -79.366  45.277  1
88844  97.873  -79.374  45.267  1
88845  97.885  -79.389  45.258  1
88846  97.897  -79.405  45.250  1
88847  97.910  -79.420  45.242  1
88848  97.922  -79.435  45.235  1
88849  97.935  -79.451  45.228  1
88850  97.958  -79.460  45.220  1
88851  97.981  -79.470  45.213  1
88852  98.004  -79.480  45.206  1
88853  98.028  -79.488  45.199  1
88854  98.053  -79.496  45.191  1
88855  98.077  -79.503  45.183  1
88856  98.102  -79.510  45.174  1
88857  98.127  -79.517  45.165  1
88858  98.151  -79.519  45.155  1
88859  98.195  -79.514  45.144  1
88860  98.250  -79.509  45.132  1
88861  98.301  -79.505  45.121  1
88862  98.330  -79.512  45.111  1
88863  98.363  -79.523  45.103  1
88864  98.395  -79.535  45.094  1
88865  98.428  -79.547  45.086  1
88866  98.462  -79.555  45.078  1
88867  98.495  -79.564  45.070  1
88868  98.528  -79.573  45.064  1
88869  98.562  -79.582  45.057  1
88870  98.595  -79.591  45.050  1
88871  98.625  -79.600  45.044  1
88872  98.650  -79.609  45.038  1
88873  98.675  -79.618  45.032  1
88874  98.701  -79.627  45.026  1
88875  98.697  -79.653  45.020  1
88876  98.688  -79.682  45.014  1
88877  98.696  -79.687  45.008  1
88878  98.713  -79.679  45.002  1
88879  98.730  -79.670  44.997  1
88880  98.747  -79.661  44.993  1
88881  98.763  -79.661  44.986  1
88882  98.778  -79.660  44.979  1
88883  98.794  -79.659  44.972  1
88884  98.812  -79.665  44.964  1
88885  98.831  -79.676  44.953  1
88886  98.850  -79.688  44.942  1
88887  98.878  -79.695  44.933  1
88888  98.919  -79.696  44.923  1
88889  98.960  -79.697  44.912  1
88890  99.001  -79.698  44.902  1
88891  99.042  -79.699  44.893  1
88892  99.083  -79.700  44.882  1
88893  99.124  -79.701  44.870  1
88894  99.165  -79.702  44.860  1
88895  99.192  -79.714  44.849  1
88896  99.203  -79.728  44.838  1
88897  99.206  -79.742  44.827  1
88898  99.210  -79.757  44.818  1
88899  99.213  -79.771  44.808  1
88900  99.219  -79.785  44.798  1
88901  99.242  -79.791  44.790  1
88902  99.267  -79.797  44.781  1
88903  99.290  -79.803  44.771  1
88904  99.314  -79.810  44.761  1
88905  99.338  -79.816  44.752  1
88906  99.361  -79.822  44.743  1
88907  99.385  -79.828  44.733  1
88908  99.409  -79.835  44.725  1
88909  99.432  -79.841  44.717  1
88910  99.456  -79.847  44.708  1
88911  99.473  -79.844  44.700  1
88912  99.488  -79.838  44.691  1
88913  99.503  -79.832  44.683  1
88914  99.518  -79.827  44.675  1
88915  99.534  -79.820  44.666  1
88916  99.549  -79.814  44.658  1
88917  99.551  -79.834  44.651  1
88918  99.550  -79.862  44.643  1
88919  99.549  -79.890  44.635  1
88920  99.548  -79.918  44.627  1
88921  99.546  -79.946  44.619  1
88922  99.545  -79.974  44.610  1
88923  99.544  -80.002  44.604  1
88924  99.543  -80.030  44.596  1
88925  99.541  -80.059  44.589  1
88926  99.540  -80.087  44.582  1
88927  99.552  -80.112  44.574  1
88928  99.571  -80.137  44.567  1
88929  99.591  -80.162  44.561  1
88930  99.611  -80.186  44.554  1
88931  99.630  -80.210  44.547  1
88932  99.659  -80.243  44.539  1
88933  99.697  -80.284  44.531  1
88934  99.735  -80.325  44.521  1
88935  99.765  -80.362  44.511  1
88936  99.815  -80.346  44.502  1
88937  99.859  -80.359  44.490  1
88938  99.900  -80.381  44.479  1
88939  99.945  -80.397  44.468  1
88940  99.989  -80.413  44.456  1
88941  100.034  -80.430  44.444  1
88942  100.078  -80.446  44.431  1
88943  100.123  -80.463  44.417  1
88944  100.168  -80.478  44.404  1
88945  100.212  -80.495  44.391  1
88946  100.257  -80.512  44.377  1
88947  100.301  -80.528  44.362  1
88948  100.346  -80.544  44.348  1
88949  100.391  -80.560  44.334  1
88950  100.435  -80.577  44.321  1
88951  100.480  -80.593  44.307  1
89241  93.578  -78.689  53.639  1
89242  93.587  -78.686  53.628  1
89243  93.597  -78.684  53.617  1
89244  93.607  -78.682  53.606  1
89245  93.612  -78.677  53.596  1
89246  93.610  -78.667  53.586  1
89247  93.609  -78.658  53.575  1
89248  93.608  -78.648  53.566  1
89249  93.606  -78.639  53.558  1
89250  93.605  -78.630  53.550  1
89251  93.614  -78.618  53.545  1
89252  93.636  -78.603  53.538  1
89253  93.658  -78.588  53.530  1
89254  93.681  -78.573  53.519  1
89255  93.701  -78.561  53.504  1
89256  93.717  -78.555  53.487  1
89257  93.731  -78.550  53.467  1
89258  93.747  -78.545  53.446  1
89259  93.761  -78.539  53.425  1
89260  93.776  -78.534  53.404  1
89261  93.790  -78.529  53.382  1
89262  93.805  -78.523  53.360  1
89263  93.808  -78.510  53.340  1
89264  93.807  -78.493  53.319  1
89265  93.805  -78.476  53.300  1
89266  93.803  -78.459  53.282  1
89267  93.802  -78.442  53.264  1
89268  93.800  -78.424  53.246  1
89269  93.799  -78.407  53.229  1
89270  93.797  -78.390  53.210  1
89271  93.795  -78.373  53.191  1
89272  93.815  -78.358  53.171  1
89273  93.849  -78.354  53.151  1
89274  93.900  -78.358  53.132  1
89275  93.936  -78.355  53.115  1
89276  93.964  -78.366  53.098  1
89277  93.991  -78.377  53.082  1
89278  94.018  -78.388  53.066  1
89279  94.024  -78.401  53.048  1
89280  94.020  -78.413  53.029  1
89281  94.016  -78.426  53.009  1
89282  94.025  -78.433  52.987  1
89283  94.036  -78.438  52.966  1
89284  94.048  -78.444  52.943  1
89285  94.062  -78.444  52.921  1
89286  94.078  -78.441  52.903  1
89287  94.094  -78.438  52.887  1
89288  94.109  -78.435  52.871  1
89289  94.125  -78.432  52.855  1
89290  94.138  -78.430  52.840  1
89291  94.151  -78.429  52.826  1
89292  94.165  -78.428  52.811  1
89293  94.177  -78.428  52.795  1
89294  94.178  -78.439  52.779  1
89295  94.178  -78.451  52.762  1
89296  94.179  -78.463  52.743  1
89297  94.179  -78.475  52.727  1
89298  94.180  -78.486  52.711  1
89299  94.183  -78.492  52.696  1
89300  94.197  -78.492  52.679  1
89301  94.215  -78.495  52.663  1
89302  94.231  -78.501  52.647  1
89303  94.248  -78.506  52.629  1
89304  94.264  -78.511  52.611  1
89305  94.281  -78.517  52.593  1
89306  94.297  -78.523  52.577  1
89307  94.313  -78.529  52.559  1
89308  94.330  -78.534  52.541  1
89309  94.351  -78.529  52.523  1
89310  94.374  -78.523  52.502  1
89311  94.397  -78.517  52.480  1
89312  94.418  -78.512  52.457  1
89313  94.428  -78.526  52.435  1
89314  94.438  -78.539  52.411  1
89315  94.448  -78.552  52.385  1
89316  94.461  -78.548  52.357  1
89317  94.475  -78.542  52.324  1
89318  94.488  -78.535  52.291  1
89319  94.502  -78.529  52.258  1
89320  94.516  -78.523  52.225  1
89321  94.529  -78.519  52.193  1
89322  94.542  -78.521  52.163  1
89323  94.554  -78.523  52.134  1
89324  94.567  -78.526  52.102  1
89325  94.579  -78.529  52.069  1
89326  94.593  -78.531  52.034  1
89327  94.609  -78.532  51.999  1
89328  94.625  -78.534  51.961  1
89329  94.635  -78.532  51.922  1
89330  94.645  -78.531  51.882  1
89331  94.655  -78.529  51.839  1
89332  94.666  -78.528  51.793  1
89333  94.676  -78.526  51.745  1
89334  94.687  -78.525  51.696  1
89335  94.700  -78.526  51.641  1
89336  94.715  -78.529  51.585  1
89337  94.730  -78.532  51.530  1
89338  94.744  -78.535  51.477  1
89339  94.758  -78.539  51.425  1
89340  94.772  -78.541  51.372  1
89341  94.791  -78.545  51.318  1
89342  94.812  -78.548  51.266  1
89343  94.833  -78.551  51.214  1
89344  94.840  -78.555  51.163  1
89345  94.843  -78.559  51.114  1
89346  94.846  -78.564  51.066  1
89347  94.849  -78.567  51.020  1
89348  94.852  -78.572  50.976  1
89349  94.854  -78.576  50.933  1
89350  94.863  -78.578  50.891  1
89351  94.873  -78.578  50.850  1
89352  94.883  -78.562  50.808  1
89353  94.894  -78.545  50.766  1
89354  94.905  -78.528  50.723  1
89355  94.918  -78.510  50.680  1
89356  94.932  -78.493  50.636  1
89357  94.947  -78.475  50.592  1
89358  94.961  -78.457  50.547  1
89359  94.975  -78.439  50.504  1
89360  94.990  -78.422  50.460  1
89361  95.004  -78.404  50.416  1
89362  95.019  -78.385  50.372  1
89363  95.036  -78.379  50.328  1
89364  95.056  -78.384  50.284  1
89365  95.076  -78.389  50.241  1
89366  95.097  -78.395  50.200  1
89367  95.117  -78.400  50.158  1
89368  95.138  -78.405  50.115  1
89369  95.159  -78.410  50.072  1
89370  95.179  -78.415  50.031  1
89371  95.199  -78.420  49.990  1
89372  95.220  -78.426  49.950  1
89373  95.240  -78.431  49.912  1
89374  95.251  -78.434  49.874  1
89375  95.262  -78.438  49.837  1
89376  95.290  -78.452  49.800  1
89377  95.323  -78.469  49.762  1
89378  95.356  -78.485  49.724  1
89379  95.389  -78.503  49.686  1
89380  95.422  -78.520  49.649  1
89381  95.455  -78.536  49.611  1
89382  95.483  -78.551  49.574  1
89383  95.508  -78.563  49.539  1
89384  95.532  -78.575  49.503  1
89385  95.555  -78.586  49.467  1
89386  95.580  -78.598  49.433  1
89387  95.603  -78.611  49.397  1
89388  95.611  -78.612  49.362  1
89389  95.616  -78.611  49.328  1
89390  95.621  -78.611  49.294  1
89391  95.626  -78.611  49.260  1
89392  95.631  -78.610  49.225  1
89393  95.628  -78.610  49.190  1
89394  95.623  -78.609  49.154  1
89395  95.617  -78.608  49.117  1
89396  95.612  -78.608  49.078  1
89397  95.607  -78.608  49.036  1
89398  95.602  -78.607  48.993  1
89399  95.586  -78.603  48.950  1
89400  95.568  -78.598  48.908  1
89401  95.547  -78.595  48.867  1
89402  95.521  -78.595  48.827  1
89403  95.494  -78.595  48.788  1
89404  95.476  -78.595  48.749  1
89405  95.501  -78.595  48.709  1
89406  95.526  -78.595  48.668  1
89407  95.551  -78.596  48.626  1
89408  95.576  -78.597  48.585  1
89409  95.601  -78.598  48.544  1
89410  95.623  -78.599  48.505  1
89411  95.638  -78.602  48.467  1
89412  95.653  -78.606  48.429  1
89413  95.668  -78.611  48.392  1
89414  95.683  -78.615  48.355  1
89415  95.697  -78.620  48.319  1
89416  95.712  -78.624  48.281  1
89417  95.730  -78.627  48.241  1
89418  95.754  -78.626  48.200  1
89419  95.782  -78.623  48.158  1
89420  95.811  -78.619  48.118  1
89421  95.835  -78.618  48.079  1
89422  95.856  -78.619  48.040  1
89423  95.878  -78.620  48.000  1
89424  95.900  -78.619  47.959  1
89425  95.921  -78.616  47.918  1
89426  95.941  -78.614  47.878  1
89427  95.957  -78.613  47.838  1
89428  95.972  -78.610  47.797  1
89429  95.980  -78.615  47.757  1
89430  95.987  -78.621  47.717  1
89431  95.995  -78.627  47.677  1
89432  96.015  -78.626  47.636  1
89433  96.039  -78.623  47.596  1
89434  96.059  -78.634  47.556  1
89435  96.077  -78.651  47.516  1
89436  96.094  -78.669  47.478  1
89437  96.112  -78.686  47.439  1
89438  96.130  -78.704  47.400  1
89439  96.148  -78.722  47.362  1
89440  96.165  -78.739  47.324  1
89441  96.183  -78.757  47.286  1
89442  96.200  -78.774  47.250  1
89443  96.217  -78.762  47.214  1
89444  96.231  -78.758  47.178  1
89445  96.241  -78.767  47.143  1
89446  96.251  -78.775  47.109  1
89447  96.261  -78.783  47.078  1
89448  96.270  -78.792  47.048  1
89449  96.281  -78.800  47.019  1
89450  96.291  -78.808  46.988  1
89451  96.303  -78.812  46.958  1
89452  96.315  -78.816  46.929  1
89453  96.328  -78.819  46.899  1
89454  96.341  -78.823  46.869  1
89455  96.354  -78.826  46.839  1
89456  96.352  -78.815  46.810  1
89457  96.393  -78.817  46.781  1
89458  96.436  -78.818  46.752  1
89459  96.477  -78.820  46.725  1
89460  96.518  -78.817  46.698  1
89461  96.559  -78.812  46.672  1
89462  96.599  -78.807  46.648  1
89463  96.640  -78.802  46.625  1
89464  96.680  -78.798  46.603  1
89465  96.721  -78.793  46.581  1
89466  96.761  -78.788  46.561  1
89467  96.802  -78.783  46.539  1
89468  96.835  -78.779  46.518  1
89469  96.847  -78.778  46.496  1
89470  96.867  -78.789  46.475  1
89471  96.887  -78.799  46.455  1
89472  96.907  -78.810  46.435  1
89473  96.927  -78.820  46.415  1
89474  96.947  -78.824  46.395  1
89475  96.957  -78.858  46.374  1
89476  96.962  -78.864  46.354  1
89477  96.966  -78.871  46.337  1
89478  96.958  -78.884  46.321  1
89479  96.945  -78.901  46.305  1
89480  96.931  -78.918  46.288  1
89481  96.925  -78.933  46.273  1
89482  96.933  -78.944  46.257  1
89483  96.949  -78.955  46.240  1
89484  96.974  -78.961  46.221  1
89485  97.000  -78.966  46.204  1
89486  97.024  -78.971  46.186  1
89487  97.047  -78.975  46.169  1
89488  97.071  -78.980  46.153  1
89489  97.095  -78.984  46.136  1
89490  97.118  -78.989  46.119  1
89491  97.142  -78.993  46.102  1
89492  97.166  -78.998  46.088  1
89493  97.189  -79.002  46.074  1
89494  97.212  -79.008  46.060  1
89495  97.228  -79.019  46.048  1
89496  97.243  -79.030  46.034  1
89497  97.259  -79.041  46.019  1
89498  97.275  -79.052  46.003  1
89499  97.291  -79.063  45.988  1
89500  97.306  -79.074  45.971  1
89501  97.317  -79.080  45.952  1
89502  97.331  -79.085  45.929  1
89503  97.342  -79.084  45.907  1
89504  97.354  -79.084  45.886  1
89505  97.365  -79.083  45.869  1
89506  97.376  -79.082  45.854  1
89507  97.387  -79.081  45.839  1
89508  97.399  -79.081  45.823  1
89509  97.410  -79.080  45.805  1
89510  97.422  -79.079  45.787  1
89511  97.436  -79.078  45.768  1
89512  97.449  -79.078  45.750  1
89513  97.462  -79.078  45.736  1
89514  97.471  -79.075  45.724  1
89515  97.479  -79.079  45.712  1
89516  97.500  -79.093  45.696  1
89517  97.521  -79.106  45.677  1
89518  97.542  -79.119  45.657  1
89519  97.564  -79.132  45.638  1
89520  97.585  -79.146  45.618  1
89521  97.610  -79.169  45.599  1
89522  97.605  -79.169  45.581  1
89523  97.600  -79.169  45.565  1
89524  97.596  -79.168  45.549  1
89525  97.591  -79.168  45.532  1
89526  97.586  -79.167  45.514  1
89527  97.581  -79.166  45.497  1
89528  97.578  -79.165  45.480  1
89529  97.578  -79.165  45.464  1
89530  97.578  -79.165  45.449  1
89531  97.578  -79.165  45.434  1
89532  97.578  -79.164  45.419  1
89533  97.587  -79.175  45.405  1
89534  97.605  -79.195  45.392  1
89535  97.624  -79.216  45.380  1
89536  97.658  -79.238  45.369  1
89537  97.698  -79.262  45.359  1
89538  97.738  -79.285  45.348  1
89539  97.773  -79.306  45.337  1
89540  97.789  -79.314  45.327  1
89541  97.806  -79.322  45.317  1
89542  97.823  -79.332  45.308  1
89543  97.840  -79.340  45.299  1
89544  97.856  -79.348  45.289  1
89545  97.873  -79.357  45.279  1
89546  97.886  -79.370  45.271  1
89547  97.898  -79.385  45.264  1
89548  97.911  -79.401  45.256  1
89549  97.923  -79.416  45.249  1
89550  97.942  -79.429  45.242  1
89551  97.965  -79.438  45.234  1
89552  97.988  -79.448  45.227  1
89553  98.011  -79.458  45.219  1
89554  98.035  -79.466  45.210  1
89555  98.060  -79.473  45.202  1
89556  98.084  -79.481  45.193  1
89557  98.109  -79.488  45.184  1
89558  98.134  -79.494  45.174  1
89559  98.158  -79.490  45.164  1
89560  98.207  -79.485  45.154  1
89561  98.262  -79.480  45.144  1
89562  98.301  -79.479  45.133  1
89563  98.328  -79.484  45.123  1
89564  98.361  -79.496  45.116  1
89565  98.394  -79.507  45.107  1
89566  98.427  -79.520  45.099  1
89567  98.459  -79.531  45.092  1
89568  98.492  -79.543  45.085  1
89569  98.525  -79.554  45.078  1
89570  98.558  -79.563  45.072  1
89571  98.591  -79.572  45.066  1
89572  98.625  -79.581  45.060  1
89573  98.655  -79.589  45.053  1
89574  98.680  -79.598  45.047  1
89575  98.706  -79.607  45.041  1
89576  98.699  -79.636  45.035  1
89577  98.690  -79.665  45.029  1
89578  98.690  -79.681  45.022  1
89579  98.707  -79.672  45.014  1
89580  98.724  -79.664  45.007  1
89581  98.740  -79.660  45.000  1
89582  98.756  -79.659  44.994  1
89583  98.772  -79.658  44.987  1
89584  98.788  -79.657  44.980  1
89585  98.804  -79.661  44.971  1
89586  98.823  -79.672  44.960  1
89587  98.854  -79.678  44.950  1
89588  98.895  -79.679  44.940  1
89589  98.936  -79.680  44.928  1
89590  98.978  -79.681  44.917  1
89591  99.018  -79.683  44.906  1
89592  99.060  -79.683  44.896  1
89593  99.101  -79.684  44.884  1
89594  99.142  -79.685  44.873  1
89595  99.183  -79.686  44.863  1
89596  99.209  -79.698  44.853  1
89597  99.213  -79.712  44.842  1
89598  99.216  -79.726  44.832  1
89599  99.220  -79.740  44.823  1
89600  99.223  -79.755  44.814  1
89601  99.227  -79.769  44.805  1
89602  99.246  -79.777  44.796  1
89603  99.270  -79.783  44.786  1
89604  99.294  -79.789  44.776  1
89605  99.317  -79.796  44.766  1
89606  99.342  -79.802  44.756  1
89607  99.365  -79.808  44.746  1
89608  99.389  -79.814  44.737  1
89609  99.413  -79.821  44.728  1
89610  99.436  -79.827  44.720  1
89611  99.454  -79.826  44.711  1
89612  99.470  -79.820  44.702  1
89613  99.485  -79.814  44.694  1
89614  99.500  -79.808  44.685  1
89615  99.515  -79.803  44.677  1
89616  99.530  -79.797  44.669  1
89617  99.545  -79.791  44.662  1
89618  99.547  -79.814  44.655  1
89619  99.545  -79.842  44.647  1
89620  99.544  -79.870  44.639  1
89621  99.543  -79.898  44.632  1
89622  99.542  -79.926  44.624  1
89623  99.540  -79.954  44.615  1
89624  99.539  -79.982  44.608  1
89625  99.538  -80.010  44.601  1
89626  99.537  -80.038  44.593  1
89627  99.554  -80.063  44.587  1
89628  99.573  -80.087  44.579  1
89629  99.593  -80.112  44.572  1
89630  99.613  -80.137  44.566  1
89631  99.632  -80.161  44.558  1
89632  99.652  -80.186  44.551  1
89633  99.682  -80.220  44.543  1
89634  99.720  -80.261  44.534  1
89635  99.758  -80.302  44.525  1
89636  99.783  -80.336  44.516  1
89637  99.807  -80.356  44.506  1
89638  99.868  -80.350  44.495  1
89639  99.913  -80.361  44.484  1
89640  99.947  -80.391  44.473  1
89641  99.992  -80.407  44.461  1
89642  100.036  -80.424  44.448  1
89643  100.081  -80.441  44.436  1
89644  100.125  -80.457  44.423  1
89645  100.170  -80.473  44.410  1
89646  100.214  -80.489  44.396  1
89647  100.259  -80.506  44.382  1
89648  100.303  -80.522  44.367  1
89649  100.348  -80.538  44.353  1
89650  100.393  -80.555  44.339  1
89651  100.437  -80.571  44.325  1
89652  100.482  -80.588  44.311  1
89653  100.527  -80.604  44.296  1
89654  100.571  -80.620  44.282  1
89655  100.616  -80.636  44.267  1
89942  93.578  -78.678  53.644  1
89943  93.588  -78.676  53.632  1
89944  93.597  -78.673  53.620  1
89945  93.607  -78.670  53.609  1
89946  93.608  -78.663  53.598  1
89947  93.607  -78.654  53.587  1
89948  93.606  -78.645  53.575  1
89949  93.604  -78.636  53.565  1
89950  93.603  -78.626  53.555  1
89951  93.602  -78.617  53.546  1
89952  93.619  -78.602  53.538  1
89953  93.641  -78.587  53.528  1
89954  93.664  -78.572  53.518  1
89955  93.687  -78.557  53.505  1
89956  93.705  -78.545  53.490  1
89957  93.720  -78.539  53.471  1
89958  93.734  -78.535  53.451  1
89959  93.749  -78.529  53.431  1
89960  93.764  -78.524  53.412  1
89961  93.778  -78.519  53.392  1
89962  93.793  -78.514  53.371  1
89963  93.807  -78.508  53.350  1
89964  93.821  -78.501  53.330  1
89965  93.819  -78.485  53.310  1
89966  93.817  -78.467  53.291  1
89967  93.816  -78.451  53.272  1
89968  93.814  -78.433  53.254  1
89969  93.813  -78.416  53.235  1
89970  93.811  -78.399  53.218  1
89971  93.809  -78.382  53.201  1
89972  93.807  -78.364  53.182  1
89973  93.830  -78.350  53.163  1
89974  93.859  -78.336  53.144  1
89975  93.893  -78.337  53.125  1
89976  93.920  -78.348  53.108  1
89977  93.947  -78.359  53.092  1
89978  93.975  -78.370  53.076  1
89979  94.002  -78.381  53.060  1
89980  94.026  -78.392  53.043  1
89981  94.022  -78.405  53.025  1
89982  94.018  -78.418  53.005  1
89983  94.026  -78.425  52.985  1
89984  94.038  -78.430  52.963  1
89985  94.050  -78.435  52.942  1
89986  94.062  -78.441  52.921  1
89987  94.077  -78.438  52.905  1
89988  94.093  -78.435  52.890  1
89989  94.109  -78.432  52.875  1
89990  94.122  -78.431  52.860  1
89991  94.135  -78.430  52.845  1
89992  94.148  -78.429  52.831  1
89993  94.161  -78.428  52.817  1
89994  94.171  -78.429  52.802  1
89995  94.171  -78.442  52.786  1
89996  94.172  -78.453  52.770  1
89997  94.172  -78.465  52.753  1
89998  94.173  -78.477  52.736  1
89999  94.176  -78.482  52.721  1
90000  94.180  -78.486  52.706  1
90001  94.191  -78.488  52.690  1
90002  94.213  -78.483  52.674  1
90003  94.231  -78.486  52.658  1
90004  94.248  -78.492  52.641  1
90005  94.265  -78.497  52.623  1
90006  94.281  -78.503  52.605  1
90007  94.297  -78.508  52.589  1
90008  94.314  -78.514  52.570  1
90009  94.332  -78.517  52.553  1
90010  94.354  -78.510  52.535  1
90011  94.377  -78.504  52.514  1
90012  94.397  -78.501  52.492  1
90013  94.407  -78.514  52.470  1
90014  94.417  -78.528  52.447  1
90015  94.427  -78.542  52.422  1
90016  94.436  -78.554  52.396  1
90017  94.450  -78.552  52.369  1
90018  94.463  -78.545  52.336  1
90019  94.477  -78.539  52.303  1
90020  94.491  -78.532  52.270  1
90021  94.504  -78.526  52.238  1
90022  94.518  -78.520  52.206  1
90023  94.532  -78.513  52.175  1
90024  94.545  -78.509  52.145  1
90025  94.558  -78.512  52.114  1
90026  94.571  -78.514  52.081  1
90027  94.588  -78.516  52.046  1
90028  94.604  -78.517  52.011  1
90029  94.621  -78.519  51.973  1
90030  94.637  -78.520  51.934  1
90031  94.647  -78.518  51.893  1
90032  94.657  -78.517  51.850  1
90033  94.668  -78.515  51.802  1
90034  94.678  -78.514  51.752  1
90035  94.688  -78.512  51.702  1
90036  94.701  -78.514  51.646  1
90037  94.716  -78.517  51.591  1
90038  94.732  -78.520  51.535  1
90039  94.748  -78.524  51.481  1
90040  94.762  -78.527  51.429  1
90041  94.776  -78.529  51.376  1
90042  94.793  -78.532  51.323  1
90043  94.814  -78.536  51.270  1
90044  94.826  -78.540  51.219  1
90045  94.829  -78.544  51.168  1
90046  94.832  -78.548  51.120  1
90047  94.835  -78.552  51.071  1
90048  94.841  -78.555  51.024  1
90049  94.851  -78.557  50.981  1
90050  94.861  -78.558  50.939  1
90051  94.871  -78.560  50.899  1
90052  94.881  -78.546  50.858  1
90053  94.890  -78.529  50.816  1
90054  94.900  -78.514  50.773  1
90055  94.911  -78.497  50.729  1
90056  94.923  -78.479  50.685  1
90057  94.937  -78.462  50.640  1
90058  94.952  -78.444  50.594  1
90059  94.966  -78.426  50.548  1
90060  94.980  -78.408  50.504  1
90061  94.995  -78.390  50.460  1
90062  95.009  -78.373  50.415  1
90063  95.024  -78.354  50.371  1
90064  95.044  -78.359  50.327  1
90065  95.064  -78.364  50.284  1
90066  95.085  -78.369  50.240  1
90067  95.105  -78.374  50.198  1
90068  95.125  -78.379  50.156  1
90069  95.146  -78.385  50.114  1
90070  95.167  -78.390  50.073  1
90071  95.187  -78.395  50.033  1
90072  95.207  -78.400  49.993  1
90073  95.228  -78.405  49.953  1
90074  95.248  -78.410  49.916  1
90075  95.265  -78.415  49.879  1
90076  95.283  -78.423  49.842  1
90077  95.317  -78.440  49.804  1
90078  95.349  -78.457  49.766  1
90079  95.379  -78.472  49.729  1
90080  95.402  -78.484  49.691  1
90081  95.426  -78.495  49.653  1
90082  95.451  -78.507  49.616  1
90083  95.474  -78.520  49.579  1
90084  95.498  -78.532  49.543  1
90085  95.523  -78.543  49.506  1
90086  95.546  -78.555  49.471  1
90087  95.570  -78.567  49.436  1
90088  95.594  -78.579  49.400  1
90089  95.602  -78.580  49.366  1
90090  95.607  -78.580  49.332  1
90091  95.612  -78.579  49.298  1
90092  95.617  -78.579  49.263  1
90093  95.622  -78.579  49.228  1
90094  95.628  -78.579  49.194  1
90095  95.633  -78.578  49.159  1
90096  95.638  -78.578  49.123  1
90097  95.640  -78.577  49.085  1
90098  95.635  -78.576  49.045  1
90099  95.629  -78.576  49.003  1
90100  95.623  -78.575  48.961  1
90101  95.606  -78.570  48.919  1
90102  95.581  -78.570  48.878  1
90103  95.554  -78.569  48.839  1
90104  95.527  -78.569  48.800  1
90105  95.501  -78.569  48.762  1
90106  95.504  -78.569  48.721  1
90107  95.529  -78.570  48.680  1
90108  95.554  -78.570  48.637  1
90109  95.579  -78.571  48.595  1
90110  95.604  -78.571  48.554  1
90111  95.624  -78.573  48.515  1
90112  95.639  -78.577  48.476  1
90113  95.655  -78.581  48.438  1
90114  95.670  -78.585  48.400  1
90115  95.684  -78.589  48.362  1
90116  95.699  -78.594  48.325  1
90117  95.714  -78.598  48.286  1
90118  95.735  -78.599  48.246  1
90119  95.758  -78.598  48.206  1
90120  95.784  -78.596  48.165  1
90121  95.811  -78.594  48.124  1
90122  95.832  -78.595  48.085  1
90123  95.854  -78.595  48.046  1
90124  95.876  -78.596  48.006  1
90125  95.897  -78.597  47.965  1
90126  95.917  -78.595  47.925  1
90127  95.934  -78.594  47.885  1
90128  95.951  -78.593  47.845  1
90129  95.966  -78.590  47.805  1
90130  95.981  -78.587  47.766  1
90131  95.997  -78.583  47.727  1
90132  96.006  -78.589  47.687  1
90133  96.018  -78.592  47.647  1
90134  96.040  -78.594  47.607  1
90135  96.058  -78.611  47.567  1
90136  96.076  -78.629  47.528  1
90137  96.093  -78.647  47.488  1
90138  96.111  -78.664  47.449  1
90139  96.128  -78.682  47.410  1
90140  96.147  -78.699  47.372  1
90141  96.164  -78.717  47.334  1
90142  96.182  -78.734  47.296  1
90143  96.199  -78.752  47.260  1
90144  96.215  -78.758  47.224  1
90145  96.225  -78.766  47.189  1
90146  96.238  -78.769  47.155  1
90147  96.250  -78.773  47.123  1
90148  96.263  -78.776  47.092  1
90149  96.276  -78.779  47.061  1
90150  96.289  -78.783  47.030  1
90151  96.302  -78.786  47.000  1
90152  96.315  -78.789  46.970  1
90153  96.327  -78.793  46.940  1
90154  96.340  -78.796  46.911  1
90155  96.353  -78.799  46.882  1
90156  96.366  -78.802  46.852  1
90157  96.357  -78.788  46.823  1
90158  96.377  -78.777  46.795  1
90159  96.419  -78.779  46.767  1
90160  96.461  -78.780  46.741  1
90161  96.503  -78.782  46.714  1
90162  96.545  -78.784  46.690  1
90163  96.587  -78.786  46.667  1
90164  96.629  -78.787  46.645  1
90165  96.670  -78.786  46.622  1
90166  96.711  -78.780  46.601  1
90167  96.751  -78.776  46.581  1
90168  96.792  -78.771  46.561  1
90169  96.831  -78.766  46.538  1
90170  96.846  -78.769  46.516  1
90171  96.866  -78.780  46.494  1
90172  96.886  -78.790  46.474  1
90173  96.906  -78.801  46.453  1
90174  96.927  -78.811  46.432  1
90175  96.947  -78.820  46.412  1
90176  96.956  -78.840  46.391  1
90177  96.960  -78.846  46.370  1
90178  96.965  -78.852  46.353  1
90179  96.958  -78.865  46.337  1
90180  96.945  -78.883  46.320  1
90181  96.931  -78.900  46.304  1
90182  96.917  -78.918  46.289  1
90183  96.931  -78.931  46.272  1
90184  96.947  -78.943  46.253  1
90185  96.973  -78.948  46.234  1
90186  96.999  -78.953  46.215  1
90187  97.024  -78.959  46.197  1
90188  97.050  -78.964  46.179  1
90189  97.075  -78.969  46.163  1
90190  97.099  -78.974  46.147  1
90191  97.122  -78.978  46.131  1
90192  97.146  -78.983  46.114  1
90193  97.170  -78.987  46.100  1
90194  97.193  -78.992  46.087  1
90195  97.214  -78.998  46.075  1
90196  97.230  -79.009  46.062  1
90197  97.246  -79.020  46.047  1
90198  97.261  -79.031  46.032  1
90199  97.277  -79.042  46.018  1
90200  97.293  -79.053  46.003  1
90201  97.309  -79.065  45.987  1
90202  97.325  -79.071  45.970  1
90203  97.338  -79.070  45.947  1
90204  97.352  -79.070  45.924  1
90205  97.365  -79.069  45.901  1
90206  97.379  -79.069  45.882  1
90207  97.392  -79.069  45.867  1
90208  97.405  -79.068  45.852  1
90209  97.419  -79.068  45.836  1
90210  97.433  -79.068  45.819  1
90211  97.445  -79.067  45.802  1
90212  97.453  -79.065  45.783  1
90213  97.462  -79.062  45.765  1
90214  97.470  -79.060  45.750  1
90215  97.478  -79.058  45.736  1
90216  97.487  -79.056  45.723  1
90217  97.499  -79.078  45.706  1
90218  97.520  -79.091  45.688  1
90219  97.541  -79.104  45.668  1
90220  97.562  -79.118  45.651  1
90221  97.586  -79.135  45.632  1
90222  97.608  -79.156  45.614  1
90223  97.603  -79.155  45.597  1
90224  97.598  -79.155  45.579  1
90225  97.593  -79.154  45.561  1
90226  97.589  -79.153  45.542  1
90227  97.584  -79.153  45.524  1
90228  97.579  -79.153  45.508  1
90229  97.574  -79.152  45.492  1
90230  97.570  -79.151  45.476  1
90231  97.569  -79.151  45.461  1
90232  97.569  -79.150  45.445  1
90233  97.569  -79.150  45.430  1
90234  97.579  -79.162  45.417  1
90235  97.597  -79.182  45.404  1
90236  97.630  -79.204  45.392  1
90237  97.669  -79.228  45.380  1
90238  97.709  -79.252  45.371  1
90239  97.749  -79.275  45.360  1
90240  97.773  -79.288  45.350  1
90241  97.790  -79.297  45.339  1
90242  97.806  -79.305  45.329  1
90243  97.823  -79.313  45.320  1
90244  97.840  -79.322  45.310  1
90245  97.856  -79.331  45.301  1
90246  97.873  -79.339  45.292  1
90247  97.887  -79.351  45.284  1
90248  97.899  -79.366  45.276  1
90249  97.912  -79.382  45.269  1
90250  97.926  -79.396  45.261  1
90251  97.949  -79.406  45.255  1
90252  97.972  -79.416  45.247  1
90253  97.996  -79.426  45.239  1
90254  98.019  -79.435  45.231  1
90255  98.042  -79.444  45.222  1
90256  98.067  -79.451  45.212  1
90257  98.092  -79.459  45.203  1
90258  98.116  -79.466  45.194  1
90259  98.141  -79.465  45.184  1
90260  98.165  -79.461  45.174  1
90261  98.218  -79.456  45.164  1
90262  98.274  -79.451  45.155  1
90263  98.301  -79.454  45.145  1
90264  98.327  -79.457  45.136  1
90265  98.359  -79.468  45.130  1
90266  98.392  -79.479  45.121  1
90267  98.425  -79.491  45.114  1
90268  98.457  -79.503  45.107  1
90269  98.490  -79.515  45.100  1
90270  98.523  -79.527  45.094  1
90271  98.556  -79.538  45.088  1
90272  98.588  -79.551  45.083  1
90273  98.622  -79.561  45.077  1
90274  98.655  -79.570  45.070  1
90275  98.686  -79.579  45.063  1
90276  98.709  -79.590  45.057  1
90277  98.700  -79.619  45.050  1
90278  98.692  -79.648  45.044  1
90279  98.685  -79.674  45.037  1
90280  98.701  -79.666  45.028  1
90281  98.718  -79.659  45.020  1
90282  98.734  -79.658  45.014  1
90283  98.749  -79.657  45.007  1
90284  98.765  -79.657  45.000  1
90285  98.781  -79.655  44.991  1
90286  98.797  -79.657  44.982  1
90287  98.831  -79.661  44.971  1
90288  98.872  -79.663  44.960  1
90289  98.913  -79.664  44.949  1
90290  98.954  -79.664  44.936  1
90291  98.995  -79.665  44.924  1
90292  99.036  -79.667  44.913  1
90293  99.077  -79.667  44.903  1
90294  99.118  -79.668  44.891  1
90295  99.159  -79.670  44.880  1
90296  99.200  -79.670  44.870  1
90297  99.220  -79.681  44.861  1
90298  99.223  -79.695  44.850  1
90299  99.227  -79.710  44.840  1
90300  99.230  -79.724  44.830  1
90301  99.234  -79.739  44.821  1
90302  99.237  -79.753  44.812  1
90303  99.251  -79.764  44.802  1
90304  99.274  -79.770  44.792  1
90305  99.298  -79.776  44.782  1
90306  99.322  -79.783  44.772  1
90307  99.345  -79.789  44.761  1
90308  99.369  -79.795  44.751  1
90309  99.393  -79.801  44.742  1
90310  99.417  -79.808  44.733  1
90311  99.436  -79.808  44.724  1
90312  99.451  -79.802  44.714  1
90313  99.467  -79.796  44.705  1
90314  99.482  -79.791  44.697  1
90315  99.497  -79.785  44.688  1
90316  99.512  -79.779  44.680  1
90317  99.527  -79.773  44.674  1
90318  99.542  -79.767  44.667  1
90319  99.542  -79.793  44.661  1
90320  99.541  -79.821  44.654  1
90321  99.540  -79.849  44.647  1
90322  99.538  -79.877  44.639  1
90323  99.537  -79.905  44.629  1
90324  99.536  -79.933  44.620  1
90325  99.535  -79.961  44.612  1
90326  99.536  -79.989  44.604  1
90327  99.555  -80.014  44.597  1
90328  99.575  -80.038  44.591  1
90329  99.594  -80.062  44.584  1
90330  99.614  -80.087  44.577  1
90331  99.634  -80.112  44.571  1
90332  99.654  -80.137  44.563  1
90333  99.674  -80.161  44.556  1
90334  99.705  -80.196  44.548  1
90335  99.743  -80.237  44.539  1
90336  99.778  -80.277  44.530  1
90337  99.801  -80.309  44.521  1
90338  99.825  -80.342  44.511  1
90339  99.869  -80.347  44.500  1
90340  99.921  -80.354  44.490  1
90341  99.967  -80.362  44.478  1
90342  99.994  -80.402  44.466  1
90343  100.039  -80.418  44.454  1
90344  100.083  -80.435  44.441  1
90345  100.128  -80.450  44.429  1
90346  100.172  -80.467  44.415  1
90347  100.217  -80.484  44.401  1
90348  100.261  -80.500  44.386  1
90349  100.306  -80.516  44.372  1
90350  100.350  -80.532  44.358  1
90351  100.395  -80.549  44.343  1
90352  100.439  -80.565  44.329  1
90353  100.484  -80.582  44.314  1
90354  100.528  -80.598  44.300  1
90355  100.573  -80.614  44.285  1
90356  100.618  -80.631  44.270  1
90357  100.662  -80.647  44.256  1
90358  100.707  -80.663  44.241  1
90359  100.752  -80.679  44.227  1
90643  93.578  -78.667  53.649  1
90644  93.588  -78.665  53.636  1
90645  93.597  -78.662  53.624  1
90646  93.606  -78.659  53.611  1
90647  93.605  -78.650  53.599  1
90648  93.604  -78.641  53.587  1
90649  93.602  -78.632  53.575  1
90650  93.601  -78.622  53.564  1
90651  93.600  -78.613  53.553  1
90652  93.602  -78.601  53.541  1
90653  93.624  -78.586  53.530  1
90654  93.647  -78.572  53.517  1
90655  93.670  -78.557  53.504  1
90656  93.692  -78.542  53.490  1
90657  93.707  -78.532  53.474  1
90658  93.722  -78.526  53.456  1
90659  93.737  -78.519  53.438  1
90660  93.752  -78.514  53.419  1
90661  93.767  -78.509  53.400  1
90662  93.781  -78.504  53.381  1
90663  93.796  -78.498  53.362  1
90664  93.811  -78.493  53.341  1
90665  93.825  -78.488  53.321  1
90666  93.831  -78.476  53.301  1
90667  93.829  -78.459  53.283  1
90668  93.828  -78.442  53.264  1
90669  93.826  -78.425  53.245  1
90670  93.825  -78.407  53.226  1
90671  93.823  -78.391  53.209  1
90672  93.821  -78.373  53.191  1
90673  93.820  -78.356  53.173  1
90674  93.844  -78.341  53.155  1
90675  93.873  -78.328  53.137  1
90676  93.897  -78.334  53.119  1
90677  93.911  -78.342  53.101  1
90678  93.931  -78.352  53.086  1
90679  93.958  -78.363  53.071  1
90680  93.985  -78.374  53.056  1
90681  94.012  -78.385  53.039  1
90682  94.024  -78.397  53.021  1
90683  94.020  -78.410  53.003  1
90684  94.028  -78.416  52.982  1
90685  94.040  -78.422  52.961  1
90686  94.052  -78.427  52.941  1
90687  94.064  -78.432  52.922  1
90688  94.077  -78.435  52.908  1
90689  94.092  -78.433  52.894  1
90690  94.105  -78.432  52.880  1
90691  94.118  -78.431  52.865  1
90692  94.131  -78.429  52.850  1
90693  94.144  -78.429  52.836  1
90694  94.157  -78.427  52.825  1
90695  94.165  -78.432  52.809  1
90696  94.165  -78.444  52.794  1
90697  94.166  -78.455  52.779  1
90698  94.166  -78.467  52.762  1
90699  94.170  -78.472  52.747  1
90700  94.174  -78.476  52.732  1
90701  94.178  -78.481  52.718  1
90702  94.186  -78.483  52.702  1
90703  94.208  -78.479  52.687  1
90704  94.230  -78.475  52.672  1
90705  94.248  -78.478  52.654  1
90706  94.265  -78.483  52.637  1
90707  94.281  -78.489  52.620  1
90708  94.297  -78.495  52.604  1
90709  94.314  -78.500  52.586  1
90710  94.334  -78.498  52.568  1
90711  94.357  -78.491  52.550  1
90712  94.377  -78.490  52.529  1
90713  94.386  -78.504  52.507  1
90714  94.396  -78.517  52.484  1
90715  94.406  -78.530  52.460  1
90716  94.416  -78.544  52.434  1
90717  94.425  -78.557  52.408  1
90718  94.438  -78.555  52.380  1
90719  94.452  -78.549  52.348  1
90720  94.466  -78.542  52.316  1
90721  94.479  -78.535  52.283  1
90722  94.493  -78.529  52.250  1
90723  94.506  -78.523  52.219  1
90724  94.521  -78.517  52.188  1
90725  94.534  -78.510  52.156  1
90726  94.552  -78.499  52.124  1
90727  94.566  -78.498  52.090  1
90728  94.582  -78.500  52.056  1
90729  94.599  -78.501  52.021  1
90730  94.616  -78.503  51.983  1
90731  94.632  -78.504  51.943  1
90732  94.648  -78.506  51.902  1
90733  94.659  -78.504  51.857  1
90734  94.669  -78.503  51.808  1
90735  94.679  -78.501  51.757  1
90736  94.690  -78.500  51.706  1
90737  94.702  -78.501  51.651  1
90738  94.718  -78.504  51.596  1
90739  94.734  -78.508  51.540  1
90740  94.749  -78.511  51.486  1
90741  94.765  -78.515  51.433  1
90742  94.779  -78.519  51.381  1
90743  94.794  -78.521  51.328  1
90744  94.813  -78.525  51.276  1
90745  94.816  -78.529  51.224  1
90746  94.820  -78.532  51.174  1
90747  94.829  -78.534  51.126  1
90748  94.839  -78.535  51.079  1
90749  94.849  -78.537  51.033  1
90750  94.859  -78.539  50.990  1
90751  94.868  -78.540  50.948  1
90752  94.878  -78.530  50.908  1
90753  94.888  -78.514  50.868  1
90754  94.898  -78.498  50.825  1
90755  94.908  -78.482  50.782  1
90756  94.918  -78.465  50.737  1
90757  94.929  -78.448  50.691  1
90758  94.943  -78.431  50.644  1
90759  94.957  -78.413  50.597  1
90760  94.971  -78.395  50.549  1
90761  94.985  -78.377  50.504  1
90762  95.000  -78.359  50.459  1
90763  95.014  -78.341  50.414  1
90764  95.031  -78.334  50.370  1
90765  95.052  -78.339  50.326  1
90766  95.072  -78.344  50.283  1
90767  95.093  -78.349  50.241  1
90768  95.113  -78.354  50.198  1
90769  95.133  -78.360  50.156  1
90770  95.154  -78.365  50.115  1
90771  95.174  -78.369  50.076  1
90772  95.195  -78.375  50.037  1
90773  95.215  -78.380  49.997  1
90774  95.236  -78.385  49.957  1
90775  95.256  -78.391  49.919  1
90776  95.278  -78.398  49.882  1
90777  95.298  -78.404  49.844  1
90778  95.322  -78.416  49.807  1
90779  95.345  -78.429  49.768  1
90780  95.370  -78.441  49.730  1
90781  95.393  -78.452  49.693  1
90782  95.417  -78.464  49.657  1
90783  95.442  -78.476  49.620  1
90784  95.465  -78.489  49.583  1
90785  95.489  -78.500  49.547  1
90786  95.513  -78.512  49.512  1
90787  95.537  -78.524  49.476  1
90788  95.561  -78.535  49.440  1
90789  95.585  -78.548  49.405  1
90790  95.593  -78.549  49.370  1
90791  95.598  -78.549  49.336  1
90792  95.603  -78.548  49.303  1
90793  95.609  -78.548  49.268  1
90794  95.614  -78.548  49.234  1
90795  95.619  -78.548  49.201  1
90796  95.624  -78.547  49.167  1
90797  95.629  -78.547  49.132  1
90798  95.634  -78.546  49.095  1
90799  95.639  -78.545  49.055  1
90800  95.644  -78.545  49.014  1
90801  95.649  -78.545  48.972  1
90802  95.640  -78.544  48.931  1
90803  95.614  -78.544  48.893  1
90804  95.587  -78.544  48.853  1
90805  95.561  -78.543  48.812  1
90806  95.534  -78.543  48.775  1
90807  95.508  -78.543  48.735  1
90808  95.532  -78.543  48.692  1
90809  95.557  -78.544  48.649  1
90810  95.582  -78.545  48.606  1
90811  95.607  -78.545  48.565  1
90812  95.626  -78.548  48.526  1
90813  95.641  -78.551  48.486  1
90814  95.656  -78.555  48.448  1
90815  95.671  -78.559  48.410  1
90816  95.686  -78.564  48.372  1
90817  95.701  -78.568  48.333  1
90818  95.716  -78.572  48.294  1
90819  95.740  -78.571  48.254  1
90820  95.763  -78.570  48.214  1
90821  95.787  -78.569  48.174  1
90822  95.809  -78.570  48.133  1
90823  95.830  -78.570  48.092  1
90824  95.852  -78.572  48.052  1
90825  95.874  -78.573  48.012  1
90826  95.896  -78.573  47.972  1
90827  95.911  -78.573  47.933  1
90828  95.927  -78.573  47.892  1
90829  95.944  -78.573  47.851  1
90830  95.961  -78.571  47.810  1
90831  95.976  -78.568  47.773  1
90832  95.991  -78.564  47.735  1
90833  96.007  -78.561  47.697  1
90834  96.022  -78.558  47.659  1
90835  96.039  -78.571  47.620  1
90836  96.056  -78.588  47.581  1
90837  96.073  -78.604  47.542  1
90838  96.090  -78.622  47.502  1
90839  96.108  -78.639  47.463  1
90840  96.125  -78.656  47.424  1
90841  96.142  -78.673  47.384  1
90842  96.159  -78.689  47.346  1
90843  96.177  -78.707  47.308  1
90844  96.190  -78.720  47.272  1
90845  96.208  -78.738  47.236  1
90846  96.235  -78.742  47.202  1
90847  96.250  -78.745  47.169  1
90848  96.262  -78.749  47.138  1
90849  96.275  -78.752  47.107  1
90850  96.288  -78.756  47.076  1
90851  96.301  -78.759  47.044  1
90852  96.314  -78.762  47.014  1
90853  96.327  -78.766  46.985  1
90854  96.339  -78.769  46.955  1
90855  96.353  -78.772  46.925  1
90856  96.365  -78.776  46.897  1
90857  96.378  -78.779  46.868  1
90858  96.369  -78.765  46.839  1
90859  96.361  -78.738  46.811  1
90860  96.402  -78.739  46.784  1
90861  96.445  -78.742  46.758  1
90862  96.486  -78.743  46.732  1
90863  96.528  -78.745  46.707  1
90864  96.571  -78.746  46.684  1
90865  96.612  -78.748  46.662  1
90866  96.655  -78.749  46.642  1
90867  96.696  -78.751  46.622  1
90868  96.738  -78.752  46.602  1
90869  96.781  -78.754  46.581  1
90870  96.822  -78.754  46.558  1
90871  96.846  -78.761  46.535  1
90872  96.866  -78.771  46.513  1
90873  96.886  -78.781  46.492  1
90874  96.906  -78.792  46.472  1
90875  96.926  -78.802  46.451  1
90876  96.946  -78.812  46.429  1
90877  96.955  -78.822  46.406  1
90878  96.959  -78.829  46.383  1
90879  96.964  -78.835  46.363  1
90880  96.958  -78.847  46.347  1
90881  96.936  -78.869  46.332  1
90882  96.923  -78.890  46.317  1
90883  96.919  -78.905  46.301  1
90884  96.929  -78.919  46.283  1
90885  96.946  -78.930  46.264  1
90886  96.971  -78.935  46.244  1
90887  96.997  -78.940  46.226  1
90888  97.023  -78.946  46.208  1
90889  97.048  -78.951  46.190  1
90890  97.074  -78.956  46.174  1
90891  97.100  -78.962  46.157  1
90892  97.125  -78.967  46.142  1
90893  97.150  -78.971  46.127  1
90894  97.174  -78.976  46.114  1
90895  97.197  -78.981  46.101  1
90896  97.217  -78.989  46.089  1
90897  97.232  -78.999  46.074  1
90898  97.248  -79.011  46.060  1
90899  97.265  -79.021  46.046  1
90900  97.287  -79.032  46.031  1
90901  97.309  -79.043  46.016  1
90902  97.330  -79.053  46.000  1
90903  97.349  -79.059  45.981  1
90904  97.362  -79.059  45.959  1
90905  97.375  -79.059  45.937  1
90906  97.389  -79.058  45.915  1
90907  97.402  -79.058  45.895  1
90908  97.416  -79.058  45.879  1
90909  97.428  -79.056  45.864  1
90910  97.436  -79.054  45.849  1
90911  97.444  -79.052  45.834  1
90912  97.453  -79.049  45.817  1
90913  97.461  -79.047  45.800  1
90914  97.469  -79.045  45.783  1
90915  97.477  -79.043  45.768  1
90916  97.486  -79.040  45.752  1
90917  97.494  -79.038  45.736  1
90918  97.499  -79.060  45.720  1
90919  97.519  -79.076  45.703  1
90920  97.540  -79.089  45.685  1
90921  97.561  -79.103  45.669  1
90922  97.587  -79.124  45.651  1
90923  97.605  -79.142  45.632  1
90924  97.600  -79.141  45.613  1
90925  97.596  -79.140  45.593  1
90926  97.591  -79.140  45.573  1
90927  97.586  -79.140  45.554  1
90928  97.582  -79.139  45.536  1
90929  97.577  -79.139  45.520  1
90930  97.572  -79.138  45.504  1
90931  97.567  -79.137  45.489  1
90932  97.563  -79.137  45.473  1
90933  97.560  -79.137  45.457  1
90934  97.560  -79.136  45.442  1
90935  97.572  -79.149  45.429  1
90936  97.601  -79.171  45.415  1
90937  97.641  -79.194  45.403  1
90938  97.681  -79.218  45.391  1
90939  97.721  -79.242  45.382  1
90940  97.756  -79.263  45.372  1
90941  97.773  -79.271  45.361  1
90942  97.790  -79.279  45.352  1
90943  97.806  -79.288  45.341  1
90944  97.823  -79.296  45.331  1
90945  97.840  -79.305  45.321  1
90946  97.856  -79.313  45.312  1
90947  97.873  -79.322  45.305  1
90948  97.888  -79.332  45.297  1
90949  97.900  -79.347  45.288  1
90950  97.913  -79.363  45.280  1
90951  97.934  -79.374  45.273  1
90952  97.957  -79.384  45.266  1
90953  97.980  -79.394  45.258  1
90954  98.003  -79.404  45.251  1
90955  98.026  -79.413  45.242  1
90956  98.050  -79.422  45.233  1
90957  98.074  -79.429  45.224  1
90958  98.099  -79.437  45.214  1
90959  98.124  -79.440  45.204  1
90960  98.148  -79.436  45.195  1
90961  98.175  -79.432  45.185  1
90962  98.230  -79.427  45.175  1
90963  98.275  -79.425  45.166  1
90964  98.301  -79.428  45.157  1
90965  98.327  -79.432  45.149  1
90966  98.357  -79.440  45.142  1
90967  98.390  -79.452  45.134  1
90968  98.423  -79.463  45.127  1
90969  98.456  -79.476  45.121  1
90970  98.489  -79.487  45.115  1
90971  98.521  -79.499  45.109  1
90972  98.554  -79.510  45.103  1
90973  98.587  -79.523  45.098  1
90974  98.620  -79.534  45.092  1
90975  98.652  -79.546  45.086  1
90976  98.685  -79.558  45.080  1
90977  98.711  -79.573  45.073  1
90978  98.702  -79.601  45.066  1
90979  98.693  -79.630  45.059  1
90980  98.685  -79.659  45.052  1
90981  98.696  -79.659  45.043  1
90982  98.712  -79.657  45.035  1
90983  98.727  -79.657  45.026  1
90984  98.743  -79.655  45.019  1
90985  98.762  -79.645  45.011  1
90986  98.784  -79.629  45.002  1
90987  98.805  -79.643  44.992  1
90988  98.845  -79.645  44.981  1
90989  98.886  -79.646  44.969  1
90990  98.928  -79.647  44.957  1
90991  98.969  -79.648  44.945  1
90992  99.010  -79.649  44.933  1
90993  99.051  -79.650  44.922  1
90994  99.092  -79.651  44.911  1
90995  99.134  -79.652  44.900  1
90996  99.175  -79.653  44.890  1
90997  99.216  -79.654  44.880  1
90998  99.230  -79.664  44.871  1
90999  99.234  -79.679  44.860  1
91000  99.237  -79.693  44.849  1
91001  99.241  -79.708  44.839  1
91002  99.244  -79.722  44.829  1
91003  99.248  -79.736  44.819  1
91004  99.254  -79.750  44.809  1
91005  99.278  -79.756  44.799  1
91006  99.302  -79.762  44.788  1
91007  99.326  -79.768  44.778  1
91008  99.349  -79.775  44.769  1
91009  99.373  -79.781  44.759  1
91010  99.397  -79.787  44.749  1
91011  99.418  -79.790  44.739  1
91012  99.433  -79.785  44.730  1
91013  99.448  -79.779  44.720  1
91014  99.464  -79.773  44.710  1
91015  99.479  -79.767  44.702  1
91016  99.494  -79.761  44.694  1
91017  99.509  -79.755  44.685  1
91018  99.524  -79.750  44.678  1
91019  99.539  -79.745  44.671  1
91020  99.537  -79.773  44.665  1
91021  99.536  -79.801  44.658  1
91022  99.535  -79.829  44.651  1
91023  99.534  -79.857  44.642  1
91024  99.533  -79.885  44.634  1
91025  99.531  -79.913  44.625  1
91026  99.538  -79.939  44.617  1
91027  99.557  -79.965  44.610  1
91028  99.577  -79.989  44.603  1
91029  99.596  -80.013  44.597  1
91030  99.616  -80.038  44.589  1
91031  99.636  -80.062  44.583  1
91032  99.655  -80.087  44.576  1
91033  99.675  -80.112  44.569  1
91034  99.695  -80.137  44.562  1
91035  99.728  -80.173  44.553  1
91036  99.766  -80.214  44.545  1
91037  99.796  -80.250  44.535  1
91038  99.820  -80.284  44.526  1
91039  99.843  -80.316  44.517  1
91040  99.870  -80.343  44.506  1
91041  99.922  -80.350  44.495  1
91042  99.975  -80.358  44.484  1
91043  100.021  -80.363  44.472  1
91044  100.042  -80.411  44.459  1
91045  100.085  -80.428  44.447  1
91046  100.130  -80.445  44.434  1
91047  100.174  -80.461  44.420  1
91048  100.219  -80.478  44.406  1
91049  100.264  -80.494  44.391  1
91050  100.308  -80.510  44.377  1
91051  100.353  -80.526  44.362  1
91052  100.397  -80.543  44.348  1
91053  100.442  -80.560  44.333  1
91054  100.486  -80.576  44.317  1
91055  100.531  -80.592  44.302  1
91056  100.575  -80.608  44.287  1
91057  100.620  -80.625  44.272  1
91058  100.665  -80.641  44.258  1
91059  100.709  -80.657  44.243  1
91060  100.754  -80.674  44.229  1
91061  100.798  -80.690  44.215  1
91062  100.843  -80.707  44.201  1
91063  100.888  -80.723  44.187  1
91345  93.588  -78.654  53.641  1
91346  93.598  -78.651  53.628  1
91347  93.603  -78.646  53.614  1
91348  93.602  -78.637  53.601  1
91349  93.600  -78.627  53.588  1
91350  93.599  -78.618  53.575  1
91351  93.597  -78.609  53.563  1
91352  93.596  -78.600  53.550  1
91353  93.608  -78.586  53.537  1
91354  93.630  -78.571  53.524  1
91355  93.652  -78.556  53.511  1
91356  93.675  -78.541  53.496  1
91357  93.694  -78.528  53.481  1
91358  93.709  -78.520  53.464  1
91359  93.724  -78.513  53.446  1
91360  93.740  -78.505  53.428  1
91361  93.755  -78.498  53.410  1
91362  93.769  -78.494  53.392  1
91363  93.784  -78.489  53.373  1
91364  93.798  -78.483  53.353  1
91365  93.813  -78.478  53.333  1
91366  93.828  -78.473  53.314  1
91367  93.843  -78.467  53.295  1
91368  93.841  -78.451  53.276  1
91369  93.840  -78.433  53.257  1
91370  93.838  -78.416  53.237  1
91371  93.837  -78.399  53.219  1
91372  93.835  -78.382  53.200  1
91373  93.833  -78.365  53.183  1
91374  93.832  -78.347  53.165  1
91375  93.858  -78.334  53.148  1
91376  93.894  -78.322  53.130  1
91377  93.907  -78.331  53.112  1
91378  93.920  -78.339  53.095  1
91379  93.934  -78.348  53.080  1
91380  93.947  -78.357  53.066  1
91381  93.969  -78.366  53.051  1
91382  93.996  -78.378  53.034  1
91383  94.024  -78.388  53.017  1
91384  94.022  -78.401  52.999  1
91385  94.030  -78.408  52.978  1
91386  94.042  -78.413  52.959  1
91387  94.054  -78.419  52.940  1
91388  94.065  -78.424  52.922  1
91389  94.077  -78.429  52.909  1
91390  94.088  -78.432  52.896  1
91391  94.101  -78.432  52.882  1
91392  94.114  -78.430  52.868  1
91393  94.127  -78.429  52.855  1
91394  94.140  -78.428  52.842  1
91395  94.153  -78.427  52.831  1
91396  94.158  -78.434  52.817  1
91397  94.159  -78.446  52.803  1
91398  94.159  -78.457  52.790  1
91399  94.164  -78.462  52.773  1
91400  94.168  -78.467  52.758  1
91401  94.172  -78.470  52.743  1
91402  94.176  -78.475  52.729  1
91403  94.181  -78.479  52.714  1
91404  94.202  -78.475  52.699  1
91405  94.224  -78.470  52.684  1
91406  94.247  -78.467  52.667  1
91407  94.265  -78.469  52.650  1
91408  94.281  -78.474  52.634  1
91409  94.297  -78.480  52.618  1
91410  94.315  -78.485  52.601  1
91411  94.337  -78.478  52.584  1
91412  94.355  -78.479  52.567  1
91413  94.365  -78.492  52.545  1
91414  94.375  -78.506  52.521  1
91415  94.385  -78.519  52.497  1
91416  94.395  -78.532  52.472  1
91417  94.405  -78.546  52.445  1
91418  94.414  -78.559  52.417  1
91419  94.427  -78.559  52.388  1
91420  94.440  -78.552  52.358  1
91421  94.454  -78.546  52.327  1
91422  94.468  -78.539  52.295  1
91423  94.482  -78.533  52.262  1
91424  94.495  -78.526  52.230  1
91425  94.509  -78.520  52.198  1
91426  94.533  -78.504  52.166  1
91427  94.557  -78.488  52.132  1
91428  94.569  -78.482  52.098  1
91429  94.581  -78.484  52.063  1
91430  94.595  -78.486  52.028  1
91431  94.611  -78.488  51.990  1
91432  94.627  -78.489  51.950  1
91433  94.644  -78.491  51.907  1
91434  94.661  -78.492  51.860  1
91435  94.671  -78.491  51.811  1
91436  94.681  -78.489  51.761  1
91437  94.691  -78.488  51.709  1
91438  94.703  -78.488  51.655  1
91439  94.719  -78.492  51.600  1
91440  94.735  -78.495  51.545  1
91441  94.750  -78.499  51.490  1
91442  94.766  -78.502  51.437  1
91443  94.781  -78.506  51.385  1
91444  94.797  -78.510  51.334  1
91445  94.808  -78.511  51.282  1
91446  94.818  -78.513  51.231  1
91447  94.827  -78.514  51.181  1
91448  94.837  -78.516  51.133  1
91449  94.847  -78.517  51.087  1
91450  94.856  -78.519  51.042  1
91451  94.866  -78.520  51.000  1
91452  94.876  -78.514  50.958  1
91453  94.886  -78.498  50.918  1
91454  94.896  -78.482  50.878  1
91455  94.906  -78.466  50.835  1
91456  94.915  -78.449  50.790  1
91457  94.925  -78.433  50.744  1
91458  94.935  -78.416  50.696  1
91459  94.948  -78.400  50.648  1
91460  94.962  -78.382  50.599  1
91461  94.976  -78.363  50.550  1
91462  94.990  -78.346  50.503  1
91463  95.005  -78.328  50.457  1
91464  95.019  -78.310  50.413  1
91465  95.039  -78.313  50.369  1
91466  95.060  -78.319  50.325  1
91467  95.080  -78.324  50.282  1
91468  95.101  -78.329  50.240  1
91469  95.121  -78.335  50.198  1
91470  95.141  -78.339  50.157  1
91471  95.162  -78.344  50.117  1
91472  95.182  -78.350  50.079  1
91473  95.203  -78.355  50.040  1
91474  95.223  -78.360  50.000  1
91475  95.260  -78.390  49.959  1
91476  95.274  -78.383  49.921  1
91477  95.284  -78.374  49.883  1
91478  95.294  -78.376  49.845  1
91479  95.313  -78.385  49.808  1
91480  95.336  -78.398  49.771  1
91481  95.360  -78.409  49.734  1
91482  95.384  -78.421  49.697  1
91483  95.408  -78.433  49.662  1
91484  95.432  -78.445  49.625  1
91485  95.456  -78.457  49.588  1
91486  95.480  -78.469  49.552  1
91487  95.504  -78.481  49.516  1
91488  95.528  -78.493  49.480  1
91489  95.552  -78.504  49.444  1
91490  95.576  -78.517  49.409  1
91491  95.584  -78.518  49.375  1
91492  95.589  -78.517  49.341  1
91493  95.595  -78.517  49.308  1
91494  95.600  -78.517  49.275  1
91495  95.605  -78.517  49.242  1
91496  95.610  -78.516  49.208  1
91497  95.615  -78.516  49.175  1
91498  95.620  -78.515  49.140  1
91499  95.625  -78.515  49.103  1
91500  95.630  -78.514  49.064  1
91501  95.635  -78.514  49.024  1
91502  95.641  -78.515  48.984  1
91503  95.650  -78.522  48.944  1
91504  95.645  -78.518  48.905  1
91505  95.620  -78.518  48.866  1
91506  95.594  -78.517  48.827  1
91507  95.567  -78.517  48.788  1
91508  95.541  -78.517  48.747  1
91509  95.535  -78.517  48.705  1
91510  95.560  -78.518  48.661  1
91511  95.585  -78.519  48.619  1
91512  95.610  -78.519  48.578  1
91513  95.627  -78.522  48.538  1
91514  95.642  -78.526  48.498  1
91515  95.658  -78.529  48.459  1
91516  95.673  -78.533  48.421  1
91517  95.687  -78.538  48.382  1
91518  95.702  -78.542  48.344  1
91519  95.721  -78.544  48.304  1
91520  95.744  -78.543  48.265  1
91521  95.767  -78.543  48.226  1
91522  95.789  -78.547  48.186  1
91523  95.810  -78.546  48.145  1
91524  95.832  -78.547  48.103  1
91525  95.853  -78.548  48.061  1
91526  95.876  -78.548  48.020  1
91527  95.895  -78.549  47.980  1
91528  95.907  -78.548  47.940  1
91529  95.923  -78.549  47.899  1
91530  95.939  -78.549  47.858  1
91531  95.955  -78.549  47.818  1
91532  95.971  -78.551  47.781  1
91533  95.987  -78.548  47.743  1
91534  96.004  -78.546  47.704  1
91535  96.020  -78.544  47.666  1
91536  96.032  -78.543  47.627  1
91537  96.049  -78.557  47.588  1
91538  96.066  -78.575  47.550  1
91539  96.084  -78.592  47.511  1
91540  96.101  -78.609  47.472  1
91541  96.118  -78.626  47.433  1
91542  96.135  -78.642  47.393  1
91543  96.152  -78.659  47.355  1
91544  96.164  -78.670  47.319  1
91545  96.174  -78.695  47.283  1
91546  96.192  -78.713  47.249  1
91547  96.219  -78.717  47.217  1
91548  96.245  -78.721  47.185  1
91549  96.272  -78.726  47.156  1
91550  96.287  -78.729  47.125  1
91551  96.300  -78.733  47.094  1
91552  96.313  -78.736  47.061  1
91553  96.326  -78.739  47.032  1
91554  96.338  -78.742  47.003  1
91555  96.352  -78.745  46.974  1
91556  96.364  -78.749  46.945  1
91557  96.377  -78.752  46.916  1
91558  96.390  -78.755  46.887  1
91559  96.382  -78.742  46.858  1
91560  96.344  -78.698  46.829  1
91561  96.386  -78.701  46.802  1
91562  96.428  -78.702  46.776  1
91563  96.470  -78.704  46.750  1
91564  96.512  -78.705  46.724  1
91565  96.554  -78.707  46.701  1
91566  96.596  -78.708  46.679  1
91567  96.638  -78.710  46.658  1
91568  96.680  -78.711  46.638  1
91569  96.726  -78.717  46.618  1
91570  96.774  -78.727  46.596  1
91571  96.822  -78.737  46.574  1
91572  96.834  -78.748  46.552  1
91573  96.855  -78.758  46.529  1
91574  96.875  -78.769  46.509  1
91575  96.895  -78.780  46.489  1
91576  96.916  -78.790  46.468  1
91577  96.936  -78.801  46.445  1
91578  96.938  -78.819  46.421  1
91579  96.938  -78.837  46.397  1
91580  96.944  -78.843  46.377  1
91581  96.933  -78.845  46.360  1
91582  96.928  -78.861  46.344  1
91583  96.924  -78.877  46.329  1
91584  96.920  -78.893  46.311  1
91585  96.926  -78.906  46.293  1
91586  96.944  -78.917  46.274  1
91587  96.969  -78.922  46.255  1
91588  96.995  -78.927  46.237  1
91589  97.021  -78.933  46.220  1
91590  97.046  -78.938  46.202  1
91591  97.072  -78.943  46.186  1
91592  97.098  -78.949  46.171  1
91593  97.123  -78.954  46.156  1
91594  97.149  -78.959  46.141  1
91595  97.175  -78.965  46.128  1
91596  97.201  -78.970  46.116  1
91597  97.224  -78.979  46.103  1
91598  97.246  -78.990  46.088  1
91599  97.267  -78.999  46.073  1
91600  97.289  -79.010  46.058  1
91601  97.311  -79.021  46.043  1
91602  97.332  -79.031  46.028  1
91603  97.354  -79.042  46.012  1
91604  97.372  -79.048  45.993  1
91605  97.386  -79.047  45.971  1
91606  97.399  -79.047  45.950  1
91607  97.410  -79.046  45.929  1
91608  97.419  -79.043  45.908  1
91609  97.427  -79.041  45.891  1
91610  97.435  -79.039  45.876  1
91611  97.443  -79.037  45.862  1
91612  97.452  -79.034  45.848  1
91613  97.460  -79.032  45.832  1
91614  97.468  -79.030  45.816  1
91615  97.476  -79.028  45.800  1
91616  97.485  -79.025  45.786  1
91617  97.493  -79.023  45.770  1
91618  97.501  -79.020  45.752  1
91619  97.509  -79.024  45.737  1
91620  97.518  -79.061  45.721  1
91621  97.539  -79.075  45.705  1
91622  97.560  -79.087  45.690  1
91623  97.589  -79.113  45.671  1
91624  97.603  -79.128  45.651  1
91625  97.598  -79.128  45.629  1
91626  97.593  -79.127  45.606  1
91627  97.589  -79.126  45.586  1
91628  97.584  -79.126  45.567  1
91629  97.579  -79.125  45.549  1
91630  97.574  -79.125  45.533  1
91631  97.570  -79.124  45.517  1
91632  97.565  -79.124  45.500  1
91633  97.560  -79.123  45.484  1
91634  97.556  -79.122  45.469  1
91635  97.551  -79.122  45.454  1
91636  97.573  -79.137  45.440  1
91637  97.613  -79.161  45.427  1
91638  97.653  -79.184  45.414  1
91639  97.692  -79.208  45.402  1
91640  97.732  -79.232  45.394  1
91641  97.756  -79.245  45.383  1
91642  97.773  -79.253  45.372  1
91643  97.790  -79.262  45.360  1
91644  97.806  -79.270  45.350  1
91645  97.823  -79.278  45.340  1
91646  97.840  -79.287  45.330  1
91647  97.856  -79.296  45.321  1
91648  97.873  -79.304  45.313  1
91649  97.889  -79.313  45.305  1
91650  97.901  -79.328  45.296  1
91651  97.918  -79.342  45.289  1
91652  97.941  -79.352  45.282  1
91653  97.964  -79.362  45.275  1
91654  97.987  -79.372  45.269  1
91655  98.010  -79.382  45.262  1
91656  98.033  -79.391  45.254  1
91657  98.057  -79.400  45.246  1
91658  98.082  -79.407  45.237  1
91659  98.106  -79.415  45.227  1
91660  98.131  -79.411  45.217  1
91661  98.155  -79.407  45.208  1
91662  98.187  -79.403  45.198  1
91663  98.242  -79.397  45.188  1
91664  98.275  -79.399  45.178  1
91665  98.301  -79.402  45.170  1
91666  98.327  -79.406  45.162  1
91667  98.356  -79.412  45.155  1
91668  98.388  -79.424  45.147  1
91669  98.421  -79.435  45.140  1
91670  98.454  -79.447  45.134  1
91671  98.487  -79.459  45.128  1
91672  98.519  -79.471  45.123  1
91673  98.552  -79.483  45.118  1
91674  98.585  -79.494  45.113  1
91675  98.618  -79.507  45.105  1
91676  98.650  -79.518  45.099  1
91677  98.684  -79.530  45.094  1
91678  98.720  -79.542  45.087  1
91679  98.726  -79.546  45.080  1
91680  98.727  -79.548  45.073  1
91681  98.699  -79.616  45.067  1
91682  98.693  -79.645  45.058  1
91683  98.715  -79.629  45.048  1
91684  98.736  -79.612  45.038  1
91685  98.758  -79.595  45.030  1
91686  98.779  -79.591  45.021  1
91687  98.801  -79.607  45.012  1
91688  98.823  -79.622  45.002  1
91689  98.858  -79.628  44.989  1
91690  98.899  -79.629  44.978  1
91691  98.940  -79.630  44.966  1
91692  98.982  -79.631  44.953  1
91693  99.023  -79.632  44.943  1
91694  99.064  -79.633  44.932  1
91695  99.105  -79.634  44.921  1
91696  99.146  -79.635  44.911  1
91697  99.188  -79.636  44.902  1
91698  99.215  -79.636  44.891  1
91699  99.229  -79.648  44.880  1
91700  99.243  -79.663  44.869  1
91701  99.248  -79.677  44.859  1
91702  99.251  -79.692  44.849  1
91703  99.255  -79.706  44.838  1
91704  99.258  -79.720  44.828  1
91705  99.262  -79.735  44.818  1
91706  99.282  -79.742  44.807  1
91707  99.305  -79.748  44.796  1
91708  99.329  -79.755  44.786  1
91709  99.353  -79.761  44.777  1
91710  99.377  -79.767  44.766  1
91711  99.400  -79.773  44.756  1
91712  99.415  -79.767  44.746  1
91713  99.430  -79.761  44.736  1
91714  99.445  -79.755  44.727  1
91715  99.461  -79.749  44.718  1
91716  99.476  -79.744  44.709  1
91717  99.491  -79.738  44.700  1
91718  99.506  -79.732  44.691  1
91719  99.521  -79.726  44.682  1
91720  99.534  -79.724  44.677  1
91721  99.533  -79.752  44.669  1
91722  99.532  -79.780  44.661  1
91723  99.530  -79.808  44.655  1
91724  99.529  -79.836  44.646  1
91725  99.527  -79.864  44.638  1
91726  99.540  -79.890  44.630  1
91727  99.559  -79.915  44.624  1
91728  99.579  -79.939  44.617  1
91729  99.598  -79.964  44.610  1
91730  99.618  -79.989  44.603  1
91731  99.638  -80.013  44.595  1
91732  99.657  -80.038  44.588  1
91733  99.677  -80.062  44.582  1
91734  99.697  -80.087  44.575  1
91735  99.716  -80.112  44.568  1
91736  99.751  -80.149  44.560  1
91737  99.789  -80.190  44.551  1
91738  99.815  -80.225  44.541  1
91739  99.838  -80.257  44.532  1
91740  99.861  -80.290  44.523  1
91741  99.887  -80.321  44.512  1
91742  99.922  -80.347  44.501  1
91743  99.976  -80.355  44.490  1
91744  100.028  -80.363  44.478  1
91745  100.075  -80.364  44.465  1
91746  100.096  -80.412  44.453  1
91747  100.132  -80.439  44.439  1
91748  100.177  -80.455  44.425  1
91749  100.221  -80.472  44.411  1
91750  100.266  -80.488  44.397  1
91751  100.311  -80.504  44.382  1
91752  100.355  -80.521  44.367  1
91753  100.400  -80.537  44.352  1
91754  100.444  -80.554  44.337  1
91755  100.489  -80.569  44.321  1
91756  100.533  -80.586  44.305  1
91757  100.578  -80.603  44.290  1
91758  100.622  -80.619  44.275  1
91759  100.667  -80.635  44.260  1
91760  100.711  -80.651  44.245  1
91761  100.756  -80.668  44.231  1
91762  100.800  -80.685  44.217  1
91763  100.845  -80.701  44.202  1
91764  100.890  -80.717  44.188  1
91765  100.933  -80.735  44.175  1
91766  100.974  -80.757  44.161  1
91767  101.014  -80.779  44.147  1
92046  93.588  -78.643  53.644  1
92047  93.598  -78.640  53.631  1
92048  93.600  -78.633  53.617  1
92049  93.598  -78.623  53.603  1
92050  93.596  -78.614  53.590  1
92051  93.595  -78.605  53.575  1
92052  93.594  -78.596  53.562  1
92053  93.595  -78.586  53.548  1
92054  93.613  -78.570  53.534  1
92055  93.635  -78.555  53.520  1
92056  93.658  -78.540  53.505  1
92057  93.680  -78.525  53.490  1
92058  93.696  -78.514  53.474  1
92059  93.711  -78.507  53.456  1
92060  93.726  -78.500  53.439  1
92061  93.742  -78.492  53.421  1
92062  93.757  -78.485  53.403  1
92063  93.772  -78.478  53.385  1
92064  93.787  -78.473  53.366  1
92065  93.801  -78.468  53.347  1
92066  93.816  -78.463  53.327  1
92067  93.831  -78.457  53.308  1
92068  93.845  -78.452  53.288  1
92069  93.853  -78.442  53.269  1
92070  93.852  -78.425  53.250  1
92071  93.850  -78.407  53.232  1
92072  93.849  -78.391  53.212  1
92073  93.847  -78.373  53.193  1
92074  93.845  -78.357  53.175  1
92075  93.844  -78.339  53.158  1
92076  93.873  -78.326  53.140  1
92077  93.903  -78.319  53.123  1
92078  93.917  -78.328  53.106  1
92079  93.930  -78.337  53.089  1
92080  93.944  -78.345  53.073  1
92081  93.957  -78.354  53.059  1
92082  93.971  -78.363  53.045  1
92083  93.984  -78.371  53.028  1
92084  94.007  -78.381  53.011  1
92085  94.024  -78.393  52.994  1
92086  94.032  -78.400  52.974  1
92087  94.044  -78.405  52.956  1
92088  94.055  -78.410  52.938  1
92089  94.067  -78.415  52.923  1
92090  94.079  -78.420  52.909  1
92091  94.089  -78.425  52.896  1
92092  94.099  -78.429  52.883  1
92093  94.111  -78.430  52.871  1
92094  94.124  -78.429  52.859  1
92095  94.136  -78.428  52.848  1
92096  94.149  -78.426  52.837  1
92097  94.152  -78.436  52.825  1
92098  94.153  -78.448  52.813  1
92099  94.157  -78.452  52.800  1
92100  94.161  -78.456  52.784  1
92101  94.165  -78.460  52.769  1
92102  94.169  -78.464  52.754  1
92103  94.173  -78.469  52.739  1
92104  94.178  -78.473  52.725  1
92105  94.197  -78.470  52.710  1
92106  94.219  -78.466  52.695  1
92107  94.241  -78.462  52.679  1
92108  94.263  -78.458  52.664  1
92109  94.281  -78.460  52.649  1
92110  94.298  -78.466  52.633  1
92111  94.318  -78.466  52.616  1
92112  94.334  -78.468  52.599  1
92113  94.344  -78.482  52.581  1
92114  94.354  -78.495  52.558  1
92115  94.364  -78.508  52.534  1
92116  94.373  -78.521  52.508  1
92117  94.384  -78.535  52.481  1
92118  94.394  -78.548  52.453  1
92119  94.403  -78.561  52.425  1
92120  94.415  -78.562  52.397  1
92121  94.429  -78.556  52.368  1
92122  94.443  -78.549  52.336  1
92123  94.457  -78.543  52.303  1
92124  94.470  -78.536  52.268  1
92125  94.488  -78.526  52.236  1
92126  94.512  -78.510  52.203  1
92127  94.537  -78.493  52.171  1
92128  94.561  -78.476  52.137  1
92129  94.574  -78.469  52.101  1
92130  94.585  -78.468  52.066  1
92131  94.598  -78.470  52.030  1
92132  94.610  -78.472  51.992  1
92133  94.623  -78.474  51.952  1
92134  94.639  -78.476  51.909  1
92135  94.655  -78.477  51.862  1
92136  94.672  -78.479  51.814  1
92137  94.683  -78.477  51.764  1
92138  94.693  -78.476  51.713  1
92139  94.704  -78.475  51.659  1
92140  94.720  -78.479  51.603  1
92141  94.736  -78.482  51.548  1
92142  94.751  -78.486  51.494  1
92143  94.767  -78.490  51.442  1
92144  94.784  -78.489  51.390  1
92145  94.802  -78.483  51.339  1
92146  94.816  -78.493  51.288  1
92147  94.825  -78.495  51.237  1
92148  94.835  -78.496  51.188  1
92149  94.845  -78.498  51.140  1
92150  94.854  -78.499  51.095  1
92151  94.864  -78.501  51.052  1
92152  94.874  -78.498  51.011  1
92153  94.884  -78.482  50.970  1
92154  94.894  -78.466  50.929  1
92155  94.903  -78.450  50.889  1
92156  94.913  -78.433  50.844  1
92157  94.923  -78.417  50.798  1
92158  94.933  -78.401  50.750  1
92159  94.943  -78.385  50.701  1
92160  94.954  -78.368  50.650  1
92161  94.967  -78.351  50.600  1
92162  94.981  -78.332  50.550  1
92163  94.995  -78.315  50.502  1
92164  95.010  -78.297  50.456  1
92165  95.027  -78.288  50.412  1
92166  95.047  -78.294  50.367  1
92167  95.067  -78.299  50.324  1
92168  95.088  -78.304  50.281  1
92169  95.109  -78.309  50.239  1
92170  95.129  -78.314  50.197  1
92171  95.149  -78.319  50.158  1
92172  95.170  -78.325  50.119  1
92173  95.191  -78.331  50.082  1
92174  95.239  -78.376  50.042  1
92175  95.259  -78.380  50.001  1
92176  95.269  -78.369  49.960  1
92177  95.280  -78.357  49.921  1
92178  95.290  -78.352  49.883  1
92179  95.300  -78.354  49.846  1
92180  95.309  -78.357  49.808  1
92181  95.327  -78.366  49.773  1
92182  95.351  -78.378  49.738  1
92183  95.375  -78.390  49.703  1
92184  95.399  -78.402  49.667  1
92185  95.423  -78.413  49.630  1
92186  95.447  -78.426  49.592  1
92187  95.471  -78.438  49.556  1
92188  95.495  -78.450  49.520  1
92189  95.519  -78.461  49.484  1
92190  95.543  -78.473  49.448  1
92191  95.567  -78.485  49.414  1
92192  95.576  -78.487  49.379  1
92193  95.581  -78.486  49.345  1
92194  95.586  -78.486  49.313  1
92195  95.591  -78.485  49.282  1
92196  95.596  -78.485  49.250  1
92197  95.601  -78.485  49.216  1
92198  95.606  -78.485  49.182  1
92199  95.611  -78.484  49.147  1
92200  95.616  -78.484  49.110  1
92201  95.621  -78.483  49.072  1
92202  95.627  -78.484  49.034  1
92203  95.636  -78.492  48.996  1
92204  95.645  -78.498  48.956  1
92205  95.644  -78.498  48.918  1
92206  95.640  -78.494  48.880  1
92207  95.627  -78.492  48.841  1
92208  95.601  -78.492  48.802  1
92209  95.574  -78.492  48.761  1
92210  95.547  -78.492  48.718  1
92211  95.563  -78.492  48.675  1
92212  95.588  -78.492  48.633  1
92213  95.613  -78.493  48.592  1
92214  95.629  -78.497  48.552  1
92215  95.644  -78.500  48.511  1
92216  95.659  -78.504  48.472  1
92217  95.674  -78.507  48.433  1
92218  95.689  -78.511  48.394  1
92219  95.704  -78.516  48.356  1
92220  95.726  -78.516  48.317  1
92221  95.749  -78.517  48.278  1
92222  95.770  -78.521  48.239  1
92223  95.792  -78.525  48.198  1
92224  95.812  -78.523  48.157  1
92225  95.833  -78.523  48.115  1
92226  95.854  -78.523  48.072  1
92227  95.877  -78.524  48.031  1
92228  95.893  -78.525  47.990  1
92229  95.903  -78.524  47.949  1
92230  95.919  -78.524  47.908  1
92231  95.935  -78.524  47.868  1
92232  95.950  -78.526  47.828  1
92233  95.967  -78.529  47.789  1
92234  95.985  -78.533  47.750  1
92235  96.002  -78.532  47.711  1
92236  96.018  -78.529  47.672  1
92237  96.031  -78.529  47.633  1
92238  96.042  -78.529  47.595  1
92239  96.059  -78.545  47.558  1
92240  96.077  -78.562  47.519  1
92241  96.094  -78.579  47.481  1
92242  96.111  -78.595  47.442  1
92243  96.126  -78.609  47.404  1
92244  96.137  -78.620  47.368  1
92245  96.149  -78.636  47.332  1
92246  96.158  -78.670  47.296  1
92247  96.176  -78.688  47.264  1
92248  96.202  -78.692  47.233  1
92249  96.229  -78.696  47.203  1
92250  96.256  -78.701  47.174  1
92251  96.282  -78.705  47.144  1
92252  96.309  -78.709  47.112  1
92253  96.325  -78.712  47.081  1
92254  96.338  -78.716  47.052  1
92255  96.350  -78.719  47.023  1
92256  96.364  -78.722  46.994  1
92257  96.376  -78.726  46.965  1
92258  96.389  -78.729  46.936  1
92259  96.402  -78.733  46.907  1
92260  96.394  -78.718  46.877  1
92261  96.335  -78.664  46.849  1
92262  96.370  -78.661  46.822  1
92263  96.411  -78.663  46.795  1
92264  96.453  -78.664  46.768  1
92265  96.496  -78.666  46.742  1
92266  96.537  -78.667  46.717  1
92267  96.584  -78.675  46.695  1
92268  96.633  -78.685  46.673  1
92269  96.682  -78.695  46.652  1
92270  96.732  -78.705  46.632  1
92271  96.781  -78.714  46.610  1
92272  96.812  -78.724  46.589  1
92273  96.821  -78.736  46.568  1
92274  96.841  -78.746  46.545  1
92275  96.862  -78.757  46.525  1
92276  96.882  -78.767  46.505  1
92277  96.903  -78.777  46.484  1
92278  96.918  -78.790  46.460  1
92279  96.918  -78.808  46.436  1
92280  96.919  -78.827  46.412  1
92281  96.919  -78.846  46.391  1
92282  96.930  -78.855  46.374  1
92283  96.930  -78.847  46.357  1
92284  96.926  -78.863  46.340  1
92285  96.921  -78.879  46.322  1
92286  96.924  -78.894  46.303  1
92287  96.942  -78.904  46.284  1
92288  96.968  -78.909  46.266  1
92289  96.994  -78.915  46.249  1
92290  97.019  -78.920  46.232  1
92291  97.045  -78.925  46.216  1
92292  97.071  -78.930  46.200  1
92293  97.096  -78.936  46.186  1
92294  97.122  -78.941  46.170  1
92295  97.148  -78.946  46.154  1
92296  97.176  -78.956  46.142  1
92297  97.205  -78.967  46.130  1
92298  97.239  -78.982  46.117  1
92299  97.262  -78.990  46.101  1
92300  97.285  -78.999  46.086  1
92301  97.308  -79.008  46.070  1
92302  97.331  -79.016  46.054  1
92303  97.354  -79.024  46.039  1
92304  97.376  -79.033  46.023  1
92305  97.393  -79.035  46.004  1
92306  97.401  -79.033  45.981  1
92307  97.409  -79.031  45.961  1
92308  97.418  -79.028  45.941  1
92309  97.426  -79.026  45.921  1
92310  97.434  -79.024  45.905  1
92311  97.442  -79.021  45.890  1
92312  97.451  -79.019  45.875  1
92313  97.459  -79.017  45.862  1
92314  97.467  -79.015  45.846  1
92315  97.475  -79.012  45.830  1
92316  97.484  -79.009  45.814  1
92317  97.492  -79.007  45.802  1
92318  97.500  -79.005  45.787  1
92319  97.509  -79.002  45.771  1
92320  97.517  -79.000  45.756  1
92321  97.519  -79.040  45.742  1
92322  97.538  -79.059  45.726  1
92323  97.561  -79.075  45.708  1
92324  97.590  -79.103  45.690  1
92325  97.601  -79.114  45.669  1
92326  97.596  -79.113  45.644  1
92327  97.591  -79.113  45.621  1
92328  97.586  -79.112  45.601  1
92329  97.582  -79.112  45.581  1
92330  97.577  -79.112  45.563  1
92331  97.572  -79.111  45.547  1
92332  97.567  -79.110  45.531  1
92333  97.563  -79.109  45.515  1
92334  97.558  -79.109  45.497  1
92335  97.560  -79.106  45.481  1
92336  97.565  -79.106  45.466  1
92337  97.601  -79.129  45.452  1
92338  97.637  -79.153  45.438  1
92339  97.672  -79.175  45.425  1
92340  97.708  -79.199  45.414  1
92341  97.739  -79.219  45.404  1
92342  97.756  -79.227  45.393  1
92343  97.773  -79.236  45.382  1
92344  97.790  -79.244  45.369  1
92345  97.806  -79.253  45.359  1
92346  97.823  -79.261  45.349  1
92347  97.840  -79.269  45.339  1
92348  97.857  -79.278  45.330  1
92349  97.873  -79.287  45.322  1
92350  97.890  -79.295  45.314  1
92351  97.902  -79.310  45.305  1
92352  97.925  -79.319  45.299  1
92353  97.948  -79.330  45.292  1
92354  97.971  -79.340  45.285  1
92355  97.995  -79.350  45.279  1
92356  98.017  -79.360  45.272  1
92357  98.040  -79.369  45.265  1
92358  98.064  -79.379  45.258  1
92359  98.089  -79.385  45.249  1
92360  98.113  -79.387  45.240  1
92361  98.138  -79.382  45.230  1
92362  98.162  -79.378  45.220  1
92363  98.199  -79.373  45.210  1
92364  98.249  -79.370  45.200  1
92365  98.275  -79.373  45.191  1
92366  98.301  -79.376  45.184  1
92367  98.327  -79.380  45.176  1
92368  98.354  -79.384  45.168  1
92369  98.386  -79.396  45.160  1
92370  98.420  -79.407  45.153  1
92371  98.452  -79.419  45.146  1
92372  98.485  -79.432  45.141  1
92373  98.518  -79.443  45.136  1
92374  98.551  -79.455  45.132  1
92375  98.583  -79.466  45.127  1
92376  98.616  -79.479  45.118  1
92377  98.649  -79.490  45.111  1
92378  98.685  -79.503  45.105  1
92379  98.722  -79.515  45.098  1
92380  98.740  -79.522  45.090  1
92381  98.740  -79.524  45.082  1
92382  98.741  -79.526  45.076  1
92383  98.741  -79.529  45.068  1
92384  98.731  -79.562  45.058  1
92385  98.753  -79.545  45.047  1
92386  98.775  -79.554  45.036  1
92387  98.797  -79.570  45.026  1
92388  98.819  -79.585  45.017  1
92389  98.841  -79.601  45.009  1
92390  98.870  -79.611  44.998  1
92391  98.912  -79.612  44.987  1
92392  98.953  -79.613  44.976  1
92393  98.994  -79.614  44.963  1
92394  99.035  -79.615  44.953  1
92395  99.076  -79.616  44.942  1
92396  99.118  -79.617  44.931  1
92397  99.159  -79.618  44.922  1
92398  99.201  -79.614  44.912  1
92399  99.211  -79.620  44.901  1
92400  99.224  -79.632  44.890  1
92401  99.239  -79.646  44.879  1
92402  99.254  -79.661  44.868  1
92403  99.262  -79.675  44.858  1
92404  99.265  -79.689  44.848  1
92405  99.269  -79.704  44.837  1
92406  99.272  -79.718  44.827  1
92407  99.286  -79.729  44.816  1
92408  99.309  -79.735  44.804  1
92409  99.333  -79.741  44.794  1
92410  99.357  -79.747  44.784  1
92411  99.380  -79.754  44.773  1
92412  99.397  -79.749  44.763  1
92413  99.412  -79.743  44.754  1
92414  99.427  -79.738  44.744  1
92415  99.442  -79.732  44.735  1
92416  99.457  -79.726  44.726  1
92417  99.472  -79.720  44.717  1
92418  99.487  -79.714  44.706  1
92419  99.502  -79.708  44.697  1
92420  99.517  -79.703  44.688  1
92421  99.529  -79.704  44.682  1
92422  99.528  -79.732  44.674  1
92423  99.527  -79.760  44.666  1
92424  99.525  -79.788  44.660  1
92425  99.524  -79.816  44.652  1
92426  99.542  -79.841  44.644  1
92427  99.561  -79.865  44.637  1
92428  99.581  -79.890  44.631  1
92429  99.600  -79.914  44.624  1
92430  99.620  -79.939  44.616  1
92431  99.640  -79.964  44.609  1
92432  99.659  -79.989  44.602  1
92433  99.679  -80.013  44.596  1
92434  99.699  -80.037  44.589  1
92435  99.718  -80.062  44.582  1
92436  99.738  -80.087  44.574  1
92437  99.774  -80.126  44.566  1
92438  99.810  -80.165  44.558  1
92439  99.833  -80.198  44.548  1
92440  99.856  -80.231  44.539  1
92441  99.880  -80.263  44.530  1
92442  99.908  -80.292  44.519  1
92443  99.931  -80.320  44.508  1
92444  99.967  -80.345  44.496  1
92445  100.030  -80.359  44.484  1
92446  100.082  -80.366  44.472  1
92447  100.129  -80.365  44.459  1
92448  100.150  -80.413  44.445  1
92449  100.179  -80.450  44.431  1
92450  100.224  -80.466  44.417  1
92451  100.268  -80.482  44.403  1
92452  100.313  -80.498  44.387  1
92453  100.357  -80.515  44.372  1
92454  100.402  -80.532  44.356  1
92455  100.446  -80.547  44.341  1
92456  100.491  -80.564  44.326  1
92457  100.536  -80.580  44.310  1
92458  100.580  -80.597  44.293  1
92459  100.625  -80.613  44.278  1
92460  100.670  -80.629  44.263  1
92461  100.714  -80.646  44.247  1
92462  100.759  -80.662  44.233  1
92463  100.803  -80.679  44.219  1
92464  100.848  -80.695  44.204  1
92465  100.889  -80.715  44.190  1
92466  100.929  -80.737  44.176  1
92467  100.970  -80.759  44.163  1
92468  101.010  -80.781  44.150  1
92469  101.050  -80.803  44.137  1
92470  101.090  -80.826  44.123  1
92748  93.597  -78.629  53.633  1
92749  93.596  -78.620  53.620  1
92750  93.594  -78.611  53.605  1
92751  93.593  -78.601  53.591  1
92752  93.592  -78.592  53.575  1
92753  93.591  -78.582  53.561  1
92754  93.596  -78.570  53.546  1
92755  93.618  -78.554  53.531  1
92756  93.641  -78.540  53.516  1
92757  93.663  -78.525  53.501  1
92758  93.685  -78.510  53.485  1
92759  93.697  -78.502  53.468  1
92760  93.713  -78.495  53.451  1
92761  93.728  -78.487  53.433  1
92762  93.744  -78.479  53.416  1
92763  93.759  -78.473  53.397  1
92764  93.774  -78.465  53.378  1
92765  93.790  -78.457  53.359  1
92766  93.804  -78.453  53.341  1
92767  93.819  -78.448  53.321  1
92768  93.834  -78.442  53.302  1
92769  93.848  -78.437  53.283  1
92770  93.863  -78.432  53.263  1
92771  93.864  -78.416  53.245  1
92772  93.862  -78.399  53.226  1
92773  93.861  -78.382  53.206  1
92774  93.859  -78.365  53.187  1
92775  93.857  -78.347  53.169  1
92776  93.858  -78.331  53.151  1
92777  93.888  -78.317  53.134  1
92778  93.913  -78.316  53.117  1
92779  93.927  -78.326  53.100  1
92780  93.940  -78.334  53.083  1
92781  93.954  -78.342  53.067  1
92782  93.967  -78.351  53.052  1
92783  93.981  -78.360  53.037  1
92784  93.994  -78.368  53.020  1
92785  94.007  -78.377  53.004  1
92786  94.021  -78.385  52.987  1
92787  94.034  -78.391  52.969  1
92788  94.045  -78.396  52.952  1
92789  94.057  -78.401  52.936  1
92790  94.069  -78.406  52.922  1
92791  94.081  -78.410  52.909  1
92792  94.090  -78.415  52.898  1
92793  94.101  -78.420  52.887  1
92794  94.110  -78.424  52.875  1
92795  94.120  -78.428  52.866  1
92796  94.133  -78.427  52.856  1
92797  94.145  -78.426  52.846  1
92798  94.146  -78.438  52.834  1
92799  94.150  -78.442  52.823  1
92800  94.154  -78.446  52.811  1
92801  94.158  -78.450  52.795  1
92802  94.163  -78.454  52.779  1
92803  94.167  -78.458  52.763  1
92804  94.171  -78.463  52.749  1
92805  94.175  -78.467  52.735  1
92806  94.192  -78.466  52.721  1
92807  94.214  -78.461  52.706  1
92808  94.236  -78.457  52.691  1
92809  94.258  -78.454  52.677  1
92810  94.280  -78.449  52.664  1
92811  94.298  -78.451  52.649  1
92812  94.314  -78.457  52.632  1
92813  94.323  -78.470  52.613  1
92814  94.333  -78.484  52.593  1
92815  94.343  -78.497  52.569  1
92816  94.353  -78.510  52.544  1
92817  94.362  -78.523  52.517  1
92818  94.372  -78.537  52.489  1
92819  94.382  -78.550  52.460  1
92820  94.392  -78.564  52.432  1
92821  94.404  -78.566  52.405  1
92822  94.418  -78.560  52.375  1
92823  94.431  -78.553  52.342  1
92824  94.445  -78.546  52.307  1
92825  94.469  -78.531  52.272  1
92826  94.493  -78.514  52.239  1
92827  94.518  -78.498  52.207  1
92828  94.542  -78.482  52.174  1
92829  94.566  -78.465  52.139  1
92830  94.579  -78.457  52.103  1
92831  94.590  -78.451  52.066  1
92832  94.602  -78.454  52.030  1
92833  94.614  -78.456  51.992  1
92834  94.627  -78.457  51.952  1
92835  94.639  -78.460  51.910  1
92836  94.651  -78.461  51.863  1
92837  94.667  -78.463  51.814  1
92838  94.684  -78.464  51.764  1
92839  94.694  -78.463  51.714  1
92840  94.705  -78.463  51.660  1
92841  94.721  -78.466  51.605  1
92842  94.737  -78.470  51.549  1
92843  94.752  -78.473  51.495  1
92844  94.771  -78.465  51.443  1
92845  94.790  -78.457  51.391  1
92846  94.807  -78.458  51.341  1
92847  94.821  -78.471  51.290  1
92848  94.833  -78.476  51.241  1
92849  94.843  -78.478  51.194  1
92850  94.852  -78.479  51.148  1
92851  94.862  -78.481  51.105  1
92852  94.872  -78.482  51.063  1
92853  94.882  -78.466  51.022  1
92854  94.892  -78.450  50.981  1
92855  94.901  -78.434  50.938  1
92856  94.911  -78.417  50.894  1
92857  94.921  -78.401  50.848  1
92858  94.931  -78.385  50.800  1
92859  94.941  -78.369  50.751  1
92860  94.950  -78.353  50.700  1
92861  94.960  -78.336  50.649  1
92862  94.972  -78.319  50.599  1
92863  94.986  -78.301  50.549  1
92864  95.000  -78.284  50.501  1
92865  95.015  -78.266  50.455  1
92866  95.035  -78.269  50.410  1
92867  95.055  -78.273  50.366  1
92868  95.075  -78.279  50.323  1
92869  95.096  -78.284  50.281  1
92870  95.116  -78.289  50.239  1
92871  95.137  -78.294  50.198  1
92872  95.170  -78.317  50.157  1
92873  95.217  -78.363  50.118  1
92874  95.244  -78.376  50.079  1
92875  95.255  -78.366  50.040  1
92876  95.265  -78.354  50.000  1
92877  95.276  -78.343  49.959  1
92878  95.286  -78.332  49.921  1
92879  95.296  -78.330  49.883  1
92880  95.306  -78.333  49.846  1
92881  95.315  -78.335  49.810  1
92882  95.324  -78.338  49.776  1
92883  95.342  -78.347  49.742  1
92884  95.366  -78.359  49.708  1
92885  95.390  -78.370  49.672  1
92886  95.414  -78.382  49.634  1
92887  95.438  -78.395  49.597  1
92888  95.462  -78.407  49.560  1
92889  95.486  -78.418  49.523  1
92890  95.510  -78.430  49.487  1
92891  95.534  -78.442  49.452  1
92892  95.558  -78.454  49.418  1
92893  95.566  -78.456  49.384  1
92894  95.571  -78.455  49.351  1
92895  95.577  -78.455  49.319  1
92896  95.582  -78.454  49.289  1
92897  95.587  -78.454  49.258  1
92898  95.592  -78.454  49.225  1
92899  95.597  -78.454  49.190  1
92900  95.602  -78.453  49.155  1
92901  95.607  -78.452  49.118  1
92902  95.613  -78.454  49.081  1
92903  95.622  -78.460  49.044  1
92904  95.631  -78.467  49.007  1
92905  95.640  -78.475  48.969  1
92906  95.643  -78.477  48.931  1
92907  95.639  -78.473  48.893  1
92908  95.635  -78.470  48.856  1
92909  95.631  -78.467  48.817  1
92910  95.607  -78.466  48.775  1
92911  95.581  -78.466  48.732  1
92912  95.566  -78.466  48.689  1
92913  95.592  -78.467  48.648  1
92914  95.615  -78.467  48.607  1
92915  95.630  -78.471  48.566  1
92916  95.645  -78.475  48.526  1
92917  95.661  -78.479  48.487  1
92918  95.676  -78.482  48.448  1
92919  95.691  -78.485  48.409  1
92920  95.707  -78.489  48.371  1
92921  95.730  -78.491  48.332  1
92922  95.752  -78.495  48.292  1
92923  95.773  -78.500  48.252  1
92924  95.795  -78.503  48.211  1
92925  95.815  -78.501  48.169  1
92926  95.834  -78.499  48.127  1
92927  95.856  -78.499  48.085  1
92928  95.878  -78.500  48.043  1
92929  95.891  -78.500  48.002  1
92930  95.900  -78.499  47.960  1
92931  95.915  -78.499  47.920  1
92932  95.931  -78.500  47.879  1
92933  95.945  -78.502  47.837  1
92934  95.961  -78.506  47.797  1
92935  95.980  -78.510  47.758  1
92936  95.999  -78.514  47.719  1
92937  96.016  -78.515  47.680  1
92938  96.029  -78.515  47.641  1
92939  96.041  -78.515  47.602  1
92940  96.052  -78.515  47.565  1
92941  96.070  -78.532  47.527  1
92942  96.087  -78.548  47.490  1
92943  96.099  -78.560  47.453  1
92944  96.111  -78.570  47.417  1
92945  96.123  -78.580  47.383  1
92946  96.132  -78.611  47.349  1
92947  96.141  -78.646  47.313  1
92948  96.160  -78.663  47.281  1
92949  96.186  -78.667  47.252  1
92950  96.213  -78.671  47.223  1
92951  96.240  -78.676  47.192  1
92952  96.266  -78.680  47.162  1
92953  96.293  -78.684  47.132  1
92954  96.319  -78.688  47.101  1
92955  96.345  -78.692  47.074  1
92956  96.363  -78.695  47.044  1
92957  96.376  -78.698  47.014  1
92958  96.388  -78.702  46.987  1
92959  96.401  -78.705  46.958  1
92960  96.414  -78.709  46.928  1
92961  96.406  -78.695  46.897  1
92962  96.347  -78.641  46.870  1
92963  96.353  -78.622  46.843  1
92964  96.395  -78.623  46.815  1
92965  96.443  -78.632  46.787  1
92966  96.492  -78.642  46.760  1
92967  96.541  -78.651  46.734  1
92968  96.590  -78.661  46.710  1
92969  96.640  -78.671  46.688  1
92970  96.688  -78.681  46.666  1
92971  96.738  -78.691  46.645  1
92972  96.787  -78.701  46.624  1
92973  96.803  -78.712  46.604  1
92974  96.808  -78.723  46.582  1
92975  96.828  -78.733  46.560  1
92976  96.849  -78.744  46.539  1
92977  96.869  -78.755  46.518  1
92978  96.889  -78.765  46.496  1
92979  96.898  -78.780  46.473  1
92980  96.898  -78.799  46.450  1
92981  96.899  -78.817  46.427  1
92982  96.907  -78.833  46.405  1
92983  96.917  -78.843  46.387  1
92984  96.927  -78.854  46.369  1
92985  96.927  -78.850  46.351  1
92986  96.923  -78.866  46.333  1
92987  96.922  -78.881  46.315  1
92988  96.941  -78.891  46.297  1
92989  96.966  -78.896  46.278  1
92990  96.992  -78.902  46.261  1
92991  97.018  -78.907  46.245  1
92992  97.043  -78.912  46.229  1
92993  97.069  -78.918  46.213  1
92994  97.095  -78.923  46.197  1
92995  97.123  -78.933  46.181  1
92996  97.152  -78.944  46.165  1
92997  97.181  -78.955  46.153  1
92998  97.210  -78.965  46.141  1
92999  97.241  -78.978  46.128  1
93000  97.277  -78.995  46.114  1
93001  97.300  -79.003  46.098  1
93002  97.322  -79.012  46.082  1
93003  97.345  -79.021  46.066  1
93004  97.368  -79.029  46.051  1
93005  97.386  -79.031  46.034  1
93006  97.400  -79.029  46.016  1
93007  97.408  -79.024  45.997  1
93008  97.417  -79.018  45.977  1
93009  97.425  -79.012  45.956  1
93010  97.433  -79.009  45.936  1
93011  97.442  -79.006  45.920  1
93012  97.450  -79.003  45.904  1
93013  97.458  -79.001  45.888  1
93014  97.466  -78.999  45.874  1
93015  97.474  -78.996  45.858  1
93016  97.483  -78.994  45.843  1
93017  97.491  -78.992  45.828  1
93018  97.500  -78.990  45.815  1
93019  97.508  -78.987  45.801  1
93020  97.516  -78.985  45.786  1
93021  97.524  -78.983  45.772  1
93022  97.529  -79.005  45.758  1
93023  97.537  -79.044  45.741  1
93024  97.562  -79.065  45.723  1
93025  97.592  -79.092  45.704  1
93026  97.598  -79.100  45.682  1
93027  97.594  -79.100  45.658  1
93028  97.589  -79.099  45.636  1
93029  97.584  -79.099  45.615  1
93030  97.579  -79.098  45.596  1
93031  97.575  -79.097  45.577  1
93032  97.570  -79.096  45.561  1
93033  97.573  -79.094  45.545  1
93034  97.575  -79.091  45.528  1
93035  97.578  -79.088  45.510  1
93036  97.580  -79.086  45.494  1
93037  97.605  -79.100  45.479  1
93038  97.641  -79.123  45.464  1
93039  97.676  -79.147  45.450  1
93040  97.712  -79.169  45.437  1
93041  97.742  -79.189  45.425  1
93042  97.749  -79.194  45.414  1
93043  97.754  -79.206  45.403  1
93044  97.760  -79.219  45.392  1
93045  97.779  -79.227  45.379  1
93046  97.798  -79.235  45.368  1
93047  97.817  -79.244  45.358  1
93048  97.836  -79.252  45.349  1
93049  97.855  -79.260  45.340  1
93050  97.873  -79.269  45.332  1
93051  97.890  -79.278  45.324  1
93052  97.910  -79.288  45.316  1
93053  97.932  -79.297  45.310  1
93054  97.955  -79.307  45.303  1
93055  97.979  -79.317  45.296  1
93056  98.002  -79.327  45.289  1
93057  98.025  -79.337  45.282  1
93058  98.048  -79.347  45.276  1
93059  98.071  -79.356  45.269  1
93060  98.096  -79.362  45.260  1
93061  98.120  -79.357  45.251  1
93062  98.145  -79.353  45.241  1
93063  98.169  -79.349  45.230  1
93064  98.210  -79.344  45.220  1
93065  98.249  -79.344  45.210  1
93066  98.275  -79.347  45.203  1
93067  98.301  -79.350  45.196  1
93068  98.327  -79.354  45.188  1
93069  98.353  -79.357  45.180  1
93070  98.385  -79.368  45.173  1
93071  98.418  -79.380  45.166  1
93072  98.450  -79.391  45.159  1
93073  98.483  -79.404  45.153  1
93074  98.516  -79.415  45.147  1
93075  98.549  -79.427  45.141  1
93076  98.581  -79.439  45.134  1
93077  98.614  -79.451  45.124  1
93078  98.650  -79.463  45.115  1
93079  98.687  -79.475  45.108  1
93080  98.723  -79.487  45.102  1
93081  98.754  -79.498  45.095  1
93082  98.754  -79.500  45.086  1
93083  98.755  -79.502  45.078  1
93084  98.755  -79.504  45.071  1
93085  98.756  -79.507  45.061  1
93086  98.771  -79.519  45.051  1
93087  98.792  -79.534  45.039  1
93088  98.814  -79.549  45.030  1
93089  98.837  -79.565  45.021  1
93090  98.858  -79.580  45.014  1
93091  98.883  -79.594  45.004  1
93092  98.924  -79.595  44.994  1
93093  98.966  -79.596  44.983  1
93094  99.007  -79.597  44.972  1
93095  99.048  -79.598  44.962  1
93096  99.089  -79.599  44.951  1
93097  99.130  -79.600  44.941  1
93098  99.173  -79.599  44.931  1
93099  99.196  -79.598  44.920  1
93100  99.206  -79.604  44.908  1
93101  99.219  -79.615  44.899  1
93102  99.234  -79.629  44.888  1
93103  99.249  -79.644  44.877  1
93104  99.264  -79.658  44.868  1
93105  99.276  -79.673  44.857  1
93106  99.279  -79.688  44.847  1
93107  99.283  -79.701  44.836  1
93108  99.290  -79.715  44.824  1
93109  99.313  -79.721  44.812  1
93110  99.337  -79.727  44.801  1
93111  99.361  -79.733  44.790  1
93112  99.378  -79.732  44.781  1
93113  99.394  -79.726  44.773  1
93114  99.409  -79.720  44.764  1
93115  99.424  -79.714  44.754  1
93116  99.439  -79.708  44.745  1
93117  99.454  -79.702  44.735  1
93118  99.469  -79.697  44.726  1
93119  99.484  -79.691  44.715  1
93120  99.499  -79.685  44.706  1
93121  99.514  -79.679  44.698  1
93122  99.524  -79.683  44.692  1
93123  99.523  -79.711  44.684  1
93124  99.522  -79.739  44.675  1
93125  99.524  -79.767  44.667  1
93126  99.544  -79.792  44.659  1
93127  99.563  -79.816  44.652  1
93128  99.583  -79.841  44.645  1
93129  99.603  -79.865  44.640  1
93130  99.622  -79.890  44.632  1
93131  99.642  -79.914  44.624  1
93132  99.661  -79.939  44.617  1
93133  99.681  -79.964  44.611  1
93134  99.701  -79.988  44.604  1
93135  99.720  -80.013  44.596  1
93136  99.740  -80.037  44.590  1
93137  99.760  -80.062  44.582  1
93138  99.797  -80.102  44.574  1
93139  99.828  -80.140  44.565  1
93140  99.851  -80.172  44.556  1
93141  99.874  -80.205  44.547  1
93142  99.903  -80.234  44.538  1
93143  99.930  -80.262  44.527  1
93144  99.952  -80.290  44.516  1
93145  99.976  -80.319  44.504  1
93146  100.011  -80.344  44.492  1
93147  100.080  -80.362  44.479  1
93148  100.135  -80.371  44.466  1
93149  100.184  -80.368  44.453  1
93150  100.204  -80.414  44.439  1
93151  100.226  -80.460  44.424  1
93152  100.271  -80.476  44.409  1
93153  100.315  -80.493  44.394  1
93154  100.360  -80.509  44.378  1
93155  100.404  -80.526  44.363  1
93156  100.449  -80.541  44.346  1
93157  100.493  -80.558  44.331  1
93158  100.538  -80.575  44.315  1
93159  100.582  -80.591  44.299  1
93160  100.627  -80.607  44.283  1
93161  100.671  -80.623  44.267  1
93162  100.716  -80.640  44.252  1
93163  100.761  -80.656  44.237  1
93164  100.805  -80.673  44.223  1
93165  100.845  -80.695  44.208  1
93166  100.885  -80.717  44.193  1
93167  100.925  -80.739  44.179  1
93168  100.966  -80.761  44.165  1
93169  101.006  -80.784  44.152  1
93170  101.046  -80.806  44.139  1
93171  101.087  -80.828  44.125  1
93449  93.594  -78.616  53.636  1
93450  93.592  -78.607  53.621  1
93451  93.591  -78.598  53.606  1
93452  93.590  -78.588  53.591  1
93453  93.588  -78.579  53.576  1
93454  93.587  -78.570  53.560  1
93455  93.602  -78.554  53.545  1
93456  93.624  -78.539  53.529  1
93457  93.646  -78.524  53.513  1
93458  93.669  -78.509  53.497  1
93459  93.687  -78.497  53.481  1
93460  93.699  -78.489  53.464  1
93461  93.714  -78.482  53.446  1
93462  93.730  -78.474  53.428  1
93463  93.746  -78.467  53.411  1
93464  93.761  -78.460  53.392  1
93465  93.776  -78.452  53.373  1
93466  93.791  -78.445  53.354  1
93467  93.807  -78.438  53.335  1
93468  93.822  -78.432  53.315  1
93469  93.836  -78.427  53.296  1
93470  93.851  -78.422  53.278  1
93471  93.865  -78.416  53.259  1
93472  93.876  -78.408  53.240  1
93473  93.874  -78.391  53.221  1
93474  93.872  -78.374  53.200  1
93475  93.871  -78.357  53.182  1
93476  93.869  -78.339  53.164  1
93477  93.872  -78.322  53.146  1
93478  93.902  -78.309  53.129  1
93479  93.923  -78.314  53.112  1
93480  93.937  -78.322  53.095  1
93481  93.950  -78.331  53.078  1
93482  93.964  -78.340  53.062  1
93483  93.977  -78.348  53.046  1
93484  93.991  -78.357  53.030  1
93485  94.004  -78.366  53.013  1
93486  94.017  -78.374  52.998  1
93487  94.026  -78.378  52.982  1
93488  94.036  -78.382  52.965  1
93489  94.047  -78.387  52.949  1
93490  94.059  -78.391  52.935  1
93491  94.071  -78.397  52.922  1
93492  94.082  -78.401  52.911  1
93493  94.092  -78.406  52.901  1
93494  94.102  -78.410  52.892  1
93495  94.112  -78.414  52.881  1
93496  94.122  -78.419  52.871  1
93497  94.131  -78.423  52.862  1
93498  94.140  -78.427  52.853  1
93499  94.144  -78.432  52.842  1
93500  94.148  -78.435  52.831  1
93501  94.152  -78.440  52.819  1
93502  94.156  -78.444  52.802  1
93503  94.160  -78.448  52.786  1
93504  94.165  -78.453  52.771  1
93505  94.169  -78.457  52.759  1
93506  94.173  -78.461  52.745  1
93507  94.186  -78.461  52.730  1
93508  94.208  -78.457  52.716  1
93509  94.230  -78.453  52.702  1
93510  94.253  -78.449  52.689  1
93511  94.274  -78.445  52.675  1
93512  94.295  -78.438  52.660  1
93513  94.304  -78.454  52.642  1
93514  94.313  -78.471  52.623  1
93515  94.322  -78.486  52.602  1
93516  94.332  -78.499  52.577  1
93517  94.342  -78.513  52.550  1
93518  94.351  -78.526  52.522  1
93519  94.361  -78.539  52.493  1
93520  94.371  -78.552  52.464  1
93521  94.381  -78.566  52.435  1
93522  94.393  -78.570  52.408  1
93523  94.406  -78.563  52.376  1
93524  94.424  -78.553  52.343  1
93525  94.449  -78.536  52.308  1
93526  94.473  -78.520  52.272  1
93527  94.497  -78.503  52.239  1
93528  94.522  -78.487  52.207  1
93529  94.546  -78.470  52.174  1
93530  94.571  -78.454  52.138  1
93531  94.584  -78.445  52.102  1
93532  94.595  -78.439  52.065  1
93533  94.607  -78.438  52.027  1
93534  94.619  -78.439  51.990  1
93535  94.631  -78.442  51.950  1
93536  94.643  -78.443  51.908  1
93537  94.655  -78.445  51.861  1
93538  94.668  -78.447  51.812  1
93539  94.680  -78.449  51.762  1
93540  94.695  -78.451  51.712  1
93541  94.706  -78.450  51.659  1
93542  94.722  -78.454  51.604  1
93543  94.740  -78.451  51.548  1
93544  94.759  -78.442  51.494  1
93545  94.777  -78.434  51.442  1
93546  94.796  -78.426  51.391  1
93547  94.812  -78.434  51.341  1
93548  94.826  -78.446  51.291  1
93549  94.840  -78.458  51.244  1
93550  94.850  -78.460  51.198  1
93551  94.860  -78.461  51.155  1
93552  94.870  -78.463  51.113  1
93553  94.880  -78.451  51.072  1
93554  94.890  -78.434  51.030  1
93555  94.899  -78.418  50.987  1
93556  94.909  -78.401  50.943  1
93557  94.919  -78.385  50.896  1
93558  94.928  -78.369  50.847  1
93559  94.938  -78.353  50.798  1
93560  94.948  -78.337  50.748  1
93561  94.958  -78.320  50.697  1
93562  94.968  -78.304  50.646  1
93563  94.978  -78.288  50.595  1
93564  94.991  -78.270  50.546  1
93565  95.005  -78.252  50.498  1
93566  95.022  -78.243  50.452  1
93567  95.043  -78.248  50.407  1
93568  95.063  -78.253  50.364  1
93569  95.084  -78.259  50.322  1
93570  95.104  -78.263  50.280  1
93571  95.148  -78.304  50.238  1
93572  95.196  -78.350  50.197  1
93573  95.229  -78.373  50.156  1
93574  95.240  -78.363  50.116  1
93575  95.250  -78.351  50.076  1
93576  95.261  -78.340  50.037  1
93577  95.271  -78.329  49.998  1
93578  95.282  -78.318  49.958  1
93579  95.293  -78.307  49.920  1
93580  95.302  -78.308  49.883  1
93581  95.312  -78.311  49.846  1
93582  95.321  -78.313  49.811  1
93583  95.330  -78.316  49.777  1
93584  95.339  -78.319  49.743  1
93585  95.357  -78.327  49.709  1
93586  95.381  -78.339  49.672  1
93587  95.405  -78.351  49.635  1
93588  95.429  -78.363  49.598  1
93589  95.453  -78.375  49.561  1
93590  95.477  -78.387  49.526  1
93591  95.501  -78.399  49.492  1
93592  95.525  -78.410  49.456  1
93593  95.549  -78.423  49.423  1
93594  95.557  -78.425  49.390  1
93595  95.562  -78.424  49.357  1
93596  95.567  -78.423  49.326  1
93597  95.572  -78.423  49.295  1
93598  95.578  -78.423  49.264  1
93599  95.583  -78.423  49.233  1
93600  95.588  -78.422  49.199  1
93601  95.593  -78.422  49.163  1
93602  95.599  -78.423  49.128  1
93603  95.608  -78.430  49.092  1
93604  95.617  -78.437  49.057  1
93605  95.626  -78.444  49.021  1
93606  95.635  -78.451  48.984  1
93607  95.642  -78.457  48.946  1
93608  95.638  -78.453  48.909  1
93609  95.634  -78.449  48.872  1
93610  95.630  -78.446  48.833  1
93611  95.626  -78.442  48.791  1
93612  95.614  -78.440  48.749  1
93613  95.588  -78.440  48.706  1
93614  95.595  -78.440  48.665  1
93615  95.617  -78.442  48.623  1
93616  95.632  -78.445  48.581  1
93617  95.647  -78.449  48.542  1
93618  95.662  -78.453  48.502  1
93619  95.677  -78.457  48.463  1
93620  95.692  -78.460  48.424  1
93621  95.711  -78.465  48.386  1
93622  95.733  -78.470  48.346  1
93623  95.755  -78.473  48.304  1
93624  95.777  -78.478  48.262  1
93625  95.798  -78.481  48.220  1
93626  95.818  -78.479  48.179  1
93627  95.837  -78.477  48.137  1
93628  95.857  -78.476  48.095  1
93629  95.879  -78.476  48.055  1
93630  95.890  -78.476  48.015  1
93631  95.898  -78.475  47.973  1
93632  95.911  -78.475  47.932  1
93633  95.926  -78.476  47.892  1
93634  95.940  -78.479  47.850  1
93635  95.956  -78.482  47.811  1
93636  95.975  -78.487  47.771  1
93637  95.993  -78.491  47.732  1
93638  96.011  -78.496  47.695  1
93639  96.023  -78.498  47.657  1
93640  96.036  -78.499  47.619  1
93641  96.049  -78.500  47.582  1
93642  96.061  -78.502  47.544  1
93643  96.073  -78.510  47.507  1
93644  96.085  -78.520  47.469  1
93645  96.097  -78.530  47.434  1
93646  96.107  -78.552  47.400  1
93647  96.116  -78.587  47.365  1
93648  96.124  -78.622  47.330  1
93649  96.144  -78.638  47.300  1
93650  96.170  -78.642  47.269  1
93651  96.197  -78.646  47.239  1
93652  96.224  -78.651  47.210  1
93653  96.250  -78.655  47.181  1
93654  96.276  -78.658  47.151  1
93655  96.303  -78.663  47.120  1
93656  96.329  -78.667  47.093  1
93657  96.356  -78.671  47.065  1
93658  96.382  -78.675  47.036  1
93659  96.400  -78.679  47.007  1
93660  96.413  -78.682  46.978  1
93661  96.426  -78.686  46.949  1
93662  96.418  -78.672  46.919  1
93663  96.360  -78.617  46.891  1
93664  96.350  -78.599  46.862  1
93665  96.400  -78.609  46.833  1
93666  96.449  -78.619  46.806  1
93667  96.498  -78.629  46.779  1
93668  96.547  -78.639  46.753  1
93669  96.596  -78.648  46.728  1
93670  96.645  -78.658  46.706  1
93671  96.694  -78.668  46.683  1
93672  96.744  -78.678  46.661  1
93673  96.793  -78.688  46.639  1
93674  96.793  -78.699  46.618  1
93675  96.795  -78.710  46.596  1
93676  96.815  -78.720  46.574  1
93677  96.835  -78.731  46.553  1
93678  96.856  -78.742  46.532  1
93679  96.876  -78.752  46.510  1
93680  96.879  -78.770  46.487  1
93681  96.879  -78.788  46.464  1
93682  96.883  -78.805  46.441  1
93683  96.894  -78.819  46.420  1
93684  96.904  -78.830  46.401  1
93685  96.915  -78.840  46.382  1
93686  96.925  -78.851  46.364  1
93687  96.924  -78.853  46.345  1
93688  96.920  -78.869  46.328  1
93689  96.939  -78.878  46.310  1
93690  96.965  -78.883  46.291  1
93691  96.991  -78.889  46.273  1
93692  97.016  -78.894  46.257  1
93693  97.042  -78.899  46.242  1
93694  97.071  -78.910  46.226  1
93695  97.099  -78.921  46.210  1
93696  97.128  -78.931  46.195  1
93697  97.157  -78.943  46.180  1
93698  97.186  -78.953  46.167  1
93699  97.215  -78.964  46.154  1
93700  97.244  -78.975  46.141  1
93701  97.288  -78.997  46.127  1
93702  97.314  -79.008  46.111  1
93703  97.337  -79.017  46.095  1
93704  97.360  -79.025  46.078  1
93705  97.376  -79.025  46.062  1
93706  97.392  -79.024  46.045  1
93707  97.407  -79.024  46.028  1
93708  97.416  -79.018  46.010  1
93709  97.425  -79.012  45.991  1
93710  97.433  -79.006  45.970  1
93711  97.441  -79.000  45.949  1
93712  97.449  -78.994  45.933  1
93713  97.457  -78.988  45.917  1
93714  97.465  -78.984  45.901  1
93715  97.474  -78.981  45.885  1
93716  97.482  -78.979  45.870  1
93717  97.490  -78.977  45.855  1
93718  97.499  -78.974  45.841  1
93719  97.507  -78.972  45.828  1
93720  97.515  -78.970  45.815  1
93721  97.523  -78.968  45.801  1
93722  97.532  -78.965  45.787  1
93723  97.539  -78.969  45.771  1
93724  97.540  -79.021  45.754  1
93725  97.564  -79.053  45.736  1
93726  97.593  -79.081  45.715  1
93727  97.596  -79.086  45.693  1
93728  97.591  -79.086  45.671  1
93729  97.587  -79.085  45.650  1
93730  97.584  -79.084  45.629  1
93731  97.586  -79.081  45.610  1
93732  97.589  -79.078  45.592  1
93733  97.591  -79.076  45.575  1
93734  97.594  -79.073  45.558  1
93735  97.596  -79.070  45.541  1
93736  97.599  -79.068  45.523  1
93737  97.609  -79.071  45.507  1
93738  97.645  -79.093  45.492  1
93739  97.680  -79.117  45.478  1
93740  97.716  -79.140  45.463  1
93741  97.747  -79.160  45.450  1
93742  97.754  -79.165  45.438  1
93743  97.761  -79.170  45.425  1
93744  97.768  -79.178  45.413  1
93745  97.772  -79.192  45.401  1
93746  97.776  -79.206  45.389  1
93747  97.781  -79.219  45.380  1
93748  97.800  -79.227  45.370  1
93749  97.819  -79.235  45.360  1
93750  97.838  -79.244  45.351  1
93751  97.857  -79.252  45.342  1
93752  97.875  -79.247  45.333  1
93753  97.893  -79.240  45.326  1
93754  97.911  -79.232  45.320  1
93755  97.946  -79.259  45.314  1
93756  97.981  -79.287  45.308  1
93757  98.009  -79.305  45.300  1
93758  98.032  -79.315  45.293  1
93759  98.055  -79.325  45.285  1
93760  98.079  -79.334  45.277  1
93761  98.103  -79.333  45.269  1
93762  98.128  -79.328  45.260  1
93763  98.152  -79.324  45.250  1
93764  98.176  -79.320  45.241  1
93765  98.222  -79.316  45.230  1
93766  98.249  -79.319  45.221  1
93767  98.275  -79.322  45.214  1
93768  98.301  -79.325  45.207  1
93769  98.327  -79.328  45.200  1
93770  98.353  -79.332  45.192  1
93771  98.383  -79.340  45.184  1
93772  98.416  -79.352  45.176  1
93773  98.449  -79.363  45.169  1
93774  98.482  -79.375  45.162  1
93775  98.514  -79.388  45.154  1
93776  98.547  -79.399  45.146  1
93777  98.580  -79.411  45.137  1
93778  98.615  -79.423  45.128  1
93779  98.652  -79.435  45.118  1
93780  98.688  -79.447  45.109  1
93781  98.725  -79.460  45.102  1
93782  98.762  -79.472  45.095  1
93783  98.768  -79.476  45.087  1
93784  98.768  -79.478  45.077  1
93785  98.769  -79.480  45.070  1
93786  98.769  -79.482  45.061  1
93787  98.787  -79.496  45.051  1
93788  98.810  -79.513  45.041  1
93789  98.832  -79.529  45.031  1
93790  98.854  -79.545  45.023  1
93791  98.876  -79.560  45.017  1
93792  98.898  -79.575  45.009  1
93793  98.937  -79.578  44.999  1
93794  98.978  -79.579  44.988  1
93795  99.019  -79.580  44.979  1
93796  99.060  -79.581  44.969  1
93797  99.101  -79.582  44.959  1
93798  99.143  -79.583  44.950  1
93799  99.182  -79.576  44.937  1
93800  99.192  -79.582  44.924  1
93801  99.201  -79.587  44.913  1
93802  99.214  -79.598  44.903  1
93803  99.229  -79.613  44.893  1
93804  99.244  -79.627  44.883  1
93805  99.259  -79.642  44.874  1
93806  99.274  -79.657  44.864  1
93807  99.289  -79.671  44.853  1
93808  99.293  -79.686  44.842  1
93809  99.296  -79.700  44.832  1
93810  99.317  -79.708  44.820  1
93811  99.341  -79.714  44.809  1
93812  99.360  -79.714  44.799  1
93813  99.375  -79.708  44.790  1
93814  99.391  -79.702  44.781  1
93815  99.406  -79.696  44.772  1
93816  99.421  -79.691  44.762  1
93817  99.436  -79.685  44.752  1
93818  99.451  -79.679  44.742  1
93819  99.466  -79.673  44.732  1
93820  99.481  -79.667  44.723  1
93821  99.496  -79.661  44.714  1
93822  99.511  -79.656  44.707  1
93823  99.520  -79.663  44.700  1
93824  99.519  -79.691  44.692  1
93825  99.525  -79.718  44.683  1
93826  99.545  -79.742  44.675  1
93827  99.565  -79.767  44.667  1
93828  99.584  -79.792  44.660  1
93829  99.604  -79.816  44.653  1
93830  99.624  -79.841  44.648  1
93831  99.644  -79.865  44.641  1
93832  99.663  -79.889  44.633  1
93833  99.683  -79.914  44.625  1
93834  99.703  -79.939  44.620  1
93835  99.722  -79.964  44.613  1
93836  99.742  -79.988  44.605  1
93837  99.762  -80.013  44.598  1
93838  99.782  -80.038  44.590  1
93839  99.820  -80.079  44.582  1
93840  99.846  -80.113  44.574  1
93841  99.869  -80.146  44.565  1
93842  99.896  -80.176  44.556  1
93843  99.924  -80.205  44.547  1
93844  99.951  -80.234  44.537  1
93845  99.974  -80.262  44.526  1
93846  99.997  -80.289  44.514  1
93847  100.020  -80.317  44.501  1
93848  100.055  -80.343  44.489  1
93849  100.125  -80.360  44.475  1
93850  100.189  -80.375  44.462  1
93851  100.238  -80.374  44.447  1
93852  100.258  -80.416  44.432  1
93853  100.278  -80.463  44.417  1
93854  100.318  -80.487  44.402  1
93855  100.362  -80.504  44.386  1
93856  100.407  -80.519  44.369  1
93857  100.451  -80.536  44.353  1
93858  100.496  -80.552  44.336  1
93859  100.540  -80.569  44.320  1
93860  100.585  -80.585  44.304  1
93861  100.629  -80.601  44.288  1
93862  100.674  -80.618  44.272  1
93863  100.718  -80.634  44.257  1
93864  100.760  -80.654  44.242  1
93865  100.800  -80.676  44.227  1
93866  100.841  -80.698  44.212  1
93867  100.881  -80.720  44.197  1
93868  100.921  -80.742  44.183  1
93869  100.962  -80.764  44.169  1
93870  101.002  -80.786  44.155  1
93871  101.042  -80.808  44.142  1
93872  101.082  -80.830  44.128  1
93873  101.122  -80.852  44.114  1
94143  93.531  -78.625  53.747  1
94144  93.541  -78.623  53.732  1
94145  93.551  -78.620  53.717  1
94146  93.560  -78.617  53.702  1
94147  93.570  -78.615  53.686  1
94148  93.579  -78.613  53.671  1
94149  93.589  -78.611  53.655  1
94150  93.590  -78.602  53.638  1
94151  93.589  -78.593  53.623  1
94152  93.588  -78.584  53.607  1
94153  93.586  -78.575  53.591  1
94154  93.585  -78.566  53.576  1
94155  93.589  -78.554  53.559  1
94156  93.607  -78.539  53.543  1
94157  93.629  -78.523  53.527  1
94158  93.652  -78.508  53.510  1
94159  93.674  -78.494  53.494  1
94160  93.688  -78.484  53.477  1
94161  93.701  -78.476  53.459  1
94162  93.716  -78.469  53.441  1
94163  93.732  -78.461  53.423  1
94164  93.747  -78.454  53.405  1
94165  93.763  -78.447  53.386  1
94166  93.778  -78.439  53.368  1
94167  93.793  -78.432  53.349  1
94168  93.809  -78.425  53.330  1
94169  93.824  -78.417  53.311  1
94170  93.839  -78.412  53.292  1
94171  93.854  -78.407  53.273  1
94172  93.868  -78.401  53.254  1
94173  93.883  -78.396  53.235  1
94174  93.887  -78.382  53.216  1
94175  93.885  -78.365  53.197  1
94176  93.883  -78.348  53.178  1
94177  93.882  -78.331  53.159  1
94178  93.887  -78.314  53.142  1
94179  93.920  -78.303  53.125  1
94180  93.933  -78.311  53.108  1
94181  93.946  -78.319  53.092  1
94182  93.960  -78.329  53.074  1
94183  93.974  -78.337  53.057  1
94184  93.987  -78.345  53.041  1
94185  94.000  -78.354  53.024  1
94186  94.013  -78.362  53.009  1
94187  94.021  -78.366  52.994  1
94188  94.029  -78.369  52.979  1
94189  94.037  -78.373  52.963  1
94190  94.049  -78.378  52.948  1
94191  94.061  -78.382  52.934  1
94192  94.073  -78.388  52.924  1
94193  94.084  -78.392  52.914  1
94194  94.094  -78.396  52.905  1
94195  94.104  -78.401  52.896  1
94196  94.113  -78.405  52.886  1
94197  94.123  -78.410  52.876  1
94198  94.132  -78.414  52.867  1
94199  94.136  -78.423  52.859  1
94200  94.141  -78.428  52.849  1
94201  94.146  -78.430  52.838  1
94202  94.150  -78.434  52.825  1
94203  94.154  -78.438  52.808  1
94204  94.158  -78.442  52.793  1
94205  94.162  -78.447  52.779  1
94206  94.166  -78.451  52.767  1
94207  94.171  -78.455  52.754  1
94208  94.181  -78.457  52.741  1
94209  94.203  -78.452  52.727  1
94210  94.225  -78.448  52.713  1
94211  94.247  -78.445  52.699  1
94212  94.266  -78.433  52.684  1
94213  94.286  -78.425  52.668  1
94214  94.300  -78.435  52.649  1
94215  94.309  -78.452  52.628  1
94216  94.317  -78.470  52.606  1
94217  94.326  -78.487  52.580  1
94218  94.334  -78.504  52.552  1
94219  94.343  -78.521  52.523  1
94220  94.351  -78.539  52.493  1
94221  94.360  -78.554  52.464  1
94222  94.370  -78.568  52.435  1
94223  94.382  -78.573  52.405  1
94224  94.405  -78.557  52.372  1
94225  94.429  -78.542  52.337  1
94226  94.454  -78.525  52.301  1
94227  94.478  -78.508  52.266  1
94228  94.502  -78.492  52.234  1
94229  94.527  -78.476  52.202  1
94230  94.551  -78.459  52.169  1
94231  94.575  -78.442  52.132  1
94232  94.590  -78.433  52.095  1
94233  94.601  -78.428  52.057  1
94234  94.611  -78.422  52.020  1
94235  94.623  -78.423  51.981  1
94236  94.635  -78.425  51.941  1
94237  94.647  -78.427  51.897  1
94238  94.660  -78.429  51.851  1
94239  94.672  -78.431  51.803  1
94240  94.684  -78.433  51.755  1
94241  94.696  -78.435  51.706  1
94242  94.708  -78.437  51.653  1
94243  94.726  -78.430  51.599  1
94244  94.745  -78.422  51.544  1
94245  94.764  -78.414  51.490  1
94246  94.782  -78.407  51.437  1
94247  94.801  -78.399  51.386  1
94248  94.817  -78.409  51.337  1
94249  94.831  -78.421  51.290  1
94250  94.845  -78.433  51.244  1
94251  94.858  -78.442  51.201  1
94252  94.868  -78.443  51.160  1
94253  94.878  -78.435  51.119  1
94254  94.888  -78.418  51.077  1
94255  94.897  -78.402  51.032  1
94256  94.907  -78.385  50.987  1
94257  94.917  -78.369  50.941  1
94258  94.926  -78.353  50.892  1
94259  94.936  -78.337  50.842  1
94260  94.946  -78.321  50.792  1
94261  94.956  -78.304  50.741  1
94262  94.966  -78.288  50.690  1
94263  94.975  -78.272  50.639  1
94264  94.985  -78.256  50.589  1
94265  94.996  -78.239  50.541  1
94266  95.011  -78.221  50.494  1
94267  95.030  -78.223  50.448  1
94268  95.051  -78.228  50.403  1
94269  95.079  -78.244  50.361  1
94270  95.126  -78.291  50.320  1
94271  95.174  -78.336  50.278  1
94272  95.214  -78.370  50.236  1
94273  95.225  -78.359  50.195  1
94274  95.235  -78.348  50.155  1
94275  95.246  -78.337  50.114  1
94276  95.257  -78.326  50.073  1
94277  95.267  -78.314  50.034  1
94278  95.278  -78.304  49.995  1
94279  95.288  -78.292  49.957  1
94280  95.299  -78.283  49.920  1
94281  95.308  -78.286  49.883  1
94282  95.317  -78.289  49.847  1
94283  95.327  -78.291  49.812  1
94284  95.336  -78.294  49.778  1
94285  95.345  -78.297  49.743  1
94286  95.355  -78.300  49.709  1
94287  95.372  -78.308  49.672  1
94288  95.396  -78.320  49.635  1
94289  95.420  -78.332  49.599  1
94290  95.444  -78.344  49.563  1
94291  95.468  -78.356  49.530  1
94292  95.492  -78.367  49.497  1
94293  95.516  -78.379  49.462  1
94294  95.540  -78.391  49.429  1
94295  95.548  -78.393  49.397  1
94296  95.553  -78.393  49.365  1
94297  95.558  -78.392  49.333  1
94298  95.563  -78.392  49.302  1
94299  95.569  -78.391  49.271  1
94300  95.574  -78.391  49.240  1
94301  95.579  -78.391  49.207  1
94302  95.585  -78.392  49.173  1
94303  95.594  -78.399  49.138  1
94304  95.603  -78.406  49.104  1
94305  95.612  -78.413  49.070  1
94306  95.621  -78.420  49.034  1
94307  95.631  -78.427  48.997  1
94308  95.640  -78.435  48.961  1
94309  95.637  -78.432  48.924  1
94310  95.633  -78.429  48.888  1
94311  95.629  -78.425  48.847  1
94312  95.625  -78.422  48.807  1
94313  95.621  -78.418  48.765  1
94314  95.617  -78.415  48.724  1
94315  95.598  -78.414  48.682  1
94316  95.618  -78.416  48.640  1
94317  95.633  -78.420  48.598  1
94318  95.649  -78.424  48.559  1
94319  95.665  -78.430  48.519  1
94320  95.681  -78.435  48.480  1
94321  95.697  -78.442  48.440  1
94322  95.712  -78.444  48.400  1
94323  95.736  -78.448  48.359  1
94324  95.758  -78.452  48.317  1
94325  95.780  -78.456  48.275  1
94326  95.801  -78.459  48.232  1
94327  95.821  -78.457  48.190  1
94328  95.840  -78.455  48.149  1
94329  95.860  -78.454  48.107  1
94330  95.879  -78.452  48.067  1
94331  95.888  -78.451  48.027  1
94332  95.897  -78.451  47.986  1
94333  95.907  -78.450  47.946  1
94334  95.920  -78.453  47.906  1
94335  95.935  -78.455  47.865  1
94336  95.951  -78.459  47.826  1
94337  95.969  -78.463  47.786  1
94338  95.985  -78.470  47.748  1
94339  95.999  -78.476  47.711  1
94340  96.012  -78.479  47.673  1
94341  96.025  -78.480  47.636  1
94342  96.037  -78.483  47.598  1
94343  96.050  -78.492  47.561  1
94344  96.062  -78.497  47.523  1
94345  96.073  -78.498  47.486  1
94346  96.083  -78.499  47.452  1
94347  96.091  -78.528  47.417  1
94348  96.099  -78.562  47.382  1
94349  96.108  -78.597  47.348  1
94350  96.128  -78.613  47.317  1
94351  96.154  -78.617  47.286  1
94352  96.181  -78.621  47.256  1
94353  96.207  -78.626  47.228  1
94354  96.234  -78.630  47.200  1
94355  96.260  -78.633  47.171  1
94356  96.287  -78.638  47.140  1
94357  96.313  -78.642  47.112  1
94358  96.340  -78.646  47.084  1
94359  96.366  -78.650  47.056  1
94360  96.393  -78.655  47.027  1
94361  96.419  -78.658  46.998  1
94362  96.438  -78.662  46.969  1
94363  96.431  -78.649  46.940  1
94364  96.413  -78.624  46.910  1
94365  96.409  -78.610  46.880  1
94366  96.405  -78.595  46.851  1
94367  96.455  -78.605  46.824  1
94368  96.504  -78.615  46.798  1
94369  96.553  -78.626  46.772  1
94370  96.602  -78.636  46.746  1
94371  96.651  -78.645  46.724  1
94372  96.700  -78.655  46.701  1
94373  96.749  -78.665  46.678  1
94374  96.783  -78.675  46.656  1
94375  96.784  -78.686  46.633  1
94376  96.784  -78.697  46.611  1
94377  96.802  -78.708  46.589  1
94378  96.822  -78.718  46.568  1
94379  96.842  -78.729  46.547  1
94380  96.859  -78.741  46.526  1
94381  96.859  -78.760  46.502  1
94382  96.860  -78.778  46.479  1
94383  96.871  -78.793  46.457  1
94384  96.882  -78.805  46.436  1
94385  96.892  -78.816  46.416  1
94386  96.902  -78.827  46.397  1
94387  96.912  -78.837  46.378  1
94388  96.923  -78.849  46.360  1
94389  96.921  -78.856  46.341  1
94390  96.938  -78.865  46.323  1
94391  96.963  -78.871  46.305  1
94392  96.989  -78.876  46.287  1
94393  97.018  -78.886  46.270  1
94394  97.046  -78.897  46.255  1
94395  97.075  -78.908  46.240  1
94396  97.104  -78.919  46.225  1
94397  97.133  -78.930  46.211  1
94398  97.162  -78.941  46.196  1
94399  97.191  -78.952  46.182  1
94400  97.220  -78.962  46.169  1
94401  97.249  -78.974  46.156  1
94402  97.287  -78.991  46.140  1
94403  97.328  -79.012  46.125  1
94404  97.351  -79.021  46.109  1
94405  97.367  -79.020  46.091  1
94406  97.382  -79.018  46.074  1
94407  97.398  -79.018  46.058  1
94408  97.414  -79.017  46.041  1
94409  97.424  -79.012  46.021  1
94410  97.432  -79.007  46.003  1
94411  97.440  -79.001  45.983  1
94412  97.448  -78.995  45.962  1
94413  97.457  -78.989  45.944  1
94414  97.465  -78.983  45.928  1
94415  97.473  -78.977  45.913  1
94416  97.481  -78.971  45.897  1
94417  97.490  -78.965  45.881  1
94418  97.498  -78.959  45.867  1
94419  97.506  -78.956  45.854  1
94420  97.514  -78.954  45.842  1
94421  97.522  -78.952  45.830  1
94422  97.531  -78.949  45.816  1
94423  97.539  -78.947  45.800  1
94424  97.547  -78.945  45.784  1
94425  97.550  -78.985  45.766  1
94426  97.571  -79.029  45.747  1
94427  97.595  -79.070  45.726  1
94428  97.597  -79.071  45.704  1
94429  97.599  -79.068  45.683  1
94430  97.602  -79.066  45.663  1
94431  97.604  -79.063  45.643  1
94432  97.607  -79.060  45.623  1
94433  97.609  -79.058  45.604  1
94434  97.612  -79.055  45.587  1
94435  97.614  -79.052  45.569  1
94436  97.617  -79.049  45.553  1
94437  97.619  -79.046  45.536  1
94438  97.649  -79.065  45.521  1
94439  97.684  -79.087  45.506  1
94440  97.720  -79.111  45.493  1
94441  97.752  -79.131  45.478  1
94442  97.759  -79.137  45.465  1
94443  97.767  -79.141  45.452  1
94444  97.774  -79.147  45.439  1
94445  97.781  -79.152  45.426  1
94446  97.785  -79.165  45.414  1
94447  97.789  -79.178  45.402  1
94448  97.793  -79.192  45.392  1
94449  97.797  -79.206  45.382  1
94450  97.802  -79.219  45.372  1
94451  97.821  -79.224  45.363  1
94452  97.839  -79.216  45.353  1
94453  97.857  -79.208  45.344  1
94454  97.874  -79.200  45.336  1
94455  97.892  -79.191  45.329  1
94456  97.910  -79.183  45.322  1
94457  97.928  -79.175  45.316  1
94458  97.962  -79.202  45.308  1
94459  97.997  -79.229  45.300  1
94460  98.032  -79.256  45.292  1
94461  98.084  -79.300  45.283  1
94462  98.110  -79.303  45.275  1
94463  98.135  -79.300  45.266  1
94464  98.159  -79.295  45.257  1
94465  98.183  -79.291  45.250  1
94466  98.223  -79.289  45.240  1
94467  98.249  -79.293  45.231  1
94468  98.275  -79.296  45.224  1
94469  98.301  -79.300  45.217  1
94470  98.327  -79.303  45.210  1
94471  98.353  -79.306  45.203  1
94472  98.381  -79.313  45.193  1
94473  98.414  -79.324  45.184  1
94474  98.447  -79.336  45.175  1
94475  98.480  -79.347  45.167  1
94476  98.512  -79.360  45.158  1
94477  98.545  -79.371  45.148  1
94478  98.580  -79.383  45.138  1
94479  98.617  -79.395  45.129  1
94480  98.653  -79.407  45.118  1
94481  98.690  -79.420  45.107  1
94482  98.726  -79.432  45.099  1
94483  98.763  -79.444  45.091  1
94484  98.781  -79.451  45.083  1
94485  98.782  -79.454  45.074  1
94486  98.782  -79.456  45.067  1
94487  98.783  -79.458  45.058  1
94488  98.803  -79.473  45.049  1
94489  98.827  -79.491  45.039  1
94490  98.850  -79.508  45.030  1
94491  98.872  -79.523  45.023  1
94492  98.894  -79.539  45.018  1
94493  98.916  -79.554  45.011  1
94494  98.949  -79.561  45.002  1
94495  98.991  -79.562  44.991  1
94496  99.031  -79.563  44.980  1
94497  99.073  -79.564  44.971  1
94498  99.114  -79.565  44.961  1
94499  99.162  -79.557  44.952  1
94500  99.177  -79.560  44.940  1
94501  99.187  -79.565  44.928  1
94502  99.197  -79.570  44.917  1
94503  99.209  -79.582  44.906  1
94504  99.224  -79.596  44.896  1
94505  99.239  -79.610  44.886  1
94506  99.254  -79.626  44.877  1
94507  99.269  -79.640  44.867  1
94508  99.284  -79.654  44.857  1
94509  99.299  -79.669  44.848  1
94510  99.307  -79.683  44.838  1
94511  99.321  -79.694  44.827  1
94512  99.342  -79.696  44.817  1
94513  99.357  -79.690  44.807  1
94514  99.372  -79.685  44.798  1
94515  99.387  -79.679  44.789  1
94516  99.403  -79.673  44.779  1
94517  99.418  -79.667  44.770  1
94518  99.433  -79.661  44.759  1
94519  99.448  -79.655  44.748  1
94520  99.463  -79.650  44.738  1
94521  99.478  -79.644  44.729  1
94522  99.493  -79.638  44.721  1
94523  99.508  -79.632  44.714  1
94524  99.515  -79.642  44.706  1
94525  99.527  -79.668  44.698  1
94526  99.547  -79.693  44.690  1
94527  99.567  -79.717  44.681  1
94528  99.586  -79.742  44.674  1
94529  99.606  -79.767  44.668  1
94530  99.626  -79.792  44.661  1
94531  99.645  -79.816  44.656  1
94532  99.665  -79.840  44.650  1
94533  99.685  -79.865  44.643  1
94534  99.704  -79.889  44.636  1
94535  99.724  -79.914  44.630  1
94536  99.744  -79.939  44.623  1
94537  99.763  -79.964  44.616  1
94538  99.783  -79.988  44.608  1
94539  99.804  -80.015  44.600  1
94540  99.841  -80.055  44.591  1
94541  99.864  -80.087  44.582  1
94542  99.890  -80.118  44.574  1
94543  99.918  -80.147  44.565  1
94544  99.946  -80.176  44.556  1
94545  99.973  -80.204  44.547  1
94546  99.996  -80.232  44.536  1
94547  100.018  -80.260  44.525  1
94548  100.042  -80.288  44.512  1
94549  100.065  -80.316  44.499  1
94550  100.100  -80.341  44.486  1
94551  100.169  -80.359  44.472  1
94552  100.239  -80.377  44.457  1
94553  100.292  -80.380  44.442  1
94554  100.312  -80.416  44.426  1
94555  100.332  -80.465  44.410  1
94556  100.364  -80.497  44.393  1
94557  100.409  -80.513  44.376  1
94558  100.454  -80.530  44.359  1
94559  100.498  -80.546  44.343  1
94560  100.543  -80.563  44.326  1
94561  100.587  -80.579  44.309  1
94562  100.632  -80.595  44.293  1
94563  100.676  -80.612  44.277  1
94564  100.716  -80.634  44.262  1
94565  100.757  -80.656  44.248  1
94566  100.796  -80.678  44.232  1
94567  100.837  -80.701  44.218  1
94568  100.877  -80.723  44.203  1
94569  100.917  -80.745  44.189  1
94570  100.958  -80.767  44.174  1
94571  100.998  -80.789  44.159  1
94572  101.038  -80.811  44.145  1
94573  101.078  -80.833  44.131  1
94574  101.119  -80.855  44.118  1
94575  101.159  -80.877  44.105  1
94843  93.522  -78.617  53.766  1
94844  93.532  -78.614  53.752  1
94845  93.541  -78.611  53.737  1
94846  93.551  -78.609  53.721  1
94847  93.561  -78.607  53.706  1
94848  93.570  -78.604  53.690  1
94849  93.580  -78.601  53.674  1
94850  93.588  -78.598  53.658  1
94851  93.587  -78.589  53.641  1
94852  93.586  -78.580  53.625  1
94853  93.584  -78.571  53.609  1
94854  93.583  -78.562  53.592  1
94855  93.582  -78.553  53.575  1
94856  93.590  -78.538  53.557  1
94857  93.612  -78.523  53.541  1
94858  93.635  -78.508  53.525  1
94859  93.657  -78.493  53.508  1
94860  93.677  -78.479  53.491  1
94861  93.689  -78.471  53.473  1
94862  93.703  -78.463  53.455  1
94863  93.718  -78.456  53.437  1
94864  93.734  -78.448  53.418  1
94865  93.749  -78.442  53.399  1
94866  93.765  -78.434  53.381  1
94867  93.780  -78.426  53.363  1
94868  93.795  -78.420  53.344  1
94869  93.811  -78.412  53.326  1
94870  93.826  -78.404  53.307  1
94871  93.842  -78.398  53.288  1
94872  93.856  -78.391  53.268  1
94873  93.871  -78.386  53.249  1
94874  93.886  -78.381  53.230  1
94875  93.898  -78.374  53.211  1
94876  93.897  -78.357  53.193  1
94877  93.895  -78.340  53.174  1
94878  93.894  -78.322  53.155  1
94879  93.901  -78.307  53.138  1
94880  93.929  -78.300  53.121  1
94881  93.943  -78.308  53.104  1
94882  93.957  -78.317  53.089  1
94883  93.970  -78.326  53.072  1
94884  93.983  -78.334  53.055  1
94885  93.997  -78.343  53.039  1
94886  94.008  -78.349  53.023  1
94887  94.016  -78.353  53.009  1
94888  94.025  -78.357  52.995  1
94889  94.033  -78.360  52.981  1
94890  94.041  -78.364  52.967  1
94891  94.051  -78.368  52.953  1
94892  94.063  -78.373  52.938  1
94893  94.075  -78.378  52.927  1
94894  94.085  -78.382  52.917  1
94895  94.096  -78.387  52.907  1
94896  94.105  -78.391  52.897  1
94897  94.115  -78.395  52.887  1
94898  94.124  -78.401  52.877  1
94899  94.128  -78.410  52.869  1
94900  94.133  -78.419  52.861  1
94901  94.138  -78.426  52.852  1
94902  94.142  -78.429  52.842  1
94903  94.147  -78.431  52.831  1
94904  94.151  -78.433  52.814  1
94905  94.156  -78.436  52.799  1
94906  94.160  -78.441  52.786  1
94907  94.164  -78.445  52.775  1
94908  94.168  -78.449  52.764  1
94909  94.176  -78.452  52.752  1
94910  94.197  -78.448  52.738  1
94911  94.219  -78.444  52.724  1
94912  94.239  -78.432  52.708  1
94913  94.257  -78.418  52.691  1
94914  94.277  -78.412  52.672  1
94915  94.296  -78.416  52.652  1
94916  94.305  -78.433  52.630  1
94917  94.313  -78.451  52.607  1
94918  94.322  -78.468  52.579  1
94919  94.330  -78.485  52.550  1
94920  94.339  -78.502  52.520  1
94921  94.347  -78.520  52.490  1
94922  94.356  -78.537  52.461  1
94923  94.364  -78.554  52.431  1
94924  94.384  -78.561  52.400  1
94925  94.409  -78.546  52.364  1
94926  94.433  -78.530  52.328  1
94927  94.458  -78.514  52.292  1
94928  94.482  -78.497  52.257  1
94929  94.507  -78.480  52.226  1
94930  94.531  -78.464  52.194  1
94931  94.556  -78.448  52.161  1
94932  94.580  -78.431  52.124  1
94933  94.595  -78.422  52.084  1
94934  94.606  -78.416  52.045  1
94935  94.616  -78.410  52.007  1
94936  94.627  -78.407  51.967  1
94937  94.639  -78.409  51.925  1
94938  94.651  -78.410  51.880  1
94939  94.664  -78.413  51.833  1
94940  94.676  -78.415  51.786  1
94941  94.688  -78.416  51.738  1
94942  94.700  -78.419  51.690  1
94943  94.712  -78.419  51.639  1
94944  94.725  -78.420  51.586  1
94945  94.744  -78.411  51.532  1
94946  94.763  -78.404  51.478  1
94947  94.781  -78.396  51.427  1
94948  94.800  -78.388  51.377  1
94949  94.814  -78.393  51.330  1
94950  94.831  -78.402  51.286  1
94951  94.848  -78.410  51.243  1
94952  94.864  -78.420  51.202  1
94953  94.876  -78.419  51.162  1
94954  94.886  -78.402  51.119  1
94955  94.895  -78.386  51.073  1
94956  94.905  -78.369  51.025  1
94957  94.915  -78.354  50.977  1
94958  94.924  -78.337  50.929  1
94959  94.934  -78.321  50.880  1
94960  94.944  -78.305  50.829  1
94961  94.954  -78.288  50.778  1
94962  94.964  -78.272  50.727  1
94963  94.973  -78.256  50.677  1
94964  94.983  -78.240  50.628  1
94965  94.993  -78.224  50.580  1
94966  95.003  -78.207  50.533  1
94967  95.018  -78.197  50.488  1
94968  95.057  -78.232  50.443  1
94969  95.105  -78.277  50.399  1
94970  95.153  -78.322  50.356  1
94971  95.199  -78.367  50.315  1
94972  95.210  -78.356  50.274  1
94973  95.220  -78.344  50.232  1
94974  95.231  -78.334  50.192  1
94975  95.242  -78.322  50.152  1
94976  95.252  -78.311  50.113  1
94977  95.263  -78.300  50.073  1
94978  95.273  -78.289  50.034  1
94979  95.284  -78.278  49.996  1
94980  95.295  -78.266  49.957  1
94981  95.305  -78.261  49.920  1
94982  95.314  -78.264  49.885  1
94983  95.323  -78.267  49.849  1
94984  95.333  -78.270  49.814  1
94985  95.342  -78.272  49.779  1
94986  95.351  -78.275  49.744  1
94987  95.361  -78.279  49.708  1
94988  95.370  -78.282  49.672  1
94989  95.387  -78.288  49.636  1
94990  95.411  -78.300  49.602  1
94991  95.435  -78.313  49.567  1
94992  95.459  -78.324  49.535  1
94993  95.483  -78.336  49.503  1
94994  95.507  -78.348  49.469  1
94995  95.531  -78.360  49.436  1
94996  95.539  -78.362  49.405  1
94997  95.544  -78.362  49.374  1
94998  95.550  -78.361  49.342  1
94999  95.555  -78.361  49.311  1
95000  95.560  -78.360  49.279  1
95001  95.565  -78.360  49.247  1
95002  95.571  -78.361  49.215  1
95003  95.580  -78.368  49.183  1
95004  95.589  -78.376  49.150  1
95005  95.598  -78.382  49.116  1
95006  95.608  -78.390  49.082  1
95007  95.617  -78.397  49.047  1
95008  95.626  -78.404  49.010  1
95009  95.635  -78.411  48.974  1
95010  95.636  -78.411  48.938  1
95011  95.632  -78.408  48.902  1
95012  95.628  -78.404  48.862  1
95013  95.624  -78.401  48.822  1
95014  95.620  -78.398  48.781  1
95015  95.615  -78.394  48.740  1
95016  95.611  -78.391  48.699  1
95017  95.621  -78.393  48.659  1
95018  95.637  -78.399  48.618  1
95019  95.654  -78.405  48.578  1
95020  95.670  -78.411  48.538  1
95021  95.686  -78.417  48.497  1
95022  95.701  -78.422  48.455  1
95023  95.713  -78.423  48.414  1
95024  95.737  -78.427  48.372  1
95025  95.760  -78.431  48.331  1
95026  95.783  -78.435  48.289  1
95027  95.804  -78.437  48.246  1
95028  95.824  -78.435  48.204  1
95029  95.842  -78.434  48.161  1
95030  95.859  -78.433  48.120  1
95031  95.874  -78.432  48.080  1
95032  95.885  -78.432  48.041  1
95033  95.895  -78.431  48.001  1
95034  95.905  -78.430  47.961  1
95035  95.917  -78.431  47.921  1
95036  95.930  -78.432  47.881  1
95037  95.945  -78.435  47.842  1
95038  95.959  -78.442  47.803  1
95039  95.973  -78.449  47.765  1
95040  95.987  -78.456  47.729  1
95041  96.001  -78.460  47.691  1
95042  96.013  -78.464  47.653  1
95043  96.026  -78.472  47.614  1
95044  96.038  -78.480  47.576  1
95045  96.051  -78.488  47.539  1
95046  96.062  -78.492  47.505  1
95047  96.070  -78.500  47.470  1
95048  96.075  -78.511  47.435  1
95049  96.083  -78.538  47.400  1
95050  96.092  -78.573  47.366  1
95051  96.112  -78.588  47.334  1
95052  96.138  -78.592  47.303  1
95053  96.165  -78.596  47.274  1
95054  96.191  -78.600  47.246  1
95055  96.218  -78.604  47.218  1
95056  96.244  -78.608  47.190  1
95057  96.270  -78.613  47.161  1
95058  96.297  -78.617  47.131  1
95059  96.324  -78.621  47.102  1
95060  96.350  -78.625  47.074  1
95061  96.377  -78.630  47.048  1
95062  96.405  -78.634  47.018  1
95063  96.434  -78.640  46.988  1
95064  96.463  -78.644  46.958  1
95065  96.472  -78.636  46.927  1
95066  96.468  -78.621  46.898  1
95067  96.464  -78.607  46.870  1
95068  96.461  -78.592  46.843  1
95069  96.510  -78.602  46.818  1
95070  96.559  -78.612  46.791  1
95071  96.608  -78.622  46.764  1
95072  96.657  -78.632  46.743  1
95073  96.707  -78.642  46.721  1
95074  96.755  -78.651  46.698  1
95075  96.773  -78.662  46.675  1
95076  96.774  -78.673  46.653  1
95077  96.774  -78.684  46.630  1
95078  96.789  -78.695  46.607  1
95079  96.809  -78.705  46.584  1
95080  96.829  -78.716  46.563  1
95081  96.839  -78.731  46.542  1
95082  96.839  -78.749  46.519  1
95083  96.847  -78.766  46.497  1
95084  96.859  -78.780  46.475  1
95085  96.870  -78.792  46.452  1
95086  96.880  -78.802  46.433  1
95087  96.890  -78.813  46.414  1
95088  96.900  -78.824  46.396  1
95089  96.910  -78.834  46.378  1
95090  96.920  -78.846  46.359  1
95091  96.936  -78.852  46.339  1
95092  96.965  -78.863  46.320  1
95093  96.994  -78.874  46.302  1
95094  97.023  -78.885  46.286  1
95095  97.051  -78.896  46.270  1
95096  97.080  -78.907  46.255  1
95097  97.109  -78.918  46.240  1
95098  97.138  -78.928  46.224  1
95099  97.167  -78.940  46.209  1
95100  97.196  -78.950  46.197  1
95101  97.225  -78.961  46.184  1
95102  97.254  -78.972  46.170  1
95103  97.286  -78.985  46.154  1
95104  97.333  -79.010  46.139  1
95105  97.357  -79.014  46.122  1
95106  97.373  -79.013  46.103  1
95107  97.388  -79.012  46.085  1
95108  97.404  -79.012  46.068  1
95109  97.420  -79.011  46.050  1
95110  97.432  -79.007  46.031  1
95111  97.440  -79.001  46.013  1
95112  97.448  -78.996  45.993  1
95113  97.456  -78.990  45.972  1
95114  97.464  -78.984  45.956  1
95115  97.472  -78.977  45.940  1
95116  97.480  -78.971  45.924  1
95117  97.489  -78.966  45.908  1
95118  97.497  -78.960  45.893  1
95119  97.505  -78.954  45.879  1
95120  97.513  -78.948  45.866  1
95121  97.522  -78.942  45.855  1
95122  97.530  -78.936  45.842  1
95123  97.538  -78.932  45.829  1
95124  97.546  -78.930  45.814  1
95125  97.555  -78.927  45.798  1
95126  97.560  -78.949  45.779  1
95127  97.583  -78.993  45.759  1
95128  97.604  -79.031  45.737  1
95129  97.617  -79.050  45.715  1
95130  97.620  -79.048  45.694  1
95131  97.623  -79.045  45.674  1
95132  97.626  -79.042  45.655  1
95133  97.628  -79.040  45.636  1
95134  97.631  -79.037  45.616  1
95135  97.633  -79.034  45.598  1
95136  97.636  -79.031  45.581  1
95137  97.638  -79.028  45.565  1
95138  97.652  -79.035  45.549  1
95139  97.688  -79.058  45.534  1
95140  97.724  -79.081  45.521  1
95141  97.756  -79.103  45.507  1
95142  97.764  -79.107  45.493  1
95143  97.771  -79.112  45.479  1
95144  97.778  -79.118  45.466  1
95145  97.786  -79.123  45.454  1
95146  97.793  -79.128  45.441  1
95147  97.798  -79.137  45.428  1
95148  97.802  -79.151  45.416  1
95149  97.806  -79.165  45.405  1
95150  97.810  -79.178  45.395  1
95151  97.814  -79.192  45.385  1
95152  97.826  -79.200  45.374  1
95153  97.842  -79.193  45.364  1
95154  97.857  -79.182  45.355  1
95155  97.872  -79.172  45.346  1
95156  97.887  -79.161  45.337  1
95157  97.901  -79.151  45.329  1
95158  97.917  -79.140  45.321  1
95159  97.932  -79.130  45.313  1
95160  97.947  -79.120  45.305  1
95161  98.008  -79.172  45.297  1
95162  98.069  -79.225  45.287  1
95163  98.114  -79.258  45.279  1
95164  98.141  -79.267  45.271  1
95165  98.166  -79.266  45.263  1
95166  98.191  -79.262  45.257  1
95167  98.223  -79.263  45.249  1
95168  98.249  -79.267  45.240  1
95169  98.275  -79.270  45.232  1
95170  98.301  -79.274  45.225  1
95171  98.327  -79.277  45.217  1
95172  98.353  -79.280  45.208  1
95173  98.379  -79.285  45.197  1
95174  98.412  -79.296  45.186  1
95175  98.445  -79.308  45.176  1
95176  98.478  -79.319  45.166  1
95177  98.511  -79.332  45.156  1
95178  98.545  -79.344  45.146  1
95179  98.582  -79.356  45.136  1
95180  98.618  -79.368  45.126  1
95181  98.655  -79.380  45.116  1
95182  98.692  -79.392  45.106  1
95183  98.728  -79.404  45.098  1
95184  98.765  -79.417  45.088  1
95185  98.795  -79.427  45.079  1
95186  98.795  -79.429  45.071  1
95187  98.796  -79.432  45.064  1
95188  98.796  -79.434  45.056  1
95189  98.819  -79.451  45.047  1
95190  98.843  -79.468  45.038  1
95191  98.866  -79.485  45.030  1
95192  98.889  -79.503  45.024  1
95193  98.912  -79.518  45.018  1
95194  98.933  -79.534  45.012  1
95195  98.962  -79.545  45.004  1
95196  99.003  -79.545  44.993  1
95197  99.044  -79.546  44.982  1
95198  99.085  -79.548  44.972  1
95199  99.131  -79.542  44.962  1
95200  99.162  -79.537  44.953  1
95201  99.172  -79.543  44.942  1
95202  99.182  -79.548  44.931  1
95203  99.192  -79.554  44.919  1
95204  99.205  -79.565  44.907  1
95205  99.219  -79.579  44.898  1
95206  99.234  -79.594  44.888  1
95207  99.250  -79.609  44.879  1
95208  99.264  -79.623  44.868  1
95209  99.279  -79.638  44.860  1
95210  99.294  -79.652  44.852  1
95211  99.309  -79.667  44.842  1
95212  99.324  -79.679  44.833  1
95213  99.339  -79.673  44.824  1
95214  99.354  -79.667  44.814  1
95215  99.369  -79.661  44.805  1
95216  99.384  -79.656  44.795  1
95217  99.400  -79.650  44.785  1
95218  99.415  -79.645  44.775  1
95219  99.431  -79.639  44.765  1
95220  99.446  -79.634  44.755  1
95221  99.462  -79.629  44.745  1
95222  99.477  -79.623  44.735  1
95223  99.492  -79.617  44.728  1
95224  99.507  -79.612  44.720  1
95225  99.531  -79.619  44.712  1
95226  99.549  -79.644  44.704  1
95227  99.569  -79.668  44.696  1
95228  99.588  -79.693  44.688  1
95229  99.608  -79.717  44.681  1
95230  99.628  -79.742  44.676  1
95231  99.647  -79.767  44.670  1
95232  99.667  -79.791  44.665  1
95233  99.687  -79.816  44.659  1
95234  99.706  -79.840  44.653  1
95235  99.726  -79.865  44.646  1
95236  99.746  -79.889  44.640  1
95237  99.765  -79.914  44.633  1
95238  99.785  -79.939  44.626  1
95239  99.804  -79.963  44.618  1
95240  99.828  -79.991  44.610  1
95241  99.859  -80.028  44.601  1
95242  99.883  -80.061  44.592  1
95243  99.912  -80.089  44.584  1
95244  99.940  -80.118  44.576  1
95245  99.969  -80.146  44.568  1
95246  99.994  -80.175  44.558  1
95247  100.017  -80.203  44.548  1
95248  100.040  -80.231  44.537  1
95249  100.063  -80.259  44.525  1
95250  100.086  -80.287  44.511  1
95251  100.114  -80.313  44.497  1
95252  100.150  -80.338  44.483  1
95253  100.213  -80.358  44.468  1
95254  100.283  -80.375  44.453  1
95255  100.346  -80.386  44.437  1
95256  100.366  -80.418  44.419  1
95257  100.386  -80.466  44.402  1
95258  100.411  -80.508  44.385  1
95259  100.456  -80.524  44.368  1
95260  100.500  -80.541  44.351  1
95261  100.545  -80.557  44.333  1
95262  100.590  -80.573  44.317  1
95263  100.632  -80.592  44.301  1
95264  100.672  -80.614  44.285  1
95265  100.712  -80.636  44.269  1
95266  100.753  -80.659  44.254  1
95267  100.792  -80.681  44.238  1
95268  100.833  -80.703  44.224  1
95269  100.873  -80.725  44.209  1
95270  100.913  -80.747  44.194  1
95271  100.954  -80.769  44.179  1
95272  100.994  -80.791  44.164  1
95273  101.034  -80.813  44.149  1
95274  101.074  -80.835  44.135  1
95275  101.115  -80.857  44.122  1
95276  101.159  -80.872  44.108  1
95277  101.206  -80.885  44.094  1
95543  93.512  -78.608  53.784  1
95544  93.522  -78.606  53.770  1
95545  93.532  -78.603  53.757  1
95546  93.542  -78.601  53.741  1
95547  93.551  -78.598  53.725  1
95548  93.561  -78.596  53.710  1
95549  93.570  -78.593  53.694  1
95550  93.580  -78.591  53.677  1
95551  93.585  -78.586  53.661  1
95552  93.584  -78.576  53.643  1
95553  93.582  -78.567  53.626  1
95554  93.581  -78.557  53.609  1
95555  93.580  -78.548  53.592  1
95556  93.581  -78.538  53.574  1
95557  93.595  -78.523  53.556  1
95558  93.618  -78.507  53.539  1
95559  93.640  -78.492  53.522  1
95560  93.662  -78.477  53.504  1
95561  93.679  -78.467  53.487  1
95562  93.690  -78.458  53.469  1
95563  93.705  -78.451  53.451  1
95564  93.720  -78.443  53.433  1
95565  93.735  -78.436  53.415  1
95566  93.751  -78.429  53.395  1
95567  93.767  -78.421  53.377  1
95568  93.782  -78.414  53.358  1
95569  93.797  -78.407  53.339  1
95570  93.813  -78.399  53.321  1
95571  93.828  -78.391  53.302  1
95572  93.844  -78.385  53.283  1
95573  93.859  -78.377  53.264  1
95574  93.874  -78.371  53.245  1
95575  93.889  -78.366  53.226  1
95576  93.903  -78.360  53.207  1
95577  93.909  -78.348  53.189  1
95578  93.907  -78.331  53.170  1
95579  93.906  -78.314  53.152  1
95580  93.916  -78.298  53.135  1
95581  93.939  -78.297  53.118  1
95582  93.953  -78.306  53.102  1
95583  93.967  -78.314  53.087  1
95584  93.980  -78.322  53.070  1
95585  93.993  -78.332  53.054  1
95586  94.003  -78.337  53.039  1
95587  94.011  -78.341  53.025  1
95588  94.019  -78.344  53.011  1
95589  94.028  -78.347  52.998  1
95590  94.036  -78.351  52.984  1
95591  94.044  -78.355  52.972  1
95592  94.053  -78.359  52.958  1
95593  94.065  -78.364  52.944  1
95594  94.077  -78.369  52.931  1
95595  94.087  -78.373  52.921  1
95596  94.097  -78.378  52.910  1
95597  94.107  -78.382  52.899  1
95598  94.116  -78.387  52.887  1
95599  94.120  -78.396  52.877  1
95600  94.125  -78.404  52.869  1
95601  94.129  -78.413  52.861  1
95602  94.134  -78.423  52.854  1
95603  94.139  -78.428  52.845  1
95604  94.143  -78.430  52.835  1
95605  94.148  -78.432  52.819  1
95606  94.152  -78.435  52.805  1
95607  94.157  -78.437  52.792  1
95608  94.161  -78.439  52.782  1
95609  94.166  -78.443  52.772  1
95610  94.170  -78.448  52.762  1
95611  94.192  -78.443  52.749  1
95612  94.211  -78.431  52.733  1
95613  94.229  -78.417  52.716  1
95614  94.248  -78.404  52.696  1
95615  94.268  -78.400  52.674  1
95616  94.289  -78.401  52.651  1
95617  94.301  -78.414  52.627  1
95618  94.310  -78.432  52.603  1
95619  94.318  -78.449  52.574  1
95620  94.326  -78.467  52.543  1
95621  94.335  -78.483  52.513  1
95622  94.343  -78.501  52.483  1
95623  94.352  -78.518  52.453  1
95624  94.360  -78.535  52.421  1
95625  94.381  -78.529  52.389  1
95626  94.414  -78.535  52.353  1
95627  94.438  -78.519  52.316  1
95628  94.463  -78.502  52.281  1
95629  94.487  -78.485  52.246  1
95630  94.511  -78.469  52.215  1
95631  94.536  -78.453  52.184  1
95632  94.560  -78.436  52.151  1
95633  94.585  -78.420  52.111  1
95634  94.601  -78.410  52.070  1
95635  94.611  -78.404  52.029  1
95636  94.622  -78.398  51.988  1
95637  94.632  -78.392  51.946  1
95638  94.644  -78.392  51.903  1
95639  94.656  -78.395  51.857  1
95640  94.668  -78.396  51.809  1
95641  94.680  -78.398  51.762  1
95642  94.692  -78.401  51.715  1
95643  94.705  -78.402  51.667  1
95644  94.717  -78.401  51.618  1
95645  94.729  -78.402  51.567  1
95646  94.743  -78.401  51.515  1
95647  94.762  -78.393  51.463  1
95648  94.780  -78.385  51.413  1
95649  94.799  -78.378  51.365  1
95650  94.812  -78.381  51.322  1
95651  94.827  -78.388  51.280  1
95652  94.844  -78.397  51.240  1
95653  94.861  -78.405  51.201  1
95654  94.886  -78.407  51.159  1
95655  94.897  -78.408  51.113  1
95656  94.907  -78.410  51.065  1
95657  94.918  -78.411  51.014  1
95658  94.929  -78.410  50.965  1
95659  94.938  -78.393  50.915  1
95660  94.948  -78.376  50.866  1
95661  94.958  -78.359  50.815  1
95662  94.968  -78.342  50.764  1
95663  94.977  -78.325  50.714  1
95664  94.987  -78.308  50.666  1
95665  94.997  -78.291  50.618  1
95666  95.006  -78.274  50.571  1
95667  95.016  -78.257  50.525  1
95668  95.075  -78.271  50.481  1
95669  95.131  -78.310  50.438  1
95670  95.179  -78.355  50.395  1
95671  95.195  -78.353  50.352  1
95672  95.205  -78.341  50.311  1
95673  95.216  -78.330  50.270  1
95674  95.227  -78.319  50.230  1
95675  95.237  -78.308  50.190  1
95676  95.248  -78.297  50.150  1
95677  95.258  -78.286  50.112  1
95678  95.269  -78.275  50.073  1
95679  95.280  -78.263  50.035  1
95680  95.290  -78.252  49.997  1
95681  95.301  -78.241  49.959  1
95682  95.311  -78.239  49.922  1
95683  95.320  -78.242  49.886  1
95684  95.329  -78.245  49.851  1
95685  95.339  -78.248  49.815  1
95686  95.348  -78.250  49.780  1
95687  95.357  -78.253  49.745  1
95688  95.367  -78.257  49.709  1
95689  95.376  -78.260  49.674  1
95690  95.386  -78.262  49.639  1
95691  95.402  -78.269  49.606  1
95692  95.426  -78.281  49.573  1
95693  95.450  -78.293  49.542  1
95694  95.474  -78.305  49.510  1
95695  95.497  -78.317  49.477  1
95696  95.522  -78.329  49.446  1
95697  95.531  -78.331  49.415  1
95698  95.536  -78.331  49.385  1
95699  95.541  -78.330  49.353  1
95700  95.546  -78.329  49.322  1
95701  95.551  -78.329  49.291  1
95702  95.557  -78.330  49.260  1
95703  95.566  -78.338  49.229  1
95704  95.575  -78.344  49.197  1
95705  95.584  -78.352  49.164  1
95706  95.594  -78.359  49.129  1
95707  95.603  -78.366  49.094  1
95708  95.612  -78.373  49.058  1
95709  95.621  -78.380  49.022  1
95710  95.630  -78.387  48.986  1
95711  95.635  -78.391  48.951  1
95712  95.631  -78.388  48.916  1
95713  95.627  -78.384  48.878  1
95714  95.623  -78.380  48.837  1
95715  95.618  -78.377  48.796  1
95716  95.614  -78.373  48.754  1
95717  95.610  -78.370  48.714  1
95718  95.625  -78.379  48.674  1
95719  95.642  -78.381  48.633  1
95720  95.659  -78.387  48.591  1
95721  95.675  -78.393  48.551  1
95722  95.692  -78.398  48.509  1
95723  95.705  -78.401  48.467  1
95724  95.717  -78.403  48.426  1
95725  95.738  -78.407  48.385  1
95726  95.761  -78.410  48.343  1
95727  95.784  -78.413  48.302  1
95728  95.804  -78.416  48.260  1
95729  95.821  -78.416  48.219  1
95730  95.838  -78.415  48.177  1
95731  95.855  -78.414  48.137  1
95732  95.869  -78.413  48.097  1
95733  95.880  -78.413  48.057  1
95734  95.891  -78.412  48.016  1
95735  95.905  -78.413  47.976  1
95736  95.917  -78.413  47.936  1
95737  95.929  -78.414  47.896  1
95738  95.943  -78.417  47.856  1
95739  95.955  -78.424  47.818  1
95740  95.967  -78.430  47.780  1
95741  95.979  -78.437  47.741  1
95742  95.992  -78.444  47.704  1
95743  96.005  -78.452  47.666  1
95744  96.019  -78.460  47.628  1
95745  96.032  -78.467  47.590  1
95746  96.045  -78.475  47.555  1
95747  96.059  -78.485  47.522  1
95748  96.059  -78.499  47.487  1
95749  96.062  -78.512  47.452  1
95750  96.067  -78.523  47.418  1
95751  96.075  -78.548  47.385  1
95752  96.096  -78.563  47.354  1
95753  96.122  -78.567  47.322  1
95754  96.149  -78.571  47.291  1
95755  96.175  -78.575  47.262  1
95756  96.201  -78.579  47.234  1
95757  96.230  -78.585  47.206  1
95758  96.259  -78.590  47.178  1
95759  96.289  -78.595  47.150  1
95760  96.318  -78.601  47.121  1
95761  96.347  -78.607  47.093  1
95762  96.377  -78.613  47.065  1
95763  96.406  -78.618  47.035  1
95764  96.435  -78.623  47.004  1
95765  96.464  -78.625  46.974  1
95766  96.493  -78.628  46.945  1
95767  96.523  -78.630  46.917  1
95768  96.523  -78.617  46.889  1
95769  96.519  -78.603  46.862  1
95770  96.516  -78.589  46.836  1
95771  96.565  -78.599  46.809  1
95772  96.614  -78.609  46.782  1
95773  96.663  -78.619  46.760  1
95774  96.713  -78.629  46.738  1
95775  96.761  -78.639  46.716  1
95776  96.764  -78.649  46.693  1
95777  96.765  -78.661  46.670  1
95778  96.765  -78.671  46.647  1
95779  96.775  -78.683  46.623  1
95780  96.796  -78.693  46.601  1
95781  96.816  -78.704  46.579  1
95782  96.819  -78.720  46.557  1
95783  96.822  -78.739  46.536  1
95784  96.835  -78.753  46.513  1
95785  96.847  -78.767  46.491  1
95786  96.857  -78.777  46.469  1
95787  96.867  -78.789  46.449  1
95788  96.877  -78.799  46.430  1
95789  96.887  -78.810  46.412  1
95790  96.897  -78.821  46.394  1
95791  96.911  -78.836  46.375  1
95792  96.932  -78.854  46.355  1
95793  96.962  -78.865  46.335  1
95794  96.992  -78.875  46.318  1
95795  97.022  -78.886  46.302  1
95796  97.051  -78.896  46.286  1
95797  97.081  -78.907  46.270  1
95798  97.111  -78.918  46.255  1
95799  97.141  -78.928  46.239  1
95800  97.170  -78.939  46.224  1
95801  97.200  -78.949  46.212  1
95802  97.230  -78.960  46.198  1
95803  97.259  -78.971  46.184  1
95804  97.288  -78.981  46.168  1
95805  97.325  -78.995  46.152  1
95806  97.363  -79.007  46.134  1
95807  97.378  -79.006  46.114  1
95808  97.394  -79.006  46.096  1
95809  97.409  -79.005  46.078  1
95810  97.426  -79.004  46.060  1
95811  97.439  -79.002  46.042  1
95812  97.447  -78.996  46.023  1
95813  97.456  -78.990  46.003  1
95814  97.464  -78.984  45.983  1
95815  97.472  -78.978  45.967  1
95816  97.480  -78.972  45.950  1
95817  97.489  -78.966  45.934  1
95818  97.497  -78.960  45.918  1
95819  97.505  -78.955  45.903  1
95820  97.513  -78.949  45.890  1
95821  97.521  -78.943  45.877  1
95822  97.529  -78.937  45.866  1
95823  97.537  -78.930  45.854  1
95824  97.545  -78.925  45.840  1
95825  97.554  -78.919  45.827  1
95826  97.562  -78.913  45.811  1
95827  97.572  -78.912  45.792  1
95828  97.593  -78.949  45.770  1
95829  97.614  -78.987  45.748  1
95830  97.636  -79.024  45.726  1
95831  97.641  -79.027  45.706  1
95832  97.644  -79.024  45.685  1
95833  97.646  -79.021  45.666  1
95834  97.649  -79.018  45.647  1
95835  97.651  -79.015  45.628  1
95836  97.654  -79.013  45.610  1
95837  97.656  -79.010  45.593  1
95838  97.659  -79.007  45.578  1
95839  97.692  -79.028  45.562  1
95840  97.728  -79.052  45.548  1
95841  97.761  -79.073  45.534  1
95842  97.769  -79.078  45.519  1
95843  97.776  -79.084  45.506  1
95844  97.783  -79.089  45.494  1
95845  97.790  -79.093  45.481  1
95846  97.798  -79.099  45.469  1
95847  97.805  -79.104  45.455  1
95848  97.812  -79.110  45.442  1
95849  97.816  -79.124  45.429  1
95850  97.819  -79.137  45.417  1
95851  97.823  -79.151  45.406  1
95852  97.827  -79.165  45.396  1
95853  97.842  -79.172  45.385  1
95854  97.859  -79.179  45.374  1
95855  97.874  -79.169  45.365  1
95856  97.889  -79.159  45.357  1
95857  97.903  -79.149  45.347  1
95858  97.919  -79.138  45.338  1
95859  97.934  -79.128  45.329  1
95860  97.949  -79.118  45.319  1
95861  97.963  -79.107  45.309  1
95862  97.997  -79.111  45.300  1
95863  98.055  -79.149  45.290  1
95864  98.116  -79.202  45.281  1
95865  98.144  -79.214  45.273  1
95866  98.171  -79.223  45.266  1
95867  98.197  -79.233  45.259  1
95868  98.223  -79.238  45.252  1
95869  98.249  -79.241  45.245  1
95870  98.275  -79.244  45.237  1
95871  98.301  -79.248  45.230  1
95872  98.327  -79.251  45.221  1
95873  98.353  -79.255  45.211  1
95874  98.379  -79.258  45.200  1
95875  98.411  -79.269  45.190  1
95876  98.443  -79.280  45.179  1
95877  98.476  -79.292  45.167  1
95878  98.510  -79.303  45.157  1
95879  98.547  -79.316  45.147  1
95880  98.583  -79.328  45.137  1
95881  98.620  -79.341  45.126  1
95882  98.656  -79.353  45.116  1
95883  98.693  -79.365  45.106  1
95884  98.730  -79.377  45.097  1
95885  98.766  -79.389  45.086  1
95886  98.803  -79.401  45.077  1
95887  98.809  -79.405  45.069  1
95888  98.809  -79.407  45.062  1
95889  98.811  -79.411  45.054  1
95890  98.835  -79.429  45.045  1
95891  98.859  -79.446  45.036  1
95892  98.882  -79.463  45.030  1
95893  98.906  -79.480  45.024  1
95894  98.929  -79.498  45.018  1
95895  98.951  -79.513  45.012  1
95896  98.975  -79.527  45.005  1
95897  99.016  -79.529  44.996  1
95898  99.057  -79.529  44.983  1
95899  99.099  -79.529  44.973  1
95900  99.148  -79.515  44.962  1
95901  99.158  -79.521  44.952  1
95902  99.167  -79.526  44.942  1
95903  99.178  -79.532  44.931  1
95904  99.187  -79.538  44.920  1
95905  99.200  -79.548  44.908  1
95906  99.215  -79.563  44.898  1
95907  99.229  -79.577  44.889  1
95908  99.244  -79.592  44.880  1
95909  99.260  -79.607  44.870  1
95910  99.274  -79.621  44.863  1
95911  99.289  -79.636  44.855  1
95912  99.304  -79.651  44.846  1
95913  99.326  -79.659  44.838  1
95914  99.345  -79.661  44.828  1
95915  99.360  -79.656  44.818  1
95916  99.375  -79.651  44.808  1
95917  99.391  -79.645  44.798  1
95918  99.406  -79.639  44.788  1
95919  99.421  -79.634  44.779  1
95920  99.437  -79.629  44.769  1
95921  99.452  -79.623  44.760  1
95922  99.468  -79.617  44.750  1
95923  99.483  -79.612  44.741  1
95924  99.498  -79.607  44.733  1
95925  99.517  -79.604  44.726  1
95926  99.547  -79.607  44.718  1
95927  99.579  -79.617  44.710  1
95928  99.597  -79.642  44.702  1
95929  99.615  -79.667  44.695  1
95930  99.632  -79.692  44.689  1
95931  99.650  -79.717  44.684  1
95932  99.669  -79.742  44.679  1
95933  99.689  -79.767  44.674  1
95934  99.708  -79.791  44.669  1
95935  99.728  -79.816  44.663  1
95936  99.748  -79.840  44.657  1
95937  99.767  -79.864  44.650  1
95938  99.787  -79.889  44.643  1
95939  99.806  -79.914  44.636  1
95940  99.826  -79.939  44.629  1
95941  99.850  -79.968  44.620  1
95942  99.877  -80.002  44.612  1
95943  99.905  -80.031  44.604  1
95944  99.934  -80.060  44.598  1
95945  99.963  -80.089  44.590  1
95946  99.993  -80.118  44.582  1
95947  100.033  -80.143  44.574  1
95948  100.067  -80.167  44.564  1
95949  100.096  -80.193  44.552  1
95950  100.124  -80.220  44.540  1
95951  100.153  -80.247  44.526  1
95952  100.182  -80.273  44.512  1
95953  100.207  -80.300  44.497  1
95954  100.242  -80.326  44.482  1
95955  100.303  -80.346  44.467  1
95956  100.360  -80.361  44.451  1
95957  100.384  -80.368  44.433  1
95958  100.414  -80.418  44.414  1
95959  100.440  -80.467  44.396  1
95960  100.460  -80.515  44.378  1
95961  100.502  -80.535  44.360  1
95962  100.547  -80.551  44.342  1
95963  100.587  -80.573  44.325  1
95964  100.628  -80.594  44.308  1
95965  100.668  -80.617  44.292  1
95966  100.708  -80.639  44.276  1
95967  100.749  -80.661  44.260  1
95968  100.789  -80.683  44.245  1
95969  100.829  -80.705  44.230  1
95970  100.869  -80.727  44.215  1
95971  100.909  -80.749  44.200  1
95972  100.950  -80.771  44.185  1
95973  100.990  -80.793  44.170  1
95974  101.030  -80.815  44.154  1
95975  101.071  -80.836  44.139  1
95976  101.117  -80.849  44.126  1
95977  101.164  -80.862  44.112  1
95978  101.210  -80.875  44.099  1
95979  101.257  -80.888  44.085  1
96244  93.512  -78.597  53.788  1
96245  93.522  -78.595  53.774  1
96246  93.532  -78.592  53.760  1
96247  93.542  -78.590  53.745  1
96248  93.551  -78.587  53.729  1
96249  93.561  -78.585  53.714  1
96250  93.571  -78.582  53.697  1
96251  93.580  -78.580  53.680  1
96252  93.582  -78.573  53.663  1
96253  93.580  -78.563  53.645  1
96254  93.579  -78.554  53.627  1
96255  93.578  -78.545  53.609  1
96256  93.576  -78.535  53.591  1
96257  93.583  -78.522  53.573  1
96258  93.601  -78.507  53.555  1
96259  93.623  -78.492  53.537  1
96260  93.645  -78.476  53.518  1
96261  93.668  -78.462  53.500  1
96262  93.680  -78.454  53.483  1
96263  93.691  -78.445  53.465  1
96264  93.707  -78.438  53.446  1
96265  93.722  -78.430  53.428  1
96266  93.737  -78.423  53.410  1
96267  93.753  -78.416  53.391  1
96268  93.768  -78.408  53.372  1
96269  93.784  -78.401  53.353  1
96270  93.799  -78.394  53.335  1
96271  93.815  -78.386  53.315  1
96272  93.830  -78.379  53.296  1
96273  93.845  -78.372  53.277  1
96274  93.861  -78.364  53.259  1
96275  93.876  -78.357  53.240  1
96276  93.892  -78.350  53.221  1
96277  93.906  -78.345  53.203  1
96278  93.921  -78.340  53.184  1
96279  93.919  -78.322  53.165  1
96280  93.918  -78.306  53.148  1
96281  93.930  -78.290  53.132  1
96282  93.949  -78.294  53.117  1
96283  93.963  -78.303  53.102  1
96284  93.976  -78.311  53.087  1
96285  93.990  -78.320  53.071  1
96286  93.998  -78.324  53.056  1
96287  94.006  -78.328  53.041  1
96288  94.015  -78.332  53.028  1
96289  94.023  -78.335  53.016  1
96290  94.031  -78.339  53.003  1
96291  94.039  -78.342  52.989  1
96292  94.047  -78.346  52.977  1
96293  94.056  -78.350  52.964  1
96294  94.067  -78.354  52.950  1
96295  94.079  -78.360  52.935  1
96296  94.088  -78.363  52.924  1
96297  94.099  -78.368  52.913  1
96298  94.107  -78.373  52.901  1
96299  94.112  -78.382  52.888  1
96300  94.117  -78.391  52.877  1
96301  94.121  -78.400  52.868  1
96302  94.126  -78.409  52.861  1
96303  94.130  -78.417  52.855  1
96304  94.135  -78.426  52.847  1
96305  94.140  -78.429  52.837  1
96306  94.144  -78.432  52.822  1
96307  94.149  -78.433  52.809  1
96308  94.153  -78.435  52.798  1
96309  94.158  -78.438  52.788  1
96310  94.163  -78.440  52.779  1
96311  94.167  -78.442  52.769  1
96312  94.183  -78.429  52.756  1
96313  94.201  -78.416  52.738  1
96314  94.220  -78.402  52.718  1
96315  94.238  -78.388  52.696  1
96316  94.259  -78.387  52.672  1
96317  94.280  -78.389  52.647  1
96318  94.297  -78.395  52.621  1
96319  94.306  -78.413  52.596  1
96320  94.314  -78.430  52.566  1
96321  94.323  -78.448  52.535  1
96322  94.331  -78.464  52.503  1
96323  94.339  -78.482  52.473  1
96324  94.348  -78.499  52.441  1
96325  94.359  -78.510  52.408  1
96326  94.381  -78.502  52.375  1
96327  94.411  -78.507  52.338  1
96328  94.443  -78.507  52.302  1
96329  94.467  -78.491  52.266  1
96330  94.492  -78.474  52.232  1
96331  94.516  -78.457  52.199  1
96332  94.541  -78.442  52.165  1
96333  94.565  -78.425  52.131  1
96334  94.590  -78.408  52.090  1
96335  94.606  -78.398  52.047  1
96336  94.616  -78.392  52.003  1
96337  94.627  -78.386  51.960  1
96338  94.637  -78.380  51.917  1
96339  94.648  -78.376  51.872  1
96340  94.661  -78.378  51.825  1
96341  94.673  -78.380  51.776  1
96342  94.685  -78.382  51.729  1
96343  94.697  -78.384  51.683  1
96344  94.709  -78.386  51.637  1
96345  94.721  -78.384  51.589  1
96346  94.734  -78.382  51.541  1
96347  94.745  -78.386  51.492  1
96348  94.761  -78.382  51.442  1
96349  94.779  -78.375  51.395  1
96350  94.798  -78.367  51.351  1
96351  94.812  -78.369  51.310  1
96352  94.824  -78.373  51.272  1
96353  94.841  -78.382  51.234  1
96354  94.862  -78.387  51.195  1
96355  94.887  -78.388  51.150  1
96356  94.907  -78.389  51.101  1
96357  94.918  -78.391  51.050  1
96358  94.928  -78.392  51.000  1
96359  94.939  -78.394  50.950  1
96360  94.950  -78.395  50.900  1
96361  94.961  -78.397  50.850  1
96362  94.972  -78.398  50.799  1
96363  94.982  -78.400  50.750  1
96364  94.993  -78.401  50.702  1
96365  95.003  -78.397  50.655  1
96366  95.013  -78.379  50.608  1
96367  95.023  -78.363  50.563  1
96368  95.047  -78.354  50.518  1
96369  95.119  -78.373  50.475  1
96370  95.165  -78.327  50.432  1
96371  95.191  -78.338  50.390  1
96372  95.201  -78.327  50.348  1
96373  95.212  -78.316  50.307  1
96374  95.222  -78.305  50.267  1
96375  95.233  -78.294  50.228  1
96376  95.244  -78.282  50.189  1
96377  95.254  -78.272  50.150  1
96378  95.265  -78.260  50.112  1
96379  95.275  -78.249  50.074  1
96380  95.286  -78.238  50.036  1
96381  95.297  -78.227  49.999  1
96382  95.307  -78.216  49.962  1
96383  95.317  -78.217  49.924  1
96384  95.326  -78.220  49.888  1
96385  95.335  -78.223  49.852  1
96386  95.345  -78.226  49.817  1
96387  95.354  -78.228  49.782  1
96388  95.364  -78.232  49.746  1
96389  95.373  -78.235  49.712  1
96390  95.382  -78.238  49.678  1
96391  95.392  -78.241  49.644  1
96392  95.401  -78.243  49.612  1
96393  95.417  -78.250  49.581  1
96394  95.441  -78.262  49.550  1
96395  95.465  -78.274  49.519  1
96396  95.488  -78.285  49.488  1
96397  95.513  -78.297  49.458  1
96398  95.522  -78.300  49.428  1
96399  95.527  -78.299  49.398  1
96400  95.532  -78.299  49.367  1
96401  95.537  -78.298  49.335  1
96402  95.543  -78.300  49.304  1
96403  95.552  -78.307  49.273  1
96404  95.561  -78.314  49.243  1
96405  95.570  -78.321  49.211  1
96406  95.580  -78.328  49.178  1
96407  95.589  -78.335  49.144  1
96408  95.598  -78.342  49.107  1
96409  95.607  -78.350  49.071  1
96410  95.616  -78.357  49.034  1
96411  95.625  -78.363  48.998  1
96412  95.634  -78.370  48.963  1
96413  95.630  -78.366  48.928  1
96414  95.626  -78.363  48.891  1
96415  95.621  -78.360  48.852  1
96416  95.617  -78.357  48.811  1
96417  95.613  -78.353  48.769  1
96418  95.615  -78.353  48.728  1
96419  95.629  -78.362  48.687  1
96420  95.646  -78.366  48.646  1
96421  95.664  -78.368  48.604  1
96422  95.681  -78.374  48.562  1
96423  95.697  -78.380  48.520  1
96424  95.708  -78.382  48.478  1
96425  95.721  -78.383  48.438  1
96426  95.739  -78.385  48.397  1
96427  95.762  -78.389  48.355  1
96428  95.785  -78.396  48.314  1
96429  95.801  -78.397  48.273  1
96430  95.817  -78.396  48.232  1
96431  95.834  -78.396  48.190  1
96432  95.850  -78.395  48.150  1
96433  95.863  -78.395  48.109  1
96434  95.874  -78.394  48.069  1
96435  95.891  -78.395  48.027  1
96436  95.907  -78.398  47.986  1
96437  95.919  -78.398  47.946  1
96438  95.931  -78.399  47.906  1
96439  95.946  -78.403  47.867  1
96440  95.959  -78.407  47.829  1
96441  95.971  -78.414  47.791  1
96442  95.983  -78.421  47.752  1
96443  95.996  -78.428  47.715  1
96444  96.010  -78.435  47.678  1
96445  96.023  -78.444  47.640  1
96446  96.036  -78.451  47.605  1
96447  96.050  -78.463  47.571  1
96448  96.064  -78.475  47.539  1
96449  96.068  -78.486  47.504  1
96450  96.067  -78.501  47.469  1
96451  96.067  -78.517  47.435  1
96452  96.066  -78.532  47.404  1
96453  96.084  -78.541  47.373  1
96454  96.114  -78.546  47.341  1
96455  96.143  -78.551  47.309  1
96456  96.172  -78.557  47.280  1
96457  96.202  -78.563  47.251  1
96458  96.231  -78.569  47.222  1
96459  96.260  -78.574  47.194  1
96460  96.290  -78.580  47.168  1
96461  96.319  -78.586  47.140  1
96462  96.348  -78.591  47.111  1
96463  96.378  -78.597  47.083  1
96464  96.407  -78.601  47.052  1
96465  96.436  -78.604  47.021  1
96466  96.465  -78.607  46.992  1
96467  96.495  -78.609  46.963  1
96468  96.524  -78.612  46.935  1
96469  96.553  -78.614  46.908  1
96470  96.578  -78.614  46.881  1
96471  96.574  -78.600  46.854  1
96472  96.571  -78.586  46.828  1
96473  96.620  -78.595  46.801  1
96474  96.669  -78.605  46.777  1
96475  96.718  -78.615  46.754  1
96476  96.754  -78.626  46.732  1
96477  96.755  -78.636  46.709  1
96478  96.755  -78.648  46.686  1
96479  96.756  -78.659  46.663  1
96480  96.762  -78.670  46.639  1
96481  96.783  -78.680  46.617  1
96482  96.799  -78.692  46.594  1
96483  96.800  -78.711  46.572  1
96484  96.810  -78.726  46.551  1
96485  96.823  -78.740  46.529  1
96486  96.834  -78.753  46.506  1
96487  96.844  -78.764  46.485  1
96488  96.855  -78.774  46.465  1
96489  96.865  -78.786  46.445  1
96490  96.875  -78.796  46.426  1
96491  96.889  -78.812  46.408  1
96492  96.908  -78.836  46.390  1
96493  96.928  -78.859  46.370  1
96494  96.955  -78.868  46.350  1
96495  96.984  -78.879  46.334  1
96496  97.014  -78.890  46.318  1
96497  97.044  -78.900  46.302  1
96498  97.074  -78.910  46.285  1
96499  97.103  -78.921  46.270  1
96500  97.133  -78.931  46.255  1
96501  97.163  -78.942  46.240  1
96502  97.192  -78.952  46.226  1
96503  97.222  -78.963  46.213  1
96504  97.252  -78.974  46.198  1
96505  97.283  -78.981  46.182  1
96506  97.318  -78.981  46.164  1
96507  97.356  -78.993  46.145  1
96508  97.384  -79.000  46.125  1
96509  97.400  -78.999  46.107  1
96510  97.416  -78.998  46.089  1
96511  97.431  -78.997  46.070  1
96512  97.447  -78.996  46.052  1
96513  97.455  -78.990  46.034  1
96514  97.463  -78.984  46.014  1
96515  97.471  -78.979  45.993  1
96516  97.479  -78.973  45.977  1
96517  97.488  -78.967  45.960  1
96518  97.496  -78.961  45.943  1
96519  97.504  -78.955  45.927  1
96520  97.512  -78.949  45.913  1
96521  97.521  -78.943  45.900  1
96522  97.529  -78.937  45.886  1
96523  97.537  -78.931  45.876  1
96524  97.545  -78.925  45.864  1
96525  97.554  -78.919  45.850  1
96526  97.562  -78.914  45.838  1
96527  97.572  -78.908  45.821  1
96528  97.590  -78.905  45.801  1
96529  97.603  -78.905  45.780  1
96530  97.625  -78.943  45.756  1
96531  97.646  -78.980  45.735  1
96532  97.662  -79.006  45.715  1
96533  97.664  -79.003  45.696  1
96534  97.667  -79.000  45.676  1
96535  97.670  -78.997  45.657  1
96536  97.672  -78.995  45.639  1
96537  97.675  -78.992  45.623  1
96538  97.677  -78.989  45.606  1
96539  97.696  -78.999  45.590  1
96540  97.732  -79.022  45.575  1
96541  97.766  -79.044  45.561  1
96542  97.773  -79.049  45.546  1
96543  97.781  -79.055  45.532  1
96544  97.788  -79.059  45.518  1
96545  97.795  -79.065  45.505  1
96546  97.802  -79.070  45.493  1
96547  97.809  -79.075  45.480  1
96548  97.817  -79.080  45.467  1
96549  97.824  -79.085  45.454  1
96550  97.829  -79.096  45.442  1
96551  97.833  -79.110  45.429  1
96552  97.837  -79.124  45.417  1
96553  97.841  -79.137  45.406  1
96554  97.858  -79.143  45.395  1
96555  97.874  -79.150  45.385  1
96556  97.891  -79.157  45.375  1
96557  97.906  -79.147  45.366  1
96558  97.921  -79.136  45.356  1
96559  97.936  -79.126  45.345  1
96560  97.951  -79.115  45.335  1
96561  97.965  -79.105  45.324  1
96562  97.981  -79.095  45.313  1
96563  97.996  -79.099  45.303  1
96564  98.046  -79.101  45.293  1
96565  98.101  -79.126  45.284  1
96566  98.148  -79.161  45.276  1
96567  98.174  -79.170  45.268  1
96568  98.200  -79.182  45.260  1
96569  98.224  -79.196  45.253  1
96570  98.249  -79.209  45.247  1
96571  98.275  -79.219  45.241  1
96572  98.301  -79.222  45.233  1
96573  98.327  -79.225  45.224  1
96574  98.353  -79.229  45.214  1
96575  98.379  -79.232  45.203  1
96576  98.409  -79.241  45.194  1
96577  98.442  -79.252  45.183  1
96578  98.475  -79.264  45.170  1
96579  98.512  -79.276  45.161  1
96580  98.548  -79.288  45.151  1
96581  98.585  -79.300  45.140  1
96582  98.622  -79.313  45.130  1
96583  98.658  -79.325  45.118  1
96584  98.695  -79.338  45.106  1
96585  98.731  -79.350  45.096  1
96586  98.768  -79.362  45.086  1
96587  98.804  -79.374  45.076  1
96588  98.822  -79.381  45.068  1
96589  98.823  -79.383  45.061  1
96590  98.828  -79.388  45.051  1
96591  98.851  -79.406  45.043  1
96592  98.875  -79.423  45.036  1
96593  98.898  -79.441  45.031  1
96594  98.922  -79.458  45.025  1
96595  98.945  -79.475  45.019  1
96596  98.969  -79.492  45.013  1
96597  98.991  -79.507  45.005  1
96598  99.028  -79.511  44.996  1
96599  99.069  -79.513  44.986  1
96600  99.119  -79.500  44.975  1
96601  99.143  -79.499  44.965  1
96602  99.153  -79.504  44.954  1
96603  99.163  -79.510  44.942  1
96604  99.172  -79.516  44.931  1
96605  99.183  -79.521  44.921  1
96606  99.195  -79.532  44.910  1
96607  99.210  -79.546  44.899  1
96608  99.225  -79.561  44.890  1
96609  99.239  -79.576  44.880  1
96610  99.255  -79.590  44.872  1
96611  99.270  -79.604  44.864  1
96612  99.284  -79.619  44.857  1
96613  99.305  -79.629  44.849  1
96614  99.327  -79.637  44.840  1
96615  99.348  -79.645  44.831  1
96616  99.366  -79.645  44.821  1
96617  99.381  -79.639  44.810  1
96618  99.397  -79.634  44.800  1
96619  99.412  -79.629  44.791  1
96620  99.427  -79.623  44.782  1
96621  99.442  -79.617  44.773  1
96622  99.458  -79.612  44.764  1
96623  99.473  -79.607  44.755  1
96624  99.489  -79.601  44.747  1
96625  99.504  -79.595  44.739  1
96626  99.532  -79.598  44.732  1
96627  99.561  -79.601  44.725  1
96628  99.591  -79.604  44.717  1
96629  99.623  -79.612  44.710  1
96630  99.646  -79.640  44.704  1
96631  99.663  -79.665  44.699  1
96632  99.681  -79.690  44.694  1
96633  99.699  -79.715  44.689  1
96634  99.716  -79.740  44.684  1
96635  99.733  -79.765  44.678  1
96636  99.751  -79.790  44.671  1
96637  99.769  -79.815  44.664  1
96638  99.789  -79.840  44.658  1
96639  99.808  -79.864  44.651  1
96640  99.828  -79.889  44.644  1
96641  99.848  -79.914  44.638  1
96642  99.872  -79.943  44.631  1
96643  99.899  -79.974  44.623  1
96644  99.927  -80.002  44.616  1
96645  99.960  -80.033  44.609  1
96646  99.992  -80.064  44.601  1
96647  100.024  -80.096  44.593  1
96648  100.063  -80.120  44.585  1
96649  100.109  -80.139  44.575  1
96650  100.154  -80.157  44.564  1
96651  100.192  -80.180  44.552  1
96652  100.221  -80.206  44.539  1
96653  100.250  -80.233  44.526  1
96654  100.276  -80.260  44.512  1
96655  100.294  -80.290  44.497  1
96656  100.334  -80.314  44.481  1
96657  100.384  -80.331  44.464  1
96658  100.434  -80.365  44.447  1
96659  100.462  -80.410  44.428  1
96660  100.482  -80.450  44.409  1
96661  100.502  -80.491  44.390  1
96662  100.555  -80.554  44.371  1
96663  100.543  -80.553  44.352  1
96664  100.583  -80.576  44.333  1
96665  100.624  -80.598  44.316  1
96666  100.664  -80.620  44.300  1
96667  100.704  -80.641  44.284  1
96668  100.745  -80.663  44.268  1
96669  100.785  -80.685  44.253  1
96670  100.825  -80.707  44.238  1
96671  100.865  -80.729  44.222  1
96672  100.905  -80.751  44.206  1
96673  100.946  -80.773  44.190  1
96674  100.986  -80.795  44.175  1
96675  101.029  -80.814  44.159  1
96676  101.075  -80.827  44.144  1
96677  101.121  -80.840  44.130  1
96678  101.168  -80.853  44.116  1
96679  101.214  -80.866  44.103  1
96680  101.261  -80.879  44.089  1
96681  101.307  -80.892  44.075  1
96944  93.503  -78.589  53.807  1
96945  93.513  -78.586  53.793  1
96946  93.522  -78.584  53.779  1
96947  93.532  -78.582  53.764  1
96948  93.542  -78.579  53.749  1
96949  93.552  -78.576  53.733  1
96950  93.561  -78.574  53.716  1
96951  93.571  -78.572  53.699  1
96952  93.580  -78.568  53.681  1
96953  93.578  -78.559  53.664  1
96954  93.577  -78.550  53.646  1
96955  93.576  -78.541  53.627  1
96956  93.574  -78.532  53.608  1
96957  93.574  -78.522  53.590  1
96958  93.584  -78.507  53.571  1
96959  93.606  -78.492  53.552  1
96960  93.629  -78.476  53.534  1
96961  93.651  -78.461  53.515  1
96962  93.669  -78.449  53.497  1
96963  93.681  -78.441  53.479  1
96964  93.693  -78.432  53.460  1
96969  93.770  -78.395  53.367  1
96970  93.786  -78.388  53.348  1
96971  93.801  -78.381  53.330  1
96972  93.817  -78.373  53.309  1
96973  93.832  -78.366  53.290  1
96974  93.847  -78.359  53.271  1
96975  93.863  -78.351  53.253  1
96976  93.878  -78.344  53.234  1
96977  93.894  -78.337  53.215  1
96978  93.909  -78.329  53.198  1
96979  93.923  -78.325  53.179  1
96980  93.931  -78.314  53.161  1
96981  93.930  -78.297  53.144  1
96982  93.946  -78.283  53.129  1
96983  93.959  -78.291  53.116  1
96984  93.973  -78.300  53.102  1
96985  93.985  -78.308  53.088  1
96986  93.994  -78.312  53.074  1
96987  94.002  -78.316  53.059  1
96988  94.010  -78.319  53.044  1
96989  94.018  -78.322  53.032  1
96990  94.026  -78.326  53.020  1
96991  94.035  -78.330  53.007  1
96992  94.043  -78.334  52.994  1
96993  94.051  -78.338  52.981  1
96994  94.059  -78.341  52.967  1
96995  94.069  -78.345  52.953  1
96996  94.080  -78.350  52.940  1
96997  94.090  -78.354  52.928  1
96998  94.099  -78.360  52.915  1
96999  94.104  -78.369  52.902  1
97000  94.108  -78.377  52.889  1
97001  94.113  -78.386  52.877  1
97002  94.118  -78.395  52.868  1
97003  94.122  -78.404  52.859  1
97004  94.127  -78.413  52.853  1
97005  94.132  -78.422  52.846  1
97006  94.136  -78.428  52.837  1
97007  94.141  -78.430  52.824  1
97008  94.145  -78.432  52.813  1
97009  94.150  -78.435  52.803  1
97010  94.154  -78.437  52.793  1
97011  94.159  -78.439  52.783  1
97012  94.163  -78.432  52.772  1
97013  94.174  -78.414  52.757  1
97014  94.192  -78.401  52.737  1
97015  94.210  -78.387  52.715  1
97016  94.228  -78.373  52.691  1
97017  94.250  -78.374  52.666  1
97018  94.271  -78.376  52.640  1
97019  94.291  -78.379  52.613  1
97020  94.301  -78.394  52.586  1
97021  94.310  -78.411  52.555  1
97022  94.319  -78.429  52.524  1
97023  94.327  -78.446  52.492  1
97024  94.336  -78.463  52.461  1
97025  94.344  -78.480  52.428  1
97026  94.359  -78.483  52.394  1
97027  94.381  -78.475  52.360  1
97028  94.406  -78.473  52.323  1
97029  94.444  -78.487  52.286  1
97030  94.472  -78.479  52.249  1
97031  94.496  -78.463  52.214  1
97032  94.521  -78.446  52.178  1
97033  94.545  -78.430  52.143  1
97034  94.570  -78.413  52.107  1
97035  94.594  -78.397  52.064  1
97036  94.611  -78.386  52.021  1
97037  94.622  -78.380  51.976  1
97038  94.632  -78.375  51.932  1
97039  94.642  -78.369  51.887  1
97040  94.653  -78.363  51.840  1
97041  94.665  -78.362  51.791  1
97042  94.677  -78.364  51.743  1
97043  94.689  -78.366  51.696  1
97044  94.701  -78.368  51.651  1
97045  94.713  -78.369  51.605  1
97046  94.726  -78.366  51.558  1
97047  94.739  -78.363  51.512  1
97048  94.750  -78.367  51.466  1
97049  94.760  -78.371  51.420  1
97050  94.778  -78.364  51.377  1
97051  94.797  -78.357  51.337  1
97052  94.811  -78.358  51.300  1
97053  94.823  -78.362  51.264  1
97054  94.838  -78.366  51.225  1
97055  94.863  -78.368  51.184  1
97056  94.888  -78.369  51.136  1
97057  94.913  -78.371  51.086  1
97058  94.928  -78.373  51.034  1
97059  94.939  -78.374  50.983  1
97060  94.950  -78.376  50.934  1
97061  94.960  -78.377  50.885  1
97062  94.971  -78.379  50.836  1
97063  94.982  -78.380  50.787  1
97064  94.992  -78.382  50.739  1
97065  95.003  -78.383  50.692  1
97066  95.014  -78.385  50.645  1
97067  95.025  -78.385  50.599  1
97068  95.034  -78.382  50.555  1
97069  95.051  -78.340  50.510  1
97070  95.093  -78.288  50.467  1
97071  95.126  -78.244  50.426  1
97072  95.162  -78.266  50.385  1
97073  95.198  -78.289  50.345  1
97074  95.218  -78.291  50.305  1
97075  95.229  -78.279  50.265  1
97076  95.239  -78.268  50.227  1
97077  95.250  -78.257  50.189  1
97078  95.260  -78.246  50.152  1
97079  95.271  -78.235  50.116  1
97080  95.281  -78.224  50.079  1
97081  95.293  -78.213  50.040  1
97082  95.303  -78.201  50.002  1
97083  95.313  -78.193  49.965  1
97084  95.323  -78.195  49.928  1
97085  95.332  -78.198  49.890  1
97086  95.341  -78.201  49.854  1
97087  95.351  -78.204  49.819  1
97088  95.360  -78.207  49.784  1
97089  95.370  -78.210  49.749  1
97090  95.379  -78.213  49.715  1
97091  95.388  -78.216  49.684  1
97092  95.398  -78.219  49.652  1
97093  95.407  -78.221  49.621  1
97094  95.416  -78.224  49.590  1
97095  95.431  -78.231  49.561  1
97096  95.456  -78.242  49.532  1
97097  95.479  -78.254  49.502  1
97098  95.503  -78.266  49.472  1
97099  95.513  -78.269  49.444  1
97100  95.518  -78.268  49.415  1
97101  95.523  -78.268  49.384  1
97102  95.529  -78.269  49.351  1
97103  95.538  -78.276  49.318  1
97104  95.547  -78.283  49.287  1
97105  95.556  -78.290  49.256  1
97106  95.565  -78.297  49.225  1
97107  95.574  -78.304  49.193  1
97108  95.584  -78.312  49.160  1
97109  95.593  -78.319  49.123  1
97110  95.602  -78.326  49.085  1
97111  95.611  -78.333  49.047  1
97112  95.620  -78.340  49.009  1
97113  95.630  -78.347  48.973  1
97114  95.629  -78.346  48.938  1
97115  95.625  -78.343  48.903  1
97116  95.620  -78.339  48.865  1
97117  95.616  -78.335  48.825  1
97118  95.612  -78.332  48.784  1
97119  95.620  -78.336  48.742  1
97120  95.634  -78.344  48.700  1
97121  95.650  -78.353  48.657  1
97122  95.668  -78.354  48.615  1
97123  95.686  -78.356  48.572  1
97124  95.700  -78.360  48.530  1
97125  95.712  -78.361  48.489  1
97126  95.725  -78.363  48.449  1
97127  95.740  -78.366  48.408  1
97128  95.762  -78.373  48.367  1
97129  95.783  -78.376  48.325  1
97130  95.798  -78.377  48.284  1
97131  95.814  -78.377  48.242  1
97132  95.830  -78.376  48.202  1
97133  95.846  -78.376  48.160  1
97134  95.858  -78.376  48.118  1
97135  95.875  -78.378  48.077  1
97136  95.892  -78.379  48.035  1
97137  95.908  -78.382  47.995  1
97138  95.920  -78.382  47.955  1
97139  95.934  -78.385  47.915  1
97140  95.948  -78.388  47.876  1
97141  95.963  -78.392  47.836  1
97142  95.975  -78.398  47.798  1
97143  95.987  -78.404  47.761  1
97144  96.001  -78.412  47.724  1
97145  96.014  -78.420  47.688  1
97146  96.027  -78.429  47.652  1
97147  96.042  -78.441  47.620  1
97148  96.056  -78.453  47.588  1
97149  96.071  -78.465  47.555  1
97150  96.077  -78.473  47.520  1
97151  96.077  -78.489  47.486  1
97152  96.076  -78.504  47.453  1
97153  96.075  -78.520  47.422  1
97154  96.090  -78.525  47.391  1
97155  96.115  -78.530  47.359  1
97156  96.144  -78.536  47.328  1
97157  96.174  -78.542  47.299  1
97158  96.203  -78.547  47.269  1
97159  96.232  -78.553  47.239  1
97160  96.261  -78.558  47.211  1
97161  96.291  -78.564  47.184  1
97162  96.320  -78.570  47.157  1
97163  96.349  -78.576  47.130  1
97164  96.379  -78.579  47.101  1
97165  96.408  -78.582  47.070  1
97166  96.437  -78.586  47.039  1
97167  96.466  -78.589  47.010  1
97168  96.496  -78.591  46.981  1
97169  96.525  -78.593  46.953  1
97170  96.554  -78.596  46.926  1
97171  96.584  -78.598  46.901  1
97172  96.613  -78.601  46.874  1
97173  96.629  -78.597  46.847  1
97174  96.626  -78.582  46.820  1
97175  96.675  -78.592  46.793  1
97176  96.724  -78.602  46.769  1
97177  96.745  -78.613  46.747  1
97178  96.745  -78.624  46.725  1
97179  96.746  -78.635  46.702  1
97180  96.746  -78.646  46.678  1
97181  96.749  -78.657  46.654  1
97182  96.769  -78.667  46.630  1
97183  96.780  -78.682  46.608  1
97184  96.786  -78.698  46.586  1
97185  96.799  -78.713  46.565  1
97186  96.811  -78.727  46.543  1
97187  96.822  -78.739  46.521  1
97188  96.832  -78.750  46.499  1
97189  96.842  -78.761  46.480  1
97190  96.853  -78.772  46.461  1
97191  96.868  -78.789  46.441  1
97192  96.887  -78.812  46.422  1
97193  96.906  -78.836  46.403  1
97194  96.926  -78.859  46.385  1
97195  96.947  -78.872  46.366  1
97196  96.977  -78.882  46.349  1
97197  97.007  -78.893  46.333  1
97198  97.036  -78.903  46.319  1
97199  97.066  -78.914  46.303  1
97200  97.096  -78.924  46.286  1
97201  97.125  -78.935  46.271  1
97202  97.155  -78.946  46.257  1
97203  97.185  -78.956  46.243  1
97204  97.215  -78.966  46.228  1
97205  97.244  -78.977  46.213  1
97206  97.277  -78.979  46.196  1
97207  97.312  -78.975  46.177  1
97208  97.348  -78.977  46.157  1
97209  97.385  -78.990  46.137  1
97210  97.406  -78.993  46.118  1
97211  97.422  -78.992  46.099  1
97212  97.437  -78.991  46.080  1
97213  97.453  -78.990  46.063  1
97214  97.463  -78.985  46.043  1
97215  97.471  -78.979  46.023  1
97216  97.479  -78.973  46.003  1
97217  97.487  -78.968  45.986  1
97218  97.496  -78.962  45.970  1
97219  97.504  -78.955  45.953  1
97220  97.512  -78.949  45.937  1
97221  97.520  -78.943  45.922  1
97222  97.528  -78.938  45.908  1
97223  97.536  -78.932  45.894  1
97224  97.544  -78.926  45.882  1
97225  97.553  -78.920  45.869  1
97226  97.561  -78.914  45.856  1
97227  97.572  -78.908  45.842  1
97228  97.590  -78.905  45.825  1
97229  97.608  -78.902  45.807  1
97230  97.621  -78.899  45.786  1
97231  97.635  -78.899  45.765  1
97232  97.656  -78.936  45.745  1
97233  97.678  -78.974  45.726  1
97234  97.685  -78.982  45.707  1
97235  97.688  -78.979  45.689  1
97236  97.690  -78.977  45.671  1
97237  97.693  -78.974  45.653  1
97238  97.696  -78.971  45.637  1
97239  97.700  -78.970  45.621  1
97240  97.736  -78.993  45.605  1
97241  97.771  -79.015  45.589  1
97242  97.778  -79.021  45.573  1
97243  97.785  -79.026  45.558  1
97244  97.792  -79.031  45.544  1
97245  97.800  -79.036  45.531  1
97246  97.807  -79.041  45.518  1
97247  97.814  -79.046  45.505  1
97248  97.821  -79.051  45.492  1
97249  97.829  -79.056  45.478  1
97250  97.836  -79.062  45.466  1
97251  97.843  -79.069  45.454  1
97252  97.846  -79.083  45.442  1
97253  97.850  -79.096  45.428  1
97254  97.857  -79.109  45.416  1
97255  97.873  -79.115  45.405  1
97256  97.890  -79.122  45.395  1
97257  97.907  -79.129  45.385  1
97258  97.923  -79.134  45.374  1
97259  97.938  -79.124  45.364  1
97260  97.953  -79.113  45.352  1
97261  97.967  -79.103  45.340  1
97262  97.983  -79.093  45.328  1
97263  97.998  -79.082  45.317  1
97264  98.004  -79.087  45.307  1
97265  98.045  -79.089  45.297  1
97266  98.096  -79.091  45.287  1
97267  98.148  -79.103  45.278  1
97268  98.177  -79.118  45.270  1
97269  98.202  -79.132  45.262  1
97270  98.227  -79.145  45.254  1
97271  98.252  -79.159  45.247  1
97272  98.277  -79.172  45.242  1
97273  98.302  -79.185  45.234  1
97274  98.327  -79.198  45.226  1
97275  98.353  -79.203  45.217  1
97276  98.379  -79.206  45.207  1
97277  98.407  -79.212  45.197  1
97278  98.440  -79.225  45.187  1
97279  98.477  -79.237  45.175  1
97280  98.513  -79.249  45.166  1
97281  98.550  -79.261  45.155  1
97282  98.586  -79.273  45.143  1
97283  98.623  -79.285  45.132  1
97284  98.660  -79.297  45.121  1
97285  98.696  -79.310  45.110  1
97286  98.733  -79.322  45.098  1
97287  98.770  -79.335  45.089  1
97288  98.806  -79.347  45.079  1
97289  98.836  -79.357  45.070  1
97290  98.836  -79.359  45.061  1
97291  98.844  -79.366  45.053  1
97292  98.867  -79.383  45.045  1
97293  98.890  -79.400  45.038  1
97294  98.914  -79.418  45.032  1
97295  98.938  -79.435  45.026  1
97296  98.961  -79.453  45.020  1
97297  98.985  -79.470  45.014  1
97298  99.008  -79.487  45.006  1
97299  99.041  -79.494  44.998  1
97300  99.088  -79.486  44.988  1
97301  99.129  -79.476  44.977  1
97302  99.139  -79.482  44.967  1
97303  99.148  -79.488  44.956  1
97304  99.158  -79.494  44.944  1
97305  99.168  -79.499  44.933  1
97306  99.178  -79.505  44.922  1
97307  99.190  -79.515  44.913  1
97308  99.205  -79.529  44.901  1
97309  99.220  -79.545  44.890  1
97310  99.235  -79.559  44.881  1
97311  99.250  -79.573  44.873  1
97312  99.265  -79.588  44.866  1
97313  99.284  -79.598  44.859  1
97314  99.306  -79.607  44.851  1
97315  99.328  -79.615  44.842  1
97316  99.349  -79.623  44.833  1
97317  99.371  -79.632  44.824  1
97318  99.387  -79.629  44.813  1
97319  99.403  -79.623  44.803  1
97320  99.418  -79.617  44.793  1
97321  99.433  -79.612  44.784  1
97322  99.448  -79.607  44.775  1
97323  99.464  -79.601  44.768  1
97324  99.479  -79.595  44.760  1
97325  99.495  -79.590  44.752  1
97326  99.515  -79.588  44.745  1
97327  99.546  -79.592  44.738  1
97328  99.576  -79.595  44.730  1
97329  99.606  -79.598  44.723  1
97330  99.636  -79.601  44.717  1
97331  99.666  -79.607  44.712  1
97332  99.695  -79.638  44.706  1
97333  99.712  -79.663  44.701  1
97334  99.730  -79.688  44.696  1
97335  99.748  -79.713  44.691  1
97336  99.765  -79.739  44.685  1
97337  99.782  -79.764  44.679  1
97338  99.800  -79.789  44.673  1
97339  99.818  -79.814  44.666  1
97340  99.835  -79.839  44.659  1
97341  99.852  -79.864  44.653  1
97342  99.870  -79.889  44.648  1
97343  99.894  -79.916  44.640  1
97344  99.926  -79.947  44.633  1
97345  99.958  -79.978  44.626  1
97346  99.990  -80.009  44.618  1
97347  100.023  -80.041  44.611  1
97348  100.055  -80.072  44.603  1
97349  100.093  -80.098  44.594  1
97350  100.139  -80.116  44.584  1
97351  100.185  -80.134  44.574  1
97352  100.230  -80.153  44.563  1
97353  100.276  -80.171  44.552  1
97354  100.318  -80.192  44.540  1
97355  100.345  -80.219  44.526  1
97356  100.364  -80.252  44.512  1
97357  100.387  -80.295  44.495  1
97358  100.430  -80.329  44.478  1
97359  100.482  -80.362  44.461  1
97360  100.517  -80.411  44.443  1
97361  100.543  -80.455  44.425  1
97362  100.628  -80.530  44.407  1
97363  100.607  -80.585  44.388  1
97364  100.545  -80.563  44.367  1
97365  100.579  -80.578  44.347  1
97366  100.620  -80.600  44.328  1
97367  100.660  -80.622  44.312  1
97368  100.700  -80.644  44.295  1
97369  100.741  -80.666  44.279  1
97370  100.781  -80.688  44.263  1
97371  100.821  -80.710  44.246  1
97372  100.861  -80.732  44.230  1
97373  100.901  -80.754  44.213  1
97374  100.941  -80.776  44.197  1
97375  100.986  -80.792  44.181  1
97376  101.033  -80.804  44.165  1
97377  101.079  -80.817  44.150  1
97378  101.125  -80.830  44.136  1
97379  101.172  -80.843  44.121  1
97380  101.218  -80.856  44.107  1
97381  101.265  -80.869  44.093  1
97382  101.312  -80.882  44.079  1
97383  101.358  -80.895  44.065  1
97645  93.503  -78.578  53.812  1
97646  93.513  -78.576  53.798  1
97647  93.523  -78.573  53.783  1
97648  93.533  -78.570  53.768  1
97649  93.542  -78.568  53.753  1
97650  93.552  -78.566  53.736  1
97651  93.562  -78.563  53.718  1
97652  93.571  -78.561  53.700  1
97653  93.576  -78.555  53.682  1
97654  93.575  -78.546  53.664  1
97655  93.574  -78.537  53.645  1
97656  93.572  -78.528  53.626  1
97657  93.571  -78.518  53.607  1
97658  93.575  -78.506  53.588  1
97659  93.589  -78.491  53.569  1
97660  93.612  -78.476  53.549  1
97661  93.634  -78.460  53.530  1
97662  93.656  -78.445  53.511  1
97663  93.671  -78.435  53.493  1
97664  93.682  -78.428  53.474  1
97673  93.819  -78.360  53.304  1
97674  93.834  -78.354  53.285  1
97675  93.849  -78.346  53.266  1
97676  93.864  -78.338  53.246  1
97677  93.880  -78.332  53.227  1
97678  93.896  -78.324  53.209  1
97679  93.911  -78.316  53.193  1
97680  93.926  -78.310  53.174  1
97681  93.941  -78.304  53.157  1
97682  93.942  -78.288  53.140  1
97683  93.956  -78.280  53.125  1
97684  93.969  -78.289  53.113  1
97685  93.981  -78.295  53.102  1
97686  93.989  -78.299  53.089  1
97687  93.997  -78.303  53.076  1
97688  94.005  -78.307  53.061  1
97689  94.013  -78.310  53.047  1
97690  94.022  -78.314  53.035  1
97691  94.030  -78.317  53.023  1
97692  94.038  -78.321  53.011  1
97693  94.046  -78.325  52.998  1
97694  94.054  -78.329  52.985  1
97695  94.062  -78.332  52.971  1
97696  94.071  -78.336  52.957  1
97697  94.082  -78.341  52.944  1
97698  94.091  -78.346  52.931  1
97699  94.096  -78.355  52.918  1
97700  94.100  -78.363  52.903  1
97701  94.105  -78.373  52.890  1
97702  94.110  -78.382  52.878  1
97703  94.114  -78.390  52.868  1
97704  94.119  -78.399  52.857  1
97705  94.123  -78.408  52.850  1
97706  94.128  -78.416  52.843  1
97707  94.133  -78.426  52.834  1
97708  94.137  -78.429  52.822  1
97709  94.142  -78.432  52.811  1
97710  94.146  -78.434  52.801  1
97711  94.151  -78.436  52.792  1
97712  94.155  -78.438  52.780  1
97713  94.158  -78.420  52.766  1
97714  94.164  -78.399  52.750  1
97715  94.183  -78.385  52.728  1
97716  94.201  -78.372  52.705  1
97717  94.219  -78.360  52.681  1
97718  94.241  -78.362  52.656  1
97719  94.262  -78.363  52.629  1
97720  94.282  -78.366  52.601  1
97721  94.297  -78.375  52.574  1
97722  94.306  -78.392  52.542  1
97723  94.315  -78.410  52.510  1
97724  94.323  -78.427  52.478  1
97725  94.332  -78.444  52.446  1
97726  94.340  -78.461  52.413  1
97727  94.359  -78.456  52.379  1
97728  94.381  -78.448  52.345  1
97729  94.402  -78.439  52.307  1
97730  94.439  -78.453  52.268  1
97731  94.476  -78.467  52.230  1
97732  94.501  -78.451  52.191  1
97733  94.526  -78.435  52.153  1
97734  94.550  -78.419  52.115  1
97735  94.574  -78.402  52.077  1
97736  94.599  -78.385  52.035  1
97737  94.616  -78.374  51.992  1
97738  94.627  -78.369  51.948  1
97739  94.637  -78.363  51.903  1
97740  94.648  -78.357  51.856  1
97741  94.659  -78.351  51.807  1
97742  94.669  -78.346  51.757  1
97743  94.681  -78.347  51.710  1
97744  94.693  -78.350  51.664  1
97745  94.705  -78.351  51.618  1
97746  94.718  -78.352  51.572  1
97747  94.731  -78.349  51.527  1
97748  94.744  -78.346  51.483  1
97749  94.755  -78.348  51.439  1
97750  94.765  -78.352  51.398  1
97751  94.778  -78.354  51.359  1
97752  94.796  -78.346  51.323  1
97753  94.810  -78.347  51.289  1
97754  94.823  -78.351  51.252  1
97755  94.844  -78.351  51.213  1
97756  94.866  -78.351  51.170  1
97757  94.889  -78.351  51.121  1
97758  94.913  -78.352  51.070  1
97759  94.938  -78.354  51.018  1
97760  94.949  -78.355  50.967  1
97761  94.960  -78.357  50.918  1
97762  94.971  -78.358  50.870  1
97763  94.981  -78.360  50.823  1
97764  94.992  -78.361  50.775  1
97765  95.002  -78.361  50.728  1
97766  95.011  -78.357  50.681  1
97767  95.020  -78.354  50.635  1
97768  95.029  -78.349  50.591  1
97769  95.039  -78.338  50.547  1
97770  95.061  -78.278  50.503  1
97771  95.083  -78.219  50.461  1
97772  95.111  -78.183  50.421  1
97773  95.126  -78.184  50.381  1
97774  95.162  -78.207  50.342  1
97775  95.198  -78.229  50.302  1
97776  95.234  -78.252  50.264  1
97777  95.246  -78.243  50.227  1
97778  95.256  -78.232  50.190  1
97779  95.267  -78.220  50.153  1
97780  95.277  -78.210  50.117  1
97781  95.288  -78.198  50.079  1
97782  95.299  -78.187  50.041  1
97783  95.309  -78.175  50.004  1
97784  95.319  -78.171  49.967  1
97785  95.329  -78.174  49.929  1
97786  95.338  -78.176  49.893  1
97787  95.347  -78.179  49.857  1
97788  95.356  -78.182  49.823  1
97789  95.366  -78.185  49.790  1
97790  95.376  -78.188  49.757  1
97791  95.385  -78.191  49.726  1
97792  95.394  -78.194  49.693  1
97793  95.404  -78.197  49.661  1
97794  95.413  -78.199  49.629  1
97795  95.422  -78.202  49.600  1
97796  95.431  -78.205  49.572  1
97797  95.447  -78.211  49.543  1
97798  95.470  -78.223  49.514  1
97799  95.494  -78.235  49.484  1
97800  95.503  -78.238  49.455  1
97801  95.509  -78.237  49.427  1
97802  95.515  -78.238  49.397  1
97803  95.524  -78.245  49.365  1
97804  95.533  -78.253  49.333  1
97805  95.542  -78.260  49.303  1
97806  95.551  -78.266  49.272  1
97807  95.560  -78.274  49.240  1
97808  95.570  -78.281  49.208  1
97809  95.579  -78.288  49.174  1
97810  95.588  -78.295  49.138  1
97811  95.597  -78.302  49.100  1
97812  95.606  -78.310  49.060  1
97813  95.616  -78.316  49.022  1
97814  95.625  -78.323  48.984  1
97815  95.628  -78.326  48.946  1
97816  95.623  -78.322  48.911  1
97817  95.619  -78.319  48.874  1
97818  95.615  -78.315  48.835  1
97819  95.611  -78.312  48.795  1
97820  95.625  -78.319  48.753  1
97821  95.639  -78.328  48.712  1
97822  95.654  -78.336  48.670  1
97823  95.671  -78.341  48.629  1
97824  95.689  -78.342  48.586  1
97825  95.703  -78.343  48.543  1
97826  95.716  -78.344  48.500  1
97827  95.728  -78.347  48.459  1
97828  95.740  -78.349  48.419  1
97829  95.762  -78.355  48.377  1
97830  95.780  -78.357  48.335  1
97831  95.796  -78.357  48.293  1
97832  95.811  -78.357  48.251  1
97833  95.826  -78.357  48.209  1
97834  95.842  -78.358  48.168  1
97835  95.860  -78.360  48.126  1
97836  95.876  -78.362  48.085  1
97837  95.893  -78.363  48.044  1
97838  95.910  -78.366  48.003  1
97839  95.922  -78.366  47.963  1
97840  95.937  -78.370  47.925  1
97841  95.951  -78.374  47.888  1
97842  95.965  -78.378  47.850  1
97843  95.979  -78.382  47.813  1
97844  95.991  -78.388  47.776  1
97845  96.005  -78.396  47.740  1
97846  96.019  -78.406  47.704  1
97847  96.033  -78.418  47.667  1
97848  96.047  -78.430  47.635  1
97849  96.062  -78.442  47.602  1
97850  96.076  -78.454  47.569  1
97851  96.086  -78.461  47.535  1
97852  96.085  -78.476  47.501  1
97853  96.084  -78.492  47.468  1
97854  96.085  -78.506  47.437  1
97855  96.102  -78.510  47.407  1
97856  96.118  -78.514  47.376  1
97857  96.146  -78.520  47.346  1
97858  96.175  -78.526  47.317  1
97859  96.204  -78.531  47.287  1
97860  96.234  -78.537  47.257  1
97861  96.263  -78.542  47.229  1
97862  96.292  -78.548  47.201  1
97863  96.321  -78.554  47.174  1
97864  96.350  -78.558  47.147  1
97865  96.380  -78.561  47.118  1
97866  96.409  -78.564  47.087  1
97867  96.438  -78.568  47.057  1
97868  96.467  -78.570  47.026  1
97869  96.497  -78.573  46.998  1
97870  96.526  -78.575  46.971  1
97871  96.555  -78.578  46.944  1
97872  96.585  -78.580  46.918  1
97873  96.614  -78.582  46.891  1
97874  96.643  -78.585  46.864  1
97875  96.672  -78.587  46.837  1
97876  96.681  -78.579  46.810  1
97877  96.730  -78.589  46.785  1
97878  96.735  -78.600  46.762  1
97879  96.736  -78.611  46.739  1
97880  96.736  -78.622  46.716  1
97881  96.737  -78.633  46.692  1
97882  96.737  -78.644  46.669  1
97883  96.756  -78.655  46.645  1
97884  96.761  -78.671  46.623  1
97885  96.774  -78.686  46.601  1
97886  96.787  -78.700  46.579  1
97887  96.799  -78.715  46.557  1
97888  96.809  -78.726  46.535  1
97889  96.819  -78.736  46.513  1
97890  96.830  -78.747  46.494  1
97891  96.846  -78.766  46.474  1
97892  96.865  -78.789  46.455  1
97893  96.885  -78.812  46.436  1
97894  96.904  -78.836  46.418  1
97895  96.923  -78.859  46.399  1
97896  96.943  -78.880  46.381  1
97897  96.969  -78.886  46.364  1
97898  96.999  -78.896  46.348  1
97899  97.029  -78.906  46.333  1
97900  97.058  -78.917  46.317  1
97901  97.088  -78.927  46.301  1
97902  97.118  -78.938  46.286  1
97903  97.148  -78.949  46.271  1
97904  97.177  -78.959  46.256  1
97905  97.207  -78.970  46.241  1
97906  97.237  -78.980  46.226  1
97907  97.272  -78.976  46.208  1
97908  97.306  -78.973  46.189  1
97909  97.341  -78.970  46.169  1
97910  97.377  -78.975  46.148  1
97911  97.412  -78.986  46.129  1
97912  97.428  -78.985  46.110  1
97913  97.443  -78.984  46.092  1
97914  97.459  -78.984  46.074  1
97915  97.470  -78.980  46.055  1
97916  97.478  -78.974  46.035  1
97917  97.487  -78.968  46.015  1
97918  97.495  -78.962  45.997  1
97919  97.503  -78.956  45.980  1
97920  97.511  -78.950  45.963  1
97921  97.519  -78.944  45.946  1
97922  97.528  -78.938  45.930  1
97923  97.536  -78.932  45.915  1
97924  97.544  -78.927  45.901  1
97925  97.552  -78.921  45.886  1
97926  97.561  -78.915  45.873  1
97927  97.573  -78.910  45.860  1
97928  97.590  -78.906  45.845  1
97929  97.608  -78.903  45.829  1
97930  97.626  -78.899  45.811  1
97931  97.640  -78.897  45.792  1
97932  97.653  -78.895  45.774  1
97933  97.666  -78.893  45.755  1
97934  97.688  -78.930  45.737  1
97935  97.706  -78.961  45.719  1
97936  97.709  -78.959  45.702  1
97937  97.711  -78.955  45.685  1
97938  97.714  -78.952  45.667  1
97939  97.717  -78.950  45.653  1
97940  97.740  -78.964  45.637  1
97941  97.775  -78.987  45.621  1
97942  97.783  -78.992  45.603  1
97943  97.790  -78.996  45.586  1
97944  97.797  -79.002  45.571  1
97945  97.804  -79.007  45.556  1
97946  97.812  -79.012  45.544  1
97947  97.819  -79.017  45.531  1
97948  97.826  -79.022  45.518  1
97949  97.833  -79.028  45.505  1
97950  97.841  -79.033  45.492  1
97951  97.848  -79.037  45.479  1
97952  97.855  -79.043  45.466  1
97953  97.860  -79.056  45.453  1
97954  97.864  -79.069  45.439  1
97955  97.872  -79.080  45.427  1
97956  97.889  -79.087  45.416  1
97957  97.906  -79.093  45.405  1
97958  97.922  -79.100  45.394  1
97959  97.938  -79.107  45.383  1
97960  97.955  -79.111  45.373  1
97961  97.969  -79.101  45.361  1
97962  97.985  -79.090  45.348  1
97963  98.000  -79.080  45.336  1
97964  98.014  -79.070  45.323  1
97965  98.021  -79.074  45.311  1
97966  98.045  -79.078  45.300  1
97967  98.095  -79.080  45.291  1
97968  98.145  -79.081  45.282  1
97969  98.177  -79.096  45.273  1
97970  98.203  -79.105  45.265  1
97971  98.228  -79.115  45.256  1
97972  98.253  -79.124  45.249  1
97973  98.279  -79.134  45.242  1
97974  98.304  -79.143  45.235  1
97975  98.329  -79.153  45.227  1
97976  98.355  -79.162  45.218  1
97977  98.379  -79.174  45.209  1
97978  98.405  -79.184  45.200  1
97979  98.441  -79.197  45.190  1
97980  98.478  -79.209  45.179  1
97981  98.515  -79.221  45.169  1
97982  98.552  -79.234  45.158  1
97983  98.588  -79.246  45.147  1
97984  98.625  -79.258  45.136  1
97985  98.661  -79.270  45.125  1
97986  98.698  -79.282  45.113  1
97987  98.734  -79.294  45.102  1
97988  98.771  -79.306  45.093  1
97989  98.808  -79.319  45.083  1
97990  98.844  -79.332  45.073  1
97991  98.850  -79.335  45.063  1
97992  98.860  -79.343  45.055  1
97993  98.883  -79.360  45.048  1
97994  98.907  -79.378  45.041  1
97995  98.930  -79.395  45.034  1
97996  98.954  -79.413  45.027  1
97997  98.978  -79.430  45.021  1
97998  99.001  -79.447  45.015  1
97999  99.025  -79.465  45.007  1
98000  99.057  -79.473  44.999  1
98001  99.108  -79.457  44.989  1
98002  99.124  -79.460  44.979  1
98003  99.134  -79.466  44.969  1
98004  99.144  -79.472  44.959  1
98005  99.153  -79.477  44.949  1
98006  99.163  -79.483  44.938  1
98007  99.173  -79.488  44.926  1
98008  99.185  -79.498  44.915  1
98009  99.200  -79.513  44.903  1
98010  99.215  -79.528  44.892  1
98011  99.230  -79.542  44.882  1
98012  99.245  -79.557  44.874  1
98013  99.264  -79.568  44.866  1
98014  99.285  -79.576  44.858  1
98015  99.307  -79.585  44.850  1
98016  99.329  -79.593  44.841  1
98017  99.350  -79.602  44.832  1
98018  99.372  -79.610  44.823  1
98019  99.393  -79.617  44.814  1
98020  99.408  -79.612  44.804  1
98021  99.424  -79.607  44.795  1
98022  99.439  -79.601  44.786  1
98023  99.454  -79.595  44.778  1
98024  99.470  -79.590  44.771  1
98025  99.485  -79.585  44.764  1
98026  99.500  -79.579  44.756  1
98027  99.530  -79.582  44.749  1
98028  99.560  -79.585  44.743  1
98029  99.590  -79.588  44.736  1
98030  99.620  -79.592  44.729  1
98031  99.650  -79.595  44.724  1
98032  99.680  -79.598  44.719  1
98033  99.710  -79.604  44.713  1
98034  99.744  -79.636  44.708  1
98035  99.761  -79.661  44.703  1
98036  99.779  -79.686  44.698  1
98037  99.796  -79.711  44.692  1
98038  99.814  -79.736  44.687  1
98039  99.831  -79.761  44.681  1
98040  99.849  -79.786  44.674  1
98041  99.866  -79.811  44.668  1
98042  99.884  -79.836  44.661  1
98043  99.900  -79.862  44.656  1
98044  99.931  -79.899  44.649  1
98045  99.957  -79.924  44.641  1
98046  99.989  -79.955  44.633  1
98047  100.021  -79.987  44.626  1
98048  100.054  -80.018  44.618  1
98049  100.086  -80.049  44.610  1
98050  100.123  -80.075  44.603  1
98051  100.169  -80.093  44.594  1
98052  100.215  -80.112  44.584  1
98053  100.261  -80.131  44.574  1
98054  100.307  -80.149  44.563  1
98055  100.352  -80.168  44.552  1
98056  100.392  -80.201  44.539  1
98057  100.431  -80.239  44.525  1
98058  100.464  -80.279  44.511  1
98059  100.487  -80.322  44.495  1
98060  100.529  -80.359  44.478  1
98061  100.564  -80.408  44.460  1
98062  100.563  -80.458  44.442  1
98063  100.536  -80.509  44.424  1
98064  100.532  -80.554  44.406  1
98065  100.554  -80.582  44.385  1
98066  100.583  -80.591  44.365  1
98067  100.616  -80.602  44.346  1
98068  100.656  -80.624  44.327  1
98069  100.696  -80.646  44.309  1
98070  100.737  -80.668  44.291  1
98071  100.777  -80.690  44.273  1
98072  100.817  -80.712  44.256  1
98073  100.857  -80.734  44.239  1
98074  100.897  -80.756  44.222  1
98075  100.944  -80.770  44.204  1
98076  100.990  -80.782  44.188  1
98077  101.037  -80.795  44.172  1
98078  101.083  -80.808  44.157  1
98079  101.130  -80.821  44.142  1
98080  101.176  -80.834  44.127  1
98081  101.222  -80.847  44.113  1
98082  101.269  -80.860  44.098  1
98083  101.316  -80.873  44.084  1
98084  101.362  -80.886  44.070  1
98085  101.408  -80.898  44.055  1
98345  93.494  -78.570  53.829  1
98346  93.504  -78.567  53.816  1
98347  93.513  -78.564  53.802  1
98348  93.523  -78.562  53.787  1
98349  93.533  -78.560  53.771  1
98350  93.543  -78.557  53.755  1
98351  93.552  -78.554  53.738  1
98352  93.562  -78.552  53.720  1
98353  93.571  -78.550  53.701  1
98354  93.573  -78.542  53.682  1
98355  93.571  -78.533  53.663  1
98356  93.570  -78.523  53.644  1
98357  93.569  -78.514  53.624  1
98358  93.568  -78.505  53.605  1
98359  93.577  -78.490  53.586  1
98360  93.594  -78.475  53.566  1
98361  93.617  -78.460  53.546  1
98362  93.639  -78.445  53.526  1
98363  93.660  -78.431  53.507  1
98364  93.672  -78.423  53.488  1
98365  93.683  -78.414  53.469  1
98375  93.836  -78.341  53.280  1
98376  93.851  -78.333  53.260  1
98377  93.866  -78.326  53.241  1
98378  93.882  -78.319  53.222  1
98379  93.897  -78.311  53.204  1
98380  93.913  -78.304  53.187  1
98381  93.928  -78.297  53.169  1
98382  93.943  -78.289  53.152  1
98383  93.954  -78.280  53.135  1
98384  93.966  -78.278  53.121  1
98385  93.976  -78.283  53.109  1
98386  93.984  -78.287  53.098  1
98387  93.992  -78.290  53.088  1
98388  94.000  -78.294  53.076  1
98389  94.008  -78.297  53.063  1
98390  94.016  -78.301  53.049  1
98391  94.025  -78.305  53.036  1
98392  94.033  -78.309  53.025  1
98393  94.041  -78.313  53.013  1
98394  94.049  -78.316  53.001  1
98395  94.057  -78.319  52.988  1
98396  94.066  -78.323  52.975  1
98397  94.074  -78.327  52.961  1
98398  94.082  -78.332  52.948  1
98399  94.087  -78.341  52.934  1
98400  94.092  -78.350  52.920  1
98401  94.097  -78.359  52.904  1
98402  94.101  -78.367  52.890  1
98403  94.106  -78.376  52.878  1
98404  94.111  -78.385  52.866  1
98405  94.115  -78.394  52.854  1
98406  94.120  -78.403  52.846  1
98407  94.124  -78.412  52.838  1
98408  94.129  -78.420  52.828  1
98409  94.134  -78.429  52.816  1
98410  94.138  -78.431  52.805  1
98411  94.143  -78.432  52.795  1
98412  94.147  -78.435  52.786  1
98413  94.151  -78.429  52.772  1
98414  94.153  -78.407  52.757  1
98415  94.156  -78.385  52.739  1
98416  94.173  -78.371  52.717  1
98417  94.191  -78.357  52.694  1
98418  94.210  -78.347  52.669  1
98419  94.231  -78.349  52.643  1
98420  94.253  -78.351  52.615  1
98421  94.273  -78.353  52.588  1
98422  94.294  -78.356  52.560  1
98423  94.302  -78.373  52.528  1
98424  94.311  -78.391  52.496  1
98425  94.319  -78.408  52.464  1
98426  94.328  -78.425  52.431  1
98427  94.339  -78.438  52.398  1
98428  94.360  -78.429  52.364  1
98429  94.381  -78.421  52.328  1
98430  94.402  -78.413  52.289  1
98431  94.434  -78.420  52.248  1
98432  94.472  -78.433  52.207  1
98433  94.506  -78.440  52.164  1
98434  94.530  -78.423  52.123  1
98435  94.555  -78.407  52.083  1
98436  94.579  -78.391  52.044  1
98437  94.604  -78.374  52.002  1
98438  94.622  -78.363  51.960  1
98439  94.632  -78.357  51.918  1
98440  94.642  -78.351  51.874  1
98441  94.653  -78.345  51.826  1
98442  94.664  -78.339  51.776  1
98443  94.674  -78.333  51.725  1
98444  94.686  -78.332  51.676  1
98445  94.698  -78.333  51.630  1
98446  94.710  -78.335  51.585  1
98447  94.722  -78.335  51.540  1
98448  94.735  -78.332  51.497  1
98449  94.748  -78.329  51.456  1
98450  94.760  -78.329  51.414  1
98451  94.770  -78.332  51.375  1
98452  94.781  -78.336  51.340  1
98453  94.795  -78.335  51.308  1
98454  94.810  -78.335  51.274  1
98455  94.829  -78.336  51.237  1
98456  94.851  -78.336  51.196  1
98457  94.873  -78.336  51.152  1
98458  94.895  -78.335  51.102  1
98459  94.917  -78.335  51.051  1
98460  94.939  -78.335  51.001  1
98461  94.960  -78.336  50.952  1
98462  94.970  -78.338  50.903  1
98463  94.980  -78.337  50.856  1
98464  94.989  -78.333  50.810  1
98465  94.997  -78.329  50.763  1
98466  95.006  -78.325  50.717  1
98467  95.015  -78.321  50.670  1
98468  95.024  -78.317  50.625  1
98469  95.032  -78.313  50.582  1
98470  95.049  -78.276  50.539  1
98471  95.071  -78.216  50.497  1
98472  95.100  -78.175  50.456  1
98473  95.142  -78.169  50.416  1
98474  95.151  -78.164  50.376  1
98475  95.161  -78.160  50.339  1
98476  95.170  -78.156  50.300  1
98477  95.197  -78.170  50.263  1
98478  95.233  -78.193  50.227  1
98479  95.262  -78.206  50.190  1
98480  95.273  -78.195  50.153  1
98481  95.283  -78.184  50.116  1
98482  95.294  -78.172  50.078  1
98483  95.305  -78.162  50.041  1
98484  95.316  -78.150  50.005  1
98485  95.325  -78.149  49.968  1
98486  95.334  -78.152  49.932  1
98487  95.344  -78.154  49.896  1
98488  95.353  -78.157  49.862  1
98489  95.362  -78.160  49.829  1
98490  95.372  -78.163  49.797  1
98491  95.382  -78.166  49.766  1
98492  95.391  -78.169  49.735  1
98493  95.400  -78.172  49.702  1
98494  95.409  -78.175  49.670  1
98495  95.419  -78.178  49.638  1
98496  95.428  -78.180  49.611  1
98497  95.438  -78.183  49.583  1
98498  95.447  -78.186  49.555  1
98499  95.461  -78.192  49.526  1
98500  95.485  -78.203  49.497  1
98501  95.494  -78.206  49.469  1
98502  95.500  -78.207  49.441  1
98503  95.510  -78.215  49.412  1
98504  95.519  -78.222  49.382  1
98505  95.528  -78.228  49.351  1
98506  95.537  -78.236  49.321  1
98507  95.546  -78.243  49.290  1
98508  95.556  -78.250  49.257  1
98509  95.565  -78.257  49.223  1
98510  95.574  -78.264  49.189  1
98511  95.583  -78.272  49.153  1
98512  95.593  -78.279  49.115  1
98513  95.602  -78.285  49.074  1
98514  95.611  -78.293  49.034  1
98515  95.620  -78.300  48.994  1
98516  95.626  -78.305  48.955  1
98517  95.622  -78.301  48.918  1
98518  95.618  -78.298  48.881  1
98519  95.614  -78.294  48.843  1
98520  95.615  -78.294  48.803  1
98521  95.629  -78.303  48.763  1
98522  95.644  -78.311  48.722  1
98523  95.659  -78.319  48.681  1
98524  95.674  -78.328  48.640  1
98525  95.691  -78.329  48.596  1
98526  95.704  -78.329  48.552  1
98527  95.718  -78.330  48.509  1
98528  95.731  -78.331  48.468  1
98529  95.743  -78.332  48.427  1
98530  95.762  -78.337  48.386  1
98531  95.777  -78.337  48.344  1
98532  95.793  -78.337  48.303  1
98533  95.810  -78.333  48.260  1
98534  95.827  -78.332  48.217  1
98535  95.845  -78.340  48.176  1
98536  95.862  -78.343  48.135  1
98537  95.878  -78.345  48.094  1
98538  95.894  -78.347  48.054  1
98539  95.911  -78.350  48.015  1
98540  95.925  -78.352  47.976  1
98541  95.939  -78.356  47.938  1
98542  95.954  -78.360  47.901  1
98543  95.968  -78.363  47.864  1
98544  95.982  -78.366  47.828  1
98545  95.995  -78.373  47.791  1
98546  96.010  -78.384  47.755  1
98547  96.024  -78.396  47.719  1
98548  96.039  -78.408  47.681  1
98549  96.053  -78.420  47.649  1
98550  96.067  -78.432  47.616  1
98551  96.082  -78.445  47.583  1
98552  96.092  -78.451  47.549  1
98553  96.094  -78.463  47.516  1
98554  96.093  -78.479  47.483  1
98555  96.097  -78.491  47.451  1
98556  96.114  -78.495  47.422  1
98557  96.130  -78.500  47.392  1
98558  96.147  -78.504  47.363  1
98559  96.176  -78.510  47.334  1
98560  96.205  -78.516  47.304  1
98561  96.235  -78.521  47.275  1
98562  96.264  -78.526  47.245  1
98563  96.293  -78.532  47.218  1
98564  96.322  -78.536  47.190  1
98565  96.352  -78.540  47.163  1
98566  96.381  -78.543  47.134  1
98567  96.410  -78.547  47.105  1
98568  96.439  -78.550  47.074  1
98569  96.468  -78.552  47.044  1
98570  96.498  -78.554  47.016  1
98571  96.527  -78.557  46.989  1
98572  96.556  -78.559  46.963  1
98573  96.585  -78.562  46.936  1
98574  96.615  -78.564  46.909  1
98575  96.644  -78.567  46.881  1
98576  96.673  -78.569  46.853  1
98577  96.702  -78.571  46.828  1
98578  96.724  -78.576  46.802  1
98579  96.726  -78.587  46.777  1
98580  96.726  -78.598  46.754  1
98581  96.727  -78.609  46.730  1
98582  96.727  -78.620  46.706  1
98583  96.728  -78.631  46.683  1
98584  96.740  -78.643  46.660  1
98585  96.750  -78.658  46.638  1
98586  96.762  -78.673  46.616  1
98587  96.775  -78.688  46.593  1
98588  96.787  -78.701  46.571  1
98589  96.797  -78.712  46.549  1
98590  96.807  -78.723  46.528  1
98591  96.824  -78.742  46.508  1
98592  96.843  -78.766  46.488  1
98593  96.863  -78.789  46.470  1
98594  96.882  -78.812  46.451  1
98595  96.901  -78.836  46.432  1
98596  96.921  -78.859  46.414  1
98597  96.940  -78.882  46.395  1
98598  96.963  -78.891  46.379  1
98599  96.992  -78.899  46.362  1
98600  97.021  -78.910  46.345  1
98601  97.051  -78.921  46.329  1
98602  97.081  -78.931  46.314  1
98603  97.110  -78.942  46.299  1
98604  97.140  -78.952  46.283  1
98605  97.170  -78.962  46.268  1
98606  97.199  -78.973  46.253  1
98607  97.232  -78.977  46.237  1
98608  97.266  -78.974  46.219  1
98609  97.301  -78.971  46.200  1
98610  97.335  -78.967  46.181  1
98611  97.370  -78.964  46.159  1
98612  97.407  -78.973  46.141  1
98613  97.434  -78.978  46.123  1
98614  97.449  -78.977  46.105  1
98615  97.465  -78.977  46.087  1
98616  97.478  -78.974  46.068  1
98617  97.486  -78.968  46.048  1
98618  97.494  -78.962  46.028  1
98619  97.503  -78.956  46.010  1
98620  97.511  -78.951  45.991  1
98621  97.519  -78.945  45.973  1
98622  97.527  -78.939  45.956  1
98623  97.535  -78.933  45.939  1
98624  97.543  -78.927  45.923  1
98625  97.551  -78.921  45.906  1
98626  97.560  -78.915  45.891  1
98627  97.573  -78.911  45.877  1
98628  97.591  -78.907  45.862  1
98629  97.609  -78.904  45.847  1
98630  97.627  -78.900  45.832  1
98631  97.645  -78.897  45.816  1
98632  97.659  -78.894  45.797  1
98633  97.672  -78.892  45.781  1
98634  97.685  -78.890  45.764  1
98635  97.698  -78.887  45.747  1
98636  97.719  -78.924  45.729  1
98637  97.730  -78.937  45.713  1
98638  97.732  -78.934  45.698  1
98639  97.735  -78.932  45.683  1
98640  97.744  -78.934  45.668  1
98641  97.780  -78.957  45.652  1
98642  97.787  -78.962  45.636  1
98643  97.795  -78.968  45.617  1
98644  97.802  -78.973  45.600  1
98645  97.809  -78.978  45.584  1
98646  97.816  -78.983  45.569  1
98647  97.824  -78.988  45.557  1
98648  97.831  -78.993  45.544  1
98649  97.838  -78.999  45.532  1
98650  97.846  -79.003  45.520  1
98651  97.853  -79.009  45.506  1
98652  97.860  -79.014  45.493  1
98653  97.867  -79.019  45.480  1
98654  97.873  -79.028  45.466  1
98655  97.877  -79.042  45.452  1
98656  97.888  -79.051  45.439  1
98657  97.904  -79.058  45.428  1
98658  97.921  -79.065  45.416  1
98659  97.938  -79.071  45.404  1
98660  97.954  -79.078  45.391  1
98661  97.970  -79.085  45.380  1
98662  97.987  -79.088  45.368  1
98663  98.002  -79.078  45.356  1
98664  98.017  -79.068  45.343  1
98665  98.031  -79.057  45.329  1
98666  98.039  -79.060  45.317  1
98667  98.044  -79.065  45.305  1
98668  98.095  -79.068  45.296  1
98669  98.142  -79.077  45.286  1
98670  98.176  -79.095  45.276  1
98671  98.201  -79.104  45.268  1
98672  98.227  -79.114  45.259  1
98673  98.252  -79.123  45.250  1
98674  98.277  -79.133  45.243  1
98675  98.302  -79.142  45.236  1
98676  98.327  -79.152  45.227  1
98677  98.354  -79.160  45.219  1
98678  98.384  -79.164  45.210  1
98679  98.416  -79.169  45.202  1
98680  98.450  -79.178  45.193  1
98681  98.484  -79.187  45.182  1
98682  98.518  -79.196  45.172  1
98683  98.553  -79.206  45.161  1
98684  98.590  -79.218  45.151  1
98685  98.626  -79.231  45.140  1
98686  98.663  -79.243  45.128  1
98687  98.700  -79.255  45.117  1
98688  98.736  -79.267  45.107  1
98689  98.773  -79.279  45.098  1
98690  98.809  -79.291  45.087  1
98691  98.846  -79.303  45.076  1
98692  98.863  -79.311  45.066  1
98693  98.876  -79.321  45.059  1
98694  98.899  -79.338  45.053  1
98695  98.923  -79.355  45.046  1
98696  98.946  -79.372  45.038  1
98697  98.970  -79.390  45.031  1
98698  98.994  -79.407  45.023  1
98699  99.022  -79.419  45.017  1
98700  99.052  -79.429  45.009  1
98701  99.081  -79.438  45.000  1
98702  99.110  -79.438  44.991  1
98703  99.119  -79.444  44.981  1
98704  99.129  -79.450  44.971  1
98705  99.139  -79.455  44.961  1
98706  99.149  -79.460  44.951  1
98707  99.158  -79.466  44.940  1
98708  99.168  -79.472  44.928  1
98709  99.181  -79.482  44.916  1
98710  99.195  -79.496  44.904  1
98711  99.210  -79.511  44.893  1
98712  99.225  -79.526  44.882  1
98713  99.242  -79.538  44.873  1
98714  99.264  -79.546  44.865  1
98715  99.286  -79.554  44.857  1
98716  99.308  -79.563  44.849  1
98717  99.330  -79.572  44.840  1
98718  99.351  -79.580  44.831  1
98719  99.373  -79.588  44.822  1
98720  99.395  -79.597  44.814  1
98721  99.414  -79.601  44.805  1
98722  99.430  -79.595  44.796  1
98723  99.445  -79.590  44.788  1
98724  99.461  -79.585  44.781  1
98725  99.476  -79.579  44.774  1
98726  99.491  -79.574  44.767  1
98727  99.514  -79.573  44.760  1
98728  99.544  -79.576  44.753  1
98729  99.574  -79.579  44.747  1
98730  99.604  -79.582  44.741  1
98731  99.634  -79.585  44.735  1
98732  99.664  -79.588  44.730  1
98733  99.694  -79.592  44.725  1
98734  99.724  -79.595  44.720  1
98735  99.754  -79.599  44.715  1
98736  99.792  -79.634  44.710  1
98737  99.810  -79.659  44.705  1
98738  99.828  -79.684  44.699  1
98739  99.845  -79.709  44.694  1
98740  99.862  -79.734  44.688  1
98741  99.880  -79.759  44.681  1
98742  99.898  -79.784  44.675  1
98743  99.915  -79.810  44.669  1
98744  99.902  -79.846  44.664  1
98745  99.973  -79.886  44.657  1
98746  99.997  -79.909  44.650  1
98747  100.021  -79.933  44.644  1
98748  100.053  -79.963  44.636  1
98749  100.085  -79.994  44.628  1
98750  100.117  -80.025  44.620  1
98751  100.153  -80.052  44.612  1
98752  100.199  -80.071  44.604  1
98753  100.245  -80.090  44.595  1
98754  100.291  -80.108  44.586  1
98755  100.335  -80.129  44.575  1
98756  100.374  -80.167  44.565  1
98757  100.412  -80.206  44.553  1
98758  100.451  -80.243  44.539  1
98759  100.489  -80.281  44.526  1
98760  100.527  -80.316  44.510  1
98761  100.559  -80.344  44.494  1
98762  100.555  -80.390  44.477  1
98763  100.552  -80.435  44.459  1
98764  100.548  -80.479  44.441  1
98765  100.545  -80.524  44.424  1
98766  100.570  -80.559  44.405  1
98767  100.595  -80.593  44.387  1
98768  100.622  -80.618  44.368  1
98769  100.652  -80.626  44.347  1
98770  100.692  -80.648  44.326  1
98771  100.733  -80.670  44.306  1
98772  100.773  -80.692  44.285  1
98773  100.813  -80.714  44.267  1
98774  100.855  -80.734  44.249  1
98775  100.901  -80.747  44.231  1
98776  100.948  -80.760  44.213  1
98777  100.994  -80.773  44.196  1
98778  101.041  -80.786  44.180  1
98779  101.088  -80.798  44.164  1
98780  101.134  -80.811  44.148  1
98781  101.180  -80.824  44.133  1
98782  101.227  -80.837  44.118  1
98783  101.273  -80.850  44.104  1
98784  101.320  -80.863  44.089  1
98785  101.366  -80.876  44.075  1
98786  101.413  -80.889  44.060  1
98787  101.459  -80.902  44.047  1
99046  93.494  -78.558  53.833  1
99047  93.504  -78.556  53.820  1
99048  93.514  -78.554  53.806  1
99049  93.523  -78.551  53.791  1
99050  93.533  -78.548  53.775  1
99051  93.543  -78.546  53.758  1
99052  93.552  -78.544  53.740  1
99053  93.562  -78.542  53.722  1
99054  93.571  -78.539  53.703  1
99055  93.569  -78.529  53.683  1
99056  93.568  -78.520  53.663  1
99057  93.567  -78.510  53.643  1
99058  93.566  -78.501  53.623  1
99059  93.568  -78.490  53.603  1
99060  93.578  -78.475  53.584  1
99061  93.600  -78.460  53.563  1
99062  93.622  -78.445  53.542  1
99063  93.645  -78.429  53.522  1
99064  93.661  -78.418  53.502  1
99065  93.673  -78.410  53.483  1
99066  93.685  -78.401  53.464  1
99076  93.838  -78.328  53.274  1
99077  93.853  -78.320  53.255  1
99078  93.868  -78.313  53.235  1
99079  93.884  -78.306  53.216  1
99080  93.899  -78.298  53.198  1
99081  93.915  -78.291  53.180  1
99082  93.930  -78.284  53.163  1
99083  93.945  -78.276  53.146  1
99084  93.961  -78.269  53.130  1
99085  93.969  -78.272  53.116  1
99086  93.977  -78.276  53.104  1
99087  93.984  -78.280  53.093  1
99088  93.992  -78.285  53.086  1
99089  93.999  -78.288  53.075  1
99090  94.007  -78.293  53.063  1
99091  94.014  -78.297  53.050  1
99092  94.022  -78.301  53.037  1
99093  94.030  -78.305  53.025  1
99094  94.037  -78.310  53.014  1
99095  94.045  -78.313  53.003  1
99096  94.052  -78.318  52.990  1
99097  94.060  -78.322  52.975  1
99098  94.067  -78.326  52.961  1
99099  94.075  -78.331  52.947  1
99100  94.081  -78.338  52.932  1
99101  94.088  -78.345  52.916  1
99102  94.093  -78.354  52.900  1
99103  94.098  -78.363  52.885  1
99104  94.102  -78.372  52.872  1
99105  94.107  -78.380  52.861  1
99106  94.112  -78.389  52.849  1
99107  94.116  -78.398  52.839  1
99108  94.121  -78.407  52.830  1
99109  94.126  -78.416  52.820  1
99110  94.130  -78.425  52.808  1
99111  94.135  -78.429  52.796  1
99112  94.139  -78.432  52.785  1
99113  94.144  -78.434  52.775  1
99114  94.146  -78.416  52.760  1
99115  94.149  -78.395  52.744  1
99116  94.151  -78.373  52.726  1
99117  94.164  -78.356  52.704  1
99118  94.182  -78.342  52.680  1
99119  94.201  -78.334  52.654  1
99120  94.222  -78.336  52.627  1
99121  94.244  -78.338  52.600  1
99122  94.265  -78.340  52.572  1
99123  94.285  -78.342  52.544  1
99124  94.298  -78.354  52.512  1
99125  94.307  -78.372  52.480  1
99126  94.315  -78.389  52.448  1
99127  94.324  -78.406  52.415  1
99128  94.339  -78.410  52.381  1
99129  94.360  -78.402  52.347  1
99130  94.381  -78.394  52.310  1
99131  94.402  -78.385  52.269  1
99132  94.429  -78.385  52.227  1
99133  94.467  -78.399  52.183  1
99134  94.504  -78.413  52.137  1
99135  94.535  -78.412  52.093  1
99136  94.559  -78.396  52.050  1
99137  94.584  -78.379  52.009  1
99138  94.608  -78.363  51.967  1
99139  94.627  -78.351  51.925  1
99140  94.637  -78.344  51.883  1
99141  94.648  -78.339  51.839  1
99142  94.659  -78.333  51.791  1
99143  94.669  -78.327  51.741  1
99144  94.680  -78.322  51.691  1
99145  94.690  -78.316  51.643  1
99146  94.702  -78.317  51.598  1
99147  94.714  -78.319  51.554  1
99148  94.727  -78.316  51.510  1
99149  94.740  -78.314  51.469  1
99150  94.753  -78.311  51.428  1
99151  94.765  -78.310  51.389  1
99152  94.775  -78.313  51.354  1
99153  94.786  -78.317  51.321  1
99154  94.797  -78.321  51.289  1
99155  94.815  -78.322  51.255  1
99156  94.835  -78.322  51.215  1
99157  94.856  -78.322  51.172  1
99158  94.876  -78.322  51.128  1
99159  94.897  -78.322  51.079  1
99160  94.917  -78.322  51.030  1
99161  94.937  -78.322  50.982  1
99162  94.958  -78.320  50.935  1
99163  94.975  -78.304  50.888  1
99164  94.984  -78.300  50.841  1
99165  94.992  -78.297  50.796  1
99166  95.001  -78.293  50.751  1
99167  95.010  -78.289  50.705  1
99168  95.019  -78.285  50.660  1
99169  95.028  -78.281  50.617  1
99170  95.037  -78.274  50.575  1
99171  95.059  -78.215  50.533  1
99172  95.085  -78.166  50.492  1
99173  95.128  -78.160  50.452  1
99174  95.172  -78.154  50.413  1
99175  95.182  -78.150  50.375  1
99176  95.191  -78.145  50.338  1
99177  95.200  -78.141  50.300  1
99178  95.210  -78.137  50.262  1
99179  95.219  -78.133  50.225  1
99180  95.233  -78.133  50.189  1
99181  95.269  -78.156  50.151  1
99182  95.290  -78.158  50.114  1
99183  95.301  -78.147  50.077  1
99184  95.311  -78.136  50.042  1
99185  95.322  -78.125  50.007  1
99186  95.331  -78.127  49.971  1
99187  95.340  -78.130  49.936  1
99188  95.350  -78.132  49.902  1
99189  95.359  -78.135  49.869  1
99190  95.369  -78.138  49.836  1
99191  95.378  -78.141  49.804  1
99192  95.387  -78.144  49.772  1
99193  95.397  -78.147  49.741  1
99194  95.406  -78.150  49.710  1
99195  95.415  -78.153  49.679  1
99196  95.425  -78.156  49.649  1
99197  95.435  -78.158  49.620  1
99198  95.444  -78.161  49.592  1
99199  95.453  -78.164  49.565  1
99200  95.462  -78.167  49.538  1
99201  95.476  -78.172  49.512  1
99202  95.486  -78.177  49.486  1
99203  95.496  -78.184  49.459  1
99204  95.505  -78.191  49.430  1
99205  95.514  -78.198  49.402  1
99206  95.523  -78.205  49.373  1
99207  95.533  -78.213  49.342  1
99208  95.542  -78.219  49.309  1
99209  95.551  -78.226  49.275  1
99210  95.560  -78.234  49.240  1
99211  95.569  -78.241  49.205  1
99212  95.579  -78.247  49.169  1
99213  95.588  -78.255  49.130  1
99214  95.597  -78.262  49.088  1
99215  95.606  -78.269  49.045  1
99216  95.615  -78.276  49.003  1
99217  95.624  -78.283  48.963  1
99218  95.621  -78.281  48.924  1
99219  95.617  -78.277  48.887  1
99220  95.613  -78.274  48.849  1
99221  95.620  -78.277  48.809  1
99222  95.634  -78.285  48.771  1
99223  95.649  -78.294  48.731  1
99224  95.664  -78.303  48.690  1
99225  95.678  -78.311  48.649  1
99226  95.692  -78.315  48.604  1
99227  95.705  -78.316  48.560  1
99228  95.719  -78.316  48.517  1
99229  95.732  -78.317  48.476  1
99230  95.745  -78.318  48.435  1
99231  95.760  -78.315  48.394  1
99232  95.777  -78.311  48.352  1
99233  95.795  -78.307  48.311  1
99234  95.812  -78.305  48.269  1
99235  95.830  -78.313  48.226  1
99236  95.848  -78.321  48.185  1
99237  95.865  -78.326  48.144  1
99238  95.881  -78.328  48.104  1
99239  95.897  -78.330  48.066  1
99240  95.913  -78.333  48.029  1
99241  95.928  -78.337  47.991  1
99242  95.943  -78.341  47.952  1
99243  95.958  -78.344  47.915  1
99244  95.972  -78.347  47.879  1
99245  95.987  -78.351  47.842  1
99246  96.002  -78.360  47.806  1
99247  96.016  -78.374  47.770  1
99248  96.030  -78.386  47.733  1
99249  96.045  -78.398  47.695  1
99250  96.059  -78.410  47.662  1
99251  96.074  -78.423  47.630  1
99252  96.088  -78.435  47.597  1
99253  96.098  -78.440  47.564  1
99254  96.103  -78.451  47.531  1
99255  96.102  -78.467  47.498  1
99256  96.109  -78.476  47.466  1
99257  96.126  -78.481  47.436  1
99258  96.143  -78.485  47.407  1
99259  96.159  -78.489  47.379  1
99260  96.177  -78.494  47.351  1
99261  96.206  -78.500  47.321  1
99262  96.236  -78.505  47.291  1
99263  96.265  -78.511  47.261  1
99264  96.294  -78.515  47.233  1
99265  96.323  -78.518  47.206  1
99266  96.353  -78.522  47.179  1
99267  96.382  -78.525  47.151  1
99268  96.410  -78.529  47.122  1
99269  96.440  -78.532  47.093  1
99270  96.469  -78.534  47.064  1
99271  96.499  -78.536  47.035  1
99272  96.528  -78.539  47.008  1
99273  96.557  -78.541  46.982  1
99274  96.586  -78.543  46.954  1
99275  96.613  -78.546  46.927  1
99276  96.640  -78.549  46.899  1
99277  96.665  -78.552  46.871  1
99278  96.691  -78.555  46.846  1
99279  96.703  -78.564  46.820  1
99280  96.707  -78.574  46.793  1
99281  96.710  -78.586  46.769  1
99282  96.713  -78.596  46.745  1
99283  96.716  -78.608  46.721  1
99284  96.718  -78.619  46.698  1
99285  96.725  -78.631  46.675  1
99286  96.738  -78.646  46.653  1
99287  96.750  -78.661  46.632  1
99288  96.763  -78.675  46.609  1
99289  96.774  -78.687  46.586  1
99290  96.785  -78.698  46.565  1
99291  96.802  -78.720  46.544  1
99292  96.822  -78.742  46.524  1
99293  96.841  -78.766  46.505  1
99294  96.861  -78.789  46.485  1
99295  96.880  -78.812  46.466  1
99296  96.899  -78.836  46.447  1
99297  96.919  -78.859  46.428  1
99298  96.938  -78.882  46.409  1
99299  96.959  -78.900  46.393  1
99300  96.984  -78.902  46.375  1
99301  97.014  -78.913  46.358  1
99302  97.043  -78.924  46.342  1
99303  97.073  -78.934  46.326  1
99304  97.103  -78.945  46.310  1
99305  97.133  -78.955  46.295  1
99306  97.162  -78.966  46.279  1
99307  97.192  -78.977  46.264  1
99308  97.226  -78.974  46.247  1
99309  97.261  -78.971  46.230  1
99310  97.296  -78.968  46.211  1
99311  97.330  -78.965  46.192  1
99312  97.365  -78.962  46.173  1
99313  97.399  -78.959  46.154  1
99314  97.437  -78.971  46.134  1
99315  97.455  -78.971  46.115  1
99316  97.471  -78.970  46.097  1
99317  97.486  -78.969  46.078  1
99318  97.494  -78.963  46.059  1
99319  97.502  -78.957  46.040  1
99320  97.510  -78.951  46.023  1
99321  97.518  -78.945  46.004  1
99322  97.526  -78.940  45.984  1
99323  97.535  -78.933  45.967  1
99324  97.543  -78.927  45.950  1
99325  97.551  -78.921  45.932  1
99326  97.560  -78.915  45.914  1
99327  97.574  -78.912  45.898  1
99328  97.591  -78.908  45.883  1
99329  97.609  -78.905  45.867  1
99330  97.627  -78.901  45.852  1
99331  97.645  -78.898  45.836  1
99332  97.663  -78.894  45.820  1
99333  97.677  -78.892  45.803  1
99334  97.690  -78.890  45.787  1
99335  97.704  -78.886  45.771  1
99336  97.717  -78.884  45.755  1
99337  97.730  -78.882  45.738  1
99338  97.750  -78.916  45.722  1
99339  97.753  -78.914  45.708  1
99340  97.755  -78.911  45.695  1
99341  97.784  -78.927  45.679  1
99342  97.792  -78.933  45.664  1
99343  97.799  -78.939  45.648  1
99344  97.807  -78.944  45.629  1
99345  97.814  -78.949  45.612  1
99346  97.821  -78.954  45.597  1
99347  97.828  -78.959  45.582  1
99348  97.836  -78.965  45.571  1
99349  97.843  -78.969  45.559  1
99350  97.850  -78.974  45.547  1
99351  97.858  -78.980  45.535  1
99352  97.865  -78.985  45.521  1
99353  97.872  -78.990  45.507  1
99354  97.879  -78.995  45.494  1
99355  97.886  -79.001  45.479  1
99356  97.890  -79.015  45.466  1
99357  97.903  -79.023  45.453  1
99358  97.920  -79.030  45.440  1
99359  97.937  -79.037  45.427  1
99360  97.953  -79.043  45.413  1
99361  97.969  -79.050  45.399  1
99362  97.986  -79.057  45.387  1
99363  98.003  -79.064  45.375  1
99364  98.019  -79.065  45.363  1
99365  98.033  -79.055  45.350  1
99366  98.049  -79.045  45.336  1
99367  98.056  -79.047  45.323  1
99368  98.062  -79.053  45.311  1
99369  98.094  -79.056  45.301  1
99370  98.138  -79.074  45.290  1
99371  98.174  -79.093  45.280  1
99372  98.200  -79.103  45.271  1
99373  98.225  -79.112  45.262  1
99374  98.250  -79.122  45.253  1
99375  98.276  -79.132  45.244  1
99376  98.305  -79.137  45.237  1
99377  98.335  -79.141  45.229  1
99378  98.366  -79.146  45.220  1
99379  98.396  -79.150  45.210  1
99380  98.428  -79.156  45.201  1
99381  98.462  -79.165  45.192  1
99382  98.496  -79.174  45.183  1
99383  98.530  -79.182  45.174  1
99384  98.564  -79.191  45.165  1
99385  98.598  -79.200  45.155  1
99386  98.632  -79.209  45.143  1
99387  98.666  -79.218  45.132  1
99388  98.701  -79.228  45.120  1
99389  98.738  -79.240  45.109  1
99390  98.774  -79.252  45.098  1
99391  98.811  -79.264  45.088  1
99392  98.848  -79.276  45.077  1
99393  98.877  -79.287  45.067  1
99394  98.891  -79.298  45.060  1
99395  98.915  -79.316  45.053  1
99396  98.939  -79.333  45.046  1
99397  98.965  -79.347  45.039  1
99398  98.994  -79.357  45.031  1
99399  99.024  -79.367  45.023  1
99400  99.047  -79.379  45.017  1
99401  99.066  -79.391  45.008  1
99402  99.086  -79.404  45.000  1
99403  99.101  -79.416  44.991  1
99404  99.115  -79.427  44.982  1
99405  99.124  -79.433  44.971  1
99406  99.134  -79.438  44.961  1
99407  99.144  -79.444  44.951  1
99408  99.154  -79.450  44.939  1
99409  99.163  -79.456  44.927  1
99410  99.175  -79.465  44.915  1
99411  99.191  -79.480  44.903  1
99412  99.205  -79.494  44.892  1
99413  99.222  -79.507  44.881  1
99414  99.243  -79.516  44.871  1
99415  99.265  -79.524  44.863  1
99416  99.287  -79.532  44.855  1
99417  99.309  -79.541  44.847  1
99418  99.331  -79.550  44.839  1
99419  99.352  -79.558  44.830  1
99420  99.374  -79.567  44.821  1
99421  99.396  -79.575  44.813  1
99422  99.417  -79.583  44.804  1
99423  99.435  -79.585  44.797  1
99424  99.451  -79.579  44.790  1
99425  99.466  -79.574  44.783  1
99426  99.482  -79.568  44.776  1
99427  99.498  -79.563  44.769  1
99428  99.528  -79.567  44.763  1
99429  99.558  -79.570  44.757  1
99430  99.588  -79.573  44.751  1
99431  99.618  -79.576  44.745  1
99432  99.648  -79.579  44.740  1
99433  99.678  -79.582  44.735  1
99434  99.708  -79.586  44.731  1
99435  99.738  -79.589  44.726  1
99436  99.768  -79.592  44.722  1
99437  99.798  -79.595  44.717  1
99438  99.837  -79.629  44.712  1
99439  99.859  -79.657  44.706  1
99440  99.876  -79.682  44.701  1
99441  99.894  -79.707  44.696  1
99442  99.911  -79.733  44.689  1
99443  99.929  -79.758  44.683  1
99444  99.930  -79.789  44.677  1
99445  99.930  -79.833  44.671  1
99446  100.015  -79.874  44.665  1
99447  100.039  -79.896  44.659  1
99448  100.063  -79.920  44.653  1
99449  100.087  -79.943  44.645  1
99450  100.116  -79.971  44.638  1
99451  100.148  -80.002  44.630  1
99452  100.184  -80.030  44.622  1
99453  100.229  -80.048  44.614  1
99454  100.275  -80.067  44.606  1
99455  100.317  -80.096  44.598  1
99456  100.355  -80.134  44.588  1
99457  100.394  -80.171  44.577  1
99458  100.431  -80.206  44.565  1
99459  100.466  -80.233  44.553  1
99460  100.500  -80.261  44.539  1
99461  100.535  -80.288  44.523  1
99462  100.569  -80.316  44.507  1
99463  100.567  -80.360  44.491  1
99464  100.563  -80.405  44.473  1
99465  100.560  -80.450  44.455  1
99466  100.562  -80.493  44.436  1
99467  100.587  -80.527  44.418  1
99468  100.612  -80.562  44.400  1
99469  100.637  -80.597  44.381  1
99470  100.662  -80.632  44.362  1
99471  100.690  -80.653  44.342  1
99472  100.728  -80.673  44.320  1
99473  100.769  -80.695  44.298  1
99474  100.813  -80.711  44.278  1
99475  100.859  -80.724  44.259  1
99476  100.906  -80.737  44.241  1
99477  100.952  -80.750  44.223  1
99478  100.998  -80.763  44.205  1
99479  101.045  -80.776  44.189  1
99480  101.092  -80.789  44.172  1
99481  101.138  -80.801  44.156  1
99482  101.184  -80.814  44.140  1
99483  101.231  -80.827  44.125  1
99484  101.277  -80.840  44.110  1
99485  101.324  -80.853  44.095  1
99486  101.370  -80.866  44.080  1
99487  101.417  -80.879  44.066  1
99488  101.463  -80.892  44.052  1
99489  101.510  -80.905  44.037  1
99747  93.495  -78.548  53.838  1
99748  93.504  -78.545  53.824  1
99749  93.514  -78.542  53.809  1
99750  93.523  -78.540  53.794  1
99751  93.534  -78.538  53.777  1
99752  93.543  -78.535  53.760  1
99753  93.553  -78.532  53.741  1
99754  93.562  -78.530  53.723  1
99755  93.567  -78.525  53.703  1
99756  93.566  -78.516  53.683  1
99757  93.565  -78.507  53.663  1
99758  93.563  -78.498  53.642  1
99759  93.562  -78.489  53.620  1
99760  93.569  -78.474  53.600  1
99761  93.583  -78.459  53.580  1
99762  93.606  -78.444  53.559  1
99763  93.628  -78.429  53.538  1
99764  93.650  -78.413  53.518  1
99765  93.662  -78.405  53.498  1
99766  93.674  -78.397  53.478  1
99767  93.686  -78.388  53.459  1
99777  93.840  -78.315  53.267  1
99778  93.855  -78.307  53.249  1
99779  93.870  -78.300  53.229  1
99780  93.886  -78.293  53.210  1
99781  93.901  -78.285  53.191  1
99782  93.917  -78.279  53.173  1
99783  93.932  -78.271  53.155  1
99784  93.947  -78.263  53.138  1
99785  93.962  -78.257  53.124  1
99786  93.967  -78.262  53.110  1
99787  93.970  -78.272  53.097  1
99788  93.973  -78.282  53.087  1
99789  93.979  -78.288  53.082  1
99790  93.987  -78.293  53.073  1
99791  93.994  -78.297  53.062  1
99792  94.002  -78.301  53.049  1
99793  94.010  -78.305  53.036  1
99794  94.017  -78.310  53.024  1
99795  94.025  -78.313  53.013  1
99796  94.033  -78.318  53.001  1
99797  94.040  -78.322  52.987  1
99798  94.048  -78.326  52.972  1
99799  94.055  -78.330  52.956  1
99800  94.063  -78.335  52.942  1
99801  94.070  -78.340  52.926  1
99802  94.076  -78.347  52.908  1
99803  94.083  -78.354  52.891  1
99804  94.089  -78.362  52.875  1
99805  94.096  -78.369  52.861  1
99806  94.103  -78.376  52.850  1
99807  94.108  -78.385  52.839  1
99808  94.113  -78.393  52.828  1
99809  94.117  -78.402  52.818  1
99810  94.122  -78.411  52.807  1
99811  94.127  -78.420  52.794  1
99812  94.131  -78.429  52.782  1
99813  94.136  -78.431  52.770  1
99814  94.140  -78.425  52.757  1
99815  94.142  -78.403  52.743  1
99816  94.144  -78.382  52.726  1
99817  94.147  -78.360  52.707  1
99818  94.154  -78.341  52.685  1
99819  94.173  -78.327  52.660  1
99820  94.192  -78.322  52.635  1
99821  94.213  -78.323  52.608  1
99822  94.235  -78.326  52.580  1
99823  94.256  -78.328  52.552  1
99824  94.276  -78.329  52.524  1
99825  94.294  -78.335  52.492  1
99826  94.303  -78.353  52.461  1
99827  94.312  -78.370  52.429  1
99828  94.320  -78.387  52.395  1
99829  94.339  -78.383  52.361  1
99830  94.360  -78.375  52.325  1
99831  94.381  -78.366  52.288  1
99832  94.402  -78.358  52.246  1
99833  94.424  -78.351  52.202  1
99834  94.462  -78.366  52.157  1
99835  94.499  -78.379  52.109  1
99836  94.537  -78.394  52.062  1
99837  94.564  -78.385  52.016  1
99838  94.589  -78.368  51.971  1
99839  94.613  -78.351  51.929  1
99840  94.632  -78.339  51.887  1
99841  94.642  -78.333  51.845  1
99842  94.653  -78.327  51.801  1
99843  94.664  -78.321  51.753  1
99844  94.674  -78.316  51.705  1
99845  94.685  -78.310  51.657  1
99846  94.695  -78.304  51.611  1
99847  94.706  -78.300  51.566  1
99848  94.718  -78.302  51.523  1
99849  94.732  -78.299  51.481  1
99850  94.744  -78.296  51.441  1
99851  94.757  -78.294  51.401  1
99852  94.770  -78.291  51.364  1
99853  94.780  -78.294  51.331  1
99854  94.791  -78.299  51.299  1
99855  94.801  -78.304  51.267  1
99856  94.812  -78.308  51.231  1
99857  94.825  -78.312  51.190  1
99858  94.845  -78.312  51.147  1
99859  94.865  -78.312  51.103  1
99860  94.886  -78.312  51.057  1
99861  94.906  -78.312  51.010  1
99862  94.927  -78.313  50.964  1
99863  94.947  -78.305  50.918  1
99864  94.968  -78.284  50.873  1
99865  94.988  -78.264  50.828  1
99866  94.996  -78.260  50.783  1
99867  95.005  -78.257  50.739  1
99868  95.014  -78.253  50.695  1
99869  95.023  -78.249  50.651  1
99870  95.031  -78.244  50.609  1
99871  95.047  -78.213  50.568  1
99872  95.070  -78.157  50.527  1
99873  95.114  -78.151  50.488  1
99874  95.157  -78.146  50.448  1
99875  95.201  -78.140  50.410  1
99876  95.213  -78.135  50.372  1
99877  95.222  -78.131  50.335  1
99878  95.232  -78.127  50.297  1
99879  95.241  -78.122  50.260  1
99880  95.250  -78.118  50.224  1
99881  95.259  -78.114  50.187  1
99882  95.269  -78.109  50.151  1
99883  95.278  -78.106  50.115  1
99884  95.305  -78.119  50.079  1
99885  95.317  -78.110  50.044  1
99886  95.328  -78.102  50.010  1
99887  95.337  -78.105  49.975  1
99888  95.346  -78.108  49.942  1
99889  95.356  -78.111  49.909  1
99890  95.365  -78.113  49.876  1
99891  95.375  -78.116  49.844  1
99892  95.384  -78.119  49.812  1
99893  95.393  -78.122  49.781  1
99894  95.403  -78.125  49.751  1
99895  95.412  -78.128  49.722  1
99896  95.421  -78.131  49.692  1
99897  95.431  -78.134  49.663  1
99898  95.442  -78.138  49.634  1
99899  95.452  -78.142  49.607  1
99900  95.462  -78.147  49.581  1
99901  95.471  -78.150  49.556  1
99902  95.477  -78.154  49.531  1
99903  95.483  -78.155  49.506  1
99904  95.491  -78.160  49.480  1
99905  95.500  -78.167  49.453  1
99906  95.510  -78.175  49.424  1
99907  95.519  -78.181  49.394  1
99908  95.528  -78.188  49.362  1
99909  95.537  -78.196  49.328  1
99910  95.546  -78.203  49.293  1
99911  95.555  -78.210  49.257  1
99912  95.564  -78.217  49.220  1
99913  95.573  -78.224  49.181  1
99914  95.583  -78.232  49.141  1
99915  95.592  -78.238  49.099  1
99916  95.601  -78.245  49.057  1
99917  95.610  -78.253  49.015  1
99918  95.619  -78.260  48.972  1
99919  95.620  -78.260  48.931  1
99920  95.616  -78.257  48.891  1
99921  95.612  -78.253  48.852  1
99922  95.624  -78.260  48.813  1
99923  95.639  -78.269  48.775  1
99924  95.654  -78.277  48.736  1
99925  95.669  -78.286  48.696  1
99926  95.686  -78.298  48.655  1
99927  95.703  -78.304  48.613  1
99928  95.706  -78.302  48.570  1
99929  95.719  -78.303  48.526  1
99930  95.732  -78.304  48.484  1
99931  95.745  -78.304  48.442  1
99932  95.762  -78.285  48.400  1
99933  95.779  -78.282  48.359  1
99934  95.797  -78.278  48.317  1
99935  95.815  -78.285  48.275  1
99936  95.833  -78.294  48.234  1
99937  95.851  -78.302  48.195  1
99938  95.868  -78.308  48.156  1
99939  95.884  -78.310  48.117  1
99940  95.900  -78.313  48.079  1
99941  95.917  -78.316  48.042  1
99942  95.934  -78.320  48.005  1
99943  95.948  -78.324  47.966  1
99944  95.963  -78.327  47.929  1
99945  95.979  -78.330  47.893  1
99946  95.995  -78.332  47.856  1
99947  96.010  -78.344  47.820  1
99948  96.022  -78.362  47.783  1
99949  96.036  -78.376  47.746  1
99950  96.050  -78.388  47.709  1
99951  96.065  -78.401  47.676  1
99952  96.079  -78.413  47.643  1
99953  96.094  -78.425  47.611  1
99954  96.104  -78.430  47.578  1
99955  96.112  -78.438  47.545  1
99956  96.111  -78.454  47.512  1
99957  96.121  -78.462  47.481  1
99958  96.138  -78.466  47.451  1
99959  96.155  -78.470  47.422  1
99960  96.171  -78.475  47.394  1
99961  96.187  -78.479  47.367  1
99962  96.207  -78.484  47.337  1
99963  96.237  -78.489  47.307  1
99964  96.266  -78.493  47.278  1
99965  96.295  -78.497  47.249  1
99966  96.324  -78.500  47.221  1
99967  96.354  -78.504  47.194  1
99968  96.383  -78.507  47.167  1
99969  96.411  -78.510  47.140  1
99970  96.441  -78.513  47.111  1
99971  96.470  -78.516  47.082  1
99972  96.498  -78.518  47.054  1
99973  96.523  -78.521  47.027  1
99974  96.549  -78.524  47.000  1
99975  96.576  -78.527  46.972  1
99976  96.601  -78.530  46.944  1
99977  96.627  -78.533  46.916  1
99978  96.654  -78.536  46.889  1
99979  96.680  -78.540  46.863  1
99980  96.683  -78.551  46.838  1
99981  96.686  -78.562  46.813  1
99982  96.689  -78.573  46.789  1
99983  96.692  -78.584  46.763  1
99984  96.700  -78.598  46.738  1
99985  96.708  -78.608  46.714  1
99986  96.719  -78.616  46.691  1
99987  96.726  -78.633  46.669  1
99988  96.739  -78.648  46.648  1
99989  96.751  -78.662  46.625  1
99990  96.762  -78.673  46.603  1
99991  96.781  -78.696  46.582  1
99992  96.800  -78.720  46.562  1
99993  96.819  -78.742  46.542  1
99994  96.839  -78.766  46.522  1
99995  96.858  -78.789  46.503  1
99996  96.878  -78.812  46.484  1
99997  96.897  -78.836  46.464  1
99998  96.916  -78.859  46.445  1
99999  96.936  -78.882  46.426  1
100000  96.955  -78.905  46.409  1
100001  96.979  -78.911  46.391  1
100002  97.006  -78.917  46.374  1
100003  97.036  -78.927  46.357  1
100004  97.066  -78.938  46.339  1
100005  97.095  -78.949  46.323  1
100006  97.125  -78.959  46.307  1
100007  97.155  -78.969  46.291  1
100008  97.186  -78.975  46.275  1
100009  97.221  -78.972  46.258  1
100010  97.255  -78.968  46.241  1
100011  97.290  -78.965  46.223  1
100012  97.325  -78.962  46.204  1
100013  97.360  -78.959  46.186  1
100014  97.394  -78.955  46.168  1
100015  97.430  -78.955  46.148  1
100016  97.461  -78.965  46.128  1
100017  97.476  -78.964  46.109  1
100018  97.492  -78.963  46.090  1
100019  97.502  -78.958  46.070  1
100020  97.510  -78.952  46.051  1
100021  97.518  -78.946  46.034  1
100022  97.526  -78.940  46.015  1
100023  97.534  -78.933  45.996  1
100024  97.542  -78.928  45.979  1
100025  97.550  -78.922  45.961  1
100026  97.559  -78.916  45.942  1
100027  97.574  -78.912  45.923  1
100028  97.592  -78.908  45.906  1
100029  97.609  -78.905  45.890  1
100030  97.628  -78.902  45.873  1
100031  97.645  -78.899  45.857  1
100032  97.663  -78.895  45.842  1
100033  97.681  -78.892  45.826  1
100034  97.696  -78.889  45.809  1
100035  97.709  -78.886  45.794  1
100036  97.722  -78.884  45.777  1
100037  97.735  -78.882  45.761  1
100038  97.749  -78.880  45.746  1
100039  97.762  -78.877  45.731  1
100040  97.774  -78.893  45.717  1
100041  97.788  -78.899  45.704  1
100042  97.797  -78.905  45.689  1
100043  97.804  -78.910  45.673  1
100044  97.811  -78.915  45.658  1
100045  97.818  -78.920  45.640  1
100046  97.826  -78.925  45.624  1
100047  97.833  -78.930  45.610  1
100048  97.841  -78.936  45.597  1
100049  97.848  -78.940  45.586  1
100050  97.855  -78.946  45.575  1
100051  97.862  -78.951  45.563  1
100052  97.869  -78.956  45.550  1
100053  97.877  -78.961  45.536  1
100054  97.884  -78.966  45.523  1
100055  97.891  -78.971  45.509  1
100056  97.898  -78.977  45.494  1
100057  97.903  -78.987  45.480  1
100058  97.919  -78.994  45.466  1
100059  97.936  -79.001  45.452  1
100060  97.952  -79.008  45.438  1
100061  97.968  -79.015  45.423  1
100062  97.985  -79.021  45.408  1
100063  98.002  -79.028  45.394  1
100064  98.018  -79.035  45.381  1
100065  98.034  -79.042  45.368  1
100066  98.051  -79.043  45.356  1
100067  98.066  -79.032  45.342  1
100068  98.073  -79.034  45.329  1
100069  98.079  -79.040  45.317  1
100070  98.093  -79.046  45.306  1
100071  98.134  -79.071  45.295  1
100072  98.173  -79.093  45.285  1
100073  98.199  -79.103  45.274  1
100074  98.225  -79.110  45.265  1
100075  98.256  -79.114  45.256  1
100076  98.286  -79.118  45.246  1
100077  98.316  -79.122  45.238  1
100078  98.347  -79.127  45.229  1
100079  98.377  -79.131  45.220  1
100080  98.407  -79.135  45.210  1
100081  98.440  -79.143  45.201  1
100082  98.474  -79.152  45.192  1
100083  98.508  -79.160  45.183  1
100084  98.543  -79.169  45.176  1
100085  98.576  -79.178  45.167  1
100086  98.610  -79.187  45.157  1
100087  98.645  -79.196  45.147  1
100088  98.678  -79.204  45.135  1
100089  98.713  -79.213  45.123  1
100090  98.746  -79.222  45.112  1
100091  98.781  -79.231  45.100  1
100092  98.815  -79.240  45.090  1
100093  98.849  -79.249  45.080  1
100094  98.886  -79.261  45.069  1
100095  98.908  -79.275  45.060  1
100096  98.934  -79.287  45.052  1
100097  98.954  -79.299  45.044  1
100098  98.975  -79.311  45.037  1
100099  98.995  -79.323  45.030  1
100100  99.015  -79.335  45.022  1
100101  99.034  -79.347  45.015  1
100102  99.055  -79.360  45.007  1
100103  99.071  -79.375  44.998  1
100104  99.083  -79.380  44.990  1
100105  99.100  -79.397  44.981  1
100106  99.118  -79.414  44.970  1
100107  99.130  -79.422  44.959  1
100108  99.139  -79.428  44.949  1
100109  99.149  -79.433  44.936  1
100110  99.159  -79.439  44.924  1
100111  99.171  -79.448  44.912  1
100112  99.186  -79.463  44.900  1
100113  99.201  -79.477  44.890  1
100114  99.223  -79.485  44.880  1
100115  99.244  -79.494  44.870  1
100116  99.266  -79.503  44.861  1
100117  99.288  -79.511  44.852  1
100118  99.309  -79.520  44.845  1
100119  99.331  -79.528  44.836  1
100120  99.353  -79.536  44.828  1
100121  99.375  -79.545  44.820  1
100122  99.397  -79.553  44.812  1
100123  99.418  -79.562  44.804  1
100124  99.440  -79.570  44.797  1
100125  99.457  -79.568  44.791  1
100126  99.472  -79.563  44.784  1
100127  99.488  -79.557  44.778  1
100128  99.512  -79.557  44.772  1
100129  99.542  -79.560  44.767  1
100130  99.572  -79.564  44.761  1
100131  99.602  -79.567  44.756  1
100132  99.632  -79.570  44.750  1
100133  99.662  -79.573  44.745  1
100134  99.692  -79.577  44.741  1
100135  99.722  -79.580  44.737  1
100136  99.752  -79.583  44.732  1
100137  99.782  -79.586  44.728  1
100138  99.812  -79.589  44.724  1
100139  99.842  -79.593  44.719  1
100140  99.880  -79.626  44.713  1
100141  99.907  -79.655  44.708  1
100142  99.925  -79.680  44.703  1
100143  99.942  -79.705  44.696  1
100144  99.958  -79.731  44.690  1
100145  99.932  -79.773  44.684  1
100146  99.981  -79.834  44.678  1
100147  100.057  -79.861  44.672  1
100148  100.081  -79.883  44.666  1
100149  100.105  -79.907  44.659  1
100150  100.129  -79.930  44.652  1
100151  100.153  -79.953  44.646  1
100152  100.180  -79.978  44.640  1
100153  100.214  -80.007  44.633  1
100154  100.260  -80.026  44.624  1
100155  100.299  -80.062  44.616  1
100156  100.335  -80.095  44.608  1
100157  100.370  -80.123  44.598  1
100158  100.405  -80.150  44.586  1
100159  100.439  -80.178  44.573  1
100160  100.474  -80.206  44.560  1
100161  100.508  -80.233  44.547  1
100162  100.543  -80.261  44.532  1
100163  100.577  -80.288  44.516  1
100164  100.579  -80.331  44.500  1
100165  100.575  -80.375  44.483  1
100166  100.572  -80.420  44.465  1
100167  100.579  -80.461  44.447  1
100168  100.605  -80.496  44.428  1
100169  100.630  -80.531  44.410  1
100170  100.654  -80.566  44.392  1
100171  100.680  -80.600  44.374  1
100172  100.705  -80.635  44.354  1
100173  100.730  -80.670  44.333  1
100174  100.770  -80.689  44.311  1
100175  100.817  -80.702  44.291  1
100176  100.863  -80.715  44.271  1
100177  100.910  -80.728  44.251  1
100178  100.956  -80.741  44.233  1
100179  101.002  -80.754  44.215  1
100180  101.049  -80.767  44.198  1
100181  101.096  -80.779  44.181  1
100182  101.142  -80.792  44.164  1
100183  101.189  -80.805  44.148  1
100184  101.235  -80.818  44.133  1
100185  101.281  -80.831  44.117  1
100186  101.328  -80.844  44.101  1
100187  101.375  -80.857  44.086  1
100188  101.421  -80.870  44.071  1
100189  101.467  -80.883  44.057  1
100190  101.514  -80.895  44.042  1
100191  101.548  -80.911  44.027  1
100448  93.495  -78.537  53.841  1
100449  93.504  -78.534  53.828  1
100450  93.514  -78.532  53.813  1
100451  93.524  -78.529  53.797  1
100452  93.534  -78.527  53.779  1
100453  93.543  -78.524  53.761  1
100454  93.553  -78.522  53.742  1
100455  93.563  -78.520  53.723  1
100456  93.564  -78.512  53.703  1
100457  93.563  -78.503  53.683  1
100458  93.561  -78.494  53.663  1
100459  93.560  -78.484  53.640  1
100460  93.561  -78.474  53.618  1
100461  93.571  -78.459  53.596  1
100462  93.588  -78.443  53.576  1
100463  93.611  -78.429  53.554  1
100464  93.633  -78.413  53.533  1
100465  93.652  -78.401  53.514  1
100466  93.663  -78.392  53.492  1
100467  93.675  -78.384  53.472  1
100479  93.857  -78.295  53.242  1
100480  93.872  -78.288  53.222  1
100481  93.888  -78.280  53.202  1
100482  93.903  -78.272  53.184  1
100483  93.918  -78.266  53.165  1
100484  93.934  -78.258  53.146  1
100485  93.949  -78.250  53.129  1
100486  93.963  -78.246  53.114  1
100487  93.966  -78.248  53.100  1
100488  93.969  -78.259  53.088  1
100489  93.973  -78.269  53.078  1
100490  93.976  -78.279  53.074  1
100491  93.980  -78.290  53.067  1
100492  93.983  -78.300  53.058  1
100493  93.990  -78.305  53.047  1
100494  93.997  -78.310  53.033  1
100495  94.005  -78.313  53.021  1
100496  94.012  -78.318  53.009  1
100497  94.020  -78.322  52.997  1
100498  94.028  -78.326  52.982  1
100499  94.035  -78.330  52.965  1
100500  94.043  -78.335  52.948  1
100501  94.050  -78.338  52.932  1
100502  94.058  -78.343  52.915  1
100503  94.065  -78.349  52.897  1
100504  94.071  -78.357  52.878  1
100505  94.078  -78.363  52.861  1
100506  94.084  -78.371  52.847  1
100507  94.091  -78.378  52.837  1
100508  94.098  -78.385  52.825  1
100509  94.104  -78.392  52.813  1
100510  94.111  -78.400  52.801  1
100511  94.117  -78.407  52.789  1
100512  94.123  -78.415  52.777  1
100513  94.128  -78.423  52.764  1
100514  94.132  -78.430  52.751  1
100515  94.135  -78.412  52.737  1
100516  94.137  -78.391  52.721  1
100517  94.140  -78.369  52.703  1
100518  94.142  -78.347  52.683  1
100519  94.145  -78.326  52.660  1
100520  94.163  -78.312  52.636  1
100521  94.183  -78.309  52.610  1
100522  94.204  -78.311  52.582  1
100523  94.225  -78.313  52.555  1
100524  94.247  -78.315  52.527  1
100525  94.267  -78.317  52.498  1
100526  94.288  -78.319  52.468  1
100527  94.299  -78.334  52.436  1
100528  94.308  -78.351  52.404  1
100529  94.318  -78.365  52.369  1
100530  94.339  -78.357  52.333  1
100531  94.360  -78.348  52.295  1
100532  94.381  -78.340  52.255  1
100533  94.402  -78.332  52.212  1
100534  94.423  -78.323  52.168  1
100535  94.457  -78.332  52.122  1
100536  94.494  -78.346  52.074  1
100537  94.532  -78.360  52.026  1
100538  94.569  -78.373  51.979  1
100539  94.593  -78.357  51.935  1
100540  94.618  -78.340  51.892  1
100541  94.637  -78.327  51.849  1
100542  94.648  -78.321  51.805  1
100543  94.659  -78.316  51.761  1
100544  94.669  -78.310  51.715  1
100545  94.680  -78.304  51.668  1
100546  94.690  -78.297  51.623  1
100547  94.700  -78.292  51.579  1
100548  94.711  -78.286  51.536  1
100549  94.723  -78.285  51.496  1
100550  94.736  -78.282  51.454  1
100551  94.749  -78.279  51.415  1
100552  94.760  -78.276  51.377  1
100553  94.772  -78.273  51.340  1
100554  94.784  -78.277  51.306  1
100555  94.795  -78.282  51.273  1
100556  94.806  -78.286  51.240  1
100557  94.816  -78.291  51.202  1
100558  94.826  -78.296  51.162  1
100559  94.836  -78.300  51.121  1
100560  94.854  -78.302  51.079  1
100561  94.875  -78.302  51.035  1
100562  94.895  -78.302  50.991  1
100563  94.916  -78.302  50.946  1
100564  94.936  -78.289  50.902  1
100565  94.957  -78.268  50.859  1
100566  94.978  -78.247  50.815  1
100567  94.999  -78.225  50.772  1
100568  95.009  -78.220  50.729  1
100569  95.018  -78.216  50.686  1
100570  95.027  -78.213  50.643  1
100571  95.035  -78.209  50.602  1
100572  95.056  -78.151  50.561  1
100573  95.099  -78.143  50.521  1
100574  95.142  -78.137  50.483  1
100575  95.186  -78.131  50.444  1
100576  95.230  -78.125  50.406  1
100577  95.244  -78.121  50.368  1
100578  95.253  -78.116  50.332  1
100579  95.263  -78.112  50.295  1
100580  95.272  -78.108  50.258  1
100581  95.281  -78.103  50.222  1
100582  95.290  -78.100  50.187  1
100583  95.300  -78.095  50.151  1
100584  95.309  -78.091  50.117  1
100585  95.318  -78.087  50.082  1
100586  95.327  -78.082  50.048  1
100587  95.335  -78.082  50.014  1
100588  95.346  -78.087  49.981  1
100589  95.356  -78.091  49.949  1
100590  95.366  -78.094  49.917  1
100591  95.377  -78.099  49.885  1
100592  95.387  -78.103  49.853  1
100593  95.397  -78.106  49.822  1
100594  95.407  -78.111  49.792  1
100595  95.417  -78.115  49.762  1
100596  95.427  -78.119  49.735  1
100597  95.438  -78.123  49.706  1
100598  95.448  -78.127  49.678  1
100599  95.456  -78.131  49.650  1
100600  95.462  -78.135  49.624  1
100601  95.468  -78.139  49.599  1
100602  95.473  -78.143  49.574  1
100603  95.478  -78.144  49.550  1
100604  95.482  -78.140  49.525  1
100605  95.490  -78.144  49.500  1
100606  95.498  -78.149  49.472  1
100607  95.506  -78.154  49.443  1
100608  95.514  -78.159  49.413  1
100609  95.523  -78.165  49.380  1
100610  95.532  -78.172  49.345  1
100611  95.541  -78.179  49.309  1
100612  95.550  -78.186  49.272  1
100613  95.559  -78.194  49.234  1
100614  95.568  -78.200  49.193  1
100615  95.578  -78.207  49.151  1
100616  95.587  -78.215  49.109  1
100617  95.596  -78.222  49.067  1
100618  95.605  -78.228  49.024  1
100619  95.615  -78.236  48.981  1
100620  95.619  -78.239  48.938  1
100621  95.615  -78.236  48.897  1
100622  95.615  -78.235  48.856  1
100623  95.629  -78.244  48.817  1
100624  95.644  -78.252  48.779  1
100625  95.659  -78.260  48.741  1
100626  95.678  -78.274  48.702  1
100627  95.697  -78.288  48.663  1
100628  95.714  -78.294  48.621  1
100629  95.729  -78.291  48.579  1
100630  95.725  -78.290  48.535  1
100631  95.733  -78.290  48.492  1
100632  95.747  -78.276  48.450  1
100633  95.764  -78.255  48.408  1
100634  95.781  -78.251  48.366  1
100635  95.799  -78.258  48.326  1
100636  95.817  -78.266  48.285  1
100637  95.835  -78.275  48.244  1
100638  95.853  -78.282  48.206  1
100639  95.872  -78.291  48.168  1
100640  95.888  -78.293  48.130  1
100641  95.904  -78.296  48.091  1
100642  95.920  -78.300  48.054  1
100643  95.937  -78.304  48.017  1
100644  95.956  -78.307  47.979  1
100645  95.972  -78.309  47.942  1
100646  95.988  -78.312  47.905  1
100647  96.004  -78.314  47.869  1
100648  96.017  -78.329  47.832  1
100649  96.030  -78.346  47.795  1
100650  96.043  -78.363  47.759  1
100651  96.056  -78.379  47.722  1
100652  96.071  -78.391  47.689  1
100653  96.085  -78.403  47.656  1
100654  96.099  -78.415  47.624  1
100655  96.110  -78.420  47.592  1
100656  96.120  -78.426  47.559  1
100657  96.119  -78.441  47.527  1
100658  96.133  -78.447  47.497  1
100659  96.150  -78.451  47.466  1
100660  96.167  -78.456  47.437  1
100661  96.183  -78.460  47.409  1
100662  96.199  -78.464  47.381  1
100663  96.216  -78.469  47.353  1
100664  96.238  -78.474  47.325  1
100665  96.267  -78.478  47.296  1
100666  96.296  -78.482  47.266  1
100667  96.325  -78.485  47.238  1
100668  96.355  -78.489  47.211  1
100669  96.383  -78.493  47.184  1
100670  96.414  -78.498  47.157  1
100671  96.449  -78.501  47.128  1
100672  96.464  -78.501  47.099  1
100673  96.485  -78.502  47.072  1
100674  96.512  -78.506  47.045  1
100675  96.538  -78.509  47.017  1
100676  96.564  -78.512  46.989  1
100677  96.590  -78.515  46.961  1
100678  96.616  -78.518  46.934  1
100679  96.642  -78.521  46.906  1
100680  96.660  -78.527  46.880  1
100681  96.663  -78.538  46.856  1
100682  96.666  -78.549  46.833  1
100683  96.677  -78.565  46.808  1
100684  96.689  -78.579  46.781  1
100685  96.695  -78.589  46.755  1
100686  96.702  -78.598  46.731  1
100687  96.716  -78.604  46.708  1
100688  96.725  -78.616  46.686  1
100689  96.731  -78.633  46.664  1
100690  96.740  -78.650  46.642  1
100691  96.759  -78.673  46.620  1
100692  96.779  -78.696  46.600  1
100693  96.798  -78.720  46.580  1
100694  96.817  -78.742  46.561  1
100695  96.836  -78.766  46.541  1
100696  96.856  -78.789  46.521  1
100697  96.875  -78.812  46.503  1
100698  96.895  -78.836  46.483  1
100699  96.914  -78.859  46.463  1
100700  96.934  -78.882  46.444  1
100701  96.953  -78.905  46.426  1
100702  96.974  -78.919  46.409  1
100703  96.999  -78.921  46.391  1
100704  97.028  -78.930  46.372  1
100705  97.058  -78.941  46.354  1
100706  97.088  -78.952  46.336  1
100707  97.117  -78.962  46.320  1
100708  97.147  -78.973  46.303  1
100709  97.181  -78.973  46.287  1
100710  97.216  -78.969  46.270  1
100711  97.250  -78.966  46.252  1
100712  97.285  -78.962  46.235  1
100713  97.319  -78.959  46.218  1
100714  97.354  -78.956  46.200  1
100715  97.389  -78.952  46.182  1
100716  97.423  -78.949  46.163  1
100717  97.459  -78.953  46.143  1
100718  97.483  -78.957  46.122  1
100719  97.498  -78.956  46.102  1
100720  97.509  -78.952  46.081  1
100721  97.517  -78.946  46.061  1
100722  97.525  -78.940  46.043  1
100723  97.534  -78.934  46.026  1
100724  97.542  -78.928  46.009  1
100725  97.550  -78.922  45.989  1
100726  97.558  -78.917  45.971  1
100727  97.574  -78.913  45.952  1
100728  97.592  -78.909  45.933  1
100729  97.610  -78.906  45.916  1
100730  97.628  -78.902  45.899  1
100731  97.646  -78.899  45.882  1
100732  97.663  -78.896  45.865  1
100733  97.681  -78.893  45.849  1
100734  97.699  -78.889  45.832  1
100735  97.715  -78.886  45.817  1
100736  97.728  -78.883  45.801  1
100737  97.741  -78.881  45.786  1
100738  97.754  -78.879  45.770  1
100739  97.768  -78.877  45.755  1
100740  97.781  -78.874  45.740  1
100741  97.794  -78.872  45.727  1
100742  97.801  -78.876  45.713  1
100743  97.809  -78.881  45.698  1
100744  97.816  -78.886  45.683  1
100745  97.823  -78.891  45.667  1
100746  97.830  -78.896  45.651  1
100747  97.838  -78.902  45.636  1
100748  97.845  -78.906  45.623  1
100749  97.852  -78.912  45.611  1
100750  97.860  -78.917  45.603  1
100751  97.867  -78.922  45.594  1
100752  97.874  -78.927  45.584  1
100753  97.881  -78.932  45.570  1
100754  97.889  -78.937  45.556  1
100755  97.896  -78.943  45.540  1
100756  97.903  -78.947  45.525  1
100757  97.911  -78.952  45.512  1
100758  97.918  -78.959  45.498  1
100759  97.935  -78.966  45.482  1
100760  97.951  -78.973  45.466  1
100761  97.968  -78.980  45.449  1
100762  97.984  -78.987  45.432  1
100763  98.001  -78.993  45.417  1
100764  98.017  -79.000  45.402  1
100765  98.034  -79.007  45.388  1
100766  98.050  -79.014  45.374  1
100767  98.067  -79.021  45.362  1
100768  98.082  -79.020  45.348  1
100769  98.091  -79.021  45.335  1
100770  98.108  -79.035  45.322  1
100771  98.136  -79.056  45.311  1
100772  98.159  -79.075  45.300  1
100773  98.179  -79.090  45.290  1
100774  98.207  -79.091  45.279  1
100775  98.237  -79.096  45.269  1
100776  98.267  -79.100  45.259  1
100777  98.297  -79.104  45.249  1
100778  98.327  -79.109  45.240  1
100779  98.358  -79.112  45.231  1
100780  98.388  -79.117  45.221  1
100781  98.419  -79.121  45.211  1
100782  98.452  -79.130  45.201  1
100783  98.487  -79.138  45.192  1
100784  98.520  -79.147  45.184  1
100785  98.555  -79.156  45.176  1
100786  98.589  -79.165  45.167  1
100787  98.623  -79.174  45.158  1
100788  98.657  -79.182  45.150  1
100789  98.691  -79.191  45.137  1
100790  98.725  -79.200  45.126  1
100791  98.759  -79.209  45.116  1
100792  98.793  -79.218  45.104  1
100793  98.827  -79.226  45.094  1
100794  98.861  -79.235  45.083  1
100795  98.888  -79.242  45.071  1
100796  98.906  -79.247  45.060  1
100797  98.923  -79.256  45.050  1
100798  98.943  -79.268  45.041  1
100799  98.963  -79.280  45.035  1
100800  98.983  -79.292  45.028  1
100801  99.003  -79.304  45.021  1
100802  99.023  -79.316  45.014  1
100803  99.043  -79.328  45.004  1
100804  99.052  -79.337  44.995  1
100805  99.065  -79.344  44.985  1
100806  99.083  -79.361  44.976  1
100807  99.100  -79.379  44.965  1
100808  99.118  -79.396  44.954  1
100809  99.135  -79.411  44.944  1
100810  99.144  -79.417  44.932  1
100811  99.154  -79.422  44.921  1
100812  99.166  -79.432  44.910  1
100813  99.181  -79.447  44.898  1
100814  99.202  -79.455  44.887  1
100815  99.224  -79.463  44.877  1
100816  99.245  -79.473  44.867  1
100817  99.267  -79.481  44.858  1
100818  99.289  -79.489  44.850  1
100819  99.310  -79.498  44.842  1
100820  99.332  -79.506  44.834  1
100821  99.354  -79.514  44.827  1
100822  99.375  -79.523  44.819  1
100823  99.398  -79.532  44.812  1
100824  99.419  -79.540  44.805  1
100825  99.441  -79.548  44.799  1
100826  99.463  -79.557  44.792  1
100827  99.478  -79.552  44.785  1
100828  99.497  -79.548  44.780  1
100829  99.526  -79.551  44.775  1
100830  99.557  -79.554  44.771  1
100831  99.586  -79.558  44.765  1
100832  99.617  -79.561  44.760  1
100833  99.646  -79.564  44.756  1
100834  99.677  -79.567  44.751  1
100835  99.706  -79.571  44.746  1
100836  99.736  -79.574  44.743  1
100837  99.766  -79.577  44.739  1
100838  99.796  -79.580  44.734  1
100839  99.826  -79.584  44.729  1
100840  99.856  -79.587  44.725  1
100841  99.886  -79.590  44.721  1
100842  99.924  -79.621  44.715  1
100843  99.956  -79.653  44.709  1
100844  99.974  -79.678  44.702  1
100845  99.967  -79.734  44.696  1
100846  99.971  -79.829  44.690  1
100847  99.989  -79.848  44.684  1
100848  100.025  -79.867  44.678  1
100849  100.062  -79.886  44.673  1
100850  100.099  -79.905  44.666  1
100851  100.135  -79.924  44.659  1
100852  100.171  -79.944  44.655  1
100853  100.208  -79.963  44.649  1
100854  100.240  -79.986  44.644  1
100855  100.274  -80.012  44.635  1
100856  100.309  -80.040  44.626  1
100857  100.344  -80.068  44.617  1
100858  100.379  -80.095  44.608  1
100859  100.413  -80.123  44.594  1
100860  100.447  -80.150  44.581  1
100861  100.482  -80.178  44.567  1
100862  100.516  -80.206  44.554  1
100863  100.551  -80.233  44.538  1
100864  100.586  -80.261  44.523  1
100865  100.592  -80.301  44.507  1
100866  100.587  -80.346  44.491  1
100867  100.584  -80.391  44.474  1
100868  100.597  -80.430  44.455  1
100869  100.622  -80.465  44.437  1
100870  100.647  -80.500  44.419  1
100871  100.672  -80.534  44.402  1
100872  100.697  -80.569  44.385  1
100873  100.722  -80.604  44.364  1
100874  100.749  -80.639  44.344  1
100875  100.777  -80.676  44.323  1
100876  100.821  -80.692  44.305  1
100877  100.867  -80.705  44.285  1
100878  100.914  -80.718  44.265  1
100879  100.960  -80.731  44.245  1
100880  101.007  -80.744  44.225  1
100881  101.053  -80.757  44.206  1
100882  101.100  -80.770  44.189  1
100883  101.146  -80.782  44.172  1
100884  101.193  -80.795  44.156  1
100885  101.239  -80.808  44.140  1
100886  101.285  -80.821  44.124  1
100887  101.332  -80.834  44.108  1
100888  101.379  -80.847  44.092  1
100889  101.425  -80.860  44.077  1
100890  101.471  -80.873  44.062  1
100891  101.504  -80.889  44.047  1
100892  101.537  -80.905  44.032  1
101149  93.495  -78.526  53.844  1
101150  93.505  -78.523  53.830  1
101151  93.514  -78.521  53.815  1
101152  93.524  -78.518  53.799  1
101153  93.534  -78.516  53.780  1
101154  93.544  -78.514  53.762  1
101155  93.553  -78.511  53.743  1
101156  93.562  -78.508  53.723  1
101157  93.561  -78.499  53.703  1
101158  93.559  -78.489  53.683  1
101159  93.558  -78.480  53.663  1
101160  93.557  -78.471  53.639  1
101161  93.562  -78.458  53.615  1
101162  93.572  -78.443  53.593  1
101163  93.594  -78.428  53.571  1
101164  93.616  -78.413  53.549  1
101165  93.639  -78.398  53.528  1
101166  93.653  -78.388  53.508  1
101167  93.665  -78.379  53.486  1
101168  93.677  -78.371  53.465  1
101180  93.859  -78.282  53.234  1
101181  93.874  -78.275  53.214  1
101182  93.890  -78.267  53.194  1
101183  93.905  -78.260  53.175  1
101184  93.920  -78.253  53.157  1
101185  93.936  -78.245  53.138  1
101186  93.951  -78.239  53.120  1
101187  93.963  -78.235  53.104  1
101188  93.965  -78.235  53.090  1
101189  93.969  -78.245  53.077  1
101190  93.972  -78.256  53.067  1
101191  93.976  -78.266  53.063  1
101192  93.979  -78.276  53.056  1
101193  93.982  -78.287  53.047  1
101194  93.986  -78.297  53.036  1
101195  93.989  -78.307  53.022  1
101196  93.993  -78.317  53.010  1
101197  94.000  -78.322  52.997  1
101198  94.007  -78.326  52.983  1
101199  94.015  -78.330  52.967  1
101200  94.023  -78.335  52.950  1
101201  94.030  -78.338  52.932  1
101202  94.038  -78.343  52.915  1
101203  94.045  -78.347  52.897  1
101204  94.053  -78.351  52.878  1
101205  94.060  -78.358  52.860  1
101206  94.066  -78.366  52.844  1
101207  94.073  -78.373  52.830  1
101208  94.079  -78.380  52.819  1
101209  94.086  -78.387  52.805  1
101210  94.092  -78.395  52.792  1
101211  94.099  -78.401  52.779  1
101212  94.106  -78.409  52.767  1
101213  94.112  -78.416  52.755  1
101214  94.119  -78.423  52.743  1
101215  94.130  -78.420  52.728  1
101216  94.130  -78.400  52.712  1
101217  94.133  -78.378  52.694  1
101218  94.135  -78.357  52.675  1
101219  94.137  -78.335  52.655  1
101220  94.140  -78.313  52.632  1
101221  94.154  -78.297  52.607  1
101222  94.174  -78.296  52.581  1
101223  94.195  -78.298  52.553  1
101224  94.216  -78.300  52.525  1
101225  94.238  -78.302  52.498  1
101226  94.258  -78.304  52.469  1
101227  94.279  -78.307  52.439  1
101228  94.295  -78.315  52.408  1
101229  94.303  -78.332  52.374  1
101230  94.318  -78.338  52.339  1
101231  94.339  -78.329  52.300  1
101232  94.360  -78.321  52.259  1
101233  94.381  -78.313  52.217  1
101234  94.402  -78.304  52.173  1
101235  94.423  -78.296  52.128  1
101236  94.452  -78.298  52.082  1
101237  94.489  -78.312  52.035  1
101238  94.527  -78.326  51.990  1
101239  94.564  -78.340  51.946  1
101240  94.598  -78.345  51.903  1
101241  94.622  -78.329  51.860  1
101242  94.642  -78.315  51.815  1
101243  94.653  -78.310  51.770  1
101244  94.664  -78.304  51.725  1
101245  94.674  -78.297  51.679  1
101246  94.685  -78.292  51.635  1
101247  94.695  -78.286  51.591  1
101248  94.706  -78.280  51.549  1
101249  94.714  -78.272  51.508  1
101250  94.723  -78.267  51.469  1
101251  94.735  -78.264  51.428  1
101252  94.746  -78.262  51.389  1
101253  94.758  -78.259  51.352  1
101254  94.770  -78.257  51.315  1
101255  94.781  -78.260  51.280  1
101256  94.793  -78.264  51.245  1
101257  94.806  -78.269  51.211  1
101258  94.818  -78.274  51.174  1
101259  94.830  -78.279  51.135  1
101260  94.840  -78.284  51.096  1
101261  94.850  -78.288  51.056  1
101262  94.864  -78.291  51.015  1
101263  94.885  -78.292  50.973  1
101264  94.905  -78.292  50.930  1
101265  94.926  -78.273  50.888  1
101266  94.947  -78.253  50.846  1
101267  94.968  -78.232  50.804  1
101268  94.988  -78.210  50.761  1
101269  95.010  -78.189  50.719  1
101270  95.022  -78.180  50.678  1
101271  95.030  -78.176  50.637  1
101272  95.044  -78.149  50.596  1
101273  95.085  -78.134  50.556  1
101274  95.128  -78.128  50.518  1
101275  95.171  -78.122  50.480  1
101276  95.215  -78.116  50.442  1
101277  95.258  -78.111  50.404  1
101278  95.275  -78.106  50.366  1
101279  95.284  -78.102  50.330  1
101280  95.294  -78.097  50.294  1
101281  95.303  -78.094  50.258  1
101282  95.312  -78.089  50.222  1
101283  95.321  -78.084  50.187  1
101284  95.328  -78.083  50.153  1
101285  95.334  -78.081  50.118  1
101286  95.341  -78.080  50.085  1
101287  95.347  -78.078  50.053  1
101288  95.353  -78.078  50.020  1
101289  95.362  -78.079  49.987  1
101290  95.373  -78.083  49.956  1
101291  95.383  -78.087  49.925  1
101292  95.393  -78.091  49.894  1
101293  95.403  -78.095  49.864  1
101294  95.413  -78.100  49.834  1
101295  95.424  -78.103  49.805  1
101296  95.434  -78.108  49.776  1
101297  95.442  -78.112  49.748  1
101298  95.447  -78.116  49.721  1
101299  95.453  -78.119  49.695  1
101300  95.458  -78.124  49.668  1
101301  95.464  -78.128  49.643  1
101302  95.470  -78.131  49.618  1
101303  95.475  -78.136  49.592  1
101304  95.480  -78.133  49.568  1
101305  95.484  -78.128  49.543  1
101306  95.490  -78.129  49.517  1
101307  95.498  -78.134  49.489  1
101308  95.506  -78.138  49.460  1
101309  95.514  -78.143  49.429  1
101310  95.522  -78.148  49.397  1
101311  95.529  -78.153  49.361  1
101312  95.537  -78.157  49.324  1
101313  95.545  -78.163  49.286  1
101314  95.555  -78.169  49.246  1
101315  95.564  -78.177  49.204  1
101316  95.573  -78.184  49.162  1
101317  95.582  -78.191  49.119  1
101318  95.591  -78.198  49.076  1
101319  95.601  -78.205  49.033  1
101320  95.610  -78.213  48.989  1
101321  95.618  -78.219  48.945  1
101322  95.614  -78.216  48.903  1
101323  95.619  -78.218  48.861  1
101324  95.634  -78.226  48.822  1
101325  95.650  -78.236  48.783  1
101326  95.669  -78.250  48.746  1
101327  95.688  -78.263  48.709  1
101328  95.707  -78.278  48.672  1
101329  95.725  -78.285  48.630  1
101330  95.740  -78.282  48.587  1
101331  95.750  -78.279  48.544  1
101332  95.747  -78.274  48.501  1
101333  95.749  -78.248  48.459  1
101334  95.765  -78.225  48.417  1
101335  95.783  -78.231  48.375  1
101336  95.802  -78.239  48.336  1
101337  95.820  -78.247  48.296  1
101338  95.838  -78.255  48.256  1
101339  95.856  -78.263  48.218  1
101340  95.874  -78.271  48.181  1
101341  95.891  -78.275  48.143  1
101342  95.907  -78.279  48.103  1
101343  95.925  -78.282  48.065  1
101344  95.944  -78.285  48.028  1
101345  95.962  -78.288  47.991  1
101346  95.980  -78.291  47.954  1
101347  95.996  -78.294  47.917  1
101348  96.012  -78.297  47.880  1
101349  96.025  -78.313  47.844  1
101350  96.038  -78.331  47.807  1
101351  96.050  -78.347  47.771  1
101352  96.063  -78.365  47.734  1
101353  96.077  -78.380  47.702  1
101354  96.091  -78.392  47.669  1
101355  96.105  -78.404  47.637  1
101356  96.116  -78.410  47.606  1
101357  96.126  -78.416  47.574  1
101358  96.129  -78.428  47.543  1
101359  96.146  -78.432  47.512  1
101360  96.162  -78.436  47.482  1
101361  96.179  -78.441  47.452  1
101362  96.191  -78.447  47.423  1
101363  96.202  -78.454  47.396  1
101364  96.212  -78.462  47.369  1
101365  96.239  -78.467  47.342  1
101366  96.268  -78.470  47.314  1
101367  96.297  -78.474  47.285  1
101368  96.326  -78.478  47.257  1
101369  96.357  -78.482  47.229  1
101370  96.388  -78.486  47.201  1
101371  96.422  -78.491  47.173  1
101372  96.457  -78.495  47.145  1
101373  96.491  -78.498  47.117  1
101374  96.526  -78.502  47.088  1
101375  96.539  -78.501  47.061  1
101376  96.551  -78.500  47.034  1
101377  96.562  -78.499  47.006  1
101378  96.578  -78.499  46.979  1
101379  96.604  -78.502  46.952  1
101380  96.630  -78.505  46.924  1
101381  96.639  -78.514  46.899  1
101382  96.654  -78.532  46.875  1
101383  96.669  -78.550  46.851  1
101384  96.676  -78.559  46.825  1
101385  96.682  -78.569  46.800  1
101386  96.689  -78.578  46.774  1
101387  96.698  -78.586  46.749  1
101388  96.711  -78.592  46.726  1
101389  96.724  -78.598  46.703  1
101390  96.730  -78.615  46.681  1
101391  96.737  -78.633  46.661  1
101392  96.757  -78.664  46.640  1
101393  96.776  -78.695  46.619  1
101394  96.796  -78.720  46.598  1
101395  96.815  -78.742  46.580  1
101396  96.834  -78.766  46.560  1
101397  96.854  -78.789  46.541  1
101398  96.873  -78.812  46.522  1
101399  96.892  -78.836  46.502  1
101400  96.912  -78.859  46.482  1
101401  96.931  -78.882  46.463  1
101402  96.950  -78.905  46.445  1
101403  96.970  -78.927  46.427  1
101404  96.995  -78.930  46.407  1
101405  97.021  -78.934  46.386  1
101406  97.050  -78.945  46.368  1
101407  97.080  -78.955  46.351  1
101408  97.110  -78.965  46.333  1
101409  97.141  -78.974  46.318  1
101410  97.175  -78.970  46.301  1
101411  97.210  -78.967  46.284  1
101412  97.245  -78.963  46.266  1
101413  97.279  -78.960  46.249  1
101414  97.314  -78.957  46.231  1
101415  97.349  -78.953  46.213  1
101416  97.383  -78.950  46.195  1
101417  97.418  -78.947  46.177  1
101418  97.453  -78.943  46.157  1
101419  97.489  -78.950  46.136  1
101420  97.504  -78.949  46.115  1
101421  97.517  -78.946  46.093  1
101422  97.525  -78.941  46.073  1
101423  97.533  -78.935  46.053  1
101424  97.541  -78.929  46.036  1
101425  97.549  -78.923  46.018  1
101426  97.558  -78.917  46.000  1
101427  97.575  -78.914  45.982  1
101428  97.592  -78.910  45.964  1
101429  97.610  -78.907  45.946  1
101430  97.628  -78.903  45.928  1
101431  97.646  -78.900  45.910  1
101432  97.664  -78.896  45.893  1
101433  97.682  -78.893  45.876  1
101434  97.700  -78.890  45.858  1
101435  97.717  -78.886  45.842  1
101436  97.733  -78.883  45.826  1
101437  97.746  -78.881  45.810  1
101438  97.759  -78.879  45.795  1
101439  97.773  -78.877  45.779  1
101440  97.786  -78.874  45.764  1
101441  97.799  -78.871  45.749  1
101442  97.801  -78.849  45.735  1
101443  97.802  -78.864  45.721  1
101444  97.809  -78.872  45.708  1
101445  97.816  -78.877  45.692  1
101446  97.823  -78.882  45.677  1
101447  97.831  -78.886  45.662  1
101448  97.839  -78.892  45.648  1
101449  97.846  -78.896  45.636  1
101450  97.854  -78.902  45.626  1
101451  97.861  -78.906  45.618  1
101452  97.868  -78.911  45.609  1
101453  97.876  -78.916  45.599  1
101454  97.883  -78.921  45.586  1
101455  97.891  -78.926  45.572  1
101456  97.898  -78.930  45.557  1
101457  97.906  -78.936  45.541  1
101458  97.919  -78.942  45.529  1
101459  97.948  -78.950  45.515  1
101460  97.966  -78.957  45.498  1
101461  97.982  -78.962  45.479  1
101462  97.997  -78.968  45.460  1
101463  98.012  -78.973  45.442  1
101464  98.028  -78.979  45.425  1
101465  98.043  -78.984  45.409  1
101466  98.059  -78.990  45.395  1
101467  98.074  -78.995  45.381  1
101468  98.089  -79.000  45.369  1
101469  98.103  -79.007  45.355  1
101470  98.120  -79.024  45.341  1
101471  98.140  -79.043  45.327  1
101472  98.160  -79.062  45.316  1
101473  98.180  -79.082  45.305  1
101474  98.199  -79.084  45.295  1
101475  98.218  -79.077  45.286  1
101476  98.248  -79.081  45.274  1
101477  98.278  -79.085  45.264  1
101478  98.308  -79.090  45.253  1
101479  98.339  -79.094  45.243  1
101480  98.369  -79.098  45.233  1
101481  98.400  -79.103  45.223  1
101482  98.431  -79.108  45.213  1
101483  98.464  -79.116  45.203  1
101484  98.499  -79.125  45.193  1
101485  98.533  -79.134  45.183  1
101486  98.567  -79.143  45.173  1
101487  98.601  -79.152  45.164  1
101488  98.635  -79.160  45.154  1
101489  98.669  -79.169  45.145  1
101490  98.703  -79.178  45.135  1
101491  98.737  -79.187  45.125  1
101492  98.771  -79.195  45.115  1
101493  98.805  -79.204  45.104  1
101494  98.839  -79.213  45.093  1
101495  98.863  -79.219  45.082  1
101496  98.887  -79.226  45.070  1
101497  98.907  -79.231  45.059  1
101498  98.921  -79.235  45.049  1
101499  98.934  -79.240  45.040  1
101500  98.951  -79.248  45.034  1
101501  98.972  -79.261  45.027  1
101502  98.991  -79.273  45.019  1
101503  99.011  -79.285  45.011  1
101504  99.031  -79.301  45.000  1
101505  99.033  -79.300  44.991  1
101506  99.047  -79.308  44.981  1
101507  99.065  -79.325  44.972  1
101508  99.082  -79.343  44.961  1
101509  99.100  -79.360  44.949  1
101510  99.118  -79.378  44.938  1
101511  99.136  -79.394  44.927  1
101512  99.149  -79.406  44.916  1
101513  99.161  -79.416  44.906  1
101514  99.182  -79.425  44.895  1
101515  99.203  -79.433  44.884  1
101516  99.225  -79.442  44.874  1
101517  99.246  -79.451  44.864  1
101518  99.268  -79.459  44.855  1
101519  99.290  -79.467  44.848  1
101520  99.311  -79.476  44.841  1
101521  99.333  -79.484  44.833  1
101522  99.355  -79.492  44.827  1
101523  99.376  -79.501  44.820  1
101524  99.398  -79.510  44.813  1
101525  99.420  -79.518  44.806  1
101526  99.442  -79.526  44.801  1
101527  99.464  -79.535  44.795  1
101528  99.484  -79.541  44.789  1
101529  99.511  -79.542  44.784  1
101530  99.541  -79.545  44.779  1
101531  99.571  -79.548  44.775  1
101532  99.600  -79.552  44.770  1
101533  99.631  -79.555  44.766  1
101534  99.660  -79.558  44.763  1
101535  99.691  -79.561  44.758  1
101536  99.720  -79.565  44.753  1
101537  99.751  -79.568  44.749  1
101538  99.780  -79.571  44.745  1
101539  99.810  -79.574  44.742  1
101540  99.840  -79.578  44.737  1
101541  99.870  -79.581  44.733  1
101542  99.900  -79.584  44.728  1
101543  99.930  -79.587  44.723  1
101544  99.968  -79.617  44.717  1
101545  100.027  -79.673  44.710  1
101546  99.978  -79.760  44.703  1
101547  99.988  -79.771  44.697  1
101548  100.032  -79.810  44.691  1
101549  100.068  -79.830  44.684  1
101550  100.105  -79.849  44.679  1
101551  100.142  -79.867  44.673  1
101552  100.174  -79.889  44.667  1
101553  100.199  -79.917  44.663  1
101554  100.224  -79.943  44.659  1
101555  100.248  -79.975  44.654  1
101556  100.283  -79.986  44.645  1
101557  100.317  -80.012  44.636  1
101558  100.352  -80.040  44.626  1
101559  100.387  -80.068  44.616  1
101560  100.421  -80.095  44.602  1
101561  100.456  -80.122  44.588  1
101562  100.490  -80.150  44.574  1
101563  100.525  -80.178  44.559  1
101564  100.559  -80.206  44.543  1
101565  100.594  -80.233  44.528  1
101566  100.604  -80.272  44.513  1
101567  100.600  -80.317  44.497  1
101568  100.596  -80.362  44.480  1
101569  100.614  -80.399  44.463  1
101570  100.639  -80.434  44.445  1
101571  100.665  -80.468  44.427  1
101572  100.689  -80.503  44.408  1
101573  100.714  -80.538  44.391  1
101574  100.741  -80.573  44.372  1
101575  100.769  -80.609  44.353  1
101576  100.797  -80.646  44.335  1
101577  100.826  -80.682  44.318  1
101578  100.872  -80.696  44.299  1
101579  100.918  -80.709  44.279  1
101580  100.965  -80.722  44.258  1
101581  101.011  -80.735  44.237  1
101582  101.057  -80.748  44.217  1
101583  101.104  -80.761  44.198  1
101584  101.150  -80.773  44.180  1
101585  101.197  -80.786  44.163  1
101586  101.243  -80.799  44.147  1
101587  101.290  -80.812  44.130  1
101588  101.336  -80.825  44.114  1
101589  101.383  -80.838  44.099  1
101590  101.428  -80.851  44.083  1
101591  101.461  -80.867  44.067  1
101592  101.493  -80.883  44.052  1
101593  101.526  -80.899  44.037  1
101850  93.495  -78.515  53.846  1
101851  93.505  -78.513  53.832  1
101852  93.515  -78.510  53.816  1
101853  93.524  -78.507  53.800  1
101854  93.534  -78.505  53.781  1
101855  93.544  -78.503  53.762  1
101856  93.554  -78.500  53.742  1
101857  93.559  -78.495  53.722  1
101858  93.557  -78.485  53.703  1
101859  93.556  -78.476  53.682  1
101860  93.555  -78.467  53.661  1
101861  93.553  -78.458  53.636  1
101862  93.563  -78.442  53.611  1
101863  93.577  -78.427  53.588  1
101864  93.599  -78.412  53.565  1
101865  93.622  -78.397  53.543  1
101866  93.643  -78.383  53.522  1
101867  93.654  -78.375  53.501  1
101868  93.666  -78.366  53.480  1
101869  93.678  -78.358  53.459  1
101882  93.876  -78.262  53.205  1
101883  93.892  -78.254  53.185  1
101884  93.907  -78.247  53.166  1
101885  93.922  -78.240  53.147  1
101886  93.938  -78.232  53.129  1
101887  93.951  -78.228  53.111  1
101888  93.964  -78.223  53.093  1
101889  93.965  -78.222  53.078  1
101890  93.968  -78.232  53.065  1
101891  93.972  -78.242  53.055  1
101892  93.975  -78.253  53.049  1
101893  93.978  -78.263  53.041  1
101894  93.982  -78.273  53.031  1
101895  93.985  -78.284  53.019  1
101896  93.989  -78.294  53.007  1
101897  93.992  -78.304  52.993  1
101898  93.995  -78.314  52.978  1
101899  93.999  -78.325  52.963  1
101900  94.003  -78.335  52.946  1
101901  94.010  -78.338  52.928  1
101902  94.018  -78.343  52.907  1
101903  94.026  -78.347  52.889  1
101904  94.033  -78.351  52.871  1
101905  94.041  -78.355  52.853  1
101906  94.048  -78.360  52.835  1
101907  94.055  -78.367  52.820  1
101908  94.061  -78.375  52.806  1
101909  94.068  -78.382  52.792  1
101910  94.074  -78.389  52.777  1
101911  94.081  -78.396  52.763  1
101912  94.087  -78.404  52.749  1
101913  94.094  -78.411  52.736  1
101914  94.105  -78.410  52.723  1
101915  94.117  -78.406  52.709  1
101916  94.129  -78.403  52.694  1
101917  94.130  -78.385  52.677  1
101918  94.131  -78.364  52.658  1
101919  94.131  -78.343  52.637  1
101920  94.133  -78.322  52.617  1
101921  94.135  -78.300  52.596  1
101922  94.144  -78.282  52.573  1
101923  94.165  -78.284  52.547  1
101924  94.186  -78.285  52.519  1
101925  94.207  -78.288  52.492  1
101926  94.228  -78.290  52.464  1
101927  94.250  -78.291  52.436  1
101928  94.270  -78.294  52.406  1
101929  94.291  -78.296  52.374  1
101930  94.299  -78.313  52.340  1
101931  94.318  -78.310  52.303  1
101932  94.339  -78.302  52.263  1
101933  94.360  -78.294  52.220  1
101934  94.381  -78.285  52.176  1
101935  94.402  -78.278  52.129  1
101936  94.423  -78.269  52.083  1
101937  94.447  -78.264  52.038  1
101938  94.484  -78.278  51.994  1
101939  94.522  -78.292  51.954  1
101940  94.559  -78.306  51.914  1
101941  94.597  -78.319  51.875  1
101942  94.627  -78.317  51.830  1
101943  94.648  -78.304  51.784  1
101944  94.659  -78.297  51.737  1
101945  94.669  -78.291  51.691  1
101946  94.680  -78.286  51.647  1
101947  94.690  -78.280  51.604  1
101948  94.698  -78.271  51.562  1
101949  94.706  -78.263  51.521  1
101950  94.714  -78.253  51.482  1
101951  94.721  -78.250  51.443  1
101952  94.733  -78.247  51.404  1
101953  94.744  -78.244  51.366  1
101954  94.756  -78.242  51.329  1
101955  94.767  -78.239  51.293  1
101956  94.779  -78.242  51.257  1
101957  94.791  -78.247  51.221  1
101958  94.804  -78.252  51.185  1
101959  94.816  -78.257  51.149  1
101960  94.828  -78.262  51.112  1
101961  94.840  -78.266  51.074  1
101962  94.852  -78.271  51.036  1
101963  94.864  -78.276  50.997  1
101964  94.875  -78.281  50.957  1
101965  94.894  -78.279  50.915  1
101966  94.915  -78.258  50.875  1
101967  94.936  -78.237  50.834  1
101968  94.957  -78.216  50.793  1
101969  94.978  -78.194  50.752  1
101970  94.998  -78.174  50.711  1
101971  95.020  -78.153  50.671  1
101972  95.034  -78.140  50.631  1
101973  95.069  -78.126  50.591  1
101974  95.113  -78.120  50.552  1
101975  95.157  -78.114  50.515  1
101976  95.200  -78.108  50.477  1
101977  95.244  -78.102  50.440  1
101978  95.287  -78.097  50.403  1
101979  95.306  -78.091  50.365  1
101980  95.315  -78.087  50.330  1
101981  95.322  -78.085  50.294  1
101982  95.329  -78.084  50.259  1
101983  95.335  -78.082  50.224  1
101984  95.341  -78.081  50.190  1
101985  95.347  -78.080  50.156  1
101986  95.354  -78.078  50.122  1
101987  95.360  -78.077  50.091  1
101988  95.367  -78.075  50.059  1
101989  95.373  -78.074  50.028  1
101990  95.379  -78.072  49.996  1
101991  95.389  -78.076  49.966  1
101992  95.399  -78.080  49.936  1
101993  95.410  -78.084  49.905  1
101994  95.420  -78.088  49.876  1
101995  95.426  -78.092  49.848  1
101996  95.432  -78.096  49.820  1
101997  95.438  -78.100  49.792  1
101998  95.444  -78.104  49.765  1
101999  95.449  -78.108  49.738  1
102000  95.455  -78.112  49.711  1
102001  95.461  -78.116  49.685  1
102002  95.466  -78.120  49.660  1
102003  95.472  -78.124  49.635  1
102004  95.477  -78.127  49.610  1
102005  95.481  -78.122  49.586  1
102006  95.485  -78.118  49.561  1
102007  95.489  -78.113  49.535  1
102008  95.497  -78.119  49.507  1
102009  95.505  -78.123  49.477  1
102010  95.513  -78.128  49.445  1
102011  95.521  -78.132  49.412  1
102012  95.529  -78.138  49.375  1
102013  95.537  -78.142  49.338  1
102014  95.545  -78.147  49.299  1
102015  95.553  -78.151  49.258  1
102016  95.560  -78.156  49.215  1
102017  95.568  -78.161  49.172  1
102018  95.578  -78.167  49.128  1
102019  95.587  -78.175  49.084  1
102020  95.596  -78.181  49.040  1
102021  95.605  -78.188  48.996  1
102022  95.614  -78.196  48.952  1
102023  95.613  -78.194  48.909  1
102024  95.624  -78.201  48.867  1
102025  95.641  -78.212  48.828  1
102026  95.660  -78.225  48.789  1
102027  95.679  -78.239  48.751  1
102028  95.698  -78.253  48.713  1
102029  95.717  -78.267  48.675  1
102030  95.735  -78.275  48.635  1
102031  95.739  -78.268  48.593  1
102032  95.745  -78.261  48.551  1
102033  95.761  -78.260  48.508  1
102034  95.772  -78.252  48.466  1
102035  95.773  -78.232  48.425  1
102036  95.786  -78.229  48.385  1
102037  95.804  -78.235  48.347  1
102038  95.822  -78.241  48.308  1
102039  95.840  -78.247  48.268  1
102040  95.859  -78.252  48.230  1
102041  95.877  -78.257  48.194  1
102042  95.895  -78.258  48.157  1
102043  95.913  -78.261  48.116  1
102044  95.932  -78.264  48.077  1
102045  95.950  -78.267  48.039  1
102046  95.968  -78.270  48.002  1
102047  95.987  -78.272  47.964  1
102048  96.004  -78.275  47.928  1
102049  96.020  -78.280  47.892  1
102050  96.033  -78.297  47.855  1
102051  96.045  -78.315  47.819  1
102052  96.058  -78.332  47.783  1
102053  96.071  -78.349  47.749  1
102054  96.084  -78.366  47.716  1
102055  96.097  -78.382  47.684  1
102056  96.111  -78.395  47.652  1
102057  96.121  -78.401  47.621  1
102058  96.131  -78.406  47.590  1
102059  96.141  -78.413  47.560  1
102060  96.157  -78.418  47.529  1
102061  96.167  -78.426  47.498  1
102062  96.177  -78.433  47.468  1
102063  96.188  -78.440  47.439  1
102064  96.198  -78.448  47.411  1
102065  96.211  -78.455  47.384  1
102066  96.240  -78.459  47.357  1
102067  96.269  -78.463  47.330  1
102068  96.299  -78.467  47.302  1
102069  96.330  -78.471  47.273  1
102070  96.363  -78.476  47.246  1
102071  96.395  -78.480  47.219  1
102072  96.430  -78.484  47.191  1
102073  96.464  -78.488  47.162  1
102074  96.499  -78.492  47.133  1
102075  96.534  -78.495  47.105  1
102076  96.568  -78.499  47.077  1
102077  96.602  -78.503  47.050  1
102078  96.614  -78.502  47.022  1
102079  96.625  -78.501  46.996  1
102080  96.638  -78.500  46.969  1
102081  96.634  -78.501  46.942  1
102082  96.649  -78.520  46.918  1
102083  96.656  -78.530  46.894  1
102084  96.663  -78.539  46.871  1
102085  96.670  -78.549  46.845  1
102086  96.676  -78.558  46.820  1
102087  96.683  -78.567  46.794  1
102088  96.694  -78.574  46.768  1
102089  96.707  -78.580  46.744  1
102090  96.720  -78.586  46.722  1
102091  96.729  -78.598  46.700  1
102092  96.736  -78.615  46.680  1
102093  96.754  -78.645  46.659  1
102094  96.773  -78.676  46.638  1
102095  96.793  -78.707  46.616  1
102096  96.813  -78.738  46.597  1
102097  96.832  -78.766  46.578  1
102098  96.852  -78.789  46.559  1
102099  96.871  -78.812  46.540  1
102100  96.890  -78.836  46.520  1
102101  96.909  -78.859  46.500  1
102102  96.929  -78.882  46.480  1
102103  96.948  -78.905  46.462  1
102104  96.967  -78.929  46.443  1
102105  96.991  -78.938  46.423  1
102106  97.015  -78.940  46.404  1
102107  97.043  -78.948  46.385  1
102108  97.073  -78.959  46.366  1
102109  97.102  -78.969  46.348  1
102110  97.135  -78.971  46.331  1
102111  97.170  -78.968  46.314  1
102112  97.205  -78.964  46.296  1
102113  97.239  -78.961  46.278  1
102114  97.274  -78.958  46.260  1
102115  97.308  -78.954  46.242  1
102116  97.343  -78.951  46.223  1
102117  97.378  -78.948  46.205  1
102118  97.413  -78.944  46.186  1
102119  97.447  -78.941  46.167  1
102120  97.482  -78.937  46.148  1
102121  97.510  -78.943  46.127  1
102122  97.524  -78.941  46.106  1
102123  97.532  -78.935  46.084  1
102124  97.541  -78.930  46.065  1
102125  97.549  -78.924  46.046  1
102126  97.557  -78.918  46.028  1
102127  97.575  -78.915  46.011  1
102128  97.593  -78.911  45.993  1
102129  97.611  -78.908  45.975  1
102130  97.629  -78.904  45.957  1
102131  97.646  -78.901  45.939  1
102132  97.664  -78.897  45.921  1
102133  97.682  -78.894  45.904  1
102134  97.700  -78.890  45.888  1
102135  97.718  -78.887  45.870  1
102136  97.736  -78.883  45.853  1
102137  97.752  -78.880  45.837  1
102138  97.765  -78.878  45.820  1
102139  97.778  -78.876  45.805  1
102140  97.791  -78.874  45.790  1
102141  97.802  -78.868  45.775  1
102142  97.805  -78.846  45.759  1
102143  97.807  -78.825  45.743  1
102144  97.808  -78.826  45.729  1
102145  97.809  -78.861  45.716  1
102146  97.816  -78.868  45.702  1
102147  97.823  -78.873  45.687  1
102148  97.831  -78.878  45.673  1
102149  97.839  -78.883  45.660  1
102150  97.846  -78.888  45.648  1
102151  97.853  -78.893  45.639  1
102152  97.861  -78.897  45.630  1
102153  97.868  -78.902  45.619  1
102154  97.876  -78.907  45.608  1
102155  97.883  -78.912  45.597  1
102156  97.891  -78.917  45.584  1
102157  97.898  -78.922  45.570  1
102158  97.921  -78.930  45.557  1
102159  97.950  -78.939  45.544  1
102160  97.979  -78.948  45.529  1
102161  98.004  -78.956  45.512  1
102162  98.020  -78.962  45.492  1
102163  98.035  -78.967  45.471  1
102164  98.051  -78.972  45.451  1
102165  98.066  -78.977  45.433  1
102166  98.081  -78.984  45.416  1
102167  98.096  -78.989  45.401  1
102168  98.112  -78.994  45.387  1
102169  98.121  -79.003  45.374  1
102170  98.126  -79.015  45.361  1
102171  98.140  -79.031  45.348  1
102172  98.160  -79.049  45.335  1
102173  98.180  -79.069  45.323  1
102174  98.201  -79.084  45.311  1
102175  98.218  -79.078  45.301  1
102176  98.229  -79.062  45.291  1
102177  98.260  -79.067  45.281  1
102178  98.290  -79.071  45.271  1
102179  98.320  -79.075  45.261  1
102180  98.350  -79.080  45.249  1
102181  98.380  -79.084  45.237  1
102182  98.411  -79.088  45.226  1
102183  98.443  -79.094  45.216  1
102184  98.477  -79.103  45.205  1
102185  98.511  -79.112  45.194  1
102186  98.545  -79.121  45.183  1
102187  98.579  -79.129  45.173  1
102188  98.613  -79.138  45.163  1
102189  98.647  -79.147  45.152  1
102190  98.681  -79.156  45.142  1
102191  98.715  -79.165  45.133  1
102192  98.749  -79.173  45.123  1
102193  98.783  -79.182  45.113  1
102194  98.814  -79.190  45.103  1
102195  98.838  -79.197  45.092  1
102196  98.862  -79.203  45.081  1
102197  98.886  -79.210  45.070  1
102198  98.908  -79.216  45.059  1
102199  98.922  -79.220  45.049  1
102200  98.935  -79.224  45.040  1
102201  98.948  -79.228  45.033  1
102202  98.961  -79.231  45.025  1
102203  98.980  -79.241  45.017  1
102204  99.000  -79.254  45.007  1
102205  99.016  -79.285  44.996  1
102206  99.014  -79.262  44.987  1
102207  99.029  -79.272  44.978  1
102208  99.047  -79.290  44.968  1
102209  99.065  -79.307  44.956  1
102210  99.082  -79.324  44.944  1
102211  99.100  -79.341  44.933  1
102212  99.120  -79.359  44.921  1
102213  99.144  -79.376  44.911  1
102214  99.163  -79.392  44.900  1
102215  99.185  -79.400  44.890  1
102216  99.207  -79.409  44.880  1
102217  99.228  -79.417  44.871  1
102218  99.251  -79.426  44.863  1
102219  99.272  -79.434  44.855  1
102220  99.294  -79.442  44.848  1
102221  99.316  -79.451  44.841  1
102222  99.338  -79.458  44.834  1
102223  99.360  -79.466  44.828  1
102224  99.381  -79.475  44.822  1
102225  99.404  -79.483  44.816  1
102226  99.425  -79.491  44.810  1
102227  99.447  -79.500  44.804  1
102228  99.469  -79.508  44.799  1
102229  99.492  -79.523  44.794  1
102230  99.522  -79.527  44.789  1
102231  99.552  -79.531  44.784  1
102232  99.582  -79.535  44.780  1
102233  99.613  -79.538  44.776  1
102234  99.642  -79.541  44.773  1
102235  99.673  -79.545  44.769  1
102236  99.703  -79.549  44.765  1
102237  99.733  -79.553  44.761  1
102238  99.763  -79.557  44.758  1
102239  99.793  -79.560  44.755  1
102240  99.823  -79.563  44.751  1
102241  99.853  -79.567  44.746  1
102242  99.884  -79.571  44.741  1
102243  99.914  -79.575  44.736  1
102244  99.943  -79.579  44.731  1
102245  99.972  -79.584  44.725  1
102246  99.974  -79.683  44.719  1
102247  99.989  -79.713  44.711  1
102248  100.039  -79.753  44.704  1
102249  100.075  -79.772  44.698  1
102250  100.109  -79.793  44.690  1
102251  100.134  -79.820  44.685  1
102252  100.159  -79.847  44.680  1
102253  100.184  -79.874  44.674  1
102254  100.209  -79.901  44.671  1
102255  100.234  -79.928  44.667  1
102256  100.257  -79.963  44.662  1
102257  100.288  -79.980  44.653  1
102258  100.326  -79.986  44.644  1
102259  100.360  -80.012  44.633  1
102260  100.395  -80.040  44.620  1
102261  100.429  -80.068  44.607  1
102262  100.464  -80.095  44.594  1
102263  100.498  -80.122  44.579  1
102264  100.533  -80.150  44.565  1
102265  100.568  -80.178  44.549  1
102266  100.602  -80.206  44.534  1
102267  100.616  -80.243  44.518  1
102268  100.612  -80.287  44.502  1
102269  100.608  -80.332  44.486  1
102270  100.632  -80.368  44.469  1
102271  100.656  -80.402  44.451  1
102272  100.682  -80.437  44.433  1
102273  100.707  -80.472  44.415  1
102274  100.732  -80.507  44.397  1
102275  100.760  -80.543  44.379  1
102276  100.788  -80.579  44.362  1
102277  100.817  -80.616  44.346  1
102278  100.845  -80.652  44.328  1
102279  100.876  -80.686  44.310  1
102280  100.922  -80.699  44.291  1
102281  100.969  -80.712  44.270  1
102282  101.015  -80.725  44.249  1
102283  101.061  -80.738  44.228  1
102284  101.108  -80.751  44.207  1
102285  101.155  -80.764  44.188  1
102286  101.201  -80.776  44.170  1
102287  101.247  -80.789  44.154  1
102288  101.294  -80.802  44.137  1
102289  101.340  -80.815  44.121  1
102290  101.384  -80.829  44.105  1
102291  101.417  -80.845  44.089  1
102292  101.450  -80.861  44.073  1
102293  101.482  -80.877  44.057  1
102294  101.515  -80.893  44.042  1
102551  93.496  -78.504  53.848  1
102552  93.505  -78.501  53.833  1
102553  93.515  -78.499  53.817  1
102554  93.524  -78.497  53.800  1
102555  93.535  -78.494  53.781  1
102556  93.544  -78.492  53.762  1
102557  93.554  -78.489  53.742  1
102558  93.555  -78.482  53.721  1
102559  93.554  -78.473  53.701  1
102560  93.553  -78.463  53.680  1
102561  93.551  -78.454  53.657  1
102562  93.555  -78.442  53.632  1
102563  93.565  -78.427  53.607  1
102564  93.582  -78.411  53.582  1
102565  93.605  -78.397  53.560  1
102566  93.627  -78.382  53.537  1
102567  93.644  -78.369  53.515  1
102568  93.656  -78.362  53.494  1
102569  93.667  -78.354  53.473  1
102570  93.679  -78.345  53.453  1
102583  93.878  -78.249  53.195  1
102584  93.894  -78.242  53.175  1
102585  93.909  -78.235  53.156  1
102586  93.924  -78.227  53.137  1
102587  93.939  -78.221  53.118  1
102588  93.952  -78.216  53.099  1
102589  93.965  -78.213  53.081  1
102590  93.965  -78.210  53.065  1
102591  93.968  -78.219  53.051  1
102592  93.971  -78.229  53.040  1
102593  93.974  -78.239  53.031  1
102594  93.978  -78.250  53.021  1
102595  93.981  -78.260  53.010  1
102596  93.985  -78.270  52.998  1
102597  93.988  -78.281  52.984  1
102598  93.991  -78.291  52.969  1
102599  93.995  -78.301  52.953  1
102600  93.998  -78.312  52.937  1
102601  94.002  -78.322  52.919  1
102602  94.005  -78.332  52.899  1
102603  94.008  -78.342  52.877  1
102604  94.013  -78.351  52.859  1
102605  94.020  -78.356  52.841  1
102606  94.028  -78.360  52.823  1
102607  94.036  -78.364  52.807  1
102608  94.043  -78.369  52.792  1
102609  94.049  -78.376  52.778  1
102610  94.056  -78.384  52.763  1
102611  94.062  -78.391  52.747  1
102612  94.069  -78.398  52.731  1
102613  94.079  -78.398  52.716  1
102614  94.091  -78.395  52.702  1
102615  94.104  -78.391  52.689  1
102616  94.115  -78.388  52.674  1
102617  94.127  -78.385  52.657  1
102618  94.130  -78.369  52.639  1
102619  94.131  -78.349  52.620  1
102620  94.131  -78.328  52.599  1
102621  94.132  -78.307  52.578  1
102622  94.132  -78.287  52.557  1
102623  94.135  -78.269  52.535  1
102624  94.156  -78.271  52.509  1
102625  94.177  -78.273  52.482  1
102626  94.198  -78.275  52.454  1
102627  94.219  -78.277  52.426  1
102628  94.241  -78.279  52.397  1
102629  94.261  -78.281  52.367  1
102630  94.282  -78.283  52.334  1
102631  94.297  -78.292  52.300  1
102632  94.318  -78.284  52.262  1
102633  94.339  -78.275  52.220  1
102634  94.360  -78.267  52.175  1
102635  94.382  -78.259  52.130  1
102636  94.403  -78.250  52.084  1
102637  94.423  -78.242  52.039  1
102638  94.445  -78.234  51.997  1
102639  94.479  -78.244  51.958  1
102640  94.517  -78.258  51.920  1
102641  94.554  -78.272  51.881  1
102642  94.592  -78.286  51.840  1
102643  94.629  -78.300  51.797  1
102644  94.653  -78.291  51.752  1
102645  94.664  -78.285  51.705  1
102646  94.674  -78.279  51.661  1
102647  94.682  -78.270  51.619  1
102648  94.690  -78.261  51.577  1
102649  94.698  -78.253  51.538  1
102650  94.706  -78.244  51.499  1
102651  94.714  -78.235  51.460  1
102652  94.720  -78.232  51.422  1
102653  94.730  -78.230  51.384  1
102654  94.742  -78.228  51.347  1
102655  94.753  -78.225  51.311  1
102656  94.765  -78.222  51.275  1
102657  94.777  -78.225  51.239  1
102658  94.789  -78.229  51.203  1
102659  94.801  -78.235  51.166  1
102660  94.813  -78.239  51.130  1
102661  94.825  -78.244  51.093  1
102662  94.837  -78.249  51.057  1
102663  94.849  -78.253  51.020  1
102664  94.862  -78.259  50.981  1
102665  94.874  -78.263  50.942  1
102666  94.890  -78.263  50.903  1
102667  94.910  -78.244  50.863  1
102668  94.931  -78.222  50.823  1
102669  94.952  -78.201  50.783  1
102670  94.973  -78.180  50.744  1
102671  94.993  -78.159  50.704  1
102672  95.015  -78.138  50.665  1
102673  95.035  -78.117  50.625  1
102674  95.075  -78.108  50.587  1
102675  95.119  -78.103  50.550  1
102676  95.163  -78.097  50.512  1
102677  95.207  -78.091  50.475  1
102678  95.251  -78.085  50.439  1
102679  95.295  -78.079  50.402  1
102680  95.318  -78.079  50.366  1
102681  95.325  -78.078  50.331  1
102682  95.332  -78.078  50.296  1
102683  95.340  -78.077  50.261  1
102684  95.347  -78.075  50.227  1
102685  95.354  -78.075  50.194  1
102686  95.362  -78.074  50.161  1
102687  95.370  -78.073  50.128  1
102688  95.377  -78.072  50.097  1
102689  95.384  -78.071  50.067  1
102690  95.392  -78.070  50.037  1
102691  95.399  -78.069  50.006  1
102692  95.406  -78.069  49.977  1
102693  95.411  -78.073  49.947  1
102694  95.417  -78.077  49.917  1
102695  95.423  -78.081  49.889  1
102696  95.428  -78.084  49.862  1
102697  95.435  -78.089  49.835  1
102698  95.440  -78.093  49.808  1
102699  95.446  -78.097  49.782  1
102700  95.451  -78.101  49.756  1
102701  95.457  -78.105  49.730  1
102702  95.463  -78.109  49.704  1
102703  95.468  -78.112  49.679  1
102704  95.474  -78.117  49.654  1
102705  95.479  -78.116  49.629  1
102706  95.483  -78.112  49.605  1
102707  95.487  -78.106  49.579  1
102708  95.491  -78.102  49.552  1
102709  95.497  -78.103  49.523  1
102710  95.505  -78.107  49.492  1
102711  95.513  -78.112  49.459  1
102712  95.521  -78.117  49.423  1
102713  95.529  -78.122  49.386  1
102714  95.536  -78.126  49.348  1
102715  95.544  -78.131  49.308  1
102716  95.552  -78.136  49.266  1
102717  95.560  -78.141  49.223  1
102718  95.568  -78.145  49.179  1
102719  95.576  -78.150  49.134  1
102720  95.584  -78.155  49.091  1
102721  95.592  -78.159  49.047  1
102722  95.600  -78.165  49.003  1
102723  95.609  -78.172  48.959  1
102724  95.614  -78.175  48.916  1
102725  95.632  -78.188  48.874  1
102726  95.651  -78.201  48.833  1
102727  95.671  -78.210  48.794  1
102728  95.690  -78.216  48.755  1
102729  95.710  -78.222  48.716  1
102730  95.730  -78.237  48.678  1
102731  95.746  -78.253  48.638  1
102732  95.758  -78.260  48.598  1
102733  95.764  -78.253  48.556  1
102734  95.771  -78.247  48.516  1
102735  95.778  -78.242  48.475  1
102736  95.785  -78.238  48.434  1
102737  95.790  -78.231  48.396  1
102738  95.807  -78.232  48.357  1
102739  95.825  -78.232  48.319  1
102740  95.843  -78.234  48.280  1
102741  95.861  -78.235  48.243  1
102742  95.881  -78.238  48.206  1
102743  95.900  -78.239  48.168  1
102744  95.919  -78.242  48.128  1
102745  95.938  -78.245  48.089  1
102746  95.956  -78.248  48.050  1
102747  95.974  -78.251  48.013  1
102748  95.993  -78.254  47.976  1
102749  96.012  -78.257  47.940  1
102750  96.028  -78.264  47.904  1
102751  96.040  -78.282  47.868  1
102752  96.053  -78.299  47.832  1
102753  96.066  -78.316  47.797  1
102754  96.079  -78.334  47.764  1
102755  96.091  -78.351  47.731  1
102756  96.104  -78.368  47.700  1
102757  96.117  -78.385  47.668  1
102758  96.127  -78.388  47.637  1
102759  96.138  -78.390  47.607  1
102760  96.154  -78.399  47.576  1
102761  96.160  -78.410  47.545  1
102762  96.163  -78.419  47.515  1
102763  96.174  -78.426  47.485  1
102764  96.184  -78.434  47.456  1
102765  96.195  -78.441  47.428  1
102766  96.212  -78.448  47.400  1
102767  96.241  -78.451  47.373  1
102768  96.272  -78.456  47.346  1
102769  96.305  -78.460  47.318  1
102770  96.337  -78.465  47.291  1
102771  96.369  -78.470  47.264  1
102772  96.403  -78.473  47.238  1
102773  96.438  -78.477  47.209  1
102774  96.472  -78.481  47.179  1
102775  96.507  -78.485  47.150  1
102776  96.541  -78.489  47.122  1
102777  96.576  -78.492  47.095  1
102778  96.610  -78.496  47.068  1
102779  96.645  -78.500  47.041  1
102780  96.677  -78.504  47.015  1
102781  96.670  -78.504  46.988  1
102782  96.648  -78.504  46.961  1
102783  96.644  -78.510  46.937  1
102784  96.650  -78.520  46.913  1
102785  96.657  -78.529  46.889  1
102786  96.663  -78.539  46.865  1
102787  96.670  -78.548  46.840  1
102788  96.677  -78.557  46.814  1
102789  96.690  -78.563  46.788  1
102790  96.702  -78.568  46.764  1
102791  96.716  -78.574  46.741  1
102792  96.728  -78.580  46.719  1
102793  96.735  -78.598  46.699  1
102794  96.752  -78.626  46.677  1
102795  96.771  -78.658  46.656  1
102796  96.791  -78.688  46.634  1
102797  96.810  -78.719  46.615  1
102798  96.829  -78.750  46.595  1
102799  96.849  -78.781  46.576  1
102800  96.868  -78.812  46.556  1
102801  96.888  -78.836  46.537  1
102802  96.907  -78.859  46.517  1
102803  96.927  -78.882  46.496  1
102804  96.946  -78.905  46.478  1
102805  96.965  -78.929  46.458  1
102806  96.986  -78.946  46.438  1
102807  97.011  -78.949  46.421  1
102808  97.035  -78.951  46.402  1
102809  97.065  -78.962  46.382  1
102810  97.095  -78.971  46.363  1
102811  97.130  -78.968  46.345  1
102812  97.164  -78.965  46.327  1
102813  97.199  -78.962  46.309  1
102814  97.234  -78.959  46.289  1
102815  97.268  -78.955  46.270  1
102816  97.303  -78.952  46.250  1
102817  97.338  -78.949  46.230  1
102818  97.372  -78.945  46.212  1
102819  97.407  -78.942  46.194  1
102820  97.442  -78.938  46.176  1
102821  97.476  -78.935  46.158  1
102822  97.511  -78.933  46.138  1
102823  97.532  -78.936  46.117  1
102824  97.540  -78.930  46.097  1
102825  97.548  -78.924  46.077  1
102826  97.558  -78.918  46.057  1
102827  97.575  -78.915  46.038  1
102828  97.593  -78.912  46.020  1
102829  97.611  -78.908  46.002  1
102830  97.629  -78.905  45.984  1
102831  97.647  -78.902  45.967  1
102832  97.665  -78.898  45.950  1
102833  97.682  -78.895  45.933  1
102834  97.701  -78.891  45.917  1
102835  97.718  -78.888  45.902  1
102836  97.736  -78.884  45.884  1
102837  97.754  -78.881  45.866  1
102838  97.771  -78.878  45.849  1
102839  97.784  -78.876  45.834  1
102840  97.797  -78.873  45.818  1
102841  97.806  -78.865  45.803  1
102842  97.809  -78.843  45.789  1
102843  97.811  -78.822  45.772  1
102844  97.813  -78.801  45.755  1
102845  97.815  -78.788  45.738  1
102846  97.816  -78.823  45.724  1
102847  97.816  -78.858  45.710  1
102848  97.823  -78.865  45.696  1
102849  97.831  -78.869  45.683  1
102850  97.839  -78.874  45.671  1
102851  97.846  -78.879  45.659  1
102852  97.853  -78.883  45.647  1
102853  97.861  -78.889  45.636  1
102854  97.868  -78.893  45.625  1
102855  97.876  -78.899  45.613  1
102856  97.883  -78.903  45.603  1
102857  97.895  -78.909  45.590  1
102858  97.924  -78.918  45.577  1
102859  97.952  -78.927  45.564  1
102860  97.981  -78.937  45.550  1
102861  98.010  -78.945  45.535  1
102862  98.038  -78.954  45.519  1
102863  98.058  -78.961  45.500  1
102864  98.073  -78.966  45.478  1
102865  98.088  -78.971  45.458  1
102866  98.104  -78.977  45.439  1
102867  98.119  -78.983  45.423  1
102868  98.133  -78.989  45.407  1
102869  98.139  -78.999  45.393  1
102870  98.144  -79.011  45.380  1
102871  98.149  -79.022  45.367  1
102872  98.161  -79.037  45.354  1
102873  98.181  -79.056  45.341  1
102874  98.202  -79.076  45.330  1
102875  98.220  -79.079  45.318  1
102876  98.238  -79.073  45.308  1
102877  98.248  -79.057  45.298  1
102878  98.271  -79.053  45.288  1
102879  98.301  -79.057  45.278  1
102880  98.331  -79.061  45.268  1
102881  98.361  -79.065  45.256  1
102882  98.392  -79.069  45.243  1
102883  98.422  -79.074  45.231  1
102884  98.455  -79.081  45.220  1
102885  98.489  -79.090  45.208  1
102886  98.523  -79.099  45.196  1
102887  98.557  -79.107  45.184  1
102888  98.591  -79.116  45.174  1
102889  98.625  -79.125  45.163  1
102890  98.659  -79.134  45.152  1
102891  98.694  -79.143  45.141  1
102892  98.727  -79.151  45.131  1
102893  98.762  -79.160  45.121  1
102894  98.789  -79.168  45.110  1
102895  98.813  -79.174  45.100  1
102896  98.837  -79.181  45.090  1
102897  98.861  -79.187  45.079  1
102898  98.885  -79.194  45.069  1
102899  98.909  -79.200  45.060  1
102900  98.923  -79.204  45.050  1
102901  98.936  -79.208  45.040  1
102902  98.949  -79.212  45.029  1
102903  98.962  -79.216  45.019  1
102904  98.976  -79.220  45.010  1
102905  98.989  -79.224  45.002  1
102906  98.997  -79.248  44.992  1
102907  98.989  -79.222  44.982  1
102908  99.020  -79.237  44.972  1
102909  99.044  -79.254  44.961  1
102910  99.068  -79.272  44.950  1
102911  99.092  -79.290  44.939  1
102912  99.116  -79.307  44.928  1
102913  99.140  -79.325  44.918  1
102914  99.163  -79.342  44.908  1
102915  99.180  -79.359  44.898  1
102916  99.193  -79.372  44.888  1
102917  99.214  -79.380  44.879  1
102918  99.236  -79.388  44.871  1
102919  99.258  -79.397  44.863  1
102920  99.280  -79.405  44.856  1
102921  99.302  -79.413  44.849  1
102922  99.324  -79.421  44.843  1
102923  99.346  -79.429  44.836  1
102924  99.367  -79.438  44.830  1
102925  99.389  -79.446  44.825  1
102926  99.411  -79.454  44.819  1
102927  99.433  -79.463  44.814  1
102928  99.455  -79.474  44.808  1
102929  99.479  -79.489  44.803  1
102930  99.502  -79.504  44.800  1
102931  99.532  -79.508  44.795  1
102932  99.562  -79.511  44.791  1
102933  99.592  -79.515  44.787  1
102934  99.623  -79.519  44.784  1
102935  99.652  -79.523  44.780  1
102936  99.683  -79.526  44.777  1
102937  99.713  -79.530  44.773  1
102938  99.743  -79.533  44.770  1
102939  99.773  -79.537  44.768  1
102940  99.803  -79.541  44.767  1
102941  99.833  -79.545  44.762  1
102942  99.863  -79.548  44.757  1
102943  99.892  -79.552  44.751  1
102944  99.917  -79.557  44.746  1
102945  99.943  -79.561  44.740  1
102946  99.974  -79.582  44.734  1
102947  100.007  -79.634  44.728  1
102948  100.040  -79.689  44.721  1
102949  100.069  -79.723  44.713  1
102950  100.094  -79.751  44.705  1
102951  100.119  -79.777  44.698  1
102952  100.144  -79.805  44.691  1
102953  100.169  -79.831  44.686  1
102954  100.194  -79.858  44.682  1
102955  100.219  -79.886  44.680  1
102956  100.244  -79.912  44.675  1
102957  100.266  -79.950  44.668  1
102958  100.294  -79.976  44.658  1
102959  100.331  -79.981  44.649  1
102960  100.368  -79.986  44.638  1
102961  100.403  -80.012  44.625  1
102962  100.437  -80.040  44.612  1
102963  100.472  -80.067  44.599  1
102964  100.507  -80.095  44.585  1
102965  100.541  -80.122  44.569  1
102966  100.576  -80.150  44.554  1
102967  100.611  -80.178  44.539  1
102968  100.628  -80.213  44.522  1
102969  100.624  -80.258  44.506  1
102970  100.624  -80.302  44.490  1
102971  100.649  -80.336  44.474  1
102972  100.674  -80.371  44.455  1
102973  100.699  -80.406  44.438  1
102974  100.724  -80.441  44.421  1
102975  100.752  -80.476  44.405  1
102976  100.780  -80.513  44.387  1
102977  100.809  -80.549  44.371  1
102978  100.837  -80.585  44.354  1
102979  100.865  -80.622  44.336  1
102980  100.894  -80.659  44.316  1
102981  100.926  -80.690  44.297  1
102982  100.973  -80.702  44.279  1
102983  101.019  -80.715  44.257  1
102984  101.066  -80.728  44.236  1
102985  101.112  -80.741  44.216  1
102986  101.159  -80.754  44.196  1
102987  101.205  -80.767  44.178  1
102988  101.252  -80.779  44.161  1
102989  101.298  -80.792  44.145  1
102990  101.340  -80.807  44.127  1
102991  101.373  -80.823  44.111  1
102992  101.405  -80.839  44.094  1
102993  101.438  -80.855  44.078  1
102994  101.471  -80.871  44.062  1
102995  101.503  -80.887  44.047  1
103252  93.496  -78.493  53.848  1
103253  93.506  -78.491  53.833  1
103254  93.515  -78.489  53.817  1
103255  93.525  -78.485  53.798  1
103256  93.535  -78.483  53.779  1
103257  93.544  -78.481  53.760  1
103258  93.553  -78.478  53.739  1
103259  93.552  -78.469  53.718  1
103260  93.551  -78.460  53.697  1
103261  93.549  -78.450  53.675  1
103262  93.548  -78.441  53.651  1
103263  93.556  -78.426  53.626  1
103264  93.566  -78.411  53.601  1
103265  93.587  -78.396  53.577  1
103266  93.610  -78.381  53.553  1
103267  93.633  -78.366  53.531  1
103268  93.645  -78.357  53.509  1
103269  93.657  -78.348  53.488  1
103270  93.669  -78.341  53.466  1
103271  93.680  -78.332  53.446  1
103284  93.880  -78.236  53.186  1
103285  93.895  -78.229  53.165  1
103286  93.911  -78.222  53.145  1
103287  93.926  -78.214  53.125  1
103288  93.939  -78.210  53.106  1
103289  93.952  -78.205  53.087  1
103290  93.965  -78.201  53.068  1
103291  93.966  -78.199  53.050  1
103292  93.967  -78.206  53.035  1
103293  93.970  -78.216  53.021  1
103294  93.974  -78.226  53.009  1
103295  93.977  -78.236  52.996  1
103296  93.981  -78.247  52.982  1
103297  93.984  -78.257  52.969  1
103298  93.987  -78.267  52.954  1
103299  93.991  -78.278  52.937  1
103300  93.994  -78.288  52.919  1
103301  93.998  -78.298  52.902  1
103302  94.001  -78.309  52.884  1
103303  94.004  -78.319  52.864  1
103304  94.008  -78.329  52.843  1
103305  94.011  -78.339  52.823  1
103306  94.015  -78.350  52.806  1
103307  94.018  -78.360  52.790  1
103308  94.024  -78.368  52.776  1
103309  94.031  -78.373  52.762  1
103310  94.038  -78.379  52.747  1
103311  94.044  -78.386  52.731  1
103312  94.054  -78.386  52.714  1
103313  94.066  -78.383  52.697  1
103314  94.078  -78.380  52.680  1
103315  94.090  -78.377  52.667  1
103316  94.102  -78.374  52.652  1
103317  94.114  -78.371  52.636  1
103318  94.125  -78.368  52.619  1
103319  94.130  -78.354  52.599  1
103320  94.131  -78.334  52.579  1
103321  94.131  -78.313  52.560  1
103322  94.132  -78.292  52.539  1
103323  94.149  -78.291  52.517  1
103324  94.167  -78.290  52.493  1
103325  94.184  -78.289  52.468  1
103326  94.201  -78.288  52.441  1
103327  94.218  -78.287  52.413  1
103328  94.236  -78.285  52.384  1
103329  94.253  -78.285  52.355  1
103330  94.270  -78.282  52.325  1
103331  94.283  -78.275  52.292  1
103332  94.297  -78.267  52.257  1
103333  94.318  -78.257  52.216  1
103334  94.339  -78.248  52.173  1
103335  94.360  -78.240  52.127  1
103336  94.382  -78.232  52.083  1
103337  94.403  -78.223  52.040  1
103338  94.424  -78.215  51.999  1
103339  94.445  -78.206  51.962  1
103340  94.475  -78.210  51.927  1
103341  94.512  -78.224  51.890  1
103342  94.549  -78.238  51.852  1
103343  94.587  -78.252  51.811  1
103344  94.624  -78.266  51.768  1
103345  94.657  -78.279  51.723  1
103346  94.666  -78.269  51.678  1
103347  94.674  -78.260  51.636  1
103348  94.682  -78.252  51.595  1
103349  94.690  -78.243  51.556  1
103350  94.698  -78.234  51.518  1
103351  94.706  -78.225  51.479  1
103352  94.714  -78.216  51.441  1
103353  94.720  -78.213  51.404  1
103354  94.728  -78.213  51.368  1
103355  94.739  -78.210  51.332  1
103356  94.751  -78.208  51.297  1
103357  94.762  -78.205  51.262  1
103358  94.774  -78.207  51.226  1
103359  94.786  -78.212  51.190  1
103360  94.799  -78.217  51.154  1
103361  94.811  -78.222  51.117  1
103362  94.823  -78.227  51.081  1
103363  94.835  -78.232  51.045  1
103364  94.847  -78.237  51.009  1
103365  94.859  -78.241  50.970  1
103366  94.872  -78.246  50.932  1
103367  94.892  -78.244  50.894  1
103368  94.910  -78.227  50.856  1
103369  94.929  -78.209  50.816  1
103370  94.951  -78.188  50.777  1
103371  94.971  -78.166  50.739  1
103372  94.992  -78.145  50.700  1
103373  95.014  -78.125  50.661  1
103374  95.034  -78.103  50.622  1
103375  95.065  -78.089  50.585  1
103376  95.109  -78.083  50.548  1
103377  95.153  -78.077  50.512  1
103378  95.197  -78.071  50.476  1
103379  95.241  -78.065  50.439  1
103380  95.281  -78.061  50.404  1
103381  95.306  -78.063  50.369  1
103382  95.322  -78.064  50.333  1
103383  95.329  -78.062  50.298  1
103384  95.336  -78.062  50.264  1
103385  95.344  -78.061  50.232  1
103386  95.351  -78.060  50.199  1
103387  95.358  -78.059  50.167  1
103388  95.366  -78.059  50.135  1
103389  95.374  -78.057  50.106  1
103390  95.381  -78.056  50.076  1
103391  95.388  -78.056  50.047  1
103392  95.396  -78.055  50.018  1
103393  95.403  -78.052  49.989  1
103394  95.414  -78.062  49.959  1
103395  95.419  -78.068  49.930  1
103396  95.425  -78.072  49.903  1
103397  95.431  -78.078  49.876  1
103398  95.437  -78.081  49.850  1
103399  95.442  -78.085  49.824  1
103400  95.448  -78.089  49.800  1
103401  95.454  -78.094  49.776  1
103402  95.459  -78.097  49.751  1
103403  95.465  -78.101  49.725  1
103404  95.471  -78.106  49.700  1
103405  95.476  -78.109  49.675  1
103406  95.480  -78.106  49.649  1
103407  95.484  -78.100  49.624  1
103408  95.488  -78.096  49.597  1
103409  95.492  -78.091  49.569  1
103410  95.499  -78.088  49.539  1
103411  95.509  -78.094  49.506  1
103412  95.519  -78.100  49.470  1
103413  95.528  -78.105  49.432  1
103414  95.536  -78.109  49.393  1
103415  95.544  -78.115  49.354  1
103416  95.553  -78.119  49.313  1
103417  95.561  -78.125  49.270  1
103418  95.569  -78.129  49.227  1
103419  95.578  -78.134  49.184  1
103420  95.587  -78.140  49.139  1
103421  95.595  -78.144  49.096  1
103422  95.604  -78.150  49.053  1
103423  95.612  -78.154  49.009  1
103424  95.620  -78.159  48.966  1
103425  95.626  -78.152  48.923  1
103426  95.644  -78.152  48.880  1
103427  95.665  -78.158  48.838  1
103428  95.684  -78.164  48.798  1
103429  95.704  -78.170  48.759  1
103430  95.724  -78.189  48.720  1
103431  95.740  -78.207  48.681  1
103432  95.756  -78.223  48.641  1
103433  95.772  -78.239  48.601  1
103434  95.784  -78.244  48.561  1
103435  95.791  -78.238  48.523  1
103436  95.798  -78.234  48.483  1
103437  95.805  -78.228  48.444  1
103438  95.806  -78.219  48.406  1
103439  95.809  -78.212  48.367  1
103440  95.827  -78.213  48.330  1
103441  95.846  -78.215  48.294  1
103442  95.866  -78.217  48.255  1
103443  95.885  -78.219  48.218  1
103444  95.905  -78.221  48.179  1
103445  95.924  -78.223  48.139  1
103446  95.943  -78.226  48.101  1
103447  95.961  -78.229  48.063  1
103448  95.979  -78.232  48.024  1
103449  95.998  -78.235  47.988  1
103450  96.016  -78.239  47.953  1
103451  96.031  -78.247  47.917  1
103452  96.046  -78.260  47.881  1
103453  96.059  -78.278  47.846  1
103454  96.072  -78.295  47.811  1
103455  96.085  -78.312  47.779  1
103456  96.097  -78.329  47.747  1
103457  96.110  -78.347  47.715  1
103458  96.124  -78.360  47.685  1
103459  96.136  -78.364  47.653  1
103460  96.147  -78.366  47.623  1
103461  96.164  -78.378  47.592  1
103462  96.184  -78.397  47.561  1
103463  96.190  -78.407  47.531  1
103464  96.192  -78.416  47.502  1
103465  96.194  -78.425  47.474  1
103466  96.196  -78.434  47.447  1
103467  96.215  -78.440  47.418  1
103468  96.247  -78.445  47.389  1
103469  96.279  -78.449  47.362  1
103470  96.311  -78.454  47.336  1
103471  96.343  -78.459  47.309  1
103472  96.377  -78.463  47.283  1
103473  96.411  -78.467  47.257  1
103474  96.446  -78.470  47.227  1
103475  96.480  -78.474  47.197  1
103476  96.515  -78.478  47.168  1
103477  96.549  -78.482  47.140  1
103478  96.584  -78.485  47.113  1
103479  96.618  -78.489  47.087  1
103480  96.650  -78.489  47.061  1
103481  96.676  -78.490  47.035  1
103482  96.680  -78.499  47.008  1
103483  96.661  -78.501  46.981  1
103484  96.639  -78.501  46.956  1
103485  96.644  -78.509  46.932  1
103486  96.650  -78.518  46.908  1
103487  96.657  -78.528  46.884  1
103488  96.664  -78.537  46.860  1
103489  96.673  -78.545  46.834  1
103490  96.685  -78.551  46.809  1
103491  96.698  -78.557  46.786  1
103492  96.711  -78.563  46.762  1
103493  96.724  -78.569  46.738  1
103494  96.734  -78.580  46.717  1
103495  96.749  -78.608  46.696  1
103496  96.769  -78.639  46.673  1
103497  96.788  -78.670  46.651  1
103498  96.808  -78.700  46.632  1
103499  96.827  -78.731  46.611  1
103500  96.847  -78.762  46.590  1
103501  96.866  -78.793  46.571  1
103502  96.885  -78.824  46.552  1
103503  96.905  -78.855  46.531  1
103504  96.924  -78.882  46.511  1
103505  96.944  -78.905  46.492  1
103506  96.963  -78.929  46.473  1
103507  96.982  -78.952  46.454  1
103508  97.006  -78.957  46.436  1
103509  97.031  -78.959  46.418  1
103510  97.058  -78.965  46.398  1
103511  97.090  -78.969  46.378  1
103512  97.124  -78.965  46.359  1
103513  97.159  -78.962  46.340  1
103514  97.193  -78.959  46.320  1
103515  97.228  -78.955  46.299  1
103516  97.263  -78.952  46.278  1
103517  97.298  -78.949  46.258  1
103518  97.332  -78.946  46.238  1
103519  97.367  -78.943  46.219  1
103520  97.401  -78.939  46.200  1
103521  97.436  -78.936  46.182  1
103522  97.471  -78.933  46.164  1
103523  97.506  -78.929  46.146  1
103524  97.537  -78.929  46.126  1
103525  97.548  -78.924  46.106  1
103526  97.558  -78.919  46.088  1
103527  97.576  -78.916  46.069  1
103528  97.594  -78.912  46.051  1
103529  97.611  -78.909  46.032  1
103530  97.630  -78.905  46.013  1
103531  97.647  -78.902  45.995  1
103532  97.665  -78.899  45.977  1
103533  97.683  -78.896  45.961  1
103534  97.701  -78.892  45.944  1
103535  97.719  -78.889  45.928  1
103536  97.736  -78.885  45.913  1
103537  97.754  -78.882  45.897  1
103538  97.772  -78.878  45.880  1
103539  97.789  -78.875  45.863  1
103540  97.802  -78.873  45.848  1
103541  97.810  -78.861  45.831  1
103542  97.813  -78.840  45.815  1
103543  97.815  -78.819  45.800  1
103544  97.817  -78.798  45.783  1
103545  97.820  -78.777  45.766  1
103546  97.821  -78.755  45.749  1
103547  97.822  -78.785  45.733  1
103548  97.823  -78.820  45.719  1
103549  97.823  -78.854  45.705  1
103550  97.831  -78.861  45.693  1
103551  97.838  -78.865  45.680  1
103552  97.846  -78.871  45.668  1
103553  97.853  -78.875  45.656  1
103554  97.861  -78.880  45.644  1
103555  97.868  -78.885  45.632  1
103556  97.876  -78.890  45.620  1
103557  97.897  -78.897  45.609  1
103558  97.926  -78.906  45.596  1
103559  97.955  -78.915  45.582  1
103560  97.984  -78.924  45.569  1
103561  98.012  -78.933  45.555  1
103562  98.041  -78.943  45.539  1
103563  98.070  -78.952  45.523  1
103564  98.096  -78.960  45.505  1
103565  98.111  -78.965  45.484  1
103566  98.127  -78.971  45.464  1
103567  98.142  -78.976  45.446  1
103568  98.151  -78.985  45.429  1
103569  98.156  -78.996  45.414  1
103570  98.161  -79.007  45.400  1
103571  98.166  -79.018  45.386  1
103572  98.171  -79.029  45.373  1
103573  98.182  -79.043  45.360  1
103574  98.202  -79.063  45.348  1
103575  98.222  -79.079  45.336  1
103576  98.240  -79.073  45.325  1
103577  98.257  -79.067  45.315  1
103578  98.270  -79.054  45.305  1
103579  98.282  -79.038  45.295  1
103580  98.312  -79.043  45.285  1
103581  98.343  -79.046  45.274  1
103582  98.373  -79.051  45.263  1
103583  98.403  -79.055  45.249  1
103584  98.433  -79.059  45.236  1
103585  98.467  -79.068  45.224  1
103586  98.501  -79.077  45.212  1
103587  98.535  -79.085  45.200  1
103588  98.570  -79.094  45.188  1
103589  98.603  -79.103  45.177  1
103590  98.638  -79.112  45.166  1
103591  98.671  -79.121  45.155  1
103592  98.706  -79.129  45.144  1
103593  98.740  -79.138  45.133  1
103594  98.764  -79.145  45.122  1
103595  98.788  -79.151  45.112  1
103596  98.812  -79.158  45.101  1
103597  98.836  -79.164  45.091  1
103598  98.860  -79.171  45.081  1
103599  98.884  -79.178  45.070  1
103600  98.908  -79.184  45.061  1
103601  98.924  -79.188  45.050  1
103602  98.937  -79.192  45.040  1
103603  98.950  -79.197  45.028  1
103604  98.963  -79.200  45.018  1
103605  98.977  -79.204  45.008  1
103606  98.999  -79.219  44.998  1
103607  98.961  -79.212  44.988  1
103608  99.025  -79.227  44.978  1
103609  99.042  -79.214  44.968  1
103610  99.064  -79.220  44.957  1
103611  99.088  -79.237  44.946  1
103612  99.112  -79.256  44.935  1
103613  99.136  -79.273  44.925  1
103614  99.159  -79.291  44.915  1
103615  99.184  -79.308  44.906  1
103616  99.199  -79.324  44.897  1
103617  99.208  -79.339  44.888  1
103618  99.222  -79.351  44.879  1
103619  99.244  -79.359  44.871  1
103620  99.266  -79.367  44.864  1
103621  99.288  -79.375  44.858  1
103622  99.309  -79.384  44.852  1
103623  99.332  -79.392  44.846  1
103624  99.353  -79.400  44.839  1
103625  99.375  -79.409  44.834  1
103626  99.397  -79.417  44.828  1
103627  99.419  -79.426  44.823  1
103628  99.442  -79.440  44.818  1
103629  99.465  -79.455  44.814  1
103630  99.488  -79.470  44.809  1
103631  99.512  -79.485  44.806  1
103632  99.542  -79.488  44.802  1
103633  99.572  -79.492  44.799  1
103634  99.603  -79.496  44.796  1
103635  99.633  -79.500  44.792  1
103636  99.662  -79.503  44.789  1
103637  99.693  -79.507  44.787  1
103638  99.723  -79.510  44.783  1
103639  99.753  -79.514  44.781  1
103640  99.783  -79.518  44.779  1
103641  99.811  -79.522  44.776  1
103642  99.837  -79.526  44.771  1
103643  99.863  -79.531  44.766  1
103644  99.889  -79.535  44.761  1
103645  99.915  -79.541  44.756  1
103646  99.941  -79.548  44.751  1
103647  99.976  -79.581  44.745  1
103648  100.009  -79.631  44.738  1
103649  100.042  -79.686  44.731  1
103650  100.079  -79.708  44.722  1
103651  100.104  -79.735  44.714  1
103652  100.129  -79.762  44.706  1
103653  100.154  -79.789  44.699  1
103654  100.179  -79.816  44.693  1
103655  100.204  -79.842  44.690  1
103656  100.229  -79.870  44.687  1
103657  100.253  -79.899  44.681  1
103658  100.275  -79.937  44.674  1
103659  100.300  -79.971  44.663  1
103660  100.337  -79.976  44.652  1
103661  100.374  -79.981  44.641  1
103662  100.411  -79.986  44.629  1
103663  100.446  -80.012  44.616  1
103664  100.480  -80.040  44.603  1
103665  100.515  -80.067  44.589  1
103666  100.550  -80.095  44.572  1
103667  100.584  -80.122  44.557  1
103668  100.619  -80.150  44.542  1
103669  100.639  -80.184  44.526  1
103670  100.636  -80.228  44.510  1
103671  100.641  -80.270  44.494  1
103672  100.666  -80.305  44.477  1
103673  100.691  -80.340  44.461  1
103674  100.716  -80.375  44.444  1
103675  100.743  -80.410  44.428  1
103676  100.771  -80.446  44.411  1
103677  100.799  -80.483  44.393  1
103678  100.828  -80.519  44.376  1
103679  100.856  -80.556  44.358  1
103680  100.885  -80.592  44.340  1
103681  100.913  -80.629  44.322  1
103682  100.942  -80.665  44.303  1
103683  100.977  -80.693  44.284  1
103684  101.023  -80.706  44.264  1
103685  101.070  -80.719  44.244  1
103686  101.116  -80.732  44.224  1
103687  101.162  -80.745  44.203  1
103688  101.209  -80.757  44.185  1
103689  101.256  -80.770  44.168  1
103690  101.296  -80.785  44.151  1
103691  101.329  -80.801  44.133  1
103692  101.361  -80.817  44.116  1
103693  101.394  -80.833  44.100  1
103694  101.427  -80.848  44.084  1
103695  101.460  -80.865  44.067  1
103696  101.492  -80.881  44.051  1
103953  93.496  -78.482  53.848  1
103954  93.506  -78.479  53.833  1
103955  93.515  -78.477  53.816  1
103956  93.525  -78.475  53.797  1
103957  93.535  -78.473  53.777  1
103958  93.545  -78.470  53.757  1
103959  93.550  -78.464  53.736  1
103960  93.549  -78.455  53.715  1
103961  93.547  -78.446  53.693  1
103962  93.546  -78.437  53.670  1
103963  93.547  -78.426  53.645  1
103964  93.558  -78.410  53.620  1
103965  93.571  -78.395  53.595  1
103966  93.593  -78.380  53.571  1
103967  93.616  -78.365  53.547  1
103968  93.635  -78.352  53.524  1
103969  93.646  -78.344  53.502  1
103970  93.658  -78.335  53.480  1
103971  93.670  -78.327  53.459  1
103986  93.897  -78.216  53.155  1
103987  93.913  -78.209  53.136  1
103988  93.927  -78.203  53.114  1
103989  93.940  -78.198  53.094  1
103990  93.953  -78.194  53.074  1
103991  93.966  -78.190  53.054  1
103992  93.966  -78.188  53.035  1
103993  93.966  -78.192  53.018  1
103994  93.970  -78.203  53.001  1
103995  93.973  -78.213  52.986  1
103996  93.977  -78.223  52.970  1
103997  93.980  -78.234  52.954  1
103998  93.983  -78.244  52.939  1
103999  93.987  -78.254  52.922  1
104000  93.990  -78.264  52.904  1
104001  93.994  -78.275  52.885  1
104002  93.997  -78.285  52.867  1
104003  94.000  -78.295  52.849  1
104004  94.004  -78.306  52.829  1
104005  94.007  -78.316  52.807  1
104006  94.011  -78.326  52.787  1
104007  94.014  -78.336  52.769  1
104008  94.017  -78.347  52.754  1
104009  94.021  -78.357  52.741  1
104010  94.025  -78.367  52.727  1
104011  94.032  -78.374  52.711  1
104012  94.042  -78.371  52.693  1
104013  94.053  -78.369  52.676  1
104014  94.065  -78.366  52.658  1
104015  94.076  -78.363  52.641  1
104016  94.088  -78.360  52.627  1
104017  94.100  -78.357  52.611  1
104018  94.112  -78.354  52.594  1
104019  94.124  -78.350  52.575  1
104020  94.130  -78.339  52.556  1
104021  94.131  -78.319  52.536  1
104022  94.146  -78.315  52.515  1
104023  94.164  -78.313  52.494  1
104024  94.181  -78.313  52.471  1
104025  94.197  -78.309  52.447  1
104026  94.210  -78.301  52.422  1
104027  94.224  -78.294  52.395  1
104028  94.238  -78.286  52.368  1
104029  94.252  -78.279  52.340  1
104030  94.265  -78.271  52.310  1
104031  94.279  -78.263  52.279  1
104032  94.292  -78.256  52.245  1
104033  94.307  -78.249  52.208  1
104034  94.321  -78.241  52.166  1
104035  94.341  -78.231  52.121  1
104036  94.362  -78.220  52.075  1
104037  94.383  -78.210  52.034  1
104038  94.404  -78.200  51.996  1
104039  94.424  -78.191  51.962  1
104040  94.445  -78.181  51.932  1
104041  94.470  -78.176  51.900  1
104042  94.507  -78.192  51.865  1
104043  94.545  -78.209  51.826  1
104044  94.582  -78.225  51.786  1
104045  94.620  -78.241  51.742  1
104046  94.656  -78.257  51.698  1
104047  94.666  -78.250  51.654  1
104048  94.674  -78.242  51.613  1
104049  94.682  -78.233  51.573  1
104050  94.690  -78.224  51.536  1
104051  94.698  -78.216  51.500  1
104052  94.706  -78.206  51.463  1
104053  94.715  -78.197  51.426  1
104054  94.721  -78.193  51.389  1
104055  94.725  -78.196  51.354  1
104056  94.737  -78.194  51.319  1
104057  94.749  -78.191  51.284  1
104058  94.760  -78.188  51.250  1
104059  94.772  -78.190  51.215  1
104060  94.784  -78.194  51.179  1
104061  94.796  -78.200  51.143  1
104062  94.809  -78.204  51.107  1
104063  94.821  -78.210  51.071  1
104064  94.833  -78.214  51.035  1
104065  94.845  -78.219  51.000  1
104066  94.857  -78.224  50.962  1
104067  94.873  -78.229  50.924  1
104068  94.895  -78.226  50.886  1
104069  94.913  -78.209  50.849  1
104070  94.931  -78.191  50.811  1
104071  94.950  -78.174  50.772  1
104072  94.970  -78.153  50.734  1
104073  94.991  -78.131  50.696  1
104074  95.012  -78.110  50.658  1
104075  95.033  -78.090  50.620  1
104076  95.055  -78.069  50.583  1
104077  95.099  -78.063  50.547  1
104078  95.143  -78.057  50.512  1
104079  95.187  -78.052  50.477  1
104080  95.231  -78.046  50.441  1
104081  95.264  -78.044  50.405  1
104082  95.289  -78.046  50.371  1
104083  95.313  -78.048  50.336  1
104084  95.326  -78.048  50.302  1
104085  95.333  -78.047  50.269  1
104086  95.340  -78.047  50.237  1
104087  95.348  -78.046  50.205  1
104088  95.355  -78.044  50.173  1
104089  95.362  -78.044  50.143  1
104090  95.370  -78.043  50.114  1
104091  95.378  -78.042  50.085  1
104092  95.385  -78.041  50.057  1
104093  95.392  -78.040  50.029  1
104094  95.400  -78.036  50.000  1
104095  95.411  -78.044  49.971  1
104096  95.422  -78.056  49.943  1
104097  95.427  -78.061  49.917  1
104098  95.433  -78.065  49.891  1
104099  95.439  -78.071  49.866  1
104100  95.445  -78.076  49.843  1
104101  95.450  -78.081  49.821  1
104102  95.456  -78.086  49.799  1
104103  95.461  -78.090  49.775  1
104104  95.467  -78.094  49.750  1
104105  95.473  -78.098  49.724  1
104106  95.478  -78.099  49.698  1
104107  95.482  -78.094  49.670  1
104108  95.488  -78.089  49.642  1
104109  95.499  -78.081  49.612  1
104110  95.511  -78.074  49.581  1
104111  95.522  -78.067  49.547  1
104112  95.520  -78.084  49.511  1
104113  95.531  -78.090  49.473  1
104114  95.541  -78.096  49.433  1
104115  95.551  -78.101  49.392  1
104116  95.562  -78.107  49.352  1
104117  95.572  -78.113  49.312  1
104118  95.583  -78.119  49.270  1
104119  95.593  -78.125  49.228  1
104120  95.604  -78.131  49.185  1
104121  95.614  -78.136  49.142  1
104122  95.624  -78.142  49.099  1
104123  95.635  -78.148  49.056  1
104124  95.644  -78.153  49.013  1
104125  95.653  -78.158  48.970  1
104126  95.650  -78.140  48.928  1
104127  95.662  -78.119  48.886  1
104128  95.678  -78.112  48.843  1
104129  95.698  -78.118  48.803  1
104130  95.718  -78.139  48.764  1
104131  95.735  -78.161  48.725  1
104132  95.751  -78.177  48.685  1
104133  95.767  -78.193  48.646  1
104134  95.783  -78.209  48.606  1
104135  95.799  -78.225  48.567  1
104136  95.811  -78.230  48.529  1
104137  95.818  -78.225  48.492  1
104138  95.821  -78.218  48.455  1
104139  95.823  -78.208  48.417  1
104140  95.820  -78.204  48.380  1
104141  95.834  -78.196  48.343  1
104142  95.851  -78.196  48.305  1
104143  95.871  -78.198  48.266  1
104144  95.890  -78.200  48.228  1
104145  95.909  -78.202  48.190  1
104146  95.929  -78.204  48.151  1
104147  95.948  -78.207  48.112  1
104148  95.966  -78.210  48.074  1
104149  95.984  -78.213  48.036  1
104150  96.002  -78.217  48.001  1
104151  96.015  -78.224  47.965  1
104152  96.030  -78.232  47.929  1
104153  96.050  -78.240  47.894  1
104154  96.065  -78.255  47.861  1
104155  96.078  -78.272  47.827  1
104156  96.091  -78.290  47.794  1
104157  96.103  -78.307  47.762  1
104158  96.116  -78.324  47.731  1
104159  96.130  -78.332  47.700  1
104160  96.145  -78.339  47.668  1
104161  96.156  -78.341  47.638  1
104162  96.174  -78.356  47.608  1
104163  96.194  -78.375  47.577  1
104164  96.214  -78.394  47.547  1
104165  96.221  -78.405  47.518  1
104166  96.223  -78.414  47.491  1
104167  96.225  -78.423  47.463  1
104168  96.225  -78.433  47.434  1
104169  96.253  -78.438  47.407  1
104170  96.286  -78.443  47.380  1
104171  96.317  -78.448  47.354  1
104172  96.350  -78.452  47.328  1
104173  96.384  -78.456  47.302  1
104174  96.419  -78.460  47.275  1
104175  96.453  -78.463  47.246  1
104176  96.488  -78.467  47.217  1
104177  96.523  -78.472  47.187  1
104178  96.555  -78.473  47.160  1
104179  96.586  -78.473  47.133  1
104180  96.616  -78.472  47.107  1
104181  96.647  -78.471  47.080  1
104182  96.661  -78.476  47.054  1
104183  96.664  -78.485  47.027  1
104184  96.668  -78.494  47.000  1
104185  96.653  -78.496  46.976  1
104186  96.638  -78.498  46.952  1
104187  96.644  -78.508  46.928  1
104188  96.651  -78.517  46.904  1
104189  96.657  -78.526  46.880  1
104190  96.669  -78.533  46.854  1
104191  96.681  -78.539  46.829  1
104192  96.694  -78.545  46.806  1
104193  96.707  -78.551  46.782  1
104194  96.720  -78.557  46.759  1
104195  96.732  -78.563  46.735  1
104196  96.747  -78.589  46.713  1
104197  96.766  -78.620  46.690  1
104198  96.786  -78.651  46.668  1
104199  96.805  -78.682  46.649  1
104200  96.825  -78.712  46.629  1
104201  96.844  -78.743  46.608  1
104202  96.864  -78.774  46.587  1
104203  96.883  -78.805  46.567  1
104204  96.902  -78.836  46.546  1
104205  96.922  -78.868  46.525  1
104206  96.941  -78.898  46.506  1
104207  96.961  -78.929  46.487  1
104208  96.980  -78.952  46.467  1
104209  97.002  -78.966  46.449  1
104210  97.026  -78.968  46.430  1
104211  97.048  -78.962  46.410  1
104212  97.084  -78.965  46.389  1
104213  97.119  -78.962  46.370  1
104214  97.154  -78.959  46.350  1
104215  97.188  -78.956  46.329  1
104216  97.223  -78.953  46.308  1
104217  97.257  -78.949  46.286  1
104218  97.292  -78.946  46.265  1
104219  97.327  -78.943  46.244  1
104220  97.362  -78.940  46.226  1
104221  97.396  -78.937  46.206  1
104222  97.431  -78.933  46.187  1
104223  97.465  -78.930  46.170  1
104224  97.500  -78.927  46.152  1
104225  97.535  -78.924  46.133  1
104226  97.559  -78.920  46.114  1
104227  97.576  -78.917  46.096  1
104228  97.594  -78.913  46.079  1
104229  97.612  -78.910  46.061  1
104230  97.630  -78.906  46.043  1
104231  97.648  -78.903  46.024  1
104232  97.665  -78.899  46.006  1
104233  97.683  -78.896  45.988  1
104234  97.701  -78.893  45.972  1
104235  97.719  -78.890  45.955  1
104236  97.737  -78.886  45.939  1
104237  97.754  -78.883  45.924  1
104238  97.773  -78.879  45.908  1
104239  97.790  -78.876  45.892  1
104240  97.808  -78.873  45.876  1
104241  97.814  -78.858  45.860  1
104242  97.816  -78.837  45.844  1
104243  97.819  -78.816  45.827  1
104244  97.821  -78.795  45.811  1
104245  97.823  -78.774  45.794  1
104246  97.826  -78.752  45.777  1
104247  97.827  -78.731  45.760  1
104248  97.828  -78.747  45.744  1
104249  97.829  -78.782  45.730  1
104250  97.830  -78.817  45.716  1
104251  97.831  -78.851  45.703  1
104252  97.838  -78.857  45.690  1
104253  97.846  -78.861  45.678  1
104254  97.853  -78.866  45.665  1
104255  97.861  -78.871  45.654  1
104256  97.871  -78.877  45.641  1
104257  97.900  -78.886  45.628  1
104258  97.929  -78.895  45.614  1
104259  97.957  -78.904  45.601  1
104260  97.986  -78.913  45.587  1
104261  98.015  -78.922  45.573  1
104262  98.043  -78.931  45.559  1
104263  98.072  -78.940  45.542  1
104264  98.101  -78.949  45.524  1
104265  98.130  -78.958  45.506  1
104266  98.149  -78.965  45.487  1
104267  98.163  -78.971  45.469  1
104268  98.168  -78.982  45.452  1
104269  98.173  -78.993  45.437  1
104270  98.178  -79.004  45.422  1
104271  98.184  -79.015  45.407  1
104272  98.189  -79.026  45.392  1
104273  98.194  -79.037  45.380  1
104274  98.203  -79.050  45.367  1
104275  98.223  -79.069  45.355  1
104276  98.242  -79.073  45.344  1
104277  98.260  -79.067  45.333  1
104278  98.277  -79.062  45.322  1
104279  98.292  -79.052  45.312  1
104280  98.295  -79.026  45.301  1
104281  98.323  -79.028  45.291  1
104282  98.354  -79.032  45.280  1
104283  98.384  -79.037  45.268  1
104284  98.414  -79.040  45.255  1
104285  98.445  -79.046  45.242  1
104286  98.480  -79.055  45.230  1
104287  98.514  -79.063  45.218  1
104288  98.548  -79.072  45.205  1
104289  98.582  -79.081  45.193  1
104290  98.616  -79.090  45.182  1
104291  98.650  -79.099  45.171  1
104292  98.684  -79.107  45.160  1
104293  98.715  -79.115  45.149  1
104294  98.739  -79.122  45.137  1
104295  98.763  -79.128  45.126  1
104296  98.787  -79.135  45.116  1
104297  98.811  -79.141  45.105  1
104298  98.835  -79.148  45.095  1
104299  98.859  -79.155  45.084  1
104300  98.882  -79.161  45.073  1
104301  98.907  -79.168  45.062  1
104302  98.925  -79.173  45.051  1
104303  98.938  -79.177  45.040  1
104304  98.951  -79.181  45.029  1
104305  98.965  -79.184  45.018  1
104306  98.983  -79.195  45.007  1
104307  99.010  -79.217  44.996  1
104308  99.034  -79.237  44.986  1
104309  99.052  -79.228  44.975  1
104310  99.070  -79.214  44.965  1
104311  99.087  -79.200  44.955  1
104312  99.108  -79.203  44.944  1
104313  99.132  -79.222  44.934  1
104314  99.156  -79.239  44.925  1
104315  99.180  -79.256  44.915  1
104316  99.204  -79.274  44.906  1
104317  99.217  -79.290  44.897  1
104318  99.226  -79.304  44.888  1
104319  99.235  -79.319  44.880  1
104320  99.252  -79.330  44.873  1
104321  99.274  -79.338  44.867  1
104322  99.295  -79.347  44.861  1
104323  99.317  -79.355  44.855  1
104324  99.339  -79.363  44.849  1
104325  99.361  -79.372  44.843  1
104326  99.383  -79.380  44.838  1
104327  99.405  -79.390  44.834  1
104328  99.428  -79.406  44.829  1
104329  99.451  -79.421  44.826  1
104330  99.475  -79.437  44.822  1
104331  99.498  -79.452  44.818  1
104332  99.522  -79.466  44.815  1
104333  99.552  -79.469  44.812  1
104334  99.582  -79.473  44.809  1
104335  99.613  -79.476  44.805  1
104336  99.643  -79.480  44.803  1
104337  99.673  -79.484  44.800  1
104338  99.703  -79.488  44.798  1
104339  99.731  -79.491  44.795  1
104340  99.757  -79.496  44.793  1
104341  99.783  -79.501  44.789  1
104342  99.808  -79.505  44.786  1
104343  99.835  -79.510  44.781  1
104344  99.860  -79.515  44.777  1
104345  99.886  -79.520  44.772  1
104346  99.912  -79.524  44.767  1
104347  99.943  -79.547  44.762  1
104348  99.977  -79.579  44.756  1
104349  100.010  -79.629  44.750  1
104350  100.044  -79.683  44.741  1
104351  100.081  -79.701  44.733  1
104352  100.114  -79.720  44.724  1
104353  100.139  -79.746  44.715  1
104354  100.164  -79.773  44.707  1
104355  100.189  -79.800  44.701  1
104356  100.214  -79.827  44.698  1
104357  100.239  -79.854  44.692  1
104358  100.263  -79.886  44.685  1
104359  100.285  -79.925  44.677  1
104360  100.307  -79.964  44.666  1
104361  100.343  -79.971  44.656  1
104362  100.380  -79.976  44.644  1
104363  100.417  -79.981  44.632  1
104364  100.454  -79.986  44.620  1
104365  100.489  -80.012  44.607  1
104366  100.523  -80.040  44.592  1
104367  100.558  -80.067  44.576  1
104368  100.593  -80.095  44.560  1
104369  100.627  -80.122  44.544  1
104370  100.651  -80.154  44.528  1
104371  100.648  -80.199  44.512  1
104372  100.658  -80.239  44.496  1
104373  100.684  -80.274  44.480  1
104374  100.709  -80.309  44.464  1
104375  100.734  -80.344  44.448  1
104376  100.763  -80.380  44.432  1
104377  100.791  -80.416  44.415  1
104378  100.820  -80.453  44.397  1
104379  100.848  -80.489  44.380  1
104380  100.876  -80.526  44.362  1
104381  100.905  -80.562  44.344  1
104382  100.933  -80.598  44.326  1
104383  100.962  -80.635  44.308  1
104384  100.990  -80.672  44.289  1
104385  101.028  -80.696  44.270  1
104386  101.074  -80.709  44.251  1
104387  101.120  -80.722  44.231  1
104388  101.167  -80.735  44.210  1
104389  101.213  -80.748  44.192  1
104390  101.252  -80.763  44.174  1
104391  101.285  -80.779  44.156  1
104392  101.318  -80.795  44.139  1
104393  101.350  -80.811  44.122  1
104394  101.383  -80.826  44.106  1
104395  101.416  -80.843  44.090  1
104396  101.449  -80.859  44.073  1
104397  101.481  -80.875  44.057  1
104398  101.514  -80.891  44.041  1
104654  93.496  -78.471  53.847  1
104655  93.506  -78.469  53.831  1
104656  93.516  -78.467  53.814  1
104657  93.525  -78.464  53.796  1
104658  93.535  -78.461  53.775  1
104659  93.545  -78.459  53.754  1
104660  93.547  -78.451  53.733  1
104661  93.545  -78.442  53.711  1
104662  93.544  -78.433  53.688  1
104663  93.543  -78.424  53.664  1
104664  93.549  -78.410  53.640  1
104665  93.559  -78.395  53.615  1
104666  93.576  -78.380  53.590  1
104667  93.599  -78.365  53.565  1
104668  93.621  -78.350  53.541  1
104669  93.636  -78.339  53.518  1
104670  93.648  -78.331  53.495  1
104671  93.659  -78.322  53.473  1
104672  93.671  -78.314  53.452  1
104687  93.899  -78.203  53.145  1
104688  93.915  -78.196  53.123  1
104689  93.928  -78.191  53.102  1
104690  93.940  -78.187  53.081  1
104691  93.954  -78.183  53.060  1
104692  93.966  -78.178  53.040  1
104693  93.967  -78.177  53.020  1
104694  93.966  -78.179  53.001  1
104695  93.969  -78.189  52.983  1
104696  93.973  -78.200  52.964  1
104697  93.976  -78.210  52.946  1
104698  93.979  -78.220  52.928  1
104699  93.983  -78.231  52.908  1
104700  93.986  -78.241  52.889  1
104701  93.990  -78.251  52.870  1
104702  93.993  -78.261  52.851  1
104703  93.996  -78.272  52.833  1
104704  94.000  -78.282  52.814  1
104705  94.003  -78.292  52.794  1
104706  94.007  -78.303  52.772  1
104707  94.010  -78.313  52.751  1
104708  94.013  -78.323  52.732  1
104709  94.017  -78.333  52.717  1
104710  94.020  -78.344  52.703  1
104711  94.024  -78.354  52.687  1
104712  94.033  -78.357  52.670  1
104713  94.052  -78.351  52.652  1
104714  94.063  -78.348  52.633  1
104715  94.073  -78.345  52.615  1
104716  94.083  -78.342  52.598  1
104717  94.094  -78.340  52.582  1
104718  94.105  -78.337  52.565  1
104719  94.115  -78.335  52.546  1
104720  94.126  -78.332  52.527  1
104721  94.137  -78.328  52.508  1
104722  94.151  -78.320  52.487  1
104723  94.165  -78.313  52.465  1
104724  94.178  -78.305  52.445  1
104725  94.192  -78.297  52.422  1
104726  94.206  -78.290  52.398  1
104727  94.219  -78.282  52.373  1
104728  94.233  -78.275  52.346  1
104729  94.247  -78.267  52.318  1
104730  94.261  -78.260  52.288  1
104731  94.274  -78.252  52.256  1
104732  94.288  -78.244  52.222  1
104733  94.301  -78.237  52.187  1
104734  94.316  -78.229  52.149  1
104735  94.323  -78.224  52.109  1
104736  94.344  -78.214  52.068  1
104737  94.365  -78.203  52.027  1
104738  94.386  -78.194  51.992  1
104739  94.406  -78.184  51.958  1
104740  94.427  -78.174  51.927  1
104741  94.448  -78.163  51.900  1
104742  94.468  -78.153  51.868  1
104743  94.503  -78.168  51.833  1
104744  94.540  -78.184  51.794  1
104745  94.578  -78.200  51.753  1
104746  94.615  -78.216  51.712  1
104747  94.653  -78.232  51.671  1
104748  94.666  -78.232  51.630  1
104749  94.674  -78.223  51.592  1
104750  94.682  -78.215  51.556  1
104751  94.690  -78.206  51.520  1
104752  94.698  -78.197  51.484  1
104753  94.706  -78.188  51.448  1
104754  94.715  -78.179  51.413  1
104755  94.721  -78.173  51.378  1
104756  94.723  -78.179  51.343  1
104757  94.735  -78.176  51.309  1
104758  94.746  -78.174  51.275  1
104759  94.758  -78.171  51.240  1
104760  94.770  -78.172  51.205  1
104761  94.782  -78.177  51.170  1
104762  94.794  -78.182  51.134  1
104763  94.806  -78.187  51.099  1
104764  94.818  -78.192  51.064  1
104765  94.830  -78.197  51.028  1
104766  94.842  -78.202  50.993  1
104767  94.854  -78.206  50.956  1
104768  94.876  -78.213  50.919  1
104769  94.897  -78.207  50.880  1
104770  94.915  -78.191  50.843  1
104771  94.933  -78.173  50.806  1
104772  94.951  -78.156  50.769  1
104773  94.970  -78.139  50.731  1
104774  94.990  -78.118  50.693  1
104775  95.011  -78.097  50.656  1
104776  95.032  -78.076  50.618  1
104777  95.053  -78.055  50.582  1
104778  95.089  -78.044  50.547  1
104779  95.133  -78.037  50.512  1
104780  95.177  -78.032  50.478  1
104781  95.221  -78.026  50.442  1
104782  95.248  -78.028  50.407  1
104783  95.272  -78.029  50.373  1
104784  95.297  -78.031  50.339  1
104785  95.321  -78.033  50.306  1
104786  95.330  -78.033  50.275  1
104787  95.337  -78.031  50.242  1
104788  95.344  -78.031  50.211  1
104789  95.352  -78.030  50.180  1
104790  95.359  -78.029  50.151  1
104791  95.367  -78.028  50.123  1
104792  95.374  -78.027  50.095  1
104793  95.382  -78.026  50.067  1
104794  95.389  -78.024  50.039  1
104795  95.397  -78.019  50.010  1
104796  95.407  -78.025  49.983  1
104797  95.418  -78.037  49.956  1
104798  95.430  -78.049  49.931  1
104799  95.436  -78.054  49.908  1
104800  95.441  -78.059  49.885  1
104801  95.447  -78.064  49.865  1
104802  95.453  -78.069  49.845  1
104803  95.458  -78.075  49.823  1
104804  95.464  -78.079  49.800  1
104805  95.469  -78.084  49.774  1
104806  95.474  -78.089  49.746  1
104807  95.487  -78.085  49.718  1
104808  95.498  -78.078  49.687  1
104809  95.510  -78.071  49.656  1
104810  95.521  -78.063  49.623  1
104811  95.532  -78.056  49.589  1
104812  95.543  -78.049  49.552  1
104813  95.543  -78.054  49.514  1
104814  95.541  -78.079  49.475  1
104815  95.552  -78.085  49.433  1
104816  95.562  -78.091  49.391  1
104817  95.572  -78.097  49.350  1
104818  95.583  -78.103  49.309  1
104819  95.594  -78.109  49.268  1
104820  95.604  -78.114  49.226  1
104821  95.614  -78.120  49.184  1
104822  95.625  -78.126  49.142  1
104823  95.635  -78.131  49.100  1
104824  95.645  -78.138  49.058  1
104825  95.656  -78.144  49.016  1
104826  95.664  -78.128  48.974  1
104827  95.670  -78.126  48.932  1
104828  95.684  -78.109  48.890  1
104829  95.696  -78.088  48.848  1
104830  95.711  -78.089  48.808  1
104831  95.729  -78.116  48.768  1
104832  95.745  -78.131  48.728  1
104833  95.761  -78.147  48.688  1
104834  95.777  -78.163  48.649  1
104835  95.794  -78.178  48.610  1
104836  95.809  -78.194  48.571  1
104837  95.825  -78.210  48.535  1
104838  95.836  -78.216  48.499  1
104839  95.833  -78.213  48.463  1
104840  95.827  -78.216  48.426  1
104841  95.826  -78.216  48.389  1
104842  95.852  -78.201  48.351  1
104843  95.871  -78.190  48.313  1
104844  95.879  -78.183  48.275  1
104845  95.895  -78.181  48.237  1
104846  95.914  -78.184  48.199  1
104847  95.934  -78.186  48.161  1
104848  95.953  -78.188  48.124  1
104849  95.971  -78.191  48.086  1
104850  95.989  -78.195  48.049  1
104851  96.001  -78.202  48.013  1
104852  96.014  -78.210  47.978  1
104853  96.030  -78.217  47.943  1
104854  96.050  -78.225  47.909  1
104855  96.070  -78.234  47.876  1
104856  96.084  -78.250  47.843  1
104857  96.096  -78.267  47.810  1
104858  96.109  -78.285  47.778  1
104859  96.123  -78.297  47.747  1
104860  96.137  -78.305  47.715  1
104861  96.153  -78.313  47.684  1
104862  96.165  -78.316  47.654  1
104863  96.184  -78.335  47.623  1
104864  96.204  -78.354  47.593  1
104865  96.225  -78.373  47.564  1
104866  96.244  -78.391  47.536  1
104867  96.251  -78.403  47.508  1
104868  96.253  -78.411  47.480  1
104869  96.253  -78.423  47.453  1
104870  96.259  -78.432  47.425  1
104871  96.292  -78.437  47.398  1
104872  96.324  -78.442  47.373  1
104873  96.358  -78.445  47.347  1
104874  96.392  -78.449  47.321  1
104875  96.427  -78.454  47.293  1
104876  96.461  -78.457  47.265  1
104877  96.491  -78.457  47.236  1
104878  96.522  -78.456  47.208  1
104879  96.552  -78.455  47.181  1
104880  96.583  -78.454  47.154  1
104881  96.613  -78.454  47.128  1
104882  96.641  -78.454  47.102  1
104883  96.645  -78.462  47.075  1
104884  96.649  -78.471  47.048  1
104885  96.652  -78.480  47.022  1
104886  96.656  -78.489  46.998  1
104887  96.644  -78.492  46.973  1
104888  96.638  -78.498  46.949  1
104889  96.644  -78.507  46.925  1
104890  96.652  -78.516  46.901  1
104891  96.664  -78.522  46.876  1
104892  96.677  -78.528  46.850  1
104893  96.690  -78.533  46.826  1
104894  96.702  -78.539  46.803  1
104895  96.716  -78.545  46.779  1
104896  96.728  -78.551  46.754  1
104897  96.742  -78.570  46.731  1
104898  96.761  -78.601  46.708  1
104899  96.781  -78.633  46.686  1
104900  96.800  -78.664  46.666  1
104901  96.819  -78.695  46.645  1
104902  96.838  -78.726  46.625  1
104903  96.857  -78.757  46.603  1
104904  96.876  -78.788  46.581  1
104905  96.895  -78.819  46.560  1
104906  96.914  -78.850  46.540  1
104907  96.934  -78.881  46.520  1
104908  96.952  -78.912  46.501  1
104909  96.971  -78.943  46.480  1
104910  96.996  -78.964  46.460  1
104911  96.989  -78.888  46.440  1
104912  97.034  -78.937  46.419  1
104913  97.072  -78.952  46.398  1
104914  97.107  -78.949  46.378  1
104915  97.142  -78.946  46.357  1
104916  97.176  -78.943  46.336  1
104917  97.212  -78.940  46.315  1
104918  97.246  -78.937  46.294  1
104919  97.281  -78.933  46.272  1
104920  97.316  -78.930  46.251  1
104921  97.351  -78.927  46.232  1
104922  97.383  -78.924  46.212  1
104923  97.414  -78.921  46.193  1
104924  97.445  -78.919  46.176  1
104925  97.475  -78.917  46.157  1
104926  97.529  -78.915  46.138  1
104927  97.565  -78.903  46.120  1
104928  97.566  -78.904  46.103  1
104929  97.584  -78.901  46.086  1
104930  97.602  -78.897  46.068  1
104931  97.621  -78.894  46.051  1
104932  97.640  -78.891  46.035  1
104933  97.658  -78.888  46.018  1
104934  97.676  -78.884  45.999  1
104935  97.695  -78.881  45.981  1
104936  97.713  -78.878  45.964  1
104937  97.731  -78.875  45.948  1
104938  97.750  -78.872  45.933  1
104939  97.768  -78.868  45.918  1
104940  97.781  -78.858  45.902  1
104941  97.805  -78.844  45.886  1
104942  97.813  -78.827  45.870  1
104943  97.820  -78.811  45.855  1
104944  97.825  -78.792  45.839  1
104945  97.827  -78.771  45.822  1
104946  97.830  -78.749  45.806  1
104947  97.832  -78.728  45.790  1
104948  97.834  -78.707  45.774  1
104949  97.835  -78.710  45.757  1
104950  97.836  -78.744  45.742  1
104951  97.837  -78.779  45.729  1
104952  97.837  -78.813  45.717  1
104953  97.838  -78.848  45.704  1
104954  97.846  -78.852  45.691  1
104955  97.853  -78.858  45.678  1
104956  97.874  -78.865  45.666  1
104957  97.902  -78.874  45.653  1
104958  97.931  -78.883  45.640  1
104959  97.960  -78.892  45.627  1
104960  97.989  -78.901  45.613  1
104961  98.017  -78.910  45.598  1
104962  98.046  -78.919  45.581  1
104963  98.075  -78.928  45.563  1
104964  98.103  -78.937  45.546  1
104965  98.131  -78.945  45.528  1
104966  98.158  -78.952  45.511  1
104967  98.178  -78.962  45.495  1
104968  98.186  -78.978  45.477  1
104969  98.191  -78.989  45.459  1
104970  98.196  -79.000  45.444  1
104971  98.201  -79.012  45.429  1
104972  98.207  -79.022  45.415  1
104973  98.212  -79.034  45.401  1
104974  98.217  -79.044  45.388  1
104975  98.224  -79.056  45.376  1
104976  98.244  -79.073  45.364  1
104977  98.262  -79.068  45.353  1
104978  98.279  -79.062  45.341  1
104979  98.297  -79.056  45.330  1
104980  98.313  -79.049  45.319  1
104981  98.317  -79.023  45.308  1
104982  98.335  -79.014  45.297  1
104983  98.365  -79.018  45.286  1
104984  98.395  -79.022  45.275  1
104985  98.426  -79.026  45.262  1
104986  98.458  -79.033  45.249  1
104987  98.492  -79.041  45.237  1
104988  98.526  -79.050  45.224  1
104989  98.560  -79.059  45.212  1
104990  98.594  -79.068  45.199  1
104991  98.628  -79.077  45.189  1
104992  98.662  -79.085  45.177  1
104993  98.690  -79.093  45.166  1
104994  98.714  -79.100  45.155  1
104995  98.738  -79.106  45.143  1
104996  98.762  -79.112  45.132  1
104997  98.786  -79.118  45.121  1
104998  98.809  -79.125  45.110  1
104999  98.834  -79.132  45.100  1
105000  98.857  -79.138  45.090  1
105001  98.881  -79.145  45.078  1
105002  98.905  -79.151  45.066  1
105003  98.926  -79.157  45.054  1
105004  98.939  -79.161  45.043  1
105005  98.952  -79.165  45.032  1
105006  98.967  -79.170  45.021  1
105007  98.994  -79.192  45.010  1
105008  99.021  -79.215  44.999  1
105009  99.047  -79.216  44.988  1
105010  99.073  -79.217  44.977  1
105011  99.097  -79.215  44.966  1
105012  99.114  -79.201  44.956  1
105013  99.132  -79.187  44.945  1
105014  99.152  -79.187  44.935  1
105015  99.175  -79.205  44.925  1
105016  99.200  -79.222  44.915  1
105017  99.223  -79.240  44.907  1
105018  99.236  -79.255  44.899  1
105019  99.244  -79.270  44.890  1
105020  99.254  -79.285  44.883  1
105021  99.263  -79.300  44.876  1
105022  99.281  -79.310  44.870  1
105023  99.303  -79.318  44.865  1
105024  99.325  -79.326  44.860  1
105025  99.347  -79.335  44.855  1
105026  99.369  -79.343  44.849  1
105027  99.392  -79.357  44.845  1
105028  99.415  -79.372  44.841  1
105029  99.438  -79.387  44.838  1
105030  99.461  -79.403  44.835  1
105031  99.484  -79.418  44.832  1
105032  99.507  -79.433  44.829  1
105033  99.533  -79.446  44.826  1
105034  99.562  -79.450  44.823  1
105035  99.592  -79.454  44.820  1
105036  99.623  -79.457  44.817  1
105037  99.650  -79.461  44.815  1
105038  99.677  -79.466  44.812  1
105039  99.702  -79.470  44.810  1
105040  99.728  -79.475  44.807  1
105041  99.754  -79.480  44.804  1
105042  99.780  -79.485  44.800  1
105043  99.806  -79.489  44.796  1
105044  99.832  -79.494  44.792  1
105045  99.858  -79.498  44.788  1
105046  99.884  -79.503  44.784  1
105047  99.911  -79.513  44.779  1
105048  99.945  -79.545  44.775  1
105049  99.979  -79.578  44.769  1
105050  100.012  -79.626  44.762  1
105051  100.045  -79.680  44.753  1
105052  100.083  -79.695  44.744  1
105053  100.123  -79.705  44.734  1
105054  100.149  -79.730  44.725  1
105055  100.174  -79.758  44.713  1
105056  100.199  -79.784  44.706  1
105057  100.223  -79.811  44.701  1
105058  100.249  -79.838  44.694  1
105059  100.272  -79.874  44.688  1
105060  100.294  -79.912  44.680  1
105061  100.316  -79.951  44.669  1
105062  100.349  -79.966  44.658  1
105063  100.385  -79.971  44.647  1
105064  100.423  -79.976  44.635  1
105065  100.460  -79.981  44.622  1
105066  100.497  -79.987  44.609  1
105067  100.531  -80.012  44.594  1
105068  100.566  -80.040  44.578  1
105069  100.601  -80.067  44.561  1
105070  100.635  -80.094  44.545  1
105071  100.664  -80.125  44.529  1
105072  100.660  -80.170  44.513  1
105073  100.676  -80.208  44.498  1
105074  100.701  -80.243  44.482  1
105075  100.726  -80.277  44.466  1
105076  100.754  -80.313  44.450  1
105077  100.782  -80.350  44.433  1
105078  100.811  -80.386  44.416  1
105079  100.839  -80.422  44.400  1
105080  100.868  -80.459  44.383  1
105081  100.896  -80.496  44.366  1
105082  100.924  -80.532  44.347  1
105083  100.953  -80.569  44.330  1
105084  100.981  -80.605  44.313  1
105085  101.010  -80.641  44.295  1
105086  101.038  -80.678  44.276  1
105087  101.078  -80.700  44.256  1
105088  101.124  -80.713  44.236  1
105089  101.171  -80.726  44.216  1
105090  101.208  -80.741  44.198  1
105091  101.241  -80.757  44.180  1
105092  101.273  -80.773  44.162  1
105093  101.306  -80.789  44.145  1
105094  101.339  -80.804  44.128  1
105095  101.372  -80.820  44.112  1
105096  101.405  -80.837  44.095  1
105097  101.438  -80.853  44.079  1
105098  101.470  -80.869  44.062  1
105099  101.503  -80.885  44.046  1
105355  93.497  -78.460  53.844  1
105356  93.506  -78.458  53.828  1
105357  93.516  -78.455  53.810  1
105358  93.526  -78.453  53.791  1
105359  93.536  -78.451  53.771  1
105360  93.544  -78.448  53.750  1
105361  93.543  -78.438  53.729  1
105362  93.542  -78.429  53.706  1
105363  93.541  -78.420  53.682  1
105364  93.540  -78.410  53.658  1
105365  93.550  -78.395  53.633  1
105366  93.560  -78.379  53.608  1
105367  93.581  -78.364  53.583  1
105368  93.604  -78.349  53.559  1
105369  93.626  -78.335  53.535  1
105370  93.637  -78.326  53.512  1
105371  93.649  -78.318  53.489  1
105372  93.660  -78.310  53.467  1
105373  93.672  -78.301  53.445  1
105388  93.901  -78.191  53.133  1
105389  93.915  -78.184  53.111  1
105390  93.928  -78.180  53.089  1
105391  93.941  -78.176  53.068  1
105392  93.954  -78.172  53.046  1
105393  93.967  -78.167  53.025  1
105394  93.967  -78.166  53.004  1
105395  93.965  -78.166  52.984  1
105396  93.969  -78.176  52.964  1
105397  93.972  -78.186  52.945  1
105398  93.976  -78.197  52.924  1
105399  93.979  -78.206  52.904  1
105400  93.982  -78.217  52.883  1
105401  93.986  -78.228  52.863  1
105402  93.989  -78.238  52.842  1
105403  93.993  -78.248  52.823  1
105404  93.996  -78.258  52.802  1
105405  93.999  -78.269  52.781  1
105406  94.003  -78.279  52.760  1
105407  94.006  -78.289  52.739  1
105408  94.010  -78.300  52.717  1
105409  94.013  -78.310  52.697  1
105410  94.016  -78.320  52.678  1
105411  94.020  -78.331  52.660  1
105412  94.024  -78.341  52.641  1
105413  94.035  -78.341  52.622  1
105414  94.059  -78.331  52.604  1
105415  94.073  -78.327  52.586  1
105416  94.083  -78.325  52.568  1
105417  94.094  -78.322  52.550  1
105418  94.104  -78.319  52.532  1
105419  94.115  -78.316  52.512  1
105420  94.125  -78.313  52.492  1
105421  94.136  -78.311  52.475  1
105422  94.146  -78.308  52.455  1
105423  94.160  -78.300  52.434  1
105424  94.174  -78.293  52.412  1
105425  94.187  -78.285  52.393  1
105426  94.201  -78.278  52.371  1
105427  94.215  -78.270  52.348  1
105428  94.228  -78.263  52.321  1
105429  94.242  -78.255  52.294  1
105430  94.256  -78.247  52.265  1
105431  94.270  -78.240  52.233  1
105432  94.283  -78.232  52.200  1
105433  94.297  -78.225  52.165  1
105434  94.311  -78.218  52.130  1
105435  94.325  -78.210  52.093  1
105436  94.333  -78.205  52.057  1
105437  94.346  -78.197  52.020  1
105438  94.367  -78.187  51.984  1
105439  94.388  -78.177  51.953  1
105440  94.409  -78.167  51.922  1
105441  94.429  -78.157  51.892  1
105442  94.450  -78.147  51.865  1
105443  94.471  -78.137  51.833  1
105444  94.498  -78.144  51.799  1
105445  94.536  -78.159  51.762  1
105446  94.573  -78.175  51.724  1
105447  94.611  -78.191  51.686  1
105448  94.648  -78.208  51.648  1
105449  94.665  -78.211  51.610  1
105450  94.674  -78.205  51.574  1
105451  94.682  -78.196  51.539  1
105452  94.690  -78.187  51.505  1
105453  94.698  -78.178  51.471  1
105454  94.707  -78.169  51.436  1
105455  94.715  -78.160  51.402  1
105456  94.722  -78.153  51.367  1
105457  94.722  -78.161  51.333  1
105458  94.732  -78.159  51.300  1
105459  94.744  -78.156  51.266  1
105460  94.755  -78.154  51.233  1
105461  94.767  -78.155  51.198  1
105462  94.779  -78.159  51.163  1
105463  94.791  -78.165  51.127  1
105464  94.804  -78.169  51.093  1
105465  94.816  -78.175  51.058  1
105466  94.828  -78.179  51.023  1
105467  94.840  -78.184  50.987  1
105468  94.853  -78.189  50.951  1
105469  94.878  -78.197  50.914  1
105470  94.899  -78.189  50.876  1
105471  94.917  -78.172  50.840  1
105472  94.935  -78.155  50.803  1
105473  94.954  -78.138  50.766  1
105474  94.972  -78.120  50.729  1
105475  94.990  -78.103  50.692  1
105476  95.010  -78.083  50.655  1
105477  95.031  -78.062  50.618  1
105478  95.052  -78.041  50.583  1
105479  95.079  -78.024  50.548  1
105480  95.123  -78.018  50.513  1
105481  95.167  -78.012  50.479  1
105482  95.207  -78.009  50.445  1
105483  95.231  -78.010  50.411  1
105484  95.255  -78.012  50.377  1
105485  95.279  -78.014  50.343  1
105486  95.304  -78.016  50.311  1
105487  95.326  -78.018  50.279  1
105488  95.334  -78.017  50.248  1
105489  95.341  -78.016  50.216  1
105490  95.348  -78.015  50.186  1
105491  95.356  -78.014  50.158  1
105492  95.364  -78.013  50.131  1
105493  95.371  -78.012  50.104  1
105494  95.378  -78.012  50.077  1
105495  95.386  -78.008  50.049  1
105496  95.394  -78.003  50.022  1
105497  95.403  -78.006  49.995  1
105498  95.414  -78.018  49.971  1
105499  95.426  -78.030  49.947  1
105500  95.438  -78.042  49.927  1
105501  95.444  -78.047  49.908  1
105502  95.449  -78.053  49.891  1
105503  95.455  -78.057  49.872  1
105504  95.459  -78.062  49.851  1
105505  95.460  -78.065  49.826  1
105506  95.461  -78.067  49.798  1
105507  95.463  -78.069  49.767  1
105508  95.494  -78.065  49.735  1
105509  95.520  -78.060  49.701  1
105510  95.531  -78.053  49.666  1
105511  95.542  -78.045  49.631  1
105512  95.553  -78.038  49.595  1
105513  95.564  -78.031  49.555  1
105514  95.570  -78.025  49.515  1
105515  95.561  -78.055  49.475  1
105516  95.562  -78.075  49.433  1
105517  95.573  -78.081  49.390  1
105518  95.584  -78.087  49.348  1
105519  95.594  -78.092  49.307  1
105520  95.604  -78.098  49.265  1
105521  95.615  -78.104  49.224  1
105522  95.625  -78.109  49.182  1
105523  95.635  -78.116  49.141  1
105524  95.646  -78.122  49.100  1
105525  95.662  -78.102  49.059  1
105526  95.666  -78.094  49.018  1
105527  95.669  -78.106  48.977  1
105528  95.677  -78.105  48.935  1
105529  95.692  -78.091  48.893  1
105530  95.707  -78.078  48.852  1
105531  95.726  -78.072  48.812  1
105532  95.743  -78.090  48.771  1
105533  95.760  -78.106  48.731  1
105534  95.777  -78.124  48.691  1
105535  95.794  -78.141  48.652  1
105536  95.811  -78.158  48.613  1
105537  95.828  -78.175  48.574  1
105538  95.844  -78.192  48.539  1
105539  95.843  -78.213  48.504  1
105540  95.834  -78.228  48.469  1
105541  95.828  -78.232  48.433  1
105542  95.839  -78.225  48.396  1
105543  95.866  -78.210  48.358  1
105544  95.893  -78.194  48.320  1
105545  95.907  -78.184  48.283  1
105546  95.916  -78.177  48.245  1
105547  95.925  -78.170  48.208  1
105548  95.938  -78.167  48.172  1
105549  95.958  -78.169  48.136  1
105550  95.975  -78.173  48.099  1
105551  95.988  -78.180  48.062  1
105552  96.000  -78.188  48.025  1
105553  96.013  -78.194  47.990  1
105554  96.029  -78.202  47.957  1
105555  96.049  -78.210  47.923  1
105556  96.070  -78.219  47.891  1
105557  96.090  -78.227  47.859  1
105558  96.102  -78.244  47.826  1
105559  96.115  -78.262  47.795  1
105560  96.130  -78.269  47.763  1
105561  96.145  -78.277  47.731  1
105562  96.160  -78.285  47.701  1
105563  96.175  -78.294  47.670  1
105564  96.195  -78.313  47.639  1
105565  96.215  -78.332  47.609  1
105566  96.235  -78.351  47.581  1
105567  96.255  -78.370  47.554  1
105568  96.275  -78.389  47.526  1
105569  96.281  -78.401  47.499  1
105570  96.282  -78.412  47.472  1
105571  96.282  -78.423  47.445  1
105572  96.298  -78.431  47.417  1
105573  96.331  -78.435  47.392  1
105574  96.366  -78.439  47.366  1
105575  96.397  -78.440  47.340  1
105576  96.428  -78.439  47.312  1
105577  96.458  -78.438  47.283  1
105578  96.489  -78.438  47.255  1
105579  96.519  -78.437  47.229  1
105580  96.550  -78.436  47.202  1
105581  96.580  -78.435  47.176  1
105582  96.610  -78.435  47.151  1
105583  96.625  -78.439  47.124  1
105584  96.629  -78.448  47.098  1
105585  96.633  -78.457  47.072  1
105586  96.637  -78.466  47.045  1
105587  96.641  -78.475  47.021  1
105588  96.644  -78.484  46.996  1
105589  96.635  -78.488  46.971  1
105590  96.638  -78.496  46.947  1
105591  96.647  -78.504  46.923  1
105592  96.660  -78.510  46.899  1
105593  96.673  -78.516  46.873  1
105594  96.685  -78.522  46.847  1
105595  96.696  -78.530  46.823  1
105596  96.705  -78.539  46.799  1
105597  96.715  -78.549  46.776  1
105598  96.716  -78.566  46.751  1
105599  96.728  -78.595  46.727  1
105600  96.747  -78.626  46.704  1
105601  96.766  -78.657  46.682  1
105602  96.785  -78.688  46.661  1
105603  96.804  -78.719  46.641  1
105604  96.823  -78.750  46.619  1
105605  96.842  -78.781  46.596  1
105606  96.861  -78.812  46.574  1
105607  96.880  -78.843  46.553  1
105608  96.899  -78.874  46.533  1
105609  96.919  -78.905  46.513  1
105610  96.941  -78.931  46.492  1
105611  96.975  -78.943  46.469  1
105612  96.984  -78.866  46.448  1
105613  97.020  -78.911  46.426  1
105614  97.061  -78.939  46.404  1
105615  97.095  -78.936  46.384  1
105616  97.130  -78.933  46.362  1
105617  97.163  -78.930  46.341  1
105618  97.194  -78.927  46.319  1
105619  97.225  -78.924  46.298  1
105620  97.255  -78.922  46.277  1
105621  97.286  -78.919  46.257  1
105622  97.317  -78.917  46.237  1
105623  97.348  -78.915  46.218  1
105624  97.378  -78.912  46.199  1
105625  97.441  -78.917  46.181  1
105626  97.487  -78.910  46.163  1
105627  97.525  -78.900  46.144  1
105628  97.560  -78.889  46.126  1
105629  97.582  -78.881  46.109  1
105630  97.568  -78.886  46.092  1
105631  97.586  -78.883  46.076  1
105632  97.605  -78.880  46.061  1
105633  97.623  -78.876  46.047  1
105634  97.642  -78.873  46.030  1
105635  97.660  -78.870  46.011  1
105636  97.678  -78.867  45.993  1
105637  97.694  -78.860  45.975  1
105638  97.707  -78.851  45.958  1
105639  97.721  -78.841  45.941  1
105640  97.734  -78.832  45.925  1
105641  97.772  -78.818  45.909  1
105642  97.791  -78.801  45.894  1
105643  97.799  -78.785  45.878  1
105644  97.806  -78.768  45.862  1
105645  97.814  -78.752  45.846  1
105646  97.821  -78.735  45.830  1
105647  97.829  -78.719  45.814  1
105648  97.837  -78.702  45.798  1
105649  97.840  -78.683  45.782  1
105650  97.842  -78.672  45.765  1
105651  97.842  -78.706  45.751  1
105652  97.843  -78.741  45.738  1
105653  97.844  -78.776  45.727  1
105654  97.845  -78.810  45.714  1
105655  97.847  -78.844  45.702  1
105656  97.874  -78.850  45.689  1
105657  97.900  -78.857  45.677  1
105658  97.927  -78.864  45.664  1
105659  97.954  -78.870  45.651  1
105660  97.981  -78.877  45.638  1
105661  98.008  -78.883  45.624  1
105662  98.035  -78.890  45.608  1
105663  98.062  -78.897  45.591  1
105664  98.088  -78.903  45.571  1
105665  98.115  -78.910  45.553  1
105666  98.142  -78.917  45.535  1
105667  98.169  -78.924  45.518  1
105668  98.183  -78.939  45.502  1
105669  98.192  -78.957  45.484  1
105670  98.201  -78.975  45.467  1
105671  98.210  -78.993  45.452  1
105672  98.220  -79.012  45.437  1
105673  98.229  -79.029  45.424  1
105674  98.234  -79.041  45.411  1
105675  98.239  -79.052  45.398  1
105676  98.245  -79.063  45.385  1
105677  98.264  -79.068  45.373  1
105678  98.281  -79.062  45.362  1
105679  98.299  -79.056  45.350  1
105680  98.316  -79.050  45.339  1
105681  98.334  -79.044  45.327  1
105682  98.339  -79.021  45.317  1
105683  98.346  -78.999  45.305  1
105684  98.376  -79.003  45.293  1
105685  98.407  -79.008  45.284  1
105686  98.437  -79.012  45.271  1
105687  98.470  -79.019  45.258  1
105688  98.504  -79.028  45.245  1
105689  98.538  -79.037  45.231  1
105690  98.572  -79.046  45.218  1
105691  98.606  -79.055  45.207  1
105692  98.640  -79.063  45.196  1
105693  98.665  -79.070  45.184  1
105694  98.689  -79.076  45.172  1
105695  98.713  -79.083  45.161  1
105696  98.736  -79.090  45.150  1
105697  98.761  -79.096  45.139  1
105698  98.784  -79.103  45.128  1
105699  98.808  -79.109  45.118  1
105700  98.832  -79.115  45.107  1
105701  98.856  -79.122  45.095  1
105702  98.880  -79.128  45.084  1
105703  98.904  -79.135  45.073  1
105704  98.927  -79.141  45.060  1
105705  98.940  -79.145  45.049  1
105706  98.953  -79.150  45.038  1
105707  98.978  -79.168  45.026  1
105708  99.005  -79.183  45.014  1
105709  99.029  -79.184  45.002  1
105710  99.055  -79.185  44.991  1
105711  99.080  -79.187  44.981  1
105712  99.106  -79.188  44.970  1
105713  99.134  -79.190  44.959  1
105714  99.159  -79.188  44.949  1
105715  99.177  -79.175  44.938  1
105716  99.196  -79.170  44.928  1
105717  99.219  -79.188  44.919  1
105718  99.243  -79.206  44.911  1
105719  99.254  -79.221  44.903  1
105720  99.263  -79.235  44.894  1
105721  99.272  -79.250  44.887  1
105722  99.281  -79.265  44.881  1
105723  99.290  -79.280  44.875  1
105724  99.311  -79.289  44.870  1
105725  99.333  -79.297  44.866  1
105726  99.355  -79.306  44.862  1
105727  99.378  -79.322  44.858  1
105728  99.401  -79.338  44.853  1
105729  99.424  -79.353  44.850  1
105730  99.447  -79.369  44.847  1
105731  99.471  -79.384  44.845  1
105732  99.494  -79.399  44.844  1
105733  99.517  -79.415  44.841  1
105734  99.543  -79.427  44.839  1
105735  99.570  -79.431  44.835  1
105736  99.596  -79.435  44.833  1
105737  99.622  -79.440  44.831  1
105738  99.648  -79.444  44.828  1
105739  99.674  -79.450  44.825  1
105740  99.700  -79.454  44.821  1
105741  99.726  -79.459  44.817  1
105742  99.752  -79.463  44.814  1
105743  99.777  -79.468  44.810  1
105744  99.803  -79.473  44.806  1
105745  99.829  -79.477  44.803  1
105746  99.855  -79.482  44.799  1
105747  99.881  -79.486  44.796  1
105748  99.913  -79.511  44.792  1
105749  99.947  -79.544  44.786  1
105750  99.981  -79.576  44.780  1
105751  100.014  -79.623  44.772  1
105752  100.047  -79.677  44.764  1
105753  100.086  -79.689  44.755  1
105754  100.125  -79.698  44.745  1
105755  100.158  -79.715  44.735  1
105756  100.184  -79.742  44.722  1
105757  100.208  -79.769  44.712  1
105758  100.233  -79.795  44.704  1
105759  100.259  -79.823  44.697  1
105760  100.281  -79.861  44.690  1
105761  100.303  -79.899  44.682  1
105762  100.326  -79.938  44.672  1
105763  100.354  -79.961  44.660  1
105764  100.392  -79.967  44.648  1
105765  100.428  -79.971  44.636  1
105766  100.466  -79.977  44.623  1
105767  100.502  -79.981  44.609  1
105768  100.540  -79.987  44.594  1
105769  100.574  -80.012  44.578  1
105770  100.609  -80.040  44.562  1
105771  100.643  -80.067  44.545  1
105772  100.676  -80.096  44.529  1
105773  100.672  -80.140  44.515  1
105774  100.693  -80.177  44.499  1
105775  100.718  -80.211  44.483  1
105776  100.745  -80.247  44.467  1
105777  100.774  -80.284  44.451  1
105778  100.802  -80.320  44.434  1
105779  100.831  -80.356  44.418  1
105780  100.859  -80.393  44.401  1
105781  100.888  -80.429  44.385  1
105782  100.916  -80.466  44.368  1
105783  100.945  -80.502  44.350  1
105784  100.973  -80.538  44.333  1
105785  101.001  -80.575  44.316  1
105786  101.030  -80.611  44.298  1
105787  101.058  -80.648  44.280  1
105788  101.087  -80.685  44.261  1
105789  101.129  -80.703  44.241  1
105790  101.164  -80.718  44.222  1
105791  101.197  -80.735  44.204  1
105792  101.230  -80.751  44.186  1
105793  101.262  -80.767  44.168  1
105794  101.295  -80.782  44.151  1
105795  101.328  -80.798  44.134  1
105796  101.360  -80.815  44.118  1
105797  101.393  -80.831  44.101  1
105798  101.426  -80.847  44.084  1
105799  101.459  -80.863  44.067  1
105800  101.491  -80.879  44.052  1
106056  93.497  -78.449  53.840  1
106057  93.507  -78.447  53.824  1
106058  93.516  -78.445  53.806  1
106059  93.526  -78.442  53.786  1
106060  93.536  -78.439  53.766  1
106061  93.541  -78.435  53.745  1
106062  93.540  -78.425  53.723  1
106063  93.538  -78.416  53.700  1
106064  93.537  -78.407  53.676  1
106065  93.541  -78.395  53.651  1
106066  93.552  -78.379  53.626  1
106067  93.564  -78.363  53.601  1
106068  93.587  -78.348  53.577  1
106069  93.610  -78.334  53.552  1
106070  93.627  -78.322  53.529  1
106071  93.639  -78.313  53.505  1
106072  93.650  -78.305  53.482  1
106073  93.662  -78.297  53.459  1
106074  93.674  -78.288  53.437  1
106090  93.916  -78.173  53.098  1
106091  93.929  -78.169  53.076  1
106092  93.942  -78.165  53.054  1
106093  93.955  -78.160  53.032  1
106094  93.968  -78.156  53.010  1
106095  93.968  -78.154  52.988  1
106096  93.965  -78.153  52.967  1
106097  93.968  -78.163  52.946  1
106098  93.972  -78.173  52.926  1
106099  93.975  -78.183  52.904  1
106100  93.978  -78.194  52.881  1
106101  93.982  -78.204  52.860  1
106102  93.985  -78.214  52.838  1
106103  93.989  -78.225  52.817  1
106104  93.992  -78.235  52.796  1
106105  93.995  -78.245  52.775  1
106106  93.999  -78.255  52.753  1
106107  94.002  -78.266  52.732  1
106108  94.006  -78.276  52.709  1
106109  94.009  -78.286  52.688  1
106110  94.012  -78.297  52.666  1
106111  94.016  -78.307  52.646  1
106112  94.019  -78.317  52.625  1
106113  94.024  -78.327  52.605  1
106114  94.036  -78.323  52.585  1
106115  94.061  -78.314  52.565  1
106116  94.083  -78.307  52.545  1
106117  94.094  -78.304  52.525  1
106118  94.104  -78.301  52.505  1
106119  94.114  -78.298  52.485  1
106120  94.125  -78.295  52.464  1
106121  94.135  -78.293  52.443  1
106122  94.146  -78.290  52.423  1
106123  94.156  -78.288  52.401  1
106124  94.169  -78.282  52.380  1
106125  94.183  -78.274  52.358  1
106126  94.196  -78.266  52.337  1
106127  94.210  -78.259  52.315  1
106128  94.224  -78.251  52.292  1
106129  94.238  -78.244  52.263  1
106130  94.251  -78.236  52.234  1
106131  94.265  -78.228  52.204  1
106132  94.279  -78.221  52.173  1
106133  94.292  -78.213  52.142  1
106134  94.306  -78.206  52.111  1
106135  94.320  -78.198  52.078  1
106136  94.334  -78.191  52.045  1
106137  94.346  -78.185  52.012  1
106138  94.349  -78.181  51.980  1
106139  94.370  -78.170  51.947  1
106140  94.391  -78.160  51.918  1
106141  94.411  -78.150  51.888  1
106142  94.432  -78.141  51.858  1
106143  94.453  -78.130  51.827  1
106144  94.473  -78.120  51.796  1
106145  94.494  -78.119  51.764  1
106146  94.532  -78.134  51.731  1
106147  94.569  -78.151  51.698  1
106148  94.607  -78.167  51.663  1
106149  94.644  -78.183  51.628  1
106150  94.664  -78.188  51.593  1
106151  94.674  -78.186  51.558  1
106152  94.682  -78.178  51.524  1
106153  94.690  -78.169  51.491  1
106154  94.698  -78.159  51.459  1
106155  94.707  -78.151  51.426  1
106156  94.715  -78.142  51.391  1
106157  94.722  -78.134  51.358  1
106158  94.722  -78.141  51.324  1
106159  94.730  -78.142  51.291  1
106160  94.741  -78.140  51.259  1
106161  94.753  -78.137  51.226  1
106162  94.765  -78.138  51.192  1
106163  94.777  -78.143  51.157  1
106164  94.789  -78.147  51.122  1
106165  94.801  -78.152  51.088  1
106166  94.813  -78.157  51.054  1
106167  94.826  -78.162  51.019  1
106168  94.838  -78.167  50.983  1
106169  94.856  -78.173  50.947  1
106170  94.881  -78.180  50.910  1
106171  94.901  -78.171  50.873  1
106172  94.919  -78.153  50.837  1
106173  94.937  -78.136  50.801  1
106174  94.956  -78.119  50.764  1
106175  94.974  -78.102  50.728  1
106176  94.992  -78.084  50.691  1
106177  95.011  -78.068  50.655  1
106178  95.030  -78.048  50.619  1
106179  95.051  -78.027  50.584  1
106180  95.072  -78.006  50.549  1
106181  95.113  -77.999  50.515  1
106182  95.157  -77.993  50.481  1
106183  95.190  -77.991  50.447  1
106184  95.214  -77.993  50.414  1
106185  95.239  -77.995  50.380  1
106186  95.263  -77.997  50.348  1
106187  95.287  -78.000  50.315  1
106188  95.312  -78.001  50.284  1
106189  95.330  -78.003  50.253  1
106190  95.338  -78.001  50.223  1
106191  95.345  -78.000  50.193  1
106192  95.352  -78.000  50.166  1
106193  95.360  -77.999  50.140  1
106194  95.368  -77.998  50.113  1
106195  95.375  -77.996  50.085  1
106196  95.383  -77.991  50.059  1
106197  95.390  -77.987  50.032  1
106198  95.401  -77.994  50.007  1
106199  95.412  -78.006  49.985  1
106200  95.423  -78.016  49.966  1
106201  95.435  -78.027  49.949  1
106202  95.443  -78.034  49.932  1
106203  95.444  -78.037  49.913  1
106204  95.445  -78.040  49.891  1
106205  95.446  -78.042  49.867  1
106206  95.447  -78.045  49.840  1
106207  95.447  -78.047  49.810  1
106208  95.460  -78.047  49.777  1
106209  95.492  -78.044  49.743  1
106210  95.524  -78.039  49.707  1
106211  95.552  -78.034  49.670  1
106212  95.563  -78.027  49.633  1
106213  95.574  -78.020  49.596  1
106214  95.586  -78.012  49.555  1
106215  95.597  -78.005  49.515  1
106216  95.588  -78.019  49.474  1
106217  95.579  -78.056  49.432  1
106218  95.584  -78.070  49.390  1
106219  95.594  -78.076  49.348  1
106220  95.605  -78.082  49.306  1
106221  95.615  -78.087  49.265  1
106222  95.625  -78.094  49.224  1
106223  95.636  -78.100  49.183  1
106224  95.649  -78.094  49.142  1
106225  95.664  -78.066  49.102  1
106226  95.676  -78.058  49.062  1
106227  95.673  -78.078  49.021  1
106228  95.669  -78.097  48.979  1
106229  95.684  -78.084  48.938  1
106230  95.699  -78.071  48.896  1
106231  95.714  -78.057  48.855  1
106232  95.741  -78.066  48.816  1
106233  95.766  -78.077  48.775  1
106234  95.783  -78.094  48.734  1
106235  95.800  -78.111  48.694  1
106236  95.817  -78.128  48.654  1
106237  95.834  -78.145  48.615  1
106238  95.851  -78.162  48.577  1
106239  95.860  -78.181  48.542  1
106240  95.848  -78.205  48.508  1
106241  95.838  -78.228  48.474  1
106242  95.829  -78.246  48.440  1
106243  95.852  -78.232  48.404  1
106244  95.879  -78.217  48.366  1
106245  95.906  -78.202  48.328  1
106246  95.933  -78.187  48.291  1
106247  95.944  -78.178  48.255  1
106248  95.953  -78.172  48.218  1
106249  95.962  -78.164  48.183  1
106250  95.969  -78.158  48.147  1
106251  95.974  -78.158  48.110  1
106252  95.986  -78.166  48.074  1
106253  95.999  -78.172  48.038  1
106254  96.011  -78.180  48.004  1
106255  96.028  -78.188  47.970  1
106256  96.048  -78.196  47.937  1
106257  96.068  -78.203  47.905  1
106258  96.089  -78.212  47.873  1
106259  96.108  -78.222  47.841  1
106260  96.122  -78.234  47.811  1
106261  96.137  -78.242  47.780  1
106262  96.153  -78.251  47.748  1
106263  96.168  -78.261  47.719  1
106264  96.183  -78.272  47.688  1
106265  96.201  -78.289  47.657  1
106266  96.222  -78.308  47.627  1
106267  96.242  -78.327  47.599  1
106268  96.262  -78.347  47.572  1
106269  96.283  -78.366  47.545  1
106270  96.296  -78.382  47.518  1
106271  96.300  -78.395  47.491  1
106272  96.303  -78.408  47.464  1
106273  96.307  -78.421  47.439  1
106274  96.334  -78.423  47.412  1
106275  96.364  -78.423  47.386  1
106276  96.395  -78.422  47.360  1
106277  96.425  -78.421  47.332  1
106278  96.456  -78.420  47.305  1
106279  96.486  -78.420  47.277  1
106280  96.517  -78.419  47.250  1
106281  96.547  -78.418  47.224  1
106282  96.577  -78.417  47.199  1
106283  96.606  -78.416  47.173  1
106284  96.610  -78.426  47.148  1
106285  96.614  -78.435  47.122  1
106286  96.617  -78.443  47.095  1
106287  96.621  -78.452  47.069  1
106288  96.625  -78.461  47.044  1
106289  96.628  -78.470  47.020  1
106290  96.632  -78.479  46.996  1
106291  96.631  -78.485  46.973  1
106292  96.643  -78.492  46.947  1
106293  96.654  -78.501  46.920  1
106294  96.663  -78.510  46.893  1
106295  96.673  -78.520  46.868  1
106296  96.682  -78.529  46.843  1
106297  96.692  -78.539  46.820  1
106298  96.701  -78.548  46.796  1
106299  96.700  -78.566  46.772  1
106300  96.695  -78.588  46.748  1
106301  96.713  -78.618  46.724  1
106302  96.732  -78.649  46.701  1
106303  96.751  -78.680  46.679  1
106304  96.770  -78.711  46.657  1
106305  96.789  -78.742  46.636  1
106306  96.808  -78.774  46.612  1
106307  96.827  -78.805  46.589  1
106308  96.847  -78.836  46.568  1
106309  96.866  -78.867  46.546  1
106310  96.887  -78.895  46.525  1
106311  96.923  -78.905  46.503  1
106312  96.955  -78.916  46.480  1
106313  97.003  -78.909  46.457  1
106314  97.019  -78.892  46.434  1
106315  97.039  -78.926  46.411  1
106316  97.067  -78.925  46.390  1
106317  97.097  -78.922  46.369  1
106318  97.128  -78.920  46.347  1
106319  97.159  -78.917  46.326  1
106320  97.189  -78.915  46.304  1
106321  97.220  -78.912  46.283  1
106322  97.251  -78.909  46.263  1
106323  97.282  -78.907  46.243  1
106324  97.329  -78.908  46.224  1
106325  97.400  -78.914  46.205  1
106326  97.443  -78.906  46.186  1
106327  97.485  -78.897  46.168  1
106328  97.520  -78.886  46.150  1
106329  97.555  -78.874  46.131  1
106330  97.589  -78.863  46.114  1
106331  97.588  -78.862  46.098  1
106332  97.570  -78.868  46.082  1
106333  97.588  -78.865  46.068  1
106334  97.607  -78.861  46.054  1
106335  97.620  -78.852  46.038  1
106336  97.634  -78.843  46.020  1
106337  97.647  -78.833  46.003  1
106338  97.661  -78.824  45.985  1
106339  97.674  -78.815  45.967  1
106340  97.687  -78.805  45.949  1
106341  97.711  -78.794  45.933  1
106342  97.769  -78.775  45.917  1
106343  97.777  -78.758  45.901  1
106344  97.786  -78.743  45.885  1
106345  97.802  -78.735  45.869  1
106346  97.818  -78.726  45.853  1
106347  97.834  -78.717  45.837  1
106348  97.850  -78.708  45.821  1
106349  97.866  -78.699  45.805  1
106350  97.852  -78.684  45.788  1
106351  97.849  -78.642  45.772  1
106352  97.861  -78.652  45.758  1
106353  97.878  -78.661  45.746  1
106354  97.895  -78.668  45.735  1
106355  97.895  -78.710  45.722  1
106356  97.868  -78.813  45.710  1
106357  97.877  -78.833  45.699  1
106358  97.907  -78.836  45.687  1
106359  97.936  -78.839  45.675  1
106360  97.965  -78.843  45.662  1
106361  97.992  -78.849  45.648  1
106362  98.019  -78.855  45.634  1
106363  98.046  -78.862  45.619  1
106364  98.073  -78.869  45.602  1
106365  98.099  -78.875  45.584  1
106366  98.127  -78.882  45.566  1
106367  98.153  -78.889  45.547  1
106368  98.178  -78.896  45.527  1
106369  98.187  -78.915  45.509  1
106370  98.197  -78.933  45.491  1
106371  98.206  -78.951  45.475  1
106372  98.215  -78.969  45.461  1
106373  98.224  -78.987  45.447  1
106374  98.234  -79.006  45.435  1
106375  98.243  -79.024  45.422  1
106376  98.251  -79.040  45.408  1
106377  98.260  -79.058  45.395  1
106378  98.283  -79.062  45.383  1
106379  98.301  -79.056  45.372  1
106380  98.318  -79.050  45.361  1
106381  98.336  -79.044  45.349  1
106382  98.353  -79.038  45.337  1
106383  98.361  -79.018  45.327  1
106384  98.364  -78.992  45.315  1
106385  98.387  -78.989  45.304  1
106386  98.418  -78.993  45.293  1
106387  98.448  -78.997  45.280  1
106388  98.482  -79.006  45.266  1
106389  98.516  -79.015  45.253  1
106390  98.550  -79.024  45.240  1
106391  98.584  -79.032  45.227  1
106392  98.616  -79.040  45.215  1
106393  98.640  -79.047  45.204  1
106394  98.663  -79.053  45.193  1
106395  98.688  -79.060  45.182  1
106396  98.711  -79.067  45.171  1
106397  98.735  -79.073  45.161  1
106398  98.759  -79.080  45.150  1
106399  98.783  -79.086  45.139  1
106400  98.807  -79.093  45.128  1
106401  98.831  -79.100  45.116  1
106402  98.855  -79.106  45.104  1
106403  98.879  -79.112  45.092  1
106404  98.903  -79.119  45.080  1
106405  98.927  -79.125  45.068  1
106406  98.941  -79.130  45.056  1
106407  98.962  -79.143  45.045  1
106408  98.988  -79.152  45.032  1
106409  99.013  -79.153  45.020  1
106410  99.038  -79.154  45.008  1
106411  99.063  -79.155  44.997  1
106412  99.088  -79.156  44.986  1
106413  99.114  -79.158  44.976  1
106414  99.141  -79.159  44.964  1
106415  99.168  -79.161  44.954  1
106416  99.195  -79.162  44.943  1
106417  99.221  -79.162  44.933  1
106418  99.239  -79.154  44.924  1
106419  99.263  -79.172  44.916  1
106420  99.273  -79.186  44.907  1
106421  99.282  -79.201  44.900  1
106422  99.291  -79.216  44.894  1
106423  99.300  -79.231  44.889  1
106424  99.309  -79.245  44.884  1
106425  99.319  -79.259  44.880  1
106426  99.341  -79.272  44.877  1
106427  99.364  -79.288  44.874  1
106428  99.386  -79.301  44.870  1
106429  99.408  -79.315  44.865  1
106430  99.430  -79.328  44.862  1
106431  99.452  -79.341  44.859  1
106432  99.474  -79.355  44.856  1
106433  99.496  -79.368  44.854  1
106434  99.519  -79.383  44.852  1
106435  99.542  -79.408  44.849  1
106436  99.568  -79.415  44.847  1
106437  99.593  -79.419  44.844  1
106438  99.620  -79.424  44.842  1
106439  99.645  -79.429  44.839  1
106440  99.671  -79.433  44.835  1
106441  99.697  -79.438  44.831  1
106442  99.723  -79.442  44.826  1
106443  99.749  -79.447  44.823  1
106444  99.775  -79.451  44.820  1
106445  99.801  -79.456  44.816  1
106446  99.827  -79.461  44.813  1
106447  99.853  -79.466  44.810  1
106448  99.880  -79.477  44.806  1
106449  99.915  -79.510  44.802  1
106450  99.948  -79.542  44.795  1
106451  99.983  -79.576  44.788  1
106452  100.016  -79.620  44.780  1
106453  100.049  -79.673  44.773  1
106454  100.088  -79.683  44.764  1
106455  100.127  -79.692  44.754  1
106456  100.167  -79.701  44.744  1
106457  100.194  -79.726  44.730  1
106458  100.218  -79.753  44.718  1
106459  100.244  -79.780  44.708  1
106460  100.268  -79.809  44.700  1
106461  100.290  -79.848  44.693  1
106462  100.313  -79.886  44.684  1
106463  100.335  -79.926  44.673  1
106464  100.360  -79.957  44.660  1
106465  100.397  -79.961  44.648  1
106466  100.434  -79.967  44.636  1
106467  100.471  -79.971  44.623  1
106468  100.508  -79.977  44.608  1
106469  100.545  -79.981  44.593  1
106470  100.582  -79.987  44.578  1
106471  100.617  -80.012  44.561  1
106472  100.652  -80.039  44.545  1
106473  100.686  -80.067  44.529  1
106474  100.686  -80.110  44.515  1
106475  100.710  -80.145  44.500  1
106476  100.737  -80.181  44.484  1
106477  100.765  -80.217  44.468  1
106478  100.793  -80.253  44.451  1
106479  100.822  -80.290  44.435  1
106480  100.850  -80.326  44.419  1
106481  100.879  -80.363  44.402  1
106482  100.907  -80.399  44.387  1
106483  100.936  -80.435  44.370  1
106484  100.964  -80.472  44.353  1
106485  100.993  -80.509  44.336  1
106486  101.021  -80.545  44.319  1
106487  101.050  -80.582  44.301  1
106488  101.081  -80.616  44.284  1
106489  101.115  -80.649  44.265  1
106490  101.149  -80.676  44.246  1
106491  101.182  -80.692  44.227  1
106492  101.215  -80.707  44.210  1
106493  101.248  -80.723  44.193  1
106494  101.281  -80.739  44.175  1
106495  101.314  -80.754  44.158  1
106496  101.347  -80.770  44.140  1
106497  101.380  -80.786  44.123  1
106498  101.413  -80.802  44.107  1
106499  101.446  -80.818  44.090  1
106500  101.479  -80.834  44.074  1
106501  101.512  -80.850  44.058  1
106757  93.497  -78.438  53.835  1
106758  93.507  -78.436  53.819  1
106759  93.516  -78.434  53.800  1
106760  93.526  -78.431  53.781  1
106761  93.536  -78.429  53.760  1
106762  93.538  -78.421  53.738  1
106763  93.536  -78.412  53.716  1
106764  93.535  -78.403  53.693  1
106765  93.534  -78.394  53.669  1
106766  93.543  -78.379  53.644  1
106767  93.553  -78.363  53.618  1
106768  93.570  -78.348  53.594  1
106769  93.592  -78.333  53.569  1
106770  93.615  -78.318  53.545  1
106771  93.628  -78.309  53.521  1
106772  93.640  -78.300  53.498  1
106773  93.651  -78.292  53.474  1
106774  93.663  -78.284  53.451  1
106775  93.675  -78.275  53.429  1
106791  93.917  -78.162  53.085  1
106792  93.929  -78.158  53.063  1
106793  93.942  -78.153  53.040  1
106794  93.955  -78.149  53.018  1
106795  93.968  -78.145  52.995  1
106796  93.968  -78.144  52.973  1
106797  93.966  -78.142  52.951  1
106798  93.968  -78.150  52.929  1
106799  93.971  -78.159  52.907  1
106800  93.974  -78.170  52.884  1
106801  93.978  -78.180  52.860  1
106802  93.981  -78.191  52.838  1
106803  93.985  -78.201  52.817  1
106804  93.988  -78.211  52.794  1
106805  93.991  -78.222  52.772  1
106806  93.995  -78.232  52.750  1
106807  93.998  -78.242  52.728  1
106808  94.002  -78.252  52.705  1
106809  94.005  -78.263  52.683  1
106810  94.008  -78.273  52.661  1
106811  94.012  -78.283  52.639  1
106812  94.015  -78.294  52.616  1
106813  94.019  -78.304  52.595  1
106814  94.028  -78.312  52.573  1
106815  94.037  -78.307  52.552  1
106816  94.062  -78.297  52.530  1
106817  94.087  -78.288  52.508  1
106818  94.104  -78.283  52.486  1
106819  94.114  -78.280  52.466  1
106820  94.125  -78.278  52.445  1
106821  94.135  -78.275  52.422  1
106822  94.145  -78.272  52.400  1
106823  94.156  -78.269  52.378  1
106824  94.167  -78.266  52.356  1
106825  94.178  -78.263  52.333  1
106826  94.192  -78.255  52.311  1
106827  94.205  -78.247  52.288  1
106828  94.219  -78.240  52.266  1
106829  94.233  -78.232  52.241  1
106830  94.247  -78.225  52.214  1
106831  94.260  -78.217  52.185  1
106832  94.274  -78.210  52.156  1
106833  94.288  -78.202  52.128  1
106834  94.301  -78.194  52.099  1
106835  94.315  -78.187  52.069  1
106836  94.329  -78.179  52.039  1
106837  94.343  -78.172  52.008  1
106838  94.357  -78.166  51.979  1
106839  94.359  -78.162  51.949  1
106840  94.372  -78.153  51.919  1
106841  94.393  -78.144  51.891  1
106842  94.414  -78.134  51.861  1
106843  94.434  -78.124  51.831  1
106844  94.455  -78.113  51.802  1
106845  94.476  -78.103  51.771  1
106846  94.494  -78.097  51.740  1
106847  94.527  -78.110  51.709  1
106848  94.565  -78.126  51.677  1
106849  94.602  -78.143  51.645  1
106850  94.640  -78.159  51.611  1
106851  94.662  -78.166  51.578  1
106852  94.674  -78.166  51.545  1
106853  94.682  -78.159  51.512  1
106854  94.690  -78.150  51.479  1
106855  94.699  -78.141  51.448  1
106856  94.707  -78.132  51.415  1
106857  94.715  -78.123  51.382  1
106858  94.723  -78.115  51.349  1
106859  94.723  -78.122  51.316  1
106860  94.728  -78.125  51.284  1
106861  94.739  -78.122  51.253  1
106862  94.751  -78.120  51.220  1
106863  94.762  -78.120  51.187  1
106864  94.774  -78.125  51.153  1
106865  94.786  -78.130  51.118  1
106866  94.799  -78.134  51.084  1
106867  94.811  -78.140  51.050  1
106868  94.823  -78.144  51.016  1
106869  94.835  -78.150  50.980  1
106870  94.859  -78.156  50.945  1
106871  94.884  -78.164  50.908  1
106872  94.903  -78.153  50.871  1
106873  94.921  -78.135  50.835  1
106874  94.940  -78.118  50.799  1
106875  94.958  -78.100  50.763  1
106876  94.976  -78.084  50.728  1
106877  94.994  -78.066  50.691  1
106878  95.013  -78.049  50.655  1
106879  95.031  -78.032  50.620  1
106880  95.050  -78.013  50.585  1
106881  95.070  -77.993  50.551  1
106882  95.103  -77.979  50.517  1
106883  95.147  -77.973  50.483  1
106884  95.173  -77.975  50.450  1
106885  95.197  -77.977  50.416  1
106886  95.222  -77.978  50.384  1
106887  95.246  -77.981  50.352  1
106888  95.270  -77.982  50.320  1
106889  95.295  -77.984  50.289  1
106890  95.319  -77.987  50.259  1
106891  95.334  -77.987  50.229  1
106892  95.342  -77.986  50.201  1
106893  95.349  -77.985  50.173  1
106894  95.356  -77.984  50.148  1
106895  95.364  -77.983  50.121  1
106896  95.372  -77.980  50.094  1
106897  95.379  -77.975  50.068  1
106898  95.390  -77.981  50.043  1
106899  95.401  -77.993  50.020  1
106900  95.412  -78.003  50.000  1
106901  95.422  -78.012  49.985  1
106902  95.424  -78.014  49.969  1
106903  95.427  -78.016  49.952  1
106904  95.429  -78.018  49.931  1
106905  95.431  -78.020  49.906  1
106906  95.432  -78.023  49.880  1
106907  95.433  -78.025  49.851  1
106908  95.434  -78.028  49.819  1
106909  95.458  -78.025  49.784  1
106910  95.490  -78.022  49.748  1
106911  95.522  -78.017  49.710  1
106912  95.553  -78.013  49.671  1
106913  95.585  -78.009  49.632  1
106914  95.596  -78.002  49.593  1
106915  95.607  -77.994  49.553  1
106916  95.618  -77.987  49.512  1
106917  95.614  -77.986  49.471  1
106918  95.606  -78.020  49.429  1
106919  95.597  -78.056  49.388  1
106920  95.605  -78.065  49.347  1
106921  95.616  -78.072  49.305  1
106922  95.626  -78.078  49.264  1
106923  95.636  -78.083  49.224  1
106924  95.654  -78.053  49.184  1
106925  95.665  -78.032  49.145  1
106926  95.680  -78.030  49.105  1
106927  95.676  -78.050  49.064  1
106928  95.672  -78.069  49.023  1
106929  95.675  -78.078  48.981  1
106930  95.690  -78.064  48.940  1
106931  95.706  -78.050  48.899  1
106932  95.729  -78.052  48.858  1
106933  95.756  -78.061  48.819  1
106934  95.782  -78.070  48.780  1
106935  95.807  -78.081  48.739  1
106936  95.824  -78.098  48.698  1
106937  95.841  -78.115  48.658  1
106938  95.858  -78.132  48.618  1
106939  95.875  -78.149  48.580  1
106940  95.865  -78.173  48.543  1
106941  95.854  -78.197  48.509  1
106942  95.844  -78.219  48.475  1
106943  95.841  -78.228  48.441  1
106944  95.866  -78.223  48.406  1
106945  95.893  -78.216  48.370  1
106946  95.919  -78.210  48.334  1
106947  95.946  -78.194  48.299  1
106948  95.972  -78.179  48.264  1
106949  95.980  -78.172  48.227  1
106950  95.985  -78.167  48.192  1
106951  95.987  -78.163  48.155  1
106952  95.988  -78.159  48.118  1
106953  95.990  -78.155  48.082  1
106954  95.998  -78.158  48.049  1
106955  96.010  -78.165  48.017  1
106956  96.028  -78.172  47.984  1
106957  96.048  -78.181  47.952  1
106958  96.068  -78.189  47.920  1
106959  96.091  -78.197  47.888  1
106960  96.115  -78.204  47.856  1
106961  96.131  -78.211  47.826  1
106962  96.147  -78.220  47.795  1
106963  96.162  -78.229  47.764  1
106964  96.178  -78.239  47.734  1
106965  96.193  -78.252  47.704  1
106966  96.207  -78.265  47.673  1
106967  96.227  -78.283  47.644  1
106968  96.247  -78.302  47.617  1
106969  96.267  -78.322  47.590  1
106970  96.288  -78.341  47.564  1
106971  96.294  -78.354  47.537  1
106972  96.297  -78.367  47.510  1
106973  96.304  -78.381  47.484  1
106974  96.318  -78.395  47.459  1
106975  96.333  -78.404  47.432  1
106976  96.362  -78.404  47.405  1
106977  96.392  -78.403  47.379  1
106978  96.422  -78.402  47.353  1
106979  96.453  -78.401  47.326  1
106980  96.483  -78.401  47.299  1
106981  96.514  -78.400  47.272  1
106982  96.544  -78.399  47.247  1
106983  96.575  -78.398  47.222  1
106984  96.591  -78.403  47.197  1
106985  96.594  -78.412  47.172  1
106986  96.598  -78.420  47.146  1
106987  96.602  -78.429  47.120  1
106988  96.605  -78.438  47.094  1
106989  96.609  -78.447  47.069  1
106990  96.613  -78.456  47.045  1
106991  96.617  -78.464  47.021  1
106992  96.624  -78.470  46.996  1
106993  96.630  -78.490  46.968  1
106994  96.640  -78.500  46.941  1
106995  96.650  -78.509  46.914  1
106996  96.659  -78.519  46.889  1
106997  96.668  -78.528  46.865  1
106998  96.678  -78.538  46.841  1
106999  96.687  -78.547  46.817  1
107000  96.685  -78.566  46.793  1
107001  96.680  -78.588  46.769  1
107002  96.679  -78.611  46.744  1
107003  96.698  -78.642  46.722  1
107004  96.717  -78.673  46.698  1
107005  96.736  -78.705  46.676  1
107006  96.755  -78.736  46.654  1
107007  96.774  -78.767  46.630  1
107008  96.793  -78.798  46.606  1
107009  96.812  -78.829  46.583  1
107010  96.833  -78.858  46.560  1
107011  96.868  -78.868  46.538  1
107012  96.903  -78.879  46.515  1
107013  96.935  -78.890  46.492  1
107014  96.972  -78.894  46.467  1
107015  97.019  -78.872  46.442  1
107016  97.026  -78.899  46.419  1
107017  97.032  -78.915  46.397  1
107018  97.062  -78.912  46.375  1
107019  97.093  -78.909  46.354  1
107020  97.123  -78.907  46.332  1
107021  97.154  -78.905  46.310  1
107022  97.185  -78.902  46.289  1
107023  97.218  -78.899  46.269  1
107024  97.299  -78.910  46.248  1
107025  97.357  -78.909  46.229  1
107026  97.400  -78.902  46.209  1
107027  97.443  -78.893  46.190  1
107028  97.480  -78.883  46.172  1
107029  97.515  -78.871  46.154  1
107030  97.549  -78.860  46.137  1
107031  97.584  -78.849  46.120  1
107032  97.618  -78.837  46.104  1
107033  97.594  -78.843  46.088  1
107034  97.583  -78.858  46.074  1
107035  97.597  -78.850  46.059  1
107036  97.611  -78.841  46.043  1
107037  97.625  -78.832  46.026  1
107038  97.639  -78.824  46.010  1
107039  97.652  -78.814  45.993  1
107040  97.666  -78.805  45.976  1
107041  97.681  -78.798  45.958  1
107042  97.742  -78.796  45.942  1
107043  97.786  -78.762  45.926  1
107044  97.802  -78.752  45.909  1
107045  97.818  -78.742  45.891  1
107046  97.833  -78.734  45.875  1
107047  97.850  -78.725  45.859  1
107048  97.866  -78.716  45.842  1
107049  97.881  -78.707  45.827  1
107050  97.891  -78.697  45.811  1
107051  97.875  -78.681  45.795  1
107052  97.863  -78.657  45.779  1
107053  97.844  -78.682  45.764  1
107054  97.856  -78.692  45.751  1
107055  97.874  -78.682  45.739  1
107056  97.919  -78.675  45.726  1
107057  97.891  -78.778  45.714  1
107058  97.885  -78.817  45.702  1
107059  97.908  -78.824  45.691  1
107060  97.937  -78.827  45.679  1
107061  97.966  -78.830  45.666  1
107062  97.995  -78.833  45.652  1
107063  98.025  -78.836  45.639  1
107064  98.054  -78.839  45.624  1
107065  98.083  -78.842  45.607  1
107066  98.110  -78.847  45.590  1
107067  98.138  -78.854  45.572  1
107068  98.164  -78.861  45.554  1
107069  98.183  -78.873  45.536  1
107070  98.193  -78.891  45.519  1
107071  98.202  -78.909  45.505  1
107072  98.211  -78.927  45.491  1
107073  98.218  -78.942  45.477  1
107074  98.226  -78.957  45.462  1
107075  98.233  -78.972  45.448  1
107076  98.241  -78.987  45.434  1
107077  98.248  -79.002  45.422  1
107078  98.265  -79.039  45.409  1
107079  98.290  -79.053  45.397  1
107080  98.319  -79.049  45.384  1
107081  98.338  -79.044  45.371  1
107082  98.355  -79.038  45.359  1
107083  98.373  -79.033  45.346  1
107084  98.382  -79.015  45.335  1
107085  98.386  -78.990  45.324  1
107086  98.399  -78.974  45.312  1
107087  98.429  -78.979  45.301  1
107088  98.460  -78.984  45.288  1
107089  98.494  -78.993  45.274  1
107090  98.528  -79.002  45.261  1
107091  98.563  -79.010  45.249  1
107092  98.590  -79.018  45.236  1
107093  98.615  -79.024  45.224  1
107094  98.638  -79.031  45.213  1
107095  98.662  -79.037  45.203  1
107096  98.686  -79.044  45.193  1
107097  98.710  -79.050  45.184  1
107098  98.734  -79.057  45.173  1
107099  98.758  -79.063  45.162  1
107100  98.782  -79.070  45.151  1
107101  98.806  -79.077  45.138  1
107102  98.830  -79.083  45.127  1
107103  98.854  -79.090  45.115  1
107104  98.878  -79.096  45.104  1
107105  98.902  -79.103  45.090  1
107106  98.926  -79.109  45.077  1
107107  98.946  -79.118  45.064  1
107108  98.971  -79.120  45.052  1
107109  98.996  -79.122  45.040  1
107110  99.021  -79.122  45.028  1
107111  99.046  -79.124  45.016  1
107112  99.071  -79.125  45.004  1
107113  99.096  -79.126  44.992  1
107114  99.121  -79.127  44.981  1
107115  99.147  -79.128  44.970  1
107116  99.174  -79.130  44.960  1
107117  99.202  -79.131  44.950  1
107118  99.229  -79.133  44.941  1
107119  99.256  -79.134  44.932  1
107120  99.282  -79.137  44.924  1
107121  99.288  -79.155  44.915  1
107122  99.294  -79.172  44.907  1
107123  99.300  -79.190  44.902  1
107124  99.307  -79.207  44.898  1
107125  99.313  -79.225  44.893  1
107126  99.316  -79.234  44.889  1
107127  99.336  -79.248  44.885  1
107128  99.361  -79.248  44.881  1
107129  99.383  -79.262  44.877  1
107130  99.405  -79.275  44.873  1
107131  99.427  -79.288  44.870  1
107132  99.449  -79.302  44.868  1
107133  99.471  -79.315  44.864  1
107134  99.494  -79.331  44.863  1
107135  99.518  -79.353  44.860  1
107136  99.541  -79.379  44.858  1
107137  99.565  -79.398  44.855  1
107138  99.591  -79.403  44.853  1
107139  99.617  -79.407  44.850  1
107140  99.643  -79.412  44.847  1
107141  99.668  -79.416  44.843  1
107142  99.695  -79.421  44.839  1
107143  99.720  -79.426  44.835  1
107144  99.747  -79.431  44.832  1
107145  99.772  -79.435  44.829  1
107146  99.798  -79.440  44.826  1
107147  99.824  -79.444  44.823  1
107148  99.850  -79.449  44.820  1
107149  99.883  -79.476  44.815  1
107150  99.916  -79.508  44.809  1
107151  99.950  -79.541  44.801  1
107152  99.984  -79.574  44.792  1
107153  100.018  -79.617  44.784  1
107154  100.052  -79.667  44.776  1
107155  100.090  -79.676  44.766  1
107156  100.130  -79.686  44.757  1
107157  100.168  -79.695  44.746  1
107158  100.203  -79.711  44.734  1
107159  100.228  -79.737  44.721  1
107160  100.253  -79.764  44.710  1
107161  100.277  -79.796  44.701  1
107162  100.299  -79.836  44.694  1
107163  100.322  -79.874  44.684  1
107164  100.344  -79.913  44.672  1
107165  100.366  -79.952  44.658  1
107166  100.403  -79.957  44.646  1
107167  100.440  -79.961  44.635  1
107168  100.477  -79.967  44.622  1
107169  100.514  -79.971  44.607  1
107170  100.551  -79.977  44.592  1
107171  100.588  -79.982  44.577  1
107172  100.625  -79.987  44.560  1
107173  100.660  -80.012  44.544  1
107174  100.695  -80.039  44.529  1
107175  100.703  -80.079  44.515  1
107176  100.728  -80.114  44.500  1
107177  100.757  -80.150  44.484  1
107178  100.785  -80.187  44.468  1
107179  100.814  -80.223  44.451  1
107180  100.842  -80.259  44.435  1
107181  100.870  -80.297  44.419  1
107182  100.899  -80.333  44.403  1
107183  100.927  -80.369  44.388  1
107184  100.956  -80.406  44.373  1
107185  100.989  -80.439  44.356  1
107186  101.024  -80.472  44.340  1
107187  101.057  -80.505  44.323  1
107188  101.092  -80.538  44.305  1
107189  101.125  -80.572  44.288  1
107190  101.159  -80.605  44.269  1
107191  101.193  -80.629  44.250  1
107192  101.226  -80.645  44.233  1
107193  101.259  -80.661  44.216  1
107194  101.292  -80.676  44.199  1
107195  101.325  -80.692  44.181  1
107196  101.358  -80.708  44.163  1
107197  101.391  -80.724  44.146  1
107198  101.424  -80.740  44.129  1
107199  101.457  -80.756  44.112  1
107200  101.490  -80.772  44.096  1
107201  101.523  -80.788  44.080  1
107202  101.556  -80.804  44.064  1
107458  93.497  -78.428  53.827  1
107459  93.507  -78.425  53.811  1
107460  93.517  -78.423  53.792  1
107461  93.526  -78.420  53.773  1
107462  93.536  -78.417  53.752  1
107463  93.534  -78.408  53.731  1
107464  93.533  -78.399  53.709  1
107465  93.532  -78.390  53.685  1
107466  93.534  -78.379  53.661  1
107467  93.544  -78.363  53.636  1
107468  93.554  -78.347  53.611  1
107469  93.575  -78.332  53.586  1
107470  93.598  -78.317  53.561  1
107471  93.618  -78.304  53.537  1
107472  93.629  -78.296  53.513  1
107473  93.641  -78.288  53.490  1
107474  93.652  -78.279  53.467  1
107475  93.664  -78.271  53.443  1
107492  93.917  -78.150  53.072  1
107493  93.930  -78.147  53.049  1
107494  93.943  -78.142  53.026  1
107495  93.956  -78.138  53.003  1
107496  93.969  -78.134  52.980  1
107497  93.969  -78.132  52.956  1
107498  93.966  -78.131  52.934  1
107499  93.967  -78.136  52.911  1
107500  93.970  -78.147  52.889  1
107501  93.974  -78.156  52.865  1
107502  93.977  -78.167  52.841  1
107503  93.981  -78.177  52.820  1
107504  93.984  -78.188  52.796  1
107505  93.987  -78.198  52.773  1
107506  93.991  -78.208  52.751  1
107507  93.994  -78.219  52.728  1
107508  93.998  -78.228  52.705  1
107509  94.001  -78.239  52.682  1
107510  94.004  -78.250  52.659  1
107511  94.008  -78.260  52.636  1
107512  94.011  -78.270  52.614  1
107513  94.015  -78.280  52.591  1
107514  94.018  -78.291  52.569  1
107515  94.031  -78.297  52.546  1
107516  94.039  -78.290  52.523  1
107517  94.064  -78.281  52.500  1
107518  94.088  -78.272  52.477  1
107519  94.114  -78.263  52.454  1
107520  94.124  -78.260  52.433  1
107521  94.135  -78.257  52.410  1
107522  94.145  -78.254  52.386  1
107523  94.156  -78.251  52.363  1
107524  94.166  -78.249  52.341  1
107525  94.177  -78.246  52.317  1
107526  94.187  -78.243  52.294  1
107527  94.201  -78.236  52.271  1
107528  94.214  -78.228  52.247  1
107529  94.228  -78.221  52.222  1
107530  94.242  -78.213  52.197  1
107531  94.256  -78.206  52.171  1
107532  94.269  -78.198  52.144  1
107533  94.283  -78.191  52.116  1
107534  94.297  -78.183  52.089  1
107535  94.311  -78.175  52.062  1
107536  94.325  -78.168  52.034  1
107537  94.338  -78.160  52.006  1
107538  94.352  -78.153  51.978  1
107539  94.366  -78.147  51.950  1
107540  94.372  -78.142  51.922  1
107541  94.374  -78.137  51.894  1
107542  94.396  -78.127  51.866  1
107543  94.416  -78.117  51.838  1
107544  94.437  -78.107  51.808  1
107545  94.458  -78.097  51.780  1
107546  94.478  -78.087  51.751  1
107547  94.498  -78.078  51.721  1
107548  94.523  -78.086  51.690  1
107549  94.560  -78.102  51.661  1
107550  94.598  -78.118  51.630  1
107551  94.635  -78.134  51.598  1
107552  94.661  -78.143  51.565  1
107553  94.672  -78.144  51.533  1
107554  94.682  -78.141  51.502  1
107555  94.690  -78.131  51.471  1
107556  94.699  -78.122  51.440  1
107557  94.707  -78.114  51.408  1
107558  94.715  -78.105  51.375  1
107559  94.723  -78.096  51.343  1
107560  94.723  -78.102  51.311  1
107561  94.725  -78.108  51.280  1
107562  94.737  -78.106  51.248  1
107563  94.748  -78.103  51.216  1
107564  94.760  -78.103  51.183  1
107565  94.772  -78.108  51.150  1
107566  94.784  -78.112  51.115  1
107567  94.796  -78.117  51.082  1
107568  94.809  -78.122  51.048  1
107569  94.821  -78.127  51.014  1
107570  94.837  -78.133  50.979  1
107571  94.862  -78.140  50.944  1
107572  94.886  -78.147  50.907  1
107573  94.906  -78.134  50.870  1
107574  94.924  -78.117  50.834  1
107575  94.942  -78.100  50.799  1
107576  94.960  -78.082  50.763  1
107577  94.978  -78.065  50.728  1
107578  94.996  -78.048  50.692  1
107579  95.015  -78.031  50.656  1
107580  95.033  -78.013  50.621  1
107581  95.051  -77.996  50.587  1
107582  95.069  -77.978  50.553  1
107583  95.093  -77.959  50.519  1
107584  95.132  -77.956  50.486  1
107585  95.157  -77.958  50.453  1
107586  95.181  -77.959  50.420  1
107587  95.205  -77.962  50.388  1
107588  95.230  -77.963  50.356  1
107589  95.254  -77.965  50.324  1
107590  95.278  -77.968  50.293  1
107591  95.303  -77.969  50.264  1
107592  95.327  -77.971  50.236  1
107593  95.338  -77.971  50.208  1
107594  95.346  -77.970  50.180  1
107595  95.353  -77.969  50.154  1
107596  95.360  -77.968  50.128  1
107597  95.369  -77.963  50.102  1
107598  95.379  -77.968  50.077  1
107599  95.390  -77.980  50.054  1
107600  95.401  -77.990  50.034  1
107601  95.404  -77.992  50.016  1
107602  95.406  -77.994  50.004  1
107603  95.409  -77.996  49.988  1
107604  95.411  -77.998  49.968  1
107605  95.414  -78.000  49.944  1
107606  95.416  -78.002  49.917  1
107607  95.418  -78.003  49.889  1
107608  95.420  -78.006  49.860  1
107609  95.424  -78.008  49.825  1
107610  95.456  -78.003  49.788  1
107611  95.487  -78.000  49.750  1
107612  95.519  -77.996  49.710  1
107613  95.551  -77.991  49.669  1
107614  95.583  -77.987  49.628  1
107615  95.615  -77.983  49.588  1
107616  95.628  -77.976  49.548  1
107617  95.640  -77.968  49.508  1
107618  95.642  -77.965  49.468  1
107619  95.632  -77.985  49.426  1
107620  95.623  -78.021  49.385  1
107621  95.616  -78.056  49.344  1
107622  95.626  -78.061  49.303  1
107623  95.641  -78.046  49.263  1
107624  95.660  -78.011  49.223  1
107625  95.677  -77.994  49.185  1
107626  95.684  -78.002  49.148  1
107627  95.680  -78.022  49.107  1
107628  95.676  -78.041  49.066  1
107629  95.672  -78.061  49.024  1
107630  95.682  -78.056  48.983  1
107631  95.697  -78.043  48.943  1
107632  95.716  -78.037  48.902  1
107633  95.743  -78.046  48.862  1
107634  95.770  -78.055  48.823  1
107635  95.797  -78.064  48.784  1
107636  95.824  -78.073  48.745  1
107637  95.847  -78.085  48.704  1
107638  95.865  -78.102  48.663  1
107639  95.881  -78.119  48.622  1
107640  95.883  -78.141  48.583  1
107641  95.870  -78.165  48.546  1
107642  95.860  -78.188  48.510  1
107643  95.856  -78.200  48.475  1
107644  95.858  -78.202  48.441  1
107645  95.880  -78.197  48.406  1
107646  95.906  -78.191  48.371  1
107647  95.933  -78.184  48.338  1
107648  95.960  -78.178  48.305  1
107649  95.986  -78.172  48.270  1
107650  96.002  -78.170  48.235  1
107651  96.004  -78.167  48.199  1
107652  96.005  -78.165  48.162  1
107653  96.007  -78.162  48.125  1
107654  96.008  -78.159  48.090  1
107655  96.010  -78.156  48.059  1
107656  96.011  -78.152  48.028  1
107657  96.029  -78.158  47.997  1
107658  96.054  -78.166  47.966  1
107659  96.079  -78.173  47.934  1
107660  96.104  -78.181  47.903  1
107661  96.125  -78.187  47.872  1
107662  96.141  -78.191  47.841  1
107663  96.156  -78.198  47.811  1
107664  96.172  -78.208  47.780  1
107665  96.187  -78.218  47.750  1
107666  96.202  -78.232  47.720  1
107667  96.217  -78.244  47.690  1
107668  96.232  -78.258  47.662  1
107669  96.252  -78.277  47.635  1
107670  96.272  -78.296  47.608  1
107671  96.288  -78.313  47.582  1
107672  96.291  -78.326  47.556  1
107673  96.300  -78.340  47.530  1
107674  96.315  -78.354  47.504  1
107675  96.329  -78.368  47.477  1
107676  96.344  -78.379  47.450  1
107677  96.360  -78.385  47.424  1
107678  96.389  -78.385  47.398  1
107679  96.419  -78.384  47.374  1
107680  96.450  -78.383  47.347  1
107681  96.480  -78.382  47.321  1
107682  96.511  -78.382  47.294  1
107683  96.541  -78.381  47.270  1
107684  96.571  -78.380  47.246  1
107685  96.575  -78.388  47.222  1
107686  96.579  -78.398  47.196  1
107687  96.582  -78.407  47.171  1
107688  96.586  -78.415  47.146  1
107689  96.590  -78.424  47.119  1
107690  96.594  -78.433  47.094  1
107691  96.602  -78.442  47.069  1
107692  96.609  -78.448  47.044  1
107693  96.614  -78.453  47.017  1
107694  96.620  -78.477  46.989  1
107695  96.626  -78.498  46.961  1
107696  96.636  -78.508  46.935  1
107697  96.645  -78.517  46.910  1
107698  96.655  -78.527  46.886  1
107699  96.664  -78.536  46.862  1
107700  96.674  -78.546  46.838  1
107701  96.670  -78.567  46.813  1
107702  96.665  -78.588  46.789  1
107703  96.660  -78.610  46.766  1
107704  96.664  -78.636  46.743  1
107705  96.683  -78.667  46.719  1
107706  96.702  -78.698  46.696  1
107707  96.721  -78.729  46.672  1
107708  96.740  -78.760  46.649  1
107709  96.759  -78.791  46.625  1
107710  96.779  -78.821  46.599  1
107711  96.814  -78.831  46.576  1
107712  96.850  -78.842  46.552  1
107713  96.885  -78.852  46.529  1
107714  96.915  -78.864  46.504  1
107715  96.945  -78.876  46.479  1
107716  97.005  -78.832  46.453  1
107717  97.014  -78.872  46.428  1
107718  97.015  -78.895  46.405  1
107719  97.027  -78.902  46.382  1
107720  97.058  -78.899  46.360  1
107721  97.088  -78.897  46.338  1
107722  97.119  -78.894  46.316  1
107723  97.188  -78.902  46.294  1
107724  97.270  -78.912  46.273  1
107725  97.314  -78.905  46.253  1
107726  97.357  -78.897  46.233  1
107727  97.400  -78.889  46.213  1
107728  97.440  -78.880  46.195  1
107729  97.475  -78.868  46.177  1
107730  97.510  -78.857  46.159  1
107731  97.544  -78.846  46.142  1
107732  97.579  -78.834  46.125  1
107733  97.613  -78.823  46.109  1
107734  97.644  -78.813  46.093  1
107735  97.621  -78.830  46.079  1
107736  97.614  -78.865  46.064  1
107737  97.628  -78.857  46.048  1
107738  97.641  -78.848  46.032  1
107739  97.655  -78.839  46.015  1
107740  97.669  -78.830  45.999  1
107741  97.684  -78.823  45.983  1
107742  97.728  -78.831  45.967  1
107743  97.779  -78.836  45.951  1
107744  97.812  -78.798  45.935  1
107745  97.833  -78.754  45.919  1
107746  97.850  -78.742  45.901  1
107747  97.865  -78.733  45.884  1
107748  97.881  -78.724  45.867  1
107749  97.897  -78.715  45.850  1
107750  97.913  -78.706  45.835  1
107751  97.914  -78.694  45.819  1
107752  97.898  -78.678  45.803  1
107753  97.881  -78.663  45.787  1
107754  97.864  -78.670  45.772  1
107755  97.858  -78.688  45.758  1
107756  97.876  -78.680  45.744  1
107757  97.928  -78.663  45.731  1
107758  97.915  -78.742  45.718  1
107759  97.905  -78.793  45.706  1
107760  97.909  -78.811  45.695  1
107761  97.938  -78.814  45.682  1
107762  97.967  -78.817  45.669  1
107763  97.997  -78.820  45.656  1
107764  98.026  -78.823  45.642  1
107765  98.055  -78.826  45.627  1
107766  98.084  -78.829  45.611  1
107767  98.113  -78.832  45.595  1
107768  98.143  -78.835  45.578  1
107769  98.172  -78.838  45.561  1
107770  98.185  -78.843  45.544  1
107771  98.193  -78.858  45.529  1
107772  98.200  -78.873  45.517  1
107773  98.208  -78.888  45.505  1
107774  98.215  -78.903  45.492  1
107775  98.223  -78.919  45.476  1
107776  98.230  -78.934  45.462  1
107777  98.238  -78.949  45.448  1
107778  98.245  -78.965  45.436  1
107779  98.269  -79.019  45.424  1
107780  98.293  -79.043  45.411  1
107781  98.322  -79.040  45.397  1
107782  98.350  -79.037  45.381  1
107783  98.375  -79.033  45.367  1
107784  98.392  -79.027  45.354  1
107785  98.405  -79.012  45.343  1
107786  98.408  -78.987  45.330  1
107787  98.411  -78.961  45.318  1
107788  98.440  -78.965  45.307  1
107789  98.473  -78.971  45.295  1
107790  98.507  -78.980  45.283  1
107791  98.541  -78.988  45.270  1
107792  98.565  -78.995  45.259  1
107793  98.589  -79.002  45.246  1
107794  98.613  -79.008  45.234  1
107795  98.637  -79.015  45.224  1
107796  98.661  -79.021  45.214  1
107797  98.685  -79.028  45.204  1
107798  98.709  -79.034  45.193  1
107799  98.733  -79.040  45.183  1
107800  98.757  -79.047  45.172  1
107801  98.781  -79.054  45.161  1
107802  98.805  -79.060  45.150  1
107803  98.829  -79.067  45.137  1
107804  98.852  -79.073  45.125  1
107805  98.874  -79.080  45.114  1
107806  98.897  -79.087  45.101  1
107807  98.919  -79.093  45.089  1
107808  98.956  -79.111  45.076  1
107809  98.980  -79.100  45.064  1
107810  99.004  -79.091  45.051  1
107811  99.029  -79.092  45.038  1
107812  99.054  -79.093  45.025  1
107813  99.079  -79.094  45.012  1
107814  99.104  -79.096  45.000  1
107815  99.129  -79.096  44.989  1
107816  99.154  -79.098  44.979  1
107817  99.182  -79.100  44.969  1
107818  99.209  -79.101  44.960  1
107819  99.236  -79.103  44.950  1
107820  99.258  -79.112  44.940  1
107821  99.277  -79.124  44.931  1
107822  99.285  -79.140  44.922  1
107823  99.292  -79.158  44.914  1
107824  99.298  -79.175  44.909  1
107825  99.303  -79.191  44.904  1
107826  99.306  -79.200  44.900  1
107827  99.309  -79.209  44.896  1
107828  99.323  -79.244  44.891  1
107829  99.349  -79.240  44.886  1
107830  99.376  -79.235  44.881  1
107831  99.402  -79.235  44.878  1
107832  99.423  -79.248  44.876  1
107833  99.445  -79.262  44.873  1
107834  99.470  -79.279  44.870  1
107835  99.495  -79.297  44.868  1
107836  99.517  -79.324  44.866  1
107837  99.540  -79.351  44.864  1
107838  99.563  -79.379  44.860  1
107839  99.588  -79.386  44.857  1
107840  99.614  -79.391  44.854  1
107841  99.640  -79.395  44.851  1
107842  99.666  -79.400  44.850  1
107843  99.692  -79.405  44.847  1
107844  99.718  -79.410  44.844  1
107845  99.744  -79.414  44.841  1
107846  99.770  -79.419  44.838  1
107847  99.795  -79.423  44.834  1
107848  99.822  -79.428  44.830  1
107849  99.850  -79.441  44.825  1
107850  99.884  -79.474  44.818  1
107851  99.918  -79.507  44.810  1
107852  99.952  -79.540  44.802  1
107853  99.986  -79.573  44.793  1
107854  100.020  -79.614  44.784  1
107855  100.054  -79.661  44.776  1
107856  100.093  -79.670  44.767  1
107857  100.132  -79.679  44.758  1
107858  100.171  -79.689  44.748  1
107859  100.210  -79.698  44.736  1
107860  100.238  -79.722  44.723  1
107861  100.263  -79.748  44.712  1
107862  100.286  -79.784  44.701  1
107863  100.309  -79.823  44.693  1
107864  100.331  -79.861  44.683  1
107865  100.353  -79.900  44.671  1
107866  100.375  -79.939  44.657  1
107867  100.409  -79.952  44.645  1
107868  100.446  -79.957  44.633  1
107869  100.483  -79.962  44.621  1
107870  100.520  -79.967  44.605  1
107871  100.557  -79.972  44.590  1
107872  100.594  -79.977  44.575  1
107873  100.631  -79.982  44.558  1
107874  100.668  -79.987  44.543  1
107875  100.703  -80.012  44.529  1
107876  100.720  -80.048  44.515  1
107877  100.748  -80.084  44.499  1
107878  100.776  -80.121  44.484  1
107879  100.805  -80.157  44.468  1
107880  100.833  -80.193  44.451  1
107881  100.863  -80.228  44.436  1
107882  100.897  -80.262  44.421  1
107883  100.931  -80.295  44.405  1
107884  100.966  -80.328  44.390  1
107885  100.999  -80.362  44.375  1
107886  101.034  -80.394  44.359  1
107887  101.067  -80.428  44.343  1
107888  101.102  -80.461  44.325  1
107889  101.135  -80.494  44.308  1
107890  101.170  -80.527  44.291  1
107891  101.204  -80.560  44.273  1
107892  101.237  -80.583  44.256  1
107893  101.270  -80.599  44.239  1
107894  101.303  -80.615  44.222  1
107895  101.336  -80.630  44.204  1
107896  101.369  -80.646  44.187  1
107897  101.402  -80.662  44.169  1
107898  101.435  -80.678  44.152  1
107899  101.468  -80.694  44.135  1
107900  101.501  -80.710  44.119  1
107901  101.534  -80.726  44.102  1
107902  101.567  -80.742  44.086  1
107903  101.600  -80.757  44.070  1
107904  101.633  -80.773  44.052  1
108160  93.507  -78.414  53.802  1
108161  93.517  -78.412  53.784  1
108162  93.527  -78.410  53.764  1
108163  93.532  -78.404  53.743  1
108164  93.531  -78.395  53.721  1
108165  93.530  -78.385  53.700  1
108166  93.528  -78.376  53.676  1
108167  93.536  -78.363  53.652  1
108168  93.546  -78.347  53.626  1
108169  93.558  -78.332  53.602  1
108170  93.581  -78.316  53.577  1
108171  93.604  -78.302  53.552  1
108172  93.619  -78.291  53.528  1
108173  93.631  -78.282  53.505  1
108174  93.642  -78.275  53.481  1
108175  93.654  -78.266  53.457  1
108176  93.665  -78.258  53.434  1
108194  93.931  -78.135  53.036  1
108195  93.943  -78.131  53.013  1
108196  93.957  -78.127  52.989  1
108197  93.969  -78.122  52.965  1
108198  93.969  -78.121  52.941  1
108199  93.967  -78.120  52.917  1
108200  93.966  -78.123  52.894  1
108201  93.970  -78.133  52.871  1
108202  93.973  -78.144  52.848  1
108203  93.977  -78.153  52.824  1
108204  93.980  -78.164  52.802  1
108205  93.983  -78.174  52.778  1
108206  93.987  -78.184  52.754  1
108207  93.990  -78.195  52.731  1
108208  93.994  -78.205  52.708  1
108209  93.997  -78.216  52.685  1
108210  94.000  -78.225  52.662  1
108211  94.004  -78.236  52.638  1
108212  94.007  -78.247  52.615  1
108213  94.011  -78.257  52.592  1
108214  94.014  -78.267  52.569  1
108215  94.018  -78.277  52.546  1
108216  94.034  -78.282  52.523  1
108217  94.040  -78.273  52.499  1
108218  94.065  -78.264  52.475  1
108219  94.090  -78.254  52.452  1
108220  94.115  -78.245  52.430  1
108221  94.134  -78.238  52.407  1
108222  94.145  -78.236  52.384  1
108223  94.155  -78.233  52.360  1
108224  94.166  -78.231  52.335  1
108225  94.177  -78.228  52.311  1
108226  94.187  -78.225  52.287  1
108227  94.197  -78.222  52.264  1
108228  94.210  -78.216  52.239  1
108229  94.223  -78.209  52.215  1
108230  94.238  -78.201  52.190  1
108231  94.251  -78.194  52.164  1
108232  94.265  -78.186  52.138  1
108233  94.279  -78.178  52.112  1
108234  94.292  -78.171  52.086  1
108235  94.306  -78.163  52.059  1
108236  94.320  -78.156  52.034  1
108237  94.334  -78.148  52.007  1
108238  94.347  -78.141  51.980  1
108239  94.361  -78.134  51.953  1
108240  94.376  -78.128  51.926  1
108241  94.385  -78.122  51.899  1
108242  94.386  -78.118  51.872  1
108243  94.398  -78.110  51.845  1
108244  94.419  -78.100  51.817  1
108245  94.439  -78.091  51.789  1
108246  94.460  -78.080  51.762  1
108247  94.481  -78.070  51.734  1
108248  94.501  -78.060  51.705  1
108249  94.519  -78.061  51.676  1
108250  94.556  -78.077  51.647  1
108251  94.594  -78.094  51.617  1
108252  94.631  -78.109  51.587  1
108253  94.659  -78.120  51.555  1
108254  94.671  -78.121  51.524  1
108255  94.682  -78.121  51.493  1
108256  94.690  -78.112  51.464  1
108257  94.699  -78.104  51.433  1
108258  94.707  -78.095  51.402  1
108259  94.715  -78.086  51.370  1
108260  94.723  -78.078  51.338  1
108261  94.724  -78.082  51.307  1
108262  94.724  -78.090  51.276  1
108263  94.734  -78.088  51.244  1
108264  94.746  -78.086  51.213  1
108265  94.758  -78.085  51.181  1
108266  94.770  -78.091  51.148  1
108267  94.782  -78.095  51.113  1
108268  94.794  -78.100  51.080  1
108269  94.806  -78.105  51.046  1
108270  94.818  -78.109  51.012  1
108271  94.840  -78.116  50.978  1
108272  94.864  -78.124  50.943  1
108273  94.889  -78.131  50.907  1
108274  94.908  -78.116  50.870  1
108275  94.926  -78.098  50.834  1
108276  94.944  -78.081  50.799  1
108277  94.962  -78.064  50.764  1
108278  94.981  -78.047  50.729  1
108279  94.999  -78.029  50.694  1
108280  95.017  -78.012  50.658  1
108281  95.035  -77.995  50.624  1
108282  95.053  -77.978  50.589  1
108283  95.071  -77.961  50.556  1
108284  95.090  -77.943  50.522  1
108285  95.115  -77.939  50.490  1
108286  95.140  -77.940  50.457  1
108287  95.164  -77.943  50.424  1
108288  95.188  -77.944  50.392  1
108289  95.213  -77.946  50.361  1
108290  95.237  -77.949  50.329  1
108291  95.261  -77.950  50.299  1
108292  95.285  -77.953  50.271  1
108293  95.310  -77.954  50.242  1
108294  95.334  -77.956  50.214  1
108295  95.342  -77.956  50.188  1
108296  95.350  -77.955  50.162  1
108297  95.357  -77.952  50.137  1
108298  95.367  -77.956  50.112  1
108299  95.379  -77.967  50.089  1
108300  95.383  -77.970  50.067  1
108301  95.385  -77.972  50.047  1
108302  95.388  -77.974  50.031  1
108303  95.390  -77.976  50.016  1
108304  95.393  -77.978  49.998  1
108305  95.395  -77.980  49.976  1
108306  95.398  -77.981  49.951  1
108307  95.400  -77.984  49.923  1
108308  95.403  -77.985  49.893  1
108309  95.409  -77.987  49.861  1
108310  95.422  -77.992  49.825  1
108311  95.453  -77.982  49.787  1
108312  95.485  -77.978  49.747  1
108313  95.517  -77.974  49.704  1
108314  95.549  -77.969  49.663  1
108315  95.581  -77.965  49.622  1
108316  95.612  -77.961  49.582  1
108317  95.644  -77.957  49.542  1
108318  95.661  -77.950  49.502  1
108319  95.671  -77.943  49.462  1
108320  95.659  -77.949  49.422  1
108321  95.650  -77.986  49.382  1
108322  95.656  -78.012  49.342  1
108323  95.662  -77.995  49.302  1
108324  95.665  -77.970  49.263  1
108325  95.689  -77.956  49.225  1
108326  95.687  -77.974  49.188  1
108327  95.683  -77.993  49.150  1
108328  95.680  -78.013  49.111  1
108329  95.676  -78.033  49.070  1
108330  95.674  -78.050  49.028  1
108331  95.689  -78.036  48.988  1
108332  95.704  -78.022  48.946  1
108333  95.731  -78.031  48.905  1
108334  95.758  -78.040  48.864  1
108335  95.784  -78.050  48.826  1
108336  95.812  -78.059  48.787  1
108337  95.838  -78.068  48.748  1
108338  95.865  -78.077  48.708  1
108339  95.888  -78.089  48.668  1
108340  95.901  -78.107  48.627  1
108341  95.888  -78.132  48.587  1
108342  95.876  -78.156  48.550  1
108343  95.870  -78.172  48.513  1
108344  95.872  -78.174  48.477  1
108345  95.874  -78.175  48.441  1
108346  95.894  -78.172  48.406  1
108347  95.920  -78.166  48.371  1
108348  95.947  -78.159  48.337  1
108349  95.974  -78.153  48.305  1
108350  95.990  -78.151  48.271  1
108351  96.007  -78.150  48.235  1
108352  96.021  -78.149  48.201  1
108353  96.022  -78.147  48.165  1
108354  96.024  -78.144  48.130  1
108355  96.025  -78.141  48.096  1
108356  96.027  -78.138  48.066  1
108357  96.028  -78.135  48.036  1
108358  96.043  -78.140  48.008  1
108359  96.067  -78.149  47.977  1
108360  96.093  -78.156  47.947  1
108361  96.118  -78.164  47.917  1
108362  96.135  -78.169  47.887  1
108363  96.151  -78.174  47.855  1
108364  96.166  -78.178  47.825  1
108365  96.181  -78.186  47.796  1
108366  96.196  -78.197  47.768  1
108367  96.212  -78.211  47.738  1
108368  96.226  -78.224  47.709  1
108369  96.241  -78.238  47.680  1
108370  96.257  -78.252  47.653  1
108371  96.277  -78.271  47.627  1
108372  96.286  -78.285  47.602  1
108373  96.297  -78.299  47.575  1
108374  96.312  -78.313  47.549  1
108375  96.326  -78.327  47.523  1
108376  96.340  -78.341  47.497  1
108377  96.355  -78.354  47.471  1
108378  96.371  -78.360  47.444  1
108379  96.387  -78.366  47.419  1
108380  96.416  -78.365  47.396  1
108381  96.447  -78.364  47.370  1
108382  96.477  -78.363  47.344  1
108383  96.508  -78.363  47.319  1
108384  96.538  -78.362  47.295  1
108385  96.555  -78.366  47.270  1
108386  96.559  -78.375  47.245  1
108387  96.563  -78.384  47.222  1
108388  96.567  -78.392  47.197  1
108389  96.571  -78.401  47.171  1
108390  96.578  -78.410  47.144  1
108391  96.588  -78.420  47.118  1
108392  96.596  -78.427  47.090  1
108393  96.596  -78.428  47.063  1
108394  96.605  -78.436  47.036  1
108395  96.610  -78.460  47.010  1
108396  96.616  -78.484  46.984  1
108397  96.622  -78.507  46.958  1
108398  96.631  -78.517  46.933  1
108399  96.641  -78.526  46.908  1
108400  96.650  -78.535  46.884  1
108401  96.660  -78.545  46.860  1
108402  96.655  -78.567  46.835  1
108403  96.650  -78.588  46.810  1
108404  96.645  -78.610  46.786  1
108405  96.639  -78.632  46.764  1
108406  96.649  -78.659  46.740  1
108407  96.668  -78.690  46.715  1
108408  96.687  -78.721  46.691  1
108409  96.706  -78.752  46.667  1
108410  96.725  -78.783  46.642  1
108411  96.760  -78.795  46.616  1
108412  96.795  -78.805  46.592  1
108413  96.830  -78.815  46.568  1
108414  96.865  -78.826  46.543  1
108415  96.895  -78.838  46.518  1
108416  96.970  -78.849  46.492  1
108417  97.011  -78.861  46.465  1
108418  97.018  -78.844  46.439  1
108419  97.001  -78.865  46.414  1
108420  97.006  -78.886  46.390  1
108421  97.022  -78.890  46.367  1
108422  97.076  -78.893  46.344  1
108423  97.158  -78.903  46.321  1
108424  97.228  -78.908  46.299  1
108425  97.271  -78.900  46.278  1
108426  97.314  -78.893  46.259  1
108427  97.357  -78.884  46.239  1
108428  97.400  -78.877  46.219  1
108429  97.435  -78.865  46.200  1
108430  97.470  -78.854  46.182  1
108431  97.505  -78.843  46.165  1
108432  97.539  -78.831  46.148  1
108433  97.574  -78.820  46.131  1
108434  97.608  -78.808  46.115  1
108435  97.643  -78.797  46.100  1
108436  97.664  -78.789  46.086  1
108437  97.657  -78.825  46.070  1
108438  97.650  -78.860  46.054  1
108439  97.658  -78.865  46.038  1
108440  97.672  -78.855  46.022  1
108441  97.687  -78.847  46.006  1
108442  97.731  -78.856  45.991  1
108443  97.774  -78.865  45.976  1
108444  97.817  -78.874  45.960  1
108445  97.840  -78.833  45.945  1
108446  97.860  -78.789  45.929  1
108447  97.880  -78.745  45.911  1
108448  97.897  -78.732  45.894  1
108449  97.913  -78.724  45.877  1
108450  97.929  -78.714  45.859  1
108451  97.945  -78.705  45.844  1
108452  97.937  -78.692  45.827  1
108453  97.921  -78.676  45.811  1
108454  97.904  -78.660  45.796  1
108455  97.892  -78.668  45.780  1
108456  97.885  -78.706  45.765  1
108457  97.879  -78.679  45.750  1
108458  97.929  -78.661  45.737  1
108459  97.938  -78.708  45.724  1
108460  97.925  -78.768  45.711  1
108461  97.925  -78.789  45.698  1
108462  97.939  -78.801  45.685  1
108463  97.968  -78.804  45.673  1
108464  97.998  -78.807  45.660  1
108465  98.027  -78.809  45.645  1
108466  98.056  -78.812  45.629  1
108467  98.086  -78.815  45.613  1
108468  98.115  -78.818  45.599  1
108469  98.144  -78.821  45.585  1
108470  98.170  -78.829  45.569  1
108471  98.184  -78.831  45.553  1
108472  98.190  -78.820  45.537  1
108473  98.197  -78.835  45.525  1
108474  98.205  -78.850  45.513  1
108475  98.212  -78.865  45.502  1
108476  98.220  -78.880  45.489  1
108477  98.228  -78.896  45.476  1
108478  98.235  -78.911  45.463  1
108479  98.253  -78.934  45.451  1
108480  98.273  -78.999  45.437  1
108481  98.296  -79.034  45.422  1
108482  98.324  -79.031  45.408  1
108483  98.353  -79.028  45.392  1
108484  98.381  -79.024  45.378  1
108485  98.410  -79.021  45.366  1
108486  98.426  -79.010  45.354  1
108487  98.429  -78.984  45.343  1
108488  98.433  -78.959  45.332  1
108489  98.452  -78.950  45.322  1
108490  98.485  -78.958  45.309  1
108491  98.516  -78.965  45.296  1
108492  98.540  -78.972  45.283  1
108493  98.564  -78.979  45.268  1
108494  98.588  -78.985  45.254  1
108495  98.612  -78.992  45.242  1
108496  98.636  -78.999  45.232  1
108497  98.660  -79.005  45.221  1
108498  98.684  -79.012  45.210  1
108499  98.706  -79.018  45.199  1
108500  98.728  -79.024  45.188  1
108501  98.750  -79.031  45.177  1
108502  98.773  -79.038  45.166  1
108503  98.795  -79.044  45.155  1
108504  98.817  -79.051  45.143  1
108505  98.839  -79.058  45.131  1
108506  98.861  -79.064  45.120  1
108507  98.884  -79.071  45.108  1
108508  98.939  -79.129  45.097  1
108509  98.972  -79.134  45.086  1
108510  98.995  -79.125  45.074  1
108511  99.019  -79.114  45.061  1
108512  99.043  -79.104  45.048  1
108513  99.066  -79.093  45.035  1
108514  99.090  -79.084  45.021  1
108515  99.114  -79.073  45.009  1
108516  99.137  -79.066  44.998  1
108517  99.162  -79.068  44.988  1
108518  99.188  -79.069  44.980  1
108519  99.213  -79.075  44.971  1
108520  99.233  -79.087  44.960  1
108521  99.253  -79.099  44.948  1
108522  99.272  -79.111  44.938  1
108523  99.283  -79.127  44.929  1
108524  99.289  -79.144  44.920  1
108525  99.294  -79.157  44.913  1
108526  99.296  -79.166  44.906  1
108527  99.299  -79.175  44.901  1
108528  99.302  -79.184  44.896  1
108529  99.315  -79.219  44.892  1
108530  99.336  -79.235  44.888  1
108531  99.363  -79.231  44.884  1
108532  99.390  -79.227  44.881  1
108533  99.427  -79.221  44.878  1
108534  99.445  -79.227  44.875  1
108535  99.470  -79.245  44.872  1
108536  99.494  -79.269  44.870  1
108537  99.516  -79.296  44.868  1
108538  99.539  -79.323  44.866  1
108539  99.562  -79.350  44.864  1
108540  99.586  -79.370  44.861  1
108541  99.612  -79.375  44.859  1
108542  99.638  -79.379  44.858  1
108543  99.663  -79.384  44.857  1
108544  99.689  -79.388  44.855  1
108545  99.715  -79.393  44.852  1
108546  99.741  -79.397  44.849  1
108547  99.767  -79.402  44.844  1
108548  99.793  -79.407  44.839  1
108549  99.819  -79.411  44.833  1
108550  99.852  -79.440  44.827  1
108551  99.886  -79.473  44.819  1
108552  99.920  -79.506  44.810  1
108553  99.954  -79.538  44.802  1
108554  99.988  -79.571  44.793  1
108555  100.021  -79.612  44.784  1
108556  100.056  -79.654  44.776  1
108557  100.096  -79.664  44.767  1
108558  100.134  -79.673  44.758  1
108559  100.174  -79.683  44.749  1
108560  100.212  -79.692  44.737  1
108561  100.248  -79.706  44.725  1
108562  100.273  -79.733  44.713  1
108563  100.295  -79.771  44.702  1
108564  100.318  -79.810  44.691  1
108565  100.340  -79.849  44.680  1
108566  100.362  -79.888  44.669  1
108567  100.385  -79.927  44.657  1
108568  100.415  -79.947  44.644  1
108569  100.452  -79.952  44.631  1
108570  100.489  -79.957  44.618  1
108571  100.525  -79.962  44.604  1
108572  100.563  -79.967  44.588  1
108573  100.600  -79.972  44.572  1
108574  100.637  -79.977  44.557  1
108575  100.674  -79.982  44.543  1
108576  100.711  -79.987  44.528  1
108577  100.739  -80.018  44.514  1
108578  100.771  -80.052  44.499  1
108579  100.805  -80.085  44.484  1
108580  100.839  -80.118  44.469  1
108581  100.874  -80.151  44.453  1
108582  100.908  -80.184  44.438  1
108583  100.941  -80.218  44.423  1
108584  100.976  -80.251  44.408  1
108585  101.009  -80.284  44.393  1
108586  101.042  -80.318  44.377  1
108587  101.075  -80.352  44.361  1
108588  101.108  -80.385  44.346  1
108589  101.141  -80.419  44.328  1
108590  101.174  -80.453  44.311  1
108591  101.206  -80.487  44.294  1
108592  101.240  -80.521  44.278  1
108593  101.275  -80.538  44.261  1
108594  101.307  -80.554  44.244  1
108595  101.339  -80.571  44.228  1
108596  101.371  -80.587  44.210  1
108597  101.403  -80.603  44.193  1
108598  101.435  -80.620  44.176  1
108599  101.467  -80.635  44.159  1
108600  101.499  -80.651  44.142  1
108601  101.531  -80.668  44.125  1
108602  101.563  -80.684  44.108  1
108603  101.596  -80.700  44.092  1
108604  101.628  -80.716  44.075  1
108605  101.659  -80.732  44.057  1
108862  93.517  -78.401  53.775  1
108863  93.527  -78.398  53.755  1
108864  93.529  -78.391  53.733  1
108865  93.528  -78.382  53.711  1
108866  93.526  -78.373  53.689  1
108867  93.526  -78.363  53.667  1
108868  93.537  -78.347  53.642  1
108869  93.547  -78.332  53.616  1
108870  93.564  -78.316  53.592  1
108871  93.586  -78.301  53.568  1
108872  93.609  -78.286  53.543  1
108873  93.620  -78.278  53.520  1
108874  93.632  -78.269  53.496  1
108875  93.643  -78.261  53.473  1
108876  93.655  -78.253  53.448  1
108877  93.666  -78.245  53.425  1
108895  93.931  -78.124  53.022  1
108896  93.944  -78.120  52.999  1
108897  93.957  -78.116  52.975  1
108898  93.970  -78.111  52.951  1
108899  93.970  -78.109  52.927  1
108900  93.967  -78.109  52.903  1
108901  93.966  -78.109  52.879  1
108902  93.969  -78.120  52.856  1
108903  93.973  -78.130  52.832  1
108904  93.976  -78.141  52.808  1
108905  93.979  -78.150  52.784  1
108906  93.983  -78.161  52.761  1
108907  93.986  -78.172  52.737  1
108908  93.990  -78.181  52.714  1
108909  93.993  -78.192  52.691  1
108910  93.996  -78.202  52.667  1
108911  94.000  -78.213  52.644  1
108912  94.003  -78.222  52.619  1
108913  94.007  -78.233  52.595  1
108914  94.010  -78.244  52.572  1
108915  94.013  -78.253  52.549  1
108916  94.021  -78.262  52.526  1
108917  94.036  -78.266  52.503  1
108918  94.042  -78.256  52.479  1
108919  94.066  -78.247  52.454  1
108920  94.091  -78.238  52.431  1
108921  94.117  -78.228  52.407  1
108922  94.141  -78.219  52.384  1
108923  94.155  -78.216  52.360  1
108924  94.166  -78.213  52.336  1
108925  94.176  -78.210  52.312  1
108926  94.187  -78.207  52.287  1
108927  94.197  -78.204  52.263  1
108928  94.208  -78.202  52.238  1
108929  94.219  -78.197  52.214  1
108930  94.233  -78.190  52.190  1
108931  94.247  -78.182  52.165  1
108932  94.260  -78.175  52.139  1
108933  94.274  -78.167  52.113  1
108934  94.288  -78.159  52.088  1
108935  94.301  -78.152  52.063  1
108936  94.315  -78.144  52.037  1
108937  94.329  -78.137  52.011  1
108938  94.343  -78.129  51.986  1
108939  94.356  -78.122  51.960  1
108940  94.370  -78.116  51.934  1
108941  94.385  -78.109  51.908  1
108942  94.397  -78.103  51.882  1
108943  94.399  -78.098  51.856  1
108944  94.401  -78.094  51.830  1
108945  94.421  -78.084  51.804  1
108946  94.442  -78.074  51.776  1
108947  94.463  -78.063  51.749  1
108948  94.483  -78.053  51.721  1
108949  94.504  -78.044  51.694  1
108950  94.521  -78.041  51.666  1
108951  94.551  -78.053  51.638  1
108952  94.589  -78.069  51.608  1
108953  94.626  -78.085  51.577  1
108954  94.657  -78.097  51.547  1
108955  94.669  -78.098  51.517  1
108956  94.681  -78.098  51.487  1
108957  94.691  -78.094  51.458  1
108958  94.699  -78.085  51.428  1
108959  94.707  -78.077  51.397  1
108960  94.715  -78.068  51.365  1
108961  94.723  -78.059  51.334  1
108962  94.725  -78.062  51.303  1
108963  94.724  -78.070  51.272  1
108964  94.732  -78.072  51.242  1
108965  94.744  -78.069  51.211  1
108966  94.755  -78.068  51.179  1
108967  94.767  -78.073  51.146  1
108968  94.779  -78.078  51.113  1
108969  94.791  -78.083  51.079  1
108970  94.804  -78.087  51.045  1
108971  94.818  -78.093  51.011  1
108972  94.842  -78.100  50.978  1
108973  94.867  -78.107  50.943  1
108974  94.892  -78.114  50.907  1
108975  94.910  -78.097  50.870  1
108976  94.928  -78.080  50.835  1
108977  94.947  -78.062  50.800  1
108978  94.965  -78.046  50.765  1
108979  94.983  -78.028  50.731  1
108980  95.001  -78.011  50.696  1
108981  95.019  -77.993  50.660  1
108982  95.037  -77.977  50.626  1
108983  95.055  -77.959  50.592  1
108984  95.074  -77.942  50.558  1
108985  95.088  -77.927  50.525  1
108986  95.102  -77.913  50.493  1
108987  95.125  -77.917  50.461  1
108988  95.149  -77.921  50.428  1
108989  95.173  -77.924  50.396  1
108990  95.196  -77.928  50.365  1
108991  95.220  -77.931  50.335  1
108992  95.245  -77.934  50.305  1
108993  95.269  -77.935  50.277  1
108994  95.294  -77.937  50.249  1
108995  95.318  -77.940  50.222  1
108996  95.339  -77.941  50.196  1
108997  95.346  -77.940  50.171  1
108998  95.356  -77.943  50.147  1
108999  95.362  -77.948  50.124  1
109000  95.365  -77.950  50.102  1
109001  95.367  -77.952  50.081  1
109002  95.369  -77.954  50.061  1
109003  95.373  -77.956  50.044  1
109004  95.379  -77.959  50.027  1
109005  95.386  -77.961  50.006  1
109006  95.392  -77.963  49.982  1
109007  95.399  -77.965  49.955  1
109008  95.405  -77.968  49.925  1
109009  95.411  -77.970  49.893  1
109010  95.418  -77.972  49.859  1
109011  95.429  -77.981  49.822  1
109012  95.454  -77.990  49.782  1
109013  95.485  -77.979  49.740  1
109014  95.516  -77.968  49.696  1
109015  95.547  -77.957  49.656  1
109016  95.579  -77.946  49.616  1
109017  95.610  -77.939  49.577  1
109018  95.641  -77.935  49.538  1
109019  95.674  -77.931  49.498  1
109020  95.694  -77.925  49.459  1
109021  95.686  -77.925  49.420  1
109022  95.677  -77.958  49.380  1
109023  95.679  -77.995  49.341  1
109024  95.674  -77.993  49.302  1
109025  95.734  -77.946  49.264  1
109026  95.691  -77.945  49.226  1
109027  95.687  -77.965  49.189  1
109028  95.683  -77.985  49.152  1
109029  95.679  -78.005  49.114  1
109030  95.676  -78.025  49.074  1
109031  95.681  -78.028  49.033  1
109032  95.696  -78.015  48.993  1
109033  95.719  -78.016  48.952  1
109034  95.746  -78.025  48.910  1
109035  95.772  -78.034  48.870  1
109036  95.799  -78.044  48.830  1
109037  95.826  -78.053  48.790  1
109038  95.853  -78.062  48.751  1
109039  95.880  -78.072  48.712  1
109040  95.906  -78.081  48.672  1
109041  95.906  -78.100  48.632  1
109042  95.893  -78.125  48.592  1
109043  95.885  -78.144  48.555  1
109044  95.886  -78.145  48.519  1
109045  95.888  -78.147  48.483  1
109046  95.890  -78.150  48.446  1
109047  95.908  -78.146  48.409  1
109048  95.935  -78.140  48.373  1
109049  95.961  -78.134  48.338  1
109050  95.977  -78.132  48.305  1
109051  95.993  -78.131  48.271  1
109052  96.009  -78.131  48.236  1
109053  96.025  -78.129  48.203  1
109054  96.039  -78.128  48.169  1
109055  96.041  -78.125  48.135  1
109056  96.042  -78.122  48.103  1
109057  96.044  -78.120  48.073  1
109058  96.045  -78.117  48.045  1
109059  96.057  -78.120  48.017  1
109060  96.082  -78.129  47.989  1
109061  96.106  -78.139  47.961  1
109062  96.130  -78.147  47.931  1
109063  96.146  -78.152  47.901  1
109064  96.161  -78.157  47.871  1
109065  96.176  -78.163  47.841  1
109066  96.191  -78.169  47.812  1
109067  96.205  -78.179  47.784  1
109068  96.221  -78.192  47.754  1
109069  96.236  -78.204  47.725  1
109070  96.250  -78.217  47.697  1
109071  96.265  -78.230  47.672  1
109072  96.279  -78.244  47.647  1
109073  96.294  -78.259  47.622  1
109074  96.308  -78.272  47.596  1
109075  96.323  -78.286  47.570  1
109076  96.337  -78.300  47.543  1
109077  96.352  -78.314  47.517  1
109078  96.366  -78.328  47.491  1
109079  96.382  -78.335  47.465  1
109080  96.398  -78.341  47.440  1
109081  96.414  -78.347  47.417  1
109082  96.444  -78.346  47.392  1
109083  96.475  -78.345  47.367  1
109084  96.505  -78.344  47.343  1
109085  96.536  -78.344  47.320  1
109086  96.540  -78.352  47.295  1
109087  96.543  -78.361  47.270  1
109088  96.547  -78.369  47.246  1
109089  96.553  -78.379  47.220  1
109090  96.563  -78.388  47.193  1
109091  96.573  -78.397  47.165  1
109092  96.583  -78.405  47.138  1
109093  96.583  -78.407  47.110  1
109094  96.586  -78.407  47.082  1
109095  96.596  -78.420  47.056  1
109096  96.601  -78.443  47.030  1
109097  96.607  -78.467  47.005  1
109098  96.612  -78.490  46.980  1
109099  96.618  -78.514  46.955  1
109100  96.627  -78.525  46.931  1
109101  96.637  -78.534  46.906  1
109102  96.645  -78.545  46.881  1
109103  96.640  -78.567  46.856  1
109104  96.635  -78.588  46.831  1
109105  96.629  -78.610  46.807  1
109106  96.624  -78.632  46.784  1
109107  96.618  -78.654  46.759  1
109108  96.634  -78.683  46.734  1
109109  96.653  -78.714  46.710  1
109110  96.672  -78.745  46.685  1
109111  96.706  -78.758  46.659  1
109112  96.741  -78.768  46.633  1
109113  96.777  -78.779  46.608  1
109114  96.812  -78.789  46.583  1
109115  96.845  -78.800  46.557  1
109116  96.890  -78.816  46.531  1
109117  96.924  -78.833  46.504  1
109118  96.957  -78.850  46.476  1
109119  96.991  -78.868  46.450  1
109120  97.056  -78.913  46.423  1
109121  97.042  -78.908  46.398  1
109122  97.051  -78.890  46.374  1
109123  97.127  -78.905  46.351  1
109124  97.185  -78.904  46.327  1
109125  97.228  -78.896  46.305  1
109126  97.271  -78.888  46.284  1
109127  97.314  -78.880  46.264  1
109128  97.357  -78.872  46.245  1
109129  97.396  -78.862  46.225  1
109130  97.430  -78.851  46.206  1
109131  97.465  -78.839  46.189  1
109132  97.500  -78.828  46.171  1
109133  97.534  -78.817  46.154  1
109134  97.569  -78.805  46.138  1
109135  97.604  -78.795  46.122  1
109136  97.643  -78.794  46.107  1
109137  97.697  -78.792  46.092  1
109138  97.689  -78.849  46.078  1
109139  97.688  -78.863  46.062  1
109140  97.690  -78.858  46.046  1
109141  97.690  -78.872  46.030  1
109142  97.681  -78.864  46.015  1
109143  97.732  -78.864  46.000  1
109144  97.783  -78.864  45.985  1
109145  97.820  -78.846  45.969  1
109146  97.850  -78.827  45.954  1
109147  97.886  -78.823  45.939  1
109148  97.908  -78.780  45.922  1
109149  97.928  -78.737  45.905  1
109150  97.945  -78.723  45.887  1
109151  97.961  -78.714  45.869  1
109152  97.977  -78.705  45.854  1
109153  97.960  -78.689  45.837  1
109154  97.943  -78.673  45.821  1
109155  97.924  -78.665  45.805  1
109156  97.920  -78.686  45.790  1
109157  97.911  -78.718  45.775  1
109158  97.900  -78.683  45.760  1
109159  97.931  -78.659  45.746  1
109160  97.962  -78.673  45.732  1
109161  97.945  -78.745  45.718  1
109162  97.945  -78.764  45.704  1
109163  97.945  -78.785  45.691  1
109164  97.969  -78.790  45.678  1
109165  97.999  -78.793  45.664  1
109166  98.028  -78.796  45.649  1
109167  98.058  -78.799  45.634  1
109168  98.087  -78.802  45.619  1
109169  98.116  -78.805  45.604  1
109170  98.145  -78.808  45.590  1
109171  98.167  -78.822  45.576  1
109172  98.184  -78.829  45.560  1
109173  98.190  -78.818  45.545  1
109174  98.195  -78.805  45.533  1
109175  98.202  -78.812  45.522  1
109176  98.210  -78.827  45.512  1
109177  98.217  -78.843  45.499  1
109178  98.225  -78.858  45.486  1
109179  98.232  -78.873  45.473  1
109180  98.257  -78.915  45.461  1
109181  98.277  -78.981  45.446  1
109182  98.299  -79.024  45.432  1
109183  98.327  -79.021  45.418  1
109184  98.356  -79.018  45.403  1
109185  98.384  -79.015  45.390  1
109186  98.406  -78.975  45.377  1
109187  98.394  -78.987  45.366  1
109188  98.420  -78.977  45.354  1
109189  98.454  -78.955  45.343  1
109190  98.463  -78.936  45.332  1
109191  98.491  -78.943  45.320  1
109192  98.515  -78.949  45.308  1
109193  98.538  -78.956  45.294  1
109194  98.560  -78.962  45.279  1
109195  98.582  -78.969  45.264  1
109196  98.604  -78.976  45.251  1
109197  98.627  -78.983  45.239  1
109198  98.649  -78.989  45.228  1
109199  98.671  -78.996  45.216  1
109200  98.693  -79.002  45.203  1
109201  98.715  -79.009  45.190  1
109202  98.737  -79.015  45.179  1
109203  98.760  -79.022  45.167  1
109204  98.782  -79.029  45.156  1
109205  98.804  -79.035  45.145  1
109206  98.826  -79.042  45.133  1
109207  98.849  -79.049  45.121  1
109208  98.871  -79.055  45.110  1
109209  98.949  -79.101  45.099  1
109210  98.972  -79.088  45.090  1
109211  98.997  -79.081  45.080  1
109212  99.021  -79.075  45.069  1
109213  99.046  -79.068  45.057  1
109214  99.070  -79.062  45.045  1
109215  99.094  -79.056  45.032  1
109216  99.119  -79.049  45.019  1
109217  99.143  -79.044  45.007  1
109218  99.168  -79.046  44.997  1
109219  99.188  -79.052  44.990  1
109220  99.197  -79.062  44.980  1
109221  99.222  -79.073  44.969  1
109222  99.248  -79.085  44.958  1
109223  99.267  -79.097  44.948  1
109224  99.280  -79.112  44.938  1
109225  99.284  -79.123  44.929  1
109226  99.287  -79.132  44.922  1
109227  99.289  -79.141  44.914  1
109228  99.292  -79.150  44.907  1
109229  99.294  -79.159  44.901  1
109230  99.307  -79.194  44.895  1
109231  99.323  -79.231  44.890  1
109232  99.350  -79.227  44.886  1
109233  99.414  -79.216  44.882  1
109234  99.494  -79.203  44.879  1
109235  99.471  -79.200  44.877  1
109236  99.470  -79.213  44.875  1
109237  99.493  -79.241  44.873  1
109238  99.515  -79.267  44.870  1
109239  99.538  -79.294  44.868  1
109240  99.561  -79.322  44.867  1
109241  99.584  -79.349  44.866  1
109242  99.609  -79.358  44.866  1
109243  99.635  -79.363  44.866  1
109244  99.661  -79.367  44.864  1
109245  99.687  -79.372  44.861  1
109246  99.713  -79.376  44.858  1
109247  99.738  -79.381  44.854  1
109248  99.765  -79.386  44.847  1
109249  99.790  -79.391  44.841  1
109250  99.820  -79.406  44.834  1
109251  99.853  -79.438  44.827  1
109252  99.888  -79.472  44.818  1
109253  99.922  -79.504  44.809  1
109254  99.956  -79.537  44.800  1
109255  99.990  -79.570  44.792  1
109256  100.023  -79.609  44.784  1
109257  100.059  -79.648  44.775  1
109258  100.098  -79.657  44.767  1
109259  100.137  -79.667  44.758  1
109260  100.176  -79.676  44.748  1
109261  100.215  -79.686  44.737  1
109262  100.254  -79.695  44.726  1
109263  100.282  -79.720  44.713  1
109264  100.304  -79.758  44.701  1
109265  100.327  -79.797  44.690  1
109266  100.349  -79.836  44.678  1
109267  100.371  -79.875  44.667  1
109268  100.394  -79.914  44.655  1
109269  100.420  -79.943  44.643  1
109270  100.458  -79.947  44.630  1
109271  100.494  -79.952  44.616  1
109272  100.531  -79.957  44.602  1
109273  100.568  -79.962  44.586  1
109274  100.606  -79.967  44.570  1
109275  100.643  -79.970  44.556  1
109276  100.680  -79.969  44.542  1
109277  100.717  -79.968  44.528  1
109278  100.752  -79.992  44.513  1
109279  100.783  -80.025  44.498  1
109280  100.816  -80.059  44.483  1
109281  100.848  -80.093  44.469  1
109282  100.882  -80.127  44.455  1
109283  100.914  -80.160  44.440  1
109284  100.948  -80.194  44.425  1
109285  100.980  -80.228  44.411  1
109286  101.013  -80.262  44.395  1
109287  101.046  -80.296  44.380  1
109288  101.079  -80.329  44.364  1
109289  101.112  -80.363  44.348  1
109290  101.145  -80.397  44.332  1
109291  101.178  -80.431  44.315  1
109292  101.211  -80.464  44.299  1
109293  101.251  -80.482  44.282  1
109294  101.292  -80.500  44.266  1
109295  101.324  -80.516  44.250  1
109296  101.356  -80.532  44.233  1
109297  101.388  -80.549  44.216  1
109298  101.420  -80.565  44.199  1
109299  101.453  -80.581  44.182  1
109300  101.484  -80.597  44.165  1
109301  101.516  -80.613  44.148  1
109302  101.549  -80.629  44.131  1
109303  101.581  -80.645  44.114  1
109304  101.613  -80.662  44.098  1
109305  101.645  -80.678  44.080  1
109306  101.677  -80.694  44.063  1
109564  93.526  -78.387  53.744  1
109565  93.525  -78.378  53.723  1
109566  93.524  -78.369  53.701  1
109567  93.523  -78.360  53.678  1
109568  93.528  -78.347  53.656  1
109569  93.538  -78.332  53.632  1
109570  93.548  -78.316  53.607  1
109571  93.569  -78.300  53.583  1
109572  93.592  -78.285  53.559  1
109573  93.610  -78.273  53.534  1
109574  93.621  -78.265  53.511  1
109575  93.633  -78.257  53.488  1
109576  93.644  -78.248  53.464  1
109577  93.656  -78.240  53.439  1
109578  93.668  -78.232  53.417  1
109597  93.945  -78.109  52.986  1
109598  93.958  -78.104  52.963  1
109599  93.971  -78.100  52.938  1
109600  93.970  -78.098  52.914  1
109601  93.968  -78.097  52.890  1
109602  93.965  -78.096  52.866  1
109603  93.969  -78.106  52.842  1
109604  93.972  -78.117  52.818  1
109605  93.975  -78.127  52.794  1
109606  93.979  -78.138  52.770  1
109607  93.982  -78.147  52.746  1
109608  93.986  -78.158  52.722  1
109609  93.989  -78.169  52.699  1
109610  93.992  -78.178  52.675  1
109611  93.996  -78.189  52.651  1
109612  93.999  -78.199  52.628  1
109613  94.003  -78.210  52.603  1
109614  94.006  -78.220  52.580  1
109615  94.009  -78.230  52.556  1
109616  94.013  -78.241  52.532  1
109617  94.024  -78.247  52.509  1
109618  94.037  -78.249  52.486  1
109619  94.043  -78.239  52.461  1
109620  94.068  -78.230  52.438  1
109621  94.093  -78.221  52.413  1
109622  94.118  -78.212  52.388  1
109623  94.143  -78.203  52.364  1
109624  94.165  -78.194  52.339  1
109625  94.176  -78.192  52.315  1
109626  94.186  -78.189  52.291  1
109627  94.197  -78.186  52.267  1
109628  94.207  -78.184  52.242  1
109629  94.218  -78.181  52.216  1
109630  94.228  -78.178  52.192  1
109631  94.242  -78.171  52.168  1
109632  94.256  -78.163  52.143  1
109633  94.269  -78.156  52.118  1
109634  94.283  -78.148  52.092  1
109635  94.297  -78.141  52.067  1
109636  94.311  -78.133  52.043  1
109637  94.324  -78.125  52.018  1
109638  94.338  -78.118  51.993  1
109639  94.352  -78.110  51.968  1
109640  94.365  -78.103  51.942  1
109641  94.380  -78.097  51.918  1
109642  94.394  -78.090  51.893  1
109643  94.408  -78.083  51.867  1
109644  94.411  -78.078  51.842  1
109645  94.412  -78.074  51.818  1
109646  94.424  -78.067  51.792  1
109647  94.445  -78.057  51.765  1
109648  94.465  -78.047  51.738  1
109649  94.486  -78.037  51.711  1
109650  94.506  -78.027  51.684  1
109651  94.524  -78.022  51.657  1
109652  94.547  -78.028  51.630  1
109653  94.584  -78.044  51.601  1
109654  94.622  -78.060  51.571  1
109655  94.656  -78.075  51.541  1
109656  94.668  -78.075  51.512  1
109657  94.679  -78.075  51.482  1
109658  94.691  -78.075  51.453  1
109659  94.699  -78.067  51.424  1
109660  94.707  -78.058  51.394  1
109661  94.715  -78.049  51.362  1
109662  94.723  -78.040  51.332  1
109663  94.725  -78.044  51.301  1
109664  94.725  -78.050  51.270  1
109665  94.730  -78.054  51.240  1
109666  94.741  -78.052  51.209  1
109667  94.753  -78.050  51.178  1
109668  94.765  -78.056  51.146  1
109669  94.777  -78.060  51.112  1
109670  94.789  -78.065  51.079  1
109671  94.802  -78.070  51.045  1
109672  94.821  -78.076  51.012  1
109673  94.845  -78.084  50.978  1
109674  94.870  -78.091  50.943  1
109675  94.894  -78.096  50.907  1
109676  94.912  -78.078  50.872  1
109677  94.930  -78.062  50.836  1
109678  94.949  -78.044  50.801  1
109679  94.967  -78.027  50.767  1
109680  94.985  -78.010  50.732  1
109681  95.003  -77.993  50.697  1
109682  95.022  -77.975  50.662  1
109683  95.040  -77.958  50.627  1
109684  95.058  -77.941  50.594  1
109685  95.073  -77.925  50.560  1
109686  95.082  -77.912  50.527  1
109687  95.091  -77.899  50.496  1
109688  95.113  -77.887  50.464  1
109689  95.137  -77.891  50.431  1
109690  95.161  -77.896  50.400  1
109691  95.184  -77.899  50.368  1
109692  95.207  -77.903  50.339  1
109693  95.231  -77.907  50.311  1
109694  95.255  -77.911  50.284  1
109695  95.278  -77.915  50.258  1
109696  95.302  -77.919  50.232  1
109697  95.326  -77.923  50.206  1
109698  95.343  -77.927  50.182  1
109699  95.349  -77.929  50.160  1
109700  95.356  -77.931  50.139  1
109701  95.362  -77.934  50.117  1
109702  95.369  -77.936  50.097  1
109703  95.375  -77.938  50.077  1
109704  95.382  -77.940  50.057  1
109705  95.388  -77.943  50.036  1
109706  95.394  -77.946  50.012  1
109707  95.401  -77.948  49.985  1
109708  95.407  -77.950  49.957  1
109709  95.414  -77.953  49.924  1
109710  95.420  -77.955  49.890  1
109711  95.426  -77.957  49.854  1
109712  95.437  -77.964  49.814  1
109713  95.459  -77.986  49.772  1
109714  95.486  -77.989  49.730  1
109715  95.517  -77.978  49.687  1
109716  95.548  -77.967  49.648  1
109717  95.579  -77.956  49.609  1
109718  95.610  -77.944  49.572  1
109719  95.641  -77.933  49.534  1
109720  95.672  -77.922  49.496  1
109721  95.703  -77.911  49.458  1
109722  95.705  -77.923  49.418  1
109723  95.680  -77.964  49.380  1
109724  95.654  -78.005  49.342  1
109725  95.671  -78.003  49.303  1
109726  95.722  -77.960  49.265  1
109727  95.690  -77.937  49.228  1
109728  95.687  -77.956  49.190  1
109729  95.683  -77.977  49.153  1
109730  95.679  -77.996  49.116  1
109731  95.675  -78.016  49.078  1
109732  95.688  -78.008  49.038  1
109733  95.707  -78.002  48.999  1
109734  95.734  -78.011  48.958  1
109735  95.760  -78.020  48.917  1
109736  95.787  -78.029  48.876  1
109737  95.814  -78.038  48.835  1
109738  95.840  -78.047  48.795  1
109739  95.868  -78.056  48.755  1
109740  95.890  -78.059  48.717  1
109741  95.908  -78.067  48.678  1
109742  95.905  -78.090  48.638  1
109743  95.896  -78.116  48.598  1
109744  95.901  -78.117  48.561  1
109745  95.902  -78.119  48.525  1
109746  95.904  -78.121  48.490  1
109747  95.906  -78.123  48.452  1
109748  95.922  -78.120  48.414  1
109749  95.947  -78.115  48.377  1
109750  95.963  -78.114  48.341  1
109751  95.979  -78.112  48.307  1
109752  95.995  -78.112  48.272  1
109753  96.012  -78.111  48.238  1
109754  96.028  -78.109  48.206  1
109755  96.044  -78.109  48.173  1
109756  96.058  -78.107  48.141  1
109757  96.060  -78.105  48.109  1
109758  96.061  -78.102  48.081  1
109759  96.063  -78.099  48.054  1
109760  96.072  -78.100  48.026  1
109761  96.096  -78.110  48.000  1
109762  96.121  -78.119  47.973  1
109763  96.139  -78.131  47.944  1
109764  96.154  -78.142  47.913  1
109765  96.168  -78.148  47.885  1
109766  96.183  -78.153  47.856  1
109767  96.198  -78.159  47.827  1
109768  96.214  -78.168  47.798  1
109769  96.229  -78.180  47.768  1
109770  96.243  -78.192  47.740  1
109771  96.258  -78.205  47.713  1
109772  96.273  -78.217  47.690  1
109773  96.287  -78.227  47.666  1
109774  96.301  -78.238  47.641  1
109775  96.317  -78.249  47.616  1
109776  96.333  -78.260  47.590  1
109777  96.348  -78.273  47.563  1
109778  96.363  -78.288  47.536  1
109779  96.377  -78.301  47.511  1
109780  96.393  -78.310  47.486  1
109781  96.409  -78.316  47.462  1
109782  96.425  -78.322  47.438  1
109783  96.442  -78.327  47.414  1
109784  96.472  -78.326  47.390  1
109785  96.502  -78.326  47.366  1
109786  96.521  -78.329  47.344  1
109787  96.524  -78.338  47.320  1
109788  96.528  -78.347  47.295  1
109789  96.539  -78.356  47.268  1
109790  96.549  -78.365  47.241  1
109791  96.559  -78.374  47.213  1
109792  96.569  -78.383  47.183  1
109793  96.570  -78.385  47.155  1
109794  96.570  -78.385  47.129  1
109795  96.578  -78.385  47.103  1
109796  96.586  -78.402  47.077  1
109797  96.592  -78.426  47.051  1
109798  96.597  -78.450  47.026  1
109799  96.603  -78.473  47.001  1
109800  96.608  -78.497  46.977  1
109801  96.614  -78.520  46.953  1
109802  96.622  -78.533  46.928  1
109803  96.630  -78.545  46.903  1
109804  96.624  -78.567  46.878  1
109805  96.619  -78.588  46.853  1
109806  96.614  -78.610  46.827  1
109807  96.609  -78.632  46.804  1
109808  96.603  -78.654  46.778  1
109809  96.600  -78.677  46.752  1
109810  96.619  -78.708  46.729  1
109811  96.652  -78.721  46.703  1
109812  96.687  -78.731  46.677  1
109813  96.725  -78.742  46.650  1
109814  96.765  -78.752  46.624  1
109815  96.806  -78.764  46.597  1
109816  96.842  -78.777  46.569  1
109817  96.871  -78.795  46.542  1
109818  96.901  -78.812  46.513  1
109819  96.930  -78.830  46.485  1
109820  96.960  -78.848  46.458  1
109821  96.989  -78.865  46.432  1
109822  97.019  -78.883  46.407  1
109823  97.073  -78.893  46.381  1
109824  97.142  -78.899  46.356  1
109825  97.185  -78.892  46.334  1
109826  97.228  -78.883  46.311  1
109827  97.271  -78.875  46.289  1
109828  97.314  -78.868  46.271  1
109829  97.356  -78.859  46.251  1
109830  97.391  -78.848  46.232  1
109831  97.425  -78.836  46.213  1
109832  97.460  -78.825  46.195  1
109833  97.495  -78.814  46.179  1
109834  97.530  -78.805  46.162  1
109835  97.569  -78.804  46.146  1
109836  97.607  -78.803  46.130  1
109837  97.646  -78.802  46.115  1
109838  97.699  -78.798  46.099  1
109839  97.691  -78.855  46.084  1
109840  97.684  -78.912  46.069  1
109841  97.655  -78.890  46.054  1
109842  97.648  -78.854  46.039  1
109843  97.698  -78.852  46.024  1
109844  97.749  -78.853  46.009  1
109845  97.800  -78.853  45.994  1
109846  97.821  -78.814  45.979  1
109847  97.845  -78.783  45.965  1
109848  97.882  -78.779  45.949  1
109849  97.918  -78.774  45.932  1
109850  97.954  -78.770  45.915  1
109851  97.975  -78.729  45.898  1
109852  97.993  -78.713  45.880  1
109853  97.999  -78.702  45.865  1
109854  97.979  -78.689  45.848  1
109855  97.946  -78.688  45.831  1
109856  97.953  -78.678  45.816  1
109857  97.947  -78.705  45.800  1
109858  97.935  -78.723  45.785  1
109859  97.921  -78.686  45.770  1
109860  97.932  -78.657  45.755  1
109861  97.984  -78.639  45.741  1
109862  97.964  -78.720  45.726  1
109863  97.964  -78.741  45.712  1
109864  97.965  -78.761  45.698  1
109865  97.971  -78.777  45.684  1
109866  98.000  -78.780  45.670  1
109867  98.029  -78.783  45.655  1
109868  98.059  -78.786  45.640  1
109869  98.088  -78.789  45.625  1
109870  98.117  -78.793  45.611  1
109871  98.143  -78.801  45.596  1
109872  98.164  -78.815  45.582  1
109873  98.183  -78.827  45.567  1
109874  98.189  -78.815  45.553  1
109875  98.195  -78.803  45.541  1
109876  98.201  -78.792  45.531  1
109877  98.207  -78.789  45.521  1
109878  98.214  -78.805  45.507  1
109879  98.222  -78.820  45.494  1
109880  98.232  -78.836  45.481  1
109881  98.262  -78.896  45.469  1
109882  98.281  -78.961  45.454  1
109883  98.302  -79.015  45.441  1
109884  98.325  -78.986  45.428  1
109885  98.346  -78.943  45.414  1
109886  98.366  -78.900  45.401  1
109887  98.354  -78.913  45.388  1
109888  98.336  -78.936  45.376  1
109889  98.318  -78.959  45.363  1
109890  98.358  -78.939  45.351  1
109891  98.416  -78.930  45.339  1
109892  98.476  -78.948  45.329  1
109893  98.499  -78.951  45.317  1
109894  98.522  -78.953  45.304  1
109895  98.545  -78.955  45.292  1
109896  98.568  -78.959  45.279  1
109897  98.591  -78.961  45.265  1
109898  98.614  -78.967  45.251  1
109899  98.636  -78.974  45.237  1
109900  98.658  -78.980  45.223  1
109901  98.680  -78.987  45.209  1
109902  98.702  -78.993  45.194  1
109903  98.724  -78.999  45.181  1
109904  98.746  -79.006  45.169  1
109905  98.769  -79.013  45.156  1
109906  98.791  -79.020  45.144  1
109907  98.813  -79.026  45.132  1
109908  98.836  -79.033  45.121  1
109909  98.883  -79.062  45.109  1
109910  98.938  -79.053  45.100  1
109911  98.973  -79.042  45.091  1
109912  98.997  -79.035  45.081  1
109913  99.021  -79.028  45.072  1
109914  99.046  -79.023  45.062  1
109915  99.071  -79.024  45.051  1
109916  99.097  -79.027  45.038  1
109917  99.122  -79.028  45.026  1
109918  99.147  -79.030  45.014  1
109919  99.171  -79.033  45.005  1
109920  99.185  -79.043  44.997  1
109921  99.199  -79.054  44.987  1
109922  99.206  -79.064  44.976  1
109923  99.212  -79.074  44.966  1
109924  99.217  -79.084  44.955  1
109925  99.271  -79.090  44.945  1
109926  99.265  -79.109  44.936  1
109927  99.268  -79.118  44.928  1
109928  99.271  -79.127  44.920  1
109929  99.274  -79.135  44.912  1
109930  99.300  -79.135  44.906  1
109931  99.317  -79.167  44.898  1
109932  99.331  -79.206  44.892  1
109933  99.400  -79.211  44.888  1
109934  99.481  -79.198  44.884  1
109935  99.562  -79.185  44.881  1
109936  99.525  -79.184  44.879  1
109937  99.479  -79.189  44.877  1
109938  99.492  -79.212  44.876  1
109939  99.514  -79.239  44.874  1
109940  99.537  -79.266  44.872  1
109941  99.560  -79.294  44.871  1
109942  99.583  -79.321  44.872  1
109943  99.607  -79.341  44.872  1
109944  99.632  -79.346  44.871  1
109945  99.658  -79.350  44.868  1
109946  99.684  -79.356  44.863  1
109947  99.710  -79.360  44.858  1
109948  99.736  -79.365  44.852  1
109949  99.762  -79.369  44.845  1
109950  99.788  -79.374  44.838  1
109951  99.821  -79.404  44.831  1
109952  99.855  -79.438  44.823  1
109953  99.890  -79.470  44.815  1
109954  99.923  -79.503  44.807  1
109955  99.958  -79.535  44.798  1
109956  99.991  -79.568  44.790  1
109957  100.025  -79.606  44.782  1
109958  100.061  -79.641  44.773  1
109959  100.100  -79.651  44.765  1
109960  100.139  -79.661  44.757  1
109961  100.178  -79.670  44.747  1
109962  100.217  -79.679  44.737  1
109963  100.256  -79.689  44.726  1
109964  100.288  -79.707  44.714  1
109965  100.312  -79.746  44.702  1
109966  100.336  -79.785  44.689  1
109967  100.358  -79.824  44.678  1
109968  100.381  -79.862  44.666  1
109969  100.403  -79.902  44.653  1
109970  100.426  -79.937  44.641  1
109971  100.463  -79.943  44.628  1
109972  100.500  -79.947  44.615  1
109973  100.538  -79.946  44.601  1
109974  100.575  -79.946  44.586  1
109975  100.613  -79.945  44.570  1
109976  100.650  -79.944  44.555  1
109977  100.687  -79.943  44.541  1
109978  100.724  -79.943  44.526  1
109979  100.759  -79.968  44.512  1
109980  100.792  -80.004  44.499  1
109981  100.825  -80.039  44.484  1
109982  100.854  -80.071  44.469  1
109983  100.886  -80.104  44.456  1
109984  100.919  -80.138  44.441  1
109985  100.952  -80.171  44.427  1
109986  100.984  -80.206  44.412  1
109987  101.018  -80.239  44.397  1
109988  101.050  -80.273  44.382  1
109989  101.084  -80.306  44.366  1
109990  101.116  -80.341  44.351  1
109991  101.149  -80.375  44.335  1
109992  101.182  -80.408  44.319  1
109993  101.218  -80.428  44.304  1
109994  101.264  -80.441  44.287  1
109995  101.309  -80.462  44.271  1
109996  101.341  -80.478  44.255  1
109997  101.374  -80.494  44.239  1
109998  101.405  -80.510  44.222  1
109999  101.438  -80.526  44.205  1
110000  101.470  -80.543  44.189  1
110001  101.502  -80.559  44.171  1
110002  101.534  -80.575  44.154  1
110003  101.566  -80.591  44.137  1
110004  101.598  -80.607  44.120  1
110005  101.630  -80.623  44.104  1
110006  101.662  -80.640  44.086  1
110007  101.694  -80.656  44.069  1
110266  93.522  -78.365  53.712  1
110267  93.520  -78.356  53.691  1
110268  93.519  -78.346  53.668  1
110269  93.530  -78.331  53.645  1
110270  93.540  -78.316  53.622  1
110271  93.552  -78.300  53.597  1
110272  93.575  -78.285  53.573  1
110273  93.597  -78.270  53.549  1
110274  93.611  -78.260  53.526  1
110275  93.623  -78.252  53.502  1
110276  93.634  -78.244  53.479  1
110277  93.646  -78.235  53.455  1
110278  93.657  -78.227  53.431  1
110302  93.968  -78.086  52.878  1
110303  93.966  -78.085  52.854  1
110304  93.968  -78.094  52.830  1
110305  93.971  -78.103  52.806  1
110306  93.975  -78.114  52.782  1
110307  93.978  -78.124  52.757  1
110308  93.982  -78.134  52.733  1
110309  93.985  -78.144  52.709  1
110310  93.988  -78.155  52.685  1
110311  93.992  -78.166  52.661  1
110312  93.995  -78.175  52.637  1
110313  93.999  -78.186  52.613  1
110314  94.002  -78.196  52.589  1
110315  94.005  -78.206  52.566  1
110316  94.009  -78.217  52.542  1
110317  94.012  -78.227  52.517  1
110318  94.028  -78.232  52.494  1
110319  94.039  -78.232  52.470  1
110320  94.045  -78.222  52.445  1
110321  94.069  -78.213  52.422  1
110322  94.095  -78.204  52.398  1
110323  94.119  -78.195  52.373  1
110324  94.144  -78.186  52.349  1
110325  94.169  -78.176  52.324  1
110326  94.186  -78.171  52.299  1
110327  94.196  -78.169  52.274  1
110328  94.207  -78.166  52.250  1
110329  94.217  -78.163  52.225  1
110330  94.228  -78.160  52.200  1
110331  94.239  -78.157  52.176  1
110332  94.251  -78.152  52.152  1
110333  94.265  -78.144  52.127  1
110334  94.278  -78.137  52.101  1
110335  94.292  -78.129  52.076  1
110336  94.306  -78.122  52.051  1
110337  94.320  -78.114  52.027  1
110338  94.333  -78.106  52.002  1
110339  94.347  -78.099  51.978  1
110340  94.361  -78.091  51.953  1
110341  94.374  -78.084  51.928  1
110342  94.389  -78.078  51.904  1
110343  94.403  -78.071  51.879  1
110344  94.417  -78.064  51.854  1
110345  94.424  -78.059  51.830  1
110346  94.425  -78.055  51.807  1
110347  94.426  -78.050  51.782  1
110348  94.447  -78.040  51.756  1
110349  94.468  -78.030  51.729  1
110350  94.488  -78.020  51.703  1
110351  94.509  -78.010  51.677  1
110352  94.528  -78.003  51.650  1
110353  94.543  -78.004  51.623  1
110354  94.580  -78.019  51.595  1
110355  94.618  -78.036  51.565  1
110356  94.654  -78.052  51.536  1
110357  94.666  -78.052  51.507  1
110358  94.678  -78.053  51.478  1
110359  94.689  -78.053  51.449  1
110360  94.699  -78.048  51.421  1
110361  94.707  -78.040  51.391  1
110362  94.715  -78.031  51.360  1
110363  94.723  -78.022  51.330  1
110364  94.726  -78.024  51.300  1
110365  94.726  -78.031  51.269  1
110366  94.727  -78.037  51.239  1
110367  94.739  -78.034  51.208  1
110368  94.750  -78.033  51.177  1
110369  94.762  -78.038  51.145  1
110370  94.775  -78.043  51.112  1
110371  94.787  -78.048  51.079  1
110372  94.799  -78.053  51.046  1
110373  94.823  -78.060  51.013  1
110374  94.848  -78.067  50.979  1
110375  94.873  -78.075  50.943  1
110376  94.896  -78.078  50.908  1
110377  94.914  -78.060  50.873  1
110378  94.932  -78.043  50.837  1
110379  94.951  -78.026  50.802  1
110380  94.969  -78.009  50.768  1
110381  94.987  -77.991  50.733  1
110382  95.005  -77.975  50.698  1
110383  95.024  -77.957  50.664  1
110384  95.042  -77.940  50.629  1
110385  95.058  -77.923  50.596  1
110386  95.067  -77.910  50.563  1
110387  95.076  -77.897  50.530  1
110388  95.085  -77.884  50.499  1
110389  95.099  -77.863  50.467  1
110390  95.124  -77.862  50.435  1
110391  95.148  -77.866  50.405  1
110392  95.172  -77.870  50.374  1
110393  95.195  -77.874  50.346  1
110394  95.219  -77.877  50.318  1
110395  95.243  -77.882  50.291  1
110396  95.266  -77.886  50.263  1
110397  95.293  -77.899  50.236  1
110398  95.305  -77.918  50.210  1
110399  95.341  -77.915  50.186  1
110400  95.358  -77.914  50.163  1
110401  95.365  -77.916  50.143  1
110402  95.371  -77.918  50.123  1
110403  95.378  -77.921  50.103  1
110404  95.384  -77.923  50.083  1
110405  95.390  -77.925  50.062  1
110406  95.397  -77.928  50.038  1
110407  95.403  -77.930  50.012  1
110408  95.409  -77.933  49.983  1
110409  95.416  -77.935  49.952  1
110410  95.422  -77.937  49.918  1
110411  95.429  -77.940  49.881  1
110412  95.435  -77.942  49.843  1
110413  95.445  -77.948  49.802  1
110414  95.467  -77.970  49.761  1
110415  95.488  -77.992  49.719  1
110416  95.518  -77.987  49.680  1
110417  95.549  -77.976  49.643  1
110418  95.580  -77.965  49.606  1
110419  95.611  -77.954  49.568  1
110420  95.642  -77.943  49.531  1
110421  95.667  -77.928  49.494  1
110422  95.686  -77.911  49.457  1
110423  95.697  -77.902  49.420  1
110424  95.672  -77.943  49.383  1
110425  95.646  -77.984  49.347  1
110426  95.652  -77.997  49.310  1
110427  95.682  -77.984  49.272  1
110428  95.733  -77.940  49.234  1
110429  95.687  -77.948  49.195  1
110430  95.683  -77.968  49.156  1
110431  95.679  -77.988  49.119  1
110432  95.679  -78.000  49.081  1
110433  95.694  -77.987  49.043  1
110434  95.722  -77.996  49.003  1
110435  95.748  -78.005  48.964  1
110436  95.775  -78.014  48.925  1
110437  95.802  -78.023  48.884  1
110438  95.828  -78.033  48.843  1
110439  95.851  -78.036  48.802  1
110440  95.873  -78.038  48.761  1
110441  95.895  -78.041  48.722  1
110442  95.905  -78.056  48.683  1
110443  95.903  -78.080  48.644  1
110444  95.895  -78.103  48.605  1
110445  95.902  -78.102  48.568  1
110446  95.909  -78.100  48.531  1
110447  95.915  -78.098  48.496  1
110448  95.922  -78.097  48.459  1
110449  95.933  -78.096  48.421  1
110450  95.949  -78.095  48.384  1
110451  95.965  -78.094  48.347  1
110452  95.981  -78.093  48.312  1
110453  95.998  -78.092  48.277  1
110454  96.014  -78.091  48.244  1
110455  96.030  -78.090  48.212  1
110456  96.046  -78.089  48.179  1
110457  96.062  -78.087  48.148  1
110458  96.077  -78.087  48.117  1
110459  96.079  -78.084  48.090  1
110460  96.080  -78.081  48.063  1
110461  96.087  -78.081  48.035  1
110462  96.111  -78.091  48.009  1
110463  96.134  -78.100  47.981  1
110464  96.148  -78.113  47.952  1
110465  96.162  -78.127  47.921  1
110466  96.176  -78.138  47.893  1
110467  96.191  -78.144  47.865  1
110468  96.206  -78.150  47.836  1
110469  96.222  -78.156  47.809  1
110470  96.236  -78.169  47.781  1
110471  96.251  -78.181  47.754  1
110472  96.266  -78.193  47.728  1
110473  96.281  -78.204  47.705  1
110474  96.293  -78.214  47.681  1
110475  96.305  -78.223  47.657  1
110476  96.319  -78.234  47.634  1
110477  96.336  -78.245  47.609  1
110478  96.352  -78.257  47.582  1
110479  96.368  -78.268  47.556  1
110480  96.385  -78.279  47.531  1
110481  96.403  -78.287  47.506  1
110482  96.419  -78.291  47.482  1
110483  96.436  -78.297  47.458  1
110484  96.452  -78.303  47.435  1
110485  96.469  -78.308  47.412  1
110486  96.500  -78.307  47.389  1
110487  96.505  -78.316  47.365  1
110488  96.514  -78.324  47.341  1
110489  96.524  -78.333  47.315  1
110490  96.534  -78.342  47.288  1
110491  96.545  -78.351  47.258  1
110492  96.555  -78.360  47.229  1
110493  96.557  -78.363  47.201  1
110494  96.556  -78.364  47.175  1
110495  96.556  -78.365  47.149  1
110496  96.571  -78.364  47.124  1
110497  96.577  -78.385  47.099  1
110498  96.583  -78.409  47.072  1
110499  96.588  -78.433  47.047  1
110500  96.594  -78.457  47.022  1
110501  96.599  -78.480  46.999  1
110502  96.605  -78.504  46.974  1
110503  96.610  -78.527  46.948  1
110504  96.615  -78.545  46.921  1
110505  96.609  -78.567  46.896  1
110506  96.604  -78.588  46.871  1
110507  96.599  -78.610  46.846  1
110508  96.595  -78.631  46.821  1
110509  96.592  -78.650  46.794  1
110510  96.589  -78.670  46.768  1
110511  96.607  -78.685  46.744  1
110512  96.648  -78.695  46.717  1
110513  96.688  -78.706  46.690  1
110514  96.729  -78.717  46.662  1
110515  96.769  -78.728  46.635  1
110516  96.810  -78.739  46.607  1
110517  96.847  -78.752  46.579  1
110518  96.876  -78.770  46.551  1
110519  96.906  -78.787  46.522  1
110520  96.935  -78.805  46.494  1
110521  96.965  -78.823  46.466  1
110522  96.994  -78.840  46.440  1
110523  97.021  -78.852  46.414  1
110524  97.066  -78.862  46.389  1
110525  97.116  -78.872  46.364  1
110526  97.184  -78.879  46.342  1
110527  97.228  -78.871  46.319  1
110528  97.271  -78.863  46.297  1
110529  97.314  -78.855  46.278  1
110530  97.351  -78.845  46.258  1
110531  97.386  -78.833  46.239  1
110532  97.420  -78.822  46.221  1
110533  97.456  -78.814  46.203  1
110534  97.495  -78.814  46.186  1
110535  97.534  -78.813  46.170  1
110536  97.572  -78.812  46.155  1
110537  97.611  -78.811  46.139  1
110538  97.650  -78.811  46.123  1
110539  97.691  -78.808  46.107  1
110540  97.694  -78.861  46.092  1
110541  97.675  -78.896  46.078  1
110542  97.656  -78.888  46.063  1
110543  97.676  -78.858  46.048  1
110544  97.714  -78.842  46.033  1
110545  97.765  -78.843  46.019  1
110546  97.800  -78.821  46.004  1
110547  97.821  -78.782  45.990  1
110548  97.842  -78.742  45.975  1
110549  97.877  -78.734  45.960  1
110550  97.913  -78.730  45.943  1
110551  97.949  -78.725  45.926  1
110552  97.986  -78.721  45.909  1
110553  98.022  -78.717  45.892  1
110554  98.015  -78.705  45.876  1
110555  97.982  -78.705  45.859  1
110556  97.981  -78.686  45.843  1
110557  97.981  -78.698  45.827  1
110558  97.974  -78.724  45.811  1
110559  97.959  -78.728  45.795  1
110560  97.941  -78.689  45.780  1
110561  97.953  -78.661  45.765  1
110562  97.986  -78.638  45.750  1
110563  97.984  -78.696  45.735  1
110564  97.984  -78.717  45.721  1
110565  97.985  -78.736  45.706  1
110566  97.985  -78.757  45.692  1
110567  98.001  -78.767  45.677  1
110568  98.030  -78.771  45.662  1
110569  98.060  -78.774  45.646  1
110570  98.089  -78.777  45.632  1
110571  98.119  -78.780  45.618  1
110572  98.140  -78.794  45.602  1
110573  98.161  -78.808  45.587  1
110574  98.182  -78.824  45.573  1
110575  98.189  -78.814  45.561  1
110576  98.195  -78.802  45.549  1
110577  98.200  -78.789  45.538  1
110578  98.206  -78.777  45.527  1
110579  98.211  -78.767  45.514  1
110580  98.219  -78.782  45.502  1
110581  98.246  -78.811  45.489  1
110582  98.266  -78.876  45.476  1
110583  98.262  -78.913  45.461  1
110584  98.285  -78.899  45.447  1
110585  98.306  -78.869  45.434  1
110586  98.327  -78.826  45.420  1
110587  98.314  -78.839  45.407  1
110588  98.296  -78.862  45.394  1
110589  98.283  -78.886  45.381  1
110590  98.302  -78.915  45.369  1
110591  98.313  -78.918  45.357  1
110592  98.334  -78.929  45.344  1
110593  98.428  -78.957  45.332  1
110594  98.479  -78.974  45.321  1
110595  98.502  -78.976  45.309  1
110596  98.524  -78.979  45.299  1
110597  98.548  -78.981  45.287  1
110598  98.570  -78.984  45.274  1
110599  98.593  -78.987  45.261  1
110600  98.617  -78.989  45.247  1
110601  98.639  -78.992  45.233  1
110602  98.662  -78.994  45.218  1
110603  98.686  -78.997  45.203  1
110604  98.708  -78.999  45.188  1
110605  98.731  -79.002  45.173  1
110606  98.755  -79.005  45.159  1
110607  98.777  -79.007  45.145  1
110608  98.800  -79.011  45.133  1
110609  98.822  -79.017  45.121  1
110610  98.873  -79.013  45.110  1
110611  98.929  -79.006  45.100  1
110612  98.975  -79.004  45.091  1
110613  99.000  -79.006  45.082  1
110614  99.025  -79.007  45.073  1
110615  99.051  -79.009  45.064  1
110616  99.076  -79.011  45.054  1
110617  99.101  -79.012  45.043  1
110618  99.127  -79.015  45.030  1
110619  99.152  -79.016  45.020  1
110620  99.168  -79.024  45.011  1
110621  99.182  -79.035  45.003  1
110622  99.195  -79.046  44.992  1
110623  99.209  -79.056  44.981  1
110624  99.215  -79.066  44.970  1
110625  99.226  -79.073  44.960  1
110626  99.246  -79.075  44.949  1
110627  99.273  -79.077  44.938  1
110628  99.236  -79.116  44.930  1
110629  99.259  -79.118  44.922  1
110630  99.299  -79.112  44.915  1
110631  99.340  -79.106  44.909  1
110632  99.359  -79.137  44.902  1
110633  99.428  -79.142  44.896  1
110634  99.497  -79.147  44.891  1
110635  99.565  -79.153  44.888  1
110636  99.612  -79.169  44.886  1
110637  99.562  -79.171  44.884  1
110638  99.505  -79.173  44.881  1
110639  99.505  -79.190  44.879  1
110640  99.513  -79.211  44.878  1
110641  99.536  -79.238  44.878  1
110642  99.559  -79.266  44.878  1
110643  99.582  -79.293  44.877  1
110644  99.605  -79.320  44.875  1
110645  99.630  -79.330  44.872  1
110646  99.656  -79.335  44.868  1
110647  99.682  -79.339  44.862  1
110648  99.707  -79.344  44.856  1
110649  99.733  -79.348  44.850  1
110650  99.759  -79.353  44.842  1
110651  99.789  -79.370  44.834  1
110652  99.823  -79.404  44.826  1
110653  99.857  -79.436  44.819  1
110654  99.891  -79.469  44.811  1
110655  99.925  -79.501  44.803  1
110656  99.959  -79.534  44.795  1
110657  99.993  -79.567  44.787  1
110658  100.027  -79.604  44.779  1
110659  100.063  -79.635  44.771  1
110660  100.102  -79.645  44.763  1
110661  100.141  -79.654  44.755  1
110662  100.181  -79.664  44.745  1
110663  100.219  -79.673  44.736  1
110664  100.254  -79.683  44.726  1
110665  100.286  -79.695  44.715  1
110666  100.311  -79.733  44.703  1
110667  100.334  -79.773  44.691  1
110668  100.358  -79.811  44.679  1
110669  100.382  -79.850  44.666  1
110670  100.406  -79.889  44.651  1
110671  100.428  -79.920  44.638  1
110672  100.470  -79.923  44.625  1
110673  100.507  -79.922  44.611  1
110674  100.545  -79.921  44.598  1
110675  100.582  -79.921  44.584  1
110676  100.620  -79.920  44.570  1
110677  100.657  -79.919  44.555  1
110678  100.694  -79.918  44.540  1
110679  100.732  -79.918  44.526  1
110680  100.766  -79.946  44.512  1
110681  100.799  -79.980  44.498  1
110682  100.832  -80.015  44.484  1
110683  100.865  -80.051  44.469  1
110684  100.898  -80.086  44.456  1
110685  100.925  -80.117  44.442  1
110686  100.956  -80.149  44.428  1
110687  100.989  -80.183  44.414  1
110688  101.022  -80.217  44.400  1
110689  101.055  -80.250  44.385  1
110690  101.088  -80.284  44.369  1
110691  101.120  -80.318  44.355  1
110692  101.153  -80.352  44.339  1
110693  101.185  -80.375  44.323  1
110694  101.231  -80.388  44.309  1
110695  101.277  -80.402  44.293  1
110696  101.326  -80.424  44.278  1
110697  101.358  -80.440  44.261  1
110698  101.391  -80.456  44.245  1
110699  101.423  -80.472  44.229  1
110700  101.455  -80.488  44.212  1
110701  101.487  -80.504  44.195  1
110702  101.519  -80.521  44.177  1
110703  101.551  -80.537  44.160  1
110704  101.583  -80.553  44.144  1
110705  101.615  -80.569  44.127  1
110706  101.647  -80.585  44.110  1
110707  101.679  -80.601  44.092  1
110708  101.711  -80.617  44.075  1
111023  94.096  -78.188  52.385  1
111024  94.121  -78.178  52.360  1
111025  94.146  -78.169  52.335  1
111026  94.171  -78.159  52.311  1
111027  94.196  -78.150  52.286  1
111028  94.207  -78.147  52.261  1
111029  94.217  -78.145  52.236  1
111030  94.227  -78.142  52.211  1
111031  94.238  -78.139  52.186  1
111032  94.249  -78.137  52.162  1
111033  94.260  -78.132  52.138  1
111034  94.274  -78.125  52.113  1
111035  94.287  -78.117  52.087  1
111036  94.301  -78.109  52.063  1
111037  94.315  -78.102  52.039  1
111038  94.329  -78.094  52.014  1
111039  94.342  -78.087  51.990  1
111040  94.356  -78.079  51.967  1
111041  94.370  -78.072  51.942  1
111042  94.384  -78.065  51.918  1
111043  94.398  -78.058  51.894  1
111044  94.412  -78.052  51.870  1
111045  94.426  -78.045  51.846  1
111046  94.436  -78.039  51.823  1
111047  94.437  -78.035  51.800  1
111048  94.438  -78.031  51.775  1
111049  94.450  -78.023  51.750  1
111050  94.470  -78.013  51.723  1
111051  94.491  -78.003  51.698  1
111052  94.511  -77.993  51.672  1
111053  94.532  -77.984  51.645  1
111054  94.547  -77.985  51.619  1
111055  94.576  -77.995  51.591  1
111056  94.613  -78.011  51.562  1
111057  94.651  -78.028  51.534  1
111058  94.665  -78.029  51.505  1
111059  94.676  -78.030  51.476  1
111060  94.688  -78.031  51.447  1
111061  94.699  -78.030  51.420  1
111062  94.707  -78.021  51.390  1
111063  94.715  -78.012  51.360  1
111064  94.723  -78.003  51.330  1
111065  94.726  -78.004  51.299  1
111066  94.726  -78.011  51.269  1
111067  94.726  -78.018  51.239  1
111068  94.736  -78.017  51.208  1
111069  94.748  -78.015  51.177  1
111070  94.760  -78.021  51.145  1
111071  94.772  -78.025  51.111  1
111072  94.784  -78.031  51.079  1
111073  94.802  -78.036  51.046  1
111074  94.826  -78.044  51.013  1
111075  94.851  -78.050  50.979  1
111076  94.876  -78.058  50.944  1
111077  94.898  -78.059  50.909  1
111078  94.917  -78.042  50.874  1
111079  94.935  -78.025  50.839  1
111080  94.953  -78.007  50.804  1
111081  94.971  -77.990  50.769  1
111082  94.989  -77.973  50.735  1
111083  95.007  -77.956  50.701  1
111084  95.026  -77.939  50.666  1
111085  95.043  -77.921  50.632  1
111086  95.052  -77.909  50.598  1
111087  95.061  -77.895  50.565  1
111088  95.070  -77.882  50.532  1
111089  95.078  -77.868  50.501  1
111090  95.088  -77.855  50.469  1
111091  95.112  -77.833  50.438  1
111092  95.136  -77.837  50.408  1
111093  95.159  -77.840  50.379  1
111094  95.183  -77.845  50.351  1
111095  95.206  -77.849  50.324  1
111096  95.230  -77.852  50.296  1
111097  95.268  -77.902  50.266  1
111098  95.270  -77.912  50.237  1
111099  95.291  -77.915  50.210  1
111100  95.328  -77.908  50.186  1
111101  95.357  -77.902  50.163  1
111102  95.371  -77.902  50.141  1
111103  95.380  -77.903  50.122  1
111104  95.386  -77.906  50.102  1
111105  95.392  -77.908  50.081  1
111106  95.399  -77.910  50.059  1
111107  95.405  -77.912  50.034  1
111108  95.412  -77.915  50.006  1
111109  95.418  -77.917  49.976  1
111110  95.424  -77.920  49.942  1
111111  95.431  -77.922  49.906  1
111112  95.438  -77.924  49.868  1
111113  95.444  -77.927  49.829  1
111114  95.453  -77.932  49.789  1
111115  95.475  -77.954  49.750  1
111116  95.496  -77.976  49.711  1
111117  95.519  -77.997  49.675  1
111118  95.550  -77.986  49.640  1
111119  95.581  -77.975  49.605  1
111120  95.607  -77.961  49.568  1
111121  95.626  -77.943  49.531  1
111122  95.645  -77.925  49.494  1
111123  95.664  -77.908  49.457  1
111124  95.683  -77.890  49.421  1
111125  95.664  -77.923  49.385  1
111126  95.638  -77.964  49.349  1
111127  95.643  -77.978  49.313  1
111128  95.659  -77.983  49.276  1
111129  95.692  -77.963  49.238  1
111130  95.686  -77.940  49.201  1
111131  95.683  -77.959  49.162  1
111132  95.679  -77.979  49.124  1
111133  95.686  -77.980  49.085  1
111134  95.709  -77.981  49.048  1
111135  95.736  -77.990  49.010  1
111136  95.763  -78.000  48.972  1
111137  95.790  -78.009  48.933  1
111138  95.813  -78.012  48.892  1
111139  95.835  -78.015  48.851  1
111140  95.856  -78.018  48.810  1
111141  95.879  -78.020  48.769  1
111142  95.894  -78.030  48.730  1
111143  95.903  -78.047  48.691  1
111144  95.900  -78.070  48.651  1
111145  95.895  -78.090  48.612  1
111146  95.902  -78.087  48.575  1
111147  95.909  -78.086  48.539  1
111148  95.915  -78.084  48.502  1
111149  95.922  -78.082  48.466  1
111150  95.936  -78.082  48.429  1
111151  95.952  -78.079  48.392  1
111152  95.968  -78.076  48.354  1
111153  95.984  -78.073  48.320  1
111154  96.000  -78.072  48.286  1
111155  96.016  -78.071  48.253  1
111156  96.032  -78.070  48.220  1
111157  96.048  -78.069  48.189  1
111158  96.065  -78.068  48.158  1
111159  96.081  -78.067  48.128  1
111160  96.096  -78.065  48.100  1
111161  96.097  -78.063  48.073  1
111162  96.101  -78.061  48.045  1
111163  96.125  -78.071  48.019  1
111164  96.143  -78.082  47.991  1
111165  96.157  -78.096  47.962  1
111166  96.171  -78.109  47.932  1
111167  96.185  -78.122  47.905  1
111168  96.199  -78.134  47.877  1
111169  96.215  -78.141  47.849  1
111170  96.229  -78.146  47.822  1
111171  96.244  -78.156  47.795  1
111172  96.259  -78.169  47.768  1
111173  96.274  -78.181  47.743  1
111174  96.287  -78.191  47.720  1
111175  96.299  -78.200  47.696  1
111176  96.312  -78.210  47.673  1
111177  96.324  -78.219  47.651  1
111178  96.338  -78.229  47.627  1
111179  96.355  -78.241  47.601  1
111180  96.374  -78.253  47.574  1
111181  96.393  -78.264  47.550  1
111182  96.412  -78.272  47.524  1
111183  96.429  -78.276  47.499  1
111184  96.445  -78.279  47.475  1
111185  96.461  -78.283  47.453  1
111186  96.478  -78.287  47.430  1
111187  96.490  -78.293  47.407  1
111188  96.500  -78.301  47.383  1
111189  96.510  -78.310  47.358  1
111190  96.520  -78.319  47.332  1
111191  96.530  -78.329  47.305  1
111192  96.540  -78.338  47.276  1
111193  96.544  -78.341  47.248  1
111194  96.543  -78.342  47.220  1
111195  96.543  -78.344  47.195  1
111196  96.547  -78.344  47.169  1
111197  96.562  -78.345  47.144  1
111198  96.568  -78.369  47.119  1
111199  96.573  -78.392  47.092  1
111200  96.579  -78.416  47.067  1
111201  96.584  -78.439  47.042  1
111202  96.590  -78.463  47.017  1
111203  96.595  -78.487  46.992  1
111204  96.603  -78.507  46.965  1
111205  96.613  -78.530  46.937  1
111206  96.613  -78.548  46.911  1
111207  96.610  -78.567  46.885  1
111208  96.607  -78.586  46.859  1
111209  96.604  -78.606  46.834  1
111210  96.601  -78.626  46.807  1
111211  96.599  -78.645  46.781  1
111212  96.621  -78.659  46.756  1
111213  96.652  -78.670  46.728  1
111214  96.693  -78.682  46.700  1
111215  96.734  -78.692  46.672  1
111216  96.774  -78.703  46.644  1
111217  96.815  -78.714  46.616  1
111218  96.852  -78.727  46.588  1
111219  96.882  -78.745  46.560  1
111220  96.911  -78.762  46.531  1
111221  96.941  -78.780  46.503  1
111222  96.970  -78.798  46.475  1
111223  96.997  -78.809  46.448  1
111224  97.024  -78.820  46.423  1
111225  97.068  -78.830  46.397  1
111226  97.117  -78.841  46.373  1
111227  97.168  -78.851  46.350  1
111228  97.228  -78.858  46.327  1
111229  97.271  -78.851  46.305  1
111230  97.311  -78.842  46.285  1
111231  97.346  -78.830  46.265  1
111232  97.383  -78.824  46.246  1
111233  97.421  -78.824  46.228  1
111234  97.460  -78.822  46.211  1
111235  97.499  -78.821  46.194  1
111236  97.537  -78.821  46.178  1
111237  97.576  -78.820  46.164  1
111238  97.614  -78.819  46.148  1
111239  97.653  -78.818  46.133  1
111240  97.692  -78.818  46.117  1
111241  97.696  -78.867  46.102  1
111242  97.674  -78.865  46.088  1
111243  97.676  -78.854  46.074  1
111244  97.704  -78.861  46.059  1
111245  97.731  -78.831  46.044  1
111246  97.780  -78.830  46.029  1
111247  97.801  -78.789  46.015  1
111248  97.822  -78.750  46.001  1
111249  97.843  -78.711  45.986  1
111250  97.870  -78.690  45.971  1
111251  97.889  -78.696  45.956  1
111252  97.911  -78.702  45.938  1
111253  97.935  -78.709  45.921  1
111254  97.959  -78.715  45.904  1
111255  97.986  -78.713  45.888  1
111256  98.001  -78.711  45.871  1
111257  98.014  -78.691  45.855  1
111258  98.008  -78.717  45.839  1
111259  98.001  -78.743  45.822  1
111260  97.984  -78.733  45.806  1
111261  97.962  -78.693  45.791  1
111262  97.973  -78.664  45.776  1
111263  97.987  -78.636  45.760  1
111264  98.005  -78.670  45.745  1
111265  98.004  -78.692  45.730  1
111266  98.004  -78.713  45.717  1
111267  98.005  -78.733  45.702  1
111268  98.005  -78.753  45.687  1
111269  98.032  -78.758  45.672  1
111270  98.061  -78.760  45.656  1
111271  98.090  -78.763  45.641  1
111272  98.115  -78.772  45.626  1
111273  98.137  -78.787  45.611  1
111274  98.158  -78.802  45.596  1
111275  98.179  -78.817  45.582  1
111276  98.189  -78.811  45.569  1
111277  98.195  -78.800  45.557  1
111278  98.200  -78.788  45.545  1
111279  98.206  -78.776  45.534  1
111280  98.211  -78.764  45.522  1
111281  98.217  -78.753  45.510  1
111282  98.235  -78.790  45.498  1
111283  98.228  -78.821  45.484  1
111284  98.249  -78.800  45.469  1
111285  98.269  -78.774  45.455  1
111286  98.288  -78.749  45.441  1
111287  98.307  -78.772  45.427  1
111288  98.325  -78.801  45.413  1
111289  98.344  -78.830  45.400  1
111290  98.363  -78.859  45.387  1
111291  98.382  -78.889  45.374  1
111292  98.391  -78.883  45.362  1
111293  98.376  -78.888  45.349  1
111294  98.381  -78.927  45.337  1
111295  98.446  -78.990  45.325  1
111296  98.481  -78.999  45.314  1
111297  98.504  -79.002  45.304  1
111298  98.527  -79.004  45.292  1
111299  98.550  -79.007  45.280  1
111300  98.573  -79.009  45.268  1
111301  98.596  -79.012  45.255  1
111302  98.619  -79.015  45.241  1
111303  98.642  -79.017  45.227  1
111304  98.665  -79.020  45.213  1
111305  98.688  -79.022  45.196  1
111306  98.711  -79.025  45.180  1
111307  98.734  -79.028  45.163  1
111308  98.757  -79.030  45.148  1
111309  98.797  -79.026  45.135  1
111310  98.833  -79.006  45.122  1
111311  98.878  -78.988  45.111  1
111312  98.934  -78.981  45.101  1
111313  98.979  -78.980  45.091  1
111314  99.004  -78.987  45.082  1
111315  99.029  -78.993  45.074  1
111316  99.055  -78.996  45.065  1
111317  99.080  -78.997  45.055  1
111318  99.106  -78.999  45.045  1
111319  99.131  -79.001  45.033  1
111320  99.151  -79.006  45.023  1
111321  99.165  -79.017  45.015  1
111322  99.179  -79.028  45.006  1
111323  99.192  -79.038  44.995  1
111324  99.205  -79.049  44.983  1
111325  99.217  -79.059  44.972  1
111326  99.237  -79.060  44.960  1
111327  99.256  -79.061  44.950  1
111328  99.274  -79.062  44.940  1
111329  99.282  -79.079  44.931  1
111330  99.309  -79.082  44.923  1
111331  99.345  -79.079  44.916  1
111332  99.375  -79.081  44.909  1
111333  99.415  -79.090  44.904  1
111334  99.462  -79.105  44.899  1
111335  99.508  -79.120  44.895  1
111336  99.554  -79.134  44.892  1
111337  99.604  -79.159  44.891  1
111338  99.599  -79.157  44.889  1
111339  99.542  -79.159  44.887  1
111340  99.525  -79.172  44.885  1
111341  99.531  -79.191  44.884  1
111342  99.537  -79.211  44.884  1
111343  99.558  -79.237  44.883  1
111344  99.581  -79.264  44.880  1
111345  99.604  -79.291  44.876  1
111346  99.627  -79.313  44.871  1
111347  99.653  -79.318  44.866  1
111348  99.679  -79.322  44.860  1
111349  99.705  -79.327  44.853  1
111350  99.731  -79.332  44.846  1
111351  99.757  -79.337  44.839  1
111352  99.791  -79.369  44.830  1
111353  99.825  -79.402  44.822  1
111354  99.859  -79.435  44.815  1
111355  99.893  -79.467  44.807  1
111356  99.927  -79.500  44.799  1
111357  99.961  -79.533  44.791  1
111358  99.995  -79.566  44.784  1
111359  100.029  -79.601  44.776  1
111360  100.065  -79.629  44.768  1
111361  100.105  -79.638  44.760  1
111362  100.144  -79.648  44.751  1
111363  100.183  -79.657  44.742  1
111364  100.216  -79.667  44.732  1
111365  100.250  -79.677  44.724  1
111366  100.283  -79.687  44.714  1
111367  100.309  -79.721  44.704  1
111368  100.333  -79.760  44.691  1
111369  100.358  -79.797  44.678  1
111370  100.387  -79.830  44.665  1
111371  100.415  -79.862  44.650  1
111372  100.420  -79.889  44.636  1
111373  100.477  -79.898  44.623  1
111374  100.514  -79.897  44.609  1
111375  100.552  -79.896  44.597  1
111376  100.590  -79.896  44.583  1
111377  100.627  -79.895  44.570  1
111378  100.664  -79.894  44.556  1
111379  100.701  -79.893  44.541  1
111380  100.739  -79.892  44.526  1
111381  100.772  -79.922  44.512  1
111382  100.805  -79.957  44.498  1
111383  100.839  -79.993  44.484  1
111384  100.872  -80.027  44.471  1
111385  100.905  -80.062  44.457  1
111386  100.938  -80.097  44.443  1
111387  100.971  -80.133  44.430  1
111388  100.996  -80.162  44.417  1
111389  101.026  -80.194  44.404  1
111390  101.059  -80.228  44.388  1
111391  101.092  -80.262  44.373  1
111392  101.125  -80.296  44.358  1
111393  101.151  -80.322  44.343  1
111394  101.198  -80.334  44.328  1
111395  101.244  -80.346  44.313  1
111396  101.291  -80.369  44.299  1
111397  101.344  -80.385  44.283  1
111398  101.376  -80.402  44.267  1
111399  101.408  -80.418  44.251  1
111400  101.440  -80.434  44.235  1
111401  101.472  -80.450  44.219  1
111402  101.504  -80.466  44.202  1
111403  101.536  -80.482  44.184  1
111404  101.568  -80.498  44.167  1
111405  101.601  -80.515  44.150  1
111406  101.632  -80.531  44.134  1
111407  101.665  -80.547  44.116  1
111408  101.697  -80.563  44.099  1
111409  101.729  -80.579  44.081  1
111745  94.421  -78.033  51.863  1
111746  94.435  -78.026  51.840  1
111747  94.449  -78.019  51.817  1
111748  94.450  -78.015  51.794  1
111749  94.451  -78.011  51.770  1
111750  94.452  -78.006  51.745  1
111751  94.473  -77.996  51.720  1
111752  94.493  -77.987  51.694  1
111753  94.514  -77.977  51.669  1
111754  94.535  -77.967  51.643  1
111755  94.551  -77.966  51.617  1
111756  94.571  -77.970  51.589  1
111757  94.609  -77.987  51.562  1
111758  94.646  -78.003  51.533  1
111759  94.664  -78.006  51.504  1
111760  94.675  -78.007  51.476  1
111761  94.686  -78.008  51.447  1
111762  94.698  -78.008  51.420  1
111763  94.707  -78.002  51.390  1
111764  94.715  -77.993  51.360  1
111765  94.723  -77.984  51.329  1
111766  94.728  -77.984  51.300  1
111767  94.727  -77.992  51.270  1
111768  94.727  -77.999  51.240  1
111769  94.734  -78.000  51.210  1
111770  94.746  -77.998  51.179  1
111771  94.758  -78.003  51.146  1
111772  94.770  -78.008  51.113  1
111773  94.782  -78.013  51.081  1
111774  94.804  -78.020  51.048  1
111775  94.829  -78.027  51.014  1
111776  94.853  -78.034  50.980  1
111777  94.878  -78.041  50.946  1
111778  94.901  -78.040  50.910  1
111779  94.919  -78.024  50.876  1
111780  94.937  -78.006  50.840  1
111781  94.955  -77.989  50.806  1
111782  94.973  -77.971  50.772  1
111783  94.992  -77.955  50.738  1
111784  95.010  -77.937  50.704  1
111785  95.028  -77.920  50.669  1
111786  95.037  -77.907  50.634  1
111787  95.046  -77.893  50.601  1
111788  95.055  -77.881  50.568  1
111789  95.064  -77.867  50.534  1
111790  95.072  -77.854  50.503  1
111791  95.082  -77.840  50.472  1
111792  95.094  -77.823  50.441  1
111793  95.123  -77.807  50.410  1
111794  95.147  -77.812  50.382  1
111795  95.171  -77.815  50.354  1
111796  95.205  -77.852  50.327  1
111797  95.244  -77.904  50.296  1
111798  95.239  -77.907  50.266  1
111799  95.242  -77.906  50.236  1
111800  95.278  -77.908  50.207  1
111801  95.315  -77.900  50.182  1
111802  95.352  -77.893  50.158  1
111803  95.370  -77.891  50.135  1
111804  95.384  -77.890  50.114  1
111805  95.395  -77.890  50.094  1
111806  95.401  -77.893  50.073  1
111807  95.407  -77.895  50.049  1
111808  95.414  -77.897  50.024  1
111809  95.420  -77.899  49.995  1
111810  95.427  -77.902  49.963  1
111811  95.433  -77.904  49.929  1
111812  95.440  -77.907  49.892  1
111813  95.446  -77.909  49.854  1
111814  95.453  -77.912  49.815  1
111815  95.461  -77.916  49.777  1
111816  95.482  -77.938  49.740  1
111817  95.505  -77.959  49.704  1
111818  95.527  -77.981  49.671  1
111819  95.547  -77.993  49.639  1
111820  95.566  -77.976  49.605  1
111821  95.585  -77.959  49.569  1
111822  95.604  -77.940  49.532  1
111823  95.623  -77.923  49.495  1
111824  95.642  -77.906  49.460  1
111825  95.662  -77.887  49.423  1
111826  95.656  -77.902  49.388  1
111827  95.630  -77.943  49.352  1
111828  95.634  -77.958  49.315  1
111829  95.650  -77.963  49.279  1
111830  95.665  -77.968  49.243  1
111831  95.703  -77.943  49.207  1
111832  95.682  -77.951  49.169  1
111833  95.679  -77.971  49.129  1
111834  95.697  -77.966  49.091  1
111835  95.724  -77.975  49.054  1
111836  95.750  -77.984  49.017  1
111837  95.774  -77.990  48.980  1
111838  95.796  -77.992  48.941  1
111839  95.818  -77.994  48.901  1
111840  95.840  -77.996  48.860  1
111841  95.862  -77.999  48.819  1
111842  95.883  -78.003  48.779  1
111843  95.892  -78.019  48.739  1
111844  95.901  -78.037  48.699  1
111845  95.898  -78.060  48.659  1
111846  95.895  -78.075  48.619  1
111847  95.902  -78.074  48.583  1
111848  95.909  -78.072  48.547  1
111849  95.915  -78.070  48.510  1
111850  95.925  -78.070  48.474  1
111851  95.938  -78.071  48.437  1
111852  95.954  -78.068  48.400  1
111853  95.970  -78.065  48.362  1
111854  95.986  -78.062  48.328  1
111855  96.003  -78.059  48.295  1
111856  96.019  -78.056  48.262  1
111857  96.035  -78.053  48.230  1
111858  96.051  -78.049  48.200  1
111859  96.067  -78.048  48.169  1
111860  96.083  -78.047  48.139  1
111861  96.099  -78.046  48.112  1
111862  96.115  -78.045  48.085  1
111863  96.116  -78.042  48.057  1
111864  96.138  -78.052  48.030  1
111865  96.152  -78.065  48.002  1
111866  96.166  -78.078  47.973  1
111867  96.180  -78.091  47.945  1
111868  96.194  -78.104  47.918  1
111869  96.208  -78.118  47.891  1
111870  96.222  -78.131  47.864  1
111871  96.237  -78.137  47.837  1
111872  96.252  -78.145  47.810  1
111873  96.267  -78.157  47.784  1
111874  96.281  -78.169  47.758  1
111875  96.294  -78.178  47.734  1
111876  96.306  -78.187  47.711  1
111877  96.318  -78.197  47.689  1
111878  96.331  -78.206  47.667  1
111879  96.343  -78.214  47.644  1
111880  96.363  -78.225  47.619  1
111881  96.382  -78.237  47.592  1
111882  96.402  -78.248  47.567  1
111883  96.421  -78.257  47.541  1
111884  96.437  -78.261  47.516  1
111885  96.454  -78.265  47.492  1
111886  96.470  -78.269  47.469  1
111887  96.484  -78.273  47.446  1
111888  96.489  -78.280  47.423  1
111889  96.496  -78.288  47.399  1
111890  96.506  -78.297  47.374  1
111891  96.516  -78.306  47.347  1
111892  96.526  -78.315  47.321  1
111893  96.531  -78.319  47.294  1
111894  96.530  -78.321  47.267  1
111895  96.530  -78.322  47.240  1
111896  96.529  -78.322  47.215  1
111897  96.540  -78.322  47.188  1
111898  96.553  -78.328  47.162  1
111899  96.558  -78.352  47.137  1
111900  96.564  -78.376  47.111  1
111901  96.569  -78.399  47.086  1
111902  96.575  -78.423  47.060  1
111903  96.582  -78.442  47.034  1
111904  96.591  -78.458  47.007  1
111905  96.601  -78.473  46.980  1
111906  96.614  -78.517  46.951  1
111907  96.619  -78.525  46.924  1
111908  96.620  -78.542  46.897  1
111909  96.617  -78.561  46.870  1
111910  96.614  -78.581  46.844  1
111911  96.611  -78.601  46.817  1
111912  96.608  -78.620  46.791  1
111913  96.638  -78.633  46.764  1
111914  96.668  -78.645  46.736  1
111915  96.699  -78.657  46.708  1
111916  96.738  -78.667  46.681  1
111917  96.779  -78.678  46.652  1
111918  96.819  -78.689  46.624  1
111919  96.857  -78.702  46.597  1
111920  96.887  -78.719  46.569  1
111921  96.916  -78.737  46.541  1
111922  96.946  -78.755  46.512  1
111923  96.973  -78.766  46.484  1
111924  97.000  -78.777  46.457  1
111925  97.027  -78.789  46.432  1
111926  97.070  -78.799  46.406  1
111927  97.120  -78.809  46.380  1
111928  97.170  -78.819  46.357  1
111929  97.220  -78.830  46.335  1
111930  97.271  -78.838  46.313  1
111931  97.309  -78.833  46.292  1
111932  97.348  -78.833  46.273  1
111933  97.386  -78.832  46.255  1
111934  97.425  -78.831  46.237  1
111935  97.463  -78.830  46.221  1
111936  97.502  -78.830  46.204  1
111937  97.541  -78.829  46.188  1
111938  97.579  -78.828  46.174  1
111939  97.618  -78.827  46.159  1
111940  97.657  -78.827  46.146  1
111941  97.696  -78.826  46.131  1
111942  97.694  -78.843  46.116  1
111943  97.696  -78.832  46.101  1
111944  97.699  -78.821  46.086  1
111945  97.721  -78.827  46.071  1
111946  97.749  -78.826  46.056  1
111947  97.781  -78.798  46.042  1
111948  97.805  -78.757  46.028  1
111949  97.831  -78.715  46.014  1
111950  97.850  -78.691  45.999  1
111951  97.867  -78.691  45.984  1
111952  97.892  -78.695  45.967  1
111953  97.919  -78.703  45.950  1
111954  97.945  -78.711  45.933  1
111955  97.972  -78.719  45.916  1
111956  97.999  -78.727  45.899  1
111957  98.018  -78.710  45.883  1
111958  98.031  -78.702  45.867  1
111959  98.042  -78.727  45.851  1
111960  98.054  -78.754  45.834  1
111961  98.008  -78.737  45.818  1
111962  97.983  -78.697  45.803  1
111963  97.994  -78.668  45.787  1
111964  98.005  -78.639  45.772  1
111965  98.028  -78.635  45.756  1
111966  98.024  -78.669  45.741  1
111967  98.024  -78.689  45.727  1
111968  98.024  -78.709  45.712  1
111969  98.024  -78.729  45.696  1
111970  98.033  -78.744  45.681  1
111971  98.062  -78.747  45.666  1
111972  98.091  -78.750  45.650  1
111973  98.112  -78.765  45.635  1
111974  98.134  -78.780  45.621  1
111975  98.155  -78.796  45.607  1
111976  98.177  -78.809  45.592  1
111977  98.191  -78.815  45.579  1
111978  98.197  -78.810  45.566  1
111979  98.203  -78.802  45.553  1
111980  98.210  -78.793  45.540  1
111981  98.216  -78.783  45.529  1
111982  98.232  -78.786  45.518  1
111983  98.228  -78.819  45.505  1
111984  98.250  -78.808  45.491  1
111985  98.274  -78.796  45.476  1
111986  98.295  -78.777  45.462  1
111987  98.314  -78.752  45.447  1
111988  98.339  -78.755  45.433  1
111989  98.367  -78.782  45.419  1
111990  98.396  -78.810  45.405  1
111991  98.424  -78.837  45.392  1
111992  98.445  -78.871  45.379  1
111993  98.412  -78.891  45.366  1
111994  98.416  -78.893  45.354  1
111995  98.440  -78.885  45.343  1
111996  98.406  -78.959  45.331  1
111997  98.460  -79.021  45.319  1
111998  98.483  -79.024  45.308  1
111999  98.506  -79.027  45.295  1
112000  98.529  -79.030  45.283  1
112001  98.552  -79.032  45.271  1
112002  98.575  -79.034  45.257  1
112003  98.598  -79.037  45.245  1
112004  98.621  -79.040  45.233  1
112005  98.644  -79.043  45.218  1
112006  98.667  -79.045  45.204  1
112007  98.690  -79.048  45.188  1
112008  98.734  -79.043  45.173  1
112009  98.779  -79.037  45.157  1
112010  98.825  -79.031  45.142  1
112011  98.846  -78.990  45.128  1
112012  98.883  -78.963  45.116  1
112013  98.939  -78.956  45.104  1
112014  98.982  -78.955  45.095  1
112015  99.008  -78.963  45.086  1
112016  99.033  -78.971  45.079  1
112017  99.059  -78.979  45.069  1
112018  99.085  -78.984  45.059  1
112019  99.110  -78.985  45.049  1
112020  99.135  -78.987  45.039  1
112021  99.148  -78.998  45.029  1
112022  99.161  -79.009  45.019  1
112023  99.175  -79.019  45.009  1
112024  99.189  -79.026  44.998  1
112025  99.203  -79.032  44.987  1
112026  99.219  -79.041  44.975  1
112027  99.242  -79.060  44.962  1
112028  99.263  -79.066  44.952  1
112029  99.282  -79.065  44.942  1
112030  99.300  -79.065  44.933  1
112031  99.325  -79.080  44.924  1
112032  99.354  -79.083  44.917  1
112033  99.372  -79.071  44.911  1
112034  99.405  -79.072  44.905  1
112035  99.451  -79.087  44.902  1
112036  99.497  -79.101  44.899  1
112037  99.548  -79.128  44.898  1
112038  99.596  -79.150  44.896  1
112039  99.633  -79.143  44.895  1
112040  99.579  -79.146  44.895  1
112041  99.546  -79.154  44.893  1
112042  99.552  -79.173  44.891  1
112043  99.558  -79.193  44.889  1
112044  99.563  -79.212  44.886  1
112045  99.580  -79.236  44.881  1
112046  99.603  -79.263  44.875  1
112047  99.626  -79.291  44.868  1
112048  99.650  -79.301  44.861  1
112049  99.677  -79.306  44.855  1
112050  99.702  -79.311  44.847  1
112051  99.728  -79.316  44.840  1
112052  99.759  -79.335  44.832  1
112053  99.792  -79.368  44.824  1
112054  99.827  -79.400  44.817  1
112055  99.860  -79.433  44.811  1
112056  99.895  -79.466  44.803  1
112057  99.929  -79.499  44.795  1
112058  99.963  -79.532  44.787  1
112059  99.997  -79.564  44.779  1
112060  100.031  -79.598  44.771  1
112061  100.068  -79.622  44.764  1
112062  100.107  -79.632  44.755  1
112063  100.145  -79.641  44.746  1
112064  100.179  -79.651  44.738  1
112065  100.213  -79.661  44.729  1
112066  100.246  -79.671  44.720  1
112067  100.280  -79.681  44.712  1
112068  100.311  -79.705  44.704  1
112069  100.339  -79.738  44.692  1
112070  100.368  -79.770  44.678  1
112071  100.397  -79.802  44.664  1
112072  100.425  -79.835  44.650  1
112073  100.414  -79.857  44.636  1
112074  100.472  -79.866  44.623  1
112075  100.522  -79.871  44.609  1
112076  100.559  -79.871  44.596  1
112077  100.597  -79.870  44.583  1
112078  100.634  -79.869  44.570  1
112079  100.671  -79.868  44.556  1
112080  100.708  -79.867  44.542  1
112081  100.746  -79.867  44.528  1
112082  100.779  -79.899  44.513  1
112083  100.813  -79.933  44.500  1
112084  100.846  -79.969  44.487  1
112085  100.879  -80.004  44.474  1
112086  100.912  -80.039  44.461  1
112087  100.945  -80.074  44.448  1
112088  100.978  -80.109  44.434  1
112089  101.011  -80.144  44.421  1
112090  101.044  -80.180  44.406  1
112091  101.068  -80.208  44.392  1
112092  101.096  -80.239  44.377  1
112093  101.123  -80.267  44.363  1
112094  101.165  -80.281  44.348  1
112095  101.211  -80.293  44.333  1
112096  101.257  -80.305  44.319  1
112097  101.305  -80.334  44.305  1
112098  101.361  -80.347  44.289  1
112099  101.393  -80.363  44.274  1
112100  101.425  -80.379  44.258  1
112101  101.457  -80.396  44.243  1
112102  101.489  -80.412  44.226  1
112103  101.522  -80.428  44.209  1
112104  101.553  -80.444  44.191  1
112105  101.586  -80.460  44.174  1
112106  101.618  -80.476  44.157  1
112107  101.650  -80.493  44.140  1
112108  101.682  -80.509  44.124  1
112109  101.714  -80.525  44.106  1
112110  101.746  -80.541  44.088  1
112111  101.778  -80.557  44.071  1
112448  94.459  -78.000  51.813  1
112449  94.463  -77.996  51.791  1
112450  94.464  -77.991  51.767  1
112451  94.465  -77.987  51.742  1
112452  94.475  -77.980  51.718  1
112453  94.496  -77.970  51.692  1
112454  94.517  -77.960  51.667  1
112455  94.537  -77.949  51.643  1
112456  94.554  -77.947  51.616  1
112457  94.569  -77.947  51.590  1
112458  94.605  -77.962  51.562  1
112459  94.642  -77.978  51.533  1
112460  94.662  -77.984  51.505  1
112461  94.674  -77.984  51.477  1
112462  94.685  -77.984  51.449  1
112463  94.696  -77.985  51.421  1
112464  94.707  -77.984  51.392  1
112465  94.715  -77.975  51.362  1
112466  94.723  -77.966  51.331  1
112467  94.728  -77.965  51.302  1
112468  94.728  -77.972  51.272  1
112469  94.728  -77.979  51.241  1
112470  94.732  -77.983  51.212  1
112471  94.743  -77.981  51.181  1
112472  94.755  -77.986  51.148  1
112473  94.767  -77.990  51.115  1
112474  94.782  -77.996  51.083  1
112475  94.807  -78.003  51.049  1
112476  94.832  -78.010  51.015  1
112477  94.856  -78.018  50.982  1
112478  94.881  -78.025  50.948  1
112479  94.903  -78.022  50.913  1
112480  94.921  -78.005  50.878  1
112481  94.939  -77.988  50.843  1
112482  94.958  -77.971  50.809  1
112483  94.976  -77.953  50.775  1
112484  94.994  -77.936  50.741  1
112485  95.012  -77.919  50.706  1
112486  95.022  -77.906  50.671  1
112487  95.031  -77.892  50.637  1
112488  95.040  -77.879  50.603  1
112489  95.049  -77.865  50.570  1
112490  95.057  -77.852  50.536  1
112491  95.066  -77.839  50.504  1
112492  95.075  -77.826  50.473  1
112493  95.084  -77.812  50.441  1
112494  95.111  -77.778  50.409  1
112495  95.141  -77.804  50.380  1
112496  95.181  -77.855  50.351  1
112497  95.219  -77.907  50.322  1
112498  95.209  -77.902  50.291  1
112499  95.193  -77.891  50.262  1
112500  95.228  -77.908  50.232  1
112501  95.264  -77.900  50.203  1
112502  95.302  -77.893  50.176  1
112503  95.339  -77.886  50.152  1
112504  95.370  -77.880  50.129  1
112505  95.383  -77.879  50.106  1
112506  95.396  -77.878  50.082  1
112507  95.409  -77.877  50.058  1
112508  95.416  -77.880  50.034  1
112509  95.422  -77.882  50.006  1
112510  95.429  -77.884  49.978  1
112511  95.436  -77.887  49.948  1
112512  95.442  -77.889  49.914  1
112513  95.448  -77.891  49.880  1
112514  95.455  -77.894  49.846  1
112515  95.461  -77.896  49.811  1
112516  95.469  -77.899  49.773  1
112517  95.490  -77.921  49.736  1
112518  95.513  -77.943  49.701  1
112519  95.534  -77.965  49.668  1
112520  95.542  -77.982  49.636  1
112521  95.546  -77.972  49.603  1
112522  95.563  -77.956  49.570  1
112523  95.583  -77.938  49.535  1
112524  95.602  -77.921  49.500  1
112525  95.620  -77.902  49.465  1
112526  95.639  -77.885  49.429  1
112527  95.648  -77.882  49.394  1
112528  95.622  -77.922  49.358  1
112529  95.625  -77.938  49.322  1
112530  95.640  -77.943  49.285  1
112531  95.656  -77.949  49.247  1
112532  95.672  -77.954  49.210  1
112533  95.682  -77.943  49.172  1
112534  95.685  -77.952  49.136  1
112535  95.711  -77.961  49.099  1
112536  95.736  -77.966  49.063  1
112537  95.757  -77.968  49.026  1
112538  95.779  -77.971  48.989  1
112539  95.802  -77.973  48.950  1
112540  95.823  -77.975  48.910  1
112541  95.845  -77.978  48.871  1
112542  95.868  -77.980  48.831  1
112543  95.881  -77.993  48.790  1
112544  95.890  -78.009  48.749  1
112545  95.898  -78.027  48.708  1
112546  95.896  -78.050  48.668  1
112547  95.895  -78.062  48.629  1
112548  95.902  -78.059  48.592  1
112549  95.909  -78.058  48.556  1
112550  95.916  -78.056  48.520  1
112551  95.929  -78.057  48.482  1
112552  95.942  -78.059  48.446  1
112553  95.956  -78.057  48.409  1
112554  95.972  -78.053  48.372  1
112555  95.988  -78.050  48.338  1
112556  96.005  -78.047  48.305  1
112557  96.021  -78.044  48.273  1
112558  96.037  -78.041  48.242  1
112559  96.053  -78.038  48.212  1
112560  96.070  -78.035  48.182  1
112561  96.086  -78.032  48.153  1
112562  96.102  -78.028  48.127  1
112563  96.118  -78.025  48.099  1
112564  96.133  -78.024  48.071  1
112565  96.147  -78.034  48.044  1
112566  96.161  -78.047  48.015  1
112567  96.175  -78.060  47.987  1
112568  96.189  -78.074  47.959  1
112569  96.203  -78.087  47.933  1
112570  96.217  -78.100  47.906  1
112571  96.231  -78.113  47.880  1
112572  96.245  -78.126  47.854  1
112573  96.260  -78.133  47.828  1
112574  96.275  -78.145  47.802  1
112575  96.288  -78.155  47.776  1
112576  96.300  -78.164  47.751  1
112577  96.314  -78.173  47.727  1
112578  96.329  -78.181  47.703  1
112579  96.344  -78.189  47.680  1
112580  96.352  -78.197  47.657  1
112581  96.371  -78.210  47.634  1
112582  96.391  -78.222  47.609  1
112583  96.410  -78.233  47.583  1
112584  96.430  -78.243  47.557  1
112585  96.446  -78.247  47.531  1
112586  96.463  -78.250  47.506  1
112587  96.479  -78.253  47.483  1
112588  96.485  -78.261  47.460  1
112589  96.490  -78.268  47.436  1
112590  96.495  -78.275  47.413  1
112591  96.502  -78.283  47.388  1
112592  96.512  -78.292  47.363  1
112593  96.518  -78.298  47.337  1
112594  96.518  -78.299  47.311  1
112595  96.517  -78.300  47.285  1
112596  96.517  -78.301  47.259  1
112597  96.517  -78.302  47.233  1
112598  96.532  -78.301  47.207  1
112599  96.543  -78.311  47.180  1
112600  96.549  -78.335  47.155  1
112601  96.554  -78.358  47.129  1
112602  96.561  -78.379  47.101  1
112603  96.571  -78.395  47.072  1
112604  96.580  -78.410  47.044  1
112605  96.589  -78.425  47.018  1
112606  96.599  -78.441  46.991  1
112607  96.616  -78.506  46.964  1
112608  96.619  -78.506  46.936  1
112609  96.625  -78.520  46.908  1
112610  96.627  -78.536  46.881  1
112611  96.624  -78.556  46.854  1
112612  96.621  -78.576  46.827  1
112613  96.622  -78.594  46.800  1
112614  96.654  -78.606  46.773  1
112615  96.684  -78.618  46.746  1
112616  96.715  -78.630  46.718  1
112617  96.746  -78.642  46.690  1
112618  96.783  -78.654  46.662  1
112619  96.824  -78.664  46.634  1
112620  96.863  -78.677  46.607  1
112621  96.892  -78.694  46.580  1
112622  96.922  -78.711  46.551  1
112623  96.949  -78.724  46.522  1
112624  96.976  -78.734  46.494  1
112625  97.003  -78.745  46.467  1
112626  97.030  -78.757  46.442  1
112627  97.072  -78.767  46.416  1
112628  97.122  -78.777  46.391  1
112629  97.172  -78.788  46.367  1
112630  97.222  -78.798  46.344  1
112631  97.246  -78.815  46.323  1
112632  97.281  -78.819  46.302  1
112633  97.321  -78.819  46.283  1
112634  97.361  -78.820  46.264  1
112635  97.401  -78.820  46.246  1
112636  97.442  -78.821  46.230  1
112637  97.482  -78.821  46.214  1
112638  97.522  -78.821  46.199  1
112639  97.563  -78.821  46.185  1
112640  97.603  -78.822  46.171  1
112641  97.643  -78.822  46.157  1
112642  97.689  -78.818  46.143  1
112643  97.720  -78.811  46.128  1
112644  97.718  -78.799  46.112  1
112645  97.721  -78.789  46.097  1
112646  97.738  -78.790  46.083  1
112647  97.772  -78.799  46.068  1
112648  97.798  -78.760  46.054  1
112649  97.824  -78.718  46.040  1
112650  97.843  -78.692  46.027  1
112651  97.850  -78.697  46.012  1
112652  97.871  -78.695  45.997  1
112653  97.892  -78.693  45.980  1
112654  97.917  -78.698  45.962  1
112655  97.944  -78.705  45.945  1
112656  97.970  -78.714  45.928  1
112657  97.997  -78.721  45.912  1
112658  98.018  -78.710  45.895  1
112659  98.031  -78.706  45.878  1
112660  98.042  -78.732  45.862  1
112661  98.034  -78.743  45.846  1
112662  98.044  -78.741  45.831  1
112663  98.006  -78.702  45.815  1
112664  98.014  -78.672  45.799  1
112665  98.026  -78.642  45.784  1
112666  98.041  -78.614  45.768  1
112667  98.043  -78.645  45.752  1
112668  98.044  -78.664  45.737  1
112669  98.044  -78.685  45.722  1
112670  98.044  -78.705  45.706  1
112671  98.044  -78.725  45.691  1
112672  98.063  -78.734  45.675  1
112673  98.088  -78.744  45.661  1
112674  98.109  -78.758  45.646  1
112675  98.134  -78.772  45.633  1
112676  98.158  -78.785  45.618  1
112677  98.176  -78.771  45.603  1
112678  98.200  -78.767  45.589  1
112679  98.204  -78.786  45.575  1
112680  98.209  -78.807  45.561  1
112681  98.215  -78.814  45.547  1
112682  98.221  -78.805  45.536  1
112683  98.227  -78.818  45.523  1
112684  98.250  -78.806  45.510  1
112685  98.273  -78.794  45.498  1
112686  98.296  -78.783  45.484  1
112687  98.319  -78.771  45.469  1
112688  98.341  -78.755  45.454  1
112689  98.362  -78.739  45.439  1
112690  98.391  -78.767  45.423  1
112691  98.419  -78.794  45.409  1
112692  98.431  -78.839  45.396  1
112693  98.440  -78.887  45.382  1
112694  98.431  -78.905  45.370  1
112695  98.455  -78.898  45.358  1
112696  98.480  -78.890  45.347  1
112697  98.504  -78.882  45.335  1
112698  98.430  -78.990  45.323  1
112699  98.462  -79.047  45.311  1
112700  98.486  -79.049  45.297  1
112701  98.509  -79.053  45.285  1
112702  98.531  -79.055  45.272  1
112703  98.555  -79.058  45.259  1
112704  98.577  -79.060  45.246  1
112705  98.600  -79.062  45.234  1
112706  98.626  -79.065  45.221  1
112707  98.671  -79.059  45.207  1
112708  98.716  -79.053  45.193  1
112709  98.762  -79.047  45.179  1
112710  98.807  -79.042  45.163  1
112711  98.842  -79.020  45.148  1
112712  98.860  -78.974  45.134  1
112713  98.888  -78.938  45.121  1
112714  98.945  -78.931  45.110  1
112715  98.986  -78.931  45.101  1
112716  99.012  -78.939  45.094  1
112717  99.038  -78.947  45.086  1
112718  99.063  -78.955  45.076  1
112719  99.089  -78.963  45.066  1
112720  99.115  -78.971  45.057  1
112721  99.132  -78.977  45.047  1
112722  99.146  -78.984  45.036  1
112723  99.160  -78.990  45.025  1
112724  99.174  -78.997  45.013  1
112725  99.188  -79.003  45.002  1
112726  99.202  -79.010  44.990  1
112727  99.220  -79.021  44.978  1
112728  99.243  -79.040  44.965  1
112729  99.266  -79.059  44.955  1
112730  99.289  -79.077  44.945  1
112731  99.308  -79.076  44.934  1
112732  99.334  -79.084  44.926  1
112733  99.352  -79.072  44.919  1
112734  99.370  -79.060  44.914  1
112735  99.394  -79.053  44.909  1
112736  99.440  -79.068  44.906  1
112737  99.487  -79.083  44.904  1
112738  99.546  -79.132  44.904  1
112739  99.589  -79.141  44.904  1
112740  99.626  -79.134  44.903  1
112741  99.617  -79.132  44.901  1
112742  99.566  -79.136  44.897  1
112743  99.572  -79.155  44.893  1
112744  99.578  -79.175  44.888  1
112745  99.584  -79.194  44.883  1
112746  99.589  -79.212  44.877  1
112747  99.602  -79.235  44.871  1
112748  99.625  -79.263  44.864  1
112749  99.648  -79.285  44.856  1
112750  99.674  -79.290  44.848  1
112751  99.700  -79.294  44.841  1
112752  99.726  -79.300  44.833  1
112753  99.760  -79.334  44.826  1
112754  99.794  -79.366  44.818  1
112755  99.828  -79.399  44.811  1
112756  99.862  -79.432  44.805  1
112757  99.897  -79.465  44.798  1
112758  99.930  -79.498  44.790  1
112759  99.965  -79.530  44.783  1
112760  99.998  -79.563  44.774  1
112761  100.033  -79.595  44.767  1
112762  100.070  -79.616  44.759  1
112763  100.108  -79.625  44.751  1
112764  100.142  -79.636  44.741  1
112765  100.176  -79.645  44.732  1
112766  100.207  -79.648  44.724  1
112767  100.244  -79.654  44.715  1
112768  100.269  -79.671  44.709  1
112769  100.320  -79.678  44.702  1
112770  100.349  -79.711  44.692  1
112771  100.378  -79.743  44.679  1
112772  100.406  -79.776  44.666  1
112773  100.417  -79.804  44.653  1
112774  100.409  -79.825  44.639  1
112775  100.467  -79.834  44.625  1
112776  100.524  -79.844  44.610  1
112777  100.566  -79.845  44.596  1
112778  100.604  -79.845  44.583  1
112779  100.641  -79.844  44.570  1
112780  100.678  -79.843  44.557  1
112781  100.716  -79.842  44.543  1
112782  100.753  -79.842  44.530  1
112783  100.786  -79.875  44.516  1
112784  100.820  -79.911  44.502  1
112785  100.852  -79.946  44.490  1
112786  100.886  -79.980  44.478  1
112787  100.919  -80.016  44.464  1
112788  100.952  -80.051  44.451  1
112789  100.985  -80.086  44.438  1
112790  101.018  -80.121  44.424  1
112791  101.051  -80.156  44.410  1
112792  101.085  -80.191  44.396  1
112793  101.117  -80.226  44.382  1
112794  101.146  -80.232  44.368  1
112795  101.178  -80.240  44.354  1
112796  101.224  -80.252  44.339  1
112797  101.270  -80.263  44.325  1
112798  101.318  -80.300  44.312  1
112799  101.378  -80.309  44.296  1
112800  101.410  -80.325  44.281  1
112801  101.443  -80.341  44.266  1
112802  101.474  -80.357  44.250  1
112803  101.506  -80.374  44.233  1
112804  101.539  -80.390  44.216  1
112805  101.571  -80.406  44.198  1
112806  101.603  -80.422  44.181  1
112807  101.635  -80.438  44.165  1
112808  101.667  -80.454  44.148  1
112809  101.699  -80.470  44.130  1
112810  101.731  -80.487  44.112  1
112811  101.763  -80.503  44.094  1
113148  94.454  -77.988  51.835  1
113149  94.468  -77.981  51.813  1
113150  94.475  -77.976  51.790  1
113151  94.476  -77.971  51.767  1
113152  94.477  -77.968  51.743  1
113153  94.478  -77.963  51.718  1
113154  94.498  -77.953  51.694  1
113155  94.519  -77.943  51.669  1
113156  94.540  -77.933  51.644  1
113157  94.558  -77.928  51.618  1
113158  94.573  -77.929  51.591  1
113159  94.600  -77.937  51.564  1
113160  94.638  -77.953  51.537  1
113161  94.661  -77.961  51.508  1
113162  94.672  -77.962  51.480  1
113163  94.684  -77.962  51.452  1
113164  94.695  -77.962  51.424  1
113165  94.706  -77.963  51.395  1
113166  94.715  -77.956  51.365  1
113167  94.723  -77.947  51.334  1
113168  94.729  -77.945  51.305  1
113169  94.729  -77.953  51.276  1
113170  94.728  -77.960  51.245  1
113171  94.729  -77.966  51.215  1
113172  94.741  -77.963  51.183  1
113173  94.753  -77.968  51.150  1
113174  94.765  -77.973  51.118  1
113175  94.785  -77.980  51.085  1
113176  94.810  -77.987  51.051  1
113177  94.834  -77.994  51.018  1
113178  94.859  -78.001  50.985  1
113179  94.884  -78.009  50.951  1
113180  94.905  -78.004  50.917  1
113181  94.923  -77.987  50.881  1
113182  94.942  -77.969  50.846  1
113183  94.960  -77.953  50.812  1
113184  94.978  -77.935  50.777  1
113185  94.996  -77.918  50.743  1
113186  95.007  -77.904  50.709  1
113187  95.016  -77.890  50.674  1
113188  95.025  -77.877  50.639  1
113189  95.034  -77.864  50.605  1
113190  95.042  -77.851  50.572  1
113191  95.051  -77.837  50.538  1
113192  95.060  -77.824  50.505  1
113193  95.069  -77.811  50.473  1
113194  95.078  -77.798  50.442  1
113195  95.089  -77.783  50.409  1
113196  95.095  -77.853  50.379  1
113197  95.195  -77.909  50.349  1
113198  95.178  -77.899  50.319  1
113199  95.159  -77.884  50.288  1
113200  95.178  -77.895  50.258  1
113201  95.214  -77.900  50.228  1
113202  95.251  -77.893  50.199  1
113203  95.288  -77.886  50.172  1
113204  95.325  -77.878  50.147  1
113205  95.362  -77.871  50.122  1
113206  95.382  -77.868  50.098  1
113207  95.396  -77.867  50.073  1
113208  95.409  -77.866  50.048  1
113209  95.422  -77.865  50.022  1
113210  95.431  -77.867  49.995  1
113211  95.438  -77.869  49.967  1
113212  95.444  -77.871  49.939  1
113213  95.451  -77.874  49.908  1
113214  95.457  -77.876  49.877  1
113215  95.463  -77.878  49.844  1
113216  95.470  -77.881  49.810  1
113217  95.476  -77.884  49.773  1
113218  95.498  -77.906  49.736  1
113219  95.521  -77.928  49.701  1
113220  95.536  -77.952  49.667  1
113221  95.528  -77.976  49.635  1
113222  95.546  -77.958  49.602  1
113223  95.549  -77.949  49.570  1
113224  95.560  -77.935  49.536  1
113225  95.580  -77.918  49.502  1
113226  95.599  -77.900  49.468  1
113227  95.618  -77.883  49.432  1
113228  95.637  -77.865  49.397  1
113229  95.614  -77.902  49.362  1
113230  95.616  -77.918  49.325  1
113231  95.631  -77.924  49.288  1
113232  95.647  -77.929  49.252  1
113233  95.663  -77.934  49.217  1
113234  95.678  -77.940  49.181  1
113235  95.697  -77.943  49.145  1
113236  95.719  -77.945  49.109  1
113237  95.741  -77.947  49.073  1
113238  95.763  -77.949  49.036  1
113239  95.785  -77.952  48.999  1
113240  95.807  -77.954  48.962  1
113241  95.829  -77.956  48.923  1
113242  95.851  -77.959  48.884  1
113243  95.870  -77.965  48.844  1
113244  95.878  -77.982  48.803  1
113245  95.887  -78.000  48.761  1
113246  95.896  -78.017  48.720  1
113247  95.893  -78.040  48.679  1
113248  95.895  -78.047  48.639  1
113249  95.902  -78.046  48.602  1
113250  95.908  -78.044  48.565  1
113251  95.919  -78.044  48.528  1
113252  95.932  -78.045  48.491  1
113253  95.945  -78.046  48.455  1
113254  95.959  -78.046  48.419  1
113255  95.975  -78.043  48.384  1
113256  95.991  -78.040  48.351  1
113257  96.007  -78.036  48.318  1
113258  96.023  -78.033  48.286  1
113259  96.039  -78.030  48.255  1
113260  96.055  -78.027  48.225  1
113261  96.072  -78.024  48.197  1
113262  96.088  -78.021  48.168  1
113263  96.104  -78.018  48.142  1
113264  96.120  -78.015  48.115  1
113265  96.133  -78.016  48.088  1
113266  96.148  -78.024  48.060  1
113267  96.163  -78.036  48.031  1
113268  96.178  -78.048  48.003  1
113269  96.193  -78.060  47.975  1
113270  96.209  -78.072  47.950  1
113271  96.224  -78.084  47.924  1
113272  96.239  -78.097  47.898  1
113273  96.254  -78.109  47.873  1
113274  96.268  -78.122  47.847  1
113275  96.282  -78.132  47.821  1
113276  96.298  -78.140  47.795  1
113277  96.313  -78.148  47.769  1
113278  96.328  -78.156  47.745  1
113279  96.343  -78.165  47.720  1
113280  96.354  -78.172  47.696  1
113281  96.361  -78.181  47.672  1
113282  96.380  -78.194  47.647  1
113283  96.399  -78.206  47.622  1
113284  96.419  -78.217  47.598  1
113285  96.439  -78.228  47.572  1
113286  96.455  -78.232  47.547  1
113287  96.471  -78.235  47.521  1
113288  96.480  -78.241  47.497  1
113289  96.485  -78.249  47.473  1
113290  96.490  -78.256  47.448  1
113291  96.496  -78.263  47.426  1
113292  96.501  -78.271  47.402  1
113293  96.505  -78.276  47.378  1
113294  96.505  -78.277  47.353  1
113295  96.504  -78.279  47.328  1
113296  96.504  -78.279  47.303  1
113297  96.503  -78.280  47.276  1
113298  96.509  -78.281  47.250  1
113299  96.525  -78.280  47.224  1
113300  96.534  -78.294  47.197  1
113301  96.541  -78.315  47.171  1
113302  96.550  -78.330  47.143  1
113303  96.559  -78.346  47.113  1
113304  96.569  -78.361  47.084  1
113305  96.578  -78.377  47.055  1
113306  96.587  -78.392  47.029  1
113307  96.597  -78.408  47.003  1
113308  96.615  -78.482  46.976  1
113309  96.620  -78.486  46.948  1
113310  96.625  -78.501  46.919  1
113311  96.631  -78.515  46.892  1
113312  96.634  -78.531  46.865  1
113313  96.631  -78.551  46.838  1
113314  96.639  -78.568  46.810  1
113315  96.670  -78.580  46.783  1
113316  96.700  -78.592  46.756  1
113317  96.731  -78.604  46.728  1
113318  96.762  -78.616  46.700  1
113319  96.793  -78.628  46.672  1
113320  96.828  -78.639  46.645  1
113321  96.868  -78.651  46.618  1
113322  96.897  -78.669  46.591  1
113323  96.925  -78.680  46.562  1
113324  96.952  -78.692  46.534  1
113325  96.979  -78.703  46.506  1
113326  97.006  -78.714  46.478  1
113327  97.033  -78.725  46.453  1
113328  97.075  -78.736  46.427  1
113329  97.124  -78.746  46.401  1
113330  97.174  -78.756  46.377  1
113331  97.205  -78.771  46.354  1
113332  97.214  -78.793  46.332  1
113333  97.246  -78.799  46.312  1
113334  97.286  -78.799  46.293  1
113335  97.326  -78.799  46.275  1
113336  97.366  -78.799  46.257  1
113337  97.406  -78.800  46.240  1
113338  97.447  -78.801  46.225  1
113339  97.487  -78.801  46.211  1
113340  97.527  -78.802  46.196  1
113341  97.568  -78.802  46.182  1
113342  97.619  -78.793  46.168  1
113343  97.679  -78.779  46.153  1
113344  97.727  -78.787  46.139  1
113345  97.748  -78.777  46.124  1
113346  97.758  -78.762  46.109  1
113347  97.773  -78.757  46.094  1
113348  97.790  -78.763  46.081  1
113349  97.817  -78.721  46.068  1
113350  97.837  -78.693  46.054  1
113351  97.841  -78.699  46.040  1
113352  97.853  -78.702  46.026  1
113353  97.874  -78.699  46.010  1
113354  97.896  -78.698  45.992  1
113355  97.917  -78.696  45.975  1
113356  97.942  -78.700  45.958  1
113357  97.969  -78.708  45.941  1
113358  97.996  -78.716  45.924  1
113359  98.018  -78.710  45.907  1
113360  98.031  -78.711  45.890  1
113361  98.041  -78.736  45.875  1
113362  98.016  -78.724  45.860  1
113363  98.040  -78.728  45.844  1
113364  98.022  -78.702  45.828  1
113365  98.030  -78.673  45.812  1
113366  98.044  -78.645  45.795  1
113367  98.058  -78.617  45.779  1
113368  98.063  -78.620  45.764  1
113369  98.064  -78.641  45.748  1
113370  98.064  -78.661  45.733  1
113371  98.064  -78.681  45.717  1
113372  98.065  -78.702  45.702  1
113373  98.068  -78.720  45.688  1
113374  98.090  -78.734  45.673  1
113375  98.114  -78.747  45.658  1
113376  98.140  -78.760  45.644  1
113377  98.161  -78.761  45.629  1
113378  98.171  -78.726  45.614  1
113379  98.199  -78.717  45.600  1
113380  98.213  -78.738  45.585  1
113381  98.218  -78.758  45.570  1
113382  98.223  -78.778  45.556  1
113383  98.228  -78.799  45.542  1
113384  98.246  -78.805  45.528  1
113385  98.270  -78.793  45.516  1
113386  98.295  -78.781  45.504  1
113387  98.319  -78.769  45.490  1
113388  98.342  -78.758  45.475  1
113389  98.365  -78.745  45.461  1
113390  98.387  -78.732  45.445  1
113391  98.408  -78.758  45.429  1
113392  98.417  -78.806  45.414  1
113393  98.429  -78.852  45.400  1
113394  98.441  -78.897  45.386  1
113395  98.460  -78.902  45.374  1
113396  98.495  -78.902  45.363  1
113397  98.519  -78.894  45.351  1
113398  98.544  -78.886  45.339  1
113399  98.551  -78.905  45.326  1
113400  98.453  -79.021  45.313  1
113401  98.465  -79.072  45.300  1
113402  98.488  -79.075  45.287  1
113403  98.511  -79.078  45.273  1
113404  98.534  -79.081  45.261  1
113405  98.563  -79.081  45.247  1
113406  98.608  -79.075  45.234  1
113407  98.654  -79.069  45.222  1
113408  98.699  -79.064  45.208  1
113409  98.744  -79.058  45.195  1
113410  98.790  -79.053  45.182  1
113411  98.835  -79.046  45.168  1
113412  98.855  -79.003  45.153  1
113413  98.873  -78.957  45.139  1
113414  98.894  -78.913  45.126  1
113415  98.950  -78.906  45.117  1
113416  98.990  -78.907  45.110  1
113417  99.016  -78.915  45.104  1
113418  99.042  -78.923  45.095  1
113419  99.067  -78.930  45.086  1
113420  99.093  -78.939  45.077  1
113421  99.112  -78.949  45.069  1
113422  99.130  -78.955  45.059  1
113423  99.144  -78.962  45.048  1
113424  99.158  -78.968  45.036  1
113425  99.172  -78.975  45.023  1
113426  99.187  -78.981  45.009  1
113427  99.201  -78.988  44.996  1
113428  99.220  -79.002  44.983  1
113429  99.243  -79.020  44.970  1
113430  99.267  -79.038  44.958  1
113431  99.290  -79.056  44.948  1
113432  99.312  -79.075  44.937  1
113433  99.331  -79.073  44.929  1
113434  99.349  -79.061  44.923  1
113435  99.367  -79.049  44.918  1
113436  99.385  -79.037  44.914  1
113437  99.430  -79.050  44.913  1
113438  99.483  -79.084  44.912  1
113439  99.543  -79.137  44.911  1
113440  99.581  -79.132  44.910  1
113441  99.618  -79.125  44.907  1
113442  99.653  -79.118  44.902  1
113443  99.596  -79.121  44.897  1
113444  99.592  -79.137  44.892  1
113445  99.598  -79.156  44.886  1
113446  99.604  -79.175  44.878  1
113447  99.610  -79.195  44.872  1
113448  99.616  -79.214  44.865  1
113449  99.624  -79.234  44.858  1
113450  99.646  -79.261  44.849  1
113451  99.671  -79.273  44.841  1
113452  99.697  -79.278  44.833  1
113453  99.728  -79.300  44.825  1
113454  99.762  -79.332  44.819  1
113455  99.796  -79.365  44.812  1
113456  99.830  -79.397  44.805  1
113457  99.864  -79.430  44.798  1
113458  99.898  -79.463  44.792  1
113459  99.932  -79.496  44.785  1
113460  99.966  -79.529  44.778  1
113461  100.000  -79.561  44.770  1
113462  100.034  -79.595  44.762  1
113463  100.071  -79.609  44.753  1
113464  100.100  -79.614  44.745  1
113465  100.140  -79.610  44.736  1
113466  100.180  -79.614  44.727  1
113467  100.205  -79.630  44.718  1
113468  100.230  -79.647  44.710  1
113469  100.255  -79.664  44.703  1
113470  100.307  -79.666  44.696  1
113471  100.359  -79.683  44.687  1
113472  100.388  -79.716  44.676  1
113473  100.416  -79.748  44.665  1
113474  100.408  -79.773  44.653  1
113475  100.403  -79.793  44.640  1
113476  100.461  -79.802  44.627  1
113477  100.519  -79.812  44.613  1
113478  100.573  -79.820  44.599  1
113479  100.611  -79.819  44.586  1
113480  100.648  -79.818  44.572  1
113481  100.686  -79.817  44.559  1
113482  100.723  -79.817  44.545  1
113483  100.760  -79.817  44.532  1
113484  100.793  -79.852  44.518  1
113485  100.826  -79.887  44.505  1
113486  100.859  -79.922  44.493  1
113487  100.893  -79.958  44.481  1
113488  100.926  -79.993  44.467  1
113489  100.959  -80.027  44.455  1
113490  100.992  -80.063  44.442  1
113491  101.025  -80.098  44.428  1
113492  101.058  -80.133  44.414  1
113493  101.094  -80.164  44.401  1
113494  101.135  -80.187  44.387  1
113495  101.169  -80.193  44.373  1
113496  101.198  -80.200  44.360  1
113497  101.237  -80.210  44.345  1
113498  101.283  -80.222  44.331  1
113499  101.332  -80.266  44.318  1
113500  101.396  -80.271  44.302  1
113501  101.427  -80.287  44.287  1
113502  101.460  -80.303  44.272  1
113503  101.492  -80.319  44.257  1
113504  101.524  -80.335  44.240  1
113505  101.556  -80.351  44.223  1
113506  101.588  -80.368  44.206  1
113507  101.620  -80.384  44.189  1
113508  101.652  -80.400  44.171  1
113509  101.684  -80.416  44.154  1
113510  101.716  -80.432  44.136  1
113511  101.749  -80.448  44.119  1
113512  101.780  -80.464  44.101  1
113848  94.449  -77.975  51.859  1
113849  94.463  -77.969  51.837  1
113850  94.477  -77.962  51.815  1
113851  94.488  -77.956  51.793  1
113852  94.489  -77.952  51.770  1
113853  94.490  -77.948  51.746  1
113854  94.491  -77.943  51.722  1
113855  94.501  -77.937  51.697  1
113856  94.522  -77.927  51.673  1
113857  94.542  -77.916  51.649  1
113858  94.561  -77.909  51.623  1
113859  94.577  -77.910  51.596  1
113860  94.596  -77.912  51.569  1
113861  94.633  -77.929  51.542  1
113862  94.659  -77.938  51.514  1
113863  94.671  -77.938  51.486  1
113864  94.682  -77.939  51.458  1
113865  94.694  -77.940  51.430  1
113866  94.705  -77.940  51.401  1
113867  94.715  -77.937  51.371  1
113868  94.724  -77.929  51.341  1
113869  94.729  -77.925  51.311  1
113870  94.729  -77.933  51.281  1
113871  94.729  -77.940  51.250  1
113872  94.729  -77.947  51.220  1
113873  94.738  -77.946  51.189  1
113874  94.751  -77.951  51.156  1
113875  94.763  -77.956  51.123  1
113876  94.788  -77.963  51.090  1
113877  94.813  -77.971  51.056  1
113878  94.837  -77.978  51.024  1
113879  94.861  -77.985  50.990  1
113880  94.886  -77.992  50.955  1
113881  94.907  -77.985  50.920  1
113882  94.925  -77.968  50.884  1
113883  94.944  -77.951  50.850  1
113884  94.962  -77.934  50.816  1
113885  94.980  -77.917  50.781  1
113886  94.992  -77.902  50.746  1
113887  95.001  -77.889  50.712  1
113888  95.010  -77.876  50.677  1
113889  95.019  -77.862  50.641  1
113890  95.028  -77.849  50.607  1
113891  95.036  -77.836  50.574  1
113892  95.045  -77.823  50.541  1
113893  95.054  -77.809  50.508  1
113894  95.063  -77.796  50.475  1
113895  95.075  -77.789  50.443  1
113896  95.089  -77.782  50.411  1
113897  95.109  -77.795  50.380  1
113898  95.100  -77.852  50.349  1
113899  95.109  -77.865  50.317  1
113900  95.130  -77.880  50.285  1
113901  95.164  -77.898  50.255  1
113902  95.201  -77.893  50.225  1
113903  95.238  -77.886  50.196  1
113904  95.275  -77.878  50.169  1
113905  95.312  -77.871  50.142  1
113906  95.349  -77.863  50.115  1
113907  95.382  -77.857  50.090  1
113908  95.395  -77.856  50.066  1
113909  95.408  -77.855  50.041  1
113910  95.421  -77.855  50.015  1
113911  95.435  -77.854  49.988  1
113912  95.446  -77.854  49.962  1
113913  95.453  -77.856  49.936  1
113914  95.459  -77.859  49.909  1
113915  95.466  -77.861  49.879  1
113916  95.472  -77.863  49.847  1
113917  95.478  -77.865  49.812  1
113918  95.485  -77.868  49.775  1
113919  95.507  -77.890  49.738  1
113920  95.528  -77.912  49.702  1
113921  95.526  -77.942  49.668  1
113922  95.515  -77.970  49.634  1
113923  95.545  -77.943  49.602  1
113924  95.548  -77.934  49.570  1
113925  95.551  -77.926  49.536  1
113926  95.558  -77.915  49.503  1
113927  95.577  -77.897  49.469  1
113928  95.596  -77.880  49.434  1
113929  95.615  -77.862  49.399  1
113930  95.606  -77.881  49.364  1
113931  95.607  -77.899  49.328  1
113932  95.622  -77.904  49.292  1
113933  95.638  -77.909  49.258  1
113934  95.654  -77.915  49.225  1
113935  95.691  -77.907  49.190  1
113936  95.702  -77.924  49.156  1
113937  95.724  -77.926  49.120  1
113938  95.746  -77.928  49.083  1
113939  95.768  -77.931  49.047  1
113940  95.790  -77.933  49.011  1
113941  95.812  -77.935  48.974  1
113942  95.834  -77.938  48.936  1
113943  95.856  -77.940  48.898  1
113944  95.867  -77.956  48.858  1
113945  95.876  -77.972  48.817  1
113946  95.885  -77.990  48.775  1
113947  95.894  -78.007  48.733  1
113948  95.891  -78.031  48.691  1
113949  95.895  -78.034  48.650  1
113950  95.902  -78.031  48.612  1
113951  95.910  -78.031  48.575  1
113952  95.923  -78.031  48.538  1
113953  95.936  -78.033  48.501  1
113954  95.948  -78.034  48.465  1
113955  95.961  -78.034  48.430  1
113956  95.977  -78.031  48.396  1
113957  95.993  -78.028  48.364  1
113958  96.010  -78.025  48.332  1
113959  96.026  -78.022  48.299  1
113960  96.042  -78.019  48.268  1
113961  96.058  -78.015  48.239  1
113962  96.074  -78.012  48.211  1
113963  96.090  -78.009  48.184  1
113964  96.106  -78.006  48.158  1
113965  96.119  -78.009  48.131  1
113966  96.131  -78.014  48.104  1
113967  96.145  -78.021  48.076  1
113968  96.160  -78.028  48.048  1
113969  96.175  -78.040  48.020  1
113970  96.190  -78.053  47.993  1
113971  96.205  -78.065  47.967  1
113972  96.221  -78.077  47.942  1
113973  96.236  -78.089  47.917  1
113974  96.251  -78.101  47.892  1
113975  96.268  -78.108  47.867  1
113976  96.290  -78.115  47.841  1
113977  96.311  -78.123  47.814  1
113978  96.327  -78.131  47.789  1
113979  96.342  -78.140  47.763  1
113980  96.357  -78.148  47.738  1
113981  96.357  -78.155  47.712  1
113982  96.370  -78.166  47.688  1
113983  96.389  -78.178  47.662  1
113984  96.408  -78.190  47.636  1
113985  96.428  -78.202  47.613  1
113986  96.447  -78.213  47.588  1
113987  96.464  -78.217  47.563  1
113988  96.476  -78.222  47.536  1
113989  96.481  -78.229  47.511  1
113990  96.486  -78.237  47.486  1
113991  96.491  -78.244  47.461  1
113992  96.494  -78.250  47.438  1
113993  96.496  -78.255  47.415  1
113994  96.498  -78.261  47.392  1
113995  96.497  -78.261  47.367  1
113996  96.495  -78.261  47.343  1
113997  96.493  -78.261  47.318  1
113998  96.491  -78.261  47.291  1
113999  96.503  -78.260  47.266  1
114000  96.519  -78.260  47.239  1
114001  96.530  -78.266  47.212  1
114002  96.539  -78.282  47.185  1
114003  96.548  -78.297  47.154  1
114004  96.557  -78.313  47.124  1
114005  96.567  -78.329  47.094  1
114006  96.576  -78.344  47.066  1
114007  96.585  -78.360  47.040  1
114008  96.594  -78.375  47.014  1
114009  96.615  -78.458  46.987  1
114010  96.621  -78.467  46.959  1
114011  96.626  -78.481  46.931  1
114012  96.631  -78.496  46.903  1
114013  96.637  -78.510  46.876  1
114014  96.641  -78.526  46.848  1
114015  96.655  -78.542  46.821  1
114016  96.686  -78.554  46.793  1
114017  96.717  -78.566  46.766  1
114018  96.748  -78.578  46.738  1
114019  96.779  -78.589  46.711  1
114020  96.809  -78.601  46.684  1
114021  96.840  -78.614  46.657  1
114022  96.873  -78.626  46.629  1
114023  96.900  -78.638  46.602  1
114024  96.928  -78.649  46.574  1
114025  96.954  -78.660  46.546  1
114026  96.981  -78.671  46.518  1
114027  97.009  -78.683  46.490  1
114028  97.036  -78.694  46.464  1
114029  97.077  -78.705  46.438  1
114030  97.126  -78.714  46.413  1
114031  97.163  -78.728  46.388  1
114032  97.173  -78.749  46.364  1
114033  97.182  -78.770  46.342  1
114034  97.210  -78.778  46.322  1
114035  97.250  -78.779  46.304  1
114036  97.291  -78.779  46.286  1
114037  97.331  -78.780  46.268  1
114038  97.371  -78.780  46.251  1
114039  97.412  -78.780  46.236  1
114040  97.452  -78.780  46.221  1
114041  97.492  -78.781  46.205  1
114042  97.549  -78.768  46.192  1
114043  97.609  -78.754  46.178  1
114044  97.669  -78.739  46.164  1
114045  97.716  -78.749  46.150  1
114046  97.763  -78.761  46.135  1
114047  97.775  -78.742  46.121  1
114048  97.788  -78.741  46.108  1
114049  97.809  -78.724  46.095  1
114050  97.830  -78.694  46.082  1
114051  97.835  -78.700  46.069  1
114052  97.839  -78.706  46.056  1
114053  97.857  -78.705  46.040  1
114054  97.878  -78.704  46.024  1
114055  97.899  -78.702  46.006  1
114056  97.921  -78.700  45.989  1
114057  97.942  -78.698  45.972  1
114058  97.967  -78.703  45.954  1
114059  97.994  -78.711  45.937  1
114060  98.018  -78.710  45.920  1
114061  98.030  -78.715  45.903  1
114062  97.991  -78.709  45.887  1
114063  98.012  -78.711  45.872  1
114064  98.035  -78.715  45.856  1
114065  98.035  -78.702  45.840  1
114066  98.042  -78.673  45.824  1
114067  98.056  -78.645  45.807  1
114068  98.087  -78.608  45.791  1
114069  98.130  -78.636  45.775  1
114070  98.153  -78.667  45.760  1
114071  98.153  -78.686  45.745  1
114072  98.133  -78.686  45.729  1
114073  98.112  -78.687  45.713  1
114074  98.131  -78.695  45.698  1
114075  98.153  -78.703  45.684  1
114076  98.173  -78.713  45.670  1
114077  98.164  -78.717  45.655  1
114078  98.157  -78.715  45.639  1
114079  98.167  -78.680  45.625  1
114080  98.193  -78.669  45.610  1
114081  98.222  -78.689  45.594  1
114082  98.226  -78.709  45.579  1
114083  98.233  -78.730  45.564  1
114084  98.245  -78.752  45.548  1
114085  98.256  -78.773  45.534  1
114086  98.275  -78.777  45.521  1
114087  98.299  -78.765  45.509  1
114088  98.323  -78.754  45.495  1
114089  98.348  -78.742  45.481  1
114090  98.372  -78.730  45.467  1
114091  98.397  -78.719  45.451  1
114092  98.421  -78.759  45.436  1
114093  98.433  -78.805  45.420  1
114094  98.445  -78.849  45.404  1
114095  98.454  -78.874  45.390  1
114096  98.460  -78.868  45.379  1
114097  98.484  -78.867  45.368  1
114098  98.528  -78.875  45.354  1
114099  98.573  -78.883  45.341  1
114100  98.608  -78.883  45.328  1
114101  98.575  -78.937  45.314  1
114102  98.478  -79.053  45.302  1
114103  98.467  -79.098  45.289  1
114104  98.500  -79.097  45.276  1
114105  98.545  -79.091  45.263  1
114106  98.591  -79.086  45.249  1
114107  98.636  -79.080  45.235  1
114108  98.681  -79.075  45.221  1
114109  98.727  -79.068  45.208  1
114110  98.772  -79.063  45.196  1
114111  98.817  -79.057  45.183  1
114112  98.851  -79.034  45.171  1
114113  98.869  -78.987  45.157  1
114114  98.887  -78.940  45.143  1
114115  98.905  -78.894  45.129  1
114116  98.955  -78.881  45.122  1
114117  98.994  -78.883  45.114  1
114118  99.020  -78.890  45.107  1
114119  99.046  -78.899  45.099  1
114120  99.071  -78.906  45.090  1
114121  99.092  -78.916  45.081  1
114122  99.107  -78.928  45.073  1
114123  99.125  -78.934  45.063  1
114124  99.143  -78.940  45.053  1
114125  99.157  -78.946  45.043  1
114126  99.171  -78.952  45.031  1
114127  99.186  -78.959  45.018  1
114128  99.200  -78.966  45.004  1
114129  99.221  -78.982  44.991  1
114130  99.244  -79.000  44.978  1
114131  99.267  -79.018  44.965  1
114132  99.290  -79.037  44.952  1
114133  99.319  -79.051  44.941  1
114134  99.341  -79.057  44.933  1
114135  99.353  -79.048  44.927  1
114136  99.366  -79.038  44.923  1
114137  99.383  -79.027  44.921  1
114138  99.420  -79.035  44.921  1
114139  99.481  -79.088  44.920  1
114140  99.537  -79.131  44.917  1
114141  99.573  -79.123  44.913  1
114142  99.610  -79.116  44.907  1
114143  99.647  -79.109  44.901  1
114144  99.634  -79.107  44.894  1
114145  99.613  -79.119  44.889  1
114146  99.619  -79.138  44.882  1
114147  99.624  -79.157  44.873  1
114148  99.630  -79.177  44.865  1
114149  99.636  -79.196  44.858  1
114150  99.642  -79.215  44.850  1
114151  99.648  -79.234  44.842  1
114152  99.668  -79.257  44.834  1
114153  99.696  -79.266  44.826  1
114154  99.730  -79.298  44.819  1
114155  99.764  -79.331  44.812  1
114156  99.798  -79.363  44.805  1
114157  99.832  -79.396  44.798  1
114158  99.866  -79.429  44.791  1
114159  99.900  -79.462  44.784  1
114160  99.936  -79.496  44.778  1
114161  99.976  -79.532  44.771  1
114162  100.008  -79.560  44.764  1
114163  100.023  -79.574  44.755  1
114164  100.072  -79.573  44.747  1
114165  100.115  -79.573  44.739  1
114166  100.140  -79.589  44.731  1
114167  100.165  -79.606  44.722  1
114168  100.191  -79.623  44.713  1
114169  100.216  -79.639  44.704  1
114170  100.241  -79.656  44.697  1
114171  100.266  -79.673  44.689  1
114172  100.368  -79.657  44.682  1
114173  100.397  -79.689  44.673  1
114174  100.416  -79.719  44.662  1
114175  100.398  -79.742  44.651  1
114176  100.397  -79.761  44.641  1
114177  100.455  -79.770  44.628  1
114178  100.512  -79.780  44.615  1
114179  100.570  -79.789  44.602  1
114180  100.618  -79.794  44.588  1
114181  100.655  -79.793  44.575  1
114182  100.693  -79.792  44.561  1
114183  100.730  -79.792  44.547  1
114184  100.767  -79.794  44.533  1
114185  100.800  -79.829  44.520  1
114186  100.833  -79.864  44.508  1
114187  100.866  -79.899  44.496  1
114188  100.900  -79.934  44.484  1
114189  100.932  -79.969  44.471  1
114190  100.966  -80.005  44.458  1
114191  100.999  -80.040  44.446  1
114192  101.032  -80.074  44.433  1
114193  101.070  -80.101  44.420  1
114194  101.111  -80.124  44.406  1
114195  101.151  -80.148  44.393  1
114196  101.192  -80.171  44.379  1
114197  101.220  -80.162  44.366  1
114198  101.250  -80.169  44.352  1
114199  101.296  -80.181  44.337  1
114200  101.346  -80.233  44.324  1
114201  101.413  -80.232  44.309  1
114202  101.445  -80.249  44.294  1
114203  101.477  -80.265  44.279  1
114204  101.509  -80.281  44.263  1
114205  101.541  -80.297  44.246  1
114206  101.573  -80.313  44.229  1
114207  101.605  -80.329  44.213  1
114208  101.637  -80.345  44.196  1
114209  101.670  -80.362  44.178  1
114210  101.701  -80.378  44.160  1
114211  101.734  -80.394  44.142  1
114212  101.766  -80.410  44.125  1
114213  101.798  -80.426  44.107  1
114548  94.444  -77.963  51.885  1
114549  94.458  -77.956  51.863  1
114550  94.472  -77.949  51.841  1
114551  94.486  -77.943  51.820  1
114552  94.500  -77.937  51.798  1
114553  94.501  -77.932  51.775  1
114554  94.502  -77.928  51.752  1
114555  94.503  -77.924  51.727  1
114556  94.505  -77.919  51.703  1
114557  94.524  -77.910  51.678  1
114558  94.545  -77.899  51.655  1
114559  94.565  -77.890  51.630  1
114560  94.580  -77.891  51.603  1
114561  94.596  -77.891  51.575  1
114562  94.629  -77.904  51.548  1
114563  94.657  -77.915  51.521  1
114564  94.669  -77.915  51.493  1
114565  94.681  -77.916  51.466  1
114566  94.692  -77.917  51.437  1
114567  94.704  -77.918  51.408  1
114568  94.715  -77.918  51.378  1
114569  94.724  -77.910  51.349  1
114570  94.730  -77.906  51.318  1
114571  94.730  -77.913  51.288  1
114572  94.730  -77.921  51.256  1
114573  94.729  -77.928  51.226  1
114574  94.736  -77.929  51.194  1
114575  94.748  -77.934  51.162  1
114576  94.766  -77.940  51.129  1
114577  94.790  -77.946  51.095  1
114578  94.815  -77.954  51.061  1
114579  94.840  -77.961  51.028  1
114580  94.864  -77.968  50.994  1
114581  94.889  -77.975  50.959  1
114582  94.909  -77.967  50.924  1
114583  94.928  -77.949  50.889  1
114584  94.946  -77.933  50.854  1
114585  94.964  -77.915  50.820  1
114586  94.977  -77.900  50.784  1
114587  94.986  -77.887  50.749  1
114588  94.994  -77.874  50.715  1
114589  95.003  -77.861  50.680  1
114590  95.013  -77.847  50.645  1
114591  95.021  -77.834  50.611  1
114592  95.030  -77.821  50.577  1
114593  95.040  -77.810  50.543  1
114594  95.053  -77.803  50.510  1
114595  95.066  -77.796  50.478  1
114596  95.078  -77.789  50.446  1
114597  95.093  -77.783  50.415  1
114598  95.119  -77.783  50.383  1
114599  95.136  -77.801  50.351  1
114600  95.140  -77.827  50.318  1
114601  95.120  -77.840  50.286  1
114602  95.153  -77.891  50.255  1
114603  95.187  -77.886  50.225  1
114604  95.225  -77.878  50.196  1
114605  95.262  -77.871  50.168  1
114606  95.299  -77.863  50.142  1
114607  95.336  -77.855  50.115  1
114608  95.373  -77.848  50.090  1
114609  95.394  -77.845  50.065  1
114610  95.408  -77.844  50.041  1
114611  95.421  -77.843  50.015  1
114612  95.434  -77.843  49.991  1
114613  95.448  -77.842  49.966  1
114614  95.461  -77.841  49.941  1
114615  95.468  -77.843  49.915  1
114616  95.474  -77.846  49.885  1
114617  95.481  -77.848  49.852  1
114618  95.487  -77.850  49.817  1
114619  95.493  -77.852  49.781  1
114620  95.515  -77.873  49.743  1
114621  95.534  -77.896  49.705  1
114622  95.516  -77.932  49.670  1
114623  95.501  -77.964  49.635  1
114624  95.545  -77.928  49.602  1
114625  95.548  -77.920  49.569  1
114626  95.551  -77.911  49.534  1
114627  95.554  -77.902  49.501  1
114628  95.557  -77.894  49.468  1
114629  95.574  -77.877  49.434  1
114630  95.593  -77.859  49.401  1
114631  95.598  -77.861  49.367  1
114632  95.598  -77.880  49.333  1
114633  95.613  -77.884  49.298  1
114634  95.629  -77.890  49.263  1
114635  95.670  -77.881  49.228  1
114636  95.716  -77.868  49.196  1
114637  95.725  -77.887  49.164  1
114638  95.730  -77.907  49.131  1
114639  95.752  -77.909  49.097  1
114640  95.773  -77.912  49.062  1
114641  95.796  -77.915  49.025  1
114642  95.818  -77.917  48.987  1
114643  95.839  -77.919  48.949  1
114644  95.856  -77.928  48.912  1
114645  95.865  -77.945  48.873  1
114646  95.874  -77.962  48.832  1
114647  95.883  -77.980  48.790  1
114648  95.891  -77.997  48.748  1
114649  95.888  -78.021  48.706  1
114650  95.895  -78.019  48.664  1
114651  95.902  -78.018  48.625  1
114652  95.913  -78.018  48.586  1
114653  95.926  -78.019  48.548  1
114654  95.939  -78.020  48.512  1
114655  95.952  -78.022  48.477  1
114656  95.964  -78.022  48.442  1
114657  95.979  -78.020  48.407  1
114658  95.995  -78.017  48.376  1
114659  96.012  -78.014  48.344  1
114660  96.028  -78.011  48.313  1
114661  96.044  -78.008  48.282  1
114662  96.060  -78.005  48.253  1
114663  96.077  -78.002  48.226  1
114664  96.093  -77.999  48.199  1
114665  96.105  -78.002  48.172  1
114666  96.117  -78.006  48.146  1
114667  96.128  -78.012  48.119  1
114668  96.143  -78.018  48.092  1
114669  96.157  -78.026  48.066  1
114670  96.172  -78.034  48.039  1
114671  96.187  -78.045  48.011  1
114672  96.202  -78.057  47.986  1
114673  96.218  -78.069  47.961  1
114674  96.233  -78.081  47.937  1
114675  96.250  -78.086  47.913  1
114676  96.268  -78.090  47.888  1
114677  96.291  -78.098  47.861  1
114678  96.312  -78.106  47.833  1
114679  96.334  -78.115  47.808  1
114680  96.356  -78.123  47.782  1
114681  96.364  -78.131  47.756  1
114682  96.360  -78.138  47.731  1
114683  96.379  -78.150  47.705  1
114684  96.398  -78.162  47.679  1
114685  96.417  -78.174  47.653  1
114686  96.437  -78.186  47.629  1
114687  96.456  -78.197  47.604  1
114688  96.471  -78.203  47.577  1
114689  96.476  -78.210  47.551  1
114690  96.480  -78.216  47.526  1
114691  96.482  -78.222  47.500  1
114692  96.484  -78.228  47.474  1
114693  96.487  -78.233  47.450  1
114694  96.489  -78.238  47.426  1
114695  96.491  -78.244  47.401  1
114696  96.491  -78.246  47.375  1
114697  96.489  -78.246  47.351  1
114698  96.487  -78.246  47.326  1
114699  96.487  -78.246  47.301  1
114700  96.503  -78.246  47.277  1
114701  96.521  -78.250  47.250  1
114702  96.535  -78.257  47.222  1
114703  96.540  -78.261  47.193  1
114704  96.546  -78.266  47.163  1
114705  96.555  -78.280  47.133  1
114706  96.565  -78.296  47.104  1
114707  96.574  -78.311  47.077  1
114708  96.583  -78.326  47.051  1
114709  96.592  -78.342  47.025  1
114710  96.614  -78.434  46.998  1
114711  96.622  -78.449  46.971  1
114712  96.627  -78.462  46.943  1
114713  96.632  -78.476  46.914  1
114714  96.638  -78.491  46.887  1
114715  96.640  -78.504  46.860  1
114716  96.664  -78.517  46.832  1
114717  96.695  -78.529  46.804  1
114718  96.725  -78.541  46.777  1
114719  96.755  -78.553  46.750  1
114720  96.786  -78.565  46.723  1
114721  96.816  -78.576  46.697  1
114722  96.847  -78.589  46.671  1
114723  96.876  -78.600  46.644  1
114724  96.903  -78.609  46.616  1
114725  96.930  -78.617  46.587  1
114726  96.957  -78.629  46.560  1
114727  96.984  -78.639  46.533  1
114728  97.012  -78.651  46.504  1
114729  97.039  -78.662  46.477  1
114730  97.079  -78.673  46.451  1
114731  97.121  -78.685  46.425  1
114732  97.132  -78.705  46.400  1
114733  97.141  -78.726  46.376  1
114734  97.151  -78.747  46.354  1
114735  97.175  -78.758  46.334  1
114736  97.215  -78.758  46.316  1
114737  97.255  -78.758  46.297  1
114738  97.296  -78.759  46.278  1
114739  97.336  -78.759  46.262  1
114740  97.376  -78.760  46.247  1
114741  97.420  -78.758  46.232  1
114742  97.479  -78.743  46.217  1
114743  97.539  -78.729  46.204  1
114744  97.599  -78.714  46.191  1
114745  97.658  -78.700  46.177  1
114746  97.705  -78.711  46.164  1
114747  97.752  -78.723  46.150  1
114748  97.790  -78.727  46.136  1
114749  97.803  -78.725  46.123  1
114750  97.824  -78.695  46.110  1
114751  97.828  -78.701  46.097  1
114752  97.832  -78.707  46.083  1
114753  97.839  -78.712  46.070  1
114754  97.860  -78.710  46.054  1
114755  97.882  -78.708  46.037  1
114756  97.903  -78.706  46.019  1
114757  97.924  -78.705  46.003  1
114758  97.946  -78.703  45.986  1
114759  97.967  -78.701  45.969  1
114760  97.992  -78.706  45.951  1
114761  98.017  -78.709  45.934  1
114762  98.030  -78.719  45.917  1
114763  97.984  -78.695  45.900  1
114764  98.007  -78.699  45.885  1
114765  98.031  -78.702  45.869  1
114766  98.048  -78.702  45.852  1
114767  98.054  -78.672  45.836  1
114768  98.093  -78.632  45.820  1
114769  98.144  -78.609  45.803  1
114770  98.184  -78.649  45.787  1
114771  98.187  -78.659  45.772  1
114772  98.176  -78.656  45.757  1
114773  98.160  -78.654  45.742  1
114774  98.169  -78.661  45.724  1
114775  98.177  -78.672  45.709  1
114776  98.186  -78.683  45.694  1
114777  98.181  -78.677  45.680  1
114778  98.173  -78.668  45.664  1
114779  98.164  -78.659  45.649  1
114780  98.168  -78.630  45.634  1
114781  98.187  -78.620  45.619  1
114782  98.230  -78.640  45.602  1
114783  98.238  -78.661  45.587  1
114784  98.249  -78.683  45.572  1
114785  98.261  -78.705  45.556  1
114786  98.273  -78.726  45.542  1
114787  98.284  -78.748  45.527  1
114788  98.303  -78.749  45.513  1
114789  98.328  -78.738  45.500  1
114790  98.352  -78.726  45.486  1
114791  98.377  -78.714  45.471  1
114792  98.402  -78.723  45.455  1
114793  98.427  -78.761  45.440  1
114794  98.449  -78.802  45.425  1
114795  98.461  -78.847  45.408  1
114796  98.467  -78.844  45.395  1
114797  98.473  -78.837  45.383  1
114798  98.478  -78.830  45.371  1
114799  98.507  -78.832  45.358  1
114800  98.552  -78.839  45.344  1
114801  98.596  -78.847  45.330  1
114802  98.592  -78.904  45.317  1
114803  98.492  -79.022  45.304  1
114804  98.487  -79.076  45.290  1
114805  98.530  -79.086  45.276  1
114806  98.574  -79.093  45.263  1
114807  98.619  -79.090  45.249  1
114808  98.664  -79.084  45.235  1
114809  98.709  -79.079  45.221  1
114810  98.755  -79.073  45.208  1
114811  98.800  -79.068  45.196  1
114812  98.846  -79.062  45.184  1
114813  98.864  -79.017  45.172  1
114814  98.882  -78.971  45.159  1
114815  98.900  -78.924  45.145  1
114816  98.918  -78.877  45.132  1
114817  98.960  -78.856  45.125  1
114818  98.998  -78.858  45.116  1
114819  99.024  -78.866  45.108  1
114820  99.050  -78.874  45.100  1
114821  99.072  -78.883  45.091  1
114822  99.086  -78.896  45.083  1
114823  99.101  -78.907  45.075  1
114824  99.120  -78.913  45.065  1
114825  99.139  -78.918  45.056  1
114826  99.156  -78.924  45.046  1
114827  99.170  -78.930  45.037  1
114828  99.184  -78.937  45.025  1
114829  99.199  -78.943  45.013  1
114830  99.221  -78.962  45.001  1
114831  99.244  -78.981  44.988  1
114832  99.268  -78.998  44.973  1
114833  99.296  -79.012  44.958  1
114834  99.324  -79.028  44.945  1
114835  99.352  -79.041  44.938  1
114836  99.364  -79.031  44.933  1
114837  99.376  -79.022  44.929  1
114838  99.389  -79.012  44.929  1
114839  99.418  -79.038  44.927  1
114840  99.478  -79.092  44.922  1
114841  99.529  -79.122  44.916  1
114842  99.566  -79.114  44.910  1
114843  99.603  -79.107  44.904  1
114844  99.639  -79.100  44.897  1
114845  99.671  -79.093  44.889  1
114846  99.633  -79.101  44.882  1
114847  99.639  -79.120  44.874  1
114848  99.645  -79.139  44.866  1
114849  99.650  -79.159  44.857  1
114850  99.656  -79.178  44.850  1
114851  99.662  -79.197  44.842  1
114852  99.668  -79.216  44.834  1
114853  99.674  -79.235  44.826  1
114854  99.703  -79.268  44.819  1
114855  99.744  -79.304  44.812  1
114856  99.784  -79.341  44.805  1
114857  99.825  -79.378  44.798  1
114858  99.865  -79.415  44.791  1
114859  99.906  -79.452  44.784  1
114860  99.932  -79.474  44.778  1
114861  99.950  -79.494  44.771  1
114862  99.969  -79.514  44.765  1
114863  99.987  -79.534  44.757  1
114864  100.034  -79.551  44.749  1
114865  100.087  -79.545  44.742  1
114866  100.104  -79.564  44.734  1
114867  100.126  -79.582  44.725  1
114868  100.151  -79.598  44.717  1
114869  100.177  -79.615  44.708  1
114870  100.202  -79.632  44.698  1
114871  100.227  -79.648  44.690  1
114872  100.253  -79.665  44.683  1
114873  100.379  -79.629  44.677  1
114874  100.407  -79.662  44.668  1
114875  100.406  -79.688  44.659  1
114876  100.388  -79.711  44.649  1
114877  100.392  -79.730  44.640  1
114878  100.449  -79.739  44.628  1
114879  100.507  -79.748  44.615  1
114880  100.564  -79.758  44.603  1
114881  100.622  -79.767  44.590  1
114882  100.662  -79.767  44.577  1
114883  100.700  -79.767  44.564  1
114884  100.737  -79.766  44.551  1
114885  100.774  -79.770  44.537  1
114886  100.807  -79.805  44.524  1
114887  100.840  -79.841  44.512  1
114888  100.873  -79.876  44.500  1
114889  100.906  -79.911  44.488  1
114890  100.939  -79.946  44.476  1
114891  100.973  -79.981  44.463  1
114892  101.006  -80.015  44.451  1
114893  101.047  -80.038  44.438  1
114894  101.088  -80.062  44.425  1
114895  101.128  -80.086  44.412  1
114896  101.169  -80.109  44.399  1
114897  101.209  -80.133  44.386  1
114898  101.250  -80.156  44.373  1
114899  101.271  -80.130  44.359  1
114900  101.310  -80.140  44.345  1
114901  101.359  -80.199  44.331  1
114902  101.430  -80.194  44.316  1
114903  101.462  -80.210  44.301  1
114904  101.494  -80.226  44.286  1
114905  101.526  -80.243  44.271  1
114906  101.558  -80.259  44.253  1
114907  101.591  -80.275  44.236  1
114908  101.623  -80.291  44.219  1
114909  101.655  -80.307  44.202  1
114910  101.687  -80.323  44.184  1
114911  101.719  -80.340  44.166  1
114912  101.751  -80.356  44.148  1
114913  101.783  -80.372  44.130  1
114914  101.815  -80.388  44.112  1
115248  94.439  -77.950  51.913  1
115249  94.453  -77.944  51.891  1
115250  94.467  -77.937  51.869  1
115251  94.481  -77.931  51.848  1
115252  94.495  -77.924  51.825  1
115253  94.509  -77.918  51.803  1
115254  94.514  -77.912  51.781  1
115255  94.516  -77.909  51.758  1
115256  94.517  -77.904  51.735  1
115257  94.518  -77.899  51.711  1
115258  94.527  -77.893  51.686  1
115259  94.547  -77.883  51.662  1
115260  94.568  -77.873  51.637  1
115261  94.584  -77.872  51.611  1
115262  94.600  -77.872  51.585  1
115263  94.624  -77.880  51.556  1
115264  94.656  -77.892  51.529  1
115265  94.668  -77.893  51.501  1
115266  94.679  -77.893  51.474  1
115267  94.691  -77.894  51.446  1
115268  94.702  -77.894  51.416  1
115269  94.714  -77.895  51.386  1
115270  94.724  -77.892  51.356  1
115271  94.730  -77.887  51.326  1
115272  94.730  -77.893  51.295  1
115273  94.730  -77.901  51.264  1
115274  94.730  -77.909  51.232  1
115275  94.734  -77.912  51.201  1
115276  94.746  -77.916  51.168  1
115277  94.769  -77.923  51.135  1
115278  94.793  -77.931  51.101  1
115279  94.818  -77.937  51.067  1
115280  94.842  -77.945  51.033  1
115281  94.867  -77.952  50.999  1
115282  94.892  -77.959  50.964  1
115283  94.912  -77.949  50.929  1
115284  94.930  -77.931  50.894  1
115285  94.948  -77.914  50.859  1
115286  94.962  -77.899  50.824  1
115287  94.971  -77.886  50.789  1
115288  94.980  -77.872  50.754  1
115289  94.988  -77.859  50.719  1
115290  94.997  -77.846  50.684  1
115291  95.006  -77.833  50.649  1
115292  95.018  -77.824  50.615  1
115293  95.031  -77.817  50.580  1
115294  95.043  -77.810  50.546  1
115295  95.056  -77.802  50.513  1
115296  95.068  -77.796  50.481  1
115297  95.081  -77.789  50.448  1
115298  95.097  -77.783  50.417  1
115299  95.123  -77.783  50.385  1
115300  95.150  -77.784  50.352  1
115301  95.154  -77.801  50.319  1
115302  95.158  -77.843  50.287  1
115303  95.163  -77.868  50.256  1
115304  95.182  -77.874  50.225  1
115305  95.211  -77.871  50.197  1
115306  95.249  -77.863  50.169  1
115307  95.285  -77.855  50.142  1
115308  95.323  -77.848  50.116  1
115309  95.360  -77.841  50.091  1
115310  95.394  -77.834  50.068  1
115311  95.407  -77.834  50.045  1
115312  95.420  -77.833  50.021  1
115313  95.433  -77.832  49.998  1
115314  95.447  -77.831  49.974  1
115315  95.460  -77.830  49.949  1
115316  95.473  -77.830  49.922  1
115317  95.483  -77.830  49.892  1
115318  95.489  -77.833  49.859  1
115319  95.496  -77.835  49.823  1
115320  95.502  -77.837  49.786  1
115321  95.522  -77.857  49.748  1
115322  95.524  -77.886  49.710  1
115323  95.506  -77.922  49.674  1
115324  95.488  -77.958  49.639  1
115325  95.537  -77.919  49.604  1
115326  95.548  -77.906  49.569  1
115327  95.551  -77.896  49.534  1
115328  95.554  -77.888  49.500  1
115329  95.557  -77.879  49.467  1
115330  95.560  -77.871  49.434  1
115331  95.571  -77.857  49.402  1
115332  95.590  -77.840  49.370  1
115333  95.589  -77.860  49.336  1
115334  95.604  -77.865  49.302  1
115335  95.649  -77.853  49.267  1
115336  95.694  -77.842  49.234  1
115337  95.725  -77.843  49.202  1
115338  95.754  -77.845  49.170  1
115339  95.740  -77.884  49.138  1
115340  95.757  -77.891  49.105  1
115341  95.779  -77.893  49.072  1
115342  95.801  -77.896  49.037  1
115343  95.823  -77.898  49.000  1
115344  95.844  -77.901  48.962  1
115345  95.853  -77.918  48.924  1
115346  95.863  -77.935  48.885  1
115347  95.871  -77.953  48.845  1
115348  95.880  -77.970  48.802  1
115349  95.889  -77.987  48.760  1
115350  95.888  -78.007  48.718  1
115351  95.895  -78.006  48.678  1
115352  95.904  -78.005  48.638  1
115353  95.917  -78.006  48.599  1
115354  95.930  -78.007  48.561  1
115355  95.942  -78.008  48.524  1
115356  95.955  -78.009  48.489  1
115357  95.968  -78.010  48.455  1
115358  95.982  -78.009  48.421  1
115359  95.998  -78.006  48.389  1
115360  96.014  -78.003  48.358  1
115361  96.030  -78.000  48.327  1
115362  96.046  -77.996  48.297  1
115363  96.062  -77.993  48.268  1
115364  96.079  -77.990  48.241  1
115365  96.091  -77.994  48.214  1
115366  96.102  -77.999  48.189  1
115367  96.114  -78.004  48.163  1
115368  96.125  -78.009  48.136  1
115369  96.140  -78.016  48.110  1
115370  96.155  -78.024  48.083  1
115371  96.169  -78.031  48.056  1
115372  96.184  -78.039  48.031  1
115373  96.199  -78.050  48.007  1
115374  96.215  -78.062  47.983  1
115375  96.232  -78.065  47.959  1
115376  96.250  -78.068  47.936  1
115377  96.269  -78.072  47.910  1
115378  96.291  -78.081  47.883  1
115379  96.313  -78.089  47.856  1
115380  96.335  -78.097  47.830  1
115381  96.353  -78.106  47.804  1
115382  96.359  -78.112  47.779  1
115383  96.368  -78.122  47.752  1
115384  96.387  -78.134  47.724  1
115385  96.406  -78.147  47.697  1
115386  96.425  -78.159  47.670  1
115387  96.444  -78.171  47.645  1
115388  96.463  -78.183  47.619  1
115389  96.469  -78.188  47.592  1
115390  96.471  -78.194  47.565  1
115391  96.473  -78.200  47.539  1
115392  96.475  -78.205  47.513  1
115393  96.477  -78.210  47.487  1
115394  96.479  -78.216  47.462  1
115395  96.481  -78.222  47.437  1
115396  96.484  -78.227  47.411  1
115397  96.485  -78.232  47.384  1
115398  96.483  -78.232  47.360  1
115399  96.481  -78.232  47.335  1
115400  96.487  -78.232  47.309  1
115401  96.504  -78.232  47.284  1
115402  96.523  -78.241  47.258  1
115403  96.540  -78.247  47.231  1
115404  96.546  -78.252  47.202  1
115405  96.552  -78.257  47.173  1
115406  96.557  -78.262  47.144  1
115407  96.564  -78.266  47.116  1
115408  96.572  -78.279  47.089  1
115409  96.581  -78.294  47.063  1
115410  96.590  -78.310  47.036  1
115411  96.614  -78.410  47.010  1
115412  96.624  -78.442  46.983  1
115413  96.628  -78.442  46.955  1
115414  96.633  -78.457  46.927  1
115415  96.629  -78.469  46.900  1
115416  96.630  -78.483  46.872  1
115417  96.663  -78.495  46.845  1
115418  96.698  -78.504  46.817  1
115419  96.729  -78.516  46.789  1
115420  96.759  -78.528  46.762  1
115421  96.789  -78.540  46.735  1
115422  96.819  -78.552  46.710  1
115423  96.850  -78.564  46.684  1
115424  96.879  -78.575  46.657  1
115425  96.906  -78.584  46.630  1
115426  96.933  -78.592  46.602  1
115427  96.960  -78.601  46.574  1
115428  96.987  -78.610  46.547  1
115429  97.015  -78.619  46.519  1
115430  97.041  -78.630  46.491  1
115431  97.080  -78.642  46.464  1
115432  97.090  -78.662  46.438  1
115433  97.100  -78.683  46.413  1
115434  97.110  -78.703  46.389  1
115435  97.119  -78.724  46.367  1
115436  97.140  -78.738  46.347  1
115437  97.180  -78.738  46.328  1
115438  97.220  -78.739  46.309  1
115439  97.260  -78.739  46.291  1
115440  97.301  -78.739  46.274  1
115441  97.351  -78.733  46.258  1
115442  97.410  -78.718  46.243  1
115443  97.469  -78.703  46.230  1
115444  97.529  -78.689  46.217  1
115445  97.589  -78.674  46.205  1
115446  97.647  -78.662  46.192  1
115447  97.694  -78.673  46.179  1
115448  97.741  -78.685  46.166  1
115449  97.788  -78.696  46.152  1
115450  97.818  -78.696  46.139  1
115451  97.822  -78.702  46.125  1
115452  97.826  -78.708  46.111  1
115453  97.830  -78.714  46.097  1
115454  97.843  -78.716  46.084  1
115455  97.864  -78.714  46.067  1
115456  97.885  -78.712  46.049  1
115457  97.907  -78.711  46.033  1
115458  97.928  -78.709  46.016  1
115459  97.949  -78.707  46.000  1
115460  97.970  -78.705  45.983  1
115461  97.992  -78.704  45.966  1
115462  98.017  -78.708  45.949  1
115463  97.955  -78.679  45.932  1
115464  97.979  -78.683  45.914  1
115465  98.003  -78.686  45.899  1
115466  98.027  -78.690  45.883  1
115467  98.051  -78.694  45.867  1
115468  98.098  -78.655  45.850  1
115469  98.154  -78.608  45.833  1
115470  98.199  -78.623  45.816  1
115471  98.196  -78.629  45.799  1
115472  98.192  -78.633  45.784  1
115473  98.182  -78.631  45.769  1
115474  98.179  -78.633  45.754  1
115475  98.189  -78.644  45.736  1
115476  98.198  -78.655  45.720  1
115477  98.196  -78.653  45.704  1
115478  98.187  -78.644  45.689  1
115479  98.179  -78.635  45.674  1
115480  98.171  -78.626  45.658  1
115481  98.163  -78.617  45.643  1
115482  98.158  -78.610  45.628  1
115483  98.245  -78.625  45.612  1
115484  98.257  -78.626  45.596  1
115485  98.266  -78.636  45.581  1
115486  98.278  -78.657  45.565  1
115487  98.289  -78.679  45.550  1
115488  98.301  -78.701  45.535  1
115489  98.312  -78.722  45.519  1
115490  98.333  -78.722  45.505  1
115491  98.357  -78.710  45.490  1
115492  98.381  -78.698  45.475  1
115493  98.407  -78.726  45.459  1
115494  98.432  -78.764  45.444  1
115495  98.457  -78.804  45.429  1
115496  98.475  -78.821  45.413  1
115497  98.480  -78.814  45.399  1
115498  98.485  -78.807  45.386  1
115499  98.491  -78.800  45.374  1
115500  98.496  -78.793  45.361  1
115501  98.539  -78.799  45.347  1
115502  98.606  -78.810  45.333  1
115503  98.536  -78.909  45.320  1
115504  98.497  -78.987  45.306  1
115505  98.529  -79.015  45.291  1
115506  98.565  -79.038  45.277  1
115507  98.608  -79.045  45.264  1
115508  98.652  -79.052  45.249  1
115509  98.696  -79.059  45.235  1
115510  98.739  -79.066  45.220  1
115511  98.783  -79.073  45.208  1
115512  98.828  -79.072  45.196  1
115513  98.860  -79.047  45.184  1
115514  98.878  -79.000  45.173  1
115515  98.896  -78.954  45.160  1
115516  98.914  -78.908  45.147  1
115517  98.932  -78.861  45.134  1
115518  98.966  -78.831  45.125  1
115519  99.002  -78.834  45.115  1
115520  99.028  -78.843  45.106  1
115521  99.051  -78.851  45.098  1
115522  99.066  -78.862  45.090  1
115523  99.081  -78.874  45.082  1
115524  99.096  -78.886  45.074  1
115525  99.115  -78.892  45.065  1
115526  99.134  -78.897  45.057  1
115527  99.153  -78.902  45.048  1
115528  99.169  -78.908  45.038  1
115529  99.183  -78.915  45.028  1
115530  99.199  -78.924  45.016  1
115531  99.222  -78.942  45.004  1
115532  99.246  -78.960  44.992  1
115533  99.274  -78.974  44.977  1
115534  99.302  -78.989  44.963  1
115535  99.330  -79.003  44.950  1
115536  99.358  -79.018  44.942  1
115537  99.375  -79.015  44.937  1
115538  99.387  -79.006  44.933  1
115539  99.400  -78.996  44.930  1
115540  99.423  -79.018  44.925  1
115541  99.478  -79.089  44.919  1
115542  99.521  -79.112  44.913  1
115543  99.558  -79.105  44.906  1
115544  99.595  -79.098  44.899  1
115545  99.632  -79.091  44.892  1
115546  99.668  -79.084  44.884  1
115547  99.653  -79.083  44.875  1
115548  99.659  -79.102  44.866  1
115549  99.665  -79.121  44.858  1
115550  99.671  -79.140  44.850  1
115551  99.677  -79.159  44.842  1
115552  99.683  -79.178  44.835  1
115553  99.707  -79.206  44.827  1
115554  99.744  -79.240  44.819  1
115555  99.771  -79.284  44.812  1
115556  99.794  -79.334  44.804  1
115557  99.835  -79.371  44.797  1
115558  99.858  -79.394  44.791  1
115559  99.876  -79.414  44.784  1
115560  99.895  -79.434  44.778  1
115561  99.913  -79.454  44.771  1
115562  99.932  -79.474  44.765  1
115563  99.950  -79.494  44.759  1
115564  99.994  -79.511  44.751  1
115565  100.048  -79.528  44.744  1
115566  100.102  -79.529  44.737  1
115567  100.119  -79.548  44.729  1
115568  100.135  -79.567  44.720  1
115569  100.152  -79.586  44.712  1
115570  100.169  -79.605  44.703  1
115571  100.188  -79.624  44.695  1
115572  100.213  -79.641  44.687  1
115573  100.239  -79.657  44.680  1
115574  100.343  -79.631  44.673  1
115575  100.415  -79.635  44.665  1
115576  100.397  -79.657  44.656  1
115577  100.379  -79.679  44.646  1
115578  100.385  -79.697  44.638  1
115579  100.443  -79.707  44.627  1
115580  100.501  -79.717  44.615  1
115581  100.559  -79.726  44.604  1
115582  100.616  -79.736  44.592  1
115583  100.670  -79.742  44.580  1
115584  100.707  -79.742  44.568  1
115585  100.744  -79.741  44.555  1
115586  100.781  -79.747  44.542  1
115587  100.814  -79.783  44.529  1
115588  100.847  -79.817  44.517  1
115589  100.880  -79.852  44.505  1
115590  100.913  -79.887  44.493  1
115591  100.947  -79.923  44.481  1
115592  100.983  -79.952  44.468  1
115593  101.024  -79.976  44.457  1
115594  101.064  -79.999  44.444  1
115595  101.105  -80.023  44.431  1
115596  101.145  -80.046  44.419  1
115597  101.186  -80.070  44.407  1
115598  101.226  -80.093  44.395  1
115599  101.266  -80.117  44.382  1
115600  101.306  -80.138  44.368  1
115601  101.323  -80.098  44.353  1
115602  101.373  -80.165  44.339  1
115603  101.447  -80.156  44.324  1
115604  101.479  -80.172  44.309  1
115605  101.512  -80.188  44.293  1
115606  101.544  -80.204  44.277  1
115607  101.575  -80.221  44.260  1
115608  101.608  -80.237  44.242  1
115609  101.640  -80.253  44.225  1
115610  101.672  -80.269  44.208  1
115611  101.704  -80.285  44.189  1
115612  101.736  -80.301  44.171  1
115613  101.768  -80.317  44.154  1
115614  101.800  -80.334  44.135  1
115948  94.433  -77.938  51.942  1
115949  94.448  -77.931  51.920  1
115950  94.462  -77.925  51.898  1
115951  94.476  -77.918  51.876  1
115952  94.490  -77.912  51.855  1
115953  94.504  -77.905  51.833  1
115954  94.519  -77.899  51.812  1
115955  94.527  -77.893  51.790  1
115956  94.528  -77.889  51.767  1
115957  94.529  -77.884  51.743  1
115958  94.530  -77.881  51.719  1
115959  94.531  -77.876  51.695  1
115960  94.550  -77.866  51.671  1
115961  94.570  -77.856  51.647  1
115962  94.588  -77.853  51.621  1
115963  94.603  -77.853  51.595  1
115964  94.620  -77.855  51.567  1
115965  94.654  -77.869  51.539  1
115966  94.666  -77.870  51.512  1
115967  94.678  -77.871  51.484  1
115968  94.689  -77.871  51.456  1
115969  94.701  -77.871  51.427  1
115970  94.712  -77.872  51.397  1
115971  94.724  -77.873  51.367  1
115972  94.731  -77.867  51.336  1
115973  94.731  -77.874  51.305  1
115974  94.731  -77.881  51.274  1
115975  94.731  -77.889  51.242  1
115976  94.731  -77.895  51.210  1
115977  94.747  -77.899  51.175  1
115978  94.771  -77.906  51.142  1
115979  94.796  -77.914  51.108  1
115980  94.821  -77.921  51.074  1
115981  94.845  -77.928  51.040  1
115982  94.870  -77.936  51.006  1
115983  94.895  -77.943  50.971  1
115984  94.914  -77.931  50.935  1
115985  94.932  -77.913  50.899  1
115986  94.947  -77.897  50.863  1
115987  94.956  -77.884  50.828  1
115988  94.965  -77.871  50.794  1
115989  94.973  -77.858  50.759  1
115990  94.982  -77.845  50.724  1
115991  94.995  -77.837  50.688  1
115992  95.008  -77.830  50.653  1
115993  95.021  -77.824  50.617  1
115994  95.033  -77.817  50.583  1
115995  95.046  -77.809  50.548  1
115996  95.059  -77.802  50.516  1
115997  95.071  -77.796  50.483  1
115998  95.084  -77.788  50.449  1
115999  95.101  -77.783  50.416  1
116000  95.127  -77.784  50.384  1
116001  95.138  -77.799  50.352  1
116002  95.158  -77.800  50.320  1
116003  95.169  -77.815  50.289  1
116004  95.174  -77.840  50.257  1
116005  95.188  -77.854  50.227  1
116006  95.210  -77.855  50.198  1
116007  95.235  -77.855  50.170  1
116008  95.272  -77.848  50.144  1
116009  95.310  -77.841  50.118  1
116010  95.346  -77.834  50.094  1
116011  95.384  -77.826  50.073  1
116012  95.406  -77.822  50.052  1
116013  95.420  -77.821  50.031  1
116014  95.433  -77.821  50.007  1
116015  95.446  -77.820  49.983  1
116016  95.460  -77.819  49.958  1
116017  95.473  -77.818  49.931  1
116018  95.486  -77.818  49.899  1
116019  95.498  -77.818  49.865  1
116020  95.505  -77.820  49.828  1
116021  95.511  -77.822  49.791  1
116022  95.530  -77.841  49.754  1
116023  95.514  -77.876  49.716  1
116024  95.496  -77.912  49.680  1
116025  95.478  -77.948  49.644  1
116026  95.524  -77.913  49.608  1
116027  95.548  -77.890  49.572  1
116028  95.550  -77.882  49.536  1
116029  95.553  -77.873  49.502  1
116030  95.556  -77.865  49.467  1
116031  95.559  -77.856  49.435  1
116032  95.562  -77.847  49.404  1
116033  95.568  -77.837  49.373  1
116034  95.581  -77.840  49.340  1
116035  95.620  -77.833  49.306  1
116036  95.651  -77.834  49.272  1
116037  95.681  -77.835  49.239  1
116038  95.711  -77.836  49.208  1
116039  95.742  -77.837  49.175  1
116040  95.769  -77.841  49.143  1
116041  95.762  -77.872  49.112  1
116042  95.784  -77.874  49.081  1
116043  95.806  -77.877  49.048  1
116044  95.828  -77.879  49.013  1
116045  95.842  -77.891  48.974  1
116046  95.851  -77.908  48.936  1
116047  95.860  -77.925  48.898  1
116048  95.869  -77.943  48.858  1
116049  95.878  -77.960  48.815  1
116050  95.887  -77.978  48.773  1
116051  95.888  -77.993  48.732  1
116052  95.895  -77.991  48.691  1
116053  95.907  -77.993  48.652  1
116054  95.920  -77.993  48.613  1
116055  95.933  -77.994  48.575  1
116056  95.946  -77.996  48.537  1
116057  95.958  -77.996  48.502  1
116058  95.971  -77.998  48.468  1
116059  95.984  -77.998  48.435  1
116060  96.001  -77.995  48.403  1
116061  96.017  -77.992  48.372  1
116062  96.033  -77.989  48.343  1
116063  96.049  -77.986  48.314  1
116064  96.065  -77.982  48.284  1
116065  96.077  -77.987  48.257  1
116066  96.088  -77.992  48.232  1
116067  96.100  -77.996  48.207  1
116068  96.111  -78.001  48.181  1
116069  96.123  -78.006  48.154  1
116070  96.137  -78.014  48.128  1
116071  96.152  -78.022  48.101  1
116072  96.167  -78.029  48.075  1
116073  96.182  -78.037  48.051  1
116074  96.197  -78.041  48.028  1
116075  96.215  -78.044  48.004  1
116076  96.232  -78.047  47.981  1
116077  96.250  -78.050  47.957  1
116078  96.270  -78.056  47.930  1
116079  96.292  -78.064  47.904  1
116080  96.314  -78.072  47.877  1
116081  96.331  -78.080  47.851  1
116082  96.337  -78.087  47.825  1
116083  96.350  -78.099  47.800  1
116084  96.367  -78.113  47.772  1
116085  96.376  -78.133  47.742  1
116086  96.395  -78.145  47.714  1
116087  96.414  -78.157  47.687  1
116088  96.433  -78.169  47.661  1
116089  96.452  -78.181  47.634  1
116090  96.462  -78.187  47.607  1
116091  96.464  -78.184  47.580  1
116092  96.466  -78.183  47.553  1
116093  96.468  -78.188  47.526  1
116094  96.470  -78.194  47.499  1
116095  96.472  -78.200  47.474  1
116096  96.474  -78.205  47.449  1
116097  96.476  -78.210  47.422  1
116098  96.479  -78.216  47.395  1
116099  96.477  -78.216  47.369  1
116100  96.476  -78.216  47.343  1
116101  96.487  -78.216  47.317  1
116102  96.506  -78.222  47.291  1
116103  96.524  -78.231  47.266  1
116104  96.543  -78.238  47.240  1
116105  96.551  -78.244  47.212  1
116106  96.557  -78.248  47.184  1
116107  96.563  -78.253  47.156  1
116108  96.569  -78.257  47.128  1
116109  96.575  -78.262  47.101  1
116110  96.581  -78.266  47.075  1
116111  96.588  -78.276  47.049  1
116112  96.613  -78.386  47.022  1
116113  96.627  -78.434  46.995  1
116114  96.623  -78.421  46.968  1
116115  96.618  -78.433  46.941  1
116116  96.619  -78.448  46.913  1
116117  96.625  -78.461  46.886  1
116118  96.662  -78.474  46.859  1
116119  96.697  -78.483  46.830  1
116120  96.732  -78.492  46.802  1
116121  96.762  -78.504  46.775  1
116122  96.793  -78.516  46.748  1
116123  96.823  -78.528  46.722  1
116124  96.853  -78.540  46.696  1
116125  96.881  -78.550  46.670  1
116126  96.908  -78.559  46.642  1
116127  96.936  -78.567  46.616  1
116128  96.963  -78.576  46.588  1
116129  96.990  -78.585  46.561  1
116130  97.017  -78.594  46.533  1
116131  97.044  -78.605  46.505  1
116132  97.052  -78.620  46.479  1
116133  97.058  -78.639  46.453  1
116134  97.068  -78.660  46.427  1
116135  97.078  -78.680  46.404  1
116136  97.088  -78.702  46.382  1
116137  97.104  -78.717  46.360  1
116138  97.145  -78.717  46.341  1
116139  97.185  -78.718  46.323  1
116140  97.225  -78.718  46.306  1
116141  97.281  -78.708  46.290  1
116142  97.340  -78.692  46.273  1
116143  97.400  -78.678  46.258  1
116144  97.459  -78.664  46.245  1
116145  97.519  -78.649  46.233  1
116146  97.579  -78.635  46.220  1
116147  97.636  -78.624  46.206  1
116148  97.683  -78.636  46.193  1
116149  97.730  -78.647  46.180  1
116150  97.779  -78.661  46.167  1
116151  97.816  -78.699  46.155  1
116152  97.820  -78.709  46.141  1
116153  97.824  -78.714  46.128  1
116154  97.828  -78.720  46.113  1
116155  97.846  -78.720  46.097  1
116156  97.867  -78.718  46.080  1
116157  97.889  -78.717  46.064  1
116158  97.910  -78.715  46.048  1
116159  97.931  -78.713  46.031  1
116160  97.953  -78.711  46.015  1
116161  97.974  -78.710  45.999  1
116162  97.996  -78.708  45.981  1
116163  98.018  -78.702  45.964  1
116164  97.957  -78.662  45.947  1
116165  97.985  -78.664  45.929  1
116166  98.013  -78.665  45.913  1
116167  98.040  -78.667  45.897  1
116168  98.068  -78.668  45.880  1
116169  98.144  -78.627  45.863  1
116170  98.208  -78.593  45.845  1
116171  98.205  -78.598  45.828  1
116172  98.201  -78.603  45.812  1
116173  98.197  -78.608  45.795  1
116174  98.188  -78.607  45.780  1
116175  98.200  -78.616  45.764  1
116176  98.209  -78.626  45.747  1
116177  98.210  -78.629  45.730  1
116178  98.202  -78.620  45.714  1
116179  98.194  -78.611  45.699  1
116180  98.185  -78.601  45.684  1
116181  98.189  -78.601  45.668  1
116182  98.197  -78.605  45.653  1
116183  98.204  -78.608  45.637  1
116184  98.271  -78.623  45.621  1
116185  98.283  -78.623  45.606  1
116186  98.291  -78.630  45.590  1
116187  98.300  -78.637  45.575  1
116188  98.308  -78.644  45.559  1
116189  98.317  -78.654  45.543  1
116190  98.329  -78.675  45.527  1
116191  98.341  -78.697  45.511  1
116192  98.361  -78.694  45.496  1
116193  98.386  -78.690  45.481  1
116194  98.412  -78.730  45.464  1
116195  98.437  -78.760  45.449  1
116196  98.462  -78.777  45.433  1
116197  98.490  -78.802  45.417  1
116198  98.506  -78.811  45.403  1
116199  98.511  -78.803  45.389  1
116200  98.516  -78.795  45.377  1
116201  98.518  -78.781  45.365  1
116202  98.550  -78.761  45.350  1
116203  98.580  -78.796  45.336  1
116204  98.506  -78.896  45.320  1
116205  98.538  -78.925  45.305  1
116206  98.571  -78.954  45.291  1
116207  98.603  -78.983  45.278  1
116208  98.643  -78.998  45.265  1
116209  98.687  -79.005  45.251  1
116210  98.730  -79.012  45.236  1
116211  98.774  -79.018  45.221  1
116212  98.818  -79.025  45.208  1
116213  98.861  -79.031  45.196  1
116214  98.883  -79.022  45.185  1
116215  98.891  -78.984  45.174  1
116216  98.909  -78.937  45.161  1
116217  98.927  -78.891  45.148  1
116218  98.945  -78.844  45.135  1
116219  98.972  -78.806  45.123  1
116220  99.006  -78.810  45.114  1
116221  99.031  -78.818  45.106  1
116222  99.046  -78.830  45.097  1
116223  99.061  -78.842  45.090  1
116224  99.076  -78.854  45.081  1
116225  99.090  -78.865  45.073  1
116226  99.110  -78.871  45.065  1
116227  99.129  -78.876  45.056  1
116228  99.147  -78.881  45.046  1
116229  99.166  -78.886  45.037  1
116230  99.182  -78.893  45.027  1
116231  99.200  -78.904  45.016  1
116232  99.224  -78.921  45.005  1
116233  99.252  -78.936  44.994  1
116234  99.280  -78.950  44.980  1
116235  99.308  -78.965  44.966  1
116236  99.336  -78.980  44.953  1
116237  99.364  -78.994  44.944  1
116238  99.385  -78.999  44.938  1
116239  99.398  -78.990  44.934  1
116240  99.394  -78.958  44.928  1
116241  99.428  -78.997  44.922  1
116242  99.491  -79.048  44.915  1
116243  99.518  -79.071  44.907  1
116244  99.553  -79.081  44.900  1
116245  99.587  -79.089  44.893  1
116246  99.624  -79.082  44.886  1
116247  99.660  -79.075  44.878  1
116248  99.688  -79.068  44.868  1
116249  99.680  -79.084  44.859  1
116250  99.686  -79.103  44.851  1
116251  99.691  -79.122  44.843  1
116252  99.712  -79.148  44.836  1
116253  99.749  -79.181  44.828  1
116254  99.785  -79.215  44.820  1
116255  99.821  -79.248  44.812  1
116256  99.845  -79.284  44.805  1
116257  99.835  -79.302  44.797  1
116258  99.822  -79.353  44.790  1
116259  99.840  -79.374  44.784  1
116260  99.858  -79.394  44.778  1
116261  99.876  -79.413  44.772  1
116262  99.895  -79.434  44.766  1
116263  99.913  -79.454  44.759  1
116264  99.954  -79.471  44.752  1
116265  100.008  -79.488  44.746  1
116266  100.062  -79.504  44.739  1
116267  100.116  -79.513  44.732  1
116268  100.133  -79.532  44.725  1
116269  100.150  -79.551  44.717  1
116270  100.167  -79.570  44.708  1
116271  100.184  -79.589  44.700  1
116272  100.200  -79.608  44.691  1
116273  100.217  -79.628  44.684  1
116274  100.234  -79.647  44.676  1
116275  100.260  -79.659  44.669  1
116276  100.405  -79.603  44.662  1
116277  100.388  -79.626  44.653  1
116278  100.369  -79.648  44.644  1
116279  100.380  -79.665  44.635  1
116280  100.437  -79.675  44.625  1
116281  100.495  -79.685  44.615  1
116282  100.553  -79.694  44.605  1
116283  100.611  -79.704  44.594  1
116284  100.668  -79.713  44.583  1
116285  100.714  -79.717  44.571  1
116286  100.751  -79.716  44.558  1
116287  100.787  -79.724  44.547  1
116288  100.821  -79.759  44.535  1
116289  100.854  -79.794  44.522  1
116290  100.887  -79.829  44.511  1
116291  100.920  -79.864  44.499  1
116292  100.960  -79.889  44.488  1
116293  101.000  -79.913  44.475  1
116294  101.041  -79.936  44.464  1
116295  101.081  -79.960  44.452  1
116296  101.121  -79.983  44.441  1
116297  101.162  -80.008  44.429  1
116298  101.202  -80.031  44.417  1
116299  101.243  -80.055  44.405  1
116300  101.283  -80.078  44.392  1
116301  101.324  -80.102  44.378  1
116302  101.356  -80.106  44.364  1
116303  101.387  -80.131  44.348  1
116304  101.465  -80.118  44.333  1
116305  101.496  -80.134  44.317  1
116306  101.529  -80.150  44.300  1
116307  101.561  -80.166  44.284  1
116308  101.593  -80.182  44.266  1
116309  101.625  -80.198  44.248  1
116310  101.657  -80.215  44.230  1
116311  101.689  -80.231  44.213  1
116312  101.722  -80.247  44.195  1
116313  101.753  -80.263  44.176  1
116314  101.785  -80.279  44.159  1
116315  101.818  -80.295  44.140  1
116648  94.429  -77.926  51.973  1
116649  94.443  -77.919  51.951  1
116650  94.457  -77.912  51.928  1
116651  94.471  -77.906  51.906  1
116652  94.485  -77.899  51.884  1
116653  94.499  -77.893  51.862  1
116654  94.514  -77.886  51.842  1
116655  94.528  -77.880  51.821  1
116656  94.540  -77.874  51.799  1
116657  94.541  -77.869  51.776  1
116658  94.542  -77.865  51.752  1
116659  94.543  -77.861  51.729  1
116660  94.544  -77.856  51.706  1
116661  94.552  -77.849  51.682  1
116662  94.573  -77.840  51.658  1
116663  94.592  -77.834  51.633  1
116664  94.607  -77.834  51.606  1
116665  94.622  -77.835  51.579  1
116666  94.653  -77.846  51.551  1
116667  94.665  -77.847  51.524  1
116668  94.676  -77.848  51.496  1
116669  94.688  -77.848  51.467  1
116670  94.699  -77.849  51.439  1
116671  94.711  -77.849  51.410  1
116672  94.722  -77.850  51.379  1
116673  94.732  -77.847  51.348  1
116674  94.731  -77.855  51.317  1
116675  94.731  -77.862  51.285  1
116676  94.731  -77.869  51.253  1
116677  94.731  -77.877  51.220  1
116678  94.749  -77.883  51.185  1
116679  94.774  -77.890  51.151  1
116680  94.799  -77.897  51.117  1
116681  94.823  -77.905  51.082  1
116682  94.848  -77.912  51.047  1
116683  94.873  -77.919  51.013  1
116684  94.897  -77.926  50.978  1
116685  94.916  -77.912  50.941  1
116686  94.932  -77.896  50.905  1
116687  94.941  -77.883  50.869  1
116688  94.950  -77.869  50.833  1
116689  94.960  -77.859  50.798  1
116690  94.973  -77.852  50.764  1
116691  94.985  -77.844  50.728  1
116692  94.998  -77.837  50.692  1
116693  95.011  -77.830  50.656  1
116694  95.023  -77.823  50.622  1
116695  95.036  -77.816  50.587  1
116696  95.049  -77.809  50.551  1
116697  95.061  -77.802  50.519  1
116698  95.074  -77.795  50.485  1
116699  95.087  -77.788  50.451  1
116700  95.102  -77.786  50.418  1
116701  95.122  -77.787  50.386  1
116702  95.141  -77.787  50.354  1
116703  95.161  -77.788  50.322  1
116704  95.180  -77.789  50.291  1
116705  95.185  -77.814  50.260  1
116706  95.194  -77.834  50.230  1
116707  95.216  -77.836  50.201  1
116708  95.240  -77.837  50.173  1
116709  95.262  -77.839  50.146  1
116710  95.296  -77.834  50.121  1
116711  95.333  -77.826  50.096  1
116712  95.371  -77.818  50.074  1
116713  95.406  -77.812  50.054  1
116714  95.419  -77.811  50.033  1
116715  95.432  -77.810  50.010  1
116716  95.446  -77.809  49.986  1
116717  95.459  -77.808  49.961  1
116718  95.472  -77.808  49.935  1
116719  95.485  -77.807  49.903  1
116720  95.498  -77.806  49.869  1
116721  95.512  -77.805  49.834  1
116722  95.520  -77.807  49.797  1
116723  95.522  -77.830  49.761  1
116724  95.504  -77.866  49.725  1
116725  95.486  -77.902  49.688  1
116726  95.468  -77.938  49.650  1
116727  95.511  -77.907  49.614  1
116728  95.547  -77.876  49.579  1
116729  95.550  -77.868  49.543  1
116730  95.553  -77.859  49.508  1
116731  95.556  -77.850  49.473  1
116732  95.559  -77.841  49.439  1
116733  95.562  -77.833  49.407  1
116734  95.571  -77.825  49.376  1
116735  95.591  -77.824  49.345  1
116736  95.612  -77.826  49.311  1
116737  95.637  -77.827  49.278  1
116738  95.668  -77.828  49.245  1
116739  95.698  -77.830  49.213  1
116740  95.728  -77.830  49.182  1
116741  95.758  -77.832  49.151  1
116742  95.784  -77.837  49.120  1
116743  95.790  -77.855  49.090  1
116744  95.812  -77.858  49.057  1
116745  95.831  -77.864  49.023  1
116746  95.840  -77.881  48.985  1
116747  95.849  -77.898  48.950  1
116748  95.858  -77.915  48.912  1
116749  95.867  -77.933  48.871  1
116750  95.876  -77.950  48.830  1
116751  95.884  -77.967  48.789  1
116752  95.888  -77.979  48.748  1
116753  95.898  -77.979  48.706  1
116754  95.911  -77.980  48.667  1
116755  95.923  -77.981  48.628  1
116756  95.936  -77.982  48.589  1
116757  95.949  -77.984  48.553  1
116758  95.962  -77.984  48.517  1
116759  95.974  -77.985  48.482  1
116760  95.987  -77.987  48.449  1
116761  96.003  -77.984  48.418  1
116762  96.019  -77.981  48.389  1
116763  96.035  -77.978  48.359  1
116764  96.051  -77.975  48.330  1
116765  96.062  -77.979  48.301  1
116766  96.074  -77.984  48.275  1
116767  96.086  -77.989  48.252  1
116768  96.097  -77.994  48.227  1
116769  96.109  -77.999  48.200  1
116770  96.120  -78.004  48.173  1
116771  96.135  -78.012  48.146  1
116772  96.150  -78.019  48.120  1
116773  96.166  -78.021  48.095  1
116774  96.182  -78.022  48.071  1
116775  96.198  -78.023  48.048  1
116776  96.215  -78.025  48.024  1
116777  96.232  -78.028  47.999  1
116778  96.250  -78.031  47.974  1
116779  96.271  -78.038  47.948  1
116780  96.293  -78.047  47.922  1
116781  96.310  -78.055  47.896  1
116782  96.317  -78.062  47.870  1
116783  96.333  -78.076  47.843  1
116784  96.350  -78.090  47.817  1
116785  96.366  -78.103  47.789  1
116786  96.372  -78.126  47.760  1
116787  96.384  -78.144  47.732  1
116788  96.402  -78.156  47.703  1
116789  96.421  -78.169  47.676  1
116790  96.441  -78.181  47.649  1
116791  96.456  -78.191  47.622  1
116792  96.458  -78.188  47.595  1
116793  96.460  -78.184  47.567  1
116794  96.461  -78.182  47.539  1
116795  96.463  -78.179  47.512  1
116796  96.465  -78.182  47.486  1
116797  96.467  -78.188  47.461  1
116798  96.469  -78.194  47.434  1
116799  96.471  -78.199  47.407  1
116800  96.472  -78.202  47.380  1
116801  96.471  -78.202  47.353  1
116802  96.488  -78.205  47.327  1
116803  96.507  -78.213  47.301  1
116804  96.526  -78.221  47.275  1
116805  96.544  -78.228  47.249  1
116806  96.556  -78.235  47.221  1
116807  96.562  -78.239  47.194  1
116808  96.568  -78.244  47.167  1
116809  96.574  -78.248  47.140  1
116810  96.580  -78.253  47.115  1
116811  96.586  -78.258  47.088  1
116812  96.588  -78.270  47.062  1
116813  96.604  -78.351  47.036  1
116814  96.614  -78.411  47.009  1
116815  96.607  -78.395  46.982  1
116816  96.609  -78.412  46.955  1
116817  96.610  -78.426  46.928  1
116818  96.624  -78.440  46.900  1
116819  96.661  -78.453  46.872  1
116820  96.695  -78.462  46.844  1
116821  96.731  -78.471  46.816  1
116822  96.765  -78.479  46.788  1
116823  96.796  -78.492  46.761  1
116824  96.826  -78.504  46.734  1
116825  96.857  -78.516  46.707  1
116826  96.884  -78.525  46.680  1
116827  96.911  -78.534  46.654  1
116828  96.939  -78.542  46.629  1
116829  96.966  -78.551  46.603  1
116830  96.992  -78.563  46.576  1
116831  97.017  -78.579  46.549  1
116832  97.042  -78.594  46.522  1
116833  97.051  -78.609  46.495  1
116834  97.045  -78.623  46.468  1
116835  97.040  -78.639  46.443  1
116836  97.046  -78.658  46.420  1
116837  97.056  -78.678  46.398  1
116838  97.069  -78.697  46.376  1
116839  97.109  -78.698  46.356  1
116840  97.151  -78.697  46.338  1
116841  97.211  -78.682  46.321  1
116842  97.271  -78.667  46.305  1
116843  97.330  -78.653  46.288  1
116844  97.389  -78.639  46.273  1
116845  97.449  -78.624  46.259  1
116846  97.509  -78.610  46.246  1
116847  97.568  -78.595  46.233  1
116848  97.625  -78.586  46.220  1
116849  97.672  -78.598  46.206  1
116850  97.720  -78.611  46.193  1
116851  97.780  -78.643  46.180  1
116852  97.817  -78.682  46.167  1
116853  97.818  -78.716  46.155  1
116854  97.822  -78.721  46.141  1
116855  97.828  -78.727  46.126  1
116856  97.850  -78.725  46.110  1
116857  97.871  -78.723  46.094  1
116858  97.892  -78.721  46.078  1
116859  97.914  -78.719  46.062  1
116860  97.935  -78.717  46.045  1
116861  97.956  -78.716  46.029  1
116862  97.984  -78.667  46.013  1
116863  98.010  -78.678  45.995  1
116864  98.038  -78.689  45.978  1
116865  97.976  -78.636  45.961  1
116866  98.004  -78.638  45.944  1
116867  98.031  -78.639  45.927  1
116868  98.059  -78.641  45.910  1
116869  98.092  -78.638  45.894  1
116870  98.170  -78.595  45.876  1
116871  98.201  -78.580  45.857  1
116872  98.205  -78.576  45.840  1
116873  98.206  -78.577  45.824  1
116874  98.202  -78.582  45.807  1
116875  98.195  -78.582  45.791  1
116876  98.220  -78.598  45.775  1
116877  98.225  -78.604  45.758  1
116878  98.217  -78.595  45.741  1
116879  98.213  -78.590  45.724  1
116880  98.220  -78.593  45.709  1
116881  98.228  -78.597  45.694  1
116882  98.235  -78.601  45.678  1
116883  98.243  -78.604  45.662  1
116884  98.250  -78.608  45.646  1
116885  98.296  -78.621  45.630  1
116886  98.308  -78.620  45.615  1
116887  98.317  -78.627  45.600  1
116888  98.325  -78.634  45.584  1
116889  98.334  -78.641  45.568  1
116890  98.343  -78.648  45.552  1
116891  98.351  -78.655  45.535  1
116892  98.359  -78.662  45.519  1
116893  98.368  -78.671  45.504  1
116894  98.391  -78.689  45.488  1
116895  98.416  -78.706  45.470  1
116896  98.441  -78.724  45.454  1
116897  98.466  -78.742  45.438  1
116898  98.495  -78.768  45.423  1
116899  98.524  -78.796  45.408  1
116900  98.537  -78.801  45.395  1
116901  98.542  -78.793  45.382  1
116902  98.533  -78.748  45.368  1
116903  98.560  -78.724  45.354  1
116904  98.523  -78.801  45.339  1
116905  98.548  -78.835  45.323  1
116906  98.580  -78.864  45.308  1
116907  98.613  -78.893  45.294  1
116908  98.645  -78.921  45.280  1
116909  98.677  -78.950  45.266  1
116910  98.721  -78.957  45.252  1
116911  98.765  -78.964  45.238  1
116912  98.809  -78.971  45.223  1
116913  98.853  -78.977  45.208  1
116914  98.857  -78.962  45.197  1
116915  98.886  -78.956  45.185  1
116916  98.926  -78.968  45.174  1
116917  98.934  -78.921  45.162  1
116918  98.942  -78.874  45.149  1
116919  98.958  -78.828  45.136  1
116920  98.977  -78.782  45.124  1
116921  99.010  -78.786  45.114  1
116922  99.025  -78.797  45.105  1
116923  99.041  -78.809  45.096  1
116924  99.055  -78.821  45.089  1
116925  99.070  -78.833  45.080  1
116926  99.085  -78.844  45.071  1
116927  99.104  -78.849  45.064  1
116928  99.123  -78.855  45.054  1
116929  99.142  -78.860  45.044  1
116930  99.161  -78.865  45.035  1
116931  99.180  -78.871  45.025  1
116932  99.202  -78.883  45.015  1
116933  99.229  -78.897  45.004  1
116934  99.258  -78.912  44.993  1
116935  99.285  -78.927  44.982  1
116936  99.313  -78.941  44.969  1
116937  99.342  -78.955  44.955  1
116938  99.369  -78.970  44.944  1
116939  99.397  -78.984  44.937  1
116940  99.409  -78.974  44.932  1
116941  99.386  -78.917  44.925  1
116942  99.434  -78.976  44.918  1
116943  99.512  -78.976  44.910  1
116944  99.517  -79.020  44.902  1
116945  99.551  -79.030  44.893  1
116946  99.585  -79.040  44.887  1
116947  99.620  -79.050  44.879  1
116948  99.653  -79.060  44.871  1
116949  99.690  -79.059  44.860  1
116950  99.700  -79.065  44.851  1
116951  99.717  -79.090  44.842  1
116952  99.754  -79.123  44.834  1
116953  99.781  -79.158  44.827  1
116954  99.803  -79.193  44.821  1
116955  99.823  -79.223  44.814  1
116956  99.836  -79.229  44.807  1
116957  99.849  -79.234  44.799  1
116958  99.846  -79.260  44.791  1
116959  99.825  -79.315  44.785  1
116960  99.822  -79.353  44.779  1
116961  99.840  -79.373  44.773  1
116962  99.858  -79.394  44.767  1
116963  99.876  -79.413  44.760  1
116964  99.914  -79.432  44.754  1
116965  99.968  -79.448  44.747  1
116966  100.021  -79.465  44.741  1
116967  100.075  -79.481  44.735  1
116968  100.129  -79.498  44.729  1
116969  100.148  -79.516  44.722  1
116970  100.163  -79.535  44.714  1
116971  100.179  -79.555  44.705  1
116972  100.195  -79.576  44.697  1
116973  100.210  -79.595  44.689  1
116974  100.226  -79.615  44.681  1
116975  100.254  -79.624  44.673  1
116976  100.292  -79.624  44.665  1
116977  100.331  -79.624  44.658  1
116978  100.439  -79.589  44.650  1
116979  100.392  -79.612  44.642  1
116980  100.374  -79.633  44.632  1
116981  100.432  -79.643  44.623  1
116982  100.489  -79.652  44.614  1
116983  100.547  -79.662  44.604  1
116984  100.605  -79.672  44.594  1
116985  100.662  -79.681  44.583  1
116986  100.720  -79.691  44.573  1
116987  100.759  -79.690  44.562  1
116988  100.794  -79.701  44.551  1
116989  100.828  -79.736  44.539  1
116990  100.861  -79.770  44.527  1
116991  100.895  -79.804  44.516  1
116992  100.936  -79.827  44.505  1
116993  100.976  -79.851  44.494  1
116994  101.017  -79.874  44.483  1
116995  101.057  -79.898  44.472  1
116996  101.098  -79.921  44.461  1
116997  101.138  -79.945  44.451  1
116998  101.179  -79.968  44.440  1
116999  101.219  -79.993  44.427  1
117000  101.258  -80.021  44.415  1
117001  101.298  -80.049  44.402  1
117002  101.337  -80.078  44.389  1
117003  101.376  -80.106  44.374  1
117004  101.401  -80.097  44.358  1
117005  101.481  -80.082  44.342  1
117006  101.514  -80.096  44.325  1
117007  101.546  -80.112  44.307  1
117008  101.578  -80.127  44.289  1
117009  101.610  -80.144  44.272  1
117010  101.642  -80.160  44.253  1
117011  101.674  -80.176  44.235  1
117012  101.706  -80.193  44.218  1
117013  101.739  -80.209  44.200  1
117014  101.771  -80.225  44.182  1
117015  101.802  -80.240  44.163  1
117016  101.835  -80.257  44.144  1
117348  94.424  -77.915  52.003  1
117349  94.438  -77.907  51.981  1
117350  94.452  -77.900  51.960  1
117351  94.466  -77.893  51.938  1
117352  94.480  -77.887  51.916  1
117353  94.494  -77.881  51.894  1
117354  94.509  -77.874  51.873  1
117355  94.523  -77.867  51.852  1
117356  94.537  -77.861  51.831  1
117357  94.551  -77.854  51.810  1
117358  94.553  -77.849  51.787  1
117359  94.554  -77.845  51.764  1
117360  94.555  -77.841  51.742  1
117361  94.556  -77.837  51.719  1
117362  94.557  -77.832  51.694  1
117363  94.575  -77.823  51.670  1
117364  94.595  -77.815  51.645  1
117365  94.610  -77.816  51.619  1
117366  94.626  -77.816  51.593  1
117367  94.649  -77.822  51.565  1
117368  94.663  -77.824  51.538  1
117369  94.675  -77.825  51.509  1
117370  94.686  -77.825  51.480  1
117371  94.698  -77.826  51.451  1
117372  94.709  -77.827  51.424  1
117373  94.721  -77.827  51.394  1
117374  94.732  -77.827  51.363  1
117375  94.745  -77.830  51.331  1
117376  94.777  -77.825  51.299  1
117377  94.810  -77.821  51.265  1
117378  94.819  -77.862  51.231  1
117379  94.810  -77.834  51.197  1
117380  94.805  -77.847  51.162  1
117381  94.806  -77.877  51.126  1
117382  94.826  -77.888  51.090  1
117383  94.851  -77.896  51.055  1
117384  94.876  -77.902  51.021  1
117385  94.900  -77.910  50.985  1
117386  94.917  -77.894  50.949  1
117387  94.925  -77.881  50.913  1
117388  94.937  -77.872  50.876  1
117389  94.950  -77.865  50.839  1
117390  94.963  -77.859  50.804  1
117391  94.975  -77.851  50.769  1
117392  94.988  -77.844  50.733  1
117393  95.001  -77.837  50.697  1
117394  95.014  -77.829  50.661  1
117395  95.026  -77.820  50.626  1
117396  95.038  -77.812  50.591  1
117397  95.051  -77.803  50.555  1
117398  95.063  -77.794  50.522  1
117399  95.077  -77.789  50.488  1
117400  95.092  -77.783  50.454  1
117401  95.107  -77.777  50.422  1
117402  95.124  -77.774  50.389  1
117403  95.144  -77.775  50.356  1
117404  95.164  -77.776  50.324  1
117405  95.183  -77.777  50.294  1
117406  95.197  -77.787  50.263  1
117407  95.202  -77.812  50.233  1
117408  95.222  -77.816  50.204  1
117409  95.246  -77.818  50.176  1
117410  95.268  -77.819  50.149  1
117411  95.291  -77.821  50.123  1
117412  95.320  -77.818  50.098  1
117413  95.357  -77.811  50.075  1
117414  95.394  -77.803  50.053  1
117415  95.419  -77.799  50.032  1
117416  95.432  -77.799  50.010  1
117417  95.445  -77.798  49.987  1
117418  95.458  -77.797  49.963  1
117419  95.472  -77.796  49.936  1
117420  95.485  -77.796  49.904  1
117421  95.498  -77.795  49.871  1
117422  95.512  -77.794  49.836  1
117423  95.523  -77.793  49.801  1
117424  95.512  -77.821  49.765  1
117425  95.494  -77.856  49.729  1
117426  95.476  -77.892  49.692  1
117427  95.458  -77.928  49.655  1
117428  95.497  -77.901  49.619  1
117429  95.546  -77.862  49.583  1
117430  95.550  -77.852  49.548  1
117431  95.553  -77.844  49.512  1
117432  95.556  -77.835  49.478  1
117433  95.559  -77.827  49.443  1
117434  95.576  -77.821  49.411  1
117435  95.602  -77.812  49.380  1
117436  95.615  -77.814  49.349  1
117437  95.635  -77.816  49.317  1
117438  95.656  -77.818  49.287  1
117439  95.677  -77.820  49.258  1
117440  95.697  -77.822  49.228  1
117441  95.718  -77.824  49.199  1
117442  95.745  -77.825  49.168  1
117443  95.775  -77.826  49.136  1
117444  95.799  -77.833  49.101  1
117445  95.817  -77.840  49.066  1
117446  95.829  -77.854  49.031  1
117447  95.837  -77.871  48.994  1
117448  95.846  -77.888  48.960  1
117449  95.855  -77.906  48.925  1
117450  95.864  -77.923  48.886  1
117451  95.873  -77.940  48.845  1
117452  95.882  -77.957  48.804  1
117453  95.889  -77.965  48.764  1
117454  95.902  -77.967  48.722  1
117455  95.914  -77.968  48.683  1
117456  95.927  -77.968  48.644  1
117457  95.940  -77.970  48.605  1
117458  95.952  -77.971  48.568  1
117459  95.965  -77.972  48.532  1
117460  95.978  -77.973  48.497  1
117461  95.990  -77.974  48.464  1
117462  96.005  -77.973  48.434  1
117463  96.021  -77.970  48.404  1
117464  96.037  -77.967  48.375  1
117465  96.048  -77.972  48.346  1
117466  96.060  -77.977  48.316  1
117467  96.072  -77.981  48.288  1
117468  96.083  -77.987  48.262  1
117469  96.095  -77.991  48.239  1
117470  96.106  -77.996  48.215  1
117471  96.118  -78.000  48.189  1
117472  96.134  -78.001  48.162  1
117473  96.151  -78.002  48.136  1
117474  96.166  -78.003  48.110  1
117475  96.182  -78.004  48.086  1
117476  96.198  -78.006  48.061  1
117477  96.215  -78.006  48.037  1
117478  96.232  -78.009  48.011  1
117479  96.250  -78.012  47.986  1
117480  96.272  -78.021  47.960  1
117481  96.289  -78.029  47.934  1
117482  96.300  -78.040  47.908  1
117483  96.316  -78.053  47.882  1
117484  96.333  -78.066  47.856  1
117485  96.349  -78.080  47.829  1
117486  96.366  -78.094  47.802  1
117487  96.374  -78.115  47.774  1
117488  96.377  -78.139  47.745  1
117489  96.391  -78.155  47.716  1
117490  96.410  -78.167  47.690  1
117491  96.429  -78.179  47.663  1
117492  96.448  -78.191  47.635  1
117493  96.452  -78.191  47.608  1
117494  96.454  -78.188  47.581  1
117495  96.455  -78.185  47.554  1
117496  96.457  -78.182  47.527  1
117497  96.459  -78.180  47.500  1
117498  96.460  -78.177  47.474  1
117499  96.462  -78.177  47.447  1
117500  96.464  -78.182  47.419  1
117501  96.466  -78.187  47.392  1
117502  96.471  -78.188  47.365  1
117503  96.490  -78.195  47.338  1
117504  96.509  -78.203  47.312  1
117505  96.528  -78.211  47.286  1
117506  96.546  -78.219  47.260  1
117507  96.561  -78.225  47.233  1
117508  96.568  -78.231  47.206  1
117509  96.574  -78.235  47.179  1
117510  96.580  -78.240  47.153  1
117511  96.585  -78.244  47.127  1
117512  96.589  -78.254  47.101  1
117513  96.587  -78.273  47.075  1
117514  96.591  -78.312  47.049  1
117515  96.601  -78.370  47.022  1
117516  96.594  -78.351  46.995  1
117517  96.598  -78.380  46.968  1
117518  96.601  -78.404  46.941  1
117519  96.622  -78.419  46.913  1
117520  96.660  -78.432  46.885  1
117521  96.694  -78.441  46.858  1
117522  96.729  -78.450  46.831  1
117523  96.764  -78.459  46.803  1
117524  96.799  -78.467  46.776  1
117525  96.830  -78.479  46.749  1
117526  96.860  -78.491  46.721  1
117527  96.887  -78.500  46.694  1
117528  96.914  -78.508  46.668  1
117529  96.940  -78.521  46.642  1
117530  96.966  -78.536  46.617  1
117531  96.991  -78.551  46.591  1
117532  97.016  -78.567  46.564  1
117533  97.041  -78.582  46.538  1
117534  97.049  -78.598  46.511  1
117535  97.044  -78.613  46.484  1
117536  97.038  -78.627  46.459  1
117537  97.033  -78.642  46.436  1
117538  97.028  -78.657  46.413  1
117539  97.034  -78.677  46.392  1
117540  97.081  -78.671  46.371  1
117541  97.141  -78.657  46.353  1
117542  97.201  -78.642  46.336  1
117543  97.260  -78.628  46.319  1
117544  97.320  -78.614  46.303  1
117545  97.379  -78.599  46.288  1
117546  97.439  -78.585  46.273  1
117547  97.499  -78.570  46.259  1
117548  97.558  -78.555  46.245  1
117549  97.614  -78.548  46.232  1
117550  97.662  -78.562  46.219  1
117551  97.721  -78.593  46.205  1
117552  97.781  -78.625  46.192  1
117553  97.818  -78.664  46.179  1
117554  97.817  -78.714  46.166  1
117555  97.820  -78.728  46.152  1
117556  97.832  -78.731  46.138  1
117557  97.853  -78.729  46.123  1
117558  97.874  -78.727  46.107  1
117559  97.896  -78.725  46.092  1
117560  97.928  -78.683  46.076  1
117561  97.954  -78.636  46.059  1
117562  97.974  -78.642  46.042  1
117563  98.002  -78.654  46.026  1
117564  98.029  -78.665  46.009  1
117565  98.058  -78.677  45.991  1
117566  97.992  -78.620  45.974  1
117567  98.023  -78.611  45.958  1
117568  98.051  -78.613  45.940  1
117569  98.078  -78.614  45.923  1
117570  98.118  -78.605  45.906  1
117571  98.187  -78.568  45.888  1
117572  98.190  -78.569  45.869  1
117573  98.195  -78.566  45.853  1
117574  98.200  -78.563  45.836  1
117575  98.204  -78.560  45.818  1
117576  98.215  -78.565  45.802  1
117577  98.239  -78.580  45.786  1
117578  98.244  -78.582  45.769  1
117579  98.251  -78.586  45.752  1
117580  98.259  -78.589  45.736  1
117581  98.267  -78.592  45.720  1
117582  98.274  -78.595  45.704  1
117583  98.282  -78.599  45.688  1
117584  98.289  -78.603  45.672  1
117585  98.296  -78.606  45.655  1
117586  98.320  -78.619  45.641  1
117587  98.334  -78.617  45.625  1
117588  98.343  -78.625  45.609  1
117589  98.351  -78.632  45.594  1
117590  98.360  -78.639  45.577  1
117591  98.367  -78.645  45.561  1
117592  98.372  -78.647  45.544  1
117593  98.376  -78.649  45.528  1
117594  98.380  -78.651  45.512  1
117595  98.385  -78.649  45.496  1
117596  98.413  -78.667  45.479  1
117597  98.440  -78.686  45.462  1
117598  98.465  -78.710  45.446  1
117599  98.498  -78.736  45.430  1
117600  98.529  -78.762  45.415  1
117601  98.558  -78.791  45.401  1
117602  98.563  -78.776  45.387  1
117603  98.548  -78.714  45.372  1
117604  98.567  -78.688  45.358  1
117605  98.558  -78.745  45.343  1
117606  98.590  -78.774  45.327  1
117607  98.622  -78.802  45.311  1
117608  98.654  -78.832  45.297  1
117609  98.687  -78.861  45.283  1
117610  98.719  -78.890  45.268  1
117611  98.756  -78.909  45.254  1
117612  98.800  -78.916  45.240  1
117613  98.844  -78.924  45.226  1
117614  98.881  -78.927  45.210  1
117615  98.853  -78.893  45.198  1
117616  98.889  -78.890  45.186  1
117617  98.935  -78.893  45.175  1
117618  98.968  -78.906  45.163  1
117619  98.976  -78.859  45.151  1
117620  98.984  -78.812  45.138  1
117621  98.992  -78.765  45.126  1
117622  99.005  -78.764  45.114  1
117623  99.020  -78.777  45.104  1
117624  99.035  -78.788  45.096  1
117625  99.050  -78.800  45.087  1
117626  99.065  -78.812  45.078  1
117627  99.080  -78.823  45.069  1
117628  99.099  -78.828  45.061  1
117629  99.118  -78.833  45.052  1
117630  99.136  -78.839  45.042  1
117631  99.153  -78.843  45.033  1
117632  99.170  -78.848  45.024  1
117633  99.205  -78.866  45.013  1
117634  99.233  -78.878  45.002  1
117635  99.263  -78.890  44.990  1
117636  99.291  -78.902  44.978  1
117637  99.319  -78.918  44.966  1
117638  99.347  -78.932  44.954  1
117639  99.375  -78.946  44.943  1
117640  99.403  -78.961  44.935  1
117641  99.417  -78.955  44.927  1
117642  99.384  -78.884  44.921  1
117643  99.455  -78.912  44.913  1
117644  99.517  -78.915  44.904  1
117645  99.532  -78.955  44.895  1
117646  99.559  -78.977  44.887  1
117647  99.592  -78.987  44.880  1
117648  99.626  -78.998  44.872  1
117649  99.660  -79.008  44.862  1
117650  99.689  -79.028  44.852  1
117651  99.715  -79.071  44.843  1
117652  99.736  -79.107  44.834  1
117653  99.758  -79.142  44.826  1
117654  99.776  -79.168  44.820  1
117655  99.789  -79.173  44.814  1
117656  99.802  -79.176  44.808  1
117657  99.825  -79.197  44.801  1
117658  99.848  -79.219  44.793  1
117659  99.858  -79.243  44.786  1
117660  99.835  -79.272  44.780  1
117661  99.814  -79.324  44.773  1
117662  99.822  -79.353  44.767  1
117663  99.840  -79.373  44.762  1
117664  99.874  -79.391  44.756  1
117665  99.928  -79.408  44.749  1
117666  99.981  -79.425  44.743  1
117667  100.035  -79.443  44.738  1
117668  100.089  -79.463  44.732  1
117669  100.139  -79.484  44.726  1
117670  100.155  -79.504  44.719  1
117671  100.171  -79.524  44.711  1
117672  100.186  -79.544  44.703  1
117673  100.202  -79.564  44.695  1
117674  100.217  -79.584  44.687  1
117675  100.252  -79.587  44.679  1
117676  100.290  -79.587  44.671  1
117677  100.329  -79.587  44.663  1
117678  100.367  -79.587  44.655  1
117679  100.405  -79.587  44.647  1
117680  100.443  -79.586  44.639  1
117681  100.457  -79.589  44.629  1
117682  100.485  -79.603  44.621  1
117683  100.513  -79.617  44.612  1
117684  100.542  -79.630  44.603  1
117685  100.599  -79.640  44.593  1
117686  100.656  -79.649  44.584  1
117687  100.714  -79.659  44.574  1
117688  100.766  -79.665  44.565  1
117689  100.802  -79.677  44.554  1
117690  100.835  -79.712  44.542  1
117691  100.872  -79.741  44.531  1
117692  100.912  -79.764  44.521  1
117693  100.953  -79.788  44.510  1
117694  100.993  -79.811  44.500  1
117695  101.034  -79.835  44.489  1
117696  101.073  -79.863  44.480  1
117697  101.112  -79.892  44.470  1
117698  101.151  -79.920  44.459  1
117699  101.191  -79.949  44.449  1
117700  101.230  -79.977  44.437  1
117701  101.269  -80.005  44.425  1
117702  101.308  -80.034  44.412  1
117703  101.347  -80.062  44.399  1
117704  101.386  -80.090  44.383  1
117705  101.425  -80.098  44.366  1
117706  101.492  -80.054  44.350  1
117707  101.531  -80.057  44.333  1
117708  101.563  -80.074  44.314  1
117709  101.595  -80.090  44.295  1
117710  101.627  -80.106  44.277  1
117711  101.659  -80.121  44.259  1
117712  101.692  -80.138  44.240  1
117713  101.724  -80.154  44.222  1
117714  101.756  -80.170  44.204  1
117715  101.788  -80.187  44.186  1
117716  101.820  -80.203  44.167  1
117717  101.852  -80.218  44.147  1
118048  94.420  -77.903  52.034  1
118049  94.433  -77.896  52.012  1
118050  94.447  -77.888  51.991  1
118051  94.461  -77.881  51.970  1
118052  94.475  -77.874  51.948  1
118053  94.489  -77.868  51.927  1
118054  94.504  -77.861  51.906  1
118055  94.518  -77.855  51.885  1
118056  94.532  -77.848  51.863  1
118057  94.546  -77.841  51.843  1
118058  94.560  -77.835  51.822  1
118059  94.566  -77.830  51.801  1
118060  94.567  -77.825  51.779  1
118061  94.568  -77.821  51.757  1
118062  94.569  -77.817  51.734  1
118063  94.570  -77.812  51.711  1
118064  94.578  -77.806  51.687  1
118065  94.599  -77.796  51.662  1
118066  94.614  -77.797  51.637  1
118067  94.629  -77.797  51.610  1
118068  94.645  -77.798  51.582  1
118069  94.662  -77.802  51.554  1
118070  94.673  -77.802  51.526  1
118071  94.685  -77.802  51.497  1
118072  94.697  -77.804  51.467  1
118073  94.709  -77.808  51.438  1
118074  94.722  -77.811  51.409  1
118075  94.737  -77.815  51.378  1
118076  94.764  -77.815  51.346  1
118077  94.795  -77.811  51.315  1
118078  94.826  -77.807  51.282  1
118079  94.813  -77.838  51.247  1
118080  94.822  -77.840  51.212  1
118081  94.859  -77.799  51.175  1
118082  94.877  -77.811  51.139  1
118083  94.883  -77.832  51.102  1
118084  94.889  -77.853  51.066  1
118085  94.895  -77.875  51.031  1
118086  94.902  -77.893  50.995  1
118087  94.915  -77.884  50.957  1
118088  94.927  -77.875  50.920  1
118089  94.940  -77.867  50.883  1
118090  94.952  -77.859  50.847  1
118091  94.965  -77.849  50.810  1
118092  94.977  -77.841  50.775  1
118093  94.990  -77.832  50.739  1
118094  95.002  -77.824  50.703  1
118095  95.015  -77.815  50.667  1
118096  95.028  -77.806  50.631  1
118097  95.040  -77.798  50.596  1
118098  95.055  -77.796  50.561  1
118099  95.071  -77.793  50.527  1
118100  95.086  -77.787  50.493  1
118101  95.098  -77.774  50.458  1
118102  95.114  -77.771  50.425  1
118103  95.131  -77.767  50.392  1
118104  95.147  -77.764  50.359  1
118105  95.166  -77.764  50.327  1
118106  95.186  -77.765  50.297  1
118107  95.205  -77.765  50.267  1
118108  95.213  -77.785  50.236  1
118109  95.229  -77.796  50.208  1
118110  95.252  -77.798  50.179  1
118111  95.274  -77.799  50.152  1
118112  95.297  -77.801  50.125  1
118113  95.320  -77.802  50.100  1
118114  95.344  -77.803  50.075  1
118115  95.381  -77.796  50.051  1
118116  95.418  -77.789  50.029  1
118117  95.431  -77.787  50.008  1
118118  95.445  -77.787  49.986  1
118119  95.458  -77.787  49.962  1
118120  95.471  -77.786  49.935  1
118121  95.484  -77.785  49.904  1
118122  95.497  -77.784  49.871  1
118123  95.498  -77.778  49.835  1
118124  95.496  -77.770  49.802  1
118125  95.594  -77.823  49.767  1
118126  95.504  -77.849  49.730  1
118127  95.466  -77.882  49.693  1
118128  95.448  -77.918  49.658  1
118129  95.483  -77.895  49.622  1
118130  95.533  -77.855  49.586  1
118131  95.550  -77.838  49.551  1
118132  95.553  -77.830  49.516  1
118133  95.556  -77.821  49.481  1
118134  95.580  -77.818  49.447  1
118135  95.604  -77.815  49.415  1
118136  95.629  -77.796  49.384  1
118137  95.639  -77.805  49.353  1
118138  95.660  -77.806  49.324  1
118139  95.680  -77.808  49.298  1
118140  95.701  -77.810  49.273  1
118141  95.722  -77.812  49.245  1
118142  95.742  -77.814  49.217  1
118143  95.763  -77.816  49.186  1
118144  95.783  -77.818  49.151  1
118145  95.804  -77.820  49.114  1
118146  95.818  -77.825  49.077  1
118147  95.827  -77.843  49.041  1
118148  95.836  -77.859  49.005  1
118149  95.845  -77.877  48.970  1
118150  95.854  -77.894  48.935  1
118151  95.863  -77.911  48.899  1
118152  95.872  -77.928  48.858  1
118153  95.881  -77.946  48.819  1
118154  95.894  -77.955  48.779  1
118155  95.905  -77.955  48.738  1
118156  95.917  -77.956  48.699  1
118157  95.931  -77.956  48.661  1
118158  95.943  -77.958  48.622  1
118159  95.956  -77.959  48.584  1
118160  95.968  -77.959  48.547  1
118161  95.981  -77.961  48.512  1
118162  95.994  -77.962  48.479  1
118163  96.008  -77.962  48.450  1
118164  96.023  -77.960  48.421  1
118165  96.034  -77.965  48.392  1
118166  96.046  -77.969  48.361  1
118167  96.057  -77.974  48.330  1
118168  96.071  -77.978  48.300  1
118169  96.084  -77.981  48.272  1
118170  96.098  -77.984  48.249  1
118171  96.111  -77.987  48.225  1
118172  96.121  -77.985  48.201  1
118173  96.134  -77.984  48.175  1
118174  96.151  -77.984  48.149  1
118175  96.167  -77.986  48.123  1
118176  96.183  -77.987  48.098  1
118177  96.199  -77.988  48.073  1
118178  96.216  -77.989  48.048  1
118179  96.232  -77.990  48.022  1
118180  96.251  -77.996  47.996  1
118181  96.267  -78.003  47.971  1
118182  96.283  -78.016  47.945  1
118183  96.299  -78.030  47.918  1
118184  96.315  -78.044  47.893  1
118185  96.332  -78.057  47.867  1
118186  96.348  -78.071  47.841  1
118187  96.365  -78.084  47.814  1
118188  96.375  -78.103  47.786  1
118189  96.379  -78.128  47.758  1
118190  96.383  -78.152  47.730  1
118191  96.399  -78.166  47.704  1
118192  96.418  -78.178  47.677  1
118193  96.437  -78.191  47.650  1
118194  96.446  -78.194  47.623  1
118195  96.448  -78.191  47.595  1
118196  96.450  -78.188  47.568  1
118197  96.451  -78.186  47.542  1
118198  96.453  -78.183  47.515  1
118199  96.454  -78.181  47.487  1
118200  96.456  -78.178  47.460  1
118201  96.458  -78.175  47.432  1
118202  96.459  -78.172  47.405  1
118203  96.473  -78.178  47.378  1
118204  96.492  -78.186  47.350  1
118205  96.511  -78.194  47.323  1
118206  96.529  -78.201  47.297  1
118207  96.548  -78.209  47.271  1
118208  96.567  -78.217  47.245  1
118209  96.573  -78.222  47.219  1
118210  96.579  -78.226  47.193  1
118211  96.585  -78.231  47.167  1
118212  96.590  -78.238  47.141  1
118213  96.588  -78.257  47.115  1
118214  96.586  -78.275  47.089  1
118215  96.584  -78.294  47.062  1
118216  96.589  -78.329  47.035  1
118217  96.581  -78.327  47.008  1
118218  96.584  -78.344  46.981  1
118219  96.599  -78.373  46.955  1
118220  96.621  -78.397  46.928  1
118221  96.658  -78.410  46.900  1
118222  96.693  -78.420  46.873  1
118223  96.728  -78.429  46.846  1
118224  96.763  -78.438  46.820  1
118225  96.798  -78.447  46.792  1
118226  96.832  -78.455  46.765  1
118227  96.863  -78.466  46.737  1
118228  96.889  -78.479  46.710  1
118229  96.914  -78.495  46.682  1
118230  96.939  -78.510  46.656  1
118231  96.964  -78.525  46.631  1
118232  96.990  -78.541  46.605  1
118233  97.015  -78.556  46.580  1
118234  97.040  -78.572  46.553  1
118235  97.047  -78.587  46.527  1
118236  97.042  -78.601  46.501  1
118237  97.037  -78.617  46.475  1
118238  97.031  -78.631  46.451  1
118239  97.026  -78.645  46.429  1
118240  97.035  -78.651  46.408  1
118241  97.118  -78.640  46.387  1
118242  97.169  -78.624  46.368  1
118243  97.219  -78.608  46.351  1
118244  97.269  -78.592  46.335  1
118245  97.319  -78.576  46.319  1
118246  97.370  -78.560  46.303  1
118247  97.429  -78.545  46.289  1
118248  97.489  -78.530  46.274  1
118249  97.548  -78.516  46.260  1
118250  97.603  -78.512  46.246  1
118251  97.663  -78.544  46.233  1
118252  97.722  -78.576  46.218  1
118253  97.782  -78.608  46.205  1
118254  97.820  -78.645  46.193  1
118255  97.818  -78.695  46.179  1
118256  97.818  -78.735  46.165  1
118257  97.836  -78.735  46.151  1
118258  97.864  -78.705  46.136  1
118259  97.899  -78.649  46.121  1
118260  97.924  -78.604  46.106  1
118261  97.938  -78.607  46.090  1
118262  97.966  -78.618  46.073  1
118263  97.994  -78.630  46.056  1
118264  98.021  -78.641  46.040  1
118265  98.049  -78.653  46.023  1
118266  98.013  -78.634  46.005  1
118267  98.018  -78.609  45.987  1
118268  98.031  -78.588  45.970  1
118269  98.069  -78.587  45.953  1
118270  98.097  -78.589  45.936  1
118271  98.144  -78.573  45.918  1
118272  98.177  -78.558  45.900  1
118273  98.180  -78.558  45.882  1
118274  98.184  -78.555  45.865  1
118275  98.189  -78.552  45.848  1
118276  98.195  -78.548  45.831  1
118277  98.202  -78.570  45.815  1
118278  98.227  -78.597  45.798  1
118279  98.249  -78.600  45.781  1
118280  98.272  -78.603  45.765  1
118281  98.293  -78.605  45.748  1
118282  98.315  -78.608  45.731  1
118283  98.322  -78.608  45.715  1
118284  98.329  -78.608  45.698  1
118285  98.336  -78.608  45.682  1
118286  98.343  -78.608  45.665  1
118287  98.350  -78.608  45.650  1
118288  98.357  -78.612  45.634  1
118289  98.362  -78.615  45.618  1
118290  98.366  -78.617  45.603  1
118291  98.370  -78.620  45.586  1
118292  98.375  -78.622  45.570  1
118293  98.379  -78.624  45.553  1
118294  98.383  -78.627  45.537  1
118295  98.387  -78.630  45.521  1
118296  98.390  -78.625  45.505  1
118297  98.403  -78.626  45.488  1
118298  98.429  -78.648  45.471  1
118299  98.439  -78.705  45.454  1
118300  98.470  -78.734  45.439  1
118301  98.505  -78.758  45.424  1
118302  98.546  -78.762  45.408  1
118303  98.564  -78.734  45.392  1
118304  98.557  -78.677  45.376  1
118305  98.567  -78.655  45.362  1
118306  98.599  -78.683  45.347  1
118307  98.632  -78.713  45.331  1
118308  98.664  -78.742  45.315  1
118309  98.696  -78.771  45.301  1
118310  98.728  -78.799  45.286  1
118311  98.761  -78.828  45.271  1
118312  98.793  -78.857  45.257  1
118313  98.835  -78.869  45.243  1
118314  98.878  -78.876  45.228  1
118315  98.878  -78.858  45.214  1
118316  98.849  -78.823  45.201  1
118317  98.893  -78.824  45.188  1
118318  98.939  -78.827  45.176  1
118319  98.985  -78.830  45.164  1
118320  99.010  -78.844  45.151  1
118321  99.018  -78.796  45.139  1
118322  99.002  -78.777  45.127  1
118323  99.003  -78.775  45.116  1
118324  99.017  -78.783  45.104  1
118325  99.031  -78.791  45.094  1
118326  99.046  -78.799  45.086  1
118327  99.061  -78.806  45.077  1
118328  99.075  -78.802  45.068  1
118329  99.089  -78.805  45.059  1
118330  99.106  -78.810  45.049  1
118331  99.123  -78.814  45.040  1
118332  99.140  -78.819  45.031  1
118333  99.157  -78.824  45.022  1
118334  99.206  -78.855  45.011  1
118335  99.234  -78.867  45.001  1
118336  99.264  -78.879  44.989  1
118337  99.293  -78.890  44.978  1
118338  99.322  -78.902  44.967  1
118339  99.351  -78.915  44.955  1
118340  99.379  -78.927  44.944  1
118341  99.409  -78.938  44.933  1
118342  99.410  -78.913  44.924  1
118343  99.394  -78.853  44.915  1
118344  99.486  -78.852  44.907  1
118345  99.534  -78.851  44.898  1
118346  99.556  -78.885  44.889  1
118347  99.574  -78.924  44.881  1
118348  99.607  -78.936  44.873  1
118349  99.633  -78.962  44.863  1
118350  99.656  -78.996  44.853  1
118351  99.679  -79.030  44.843  1
118352  99.713  -79.091  44.835  1
118353  99.728  -79.109  44.827  1
118354  99.739  -79.106  44.820  1
118355  99.762  -79.128  44.813  1
118356  99.785  -79.149  44.807  1
118357  99.808  -79.171  44.801  1
118358  99.832  -79.193  44.794  1
118359  99.855  -79.214  44.787  1
118360  99.869  -79.237  44.781  1
118361  99.847  -79.266  44.775  1
118362  99.825  -79.295  44.769  1
118363  99.803  -79.333  44.763  1
118364  99.834  -79.352  44.758  1
118365  99.888  -79.370  44.751  1
118366  99.941  -79.391  44.746  1
118367  99.995  -79.411  44.741  1
118368  100.049  -79.432  44.735  1
118369  100.103  -79.452  44.730  1
118370  100.146  -79.473  44.724  1
118371  100.162  -79.493  44.717  1
118372  100.177  -79.513  44.708  1
118373  100.193  -79.533  44.701  1
118374  100.211  -79.551  44.693  1
118375  100.250  -79.551  44.685  1
118376  100.288  -79.550  44.677  1
118377  100.326  -79.550  44.669  1
118378  100.365  -79.550  44.662  1
118379  100.403  -79.550  44.653  1
118380  100.441  -79.550  44.645  1
118381  100.474  -79.552  44.637  1
118382  100.503  -79.558  44.628  1
118383  100.541  -79.569  44.619  1
118384  100.580  -79.579  44.611  1
118385  100.618  -79.589  44.602  1
118386  100.656  -79.600  44.593  1
118387  100.690  -79.612  44.584  1
118388  100.718  -79.626  44.576  1
118389  100.766  -79.636  44.567  1
118390  100.808  -79.654  44.557  1
118391  100.848  -79.678  44.546  1
118392  100.888  -79.705  44.534  1
118393  100.927  -79.733  44.524  1
118394  100.966  -79.762  44.514  1
118395  101.005  -79.790  44.505  1
118396  101.045  -79.819  44.494  1
118397  101.084  -79.847  44.485  1
118398  101.123  -79.874  44.474  1
118399  101.162  -79.899  44.464  1
118400  101.201  -79.924  44.453  1
118401  101.240  -79.949  44.442  1
118402  101.279  -79.974  44.430  1
118403  101.318  -79.999  44.417  1
118404  101.357  -80.024  44.404  1
118405  101.396  -80.049  44.388  1
118406  101.435  -80.068  44.372  1
118407  101.504  -80.027  44.357  1
118408  101.548  -80.019  44.339  1
118409  101.581  -80.035  44.320  1
118410  101.613  -80.051  44.300  1
118411  101.644  -80.068  44.281  1
118412  101.677  -80.084  44.263  1
118413  101.709  -80.099  44.244  1
118414  101.741  -80.116  44.225  1
118415  101.773  -80.132  44.207  1
118416  101.805  -80.148  44.189  1
118417  101.837  -80.165  44.170  1
118418  101.870  -80.181  44.151  1
118748  94.415  -77.892  52.067  1
118749  94.429  -77.884  52.045  1
118750  94.442  -77.877  52.023  1
118751  94.456  -77.869  52.002  1
118752  94.470  -77.862  51.981  1
118753  94.484  -77.855  51.959  1
118754  94.498  -77.849  51.939  1
118755  94.513  -77.842  51.918  1
118756  94.527  -77.836  51.898  1
118757  94.541  -77.829  51.876  1
118758  94.555  -77.822  51.856  1
118759  94.569  -77.816  51.836  1
118760  94.578  -77.810  51.816  1
118761  94.579  -77.805  51.795  1
118762  94.580  -77.802  51.774  1
118763  94.581  -77.797  51.752  1
118764  94.582  -77.793  51.729  1
118765  94.583  -77.789  51.706  1
118766  94.601  -77.780  51.682  1
118767  94.618  -77.778  51.656  1
118768  94.633  -77.778  51.628  1
118769  94.648  -77.779  51.600  1
118770  94.662  -77.782  51.571  1
118771  94.675  -77.785  51.542  1
118772  94.687  -77.788  51.513  1
118773  94.700  -77.792  51.484  1
118774  94.713  -77.795  51.454  1
118775  94.725  -77.798  51.424  1
118776  94.741  -77.805  51.393  1
118777  94.764  -77.808  51.361  1
118778  94.795  -77.804  51.330  1
118779  94.810  -77.812  51.297  1
118780  94.797  -77.843  51.263  1
118781  94.780  -77.909  51.227  1
118782  94.848  -77.824  51.190  1
118783  94.868  -77.866  51.152  1
118784  94.875  -77.888  51.115  1
118785  94.882  -77.902  51.078  1
118786  94.893  -77.891  51.043  1
118787  94.904  -77.880  51.006  1
118788  94.916  -77.871  50.968  1
118789  94.929  -77.862  50.930  1
118790  94.942  -77.853  50.893  1
118791  94.954  -77.844  50.856  1
118792  94.967  -77.836  50.819  1
118793  94.979  -77.827  50.783  1
118794  94.992  -77.818  50.747  1
118795  95.004  -77.810  50.710  1
118796  95.018  -77.803  50.674  1
118797  95.033  -77.802  50.638  1
118798  95.049  -77.800  50.602  1
118799  95.065  -77.798  50.567  1
118800  95.079  -77.792  50.533  1
118801  95.089  -77.771  50.498  1
118802  95.105  -77.768  50.464  1
118803  95.121  -77.764  50.431  1
118804  95.138  -77.761  50.397  1
118805  95.154  -77.757  50.363  1
118806  95.171  -77.754  50.332  1
118807  95.188  -77.752  50.302  1
118808  95.208  -77.753  50.272  1
118809  95.225  -77.758  50.241  1
118810  95.235  -77.777  50.212  1
118811  95.258  -77.779  50.184  1
118812  95.280  -77.780  50.156  1
118813  95.303  -77.782  50.128  1
118814  95.326  -77.783  50.103  1
118815  95.348  -77.784  50.077  1
118816  95.372  -77.786  50.052  1
118817  95.405  -77.781  50.027  1
118818  95.430  -77.777  50.004  1
118819  95.444  -77.776  49.981  1
118820  95.457  -77.775  49.958  1
118821  95.470  -77.774  49.930  1
118822  95.475  -77.771  49.899  1
118823  95.473  -77.763  49.867  1
118824  95.471  -77.755  49.834  1
118825  95.478  -77.753  49.799  1
118826  95.588  -77.811  49.763  1
118827  95.615  -77.855  49.726  1
118828  95.526  -77.882  49.691  1
118829  95.438  -77.909  49.656  1
118830  95.470  -77.889  49.621  1
118831  95.520  -77.849  49.586  1
118832  95.549  -77.824  49.554  1
118833  95.560  -77.817  49.520  1
118834  95.584  -77.814  49.485  1
118835  95.608  -77.811  49.451  1
118836  95.631  -77.808  49.419  1
118837  95.643  -77.792  49.388  1
118838  95.663  -77.795  49.358  1
118839  95.684  -77.796  49.332  1
118840  95.704  -77.799  49.310  1
118841  95.725  -77.800  49.288  1
118842  95.745  -77.802  49.262  1
118843  95.766  -77.805  49.234  1
118844  95.787  -77.806  49.202  1
118845  95.800  -77.805  49.165  1
118846  95.804  -77.805  49.130  1
118847  95.814  -77.812  49.092  1
118848  95.829  -77.823  49.054  1
118849  95.838  -77.840  49.018  1
118850  95.847  -77.857  48.981  1
118851  95.856  -77.874  48.944  1
118852  95.865  -77.892  48.907  1
118853  95.874  -77.909  48.870  1
118854  95.883  -77.926  48.832  1
118855  95.899  -77.941  48.793  1
118856  95.919  -77.952  48.754  1
118857  95.931  -77.952  48.716  1
118858  95.942  -77.952  48.677  1
118859  95.954  -77.952  48.638  1
118860  95.965  -77.953  48.600  1
118861  95.977  -77.953  48.562  1
118862  95.988  -77.953  48.527  1
118863  96.000  -77.953  48.495  1
118864  96.011  -77.952  48.469  1
118865  96.024  -77.954  48.440  1
118866  96.037  -77.957  48.409  1
118867  96.050  -77.960  48.376  1
118868  96.064  -77.963  48.344  1
118869  96.077  -77.966  48.313  1
118870  96.091  -77.969  48.283  1
118871  96.104  -77.973  48.258  1
118872  96.117  -77.976  48.233  1
118873  96.125  -77.971  48.208  1
118874  96.134  -77.966  48.184  1
118875  96.151  -77.968  48.160  1
118876  96.167  -77.968  48.134  1
118877  96.183  -77.969  48.107  1
118878  96.199  -77.971  48.083  1
118879  96.216  -77.971  48.058  1
118880  96.232  -77.972  48.032  1
118881  96.249  -77.980  48.006  1
118882  96.265  -77.993  47.980  1
118883  96.282  -78.007  47.954  1
118884  96.298  -78.021  47.928  1
118885  96.315  -78.034  47.902  1
118886  96.331  -78.048  47.877  1
118887  96.347  -78.061  47.852  1
118888  96.364  -78.075  47.825  1
118889  96.377  -78.091  47.799  1
118890  96.381  -78.116  47.772  1
118891  96.384  -78.141  47.745  1
118892  96.388  -78.165  47.718  1
118893  96.407  -78.177  47.692  1
118894  96.426  -78.189  47.665  1
118895  96.440  -78.197  47.638  1
118896  96.442  -78.194  47.609  1
118897  96.444  -78.192  47.582  1
118898  96.445  -78.189  47.555  1
118899  96.447  -78.187  47.529  1
118900  96.448  -78.184  47.502  1
118901  96.450  -78.181  47.474  1
118902  96.452  -78.178  47.445  1
118903  96.463  -78.170  47.419  1
118904  96.477  -78.167  47.391  1
118905  96.494  -78.176  47.363  1
118906  96.512  -78.184  47.337  1
118907  96.531  -78.191  47.311  1
118908  96.549  -78.200  47.285  1
118909  96.568  -78.207  47.259  1
118910  96.578  -78.213  47.233  1
118911  96.584  -78.217  47.208  1
118912  96.590  -78.222  47.183  1
118913  96.589  -78.240  47.158  1
118914  96.587  -78.259  47.133  1
118915  96.585  -78.278  47.106  1
118916  96.583  -78.297  47.079  1
118917  96.586  -78.303  47.051  1
118918  96.588  -78.312  47.025  1
118919  96.599  -78.322  46.999  1
118920  96.626  -78.335  46.973  1
118921  96.644  -78.362  46.946  1
118922  96.670  -78.381  46.920  1
118923  96.706  -78.389  46.893  1
118924  96.742  -78.397  46.867  1
118925  96.779  -78.405  46.840  1
118926  96.815  -78.413  46.813  1
118927  96.839  -78.431  46.785  1
118928  96.862  -78.451  46.757  1
118929  96.888  -78.467  46.728  1
118930  96.913  -78.483  46.699  1
118931  96.938  -78.498  46.672  1
118932  96.963  -78.514  46.646  1
118933  96.989  -78.529  46.620  1
118934  97.014  -78.545  46.595  1
118935  97.039  -78.561  46.570  1
118936  97.045  -78.576  46.544  1
118937  97.040  -78.590  46.517  1
118938  97.035  -78.605  46.492  1
118939  97.030  -78.620  46.468  1
118940  97.041  -78.621  46.445  1
118941  97.070  -78.625  46.424  1
118942  97.151  -78.566  46.404  1
118943  97.257  -78.601  46.385  1
118944  97.307  -78.586  46.367  1
118945  97.358  -78.569  46.350  1
118946  97.407  -78.553  46.334  1
118947  97.458  -78.537  46.318  1
118948  97.508  -78.521  46.303  1
118949  97.534  -78.553  46.288  1
118950  97.538  -78.605  46.274  1
118951  97.625  -78.561  46.260  1
118952  97.672  -78.551  46.247  1
118953  97.726  -78.566  46.233  1
118954  97.783  -78.589  46.219  1
118955  97.821  -78.627  46.206  1
118956  97.837  -78.589  46.191  1
118957  97.855  -78.579  46.177  1
118958  97.871  -78.615  46.163  1
118959  97.893  -78.573  46.148  1
118960  97.902  -78.571  46.134  1
118961  97.930  -78.582  46.119  1
118962  97.958  -78.595  46.104  1
118963  97.986  -78.606  46.086  1
118964  98.013  -78.617  46.069  1
118965  98.041  -78.629  46.052  1
118966  98.069  -78.640  46.035  1
118967  98.039  -78.623  46.018  1
118968  98.045  -78.598  46.000  1
118969  98.050  -78.573  45.982  1
118970  98.083  -78.562  45.965  1
118971  98.116  -78.562  45.948  1
118972  98.165  -78.543  45.931  1
118973  98.166  -78.548  45.913  1
118974  98.170  -78.548  45.894  1
118975  98.174  -78.545  45.877  1
118976  98.180  -78.540  45.861  1
118977  98.187  -78.534  45.845  1
118978  98.195  -78.549  45.828  1
118979  98.204  -78.615  45.811  1
118980  98.229  -78.623  45.793  1
118981  98.251  -78.625  45.777  1
118982  98.273  -78.628  45.760  1
118983  98.295  -78.630  45.743  1
118984  98.316  -78.633  45.726  1
118985  98.339  -78.636  45.710  1
118986  98.360  -78.638  45.693  1
118987  98.382  -78.640  45.675  1
118988  98.401  -78.642  45.659  1
118989  98.398  -78.636  45.644  1
118990  98.397  -78.630  45.628  1
118991  98.395  -78.625  45.611  1
118992  98.393  -78.619  45.595  1
118993  98.392  -78.613  45.579  1
118994  98.390  -78.608  45.563  1
118995  98.390  -78.604  45.545  1
118996  98.395  -78.607  45.529  1
118997  98.397  -78.603  45.513  1
118998  98.400  -78.598  45.496  1
118999  98.408  -78.645  45.480  1
119000  98.417  -78.702  45.464  1
119001  98.450  -78.711  45.447  1
119002  98.492  -78.712  45.433  1
119003  98.534  -78.714  45.417  1
119004  98.552  -78.686  45.401  1
119005  98.552  -78.639  45.385  1
119006  98.575  -78.637  45.367  1
119007  98.597  -78.655  45.352  1
119008  98.640  -78.670  45.337  1
119009  98.687  -78.691  45.322  1
119010  98.733  -78.712  45.306  1
119011  98.770  -78.738  45.292  1
119012  98.803  -78.767  45.277  1
119013  98.835  -78.796  45.263  1
119014  98.869  -78.821  45.248  1
119015  98.903  -78.822  45.234  1
119016  98.874  -78.788  45.219  1
119017  98.864  -78.765  45.204  1
119018  98.903  -78.756  45.191  1
119019  98.941  -78.748  45.178  1
119020  98.980  -78.739  45.165  1
119021  99.016  -78.733  45.153  1
119022  99.025  -78.811  45.141  1
119023  99.006  -78.795  45.128  1
119024  99.000  -78.788  45.117  1
119025  99.015  -78.796  45.105  1
119026  99.029  -78.803  45.093  1
119027  99.044  -78.811  45.085  1
119028  99.056  -78.793  45.076  1
119029  99.070  -78.783  45.066  1
119030  99.079  -78.783  45.056  1
119031  99.093  -78.786  45.047  1
119032  99.110  -78.790  45.038  1
119033  99.127  -78.795  45.029  1
119034  99.144  -78.799  45.019  1
119035  99.202  -78.839  45.009  1
119036  99.236  -78.855  44.999  1
119037  99.265  -78.868  44.989  1
119038  99.294  -78.879  44.979  1
119039  99.323  -78.891  44.969  1
119040  99.352  -78.903  44.958  1
119041  99.380  -78.915  44.947  1
119042  99.420  -78.906  44.933  1
119043  99.460  -78.885  44.921  1
119044  99.449  -78.864  44.910  1
119045  99.528  -78.950  44.901  1
119046  99.501  -78.850  44.892  1
119047  99.531  -78.874  44.884  1
119048  99.576  -78.880  44.875  1
119049  99.599  -78.915  44.865  1
119050  99.622  -78.949  44.855  1
119051  99.645  -78.984  44.845  1
119052  99.674  -79.024  44.837  1
119053  99.700  -79.057  44.829  1
119054  99.722  -79.079  44.821  1
119055  99.746  -79.101  44.813  1
119056  99.769  -79.122  44.807  1
119057  99.792  -79.144  44.800  1
119058  99.816  -79.165  44.794  1
119059  99.839  -79.187  44.788  1
119060  99.862  -79.209  44.782  1
119061  99.881  -79.231  44.776  1
119062  99.859  -79.260  44.770  1
119063  99.836  -79.289  44.764  1
119064  99.814  -79.319  44.759  1
119065  99.856  -79.338  44.754  1
119066  99.901  -79.359  44.748  1
119067  99.955  -79.379  44.743  1
119068  100.009  -79.400  44.738  1
119069  100.063  -79.421  44.732  1
119070  100.117  -79.441  44.727  1
119071  100.153  -79.462  44.721  1
119072  100.169  -79.482  44.715  1
119073  100.185  -79.501  44.706  1
119074  100.209  -79.513  44.699  1
119075  100.248  -79.513  44.691  1
119076  100.286  -79.513  44.684  1
119077  100.324  -79.513  44.676  1
119078  100.363  -79.513  44.668  1
119079  100.395  -79.516  44.660  1
119080  100.422  -79.521  44.652  1
119081  100.450  -79.527  44.644  1
119082  100.477  -79.532  44.635  1
119083  100.509  -79.540  44.627  1
119084  100.548  -79.551  44.618  1
119085  100.586  -79.561  44.610  1
119086  100.625  -79.571  44.601  1
119087  100.664  -79.582  44.592  1
119088  100.702  -79.592  44.584  1
119089  100.741  -79.602  44.576  1
119090  100.779  -79.613  44.567  1
119091  100.818  -79.629  44.558  1
119092  100.857  -79.645  44.547  1
119093  100.897  -79.662  44.537  1
119094  100.936  -79.679  44.527  1
119095  100.975  -79.695  44.518  1
119096  101.014  -79.712  44.508  1
119097  101.053  -79.732  44.499  1
119098  101.093  -79.756  44.488  1
119099  101.131  -79.781  44.478  1
119100  101.171  -79.806  44.468  1
119101  101.209  -79.831  44.457  1
119102  101.249  -79.856  44.446  1
119103  101.288  -79.880  44.433  1
119104  101.327  -79.905  44.420  1
119105  101.366  -79.930  44.407  1
119106  101.405  -79.955  44.392  1
119107  101.444  -79.979  44.376  1
119108  101.516  -79.999  44.361  1
119109  101.566  -79.980  44.343  1
119110  101.598  -79.997  44.323  1
119111  101.630  -80.013  44.304  1
119112  101.662  -80.029  44.285  1
119113  101.694  -80.046  44.266  1
119114  101.726  -80.062  44.247  1
119115  101.758  -80.077  44.228  1
119116  101.785  -80.095  44.209  1
119117  101.812  -80.112  44.191  1
119118  101.839  -80.131  44.173  1
119448  94.413  -77.877  52.102  1
119449  94.424  -77.872  52.081  1
119450  94.438  -77.865  52.059  1
119451  94.452  -77.857  52.038  1
119452  94.465  -77.849  52.017  1
119453  94.479  -77.843  51.995  1
119454  94.493  -77.837  51.974  1
119455  94.508  -77.830  51.953  1
119456  94.522  -77.823  51.933  1
119457  94.536  -77.817  51.912  1
119458  94.550  -77.810  51.892  1
119459  94.564  -77.803  51.872  1
119460  94.578  -77.797  51.852  1
119461  94.591  -77.790  51.833  1
119462  94.592  -77.787  51.813  1
119463  94.593  -77.782  51.793  1
119464  94.594  -77.777  51.773  1
119465  94.595  -77.774  51.751  1
119466  94.596  -77.769  51.727  1
119467  94.604  -77.763  51.702  1
119468  94.621  -77.759  51.674  1
119469  94.636  -77.759  51.646  1
119470  94.651  -77.762  51.617  1
119471  94.665  -77.768  51.589  1
119472  94.678  -77.773  51.559  1
119473  94.690  -77.776  51.530  1
119474  94.703  -77.779  51.501  1
119475  94.716  -77.782  51.471  1
119476  94.729  -77.785  51.440  1
119477  94.746  -77.794  51.408  1
119478  94.765  -77.800  51.377  1
119479  94.795  -77.796  51.345  1
119480  94.795  -77.818  51.312  1
119481  94.780  -77.872  51.278  1
119482  94.805  -77.855  51.243  1
119483  94.845  -77.845  51.205  1
119484  94.911  -77.874  51.167  1
119485  94.873  -77.900  51.128  1
119486  94.884  -77.889  51.092  1
119487  94.895  -77.878  51.056  1
119488  94.906  -77.867  51.019  1
119489  94.918  -77.856  50.979  1
119490  94.930  -77.848  50.940  1
119491  94.943  -77.840  50.902  1
119492  94.956  -77.830  50.865  1
119493  94.968  -77.822  50.828  1
119494  94.981  -77.813  50.792  1
119495  94.995  -77.809  50.755  1
119496  95.012  -77.808  50.718  1
119497  95.027  -77.806  50.682  1
119498  95.043  -77.805  50.645  1
119499  95.058  -77.803  50.609  1
119500  95.073  -77.796  50.574  1
119501  95.083  -77.776  50.539  1
119502  95.096  -77.764  50.504  1
119503  95.112  -77.761  50.469  1
119504  95.128  -77.758  50.436  1
119505  95.145  -77.754  50.402  1
119506  95.161  -77.751  50.369  1
119507  95.178  -77.748  50.337  1
119508  95.194  -77.744  50.308  1
119509  95.210  -77.741  50.277  1
119510  95.230  -77.742  50.247  1
119511  95.242  -77.756  50.218  1
119512  95.263  -77.759  50.189  1
119513  95.286  -77.761  50.161  1
119514  95.309  -77.762  50.134  1
119515  95.332  -77.764  50.107  1
119516  95.354  -77.765  50.081  1
119517  95.378  -77.767  50.055  1
119518  95.400  -77.768  50.029  1
119519  95.428  -77.766  50.004  1
119520  95.444  -77.765  49.980  1
119521  95.452  -77.764  49.956  1
119522  95.450  -77.755  49.928  1
119523  95.449  -77.749  49.898  1
119524  95.453  -77.744  49.866  1
119525  95.457  -77.740  49.833  1
119526  95.474  -77.735  49.798  1
119527  95.573  -77.794  49.762  1
119528  95.687  -77.855  49.726  1
119529  95.636  -77.888  49.691  1
119530  95.554  -77.881  49.657  1
119531  95.496  -77.869  49.623  1
119532  95.535  -77.836  49.589  1
119533  95.565  -77.813  49.557  1
119534  95.588  -77.810  49.524  1
119535  95.612  -77.807  49.490  1
119536  95.636  -77.804  49.456  1
119537  95.665  -77.787  49.426  1
119538  95.666  -77.783  49.396  1
119539  95.687  -77.785  49.367  1
119540  95.707  -77.787  49.343  1
119541  95.728  -77.789  49.322  1
119542  95.749  -77.791  49.301  1
119543  95.769  -77.793  49.276  1
119544  95.785  -77.793  49.246  1
119545  95.787  -77.787  49.214  1
119546  95.792  -77.787  49.179  1
119547  95.799  -77.795  49.146  1
119548  95.809  -77.802  49.109  1
119549  95.826  -77.809  49.071  1
119550  95.840  -77.821  49.034  1
119551  95.849  -77.837  48.996  1
119552  95.859  -77.855  48.957  1
119553  95.867  -77.872  48.919  1
119554  95.876  -77.889  48.882  1
119555  95.885  -77.906  48.844  1
119556  95.901  -77.921  48.806  1
119557  95.922  -77.935  48.766  1
119558  95.944  -77.949  48.728  1
119559  95.956  -77.949  48.690  1
119560  95.967  -77.949  48.651  1
119561  95.979  -77.949  48.613  1
119562  95.991  -77.949  48.576  1
119563  96.003  -77.949  48.541  1
119564  96.014  -77.952  48.508  1
119565  96.022  -77.948  48.481  1
119566  96.030  -77.943  48.452  1
119567  96.043  -77.946  48.420  1
119568  96.057  -77.949  48.387  1
119569  96.070  -77.953  48.355  1
119570  96.084  -77.956  48.324  1
119571  96.097  -77.959  48.294  1
119572  96.110  -77.962  48.267  1
119573  96.122  -77.964  48.242  1
119574  96.129  -77.957  48.217  1
119575  96.136  -77.951  48.194  1
119576  96.150  -77.950  48.170  1
119577  96.167  -77.951  48.145  1
119578  96.183  -77.953  48.118  1
119579  96.199  -77.953  48.094  1
119580  96.216  -77.954  48.068  1
119581  96.232  -77.956  48.043  1
119582  96.249  -77.971  48.018  1
119583  96.264  -77.984  47.994  1
119584  96.281  -77.998  47.968  1
119585  96.298  -78.011  47.942  1
119586  96.314  -78.025  47.916  1
119587  96.330  -78.038  47.891  1
119588  96.347  -78.052  47.865  1
119589  96.364  -78.065  47.839  1
119590  96.379  -78.080  47.812  1
119591  96.383  -78.104  47.785  1
119592  96.386  -78.128  47.758  1
119593  96.390  -78.153  47.731  1
119594  96.396  -78.176  47.706  1
119595  96.414  -78.188  47.680  1
119596  96.434  -78.200  47.654  1
119597  96.436  -78.198  47.627  1
119598  96.438  -78.195  47.599  1
119599  96.439  -78.193  47.572  1
119600  96.441  -78.190  47.545  1
119601  96.443  -78.187  47.518  1
119602  96.444  -78.184  47.490  1
119603  96.458  -78.175  47.462  1
119604  96.471  -78.166  47.435  1
119605  96.484  -78.157  47.407  1
119606  96.500  -78.164  47.380  1
119607  96.516  -78.173  47.354  1
119608  96.533  -78.181  47.328  1
119609  96.551  -78.190  47.301  1
119610  96.570  -78.197  47.275  1
119611  96.583  -78.204  47.250  1
119612  96.589  -78.209  47.225  1
119613  96.590  -78.223  47.200  1
119614  96.588  -78.242  47.174  1
119615  96.588  -78.257  47.149  1
119616  96.596  -78.260  47.123  1
119617  96.599  -78.269  47.097  1
119618  96.611  -78.275  47.070  1
119619  96.628  -78.279  47.043  1
119620  96.633  -78.291  47.017  1
119621  96.653  -78.297  46.991  1
119622  96.670  -78.325  46.965  1
119623  96.703  -78.337  46.938  1
119624  96.739  -78.345  46.911  1
119625  96.776  -78.353  46.884  1
119626  96.796  -78.374  46.857  1
119627  96.816  -78.395  46.830  1
119628  96.836  -78.416  46.802  1
119629  96.859  -78.435  46.774  1
119630  96.885  -78.453  46.746  1
119631  96.911  -78.470  46.717  1
119632  96.937  -78.487  46.688  1
119633  96.962  -78.503  46.662  1
119634  96.987  -78.519  46.636  1
119635  97.013  -78.534  46.611  1
119636  97.038  -78.549  46.586  1
119637  97.043  -78.564  46.560  1
119638  97.038  -78.579  46.534  1
119639  97.040  -78.592  46.509  1
119640  97.051  -78.593  46.485  1
119641  97.060  -78.589  46.462  1
119642  97.105  -78.598  46.441  1
119643  97.186  -78.555  46.422  1
119644  97.273  -78.551  46.403  1
119645  97.387  -78.555  46.384  1
119646  97.446  -78.547  46.365  1
119647  97.468  -78.563  46.349  1
119648  97.476  -78.570  46.334  1
119649  97.485  -78.576  46.318  1
119650  97.506  -78.584  46.303  1
119651  97.588  -78.600  46.288  1
119652  97.653  -78.615  46.275  1
119653  97.698  -78.595  46.261  1
119654  97.748  -78.596  46.247  1
119655  97.799  -78.600  46.234  1
119656  97.798  -78.613  46.219  1
119657  97.861  -78.608  46.204  1
119658  97.905  -78.589  46.190  1
119659  97.871  -78.539  46.176  1
119660  97.894  -78.548  46.161  1
119661  97.922  -78.559  46.146  1
119662  97.949  -78.570  46.132  1
119663  97.978  -78.582  46.116  1
119664  98.005  -78.593  46.099  1
119665  98.033  -78.604  46.082  1
119666  98.061  -78.616  46.064  1
119667  98.088  -78.627  46.047  1
119668  98.066  -78.611  46.030  1
119669  98.071  -78.587  46.013  1
119670  98.077  -78.562  45.995  1
119671  98.086  -78.539  45.978  1
119672  98.135  -78.535  45.960  1
119673  98.154  -78.534  45.943  1
119674  98.155  -78.539  45.925  1
119675  98.159  -78.537  45.907  1
119676  98.165  -78.532  45.891  1
119677  98.173  -78.526  45.875  1
119678  98.180  -78.520  45.859  1
119679  98.187  -78.529  45.841  1
119680  98.192  -78.607  45.824  1
119681  98.209  -78.645  45.807  1
119682  98.230  -78.648  45.790  1
119683  98.252  -78.651  45.772  1
119684  98.274  -78.653  45.755  1
119685  98.300  -78.647  45.738  1
119686  98.327  -78.636  45.721  1
119687  98.355  -78.626  45.704  1
119688  98.382  -78.615  45.687  1
119689  98.384  -78.608  45.671  1
119690  98.384  -78.603  45.655  1
119691  98.384  -78.599  45.639  1
119692  98.384  -78.595  45.623  1
119693  98.384  -78.592  45.606  1
119694  98.384  -78.588  45.589  1
119695  98.384  -78.584  45.572  1
119696  98.385  -78.581  45.555  1
119697  98.402  -78.595  45.539  1
119698  98.405  -78.609  45.522  1
119699  98.407  -78.608  45.505  1
119700  98.414  -78.648  45.489  1
119701  98.425  -78.698  45.473  1
119702  98.455  -78.683  45.457  1
119703  98.484  -78.668  45.443  1
119704  98.523  -78.665  45.427  1
119705  98.541  -78.637  45.410  1
119706  98.564  -78.630  45.393  1
119707  98.588  -78.623  45.375  1
119708  98.609  -78.643  45.359  1
119709  98.631  -78.665  45.344  1
119710  98.664  -78.667  45.328  1
119711  98.711  -78.688  45.313  1
119712  98.757  -78.708  45.298  1
119713  98.803  -78.730  45.283  1
119714  98.850  -78.750  45.269  1
119715  98.896  -78.771  45.254  1
119716  98.912  -78.764  45.239  1
119717  98.899  -78.742  45.224  1
119718  98.902  -78.725  45.208  1
119719  98.940  -78.716  45.194  1
119720  98.967  -78.720  45.181  1
119721  98.994  -78.726  45.168  1
119722  99.020  -78.730  45.156  1
119723  99.016  -78.798  45.143  1
119724  99.011  -78.813  45.129  1
119725  98.998  -78.800  45.118  1
119726  99.012  -78.808  45.105  1
119727  99.027  -78.816  45.093  1
119728  99.039  -78.796  45.083  1
119729  99.048  -78.754  45.074  1
119730  99.066  -78.763  45.065  1
119731  99.077  -78.765  45.054  1
119732  99.084  -78.764  45.045  1
119733  99.097  -78.767  45.035  1
119734  99.114  -78.771  45.025  1
119735  99.136  -78.780  45.017  1
119736  99.194  -78.819  45.007  1
119737  99.237  -78.844  44.997  1
119738  99.266  -78.856  44.988  1
119739  99.295  -78.868  44.979  1
119740  99.324  -78.880  44.969  1
119741  99.353  -78.892  44.957  1
119742  99.396  -78.874  44.946  1
119743  99.440  -78.853  44.933  1
119744  99.485  -78.833  44.920  1
119745  99.473  -78.824  44.908  1
119746  99.488  -78.836  44.897  1
119747  99.495  -78.844  44.888  1
119748  99.525  -78.838  44.878  1
119749  99.564  -78.852  44.869  1
119750  99.592  -78.892  44.859  1
119751  99.624  -78.935  44.849  1
119752  99.655  -78.978  44.840  1
119753  99.687  -79.021  44.832  1
119754  99.711  -79.051  44.824  1
119755  99.731  -79.074  44.816  1
119756  99.753  -79.096  44.808  1
119757  99.776  -79.118  44.801  1
119758  99.799  -79.139  44.794  1
119759  99.822  -79.161  44.788  1
119760  99.845  -79.182  44.782  1
119761  99.868  -79.204  44.777  1
119762  99.892  -79.225  44.771  1
119763  99.870  -79.254  44.765  1
119764  99.848  -79.284  44.760  1
119765  99.861  -79.294  44.755  1
119766  99.916  -79.312  44.750  1
119767  99.945  -79.344  44.745  1
119768  99.969  -79.369  44.741  1
119769  100.023  -79.389  44.736  1
119770  100.077  -79.410  44.730  1
119771  100.130  -79.430  44.724  1
119772  100.160  -79.451  44.718  1
119773  100.176  -79.470  44.712  1
119774  100.207  -79.476  44.705  1
119775  100.246  -79.476  44.698  1
119776  100.284  -79.476  44.691  1
119777  100.316  -79.479  44.683  1
119778  100.343  -79.485  44.675  1
119779  100.370  -79.491  44.668  1
119780  100.398  -79.496  44.660  1
119781  100.425  -79.501  44.652  1
119782  100.452  -79.507  44.643  1
119783  100.479  -79.513  44.635  1
119784  100.516  -79.522  44.626  1
119785  100.555  -79.532  44.618  1
119786  100.594  -79.543  44.610  1
119787  100.632  -79.553  44.601  1
119788  100.671  -79.563  44.593  1
119789  100.709  -79.574  44.584  1
119790  100.748  -79.584  44.576  1
119791  100.786  -79.598  44.567  1
119792  100.826  -79.615  44.559  1
119793  100.865  -79.632  44.549  1
119794  100.904  -79.648  44.539  1
119795  100.943  -79.665  44.529  1
119796  100.982  -79.682  44.520  1
119797  101.022  -79.698  44.511  1
119798  101.061  -79.715  44.502  1
119799  101.100  -79.732  44.491  1
119800  101.139  -79.748  44.481  1
119801  101.178  -79.765  44.471  1
119802  101.217  -79.782  44.459  1
119803  101.257  -79.798  44.448  1
119804  101.296  -79.815  44.435  1
119805  101.335  -79.832  44.422  1
119806  101.374  -79.849  44.409  1
119807  101.413  -79.865  44.393  1
119808  101.453  -79.886  44.378  1
119809  101.534  -79.928  44.363  1
119810  101.583  -79.943  44.344  1
119811  101.613  -79.959  44.324  1
119812  101.639  -79.977  44.305  1
119813  101.666  -79.995  44.286  1
119814  101.693  -80.012  44.267  1
119815  101.719  -80.030  44.248  1
119816  101.746  -80.047  44.229  1
119817  101.772  -80.065  44.211  1
119818  101.799  -80.083  44.192  1
119819  101.826  -80.100  44.173  1
120148  94.412  -77.859  52.137  1
120149  94.423  -77.856  52.115  1
120150  94.433  -77.853  52.094  1
120151  94.447  -77.846  52.074  1
120152  94.461  -77.838  52.052  1
120153  94.475  -77.830  52.031  1
120154  94.488  -77.824  52.010  1
120155  94.503  -77.817  51.989  1
120156  94.517  -77.811  51.969  1
120157  94.531  -77.804  51.948  1
120158  94.545  -77.797  51.928  1
120159  94.559  -77.791  51.908  1
120160  94.573  -77.784  51.888  1
120161  94.588  -77.777  51.869  1
120162  94.602  -77.771  51.851  1
120163  94.605  -77.767  51.832  1
120164  94.606  -77.762  51.813  1
120165  94.607  -77.758  51.792  1
120166  94.608  -77.754  51.770  1
120167  94.609  -77.749  51.746  1
120168  94.610  -77.745  51.720  1
120169  94.625  -77.740  51.693  1
120170  94.640  -77.742  51.665  1
120171  94.653  -77.748  51.636  1
120172  94.667  -77.754  51.606  1
120173  94.681  -77.760  51.576  1
120174  94.693  -77.763  51.547  1
120175  94.706  -77.766  51.518  1
120176  94.719  -77.769  51.488  1
120177  94.733  -77.774  51.457  1
120178  94.750  -77.783  51.426  1
120179  94.767  -77.791  51.394  1
120180  94.793  -77.792  51.361  1
120181  94.784  -77.829  51.327  1
120182  94.809  -77.813  51.293  1
120183  94.820  -77.817  51.258  1
120184  94.856  -77.832  51.220  1
120185  94.903  -77.852  51.182  1
120186  94.918  -77.861  51.143  1
120187  94.887  -77.881  51.106  1
120188  94.898  -77.866  51.069  1
120189  94.909  -77.854  51.031  1
120190  94.920  -77.843  50.991  1
120191  94.932  -77.834  50.951  1
120192  94.945  -77.825  50.912  1
120193  94.958  -77.818  50.874  1
120194  94.973  -77.816  50.837  1
120195  94.989  -77.814  50.800  1
120196  95.005  -77.812  50.763  1
120197  95.021  -77.811  50.726  1
120198  95.036  -77.809  50.690  1
120199  95.052  -77.808  50.653  1
120200  95.066  -77.802  50.617  1
120201  95.076  -77.781  50.581  1
120202  95.086  -77.761  50.546  1
120203  95.103  -77.758  50.511  1
120204  95.119  -77.755  50.476  1
120205  95.135  -77.751  50.442  1
120206  95.151  -77.748  50.408  1
120207  95.168  -77.744  50.375  1
120208  95.185  -77.741  50.344  1
120209  95.201  -77.738  50.314  1
120210  95.217  -77.734  50.283  1
120211  95.234  -77.731  50.253  1
120212  95.252  -77.731  50.224  1
120213  95.269  -77.740  50.195  1
120214  95.293  -77.741  50.168  1
120215  95.315  -77.743  50.141  1
120216  95.338  -77.744  50.113  1
120217  95.360  -77.746  50.086  1
120218  95.384  -77.747  50.059  1
120219  95.401  -77.745  50.033  1
120220  95.418  -77.743  50.007  1
120221  95.445  -77.759  49.981  1
120222  95.449  -77.755  49.956  1
120223  95.453  -77.751  49.929  1
120224  95.457  -77.747  49.900  1
120225  95.461  -77.743  49.869  1
120226  95.465  -77.739  49.835  1
120227  95.498  -77.736  49.800  1
120228  95.513  -77.716  49.764  1
120229  95.635  -77.805  49.728  1
120230  95.676  -77.834  49.693  1
120231  95.671  -77.848  49.660  1
120232  95.588  -77.841  49.627  1
120233  95.580  -77.818  49.594  1
120234  95.603  -77.805  49.561  1
120235  95.619  -77.804  49.529  1
120236  95.640  -77.800  49.497  1
120237  95.664  -77.797  49.464  1
120238  95.700  -77.764  49.434  1
120239  95.690  -77.774  49.405  1
120240  95.711  -77.775  49.377  1
120241  95.732  -77.777  49.354  1
120242  95.752  -77.779  49.332  1
120243  95.770  -77.780  49.311  1
120244  95.772  -77.775  49.287  1
120245  95.774  -77.769  49.257  1
120246  95.779  -77.770  49.225  1
120247  95.786  -77.777  49.192  1
120248  95.794  -77.784  49.159  1
120249  95.804  -77.791  49.123  1
120250  95.821  -77.799  49.085  1
120251  95.838  -77.806  49.049  1
120252  95.851  -77.818  49.011  1
120253  95.861  -77.835  48.972  1
120254  95.870  -77.852  48.932  1
120255  95.879  -77.870  48.893  1
120256  95.888  -77.887  48.856  1
120257  95.903  -77.902  48.819  1
120258  95.924  -77.915  48.778  1
120259  95.946  -77.929  48.740  1
120260  95.967  -77.943  48.702  1
120261  95.981  -77.947  48.664  1
120262  95.993  -77.947  48.626  1
120263  96.005  -77.947  48.589  1
120264  96.016  -77.949  48.554  1
120265  96.027  -77.954  48.519  1
120266  96.032  -77.943  48.491  1
120267  96.037  -77.934  48.462  1
120268  96.049  -77.935  48.430  1
120269  96.063  -77.939  48.397  1
120270  96.076  -77.942  48.366  1
120271  96.090  -77.945  48.335  1
120272  96.103  -77.948  48.304  1
120273  96.116  -77.951  48.277  1
120274  96.126  -77.949  48.251  1
120275  96.133  -77.943  48.227  1
120276  96.141  -77.937  48.204  1
120277  96.150  -77.933  48.180  1
120278  96.166  -77.934  48.156  1
120279  96.183  -77.935  48.129  1
120280  96.199  -77.936  48.105  1
120281  96.216  -77.937  48.079  1
120282  96.238  -77.953  48.054  1
120283  96.261  -77.979  48.030  1
120284  96.264  -77.975  48.008  1
120285  96.281  -77.988  47.983  1
120286  96.297  -78.002  47.957  1
120287  96.313  -78.015  47.932  1
120288  96.330  -78.029  47.906  1
120289  96.346  -78.043  47.880  1
120290  96.363  -78.056  47.853  1
120291  96.379  -78.069  47.826  1
120292  96.384  -78.093  47.799  1
120293  96.388  -78.117  47.773  1
120294  96.391  -78.141  47.747  1
120295  96.395  -78.166  47.721  1
120296  96.403  -78.187  47.696  1
120297  96.422  -78.199  47.669  1
120298  96.430  -78.201  47.643  1
120299  96.432  -78.198  47.616  1
120300  96.433  -78.196  47.588  1
120301  96.435  -78.193  47.561  1
120302  96.439  -78.189  47.533  1
120303  96.452  -78.180  47.506  1
120304  96.465  -78.172  47.479  1
120305  96.479  -78.163  47.451  1
120306  96.492  -78.153  47.424  1
120307  96.507  -78.151  47.397  1
120308  96.523  -78.160  47.371  1
120309  96.539  -78.169  47.345  1
120310  96.555  -78.178  47.318  1
120311  96.572  -78.188  47.293  1
120312  96.589  -78.195  47.268  1
120313  96.591  -78.207  47.243  1
120314  96.594  -78.217  47.217  1
120315  96.597  -78.227  47.190  1
120316  96.600  -78.237  47.165  1
120317  96.603  -78.247  47.140  1
120318  96.607  -78.257  47.114  1
120319  96.622  -78.260  47.089  1
120320  96.643  -78.262  47.062  1
120321  96.664  -78.263  47.035  1
120322  96.677  -78.269  47.009  1
120323  96.699  -78.285  46.983  1
120324  96.733  -78.296  46.956  1
120325  96.753  -78.317  46.928  1
120326  96.773  -78.338  46.900  1
120327  96.793  -78.360  46.872  1
120328  96.813  -78.381  46.845  1
120329  96.833  -78.402  46.818  1
120330  96.856  -78.421  46.791  1
120331  96.882  -78.438  46.763  1
120332  96.908  -78.455  46.735  1
120333  96.934  -78.473  46.706  1
120334  96.960  -78.489  46.679  1
120335  96.986  -78.507  46.652  1
120336  97.012  -78.523  46.627  1
120337  97.037  -78.539  46.601  1
120338  97.041  -78.553  46.575  1
120339  97.051  -78.565  46.550  1
120340  97.062  -78.565  46.527  1
120341  97.070  -78.561  46.503  1
120342  97.079  -78.557  46.480  1
120343  97.140  -78.572  46.458  1
120344  97.223  -78.565  46.439  1
120345  97.304  -78.559  46.421  1
120346  97.363  -78.551  46.402  1
120347  97.389  -78.551  46.382  1
120348  97.430  -78.547  46.365  1
120349  97.441  -78.552  46.349  1
120350  97.483  -78.564  46.333  1
120351  97.545  -78.578  46.317  1
120352  97.608  -78.592  46.303  1
120353  97.671  -78.607  46.288  1
120354  97.721  -78.599  46.274  1
120355  97.747  -78.602  46.260  1
120356  97.753  -78.600  46.247  1
120357  97.777  -78.599  46.233  1
120358  97.811  -78.582  46.217  1
120359  97.853  -78.549  46.202  1
120360  97.888  -78.522  46.188  1
120361  97.935  -78.549  46.174  1
120362  97.941  -78.546  46.159  1
120363  97.969  -78.557  46.144  1
120364  97.997  -78.569  46.128  1
120365  98.025  -78.581  46.111  1
120366  98.053  -78.592  46.094  1
120367  98.080  -78.604  46.077  1
120368  98.108  -78.615  46.060  1
120369  98.092  -78.600  46.044  1
120370  98.098  -78.576  46.026  1
120371  98.103  -78.551  46.009  1
120372  98.108  -78.526  45.991  1
120373  98.134  -78.515  45.973  1
120374  98.142  -78.523  45.956  1
120375  98.145  -78.529  45.938  1
120376  98.151  -78.525  45.921  1
120377  98.158  -78.518  45.904  1
120378  98.166  -78.512  45.888  1
120379  98.173  -78.505  45.872  1
120380  98.180  -78.507  45.854  1
120381  98.185  -78.586  45.837  1
120382  98.197  -78.646  45.820  1
120383  98.223  -78.640  45.803  1
120384  98.251  -78.630  45.786  1
120385  98.279  -78.619  45.769  1
120386  98.306  -78.608  45.751  1
120387  98.334  -78.598  45.734  1
120388  98.361  -78.587  45.716  1
120389  98.376  -78.578  45.699  1
120390  98.367  -78.571  45.682  1
120391  98.365  -78.567  45.667  1
120392  98.366  -78.563  45.651  1
120393  98.366  -78.559  45.634  1
120394  98.366  -78.555  45.618  1
120395  98.366  -78.551  45.601  1
120396  98.383  -78.565  45.583  1
120397  98.400  -78.579  45.565  1
120398  98.413  -78.595  45.549  1
120399  98.412  -78.614  45.532  1
120400  98.413  -78.618  45.515  1
120401  98.420  -78.653  45.499  1
120402  98.437  -78.680  45.483  1
120403  98.467  -78.665  45.468  1
120404  98.497  -78.650  45.453  1
120405  98.526  -78.636  45.437  1
120406  98.553  -78.627  45.421  1
120407  98.577  -78.620  45.402  1
120408  98.601  -78.614  45.383  1
120409  98.623  -78.626  45.367  1
120410  98.645  -78.648  45.351  1
120411  98.666  -78.671  45.334  1
120412  98.692  -78.672  45.320  1
120413  98.734  -78.684  45.305  1
120414  98.781  -78.705  45.290  1
120415  98.827  -78.726  45.275  1
120416  98.866  -78.740  45.261  1
120417  98.883  -78.731  45.246  1
120418  98.887  -78.707  45.229  1
120419  98.917  -78.709  45.213  1
120420  98.945  -78.714  45.198  1
120421  98.971  -78.718  45.185  1
120422  98.998  -78.724  45.173  1
120423  99.024  -78.728  45.159  1
120424  99.020  -78.783  45.145  1
120425  99.008  -78.811  45.132  1
120426  98.997  -78.814  45.120  1
120427  99.010  -78.821  45.107  1
120428  99.022  -78.800  45.095  1
120429  99.030  -78.754  45.083  1
120430  99.044  -78.733  45.074  1
120431  99.062  -78.742  45.064  1
120432  99.074  -78.747  45.053  1
120433  99.082  -78.746  45.043  1
120434  99.089  -78.745  45.033  1
120435  99.101  -78.747  45.023  1
120436  99.128  -78.760  45.014  1
120437  99.186  -78.799  45.005  1
120438  99.238  -78.833  44.996  1
120439  99.267  -78.845  44.987  1
120440  99.296  -78.857  44.978  1
120441  99.327  -78.865  44.967  1
120442  99.371  -78.843  44.956  1
120443  99.416  -78.822  44.945  1
120444  99.454  -78.809  44.932  1
120445  99.487  -78.803  44.919  1
120446  99.527  -78.814  44.907  1
120447  99.534  -78.813  44.895  1
120448  99.540  -78.812  44.884  1
120449  99.547  -78.811  44.874  1
120450  99.574  -78.847  44.864  1
120451  99.606  -78.890  44.854  1
120452  99.637  -78.933  44.845  1
120453  99.669  -78.977  44.836  1
120454  99.701  -79.020  44.828  1
120455  99.722  -79.044  44.819  1
120456  99.742  -79.067  44.812  1
120457  99.762  -79.090  44.805  1
120458  99.782  -79.112  44.797  1
120459  99.805  -79.134  44.790  1
120460  99.829  -79.156  44.784  1
120461  99.852  -79.178  44.778  1
120462  99.875  -79.199  44.772  1
120463  99.898  -79.221  44.767  1
120464  99.883  -79.249  44.761  1
120465  99.860  -79.278  44.756  1
120466  99.915  -79.266  44.752  1
120467  99.972  -79.279  44.748  1
120468  100.010  -79.325  44.744  1
120469  100.034  -79.350  44.739  1
120470  100.058  -79.375  44.735  1
120471  100.090  -79.398  44.730  1
120472  100.144  -79.419  44.724  1
120473  100.167  -79.439  44.718  1
120474  100.205  -79.440  44.711  1
120475  100.236  -79.443  44.704  1
120476  100.264  -79.448  44.696  1
120477  100.291  -79.454  44.689  1
120478  100.318  -79.460  44.682  1
120479  100.345  -79.465  44.675  1
120480  100.373  -79.470  44.668  1
120481  100.400  -79.476  44.660  1
120482  100.427  -79.482  44.652  1
120483  100.455  -79.487  44.644  1
120484  100.485  -79.494  44.635  1
120485  100.524  -79.504  44.627  1
120486  100.562  -79.514  44.619  1
120487  100.600  -79.525  44.610  1
120488  100.639  -79.535  44.602  1
120489  100.677  -79.545  44.594  1
120490  100.716  -79.556  44.585  1
120491  100.755  -79.568  44.576  1
120492  100.793  -79.585  44.568  1
120493  100.833  -79.601  44.559  1
120494  100.872  -79.618  44.550  1
120495  100.911  -79.635  44.541  1
120496  100.951  -79.651  44.531  1
120497  100.990  -79.668  44.522  1
120498  101.029  -79.685  44.513  1
120499  101.068  -79.701  44.503  1
120500  101.107  -79.718  44.492  1
120501  101.146  -79.735  44.482  1
120502  101.186  -79.751  44.471  1
120503  101.225  -79.768  44.459  1
120504  101.264  -79.785  44.446  1
120505  101.303  -79.802  44.433  1
120506  101.342  -79.818  44.420  1
120507  101.382  -79.835  44.407  1
120508  101.420  -79.852  44.392  1
120509  101.465  -79.874  44.376  1
120510  101.554  -79.907  44.361  1
120511  101.576  -79.915  44.343  1
120512  101.600  -79.929  44.324  1
120513  101.626  -79.947  44.305  1
120514  101.653  -79.965  44.286  1
120515  101.680  -79.982  44.267  1
120516  101.706  -80.000  44.248  1
120517  101.733  -80.018  44.230  1
120518  101.759  -80.035  44.211  1
120519  101.786  -80.052  44.192  1
120520  101.813  -80.071  44.173  1
120848  94.390  -77.850  52.170  1
120849  94.415  -77.841  52.150  1
120850  94.433  -77.835  52.129  1
120851  94.443  -77.833  52.108  1
120852  94.456  -77.827  52.088  1
120853  94.470  -77.819  52.067  1
120854  94.484  -77.812  52.046  1
120855  94.498  -77.805  52.026  1
120856  94.512  -77.798  52.004  1
120857  94.526  -77.792  51.984  1
120858  94.540  -77.785  51.964  1
120859  94.554  -77.778  51.944  1
120860  94.568  -77.772  51.924  1
120861  94.583  -77.765  51.905  1
120862  94.597  -77.758  51.887  1
120863  94.611  -77.752  51.870  1
120864  94.617  -77.747  51.851  1
120865  94.618  -77.743  51.831  1
120866  94.619  -77.738  51.810  1
120867  94.620  -77.734  51.788  1
120868  94.622  -77.730  51.763  1
120869  94.623  -77.725  51.738  1
120870  94.628  -77.721  51.710  1
120871  94.642  -77.727  51.682  1
120872  94.656  -77.733  51.653  1
120873  94.670  -77.739  51.622  1
120874  94.683  -77.745  51.593  1
120875  94.697  -77.750  51.564  1
120876  94.709  -77.754  51.535  1
120877  94.722  -77.757  51.506  1
120878  94.738  -77.764  51.475  1
120879  94.755  -77.772  51.443  1
120880  94.772  -77.780  51.411  1
120881  94.787  -77.788  51.378  1
120882  94.799  -77.792  51.344  1
120883  94.810  -77.796  51.309  1
120884  94.822  -77.799  51.273  1
120885  94.865  -77.818  51.235  1
120886  94.889  -77.827  51.197  1
120887  94.906  -77.834  51.159  1
120888  94.916  -77.848  51.121  1
120889  94.901  -77.861  51.082  1
120890  94.912  -77.846  51.043  1
120891  94.922  -77.832  51.003  1
120892  94.935  -77.824  50.962  1
120893  94.951  -77.822  50.923  1
120894  94.967  -77.821  50.885  1
120895  94.983  -77.819  50.847  1
120896  94.998  -77.817  50.810  1
120897  95.014  -77.815  50.773  1
120898  95.030  -77.814  50.736  1
120899  95.046  -77.812  50.699  1
120900  95.060  -77.806  50.662  1
120901  95.070  -77.786  50.626  1
120902  95.079  -77.765  50.590  1
120903  95.093  -77.755  50.555  1
120904  95.110  -77.751  50.519  1
120905  95.126  -77.748  50.484  1
120906  95.142  -77.745  50.450  1
120907  95.159  -77.741  50.416  1
120908  95.175  -77.738  50.383  1
120909  95.191  -77.735  50.351  1
120910  95.208  -77.731  50.321  1
120911  95.225  -77.728  50.290  1
120912  95.241  -77.724  50.260  1
120913  95.257  -77.721  50.232  1
120914  95.275  -77.720  50.204  1
120915  95.292  -77.717  50.176  1
120916  95.309  -77.714  50.148  1
120917  95.326  -77.712  50.119  1
120918  95.343  -77.710  50.092  1
120919  95.359  -77.708  50.066  1
120920  95.377  -77.705  50.039  1
120921  95.394  -77.703  50.013  1
120922  95.427  -77.730  49.988  1
120923  95.457  -77.754  49.964  1
120924  95.461  -77.749  49.938  1
120925  95.465  -77.746  49.909  1
120926  95.469  -77.741  49.878  1
120927  95.473  -77.737  49.844  1
120928  95.518  -77.734  49.806  1
120929  95.547  -77.719  49.768  1
120930  95.539  -77.715  49.732  1
120931  95.560  -77.734  49.698  1
120932  95.586  -77.754  49.664  1
120933  95.612  -77.776  49.631  1
120934  95.624  -77.801  49.599  1
120935  95.601  -77.787  49.568  1
120936  95.551  -77.771  49.536  1
120937  95.603  -77.777  49.505  1
120938  95.689  -77.781  49.474  1
120939  95.735  -77.740  49.444  1
120940  95.714  -77.764  49.416  1
120941  95.735  -77.766  49.388  1
120942  95.756  -77.768  49.363  1
120943  95.758  -77.762  49.340  1
120944  95.760  -77.757  49.319  1
120945  95.762  -77.752  49.295  1
120946  95.766  -77.752  49.266  1
120947  95.773  -77.759  49.236  1
120948  95.781  -77.766  49.204  1
120949  95.789  -77.773  49.169  1
120950  95.799  -77.780  49.133  1
120951  95.816  -77.788  49.097  1
120952  95.833  -77.796  49.061  1
120953  95.850  -77.802  49.025  1
120954  95.863  -77.815  48.987  1
120955  95.872  -77.833  48.947  1
120956  95.881  -77.850  48.906  1
120957  95.890  -77.868  48.867  1
120958  95.905  -77.883  48.829  1
120959  95.926  -77.896  48.791  1
120960  95.947  -77.909  48.753  1
120961  95.968  -77.923  48.715  1
120962  95.989  -77.937  48.677  1
120963  96.007  -77.944  48.638  1
120964  96.018  -77.946  48.601  1
120965  96.031  -77.956  48.566  1
120966  96.037  -77.949  48.530  1
120967  96.042  -77.940  48.500  1
120968  96.047  -77.930  48.470  1
120969  96.056  -77.924  48.439  1
120970  96.069  -77.928  48.407  1
120971  96.083  -77.931  48.375  1
120972  96.096  -77.934  48.344  1
120973  96.109  -77.937  48.314  1
120974  96.122  -77.940  48.287  1
120975  96.130  -77.936  48.262  1
120976  96.137  -77.930  48.238  1
120977  96.145  -77.924  48.215  1
120978  96.151  -77.917  48.190  1
120979  96.166  -77.917  48.165  1
120980  96.182  -77.918  48.139  1
120981  96.198  -77.918  48.116  1
120982  96.215  -77.920  48.091  1
120983  96.244  -77.951  48.066  1
120984  96.274  -77.986  48.043  1
120985  96.277  -77.983  48.021  1
120986  96.281  -77.980  47.997  1
120987  96.296  -77.992  47.973  1
120988  96.313  -78.006  47.947  1
120989  96.329  -78.019  47.921  1
120990  96.345  -78.033  47.894  1
120991  96.362  -78.047  47.868  1
120992  96.378  -78.060  47.843  1
120993  96.386  -78.081  47.817  1
120994  96.390  -78.106  47.791  1
120995  96.393  -78.130  47.765  1
120996  96.397  -78.154  47.739  1
120997  96.400  -78.179  47.712  1
120998  96.411  -78.197  47.683  1
120999  96.424  -78.204  47.656  1
121000  96.426  -78.202  47.629  1
121001  96.427  -78.199  47.603  1
121002  96.433  -78.194  47.575  1
121003  96.446  -78.185  47.548  1
121004  96.460  -78.176  47.521  1
121005  96.473  -78.168  47.495  1
121006  96.486  -78.159  47.469  1
121007  96.500  -78.150  47.441  1
121008  96.513  -78.141  47.413  1
121009  96.529  -78.148  47.387  1
121010  96.545  -78.157  47.361  1
121011  96.561  -78.166  47.336  1
121012  96.578  -78.175  47.311  1
121013  96.593  -78.184  47.285  1
121014  96.598  -78.194  47.258  1
121015  96.601  -78.204  47.232  1
121016  96.604  -78.214  47.207  1
121017  96.607  -78.224  47.182  1
121018  96.611  -78.233  47.158  1
121019  96.614  -78.243  47.132  1
121020  96.635  -78.245  47.106  1
121021  96.655  -78.247  47.079  1
121022  96.675  -78.248  47.052  1
121023  96.696  -78.250  47.027  1
121024  96.710  -78.260  47.001  1
121025  96.730  -78.281  46.973  1
121026  96.750  -78.302  46.945  1
121027  96.770  -78.323  46.916  1
121028  96.790  -78.344  46.889  1
121029  96.810  -78.366  46.861  1
121030  96.830  -78.387  46.834  1
121031  96.853  -78.406  46.807  1
121032  96.879  -78.423  46.780  1
121033  96.905  -78.441  46.753  1
121034  96.932  -78.457  46.725  1
121035  96.957  -78.475  46.697  1
121036  96.983  -78.492  46.670  1
121037  97.010  -78.509  46.644  1
121038  97.035  -78.526  46.619  1
121039  97.061  -78.537  46.594  1
121040  97.072  -78.536  46.569  1
121041  97.080  -78.532  46.545  1
121042  97.089  -78.529  46.521  1
121043  97.097  -78.524  46.498  1
121044  97.131  -78.545  46.477  1
121045  97.213  -78.530  46.457  1
121046  97.282  -78.514  46.438  1
121047  97.362  -78.523  46.419  1
121048  97.383  -78.525  46.399  1
121049  97.404  -78.527  46.381  1
121050  97.450  -78.538  46.364  1
121051  97.511  -78.552  46.348  1
121052  97.571  -78.567  46.332  1
121053  97.632  -78.582  46.317  1
121054  97.691  -78.598  46.302  1
121055  97.722  -78.603  46.288  1
121056  97.747  -78.604  46.274  1
121057  97.772  -78.604  46.260  1
121058  97.797  -78.605  46.245  1
121059  97.825  -78.598  46.230  1
121060  97.867  -78.567  46.215  1
121061  97.899  -78.539  46.201  1
121062  97.917  -78.526  46.186  1
121063  97.971  -78.535  46.171  1
121064  97.992  -78.547  46.156  1
121065  98.017  -78.557  46.140  1
121066  98.044  -78.568  46.124  1
121067  98.072  -78.579  46.108  1
121068  98.100  -78.591  46.091  1
121069  98.128  -78.602  46.074  1
121070  98.119  -78.589  46.057  1
121071  98.124  -78.564  46.040  1
121072  98.129  -78.540  46.023  1
121073  98.135  -78.515  46.005  1
121074  98.131  -78.507  45.987  1
121075  98.137  -78.515  45.969  1
121076  98.145  -78.523  45.952  1
121077  98.148  -78.514  45.934  1
121078  98.151  -78.504  45.918  1
121079  98.158  -78.498  45.902  1
121080  98.166  -78.491  45.885  1
121081  98.173  -78.487  45.868  1
121082  98.180  -78.561  45.851  1
121083  98.211  -78.578  45.834  1
121084  98.230  -78.601  45.816  1
121085  98.257  -78.591  45.800  1
121086  98.285  -78.580  45.783  1
121087  98.312  -78.570  45.764  1
121088  98.340  -78.559  45.747  1
121089  98.367  -78.549  45.729  1
121090  98.359  -78.542  45.711  1
121091  98.350  -78.535  45.694  1
121092  98.347  -78.529  45.679  1
121093  98.347  -78.526  45.663  1
121094  98.347  -78.522  45.645  1
121095  98.364  -78.535  45.629  1
121096  98.381  -78.550  45.613  1
121097  98.398  -78.564  45.595  1
121098  98.415  -78.577  45.576  1
121099  98.420  -78.595  45.559  1
121100  98.420  -78.614  45.543  1
121101  98.420  -78.628  45.526  1
121102  98.426  -78.657  45.510  1
121103  98.450  -78.661  45.494  1
121104  98.479  -78.647  45.479  1
121105  98.507  -78.636  45.463  1
121106  98.533  -78.631  45.447  1
121107  98.562  -78.622  45.430  1
121108  98.590  -78.611  45.411  1
121109  98.614  -78.604  45.392  1
121110  98.637  -78.611  45.375  1
121111  98.658  -78.633  45.358  1
121112  98.679  -78.655  45.342  1
121113  98.701  -78.677  45.327  1
121114  98.725  -78.686  45.312  1
121115  98.758  -78.681  45.297  1
121116  98.801  -78.699  45.282  1
121117  98.831  -78.705  45.267  1
121118  98.851  -78.699  45.251  1
121119  98.882  -78.704  45.234  1
121120  98.914  -78.708  45.218  1
121121  98.945  -78.711  45.204  1
121122  98.975  -78.716  45.191  1
121123  99.002  -78.721  45.178  1
121124  99.028  -78.726  45.163  1
121125  99.025  -78.768  45.149  1
121126  99.012  -78.796  45.135  1
121127  99.000  -78.824  45.123  1
121128  99.005  -78.804  45.110  1
121129  99.014  -78.757  45.097  1
121130  99.022  -78.711  45.086  1
121131  99.040  -78.714  45.076  1
121132  99.057  -78.723  45.065  1
121133  99.072  -78.729  45.054  1
121134  99.079  -78.728  45.043  1
121135  99.086  -78.727  45.032  1
121136  99.094  -78.727  45.021  1
121137  99.120  -78.740  45.012  1
121138  99.178  -78.780  45.003  1
121139  99.235  -78.818  44.993  1
121140  99.268  -78.833  44.984  1
121141  99.303  -78.833  44.974  1
121142  99.346  -78.814  44.964  1
121143  99.378  -78.808  44.954  1
121144  99.411  -78.802  44.943  1
121145  99.443  -78.796  44.931  1
121146  99.482  -78.796  44.918  1
121147  99.537  -78.815  44.905  1
121148  99.551  -78.818  44.894  1
121149  99.557  -78.816  44.884  1
121150  99.563  -78.815  44.873  1
121151  99.587  -78.845  44.862  1
121152  99.619  -78.888  44.852  1
121153  99.651  -78.931  44.843  1
121154  99.683  -78.974  44.834  1
121155  99.713  -79.015  44.825  1
121156  99.733  -79.037  44.817  1
121157  99.753  -79.060  44.809  1
121158  99.773  -79.083  44.801  1
121159  99.793  -79.106  44.793  1
121160  99.813  -79.129  44.787  1
121161  99.835  -79.151  44.781  1
121162  99.858  -79.172  44.774  1
121163  99.881  -79.194  44.769  1
121164  99.905  -79.216  44.764  1
121165  99.895  -79.243  44.759  1
121166  99.886  -79.265  44.754  1
121167  99.968  -79.237  44.751  1
121168  100.028  -79.246  44.747  1
121169  100.066  -79.294  44.743  1
121170  100.099  -79.332  44.739  1
121171  100.123  -79.357  44.735  1
121172  100.148  -79.382  44.731  1
121173  100.157  -79.405  44.724  1
121174  100.184  -79.412  44.718  1
121175  100.211  -79.418  44.711  1
121176  100.239  -79.423  44.703  1
121177  100.266  -79.429  44.696  1
121178  100.293  -79.434  44.689  1
121179  100.321  -79.440  44.682  1
121180  100.348  -79.445  44.676  1
121181  100.375  -79.451  44.669  1
121182  100.403  -79.456  44.661  1
121183  100.430  -79.462  44.652  1
121184  100.457  -79.467  44.645  1
121185  100.492  -79.476  44.637  1
121186  100.530  -79.486  44.628  1
121187  100.569  -79.496  44.620  1
121188  100.607  -79.507  44.612  1
121189  100.645  -79.517  44.603  1
121190  100.684  -79.527  44.595  1
121191  100.722  -79.538  44.586  1
121192  100.762  -79.554  44.578  1
121193  100.801  -79.571  44.570  1
121194  100.840  -79.588  44.561  1
121195  100.879  -79.604  44.552  1
121196  100.919  -79.621  44.543  1
121197  100.958  -79.638  44.534  1
121198  100.997  -79.654  44.525  1
121199  101.036  -79.671  44.515  1
121200  101.075  -79.688  44.504  1
121201  101.115  -79.704  44.494  1
121202  101.154  -79.721  44.482  1
121203  101.193  -79.738  44.471  1
121204  101.232  -79.755  44.458  1
121205  101.271  -79.771  44.445  1
121206  101.311  -79.788  44.432  1
121207  101.350  -79.805  44.418  1
121208  101.385  -79.823  44.405  1
121209  101.417  -79.842  44.390  1
121210  101.489  -79.871  44.374  1
121211  101.555  -79.892  44.358  1
121212  101.577  -79.902  44.341  1
121213  101.594  -79.908  44.323  1
121214  101.613  -79.917  44.304  1
121215  101.640  -79.934  44.285  1
121216  101.667  -79.952  44.267  1
121217  101.693  -79.970  44.248  1
121218  101.720  -79.987  44.230  1
121219  101.746  -80.005  44.211  1
121220  101.773  -80.023  44.192  1
121221  101.799  -80.040  44.173  1
121548  94.367  -77.843  52.206  1
121549  94.392  -77.834  52.184  1
121550  94.417  -77.824  52.164  1
121551  94.441  -77.815  52.143  1
121552  94.454  -77.812  52.122  1
121553  94.465  -77.808  52.102  1
121554  94.479  -77.800  52.082  1
121555  94.493  -77.793  52.062  1
121556  94.507  -77.786  52.042  1
121557  94.521  -77.779  52.021  1
121558  94.535  -77.773  52.001  1
121559  94.549  -77.766  51.981  1
121560  94.563  -77.759  51.961  1
121561  94.578  -77.752  51.942  1
121562  94.592  -77.746  51.924  1
121563  94.606  -77.740  51.906  1
121564  94.620  -77.733  51.888  1
121565  94.630  -77.727  51.870  1
121566  94.631  -77.723  51.850  1
121567  94.632  -77.718  51.828  1
121568  94.633  -77.714  51.805  1
121569  94.634  -77.710  51.780  1
121570  94.635  -77.705  51.754  1
121571  94.632  -77.707  51.727  1
121572  94.645  -77.712  51.697  1
121573  94.658  -77.718  51.668  1
121574  94.672  -77.724  51.638  1
121575  94.685  -77.730  51.609  1
121576  94.699  -77.736  51.581  1
121577  94.712  -77.741  51.553  1
121578  94.725  -77.744  51.524  1
121579  94.742  -77.753  51.493  1
121580  94.759  -77.761  51.461  1
121581  94.774  -77.766  51.428  1
121582  94.788  -77.771  51.394  1
121583  94.800  -77.774  51.360  1
121584  94.812  -77.778  51.325  1
121585  94.824  -77.782  51.289  1
121586  94.858  -77.796  51.251  1
121587  94.875  -77.802  51.213  1
121588  94.891  -77.808  51.175  1
121589  94.904  -77.819  51.135  1
121590  94.915  -77.834  51.095  1
121591  94.915  -77.841  51.055  1
121592  94.921  -77.817  51.014  1
121593  94.945  -77.827  50.974  1
121594  94.961  -77.825  50.935  1
121595  94.976  -77.824  50.896  1
121596  94.992  -77.821  50.858  1
121597  95.008  -77.820  50.820  1
121598  95.024  -77.818  50.783  1
121599  95.039  -77.817  50.746  1
121600  95.054  -77.811  50.709  1
121601  95.063  -77.790  50.672  1
121602  95.073  -77.770  50.635  1
121603  95.084  -77.752  50.599  1
121604  95.100  -77.748  50.564  1
121605  95.117  -77.745  50.529  1
121606  95.133  -77.742  50.492  1
121607  95.149  -77.738  50.458  1
121608  95.166  -77.735  50.424  1
121609  95.182  -77.731  50.391  1
121610  95.198  -77.728  50.359  1
121611  95.215  -77.725  50.328  1
121612  95.232  -77.721  50.298  1
121613  95.248  -77.718  50.268  1
121614  95.264  -77.718  50.239  1
121615  95.282  -77.708  50.212  1
121616  95.289  -77.700  50.184  1
121617  95.300  -77.693  50.155  1
121618  95.315  -77.689  50.128  1
121619  95.330  -77.683  50.101  1
121620  95.345  -77.679  50.074  1
121621  95.359  -77.674  50.048  1
121622  95.375  -77.669  50.023  1
121623  95.405  -77.695  49.998  1
121624  95.440  -77.724  49.974  1
121625  95.469  -77.748  49.946  1
121626  95.473  -77.744  49.916  1
121627  95.477  -77.740  49.885  1
121628  95.481  -77.736  49.851  1
121629  95.537  -77.733  49.815  1
121630  95.582  -77.722  49.778  1
121631  95.568  -77.727  49.741  1
121632  95.547  -77.742  49.705  1
121633  95.565  -77.761  49.671  1
121634  95.590  -77.780  49.637  1
121635  95.606  -77.795  49.605  1
121636  95.556  -77.780  49.574  1
121637  95.548  -77.749  49.545  1
121638  95.593  -77.751  49.516  1
121639  95.671  -77.741  49.486  1
121640  95.759  -77.727  49.456  1
121641  95.738  -77.754  49.427  1
121642  95.743  -77.750  49.400  1
121643  95.745  -77.745  49.374  1
121644  95.747  -77.739  49.350  1
121645  95.749  -77.733  49.327  1
121646  95.754  -77.734  49.303  1
121647  95.761  -77.741  49.277  1
121648  95.768  -77.749  49.248  1
121649  95.776  -77.755  49.216  1
121650  95.783  -77.762  49.181  1
121651  95.793  -77.770  49.145  1
121652  95.810  -77.777  49.110  1
121653  95.828  -77.784  49.072  1
121654  95.845  -77.792  49.035  1
121655  95.863  -77.799  48.998  1
121656  95.874  -77.813  48.959  1
121657  95.883  -77.830  48.919  1
121658  95.892  -77.848  48.879  1
121659  95.907  -77.863  48.841  1
121660  95.928  -77.877  48.803  1
121661  95.949  -77.890  48.765  1
121662  95.970  -77.904  48.727  1
121663  95.991  -77.917  48.690  1
121664  96.012  -77.930  48.651  1
121665  96.027  -77.937  48.613  1
121666  96.037  -77.940  48.577  1
121667  96.047  -77.945  48.542  1
121668  96.053  -77.936  48.511  1
121669  96.058  -77.926  48.480  1
121670  96.063  -77.916  48.448  1
121671  96.076  -77.917  48.417  1
121672  96.089  -77.920  48.385  1
121673  96.102  -77.924  48.354  1
121674  96.115  -77.927  48.324  1
121675  96.128  -77.928  48.298  1
121676  96.135  -77.922  48.272  1
121677  96.142  -77.915  48.248  1
121678  96.149  -77.909  48.225  1
121679  96.155  -77.903  48.201  1
121680  96.166  -77.899  48.176  1
121681  96.182  -77.900  48.150  1
121682  96.198  -77.902  48.126  1
121683  96.219  -77.912  48.102  1
121684  96.250  -77.949  48.078  1
121685  96.281  -77.985  48.056  1
121686  96.290  -77.990  48.034  1
121687  96.293  -77.987  48.011  1
121688  96.296  -77.984  47.986  1
121689  96.312  -77.996  47.960  1
121690  96.328  -78.010  47.934  1
121691  96.344  -78.024  47.908  1
121692  96.361  -78.037  47.882  1
121693  96.378  -78.050  47.857  1
121694  96.388  -78.069  47.832  1
121695  96.392  -78.094  47.808  1
121696  96.395  -78.119  47.782  1
121697  96.399  -78.143  47.756  1
121698  96.402  -78.167  47.730  1
121699  96.406  -78.192  47.703  1
121700  96.418  -78.208  47.675  1
121701  96.419  -78.205  47.647  1
121702  96.428  -78.199  47.620  1
121703  96.441  -78.191  47.592  1
121704  96.454  -78.181  47.566  1
121705  96.467  -78.172  47.540  1
121706  96.481  -78.164  47.513  1
121707  96.494  -78.155  47.486  1
121708  96.508  -78.146  47.458  1
121709  96.521  -78.138  47.431  1
121710  96.535  -78.136  47.405  1
121711  96.551  -78.145  47.378  1
121712  96.568  -78.154  47.352  1
121713  96.584  -78.163  47.327  1
121714  96.598  -78.172  47.300  1
121715  96.605  -78.181  47.274  1
121716  96.608  -78.191  47.248  1
121717  96.611  -78.200  47.223  1
121718  96.615  -78.210  47.199  1
121719  96.618  -78.220  47.174  1
121720  96.625  -78.228  47.148  1
121721  96.646  -78.229  47.123  1
121722  96.667  -78.231  47.096  1
121723  96.687  -78.232  47.069  1
121724  96.704  -78.238  47.043  1
121725  96.719  -78.248  47.018  1
121726  96.728  -78.267  46.990  1
121727  96.747  -78.288  46.962  1
121728  96.767  -78.309  46.934  1
121729  96.787  -78.330  46.907  1
121730  96.807  -78.351  46.880  1
121731  96.827  -78.373  46.852  1
121732  96.851  -78.391  46.826  1
121733  96.877  -78.408  46.799  1
121734  96.902  -78.426  46.771  1
121735  96.929  -78.443  46.743  1
121736  96.955  -78.460  46.716  1
121737  96.980  -78.477  46.689  1
121738  97.008  -78.489  46.663  1
121739  97.036  -78.489  46.639  1
121740  97.065  -78.490  46.614  1
121741  97.080  -78.495  46.590  1
121742  97.092  -78.501  46.566  1
121743  97.104  -78.507  46.541  1
121744  97.116  -78.514  46.518  1
121745  97.124  -78.505  46.496  1
121746  97.187  -78.484  46.475  1
121747  97.268  -78.477  46.456  1
121748  97.360  -78.496  46.436  1
121749  97.382  -78.498  46.417  1
121750  97.429  -78.509  46.398  1
121751  97.489  -78.523  46.380  1
121752  97.547  -78.539  46.363  1
121753  97.590  -78.551  46.347  1
121754  97.632  -78.564  46.331  1
121755  97.674  -78.576  46.317  1
121756  97.721  -78.592  46.302  1
121757  97.767  -78.609  46.288  1
121758  97.792  -78.610  46.273  1
121759  97.816  -78.611  46.257  1
121760  97.841  -78.611  46.243  1
121761  97.880  -78.584  46.228  1
121762  97.911  -78.557  46.213  1
121763  97.922  -78.541  46.198  1
121764  97.946  -78.531  46.182  1
121765  97.996  -78.535  46.167  1
121766  98.055  -78.557  46.152  1
121767  98.064  -78.555  46.136  1
121768  98.092  -78.567  46.121  1
121769  98.120  -78.579  46.104  1
121770  98.148  -78.590  46.087  1
121771  98.145  -78.578  46.069  1
121772  98.150  -78.553  46.053  1
121773  98.156  -78.529  46.036  1
121774  98.148  -78.516  46.019  1
121775  98.141  -78.506  46.000  1
121776  98.148  -78.514  45.982  1
121777  98.156  -78.521  45.966  1
121778  98.169  -78.525  45.949  1
121779  98.168  -78.511  45.933  1
121780  98.166  -78.497  45.916  1
121781  98.164  -78.482  45.900  1
121782  98.166  -78.470  45.883  1
121783  98.193  -78.493  45.866  1
121784  98.224  -78.510  45.848  1
121785  98.242  -78.537  45.831  1
121786  98.264  -78.552  45.813  1
121787  98.291  -78.542  45.796  1
121788  98.318  -78.531  45.778  1
121789  98.346  -78.521  45.759  1
121790  98.352  -78.513  45.742  1
121791  98.342  -78.505  45.725  1
121792  98.333  -78.498  45.708  1
121793  98.329  -78.493  45.691  1
121794  98.345  -78.506  45.674  1
121795  98.362  -78.520  45.656  1
121796  98.379  -78.534  45.639  1
121797  98.396  -78.548  45.622  1
121798  98.413  -78.561  45.605  1
121799  98.429  -78.576  45.586  1
121800  98.428  -78.595  45.569  1
121801  98.428  -78.614  45.552  1
121802  98.427  -78.633  45.536  1
121803  98.432  -78.658  45.520  1
121804  98.462  -78.643  45.504  1
121805  98.488  -78.638  45.488  1
121806  98.514  -78.632  45.471  1
121807  98.539  -78.626  45.455  1
121808  98.568  -78.617  45.438  1
121809  98.600  -78.604  45.420  1
121810  98.627  -78.594  45.400  1
121811  98.650  -78.595  45.383  1
121812  98.671  -78.617  45.366  1
121813  98.693  -78.639  45.350  1
121814  98.714  -78.661  45.335  1
121815  98.735  -78.683  45.319  1
121816  98.758  -78.702  45.303  1
121817  98.788  -78.693  45.289  1
121818  98.818  -78.686  45.273  1
121819  98.839  -78.685  45.257  1
121820  98.875  -78.688  45.240  1
121821  98.908  -78.699  45.224  1
121822  98.941  -78.710  45.209  1
121823  98.973  -78.714  45.196  1
121824  99.004  -78.719  45.182  1
121825  99.032  -78.724  45.167  1
121826  99.030  -78.753  45.152  1
121827  99.012  -78.773  45.139  1
121828  98.992  -78.776  45.126  1
121829  98.998  -78.748  45.113  1
121830  99.006  -78.714  45.100  1
121831  99.017  -78.684  45.090  1
121832  99.035  -78.693  45.080  1
121833  99.069  -78.695  45.069  1
121834  99.076  -78.705  45.056  1
121835  99.085  -78.703  45.043  1
121836  99.094  -78.701  45.032  1
121837  99.106  -78.717  45.021  1
121838  99.126  -78.752  45.011  1
121839  99.178  -78.779  45.000  1
121840  99.230  -78.805  44.990  1
121841  99.271  -78.811  44.981  1
121842  99.303  -78.805  44.970  1
121843  99.336  -78.799  44.960  1
121844  99.368  -78.794  44.950  1
121845  99.401  -78.788  44.939  1
121846  99.433  -78.782  44.927  1
121847  99.481  -78.793  44.916  1
121848  99.535  -78.811  44.905  1
121849  99.567  -78.821  44.895  1
121850  99.574  -78.820  44.884  1
121851  99.580  -78.819  44.874  1
121852  99.601  -78.843  44.863  1
121853  99.633  -78.886  44.852  1
121854  99.664  -78.930  44.843  1
121855  99.696  -78.972  44.834  1
121856  99.724  -79.009  44.824  1
121857  99.744  -79.031  44.815  1
121858  99.764  -79.054  44.806  1
121859  99.784  -79.077  44.798  1
121860  99.804  -79.100  44.790  1
121861  99.824  -79.122  44.784  1
121862  99.844  -79.145  44.778  1
121863  99.865  -79.168  44.771  1
121864  99.889  -79.189  44.766  1
121865  99.912  -79.211  44.761  1
121866  99.906  -79.237  44.756  1
121867  99.938  -79.237  44.752  1
121868  100.020  -79.209  44.749  1
121869  100.064  -79.239  44.746  1
121870  100.095  -79.297  44.742  1
121871  100.127  -79.313  44.739  1
121872  100.133  -79.338  44.735  1
121873  100.140  -79.363  44.731  1
121874  100.159  -79.384  44.725  1
121875  100.187  -79.392  44.718  1
121876  100.214  -79.397  44.711  1
121877  100.242  -79.404  44.704  1
121878  100.269  -79.409  44.697  1
121879  100.296  -79.414  44.690  1
121880  100.323  -79.419  44.683  1
121881  100.351  -79.425  44.677  1
121882  100.378  -79.431  44.670  1
121883  100.405  -79.436  44.662  1
121884  100.432  -79.441  44.655  1
121885  100.460  -79.447  44.647  1
121886  100.498  -79.457  44.639  1
121887  100.537  -79.468  44.631  1
121888  100.575  -79.479  44.621  1
121889  100.614  -79.488  44.613  1
121890  100.652  -79.499  44.605  1
121891  100.691  -79.509  44.597  1
121892  100.730  -79.524  44.589  1
121893  100.769  -79.541  44.580  1
121894  100.809  -79.557  44.572  1
121895  100.847  -79.574  44.564  1
121896  100.887  -79.591  44.555  1
121897  100.926  -79.607  44.546  1
121898  100.965  -79.624  44.537  1
121899  101.004  -79.641  44.527  1
121900  101.044  -79.657  44.516  1
121901  101.082  -79.674  44.505  1
121902  101.122  -79.691  44.494  1
121903  101.161  -79.708  44.483  1
121904  101.200  -79.724  44.471  1
121905  101.240  -79.741  44.458  1
121906  101.279  -79.758  44.445  1
121907  101.317  -79.774  44.431  1
121908  101.350  -79.793  44.417  1
121909  101.382  -79.813  44.402  1
121910  101.421  -79.833  44.386  1
121911  101.512  -79.867  44.371  1
121912  101.554  -79.877  44.355  1
121913  101.578  -79.889  44.338  1
121914  101.595  -79.895  44.320  1
121915  101.612  -79.901  44.302  1
121916  101.628  -79.906  44.283  1
121917  101.653  -79.922  44.264  1
121918  101.680  -79.939  44.246  1
121919  101.707  -79.958  44.229  1
121920  101.734  -79.975  44.210  1
121921  101.760  -79.993  44.191  1
122248  94.343  -77.835  52.241  1
122249  94.368  -77.826  52.220  1
122250  94.393  -77.817  52.199  1
122251  94.418  -77.808  52.178  1
122252  94.443  -77.799  52.158  1
122253  94.464  -77.791  52.137  1
122254  94.474  -77.788  52.117  1
122255  94.488  -77.780  52.097  1
122256  94.502  -77.773  52.078  1
122257  94.516  -77.767  52.058  1
122258  94.530  -77.760  52.037  1
122259  94.544  -77.753  52.017  1
122260  94.558  -77.747  51.998  1
122261  94.573  -77.740  51.979  1
122262  94.587  -77.733  51.961  1
122263  94.601  -77.727  51.943  1
122264  94.615  -77.721  51.925  1
122265  94.629  -77.714  51.906  1
122266  94.642  -77.708  51.886  1
122267  94.644  -77.703  51.865  1
122268  94.645  -77.699  51.842  1
122269  94.646  -77.695  51.818  1
122270  94.646  -77.692  51.794  1
122271  94.642  -77.693  51.769  1
122272  94.639  -77.695  51.742  1
122273  94.648  -77.699  51.713  1
122274  94.662  -77.705  51.685  1
122275  94.675  -77.710  51.656  1
122276  94.688  -77.716  51.629  1
122277  94.702  -77.721  51.602  1
122278  94.715  -77.727  51.574  1
122279  94.729  -77.733  51.544  1
122280  94.744  -77.739  51.511  1
122281  94.759  -77.744  51.478  1
122282  94.774  -77.749  51.445  1
122283  94.789  -77.755  51.411  1
122284  94.802  -77.758  51.377  1
122285  94.813  -77.761  51.342  1
122286  94.825  -77.765  51.306  1
122287  94.843  -77.771  51.267  1
122288  94.860  -77.777  51.228  1
122289  94.877  -77.783  51.190  1
122290  94.892  -77.791  51.150  1
122291  94.903  -77.806  51.110  1
122292  94.913  -77.819  51.069  1
122293  94.920  -77.800  51.026  1
122294  94.949  -77.820  50.986  1
122295  94.970  -77.828  50.946  1
122296  94.986  -77.827  50.907  1
122297  95.001  -77.824  50.869  1
122298  95.017  -77.823  50.832  1
122299  95.033  -77.821  50.795  1
122300  95.047  -77.815  50.757  1
122301  95.057  -77.795  50.720  1
122302  95.067  -77.774  50.683  1
122303  95.076  -77.755  50.646  1
122304  95.091  -77.745  50.610  1
122305  95.107  -77.742  50.575  1
122306  95.123  -77.739  50.538  1
122307  95.140  -77.735  50.501  1
122308  95.157  -77.732  50.467  1
122309  95.173  -77.728  50.433  1
122310  95.189  -77.725  50.400  1
122311  95.205  -77.722  50.367  1
122312  95.222  -77.718  50.336  1
122313  95.241  -77.718  50.305  1
122314  95.258  -77.718  50.276  1
122315  95.266  -77.713  50.246  1
122316  95.291  -77.700  50.218  1
122317  95.301  -77.691  50.191  1
122318  95.308  -77.683  50.162  1
122319  95.316  -77.675  50.136  1
122320  95.327  -77.669  50.109  1
122321  95.342  -77.664  50.082  1
122322  95.357  -77.659  50.057  1
122323  95.372  -77.654  50.032  1
122324  95.395  -77.671  50.007  1
122325  95.419  -77.691  49.981  1
122326  95.451  -77.718  49.952  1
122327  95.482  -77.743  49.921  1
122328  95.486  -77.738  49.889  1
122329  95.490  -77.734  49.857  1
122330  95.557  -77.732  49.823  1
122331  95.617  -77.725  49.787  1
122332  95.597  -77.738  49.750  1
122333  95.577  -77.753  49.715  1
122334  95.555  -77.769  49.679  1
122335  95.570  -77.787  49.645  1
122336  95.567  -77.793  49.613  1
122337  95.551  -77.752  49.582  1
122338  95.584  -77.735  49.554  1
122339  95.628  -77.736  49.526  1
122340  95.673  -77.738  49.498  1
122341  95.732  -77.735  49.467  1
122342  95.731  -77.732  49.438  1
122343  95.733  -77.727  49.411  1
122344  95.735  -77.721  49.386  1
122345  95.737  -77.716  49.360  1
122346  95.741  -77.716  49.335  1
122347  95.749  -77.724  49.311  1
122348  95.756  -77.730  49.285  1
122349  95.763  -77.737  49.258  1
122350  95.771  -77.745  49.228  1
122351  95.778  -77.752  49.192  1
122352  95.788  -77.759  49.157  1
122353  95.805  -77.766  49.121  1
122354  95.822  -77.774  49.082  1
122355  95.840  -77.781  49.045  1
122356  95.857  -77.789  49.007  1
122357  95.875  -77.796  48.969  1
122358  95.886  -77.811  48.929  1
122359  95.894  -77.828  48.890  1
122360  95.909  -77.843  48.852  1
122361  95.930  -77.857  48.814  1
122362  95.951  -77.871  48.776  1
122363  95.972  -77.884  48.739  1
122364  95.991  -77.895  48.702  1
122365  96.010  -77.905  48.663  1
122366  96.028  -77.914  48.626  1
122367  96.041  -77.920  48.590  1
122368  96.052  -77.925  48.555  1
122369  96.062  -77.930  48.522  1
122370  96.068  -77.922  48.490  1
122371  96.074  -77.912  48.458  1
122372  96.082  -77.906  48.428  1
122373  96.095  -77.909  48.396  1
122374  96.108  -77.912  48.365  1
122375  96.122  -77.915  48.334  1
122376  96.132  -77.915  48.308  1
122377  96.139  -77.908  48.283  1
122378  96.146  -77.902  48.257  1
122379  96.153  -77.896  48.234  1
122380  96.159  -77.890  48.211  1
122381  96.166  -77.883  48.186  1
122382  96.182  -77.884  48.161  1
122383  96.198  -77.884  48.136  1
122384  96.225  -77.910  48.113  1
122385  96.256  -77.946  48.090  1
122386  96.287  -77.983  48.068  1
122387  96.302  -77.998  48.046  1
122388  96.306  -77.994  48.022  1
122389  96.309  -77.991  47.997  1
122390  96.312  -77.988  47.972  1
122391  96.327  -78.000  47.947  1
122392  96.344  -78.014  47.922  1
122393  96.361  -78.028  47.896  1
122394  96.377  -78.041  47.871  1
122395  96.390  -78.058  47.847  1
122396  96.393  -78.082  47.823  1
122397  96.397  -78.106  47.798  1
122398  96.400  -78.131  47.773  1
122399  96.404  -78.156  47.747  1
122400  96.407  -78.180  47.721  1
122401  96.411  -78.205  47.693  1
122402  96.421  -78.204  47.665  1
122403  96.435  -78.195  47.636  1
122404  96.448  -78.187  47.609  1
122405  96.462  -78.178  47.584  1
122406  96.475  -78.169  47.558  1
122407  96.488  -78.160  47.531  1
122408  96.502  -78.151  47.503  1
122409  96.515  -78.142  47.475  1
122410  96.528  -78.134  47.449  1
122411  96.542  -78.125  47.422  1
122412  96.558  -78.133  47.395  1
122413  96.574  -78.142  47.368  1
122414  96.590  -78.151  47.342  1
122415  96.602  -78.159  47.314  1
122416  96.612  -78.168  47.289  1
122417  96.615  -78.178  47.264  1
122418  96.619  -78.188  47.239  1
122419  96.622  -78.197  47.215  1
122420  96.625  -78.207  47.190  1
122421  96.638  -78.213  47.164  1
122422  96.658  -78.214  47.140  1
122423  96.678  -78.216  47.114  1
122424  96.698  -78.218  47.087  1
122425  96.712  -78.228  47.060  1
122426  96.726  -78.238  47.034  1
122427  96.737  -78.255  47.008  1
122428  96.746  -78.273  46.981  1
122429  96.764  -78.294  46.953  1
122430  96.784  -78.316  46.926  1
122431  96.804  -78.337  46.899  1
122432  96.824  -78.358  46.872  1
122433  96.848  -78.376  46.846  1
122434  96.874  -78.394  46.818  1
122435  96.900  -78.411  46.789  1
122436  96.926  -78.428  46.761  1
122437  96.952  -78.445  46.734  1
122438  96.980  -78.451  46.708  1
122439  97.009  -78.452  46.683  1
122440  97.036  -78.460  46.659  1
122441  97.063  -78.471  46.636  1
122442  97.090  -78.485  46.612  1
122443  97.112  -78.501  46.588  1
122444  97.124  -78.507  46.562  1
122445  97.136  -78.514  46.538  1
122446  97.157  -78.502  46.515  1
122447  97.198  -78.470  46.493  1
122448  97.266  -78.456  46.473  1
122449  97.357  -78.468  46.454  1
122450  97.404  -78.479  46.435  1
122451  97.446  -78.492  46.416  1
122452  97.488  -78.504  46.397  1
122453  97.530  -78.517  46.379  1
122454  97.573  -78.529  46.363  1
122455  97.615  -78.542  46.347  1
122456  97.657  -78.554  46.332  1
122457  97.699  -78.566  46.317  1
122458  97.754  -78.589  46.302  1
122459  97.811  -78.616  46.286  1
122460  97.836  -78.617  46.271  1
122461  97.861  -78.617  46.256  1
122462  97.894  -78.601  46.241  1
122463  97.923  -78.576  46.226  1
122464  97.934  -78.559  46.211  1
122465  97.945  -78.542  46.195  1
122466  97.974  -78.535  46.179  1
122467  98.024  -78.540  46.163  1
122468  98.075  -78.545  46.148  1
122469  98.112  -78.554  46.132  1
122470  98.139  -78.566  46.115  1
122471  98.167  -78.577  46.098  1
122472  98.171  -78.567  46.081  1
122473  98.177  -78.542  46.064  1
122474  98.169  -78.529  46.048  1
122475  98.161  -78.517  46.030  1
122476  98.152  -78.506  46.013  1
122477  98.158  -78.513  45.996  1
122478  98.167  -78.519  45.981  1
122479  98.180  -78.523  45.964  1
122480  98.192  -78.524  45.948  1
122481  98.189  -78.509  45.932  1
122482  98.187  -78.494  45.916  1
122483  98.188  -78.475  45.899  1
122484  98.212  -78.460  45.881  1
122485  98.238  -78.465  45.864  1
122486  98.256  -78.469  45.846  1
122487  98.274  -78.496  45.828  1
122488  98.297  -78.503  45.810  1
122489  98.325  -78.493  45.793  1
122490  98.344  -78.483  45.774  1
122491  98.335  -78.476  45.756  1
122492  98.325  -78.469  45.738  1
122493  98.333  -78.476  45.721  1
122494  98.344  -78.485  45.704  1
122495  98.360  -78.504  45.686  1
122496  98.377  -78.518  45.668  1
122497  98.394  -78.532  45.650  1
122498  98.411  -78.546  45.633  1
122499  98.428  -78.560  45.615  1
122500  98.437  -78.576  45.596  1
122501  98.436  -78.595  45.578  1
122502  98.436  -78.614  45.561  1
122503  98.435  -78.633  45.545  1
122504  98.443  -78.644  45.529  1
122505  98.468  -78.639  45.512  1
122506  98.495  -78.633  45.496  1
122507  98.520  -78.628  45.478  1
122508  98.546  -78.622  45.462  1
122509  98.575  -78.613  45.445  1
122510  98.606  -78.599  45.428  1
122511  98.638  -78.586  45.408  1
122512  98.663  -78.578  45.391  1
122513  98.685  -78.600  45.374  1
122514  98.706  -78.622  45.357  1
122515  98.728  -78.644  45.342  1
122516  98.750  -78.665  45.326  1
122517  98.761  -78.677  45.310  1
122518  98.787  -78.669  45.294  1
122519  98.817  -78.661  45.278  1
122520  98.834  -78.664  45.262  1
122521  98.852  -78.669  45.246  1
122522  98.891  -78.670  45.230  1
122523  98.929  -78.673  45.215  1
122524  98.962  -78.685  45.200  1
122525  98.996  -78.695  45.186  1
122526  99.029  -78.707  45.171  1
122527  99.020  -78.713  45.157  1
122528  98.991  -78.717  45.143  1
122529  98.991  -78.714  45.130  1
122530  99.007  -78.715  45.118  1
122531  99.018  -78.695  45.106  1
122532  99.041  -78.652  45.094  1
122533  99.088  -78.646  45.082  1
122534  99.125  -78.646  45.070  1
122535  99.093  -78.677  45.058  1
122536  99.095  -78.674  45.045  1
122537  99.107  -78.695  45.033  1
122538  99.120  -78.732  45.022  1
122539  99.134  -78.769  45.010  1
122540  99.184  -78.802  44.999  1
122541  99.221  -78.814  44.989  1
122542  99.260  -78.798  44.978  1
122543  99.292  -78.792  44.968  1
122544  99.325  -78.786  44.957  1
122545  99.357  -78.780  44.947  1
122546  99.390  -78.774  44.937  1
122547  99.424  -78.771  44.925  1
122548  99.479  -78.789  44.915  1
122549  99.534  -78.808  44.906  1
122550  99.584  -78.825  44.895  1
122551  99.591  -78.824  44.885  1
122552  99.597  -78.823  44.875  1
122553  99.615  -78.841  44.865  1
122554  99.646  -78.884  44.853  1
122555  99.678  -78.927  44.843  1
122556  99.710  -78.971  44.833  1
122557  99.734  -79.002  44.823  1
122558  99.755  -79.024  44.813  1
122559  99.775  -79.047  44.804  1
122560  99.795  -79.070  44.796  1
122561  99.815  -79.093  44.788  1
122562  99.835  -79.115  44.781  1
122563  99.855  -79.138  44.775  1
122564  99.875  -79.161  44.769  1
122565  99.895  -79.184  44.763  1
122566  99.918  -79.206  44.758  1
122567  99.918  -79.231  44.754  1
122568  99.991  -79.209  44.750  1
122569  100.017  -79.243  44.746  1
122570  100.056  -79.263  44.743  1
122571  100.095  -79.276  44.739  1
122572  100.118  -79.294  44.735  1
122573  100.124  -79.319  44.730  1
122574  100.132  -79.344  44.725  1
122575  100.161  -79.362  44.721  1
122576  100.190  -79.372  44.715  1
122577  100.217  -79.378  44.709  1
122578  100.244  -79.383  44.703  1
122579  100.271  -79.388  44.698  1
122580  100.298  -79.394  44.691  1
122581  100.326  -79.400  44.685  1
122582  100.353  -79.405  44.678  1
122583  100.381  -79.410  44.671  1
122584  100.408  -79.416  44.664  1
122585  100.435  -79.422  44.657  1
122586  100.467  -79.429  44.649  1
122587  100.505  -79.439  44.641  1
122588  100.544  -79.450  44.633  1
122589  100.582  -79.460  44.624  1
122590  100.621  -79.470  44.615  1
122591  100.659  -79.481  44.608  1
122592  100.698  -79.494  44.600  1
122593  100.738  -79.510  44.591  1
122594  100.776  -79.527  44.583  1
122595  100.816  -79.544  44.575  1
122596  100.855  -79.560  44.566  1
122597  100.894  -79.577  44.557  1
122598  100.933  -79.594  44.548  1
122599  100.973  -79.610  44.539  1
122600  101.011  -79.627  44.529  1
122601  101.051  -79.644  44.518  1
122602  101.090  -79.661  44.507  1
122603  101.129  -79.677  44.495  1
122604  101.169  -79.694  44.484  1
122605  101.208  -79.711  44.471  1
122606  101.247  -79.727  44.458  1
122607  101.282  -79.745  44.444  1
122608  101.315  -79.764  44.430  1
122609  101.347  -79.783  44.415  1
122610  101.379  -79.802  44.400  1
122611  101.445  -79.830  44.384  1
122612  101.517  -79.851  44.368  1
122613  101.553  -79.864  44.352  1
122614  101.579  -79.876  44.335  1
122615  101.596  -79.882  44.318  1
122616  101.612  -79.887  44.300  1
122617  101.629  -79.893  44.281  1
122618  101.646  -79.899  44.263  1
122619  101.667  -79.910  44.245  1
122620  101.694  -79.927  44.227  1
122621  101.721  -79.945  44.208  1
122622  101.747  -79.963  44.189  1
122948  94.320  -77.827  52.276  1
122949  94.345  -77.818  52.255  1
122950  94.369  -77.809  52.234  1
122951  94.395  -77.800  52.213  1
122952  94.419  -77.791  52.192  1
122953  94.445  -77.781  52.172  1
122954  94.469  -77.772  52.153  1
122955  94.484  -77.768  52.133  1
122956  94.497  -77.761  52.113  1
122957  94.511  -77.754  52.094  1
122958  94.525  -77.748  52.074  1
122959  94.539  -77.741  52.053  1
122960  94.553  -77.734  52.033  1
122961  94.568  -77.728  52.015  1
122962  94.582  -77.721  51.997  1
122963  94.596  -77.714  51.980  1
122964  94.610  -77.708  51.963  1
122965  94.624  -77.702  51.945  1
122966  94.638  -77.695  51.923  1
122967  94.653  -77.689  51.902  1
122968  94.657  -77.683  51.880  1
122969  94.657  -77.680  51.857  1
122970  94.656  -77.678  51.833  1
122971  94.653  -77.679  51.809  1
122972  94.649  -77.680  51.785  1
122973  94.646  -77.682  51.758  1
122974  94.651  -77.686  51.730  1
122975  94.665  -77.691  51.701  1
122976  94.678  -77.696  51.673  1
122977  94.691  -77.702  51.647  1
122978  94.700  -77.710  51.621  1
122979  94.709  -77.717  51.593  1
122980  94.725  -77.721  51.562  1
122981  94.741  -77.726  51.529  1
122982  94.757  -77.730  51.495  1
122983  94.772  -77.736  51.461  1
122984  94.788  -77.740  51.427  1
122985  94.809  -77.740  51.393  1
122986  94.825  -77.741  51.357  1
122987  94.841  -77.743  51.320  1
122988  94.837  -77.759  51.281  1
122989  94.837  -77.773  51.242  1
122990  94.858  -77.768  51.203  1
122991  94.879  -77.765  51.164  1
122992  94.891  -77.772  51.124  1
122993  94.902  -77.779  51.082  1
122994  94.924  -77.794  51.040  1
122995  94.952  -77.813  50.999  1
122996  94.979  -77.831  50.960  1
122997  94.995  -77.830  50.921  1
122998  95.011  -77.827  50.883  1
122999  95.027  -77.826  50.846  1
123000  95.041  -77.821  50.808  1
123001  95.051  -77.800  50.770  1
123002  95.060  -77.780  50.732  1
123003  95.070  -77.759  50.695  1
123004  95.082  -77.742  50.658  1
123005  95.098  -77.739  50.622  1
123006  95.114  -77.735  50.586  1
123007  95.130  -77.732  50.550  1
123008  95.147  -77.729  50.513  1
123009  95.164  -77.725  50.477  1
123010  95.180  -77.722  50.443  1
123011  95.196  -77.718  50.409  1
123012  95.214  -77.718  50.376  1
123013  95.234  -77.718  50.345  1
123014  95.251  -77.718  50.314  1
123015  95.257  -77.714  50.283  1
123016  95.273  -77.705  50.252  1
123017  95.299  -77.692  50.224  1
123018  95.312  -77.683  50.197  1
123019  95.319  -77.674  50.170  1
123020  95.327  -77.667  50.144  1
123021  95.334  -77.658  50.116  1
123022  95.342  -77.650  50.086  1
123023  95.354  -77.644  50.059  1
123024  95.369  -77.639  50.033  1
123025  95.391  -77.653  50.006  1
123026  95.415  -77.673  49.979  1
123027  95.440  -77.692  49.950  1
123028  95.464  -77.712  49.920  1
123029  95.494  -77.736  49.890  1
123030  95.498  -77.733  49.859  1
123031  95.577  -77.731  49.827  1
123032  95.639  -77.731  49.794  1
123033  95.621  -77.747  49.761  1
123034  95.602  -77.764  49.725  1
123035  95.584  -77.780  49.690  1
123036  95.563  -77.796  49.655  1
123037  95.561  -77.767  49.623  1
123038  95.576  -77.719  49.594  1
123039  95.620  -77.721  49.565  1
123040  95.665  -77.722  49.537  1
123041  95.709  -77.724  49.509  1
123042  95.732  -77.721  49.479  1
123043  95.720  -77.708  49.450  1
123044  95.722  -77.703  49.422  1
123045  95.724  -77.698  49.397  1
123046  95.729  -77.699  49.371  1
123047  95.736  -77.705  49.345  1
123048  95.743  -77.713  49.318  1
123049  95.751  -77.720  49.292  1
123050  95.758  -77.727  49.265  1
123051  95.766  -77.734  49.237  1
123052  95.773  -77.741  49.202  1
123053  95.782  -77.749  49.166  1
123054  95.800  -77.755  49.130  1
123055  95.817  -77.763  49.092  1
123056  95.834  -77.771  49.053  1
123057  95.852  -77.778  49.014  1
123058  95.869  -77.786  48.975  1
123059  95.886  -77.793  48.936  1
123060  95.897  -77.808  48.898  1
123061  95.911  -77.824  48.861  1
123062  95.932  -77.837  48.824  1
123063  95.953  -77.851  48.788  1
123064  95.971  -77.860  48.751  1
123065  95.989  -77.870  48.713  1
123066  96.007  -77.879  48.675  1
123067  96.026  -77.889  48.638  1
123068  96.045  -77.902  48.603  1
123069  96.056  -77.905  48.567  1
123070  96.067  -77.910  48.532  1
123071  96.078  -77.915  48.499  1
123072  96.084  -77.908  48.468  1
123073  96.089  -77.898  48.438  1
123074  96.101  -77.899  48.407  1
123075  96.115  -77.902  48.376  1
123076  96.128  -77.905  48.345  1
123077  96.136  -77.900  48.319  1
123078  96.143  -77.894  48.293  1
123079  96.150  -77.888  48.267  1
123080  96.157  -77.882  48.243  1
123081  96.163  -77.875  48.220  1
123082  96.170  -77.869  48.196  1
123083  96.181  -77.866  48.171  1
123084  96.199  -77.871  48.147  1
123085  96.231  -77.908  48.124  1
123086  96.261  -77.944  48.101  1
123087  96.293  -77.981  48.079  1
123088  96.315  -78.005  48.056  1
123089  96.318  -78.002  48.033  1
123090  96.321  -77.999  48.008  1
123091  96.324  -77.995  47.984  1
123092  96.327  -77.992  47.960  1
123093  96.343  -78.005  47.935  1
123094  96.360  -78.018  47.910  1
123095  96.376  -78.031  47.885  1
123096  96.392  -78.046  47.861  1
123097  96.395  -78.071  47.837  1
123098  96.399  -78.095  47.813  1
123099  96.402  -78.119  47.789  1
123100  96.406  -78.144  47.763  1
123101  96.409  -78.169  47.738  1
123102  96.417  -78.184  47.710  1
123103  96.424  -78.182  47.680  1
123104  96.436  -78.176  47.651  1
123105  96.453  -78.175  47.627  1
123106  96.469  -78.174  47.601  1
123107  96.483  -78.165  47.574  1
123108  96.496  -78.156  47.548  1
123109  96.510  -78.147  47.521  1
123110  96.523  -78.138  47.494  1
123111  96.536  -78.130  47.466  1
123112  96.549  -78.121  47.439  1
123113  96.564  -78.121  47.411  1
123114  96.581  -78.130  47.383  1
123115  96.594  -78.138  47.356  1
123116  96.606  -78.147  47.330  1
123117  96.618  -78.155  47.306  1
123118  96.623  -78.164  47.282  1
123119  96.626  -78.174  47.256  1
123120  96.629  -78.184  47.232  1
123121  96.632  -78.194  47.207  1
123122  96.649  -78.197  47.181  1
123123  96.670  -78.199  47.156  1
123124  96.690  -78.200  47.131  1
123125  96.705  -78.209  47.105  1
123126  96.719  -78.219  47.079  1
123127  96.733  -78.229  47.053  1
123128  96.745  -78.243  47.026  1
123129  96.755  -78.262  47.000  1
123130  96.764  -78.280  46.972  1
123131  96.781  -78.300  46.945  1
123132  96.801  -78.322  46.919  1
123133  96.821  -78.343  46.893  1
123134  96.845  -78.362  46.865  1
123135  96.871  -78.379  46.837  1
123136  96.897  -78.396  46.809  1
123137  96.923  -78.413  46.782  1
123138  96.952  -78.413  46.755  1
123139  96.979  -78.420  46.728  1
123140  97.006  -78.432  46.703  1
123141  97.033  -78.443  46.679  1
123142  97.060  -78.455  46.655  1
123143  97.087  -78.470  46.631  1
123144  97.114  -78.483  46.605  1
123145  97.140  -78.498  46.579  1
123146  97.156  -78.513  46.555  1
123147  97.171  -78.514  46.533  1
123148  97.220  -78.479  46.511  1
123149  97.283  -78.460  46.490  1
123150  97.346  -78.458  46.471  1
123151  97.391  -78.459  46.452  1
123152  97.429  -78.470  46.433  1
123153  97.471  -78.482  46.414  1
123154  97.513  -78.495  46.396  1
123155  97.556  -78.507  46.379  1
123156  97.598  -78.519  46.363  1
123157  97.640  -78.532  46.347  1
123158  97.682  -78.544  46.332  1
123159  97.727  -78.559  46.316  1
123160  97.787  -78.587  46.300  1
123161  97.847  -78.615  46.285  1
123162  97.881  -78.623  46.269  1
123163  97.908  -78.618  46.254  1
123164  97.935  -78.594  46.238  1
123165  97.946  -78.577  46.223  1
123166  97.957  -78.560  46.207  1
123167  97.967  -78.543  46.191  1
123168  98.003  -78.540  46.175  1
123169  98.054  -78.545  46.160  1
123170  98.103  -78.550  46.143  1
123171  98.154  -78.554  46.126  1
123172  98.187  -78.565  46.109  1
123173  98.198  -78.556  46.092  1
123174  98.191  -78.542  46.076  1
123175  98.182  -78.531  46.059  1
123176  98.173  -78.519  46.042  1
123177  98.164  -78.507  46.026  1
123178  98.168  -78.511  46.011  1
123179  98.179  -78.517  45.996  1
123180  98.192  -78.521  45.979  1
123181  98.205  -78.525  45.963  1
123182  98.212  -78.522  45.947  1
123183  98.210  -78.507  45.931  1
123184  98.216  -78.480  45.915  1
123185  98.234  -78.447  45.897  1
123186  98.252  -78.454  45.880  1
123187  98.263  -78.460  45.862  1
123188  98.285  -78.450  45.844  1
123189  98.306  -78.454  45.826  1
123190  98.331  -78.454  45.808  1
123191  98.327  -78.448  45.789  1
123192  98.335  -78.454  45.770  1
123193  98.343  -78.460  45.752  1
123194  98.352  -78.467  45.733  1
123195  98.364  -78.473  45.716  1
123196  98.376  -78.499  45.698  1
123197  98.392  -78.517  45.679  1
123198  98.409  -78.530  45.662  1
123199  98.426  -78.544  45.644  1
123200  98.443  -78.558  45.626  1
123201  98.444  -78.576  45.605  1
123202  98.444  -78.595  45.588  1
123203  98.444  -78.614  45.571  1
123204  98.453  -78.623  45.554  1
123205  98.463  -78.630  45.537  1
123206  98.476  -78.634  45.520  1
123207  98.501  -78.629  45.502  1
123208  98.527  -78.623  45.485  1
123209  98.553  -78.617  45.469  1
123210  98.581  -78.609  45.452  1
123211  98.613  -78.595  45.435  1
123212  98.645  -78.582  45.418  1
123213  98.676  -78.568  45.399  1
123214  98.698  -78.584  45.381  1
123215  98.721  -78.604  45.363  1
123216  98.744  -78.626  45.348  1
123217  98.767  -78.647  45.333  1
123218  98.768  -78.651  45.317  1
123219  98.786  -78.645  45.303  1
123220  98.816  -78.637  45.286  1
123221  98.829  -78.642  45.270  1
123222  98.840  -78.648  45.254  1
123223  98.867  -78.651  45.239  1
123224  98.907  -78.653  45.223  1
123225  98.947  -78.654  45.207  1
123226  98.984  -78.659  45.192  1
123227  99.017  -78.670  45.178  1
123228  99.017  -78.677  45.162  1
123229  99.014  -78.724  45.147  1
123230  99.038  -78.808  45.135  1
123231  99.041  -78.745  45.122  1
123232  99.035  -78.645  45.109  1
123233  99.048  -78.634  45.096  1
123234  99.111  -78.618  45.084  1
123235  99.174  -78.602  45.072  1
123236  99.124  -78.634  45.059  1
123237  99.102  -78.683  45.047  1
123238  99.110  -78.731  45.035  1
123239  99.116  -78.779  45.023  1
123240  99.125  -78.838  45.011  1
123241  99.166  -78.827  45.000  1
123242  99.209  -78.803  44.989  1
123243  99.249  -78.784  44.977  1
123244  99.282  -78.778  44.967  1
123245  99.314  -78.772  44.957  1
123246  99.347  -78.766  44.946  1
123247  99.379  -78.760  44.935  1
123248  99.423  -78.767  44.925  1
123249  99.478  -78.786  44.915  1
123250  99.533  -78.804  44.905  1
123251  99.587  -78.823  44.895  1
123252  99.608  -78.827  44.887  1
123253  99.614  -78.827  44.877  1
123254  99.628  -78.839  44.867  1
123255  99.660  -78.883  44.856  1
123256  99.692  -78.925  44.845  1
123257  99.723  -78.968  44.834  1
123258  99.746  -78.995  44.824  1
123259  99.766  -79.018  44.813  1
123260  99.786  -79.040  44.803  1
123261  99.805  -79.063  44.794  1
123262  99.826  -79.086  44.787  1
123263  99.846  -79.109  44.780  1
123264  99.866  -79.132  44.773  1
123265  99.886  -79.155  44.767  1
123266  99.906  -79.178  44.761  1
123267  99.926  -79.200  44.756  1
123268  99.946  -79.203  44.752  1
123269  99.977  -79.216  44.748  1
123270  100.017  -79.228  44.744  1
123271  100.056  -79.241  44.740  1
123272  100.096  -79.253  44.736  1
123273  100.109  -79.276  44.732  1
123274  100.115  -79.300  44.727  1
123275  100.134  -79.322  44.722  1
123276  100.163  -79.340  44.718  1
123277  100.192  -79.352  44.713  1
123278  100.219  -79.358  44.708  1
123279  100.247  -79.363  44.703  1
123280  100.274  -79.369  44.698  1
123281  100.301  -79.374  44.692  1
123282  100.329  -79.380  44.686  1
123283  100.356  -79.385  44.679  1
123284  100.383  -79.391  44.673  1
123285  100.410  -79.396  44.666  1
123286  100.438  -79.402  44.659  1
123287  100.474  -79.411  44.651  1
123288  100.512  -79.422  44.643  1
123289  100.551  -79.432  44.635  1
123290  100.589  -79.442  44.626  1
123291  100.628  -79.452  44.618  1
123292  100.666  -79.463  44.610  1
123293  100.705  -79.480  44.602  1
123294  100.745  -79.497  44.593  1
123295  100.784  -79.513  44.585  1
123296  100.823  -79.530  44.576  1
123297  100.862  -79.547  44.567  1
123298  100.901  -79.563  44.559  1
123299  100.940  -79.580  44.550  1
123300  100.980  -79.597  44.540  1
123301  101.019  -79.614  44.530  1
123302  101.058  -79.630  44.519  1
123303  101.098  -79.647  44.508  1
123304  101.137  -79.664  44.496  1
123305  101.176  -79.680  44.483  1
123306  101.215  -79.697  44.470  1
123307  101.247  -79.716  44.457  1
123308  101.280  -79.735  44.443  1
123309  101.312  -79.755  44.428  1
123310  101.345  -79.773  44.413  1
123311  101.377  -79.792  44.398  1
123312  101.470  -79.828  44.382  1
123313  101.522  -79.835  44.365  1
123314  101.551  -79.851  44.349  1
123315  101.580  -79.863  44.332  1
123316  101.596  -79.868  44.315  1
123317  101.613  -79.874  44.297  1
123318  101.630  -79.880  44.279  1
123319  101.646  -79.886  44.261  1
123320  101.664  -79.891  44.243  1
123321  101.681  -79.898  44.226  1
123322  101.707  -79.915  44.206  1
123323  101.734  -79.933  44.188  1
123619  93.982  -77.875  52.947  1
123620  93.980  -77.874  52.928  1
123621  93.978  -77.873  52.907  1
123622  93.975  -77.872  52.887  1
123623  93.973  -77.871  52.867  1
123624  93.970  -77.870  52.846  1
123625  93.968  -77.868  52.825  1
123626  93.967  -77.871  52.804  1
123627  93.971  -77.882  52.782  1
123628  93.974  -77.892  52.760  1
123629  93.977  -77.902  52.739  1
123630  93.981  -77.912  52.717  1
123631  93.992  -77.919  52.695  1
123648  94.296  -77.820  52.311  1
123649  94.321  -77.811  52.291  1
123650  94.346  -77.802  52.270  1
123651  94.371  -77.793  52.249  1
123652  94.396  -77.783  52.229  1
123653  94.421  -77.774  52.208  1
123654  94.446  -77.765  52.188  1
123655  94.471  -77.755  52.169  1
123656  94.495  -77.747  52.150  1
123657  94.506  -77.743  52.130  1
123658  94.520  -77.735  52.111  1
123659  94.534  -77.728  52.092  1
123660  94.548  -77.722  52.072  1
123661  94.563  -77.715  52.052  1
123662  94.577  -77.708  52.033  1
123663  94.591  -77.702  52.016  1
123664  94.605  -77.696  52.001  1
123665  94.619  -77.689  51.983  1
123666  94.633  -77.683  51.964  1
123667  94.648  -77.676  51.941  1
123668  94.662  -77.669  51.919  1
123669  94.669  -77.664  51.897  1
123670  94.667  -77.664  51.874  1
123671  94.664  -77.665  51.850  1
123672  94.660  -77.667  51.826  1
123673  94.657  -77.668  51.802  1
123674  94.653  -77.670  51.775  1
123675  94.654  -77.672  51.746  1
123676  94.664  -77.679  51.717  1
123677  94.673  -77.686  51.689  1
123678  94.682  -77.693  51.663  1
123679  94.691  -77.701  51.638  1
123680  94.705  -77.706  51.611  1
123681  94.720  -77.711  51.579  1
123682  94.736  -77.715  51.547  1
123683  94.752  -77.721  51.512  1
123684  94.774  -77.727  51.476  1
123685  94.793  -77.732  51.442  1
123686  94.802  -77.720  51.407  1
123687  94.828  -77.720  51.371  1
123688  94.854  -77.720  51.333  1
123689  94.856  -77.738  51.294  1
123690  94.849  -77.756  51.256  1
123691  94.842  -77.774  51.217  1
123692  94.843  -77.787  51.178  1
123693  94.868  -77.781  51.137  1
123694  94.894  -77.774  51.096  1
123695  94.913  -77.771  51.054  1
123696  94.956  -77.806  51.014  1
123697  94.984  -77.826  50.975  1
123698  95.004  -77.833  50.936  1
123699  95.020  -77.830  50.898  1
123700  95.035  -77.825  50.860  1
123701  95.044  -77.805  50.822  1
123702  95.054  -77.784  50.784  1
123703  95.064  -77.764  50.746  1
123704  95.074  -77.743  50.709  1
123705  95.089  -77.736  50.672  1
123706  95.105  -77.732  50.635  1
123707  95.121  -77.729  50.599  1
123708  95.137  -77.726  50.562  1
123709  95.154  -77.722  50.525  1
123710  95.170  -77.719  50.489  1
123711  95.188  -77.718  50.454  1
123712  95.208  -77.718  50.420  1
123713  95.227  -77.718  50.387  1
123714  95.245  -77.718  50.355  1
123715  95.250  -77.714  50.323  1
123716  95.256  -77.710  50.292  1
123717  95.281  -77.698  50.261  1
123718  95.306  -77.685  50.232  1
123719  95.323  -77.674  50.203  1
123720  95.330  -77.666  50.176  1
123721  95.338  -77.658  50.150  1
123722  95.345  -77.650  50.122  1
123723  95.353  -77.642  50.092  1
123724  95.360  -77.633  50.063  1
123725  95.368  -77.625  50.035  1
123726  95.387  -77.635  50.007  1
123727  95.411  -77.655  49.979  1
123728  95.436  -77.674  49.950  1
123729  95.460  -77.694  49.921  1
123730  95.484  -77.714  49.892  1
123731  95.523  -77.727  49.861  1
123732  95.631  -77.705  49.831  1
123733  95.635  -77.708  49.800  1
123734  95.626  -77.708  49.770  1
123735  95.617  -77.708  49.735  1
123736  95.606  -77.711  49.701  1
123737  95.592  -77.716  49.667  1
123738  95.578  -77.721  49.634  1
123739  95.610  -77.705  49.604  1
123740  95.633  -77.702  49.576  1
123741  95.656  -77.699  49.547  1
123742  95.679  -77.696  49.518  1
123743  95.702  -77.693  49.489  1
123744  95.721  -77.689  49.461  1
123745  95.711  -77.680  49.434  1
123746  95.716  -77.680  49.408  1
123747  95.724  -77.688  49.382  1
123748  95.731  -77.695  49.355  1
123749  95.738  -77.702  49.327  1
123750  95.746  -77.709  49.300  1
123751  95.753  -77.716  49.273  1
123752  95.760  -77.724  49.244  1
123753  95.768  -77.730  49.210  1
123754  95.777  -77.737  49.174  1
123755  95.795  -77.745  49.137  1
123756  95.812  -77.752  49.099  1
123757  95.829  -77.760  49.062  1
123758  95.846  -77.768  49.023  1
123759  95.864  -77.774  48.984  1
123760  95.881  -77.782  48.945  1
123761  95.898  -77.790  48.907  1
123762  95.913  -77.805  48.871  1
123763  95.933  -77.816  48.835  1
123764  95.951  -77.826  48.798  1
123765  95.971  -77.838  48.762  1
123766  95.990  -77.851  48.725  1
123767  96.011  -77.863  48.688  1
123768  96.031  -77.876  48.652  1
123769  96.051  -77.888  48.615  1
123770  96.066  -77.896  48.578  1
123771  96.073  -77.893  48.544  1
123772  96.082  -77.895  48.510  1
123773  96.093  -77.900  48.478  1
123774  96.100  -77.894  48.447  1
123775  96.107  -77.888  48.417  1
123776  96.121  -77.891  48.388  1
123777  96.133  -77.893  48.357  1
123778  96.140  -77.887  48.329  1
123779  96.147  -77.881  48.302  1
123780  96.154  -77.874  48.275  1
123781  96.161  -77.868  48.251  1
123782  96.168  -77.862  48.228  1
123783  96.174  -77.855  48.205  1
123784  96.181  -77.849  48.181  1
123785  96.205  -77.869  48.157  1
123786  96.236  -77.906  48.133  1
123787  96.267  -77.942  48.109  1
123788  96.299  -77.979  48.086  1
123789  96.327  -78.012  48.064  1
123790  96.331  -78.009  48.042  1
123791  96.334  -78.006  48.019  1
123792  96.337  -78.003  47.996  1
123793  96.340  -78.000  47.972  1
123794  96.343  -77.996  47.948  1
123795  96.359  -78.009  47.923  1
123796  96.375  -78.022  47.898  1
123797  96.392  -78.036  47.874  1
123798  96.397  -78.059  47.851  1
123799  96.400  -78.084  47.828  1
123800  96.404  -78.108  47.803  1
123801  96.408  -78.132  47.777  1
123802  96.414  -78.149  47.750  1
123803  96.425  -78.159  47.723  1
123804  96.433  -78.165  47.695  1
123805  96.436  -78.149  47.667  1
123806  96.446  -78.141  47.643  1
123807  96.463  -78.140  47.617  1
123808  96.480  -78.139  47.590  1
123809  96.497  -78.138  47.563  1
123810  96.514  -78.138  47.536  1
123811  96.530  -78.134  47.508  1
123812  96.544  -78.126  47.480  1
123813  96.557  -78.117  47.453  1
123814  96.571  -78.109  47.425  1
123815  96.586  -78.118  47.398  1
123816  96.599  -78.126  47.373  1
123817  96.611  -78.134  47.347  1
123818  96.623  -78.142  47.323  1
123819  96.630  -78.151  47.299  1
123820  96.633  -78.161  47.273  1
123821  96.637  -78.171  47.249  1
123822  96.641  -78.180  47.224  1
123823  96.661  -78.181  47.200  1
123824  96.681  -78.183  47.174  1
123825  96.699  -78.189  47.149  1
123826  96.713  -78.200  47.123  1
123827  96.726  -78.210  47.097  1
123828  96.740  -78.220  47.071  1
123829  96.753  -78.231  47.045  1
123830  96.763  -78.250  47.018  1
123831  96.772  -78.268  46.991  1
123832  96.783  -78.287  46.965  1
123833  96.798  -78.307  46.938  1
123834  96.818  -78.329  46.912  1
123835  96.842  -78.347  46.884  1
123836  96.868  -78.364  46.857  1
123837  96.895  -78.376  46.830  1
123838  96.923  -78.381  46.802  1
123839  96.950  -78.392  46.775  1
123840  96.977  -78.404  46.748  1
123841  97.004  -78.416  46.721  1
123842  97.030  -78.427  46.698  1
123843  97.058  -78.439  46.673  1
123844  97.084  -78.454  46.648  1
123845  97.111  -78.467  46.623  1
123846  97.138  -78.482  46.599  1
123847  97.165  -78.496  46.575  1
123848  97.185  -78.514  46.552  1
123849  97.234  -78.476  46.530  1
123850  97.276  -78.459  46.509  1
123851  97.332  -78.452  46.488  1
123852  97.394  -78.450  46.469  1
123853  97.426  -78.453  46.450  1
123854  97.454  -78.460  46.431  1
123855  97.496  -78.473  46.413  1
123856  97.538  -78.485  46.396  1
123857  97.581  -78.497  46.379  1
123858  97.623  -78.510  46.363  1
123859  97.665  -78.522  46.347  1
123860  97.707  -78.534  46.331  1
123861  97.760  -78.556  46.315  1
123862  97.820  -78.584  46.299  1
123863  97.880  -78.613  46.283  1
123864  97.925  -78.629  46.267  1
123865  97.947  -78.612  46.250  1
123866  97.958  -78.595  46.234  1
123867  97.968  -78.578  46.218  1
123868  97.980  -78.561  46.202  1
123869  97.991  -78.545  46.186  1
123870  98.032  -78.545  46.171  1
123871  98.082  -78.550  46.154  1
123872  98.133  -78.554  46.136  1
123873  98.182  -78.557  46.120  1
123874  98.212  -78.555  46.104  1
123875  98.203  -78.544  46.088  1
123876  98.195  -78.532  46.072  1
123877  98.185  -78.520  46.055  1
123878  98.177  -78.509  46.041  1
123879  98.178  -78.510  46.026  1
123880  98.190  -78.515  46.010  1
123881  98.203  -78.519  45.994  1
123882  98.217  -78.523  45.978  1
123883  98.230  -78.527  45.963  1
123884  98.233  -78.519  45.947  1
123885  98.243  -78.485  45.930  1
123886  98.260  -78.444  45.913  1
123887  98.267  -78.445  45.895  1
123888  98.271  -78.457  45.878  1
123889  98.291  -78.451  45.860  1
123890  98.313  -78.442  45.841  1
123891  98.334  -78.433  45.822  1
123892  98.345  -78.438  45.803  1
123893  98.353  -78.445  45.783  1
123894  98.361  -78.451  45.764  1
123895  98.371  -78.458  45.746  1
123896  98.383  -78.465  45.728  1
123897  98.395  -78.480  45.709  1
123898  98.408  -78.512  45.690  1
123899  98.424  -78.529  45.672  1
123900  98.441  -78.542  45.653  1
123901  98.453  -78.557  45.635  1
123902  98.452  -78.576  45.615  1
123903  98.455  -78.592  45.597  1
123904  98.465  -78.598  45.580  1
123905  98.476  -78.605  45.562  1
123906  98.486  -78.612  45.545  1
123907  98.497  -78.619  45.527  1
123908  98.508  -78.624  45.509  1
123909  98.534  -78.619  45.492  1
123910  98.560  -78.614  45.476  1
123911  98.588  -78.604  45.459  1
123912  98.620  -78.591  45.442  1
123913  98.651  -78.577  45.425  1
123914  98.675  -78.564  45.407  1
123915  98.710  -78.567  45.389  1
123916  98.737  -78.586  45.371  1
123917  98.760  -78.608  45.356  1
123918  98.783  -78.629  45.341  1
123919  98.775  -78.627  45.326  1
123920  98.785  -78.620  45.312  1
123921  98.812  -78.614  45.296  1
123922  98.823  -78.621  45.279  1
123923  98.835  -78.627  45.263  1
123924  98.846  -78.633  45.248  1
123925  98.883  -78.635  45.232  1
123926  98.923  -78.636  45.216  1
123927  98.962  -78.636  45.200  1
123928  99.002  -78.638  45.185  1
123929  99.028  -78.665  45.168  1
123930  99.043  -78.737  45.152  1
123931  99.043  -78.682  45.140  1
123932  99.038  -78.590  45.126  1
123933  99.025  -78.602  45.112  1
123934  99.057  -78.620  45.098  1
123935  99.094  -78.617  45.086  1
123936  99.147  -78.608  45.073  1
123937  99.186  -78.604  45.060  1
123938  99.119  -78.651  45.049  1
123939  99.118  -78.717  45.037  1
123940  99.118  -78.783  45.026  1
123941  99.114  -78.838  45.014  1
123942  99.153  -78.816  45.002  1
123943  99.196  -78.793  44.991  1
123944  99.238  -78.770  44.980  1
123945  99.271  -78.764  44.970  1
123946  99.304  -78.758  44.959  1
123947  99.336  -78.752  44.948  1
123948  99.369  -78.746  44.938  1
123949  99.422  -78.763  44.928  1
123950  99.476  -78.782  44.917  1
123951  99.531  -78.801  44.907  1
123952  99.585  -78.819  44.896  1
123953  99.625  -78.831  44.887  1
123954  99.631  -78.830  44.878  1
123955  99.642  -78.837  44.868  1
123956  99.674  -78.880  44.857  1
123957  99.705  -78.924  44.846  1
123958  99.736  -78.965  44.835  1
123959  99.756  -78.988  44.823  1
123960  99.776  -79.011  44.812  1
123961  99.796  -79.034  44.803  1
123962  99.817  -79.057  44.794  1
123963  99.837  -79.080  44.786  1
123964  99.857  -79.103  44.779  1
123965  99.877  -79.125  44.772  1
123966  99.897  -79.148  44.766  1
123967  99.917  -79.171  44.760  1
123968  99.933  -79.187  44.755  1
123969  99.938  -79.180  44.750  1
123970  99.978  -79.193  44.746  1
123971  100.018  -79.206  44.742  1
123972  100.057  -79.219  44.738  1
123973  100.093  -79.233  44.734  1
123974  100.099  -79.257  44.730  1
123975  100.107  -79.281  44.726  1
123976  100.136  -79.300  44.721  1
123977  100.166  -79.318  44.717  1
123978  100.195  -79.332  44.713  1
123979  100.222  -79.338  44.708  1
123980  100.249  -79.344  44.703  1
123981  100.276  -79.349  44.697  1
123982  100.304  -79.354  44.692  1
123983  100.331  -79.360  44.687  1
123984  100.358  -79.366  44.681  1
123985  100.385  -79.371  44.674  1
123986  100.413  -79.376  44.668  1
123987  100.442  -79.382  44.660  1
123988  100.481  -79.393  44.653  1
123989  100.519  -79.404  44.645  1
123990  100.558  -79.413  44.637  1
123991  100.596  -79.424  44.630  1
123992  100.635  -79.435  44.621  1
123993  100.674  -79.450  44.612  1
123994  100.713  -79.466  44.604  1
123995  100.752  -79.483  44.595  1
123996  100.791  -79.500  44.587  1
123997  100.830  -79.516  44.578  1
123998  100.869  -79.533  44.569  1
123999  100.909  -79.550  44.560  1
124000  100.948  -79.567  44.551  1
124001  100.987  -79.583  44.541  1
124002  101.027  -79.600  44.530  1
124003  101.065  -79.617  44.519  1
124004  101.105  -79.633  44.508  1
124005  101.144  -79.650  44.495  1
124006  101.180  -79.667  44.482  1
124007  101.212  -79.687  44.469  1
124008  101.245  -79.706  44.455  1
124009  101.277  -79.725  44.441  1
124010  101.310  -79.744  44.426  1
124011  101.342  -79.764  44.411  1
124012  101.401  -79.789  44.396  1
124013  101.475  -79.811  44.379  1
124014  101.527  -79.818  44.362  1
124015  101.550  -79.837  44.345  1
124016  101.581  -79.850  44.328  1
124017  101.597  -79.855  44.312  1
124018  101.614  -79.861  44.294  1
124019  101.631  -79.867  44.276  1
124020  101.647  -79.872  44.258  1
124021  101.664  -79.878  44.241  1
124022  101.681  -79.883  44.223  1
124023  101.698  -79.889  44.205  1
124024  101.721  -79.902  44.186  1
124317  93.944  -77.877  53.018  1
124318  93.958  -77.873  52.998  1
124319  93.970  -77.868  52.978  1
124320  93.983  -77.864  52.958  1
124321  93.980  -77.863  52.938  1
124322  93.978  -77.862  52.918  1
124323  93.976  -77.861  52.898  1
124324  93.973  -77.860  52.878  1
124325  93.971  -77.859  52.857  1
124326  93.968  -77.858  52.837  1
124327  93.967  -77.859  52.816  1
124328  93.970  -77.868  52.793  1
124329  93.973  -77.879  52.771  1
124330  93.977  -77.889  52.750  1
124331  93.980  -77.899  52.729  1
124332  93.995  -77.904  52.707  1
124333  94.011  -77.909  52.685  1
124334  94.027  -77.912  52.663  1
124335  94.043  -77.917  52.639  1
124336  94.059  -77.921  52.617  1
124337  94.062  -77.915  52.595  1
124338  94.063  -77.906  52.571  1
124348  94.273  -77.812  52.347  1
124349  94.297  -77.803  52.327  1
124350  94.323  -77.794  52.306  1
124351  94.348  -77.784  52.285  1
124352  94.372  -77.775  52.265  1
124353  94.398  -77.766  52.245  1
124354  94.422  -77.757  52.225  1
124355  94.448  -77.748  52.205  1
124356  94.472  -77.739  52.186  1
124357  94.497  -77.730  52.167  1
124358  94.516  -77.724  52.149  1
124359  94.529  -77.716  52.130  1
124360  94.543  -77.709  52.111  1
124361  94.558  -77.703  52.092  1
124362  94.572  -77.696  52.073  1
124363  94.586  -77.689  52.055  1
124364  94.600  -77.683  52.037  1
124365  94.614  -77.677  52.019  1
124366  94.628  -77.670  52.001  1
124367  94.643  -77.664  51.981  1
124368  94.663  -77.655  51.958  1
124369  94.684  -77.646  51.936  1
124370  94.669  -77.651  51.914  1
124371  94.666  -77.653  51.892  1
124372  94.662  -77.655  51.868  1
124373  94.657  -77.656  51.844  1
124374  94.653  -77.658  51.821  1
124375  94.649  -77.659  51.793  1
124376  94.649  -77.664  51.765  1
124377  94.654  -77.670  51.736  1
124378  94.664  -77.677  51.708  1
124379  94.672  -77.685  51.682  1
124380  94.684  -77.691  51.655  1
124381  94.700  -77.696  51.627  1
124382  94.716  -77.701  51.595  1
124383  94.739  -77.708  51.560  1
124384  94.761  -77.714  51.525  1
124385  94.782  -77.721  51.489  1
124386  94.792  -77.716  51.454  1
124387  94.793  -77.700  51.419  1
124388  94.819  -77.700  51.383  1
124389  94.846  -77.701  51.345  1
124390  94.873  -77.732  51.307  1
124391  94.873  -77.752  51.269  1
124392  94.836  -77.767  51.230  1
124393  94.855  -77.778  51.191  1
124394  94.866  -77.771  51.151  1
124395  94.891  -77.765  51.111  1
124396  94.912  -77.761  51.071  1
124397  94.924  -77.759  51.031  1
124398  94.981  -77.812  50.992  1
124399  95.014  -77.835  50.953  1
124400  95.028  -77.830  50.914  1
124401  95.038  -77.809  50.876  1
124402  95.048  -77.789  50.838  1
124403  95.057  -77.768  50.799  1
124404  95.067  -77.748  50.761  1
124405  95.079  -77.733  50.723  1
124406  95.096  -77.729  50.686  1
124407  95.112  -77.726  50.649  1
124408  95.128  -77.722  50.612  1
124409  95.144  -77.719  50.575  1
124410  95.162  -77.717  50.537  1
124411  95.181  -77.717  50.501  1
124412  95.201  -77.718  50.466  1
124413  95.220  -77.718  50.432  1
124414  95.238  -77.718  50.398  1
124415  95.244  -77.714  50.365  1
124416  95.249  -77.710  50.333  1
124417  95.263  -77.702  50.301  1
124418  95.288  -77.690  50.270  1
124419  95.314  -77.677  50.240  1
124420  95.334  -77.665  50.210  1
124421  95.341  -77.658  50.182  1
124422  95.349  -77.649  50.155  1
124423  95.356  -77.641  50.128  1
124424  95.364  -77.633  50.099  1
124425  95.372  -77.625  50.068  1
124426  95.379  -77.617  50.038  1
124427  95.420  -77.592  50.009  1
124428  95.453  -77.603  49.979  1
124429  95.483  -77.617  49.951  1
124430  95.513  -77.632  49.923  1
124431  95.543  -77.646  49.895  1
124432  95.570  -77.661  49.865  1
124433  95.605  -77.671  49.836  1
124434  95.618  -77.677  49.807  1
124435  95.609  -77.677  49.778  1
124436  95.600  -77.677  49.745  1
124437  95.591  -77.677  49.712  1
124438  95.582  -77.677  49.678  1
124439  95.596  -77.680  49.645  1
124440  95.608  -77.688  49.615  1
124441  95.624  -77.683  49.585  1
124442  95.640  -77.677  49.556  1
124443  95.657  -77.671  49.527  1
124444  95.673  -77.666  49.498  1
124445  95.694  -77.662  49.471  1
124446  95.703  -77.663  49.444  1
124447  95.711  -77.670  49.419  1
124448  95.719  -77.677  49.392  1
124449  95.726  -77.684  49.365  1
124450  95.733  -77.691  49.337  1
124451  95.741  -77.699  49.310  1
124452  95.748  -77.705  49.282  1
124453  95.755  -77.712  49.252  1
124454  95.763  -77.720  49.218  1
124455  95.772  -77.727  49.182  1
124456  95.789  -77.734  49.145  1
124457  95.807  -77.742  49.107  1
124458  95.824  -77.749  49.069  1
124459  95.841  -77.756  49.031  1
124460  95.859  -77.764  48.993  1
124461  95.876  -77.771  48.955  1
124462  95.893  -77.779  48.917  1
124463  95.915  -77.788  48.881  1
124464  95.936  -77.800  48.845  1
124465  95.956  -77.812  48.808  1
124466  95.976  -77.825  48.772  1
124467  95.996  -77.837  48.736  1
124468  96.016  -77.850  48.700  1
124469  96.036  -77.862  48.663  1
124470  96.056  -77.875  48.627  1
124471  96.077  -77.887  48.589  1
124472  96.085  -77.887  48.555  1
124473  96.092  -77.884  48.521  1
124474  96.098  -77.881  48.488  1
124475  96.108  -77.885  48.457  1
124476  96.115  -77.880  48.427  1
124477  96.127  -77.881  48.398  1
124478  96.137  -77.879  48.368  1
124479  96.144  -77.873  48.340  1
124480  96.151  -77.866  48.312  1
124481  96.158  -77.860  48.285  1
124482  96.165  -77.854  48.260  1
124483  96.172  -77.848  48.235  1
124484  96.178  -77.846  48.212  1
124485  96.185  -77.845  48.188  1
124486  96.212  -77.869  48.165  1
124487  96.242  -77.903  48.141  1
124488  96.273  -77.940  48.118  1
124489  96.304  -77.977  48.094  1
124490  96.335  -78.013  48.072  1
124491  96.343  -78.016  48.049  1
124492  96.346  -78.013  48.027  1
124493  96.349  -78.010  48.005  1
124494  96.353  -78.006  47.982  1
124495  96.356  -78.003  47.958  1
124496  96.359  -78.000  47.933  1
124497  96.375  -78.013  47.909  1
124498  96.391  -78.026  47.887  1
124499  96.399  -78.047  47.865  1
124500  96.402  -78.072  47.842  1
124501  96.406  -78.097  47.817  1
124502  96.412  -78.114  47.791  1
124503  96.422  -78.124  47.763  1
124504  96.432  -78.134  47.736  1
124505  96.442  -78.144  47.709  1
124506  96.446  -78.131  47.683  1
124507  96.449  -78.116  47.658  1
124508  96.456  -78.104  47.632  1
124509  96.473  -78.103  47.605  1
124510  96.490  -78.103  47.578  1
124511  96.507  -78.103  47.550  1
124512  96.524  -78.102  47.521  1
124513  96.541  -78.101  47.493  1
124514  96.558  -78.100  47.466  1
124515  96.576  -78.100  47.439  1
124516  96.591  -78.105  47.414  1
124517  96.603  -78.113  47.389  1
124518  96.615  -78.122  47.365  1
124519  96.627  -78.129  47.340  1
124520  96.637  -78.138  47.315  1
124521  96.641  -78.148  47.290  1
124522  96.644  -78.158  47.266  1
124523  96.653  -78.165  47.241  1
124524  96.673  -78.166  47.217  1
124525  96.692  -78.169  47.192  1
124526  96.706  -78.180  47.167  1
124527  96.720  -78.190  47.142  1
124528  96.733  -78.200  47.116  1
124529  96.747  -78.210  47.090  1
124530  96.761  -78.221  47.063  1
124531  96.771  -78.238  47.036  1
124532  96.781  -78.257  47.010  1
124533  96.791  -78.275  46.984  1
124534  96.800  -78.294  46.957  1
124535  96.815  -78.314  46.930  1
124536  96.839  -78.332  46.903  1
124537  96.867  -78.341  46.877  1
124538  96.894  -78.353  46.850  1
124539  96.921  -78.364  46.822  1
124540  96.947  -78.376  46.795  1
124541  96.974  -78.388  46.768  1
124542  97.001  -78.399  46.739  1
124543  97.028  -78.411  46.715  1
124544  97.054  -78.424  46.691  1
124545  97.082  -78.438  46.666  1
124546  97.108  -78.452  46.642  1
124547  97.136  -78.466  46.620  1
124548  97.163  -78.480  46.597  1
124549  97.195  -78.492  46.574  1
124550  97.237  -78.481  46.552  1
124551  97.279  -78.464  46.529  1
124552  97.320  -78.448  46.507  1
124553  97.381  -78.444  46.485  1
124554  97.438  -78.443  46.467  1
124555  97.461  -78.448  46.448  1
124556  97.484  -78.452  46.429  1
124557  97.521  -78.463  46.413  1
124558  97.563  -78.475  46.396  1
124559  97.605  -78.487  46.379  1
124560  97.648  -78.500  46.363  1
124561  97.690  -78.512  46.347  1
124562  97.733  -78.526  46.331  1
124563  97.793  -78.554  46.314  1
124564  97.853  -78.582  46.297  1
124565  97.913  -78.610  46.281  1
124566  97.949  -78.620  46.264  1
124567  97.962  -78.605  46.247  1
124568  97.975  -78.590  46.231  1
124569  97.988  -78.576  46.214  1
124570  98.000  -78.561  46.197  1
124571  98.013  -78.546  46.181  1
124572  98.059  -78.544  46.164  1
124573  98.107  -78.543  46.147  1
124574  98.156  -78.540  46.131  1
124575  98.205  -78.516  46.116  1
124576  98.209  -78.528  46.100  1
124577  98.207  -78.534  46.085  1
124578  98.198  -78.522  46.071  1
124579  98.190  -78.510  46.055  1
124580  98.189  -78.509  46.040  1
124581  98.202  -78.514  46.025  1
124582  98.215  -78.517  46.010  1
124583  98.228  -78.521  45.994  1
124584  98.241  -78.526  45.979  1
124585  98.253  -78.529  45.964  1
124586  98.265  -78.493  45.947  1
124587  98.276  -78.453  45.929  1
124588  98.282  -78.438  45.912  1
124589  98.285  -78.448  45.894  1
124590  98.296  -78.452  45.876  1
124591  98.319  -78.435  45.858  1
124592  98.339  -78.431  45.838  1
124593  98.357  -78.432  45.819  1
124594  98.371  -78.436  45.798  1
124595  98.379  -78.443  45.778  1
124596  98.391  -78.449  45.759  1
124597  98.402  -78.467  45.740  1
124598  98.415  -78.480  45.721  1
124599  98.427  -78.493  45.702  1
124600  98.439  -78.525  45.682  1
124601  98.455  -78.540  45.663  1
124602  98.461  -78.557  45.645  1
124603  98.468  -78.568  45.625  1
124604  98.479  -78.574  45.607  1
124605  98.489  -78.581  45.589  1
124606  98.499  -78.588  45.571  1
124607  98.509  -78.595  45.553  1
124608  98.520  -78.601  45.535  1
124609  98.530  -78.608  45.517  1
124610  98.541  -78.614  45.499  1
124611  98.567  -78.609  45.482  1
124612  98.594  -78.601  45.465  1
124613  98.626  -78.586  45.448  1
124614  98.647  -78.574  45.431  1
124615  98.661  -78.562  45.413  1
124616  98.691  -78.556  45.396  1
124617  98.739  -78.571  45.380  1
124618  98.777  -78.589  45.365  1
124619  98.796  -78.608  45.350  1
124620  98.783  -78.602  45.335  1
124621  98.784  -78.596  45.321  1
124622  98.807  -78.593  45.306  1
124623  98.818  -78.599  45.289  1
124624  98.830  -78.605  45.272  1
124625  98.841  -78.612  45.256  1
124626  98.859  -78.617  45.240  1
124627  98.899  -78.617  45.224  1
124628  98.938  -78.619  45.208  1
124629  98.978  -78.620  45.192  1
124630  99.039  -78.643  45.176  1
124631  99.037  -78.583  45.159  1
124632  99.019  -78.593  45.146  1
124633  99.001  -78.602  45.131  1
124634  99.020  -78.623  45.118  1
124635  99.064  -78.612  45.105  1
124636  99.083  -78.617  45.092  1
124637  99.120  -78.615  45.079  1
124638  99.174  -78.605  45.067  1
124639  99.171  -78.619  45.054  1
124640  99.138  -78.675  45.043  1
124641  99.138  -78.741  45.032  1
124642  99.136  -78.805  45.020  1
124643  99.141  -78.805  45.008  1
124644  99.184  -78.782  44.997  1
124645  99.227  -78.758  44.986  1
124646  99.261  -78.750  44.975  1
124647  99.293  -78.744  44.964  1
124648  99.326  -78.739  44.953  1
124649  99.365  -78.741  44.942  1
124650  99.420  -78.759  44.931  1
124651  99.475  -78.778  44.920  1
124652  99.529  -78.797  44.909  1
124653  99.584  -78.815  44.898  1
124654  99.639  -78.834  44.888  1
124655  99.648  -78.834  44.878  1
124656  99.655  -78.835  44.868  1
124657  99.687  -78.878  44.858  1
124658  99.719  -78.921  44.847  1
124659  99.747  -78.959  44.835  1
124660  99.767  -78.982  44.822  1
124661  99.787  -79.005  44.812  1
124662  99.807  -79.028  44.803  1
124663  99.828  -79.050  44.793  1
124664  99.848  -79.073  44.785  1
124665  99.867  -79.096  44.779  1
124666  99.888  -79.118  44.772  1
124667  99.908  -79.141  44.765  1
124668  99.922  -79.153  44.760  1
124669  99.935  -79.163  44.755  1
124670  99.941  -79.159  44.750  1
124671  99.979  -79.171  44.745  1
124672  100.018  -79.183  44.741  1
124673  100.058  -79.196  44.737  1
124674  100.083  -79.214  44.733  1
124675  100.090  -79.238  44.729  1
124676  100.109  -79.259  44.725  1
124677  100.139  -79.278  44.721  1
124678  100.168  -79.296  44.717  1
124679  100.197  -79.313  44.713  1
124680  100.224  -79.318  44.708  1
124681  100.252  -79.323  44.704  1
124682  100.279  -79.329  44.698  1
124683  100.307  -79.335  44.693  1
124684  100.334  -79.340  44.688  1
124685  100.361  -79.345  44.682  1
124686  100.388  -79.351  44.676  1
124687  100.416  -79.357  44.669  1
124688  100.449  -79.365  44.662  1
124689  100.487  -79.375  44.655  1
124690  100.526  -79.385  44.647  1
124691  100.564  -79.395  44.639  1
124692  100.603  -79.406  44.631  1
124693  100.642  -79.419  44.623  1
124694  100.681  -79.436  44.614  1
124695  100.720  -79.453  44.606  1
124696  100.759  -79.469  44.597  1
124697  100.798  -79.486  44.588  1
124698  100.838  -79.503  44.579  1
124699  100.877  -79.520  44.571  1
124700  100.916  -79.536  44.560  1
124701  100.956  -79.553  44.550  1
124702  100.994  -79.570  44.540  1
124703  101.034  -79.586  44.530  1
124704  101.073  -79.603  44.518  1
124705  101.112  -79.620  44.506  1
124706  101.144  -79.639  44.494  1
124707  101.177  -79.657  44.480  1
124708  101.210  -79.676  44.466  1
124709  101.242  -79.696  44.452  1
124710  101.275  -79.715  44.438  1
124711  101.307  -79.734  44.423  1
124712  101.340  -79.753  44.408  1
124713  101.426  -79.787  44.392  1
124714  101.481  -79.795  44.375  1
124715  101.526  -79.803  44.358  1
124716  101.550  -79.823  44.342  1
124717  101.581  -79.836  44.325  1
124718  101.598  -79.842  44.308  1
124719  101.615  -79.848  44.291  1
124720  101.631  -79.854  44.273  1
124721  101.648  -79.859  44.255  1
124722  101.665  -79.864  44.238  1
124723  101.682  -79.871  44.220  1
124724  101.698  -79.876  44.202  1
124725  101.715  -79.882  44.184  1
125015  93.907  -77.878  53.087  1
125016  93.919  -77.874  53.067  1
125017  93.932  -77.870  53.048  1
125018  93.945  -77.866  53.029  1
125019  93.958  -77.862  53.009  1
125020  93.971  -77.857  52.989  1
125021  93.983  -77.853  52.969  1
125022  93.981  -77.852  52.949  1
125023  93.978  -77.851  52.930  1
125024  93.976  -77.849  52.910  1
125025  93.974  -77.849  52.890  1
125026  93.971  -77.847  52.870  1
125027  93.969  -77.846  52.849  1
125028  93.966  -77.845  52.828  1
125029  93.969  -77.855  52.806  1
125030  93.973  -77.865  52.785  1
125031  93.976  -77.876  52.764  1
125032  93.983  -77.884  52.743  1
125033  93.998  -77.889  52.721  1
125034  94.014  -77.893  52.699  1
125035  94.030  -77.897  52.677  1
125036  94.046  -77.902  52.653  1
125037  94.062  -77.906  52.631  1
125038  94.063  -77.898  52.608  1
125039  94.064  -77.890  52.586  1
125040  94.065  -77.882  52.564  1
125041  94.066  -77.874  52.542  1
125042  94.100  -77.859  52.519  1
125043  94.125  -77.850  52.496  1
125048  94.249  -77.805  52.385  1
125049  94.274  -77.796  52.363  1
125050  94.299  -77.786  52.342  1
125051  94.324  -77.777  52.322  1
125052  94.349  -77.768  52.301  1
125053  94.374  -77.758  52.280  1
125054  94.399  -77.749  52.261  1
125055  94.424  -77.740  52.242  1
125056  94.449  -77.731  52.223  1
125057  94.474  -77.722  52.203  1
125058  94.499  -77.713  52.185  1
125059  94.524  -77.703  52.167  1
125060  94.538  -77.697  52.150  1
125061  94.553  -77.690  52.132  1
125062  94.567  -77.684  52.114  1
125063  94.581  -77.677  52.096  1
125064  94.602  -77.669  52.077  1
125065  94.623  -77.660  52.058  1
125066  94.644  -77.652  52.039  1
125067  94.665  -77.643  52.019  1
125068  94.686  -77.634  51.999  1
125069  94.707  -77.626  51.976  1
125070  94.674  -77.643  51.954  1
125071  94.655  -77.640  51.932  1
125072  94.655  -77.642  51.909  1
125073  94.655  -77.644  51.885  1
125074  94.651  -77.645  51.862  1
125075  94.647  -77.647  51.839  1
125076  94.644  -77.649  51.812  1
125077  94.646  -77.656  51.784  1
125078  94.649  -77.662  51.756  1
125079  94.654  -77.669  51.729  1
125080  94.664  -77.676  51.701  1
125081  94.681  -77.681  51.673  1
125082  94.703  -77.688  51.644  1
125083  94.724  -77.695  51.611  1
125084  94.747  -77.702  51.575  1
125085  94.769  -77.708  51.540  1
125086  94.790  -77.715  51.505  1
125087  94.790  -77.700  51.470  1
125088  94.786  -77.681  51.435  1
125089  94.811  -77.680  51.400  1
125090  94.837  -77.684  51.362  1
125091  94.865  -77.715  51.324  1
125092  94.831  -77.741  51.286  1
125093  94.858  -77.762  51.247  1
125094  94.874  -77.768  51.209  1
125095  94.875  -77.761  51.170  1
125096  94.889  -77.755  51.130  1
125097  94.910  -77.750  51.090  1
125098  94.923  -77.749  51.050  1
125099  94.942  -77.755  51.010  1
125100  94.922  -77.761  50.971  1
125101  95.032  -77.814  50.933  1
125102  95.041  -77.793  50.894  1
125103  95.051  -77.774  50.855  1
125104  95.061  -77.753  50.816  1
125105  95.071  -77.733  50.777  1
125106  95.086  -77.726  50.740  1
125107  95.102  -77.723  50.702  1
125108  95.119  -77.719  50.664  1
125109  95.135  -77.716  50.627  1
125110  95.155  -77.717  50.590  1
125111  95.174  -77.717  50.552  1
125112  95.194  -77.718  50.516  1
125113  95.213  -77.718  50.480  1
125114  95.232  -77.718  50.445  1
125115  95.238  -77.714  50.411  1
125116  95.243  -77.710  50.378  1
125117  95.249  -77.707  50.344  1
125118  95.271  -77.695  50.312  1
125119  95.296  -77.683  50.280  1
125120  95.321  -77.670  50.249  1
125121  95.345  -77.657  50.219  1
125122  95.353  -77.649  50.189  1
125123  95.360  -77.641  50.161  1
125124  95.368  -77.633  50.132  1
125125  95.375  -77.624  50.102  1
125126  95.383  -77.617  50.072  1
125127  95.399  -77.595  50.043  1
125128  95.444  -77.574  50.014  1
125129  95.487  -77.558  49.984  1
125130  95.518  -77.573  49.956  1
125131  95.548  -77.587  49.928  1
125132  95.578  -77.602  49.900  1
125133  95.574  -77.621  49.872  1
125134  95.579  -77.638  49.843  1
125135  95.601  -77.646  49.814  1
125136  95.592  -77.646  49.786  1
125137  95.583  -77.646  49.755  1
125138  95.573  -77.646  49.723  1
125139  95.593  -77.650  49.691  1
125140  95.618  -77.654  49.658  1
125141  95.625  -77.675  49.626  1
125142  95.639  -77.673  49.594  1
125143  95.655  -77.667  49.564  1
125144  95.672  -77.661  49.536  1
125145  95.686  -77.656  49.507  1
125146  95.689  -77.654  49.480  1
125147  95.698  -77.655  49.452  1
125148  95.706  -77.659  49.428  1
125149  95.713  -77.666  49.402  1
125150  95.721  -77.674  49.375  1
125151  95.728  -77.680  49.346  1
125152  95.736  -77.688  49.319  1
125153  95.743  -77.695  49.291  1
125154  95.750  -77.702  49.261  1
125155  95.758  -77.709  49.227  1
125156  95.766  -77.716  49.190  1
125157  95.784  -77.724  49.153  1
125158  95.801  -77.731  49.114  1
125159  95.819  -77.739  49.076  1
125160  95.836  -77.746  49.038  1
125161  95.853  -77.753  49.000  1
125162  95.871  -77.761  48.964  1
125163  95.894  -77.772  48.927  1
125164  95.917  -77.781  48.891  1
125165  95.940  -77.790  48.854  1
125166  95.961  -77.799  48.818  1
125167  95.981  -77.812  48.783  1
125168  96.002  -77.824  48.747  1
125169  96.022  -77.837  48.711  1
125170  96.042  -77.849  48.674  1
125171  96.061  -77.862  48.637  1
125172  96.082  -77.874  48.600  1
125173  96.097  -77.881  48.566  1
125174  96.103  -77.878  48.533  1
125175  96.110  -77.875  48.499  1
125176  96.117  -77.872  48.467  1
125177  96.123  -77.870  48.437  1
125178  96.133  -77.870  48.407  1
125179  96.142  -77.865  48.376  1
125180  96.148  -77.859  48.351  1
125181  96.155  -77.857  48.324  1
125182  96.162  -77.855  48.295  1
125183  96.169  -77.855  48.269  1
125184  96.176  -77.854  48.241  1
125185  96.183  -77.853  48.216  1
125186  96.198  -77.863  48.192  1
125187  96.225  -77.888  48.170  1
125188  96.252  -77.913  48.149  1
125189  96.279  -77.938  48.126  1
125190  96.310  -77.975  48.102  1
125191  96.341  -78.011  48.079  1
125192  96.356  -78.024  48.056  1
125193  96.359  -78.021  48.033  1
125194  96.362  -78.018  48.012  1
125195  96.365  -78.014  47.989  1
125196  96.368  -78.011  47.965  1
125197  96.372  -78.008  47.941  1
125198  96.375  -78.004  47.919  1
125199  96.390  -78.017  47.897  1
125200  96.401  -78.036  47.876  1
125201  96.404  -78.060  47.855  1
125202  96.410  -78.079  47.830  1
125203  96.420  -78.089  47.804  1
125204  96.430  -78.099  47.776  1
125205  96.439  -78.109  47.750  1
125206  96.449  -78.119  47.723  1
125207  96.455  -78.115  47.697  1
125208  96.458  -78.099  47.672  1
125209  96.461  -78.083  47.645  1
125210  96.466  -78.069  47.618  1
125211  96.483  -78.068  47.590  1
125212  96.500  -78.067  47.562  1
125213  96.517  -78.066  47.533  1
125214  96.535  -78.065  47.504  1
125215  96.552  -78.065  47.478  1
125216  96.576  -78.067  47.454  1
125217  96.600  -78.081  47.430  1
125218  96.607  -78.100  47.405  1
125219  96.619  -78.109  47.381  1
125220  96.631  -78.117  47.356  1
125221  96.644  -78.125  47.331  1
125222  96.648  -78.134  47.307  1
125223  96.651  -78.144  47.283  1
125224  96.664  -78.150  47.259  1
125225  96.685  -78.151  47.234  1
125226  96.699  -78.160  47.210  1
125227  96.713  -78.170  47.185  1
125228  96.727  -78.181  47.160  1
125229  96.741  -78.191  47.134  1
125230  96.754  -78.201  47.107  1
125231  96.768  -78.211  47.081  1
125232  96.780  -78.225  47.054  1
125233  96.790  -78.244  47.029  1
125234  96.799  -78.263  47.003  1
125235  96.809  -78.282  46.976  1
125236  96.818  -78.300  46.950  1
125237  96.837  -78.313  46.922  1
125238  96.864  -78.325  46.895  1
125239  96.891  -78.337  46.867  1
125240  96.918  -78.348  46.839  1
125241  96.945  -78.360  46.812  1
125242  96.971  -78.372  46.785  1
125243  96.998  -78.383  46.758  1
125244  97.025  -78.395  46.734  1
125245  97.052  -78.408  46.710  1
125246  97.079  -78.422  46.687  1
125247  97.106  -78.436  46.664  1
125248  97.133  -78.450  46.640  1
125249  97.162  -78.464  46.617  1
125250  97.198  -78.474  46.593  1
125251  97.240  -78.479  46.572  1
125252  97.282  -78.470  46.550  1
125253  97.323  -78.454  46.527  1
125254  97.367  -78.438  46.506  1
125255  97.430  -78.436  46.485  1
125256  97.472  -78.437  46.466  1
125257  97.496  -78.442  46.447  1
125258  97.519  -78.447  46.431  1
125259  97.546  -78.453  46.414  1
125260  97.588  -78.465  46.397  1
125261  97.631  -78.478  46.381  1
125262  97.673  -78.490  46.364  1
125263  97.715  -78.502  46.347  1
125264  97.767  -78.523  46.330  1
125265  97.826  -78.551  46.312  1
125266  97.886  -78.579  46.295  1
125267  97.930  -78.605  46.278  1
125268  97.943  -78.590  46.260  1
125269  97.956  -78.576  46.244  1
125270  97.969  -78.561  46.227  1
125271  97.974  -78.529  46.210  1
125272  98.013  -78.531  46.194  1
125273  98.055  -78.529  46.177  1
125274  98.095  -78.528  46.161  1
125275  98.132  -78.516  46.145  1
125276  98.180  -78.491  46.130  1
125277  98.206  -78.485  46.115  1
125278  98.207  -78.501  46.100  1
125279  98.208  -78.515  46.086  1
125280  98.202  -78.512  46.071  1
125281  98.200  -78.507  46.056  1
125282  98.213  -78.511  46.041  1
125283  98.226  -78.515  46.026  1
125284  98.228  -78.514  46.010  1
125285  98.229  -78.510  45.995  1
125286  98.240  -78.507  45.980  1
125287  98.279  -78.502  45.963  1
125288  98.290  -78.463  45.946  1
125289  98.298  -78.433  45.928  1
125290  98.301  -78.443  45.911  1
125291  98.304  -78.445  45.893  1
125292  98.324  -78.427  45.874  1
125293  98.343  -78.428  45.854  1
125294  98.361  -78.430  45.834  1
125295  98.379  -78.432  45.814  1
125296  98.392  -78.460  45.793  1
125297  98.405  -78.473  45.772  1
125298  98.418  -78.486  45.752  1
125299  98.430  -78.499  45.733  1
125300  98.443  -78.512  45.713  1
125301  98.456  -78.525  45.694  1
125302  98.468  -78.538  45.675  1
125303  98.481  -78.544  45.656  1
125304  98.492  -78.551  45.636  1
125305  98.502  -78.557  45.617  1
125306  98.512  -78.564  45.598  1
125307  98.522  -78.570  45.580  1
125308  98.533  -78.577  45.562  1
125309  98.543  -78.584  45.544  1
125310  98.554  -78.590  45.525  1
125311  98.564  -78.597  45.507  1
125312  98.574  -78.604  45.490  1
125313  98.601  -78.596  45.473  1
125314  98.620  -78.584  45.456  1
125315  98.634  -78.572  45.438  1
125316  98.647  -78.560  45.421  1
125317  98.671  -78.546  45.404  1
125318  98.720  -78.561  45.388  1
125319  98.769  -78.576  45.373  1
125320  98.803  -78.583  45.357  1
125321  98.790  -78.577  45.342  1
125322  98.783  -78.571  45.328  1
125323  98.802  -78.572  45.312  1
125324  98.813  -78.578  45.295  1
125325  98.825  -78.584  45.278  1
125326  98.836  -78.590  45.263  1
125327  98.847  -78.596  45.248  1
125328  98.875  -78.600  45.233  1
125329  98.914  -78.601  45.216  1
125330  99.002  -78.581  45.199  1
125331  99.018  -78.586  45.182  1
125332  99.000  -78.596  45.166  1
125333  98.982  -78.605  45.153  1
125334  98.982  -78.625  45.138  1
125335  99.041  -78.607  45.124  1
125336  99.071  -78.604  45.112  1
125337  99.091  -78.610  45.099  1
125338  99.110  -78.615  45.086  1
125339  99.147  -78.612  45.074  1
125340  99.201  -78.603  45.062  1
125341  99.158  -78.633  45.051  1
125342  99.158  -78.699  45.039  1
125343  99.157  -78.765  45.027  1
125344  99.142  -78.786  45.016  1
125345  99.171  -78.771  45.005  1
125346  99.214  -78.748  44.993  1
125347  99.250  -78.736  44.981  1
125348  99.283  -78.730  44.970  1
125349  99.315  -78.724  44.959  1
125350  99.364  -78.737  44.947  1
125351  99.419  -78.756  44.936  1
125352  99.474  -78.774  44.924  1
125353  99.528  -78.793  44.912  1
125354  99.583  -78.812  44.902  1
125355  99.637  -78.830  44.890  1
125356  99.664  -78.838  44.879  1
125357  99.671  -78.837  44.869  1
125358  99.701  -78.877  44.857  1
125359  99.732  -78.920  44.846  1
125360  99.758  -78.952  44.835  1
125361  99.778  -78.975  44.824  1
125362  99.798  -78.998  44.814  1
125363  99.818  -79.021  44.804  1
125364  99.838  -79.043  44.794  1
125365  99.858  -79.066  44.787  1
125366  99.878  -79.089  44.779  1
125367  99.898  -79.110  44.772  1
125368  99.911  -79.120  44.766  1
125369  99.924  -79.130  44.761  1
125370  99.937  -79.140  44.756  1
125371  99.945  -79.141  44.751  1
125372  99.980  -79.148  44.747  1
125373  100.019  -79.161  44.742  1
125374  100.059  -79.174  44.738  1
125375  100.074  -79.195  44.734  1
125376  100.082  -79.219  44.730  1
125377  100.112  -79.237  44.726  1
125378  100.141  -79.256  44.722  1
125379  100.171  -79.274  44.718  1
125380  100.200  -79.292  44.714  1
125381  100.227  -79.298  44.710  1
125382  100.255  -79.303  44.705  1
125383  100.282  -79.309  44.700  1
125384  100.309  -79.315  44.694  1
125385  100.336  -79.320  44.689  1
125386  100.363  -79.325  44.684  1
125387  100.391  -79.331  44.678  1
125388  100.418  -79.337  44.671  1
125389  100.456  -79.347  44.665  1
125390  100.494  -79.357  44.657  1
125391  100.533  -79.367  44.648  1
125392  100.571  -79.378  44.640  1
125393  100.610  -79.389  44.632  1
125394  100.649  -79.406  44.624  1
125395  100.688  -79.422  44.615  1
125396  100.727  -79.439  44.607  1
125397  100.767  -79.456  44.598  1
125398  100.806  -79.473  44.589  1
125399  100.845  -79.489  44.579  1
125400  100.884  -79.506  44.570  1
125401  100.923  -79.523  44.559  1
125402  100.963  -79.539  44.550  1
125403  101.002  -79.556  44.540  1
125404  101.041  -79.573  44.529  1
125405  101.077  -79.590  44.517  1
125406  101.110  -79.609  44.504  1
125407  101.142  -79.629  44.492  1
125408  101.175  -79.648  44.478  1
125409  101.207  -79.667  44.464  1
125410  101.240  -79.686  44.450  1
125411  101.272  -79.704  44.435  1
125412  101.305  -79.724  44.419  1
125413  101.357  -79.748  44.403  1
125414  101.434  -79.772  44.387  1
125415  101.486  -79.779  44.371  1
125416  101.525  -79.788  44.355  1
125417  101.549  -79.809  44.338  1
125418  101.582  -79.823  44.321  1
125419  101.599  -79.829  44.305  1
125420  101.615  -79.835  44.287  1
125421  101.632  -79.840  44.269  1
125422  101.649  -79.846  44.252  1
125423  101.666  -79.852  44.234  1
125424  101.683  -79.857  44.216  1
125425  101.699  -79.863  44.198  1
125715  93.894  -77.871  53.118  1
125716  93.907  -77.868  53.099  1
125717  93.920  -77.863  53.079  1
125718  93.933  -77.859  53.060  1
125719  93.946  -77.855  53.041  1
125720  93.959  -77.850  53.021  1
125721  93.972  -77.846  53.001  1
125722  93.984  -77.842  52.982  1
125723  93.981  -77.840  52.961  1
125724  93.979  -77.840  52.942  1
125725  93.977  -77.839  52.923  1
125726  93.974  -77.837  52.903  1
125727  93.972  -77.837  52.883  1
125728  93.969  -77.835  52.862  1
125729  93.967  -77.834  52.841  1
125730  93.969  -77.842  52.820  1
125731  93.972  -77.852  52.799  1
125732  93.976  -77.862  52.777  1
125733  93.986  -77.870  52.756  1
125734  94.001  -77.874  52.734  1
125735  94.017  -77.878  52.713  1
125736  94.033  -77.882  52.691  1
125737  94.049  -77.887  52.668  1
125738  94.063  -77.890  52.645  1
125739  94.064  -77.881  52.623  1
125740  94.066  -77.873  52.600  1
125741  94.067  -77.865  52.579  1
125742  94.068  -77.857  52.556  1
125743  94.101  -77.843  52.533  1
125744  94.126  -77.834  52.510  1
125745  94.151  -77.824  52.488  1
125746  94.176  -77.815  52.466  1
125747  94.201  -77.806  52.444  1
125748  94.226  -77.797  52.423  1
125749  94.251  -77.787  52.400  1
125750  94.276  -77.778  52.379  1
125751  94.300  -77.769  52.358  1
125752  94.326  -77.760  52.338  1
125753  94.350  -77.751  52.317  1
125754  94.376  -77.742  52.297  1
125755  94.400  -77.733  52.278  1
125756  94.425  -77.724  52.258  1
125757  94.450  -77.714  52.239  1
125758  94.475  -77.705  52.221  1
125759  94.500  -77.696  52.204  1
125760  94.524  -77.688  52.187  1
125761  94.537  -77.685  52.171  1
125762  94.558  -77.677  52.154  1
125763  94.578  -77.667  52.137  1
125764  94.600  -77.659  52.120  1
125765  94.620  -77.651  52.102  1
125766  94.641  -77.642  52.083  1
125767  94.662  -77.633  52.062  1
125768  94.683  -77.625  52.040  1
125769  94.704  -77.617  52.018  1
125770  94.694  -77.633  51.996  1
125771  94.665  -77.633  51.972  1
125772  94.644  -77.630  51.948  1
125773  94.642  -77.632  51.925  1
125774  94.642  -77.633  51.902  1
125775  94.641  -77.636  51.879  1
125776  94.640  -77.637  51.856  1
125777  94.641  -77.642  51.831  1
125778  94.643  -77.649  51.804  1
125779  94.649  -77.655  51.776  1
125780  94.656  -77.661  51.749  1
125781  94.667  -77.668  51.721  1
125782  94.689  -77.675  51.691  1
125783  94.711  -77.682  51.660  1
125784  94.733  -77.689  51.627  1
125785  94.755  -77.696  51.591  1
125786  94.777  -77.702  51.556  1
125787  94.792  -77.703  51.522  1
125788  94.788  -77.684  51.488  1
125789  94.784  -77.665  51.454  1
125790  94.803  -77.660  51.419  1
125791  94.829  -77.667  51.381  1
125792  94.857  -77.699  51.344  1
125793  94.877  -77.730  51.306  1
125794  94.891  -77.765  51.267  1
125795  94.892  -77.759  51.228  1
125796  94.893  -77.752  51.190  1
125797  94.894  -77.746  51.151  1
125798  94.909  -77.740  51.111  1
125799  94.920  -77.736  51.071  1
125800  95.028  -77.732  51.031  1
125801  95.129  -77.727  50.991  1
125802  94.966  -77.752  50.952  1
125803  95.045  -77.778  50.913  1
125804  95.055  -77.758  50.874  1
125805  95.064  -77.737  50.834  1
125806  95.076  -77.723  50.795  1
125807  95.093  -77.720  50.757  1
125808  95.109  -77.716  50.718  1
125809  95.128  -77.716  50.680  1
125810  95.148  -77.716  50.643  1
125811  95.168  -77.717  50.605  1
125812  95.187  -77.717  50.567  1
125813  95.207  -77.718  50.531  1
125814  95.226  -77.718  50.495  1
125815  95.231  -77.714  50.459  1
125816  95.237  -77.710  50.425  1
125817  95.242  -77.707  50.391  1
125818  95.253  -77.700  50.357  1
125819  95.278  -77.687  50.324  1
125820  95.304  -77.675  50.291  1
125821  95.328  -77.662  50.259  1
125822  95.353  -77.649  50.228  1
125823  95.364  -77.640  50.198  1
125824  95.372  -77.632  50.168  1
125825  95.379  -77.624  50.139  1
125826  95.387  -77.616  50.109  1
125827  95.394  -77.608  50.079  1
125828  95.422  -77.577  50.049  1
125829  95.467  -77.556  50.020  1
125830  95.513  -77.536  49.991  1
125831  95.552  -77.528  49.962  1
125832  95.583  -77.542  49.934  1
125833  95.607  -77.558  49.906  1
125834  95.586  -77.580  49.878  1
125835  95.564  -77.603  49.850  1
125836  95.584  -77.615  49.822  1
125837  95.574  -77.615  49.793  1
125838  95.565  -77.615  49.764  1
125839  95.590  -77.620  49.733  1
125840  95.615  -77.624  49.701  1
125841  95.640  -77.629  49.668  1
125842  95.656  -77.642  49.636  1
125843  95.654  -77.663  49.604  1
125844  95.670  -77.658  49.574  1
125845  95.670  -77.652  49.544  1
125846  95.673  -77.651  49.516  1
125847  95.682  -77.652  49.488  1
125848  95.691  -77.652  49.461  1
125849  95.699  -77.653  49.437  1
125850  95.708  -77.655  49.411  1
125851  95.716  -77.663  49.385  1
125852  95.723  -77.670  49.356  1
125853  95.730  -77.677  49.328  1
125854  95.738  -77.684  49.299  1
125855  95.745  -77.691  49.270  1
125856  95.753  -77.699  49.235  1
125857  95.761  -77.705  49.199  1
125858  95.778  -77.713  49.162  1
125859  95.796  -77.721  49.123  1
125860  95.813  -77.727  49.085  1
125861  95.831  -77.735  49.047  1
125862  95.848  -77.743  49.010  1
125863  95.871  -77.753  48.973  1
125864  95.895  -77.765  48.936  1
125865  95.918  -77.774  48.900  1
125866  95.941  -77.782  48.864  1
125867  95.964  -77.790  48.828  1
125868  95.986  -77.799  48.793  1
125869  96.007  -77.811  48.757  1
125870  96.027  -77.824  48.720  1
125871  96.047  -77.836  48.684  1
125872  96.067  -77.849  48.649  1
125873  96.087  -77.861  48.612  1
125874  96.107  -77.874  48.577  1
125875  96.115  -77.872  48.542  1
125876  96.122  -77.870  48.509  1
125877  96.128  -77.867  48.478  1
125878  96.135  -77.864  48.448  1
125879  96.140  -77.865  48.419  1
125880  96.146  -77.866  48.390  1
125881  96.152  -77.865  48.363  1
125882  96.159  -77.864  48.335  1
125883  96.166  -77.863  48.306  1
125884  96.173  -77.862  48.277  1
125885  96.180  -77.862  48.250  1
125886  96.187  -77.860  48.224  1
125887  96.212  -77.883  48.197  1
125888  96.239  -77.908  48.174  1
125889  96.265  -77.932  48.152  1
125890  96.293  -77.957  48.131  1
125891  96.320  -77.982  48.110  1
125892  96.347  -78.009  48.087  1
125893  96.368  -78.031  48.064  1
125894  96.372  -78.028  48.041  1
125895  96.375  -78.025  48.019  1
125896  96.378  -78.022  47.996  1
125897  96.381  -78.018  47.973  1
125898  96.384  -78.015  47.950  1
125899  96.387  -78.012  47.929  1
125900  96.390  -78.009  47.908  1
125901  96.402  -78.024  47.886  1
125902  96.408  -78.044  47.865  1
125903  96.418  -78.053  47.841  1
125904  96.428  -78.064  47.815  1
125905  96.437  -78.074  47.788  1
125906  96.447  -78.084  47.763  1
125907  96.456  -78.094  47.737  1
125908  96.464  -78.097  47.711  1
125909  96.467  -78.081  47.684  1
125910  96.470  -78.065  47.656  1
125911  96.473  -78.050  47.628  1
125912  96.477  -78.034  47.600  1
125913  96.493  -78.032  47.572  1
125914  96.511  -78.031  47.546  1
125915  96.528  -78.031  47.520  1
125916  96.549  -78.031  47.494  1
125917  96.583  -78.037  47.470  1
125918  96.612  -78.046  47.446  1
125919  96.617  -78.073  47.420  1
125920  96.624  -78.096  47.397  1
125921  96.636  -78.104  47.373  1
125922  96.648  -78.112  47.349  1
125923  96.655  -78.122  47.325  1
125924  96.658  -78.131  47.300  1
125925  96.676  -78.134  47.276  1
125926  96.693  -78.141  47.251  1
125927  96.707  -78.150  47.227  1
125928  96.720  -78.161  47.202  1
125929  96.734  -78.171  47.177  1
125930  96.748  -78.181  47.150  1
125931  96.761  -78.191  47.124  1
125932  96.776  -78.202  47.098  1
125933  96.789  -78.213  47.071  1
125934  96.798  -78.232  47.046  1
125935  96.808  -78.251  47.020  1
125936  96.817  -78.269  46.994  1
125937  96.832  -78.285  46.967  1
125938  96.851  -78.297  46.939  1
125939  96.869  -78.308  46.911  1
125940  96.888  -78.320  46.883  1
125941  96.915  -78.332  46.855  1
125942  96.942  -78.344  46.830  1
125943  96.969  -78.355  46.805  1
125944  96.996  -78.366  46.780  1
125945  97.022  -78.379  46.755  1
125946  97.049  -78.392  46.732  1
125947  97.076  -78.407  46.708  1
125948  97.104  -78.420  46.684  1
125949  97.133  -78.435  46.661  1
125950  97.162  -78.449  46.637  1
125951  97.202  -78.456  46.613  1
125952  97.243  -78.462  46.591  1
125953  97.285  -78.468  46.569  1
125954  97.326  -78.459  46.547  1
125955  97.368  -78.442  46.526  1
125956  97.416  -78.430  46.505  1
125957  97.478  -78.428  46.485  1
125958  97.508  -78.432  46.466  1
125959  97.531  -78.436  46.449  1
125960  97.554  -78.441  46.433  1
125961  97.578  -78.446  46.416  1
125962  97.613  -78.455  46.400  1
125963  97.655  -78.468  46.382  1
125964  97.698  -78.480  46.364  1
125965  97.740  -78.493  46.346  1
125966  97.800  -78.520  46.329  1
125967  97.860  -78.549  46.310  1
125968  97.912  -78.591  46.293  1
125969  97.924  -78.576  46.275  1
125970  97.931  -78.547  46.258  1
125971  97.934  -78.511  46.241  1
125972  97.970  -78.510  46.224  1
125973  98.014  -78.518  46.208  1
125974  98.055  -78.520  46.191  1
125975  98.098  -78.512  46.175  1
125976  98.134  -78.498  46.160  1
125977  98.164  -78.469  46.144  1
125978  98.202  -78.444  46.130  1
125979  98.203  -78.458  46.115  1
125980  98.204  -78.473  46.101  1
125981  98.207  -78.489  46.087  1
125982  98.203  -78.501  46.073  1
125983  98.204  -78.498  46.058  1
125984  98.204  -78.495  46.042  1
125985  98.205  -78.492  46.027  1
125986  98.206  -78.489  46.012  1
125987  98.229  -78.485  45.997  1
125988  98.268  -78.480  45.980  1
125989  98.303  -78.473  45.963  1
125990  98.314  -78.432  45.945  1
125991  98.317  -78.438  45.927  1
125992  98.319  -78.433  45.908  1
125993  98.329  -78.423  45.889  1
125994  98.343  -78.431  45.870  1
125995  98.355  -78.435  45.849  1
125996  98.367  -78.439  45.829  1
125997  98.383  -78.449  45.808  1
125998  98.400  -78.466  45.788  1
125999  98.412  -78.479  45.768  1
126000  98.425  -78.492  45.748  1
126001  98.438  -78.504  45.728  1
126002  98.450  -78.517  45.708  1
126003  98.457  -78.532  45.689  1
126004  98.471  -78.538  45.669  1
126005  98.484  -78.544  45.650  1
126006  98.496  -78.550  45.630  1
126007  98.508  -78.556  45.611  1
126008  98.520  -78.562  45.592  1
126009  98.533  -78.567  45.573  1
126010  98.545  -78.573  45.554  1
126011  98.558  -78.579  45.535  1
126012  98.570  -78.586  45.517  1
126013  98.582  -78.592  45.499  1
126014  98.593  -78.589  45.482  1
126015  98.606  -78.582  45.464  1
126016  98.620  -78.570  45.446  1
126017  98.634  -78.557  45.429  1
126018  98.651  -78.535  45.412  1
126019  98.701  -78.551  45.395  1
126020  98.741  -78.558  45.380  1
126021  98.775  -78.559  45.364  1
126022  98.785  -78.553  45.348  1
126023  98.784  -78.547  45.334  1
126024  98.797  -78.551  45.317  1
126025  98.808  -78.557  45.301  1
126026  98.820  -78.563  45.284  1
126027  98.831  -78.569  45.269  1
126028  98.842  -78.575  45.254  1
126029  98.854  -78.581  45.239  1
126030  98.909  -78.575  45.223  1
126031  98.962  -78.587  45.206  1
126032  98.981  -78.598  45.189  1
126033  98.963  -78.608  45.173  1
126034  98.949  -78.620  45.160  1
126035  98.999  -78.614  45.146  1
126036  99.060  -78.592  45.132  1
126037  99.079  -78.597  45.120  1
126038  99.098  -78.602  45.107  1
126039  99.117  -78.607  45.095  1
126040  99.137  -78.612  45.083  1
126041  99.173  -78.610  45.071  1
126042  99.219  -78.604  45.060  1
126043  99.178  -78.657  45.048  1
126044  99.177  -78.724  45.037  1
126045  99.165  -78.752  45.025  1
126046  99.159  -78.761  45.013  1
126047  99.202  -78.737  45.000  1
126048  99.239  -78.723  44.989  1
126049  99.272  -78.717  44.977  1
126050  99.308  -78.714  44.965  1
126051  99.363  -78.733  44.954  1
126052  99.417  -78.752  44.942  1
126053  99.472  -78.771  44.930  1
126054  99.526  -78.789  44.918  1
126055  99.581  -78.808  44.906  1
126056  99.636  -78.827  44.894  1
126057  99.682  -78.842  44.883  1
126058  99.688  -78.841  44.871  1
126059  99.714  -78.874  44.859  1
126060  99.746  -78.918  44.848  1
126061  99.769  -78.946  44.836  1
126062  99.789  -78.968  44.825  1
126063  99.809  -78.991  44.816  1
126064  99.829  -79.014  44.805  1
126065  99.849  -79.037  44.796  1
126066  99.869  -79.060  44.788  1
126067  99.886  -79.076  44.781  1
126068  99.899  -79.086  44.774  1
126069  99.912  -79.096  44.768  1
126070  99.925  -79.106  44.763  1
126071  99.938  -79.115  44.758  1
126072  99.950  -79.122  44.754  1
126073  99.981  -79.126  44.749  1
126074  100.020  -79.138  44.745  1
126075  100.059  -79.152  44.740  1
126076  100.065  -79.176  44.736  1
126077  100.084  -79.197  44.733  1
126078  100.114  -79.216  44.728  1
126079  100.143  -79.234  44.724  1
126080  100.173  -79.252  44.720  1
126081  100.202  -79.270  44.717  1
126082  100.230  -79.278  44.712  1
126083  100.257  -79.284  44.708  1
126084  100.284  -79.289  44.703  1
126085  100.312  -79.294  44.697  1
126086  100.339  -79.300  44.691  1
126087  100.366  -79.306  44.686  1
126088  100.394  -79.311  44.680  1
126089  100.424  -79.318  44.673  1
126090  100.463  -79.328  44.666  1
126091  100.501  -79.338  44.658  1
126097  100.735  -79.426  44.607  1
126098  100.774  -79.442  44.598  1
126099  100.813  -79.459  44.589  1
126100  100.852  -79.476  44.579  1
126101  100.892  -79.492  44.570  1
126102  100.931  -79.509  44.559  1
126103  100.970  -79.526  44.549  1
126104  101.009  -79.542  44.538  1
126105  101.042  -79.561  44.527  1
126106  101.074  -79.580  44.515  1
126107  101.107  -79.599  44.502  1
126108  101.139  -79.618  44.489  1
126109  101.172  -79.638  44.475  1
126110  101.204  -79.657  44.461  1
126111  101.237  -79.676  44.446  1
126112  101.269  -79.695  44.431  1
126113  101.302  -79.714  44.415  1
126114  101.382  -79.746  44.399  1
126115  101.439  -79.756  44.383  1
126116  101.491  -79.762  44.367  1
126117  101.524  -79.773  44.351  1
126118  101.549  -79.795  44.335  1
126119  101.583  -79.811  44.319  1
126120  101.600  -79.816  44.300  1
126121  101.616  -79.821  44.282  1
126122  101.633  -79.827  44.265  1
126123  101.650  -79.833  44.247  1
126124  101.667  -79.839  44.230  1
126415  93.882  -77.865  53.149  1
126416  93.895  -77.860  53.129  1
126417  93.908  -77.856  53.110  1
126418  93.921  -77.852  53.090  1
126419  93.933  -77.848  53.071  1
126420  93.946  -77.843  53.052  1
126421  93.959  -77.839  53.033  1
126422  93.972  -77.835  53.014  1
126423  93.984  -77.830  52.994  1
126424  93.982  -77.830  52.974  1
126425  93.979  -77.828  52.954  1
126426  93.977  -77.827  52.935  1
126427  93.975  -77.826  52.915  1
126428  93.972  -77.825  52.895  1
126429  93.970  -77.824  52.874  1
126430  93.967  -77.823  52.853  1
126431  93.968  -77.829  52.833  1
126432  93.972  -77.839  52.812  1
126433  93.975  -77.849  52.791  1
126434  93.989  -77.855  52.770  1
126435  94.005  -77.859  52.748  1
126436  94.020  -77.863  52.726  1
126437  94.037  -77.868  52.704  1
126438  94.052  -77.871  52.683  1
126439  94.065  -77.873  52.660  1
126440  94.066  -77.865  52.637  1
126441  94.067  -77.856  52.615  1
126442  94.068  -77.849  52.593  1
126443  94.069  -77.840  52.570  1
126444  94.103  -77.826  52.547  1
126445  94.127  -77.817  52.524  1
126446  94.152  -77.808  52.503  1
126447  94.177  -77.799  52.481  1
126448  94.202  -77.789  52.459  1
126449  94.227  -77.780  52.438  1
126450  94.252  -77.771  52.416  1
126451  94.277  -77.761  52.395  1
126452  94.302  -77.752  52.374  1
126453  94.327  -77.743  52.354  1
126454  94.352  -77.734  52.334  1
126455  94.377  -77.725  52.314  1
126456  94.402  -77.716  52.295  1
126457  94.427  -77.707  52.275  1
126458  94.452  -77.697  52.257  1
126459  94.475  -77.690  52.239  1
126460  94.492  -77.688  52.222  1
126461  94.511  -77.681  52.207  1
126462  94.520  -77.677  52.192  1
126463  94.524  -77.681  52.176  1
126464  94.545  -77.673  52.160  1
126465  94.566  -77.664  52.144  1
126466  94.586  -77.656  52.126  1
126467  94.608  -77.647  52.106  1
126468  94.628  -77.639  52.085  1
126469  94.651  -77.630  52.063  1
126470  94.689  -77.617  52.041  1
126471  94.692  -77.624  52.018  1
126472  94.661  -77.623  51.994  1
126473  94.635  -77.620  51.971  1
126474  94.629  -77.620  51.948  1
126475  94.629  -77.623  51.924  1
126476  94.628  -77.629  51.900  1
126477  94.639  -77.664  51.877  1
126478  94.654  -77.651  51.852  1
126479  94.667  -77.642  51.825  1
126480  94.673  -77.649  51.797  1
126481  94.679  -77.655  51.771  1
126482  94.685  -77.662  51.742  1
126483  94.697  -77.669  51.711  1
126484  94.719  -77.676  51.679  1
126485  94.741  -77.683  51.645  1
126486  94.763  -77.689  51.610  1
126487  94.785  -77.696  51.575  1
126488  94.790  -77.687  51.542  1
126489  94.786  -77.668  51.508  1
126490  94.782  -77.649  51.474  1
126491  94.794  -77.640  51.440  1
126492  94.821  -77.651  51.403  1
126493  94.846  -77.683  51.366  1
126494  94.864  -77.713  51.328  1
126495  94.910  -77.755  51.288  1
126496  94.909  -77.750  51.249  1
126497  94.904  -77.743  51.211  1
126498  94.900  -77.735  51.173  1
126499  94.898  -77.724  51.133  1
126500  94.962  -77.711  51.094  1
126501  95.035  -77.701  51.054  1
126502  95.107  -77.690  51.013  1
126503  95.089  -77.727  50.973  1
126504  94.998  -77.755  50.933  1
126505  95.058  -77.742  50.893  1
126506  95.068  -77.721  50.853  1
126507  95.084  -77.717  50.814  1
126508  95.102  -77.715  50.775  1
126509  95.121  -77.716  50.735  1
126510  95.141  -77.716  50.697  1
126511  95.161  -77.717  50.659  1
126512  95.180  -77.717  50.622  1
126513  95.200  -77.718  50.583  1
126514  95.219  -77.718  50.546  1
126515  95.225  -77.714  50.510  1
126516  95.230  -77.710  50.474  1
126517  95.236  -77.706  50.439  1
126518  95.241  -77.703  50.404  1
126519  95.261  -77.692  50.370  1
126520  95.286  -77.680  50.337  1
126521  95.311  -77.667  50.303  1
126522  95.336  -77.655  50.271  1
126523  95.361  -77.642  50.239  1
126524  95.375  -77.632  50.208  1
126525  95.383  -77.624  50.177  1
126526  95.390  -77.615  50.147  1
126527  95.398  -77.608  50.117  1
126528  95.409  -77.592  50.086  1
126529  95.446  -77.558  50.057  1
126530  95.490  -77.539  50.028  1
126531  95.536  -77.518  49.999  1
126532  95.581  -77.498  49.969  1
126533  95.617  -77.498  49.941  1
126534  95.618  -77.517  49.913  1
126535  95.597  -77.539  49.885  1
126536  95.576  -77.562  49.858  1
126537  95.561  -77.583  49.830  1
126538  95.562  -77.585  49.801  1
126539  95.588  -77.595  49.773  1
126540  95.613  -77.630  49.742  1
126541  95.636  -77.645  49.710  1
126542  95.660  -77.660  49.678  1
126543  95.684  -77.635  49.646  1
126544  95.658  -77.652  49.615  1
126545  95.653  -77.649  49.584  1
126546  95.657  -77.648  49.554  1
126547  95.666  -77.649  49.525  1
126548  95.675  -77.649  49.497  1
126549  95.684  -77.650  49.471  1
126550  95.692  -77.651  49.446  1
126551  95.701  -77.652  49.420  1
126552  95.710  -77.652  49.394  1
126553  95.718  -77.659  49.366  1
126554  95.725  -77.666  49.338  1
126555  95.733  -77.674  49.308  1
126556  95.740  -77.680  49.278  1
126557  95.747  -77.687  49.244  1
126558  95.756  -77.695  49.208  1
126559  95.773  -77.702  49.170  1
126560  95.791  -77.709  49.132  1
126561  95.808  -77.717  49.094  1
126562  95.825  -77.724  49.056  1
126563  95.847  -77.735  49.019  1
126564  95.873  -77.748  48.982  1
126565  95.897  -77.758  48.945  1
126566  95.919  -77.767  48.909  1
126567  95.943  -77.775  48.873  1
126568  95.965  -77.783  48.838  1
126569  95.988  -77.792  48.802  1
126570  96.011  -77.800  48.766  1
126571  96.032  -77.810  48.730  1
126572  96.052  -77.823  48.695  1
126573  96.073  -77.835  48.659  1
126574  96.093  -77.848  48.622  1
126575  96.113  -77.861  48.587  1
126576  96.127  -77.867  48.553  1
126577  96.134  -77.864  48.520  1
126578  96.141  -77.861  48.488  1
126579  96.147  -77.858  48.458  1
126580  96.148  -77.865  48.429  1
126581  96.150  -77.874  48.400  1
126582  96.157  -77.872  48.372  1
126583  96.163  -77.871  48.344  1
126584  96.170  -77.871  48.315  1
126585  96.177  -77.870  48.286  1
126586  96.184  -77.868  48.258  1
126587  96.198  -77.877  48.231  1
126588  96.225  -77.902  48.203  1
126589  96.252  -77.927  48.179  1
126590  96.279  -77.952  48.156  1
126591  96.306  -77.977  48.134  1
126592  96.333  -78.001  48.115  1
126593  96.360  -78.026  48.092  1
126594  96.365  -78.025  48.069  1
126595  96.364  -78.022  48.045  1
126596  96.369  -78.020  48.024  1
126597  96.374  -78.018  48.002  1
126598  96.379  -78.016  47.980  1
126599  96.384  -78.014  47.959  1
126600  96.389  -78.012  47.938  1
126601  96.393  -78.010  47.917  1
126602  96.404  -78.009  47.896  1
126603  96.415  -78.018  47.874  1
126604  96.425  -78.028  47.850  1
126605  96.435  -78.038  47.826  1
126606  96.445  -78.049  47.801  1
126607  96.454  -78.059  47.776  1
126608  96.464  -78.069  47.750  1
126609  96.473  -78.078  47.723  1
126610  96.477  -78.064  47.696  1
126611  96.480  -78.048  47.667  1
126612  96.483  -78.032  47.639  1
126613  96.486  -78.016  47.611  1
126614  96.489  -78.000  47.584  1
126615  96.504  -77.996  47.559  1
126616  96.522  -77.996  47.534  1
126617  96.555  -78.002  47.509  1
126618  96.589  -78.007  47.486  1
126619  96.622  -78.013  47.461  1
126620  96.630  -78.038  47.436  1
126621  96.635  -78.065  47.412  1
126622  96.641  -78.091  47.389  1
126623  96.653  -78.100  47.365  1
126624  96.662  -78.108  47.341  1
126625  96.667  -78.117  47.316  1
126626  96.686  -78.121  47.292  1
126627  96.700  -78.131  47.269  1
126628  96.714  -78.141  47.244  1
126629  96.728  -78.151  47.218  1
126630  96.741  -78.162  47.192  1
126631  96.755  -78.172  47.166  1
126632  96.769  -78.182  47.140  1
126633  96.783  -78.192  47.114  1
126634  96.796  -78.203  47.087  1
126635  96.807  -78.220  47.062  1
126636  96.816  -78.239  47.037  1
126637  96.829  -78.255  47.011  1
126638  96.847  -78.267  46.983  1
126639  96.865  -78.279  46.955  1
126640  96.883  -78.291  46.926  1
126641  96.901  -78.304  46.898  1
126642  96.920  -78.316  46.871  1
126643  96.939  -78.327  46.848  1
126644  96.966  -78.339  46.825  1
126645  96.993  -78.351  46.802  1
126646  97.020  -78.363  46.778  1
126647  97.046  -78.376  46.754  1
126648  97.075  -78.391  46.730  1
126649  97.104  -78.405  46.705  1
126650  97.133  -78.420  46.681  1
126651  97.163  -78.432  46.657  1
126652  97.205  -78.438  46.633  1
126653  97.246  -78.445  46.609  1
126654  97.288  -78.451  46.587  1
126655  97.329  -78.456  46.566  1
126656  97.371  -78.448  46.546  1
126657  97.412  -78.432  46.525  1
126658  97.464  -78.423  46.505  1
126659  97.520  -78.421  46.486  1
126660  97.543  -78.426  46.470  1
126661  97.566  -78.431  46.453  1
126662  97.589  -78.435  46.437  1
126663  97.612  -78.440  46.420  1
126664  97.638  -78.446  46.401  1
126665  97.680  -78.458  46.383  1
126666  97.723  -78.470  46.365  1
126667  97.773  -78.490  46.346  1
126668  97.833  -78.518  46.328  1
126669  97.889  -78.563  46.310  1
126670  97.891  -78.529  46.293  1
126671  97.894  -78.493  46.275  1
126672  97.927  -78.488  46.257  1
126673  97.971  -78.496  46.240  1
126674  98.015  -78.505  46.225  1
126675  98.053  -78.519  46.208  1
126676  98.101  -78.496  46.192  1
126677  98.136  -78.479  46.176  1
126678  98.166  -78.452  46.161  1
126679  98.184  -78.434  46.147  1
126680  98.169  -78.435  46.133  1
126681  98.167  -78.454  46.118  1
126682  98.166  -78.473  46.104  1
126683  98.189  -78.501  46.090  1
126684  98.187  -78.495  46.076  1
126685  98.181  -78.476  46.060  1
126686  98.181  -78.471  46.045  1
126687  98.182  -78.469  46.029  1
126688  98.219  -78.463  46.013  1
126689  98.256  -78.458  45.996  1
126690  98.295  -78.454  45.979  1
126691  98.328  -78.442  45.962  1
126692  98.334  -78.432  45.944  1
126693  98.329  -78.419  45.924  1
126694  98.321  -78.413  45.905  1
126695  98.331  -78.417  45.886  1
126696  98.343  -78.421  45.866  1
126697  98.355  -78.426  45.845  1
126698  98.372  -78.437  45.824  1
126699  98.393  -78.458  45.804  1
126700  98.407  -78.471  45.784  1
126701  98.419  -78.484  45.764  1
126702  98.432  -78.497  45.743  1
126703  98.445  -78.510  45.723  1
126704  98.447  -78.526  45.703  1
126705  98.461  -78.532  45.683  1
126706  98.474  -78.538  45.664  1
126707  98.486  -78.544  45.644  1
126708  98.499  -78.550  45.625  1
126709  98.511  -78.556  45.605  1
126710  98.523  -78.561  45.585  1
126711  98.535  -78.567  45.565  1
126712  98.548  -78.573  45.546  1
126713  98.560  -78.579  45.528  1
126714  98.576  -78.589  45.509  1
126715  98.583  -78.570  45.491  1
126716  98.594  -78.568  45.473  1
126717  98.606  -78.567  45.455  1
126718  98.620  -78.555  45.438  1
126719  98.638  -78.532  45.420  1
126720  98.671  -78.531  45.402  1
126721  98.705  -78.532  45.386  1
126722  98.739  -78.533  45.370  1
126723  98.755  -78.529  45.353  1
126724  98.775  -78.529  45.338  1
126725  98.798  -78.532  45.320  1
126726  98.792  -78.516  45.304  1
126727  98.803  -78.523  45.289  1
126728  98.815  -78.529  45.274  1
126729  98.827  -78.536  45.259  1
126730  98.840  -78.549  45.243  1
126731  98.862  -78.586  45.227  1
126732  98.915  -78.599  45.212  1
126733  98.944  -78.611  45.196  1
126734  98.926  -78.620  45.181  1
126735  98.958  -78.620  45.168  1
126736  99.020  -78.597  45.155  1
126737  99.067  -78.584  45.142  1
126738  99.086  -78.589  45.129  1
126739  99.106  -78.594  45.116  1
126740  99.125  -78.599  45.104  1
126741  99.144  -78.604  45.092  1
126742  99.163  -78.610  45.081  1
126743  99.200  -78.608  45.069  1
126744  99.205  -78.617  45.058  1
126745  99.197  -78.681  45.047  1
126746  99.188  -78.720  45.034  1
126747  99.171  -78.734  45.021  1
126748  99.190  -78.727  45.009  1
126749  99.229  -78.709  44.997  1
126750  99.262  -78.703  44.985  1
126751  99.306  -78.711  44.973  1
126752  99.361  -78.730  44.961  1
126753  99.416  -78.749  44.948  1
126754  99.471  -78.767  44.936  1
126755  99.525  -78.786  44.924  1
126756  99.580  -78.805  44.911  1
126757  99.634  -78.824  44.899  1
126758  99.689  -78.842  44.887  1
126759  99.705  -78.845  44.875  1
126760  99.727  -78.873  44.862  1
126761  99.759  -78.916  44.850  1
126762  99.780  -78.939  44.839  1
126763  99.800  -78.962  44.827  1
126764  99.820  -78.985  44.817  1
126765  99.840  -79.008  44.808  1
126766  99.860  -79.031  44.798  1
126767  99.874  -79.043  44.791  1
126768  99.888  -79.053  44.784  1
126769  99.901  -79.062  44.777  1
126770  99.914  -79.072  44.772  1
126771  99.927  -79.082  44.766  1
126772  99.940  -79.092  44.762  1
126773  99.954  -79.102  44.758  1
126774  99.982  -79.103  44.753  1
126775  100.021  -79.116  44.748  1
126776  100.049  -79.133  44.744  1
126777  100.057  -79.157  44.739  1
126778  100.086  -79.175  44.736  1
126779  100.116  -79.194  44.733  1
126780  100.145  -79.212  44.728  1
126781  100.175  -79.230  44.723  1
126782  100.204  -79.248  44.720  1
126783  100.232  -79.258  44.716  1
126784  100.260  -79.263  44.711  1
126785  100.287  -79.269  44.706  1
126786  100.314  -79.275  44.700  1
126787  100.342  -79.280  44.695  1
126788  100.369  -79.285  44.689  1
126789  100.396  -79.291  44.682  1
126790  100.431  -79.300  44.675  1
126791  100.470  -79.310  44.668  1
126805  101.007  -79.532  44.537  1
126806  101.040  -79.551  44.526  1
126807  101.072  -79.570  44.513  1
126808  101.105  -79.589  44.500  1
126809  101.137  -79.608  44.486  1
126810  101.170  -79.627  44.473  1
126811  101.202  -79.646  44.458  1
126812  101.235  -79.666  44.443  1
126813  101.267  -79.685  44.427  1
126814  101.314  -79.708  44.412  1
126815  101.392  -79.733  44.396  1
126816  101.444  -79.739  44.379  1
126817  101.496  -79.745  44.363  1
126818  101.523  -79.758  44.347  1
126819  101.549  -79.782  44.331  1
126820  101.584  -79.797  44.314  1
126821  101.600  -79.803  44.296  1
126822  101.617  -79.808  44.278  1
127115  93.870  -77.858  53.179  1
127116  93.883  -77.853  53.160  1
127117  93.896  -77.849  53.140  1
127118  93.908  -77.845  53.121  1
127119  93.921  -77.840  53.102  1
127120  93.934  -77.837  53.082  1
127121  93.947  -77.832  53.063  1
127122  93.960  -77.827  53.045  1
127123  93.973  -77.824  53.026  1
127124  93.985  -77.819  53.007  1
127125  93.982  -77.818  52.987  1
127126  93.980  -77.817  52.967  1
127127  93.978  -77.816  52.947  1
127128  93.975  -77.815  52.928  1
127129  93.973  -77.814  52.908  1
127130  93.970  -77.813  52.888  1
127131  93.968  -77.812  52.867  1
127132  93.968  -77.815  52.847  1
127133  93.971  -77.826  52.826  1
127134  93.976  -77.835  52.805  1
127135  93.992  -77.840  52.783  1
127136  94.008  -77.843  52.762  1
127137  94.024  -77.848  52.740  1
127138  94.040  -77.852  52.718  1
127139  94.055  -77.856  52.695  1
127140  94.066  -77.856  52.673  1
127141  94.067  -77.848  52.651  1
127142  94.068  -77.840  52.630  1
127143  94.069  -77.832  52.607  1
127144  94.070  -77.824  52.584  1
127145  94.104  -77.809  52.562  1
127146  94.129  -77.800  52.539  1
127147  94.154  -77.791  52.517  1
127148  94.179  -77.781  52.495  1
127149  94.204  -77.772  52.473  1
127150  94.228  -77.763  52.453  1
127151  94.254  -77.754  52.432  1
127152  94.278  -77.745  52.411  1
127153  94.303  -77.736  52.390  1
127154  94.328  -77.727  52.369  1
127155  94.353  -77.718  52.349  1
127156  94.378  -77.708  52.330  1
127157  94.403  -77.699  52.312  1
127158  94.425  -77.692  52.292  1
127159  94.442  -77.691  52.274  1
127160  94.459  -77.689  52.257  1
127161  94.476  -77.687  52.241  1
127162  94.505  -77.659  52.226  1
127163  94.506  -77.666  52.212  1
127164  94.504  -77.676  52.198  1
127165  94.511  -77.678  52.184  1
127166  94.532  -77.670  52.167  1
127167  94.553  -77.661  52.149  1
127168  94.574  -77.652  52.129  1
127169  94.603  -77.642  52.109  1
127170  94.640  -77.629  52.087  1
127171  94.679  -77.615  52.065  1
127172  94.695  -77.613  52.041  1
127173  94.663  -77.611  52.018  1
127174  94.632  -77.610  51.995  1
127175  94.616  -77.615  51.972  1
127176  94.615  -77.629  51.948  1
127177  94.627  -77.669  51.923  1
127178  94.644  -77.700  51.899  1
127179  94.660  -77.686  51.873  1
127180  94.674  -77.673  51.846  1
127181  94.689  -77.659  51.819  1
127182  94.702  -77.650  51.792  1
127183  94.708  -77.656  51.763  1
127184  94.714  -77.663  51.732  1
127185  94.727  -77.670  51.699  1
127186  94.749  -77.677  51.666  1
127187  94.771  -77.683  51.631  1
127188  94.793  -77.690  51.598  1
127189  94.789  -77.671  51.565  1
127190  94.784  -77.652  51.531  1
127191  94.780  -77.633  51.498  1
127192  94.786  -77.620  51.465  1
127193  94.813  -77.635  51.428  1
127194  94.834  -77.666  51.391  1
127195  94.874  -77.705  51.353  1
127196  94.909  -77.727  51.313  1
127197  94.943  -77.751  51.274  1
127198  94.938  -77.743  51.235  1
127199  94.934  -77.736  51.197  1
127200  94.939  -77.719  51.158  1
127201  94.968  -77.689  51.118  1
127202  95.012  -77.665  51.078  1
127203  95.084  -77.655  51.036  1
127204  95.082  -77.683  50.997  1
127205  95.046  -77.729  50.956  1
127206  95.048  -77.746  50.915  1
127207  95.075  -77.714  50.874  1
127208  95.095  -77.715  50.834  1
127209  95.115  -77.715  50.794  1
127210  95.134  -77.716  50.754  1
127211  95.154  -77.716  50.716  1
127212  95.173  -77.717  50.678  1
127213  95.193  -77.717  50.639  1
127214  95.212  -77.718  50.600  1
127215  95.218  -77.714  50.563  1
127216  95.224  -77.710  50.526  1
127217  95.230  -77.706  50.489  1
127218  95.235  -77.703  50.454  1
127219  95.243  -77.698  50.420  1
127220  95.268  -77.685  50.385  1
127221  95.294  -77.672  50.351  1
127222  95.318  -77.660  50.317  1
127223  95.343  -77.647  50.284  1
127224  95.369  -77.634  50.251  1
127225  95.386  -77.623  50.220  1
127226  95.394  -77.615  50.189  1
127227  95.401  -77.607  50.158  1
127228  95.409  -77.599  50.126  1
127229  95.428  -77.567  50.096  1
127230  95.469  -77.541  50.066  1
127231  95.514  -77.520  50.036  1
127232  95.559  -77.500  50.007  1
127233  95.604  -77.479  49.978  1
127234  95.644  -77.461  49.950  1
127235  95.643  -77.482  49.922  1
127236  95.625  -77.506  49.893  1
127237  95.608  -77.530  49.865  1
127238  95.590  -77.555  49.838  1
127239  95.580  -77.563  49.810  1
127240  95.603  -77.578  49.780  1
127241  95.627  -77.593  49.750  1
127242  95.651  -77.608  49.719  1
127243  95.682  -77.592  49.688  1
127244  95.684  -77.604  49.656  1
127245  95.649  -77.633  49.625  1
127246  95.641  -77.644  49.595  1
127247  95.650  -77.645  49.565  1
127248  95.659  -77.645  49.536  1
127249  95.668  -77.646  49.508  1
127250  95.677  -77.647  49.481  1
127251  95.685  -77.648  49.454  1
127252  95.694  -77.649  49.428  1
127253  95.703  -77.649  49.401  1
127254  95.712  -77.650  49.376  1
127255  95.720  -77.655  49.348  1
127256  95.728  -77.663  49.318  1
127257  95.735  -77.670  49.286  1
127258  95.742  -77.677  49.253  1
127259  95.751  -77.684  49.217  1
127260  95.768  -77.691  49.179  1
127261  95.785  -77.699  49.140  1
127262  95.803  -77.706  49.103  1
127263  95.824  -77.717  49.066  1
127264  95.850  -77.729  49.028  1
127265  95.875  -77.742  48.992  1
127266  95.898  -77.751  48.955  1
127267  95.921  -77.759  48.918  1
127268  95.944  -77.768  48.881  1
127269  95.967  -77.776  48.846  1
127270  95.989  -77.785  48.811  1
127271  96.012  -77.793  48.776  1
127272  96.035  -77.802  48.740  1
127273  96.057  -77.810  48.704  1
127274  96.078  -77.822  48.669  1
127275  96.098  -77.835  48.632  1
127276  96.118  -77.847  48.598  1
127277  96.138  -77.860  48.564  1
127278  96.146  -77.858  48.530  1
127279  96.152  -77.855  48.498  1
127280  96.159  -77.852  48.467  1
127281  96.156  -77.867  48.437  1
127282  96.154  -77.881  48.407  1
127283  96.161  -77.880  48.379  1
127284  96.168  -77.879  48.351  1
127285  96.174  -77.878  48.323  1
127286  96.181  -77.877  48.294  1
127287  96.188  -77.876  48.266  1
127288  96.212  -77.896  48.237  1
127289  96.238  -77.921  48.209  1
127290  96.265  -77.946  48.184  1
127291  96.292  -77.971  48.160  1
127292  96.319  -77.996  48.137  1
127293  96.343  -78.018  48.116  1
127294  96.346  -78.012  48.094  1
127295  96.348  -78.007  48.071  1
127296  96.345  -78.003  48.048  1
127297  96.342  -78.000  48.027  1
127298  96.340  -77.996  48.007  1
127299  96.345  -77.995  47.987  1
127300  96.350  -77.993  47.966  1
127301  96.356  -77.990  47.944  1
127302  96.361  -77.988  47.924  1
127303  96.386  -77.992  47.904  1
127304  96.414  -77.996  47.882  1
127305  96.433  -78.003  47.859  1
127306  96.443  -78.013  47.836  1
127307  96.452  -78.023  47.813  1
127308  96.462  -78.034  47.787  1
127309  96.471  -78.044  47.760  1
127310  96.481  -78.053  47.732  1
127311  96.486  -78.047  47.705  1
127312  96.489  -78.031  47.678  1
127313  96.493  -78.015  47.650  1
127314  96.496  -77.999  47.623  1
127315  96.499  -77.983  47.598  1
127316  96.502  -77.967  47.572  1
127317  96.529  -77.967  47.547  1
127318  96.561  -77.971  47.524  1
127319  96.595  -77.978  47.500  1
127320  96.628  -77.983  47.476  1
127321  96.643  -78.003  47.452  1
127322  96.648  -78.031  47.427  1
127323  96.653  -78.058  47.404  1
127324  96.658  -78.084  47.381  1
127325  96.669  -78.095  47.357  1
127326  96.679  -78.102  47.333  1
127327  96.693  -78.111  47.309  1
127328  96.707  -78.122  47.284  1
127329  96.721  -78.131  47.259  1
127330  96.735  -78.142  47.233  1
127331  96.748  -78.152  47.206  1
127332  96.762  -78.163  47.178  1
127333  96.776  -78.172  47.153  1
127334  96.790  -78.183  47.127  1
127335  96.804  -78.193  47.101  1
127336  96.815  -78.208  47.077  1
127337  96.825  -78.226  47.052  1
127338  96.843  -78.238  47.025  1
127339  96.862  -78.250  46.997  1
127340  96.880  -78.263  46.970  1
127341  96.898  -78.274  46.941  1
127342  96.916  -78.286  46.914  1
127343  96.934  -78.298  46.889  1
127344  96.952  -78.310  46.867  1
127345  96.970  -78.322  46.844  1
127346  96.990  -78.335  46.822  1
127347  97.017  -78.347  46.797  1
127348  97.045  -78.361  46.773  1
127349  97.075  -78.376  46.749  1
127350  97.103  -78.389  46.725  1
127351  97.133  -78.404  46.700  1
127352  97.166  -78.415  46.676  1
127353  97.208  -78.421  46.652  1
127354  97.249  -78.426  46.630  1
127355  97.291  -78.432  46.607  1
127356  97.332  -78.438  46.585  1
127357  97.374  -78.445  46.564  1
127358  97.415  -78.438  46.543  1
127359  97.457  -78.421  46.524  1
127360  97.513  -78.414  46.505  1
127361  97.555  -78.416  46.490  1
127362  97.578  -78.420  46.474  1
127363  97.601  -78.425  46.458  1
127364  97.625  -78.430  46.442  1
127365  97.648  -78.435  46.423  1
127366  97.671  -78.439  46.404  1
127367  97.706  -78.448  46.385  1
127368  97.747  -78.461  46.366  1
127369  97.806  -78.488  46.348  1
127370  97.847  -78.506  46.329  1
127371  97.855  -78.475  46.311  1
127372  97.884  -78.467  46.293  1
127373  97.929  -78.474  46.275  1
127374  97.973  -78.482  46.258  1
127375  98.017  -78.493  46.242  1
127376  98.050  -78.517  46.226  1
127377  98.099  -78.494  46.210  1
127378  98.132  -78.473  46.194  1
127379  98.157  -78.451  46.179  1
127380  98.150  -78.442  46.165  1
127381  98.132  -78.438  46.150  1
127382  98.114  -78.437  46.136  1
127383  98.131  -78.453  46.122  1
127384  98.154  -78.464  46.108  1
127385  98.176  -78.475  46.094  1
127386  98.170  -78.465  46.078  1
127387  98.165  -78.455  46.063  1
127388  98.180  -78.444  46.047  1
127389  98.218  -78.438  46.030  1
127390  98.255  -78.434  46.013  1
127391  98.293  -78.429  45.996  1
127392  98.331  -78.424  45.979  1
127393  98.338  -78.416  45.961  1
127394  98.319  -78.397  45.941  1
127395  98.318  -78.399  45.922  1
127396  98.319  -78.403  45.902  1
127397  98.331  -78.407  45.882  1
127398  98.343  -78.412  45.862  1
127399  98.361  -78.426  45.841  1
127400  98.385  -78.448  45.820  1
127401  98.401  -78.463  45.800  1
127402  98.414  -78.476  45.780  1
127403  98.426  -78.489  45.759  1
127404  98.437  -78.504  45.738  1
127405  98.436  -78.521  45.718  1
127406  98.451  -78.526  45.698  1
127407  98.464  -78.532  45.678  1
127408  98.477  -78.538  45.659  1
127409  98.489  -78.544  45.640  1
127410  98.502  -78.550  45.620  1
127411  98.514  -78.555  45.599  1
127412  98.526  -78.561  45.579  1
127413  98.539  -78.568  45.559  1
127414  98.555  -78.578  45.539  1
127415  98.566  -78.575  45.520  1
127416  98.573  -78.554  45.502  1
127417  98.582  -78.545  45.484  1
127418  98.594  -78.547  45.465  1
127419  98.606  -78.557  45.448  1
127420  98.621  -78.555  45.430  1
127421  98.645  -78.542  45.412  1
127422  98.674  -78.526  45.395  1
127423  98.703  -78.509  45.378  1
127424  98.732  -78.510  45.361  1
127425  98.766  -78.519  45.344  1
127426  98.798  -78.527  45.328  1
127427  98.822  -78.530  45.312  1
127428  98.814  -78.513  45.296  1
127429  98.806  -78.495  45.281  1
127430  98.806  -78.496  45.265  1
127431  98.826  -78.535  45.249  1
127432  98.846  -78.573  45.234  1
127433  98.868  -78.611  45.219  1
127434  98.908  -78.623  45.204  1
127435  98.917  -78.627  45.190  1
127436  98.979  -78.604  45.176  1
127437  99.041  -78.580  45.164  1
127438  99.075  -78.576  45.152  1
127439  99.094  -78.581  45.139  1
127440  99.113  -78.586  45.126  1
127441  99.132  -78.592  45.113  1
127442  99.151  -78.597  45.101  1
127443  99.170  -78.601  45.090  1
127444  99.190  -78.607  45.078  1
127445  99.226  -78.604  45.067  1
127446  99.217  -78.639  45.056  1
127447  99.211  -78.686  45.043  1
127448  99.194  -78.701  45.031  1
127449  99.177  -78.715  45.019  1
127450  99.218  -78.695  45.006  1
127451  99.251  -78.689  44.993  1
127452  99.305  -78.708  44.980  1
127453  99.360  -78.727  44.967  1
127454  99.414  -78.745  44.956  1
127455  99.469  -78.764  44.942  1
127456  99.524  -78.783  44.930  1
127457  99.578  -78.801  44.918  1
127458  99.633  -78.820  44.905  1
127459  99.688  -78.839  44.892  1
127460  99.722  -78.849  44.879  1
127461  99.741  -78.871  44.867  1
127462  99.771  -78.910  44.854  1
127463  99.791  -78.933  44.842  1
127464  99.811  -78.955  44.831  1
127465  99.831  -78.978  44.821  1
127466  99.850  -78.999  44.812  1
127467  99.863  -79.009  44.803  1
127468  99.876  -79.018  44.795  1
127469  99.890  -79.028  44.788  1
127470  99.903  -79.038  44.782  1
127471  99.916  -79.048  44.777  1
127472  99.929  -79.058  44.771  1
127473  99.942  -79.068  44.766  1
127474  99.955  -79.078  44.761  1
127475  99.983  -79.081  44.756  1
127476  100.022  -79.093  44.752  1
127477  100.040  -79.114  44.748  1
127478  100.060  -79.135  44.744  1
127479  100.089  -79.153  44.740  1
127480  100.118  -79.172  44.736  1
127481  100.148  -79.190  44.732  1
127482  100.177  -79.208  44.727  1
127483  100.207  -79.226  44.723  1
127484  100.235  -79.238  44.719  1
127485  100.262  -79.244  44.714  1
127486  100.289  -79.249  44.709  1
127487  100.317  -79.255  44.704  1
127488  100.344  -79.260  44.698  1
127489  100.371  -79.266  44.691  1
127490  100.400  -79.272  44.684  1
127491  100.438  -79.281  44.677  1
127513  101.232  -79.655  44.440  1
127514  101.264  -79.675  44.425  1
127515  101.338  -79.705  44.409  1
127516  101.397  -79.717  44.393  1
127517  101.450  -79.723  44.376  1
127518  101.498  -79.730  44.360  1
127519  101.522  -79.743  44.344  1
127520  101.548  -79.768  44.327  1
127815  93.857  -77.851  53.210  1
127816  93.870  -77.846  53.191  1
127817  93.884  -77.842  53.172  1
127818  93.896  -77.838  53.152  1
127819  93.909  -77.834  53.132  1
127820  93.922  -77.830  53.113  1
127821  93.935  -77.825  53.094  1
127822  93.947  -77.821  53.075  1
127823  93.961  -77.817  53.057  1
127824  93.973  -77.812  53.038  1
127825  93.985  -77.808  53.019  1
127826  93.983  -77.807  52.999  1
127827  93.980  -77.806  52.980  1
127828  93.978  -77.805  52.961  1
127829  93.976  -77.804  52.941  1
127830  93.973  -77.802  52.921  1
127831  93.971  -77.802  52.902  1
127832  93.968  -77.800  52.881  1
127833  93.967  -77.802  52.860  1
127834  93.971  -77.812  52.840  1
127835  93.979  -77.820  52.818  1
127836  93.995  -77.824  52.796  1
127837  94.011  -77.828  52.775  1
127838  94.027  -77.833  52.754  1
127839  94.043  -77.837  52.732  1
127840  94.059  -77.841  52.709  1
127841  94.067  -77.840  52.687  1
127842  94.068  -77.831  52.665  1
127843  94.069  -77.823  52.644  1
127844  94.070  -77.815  52.621  1
127845  94.072  -77.807  52.598  1
127846  94.105  -77.793  52.576  1
127847  94.130  -77.783  52.554  1
127848  94.155  -77.774  52.532  1
127849  94.180  -77.765  52.510  1
127850  94.205  -77.755  52.488  1
127851  94.230  -77.746  52.468  1
127852  94.255  -77.737  52.447  1
127853  94.280  -77.728  52.426  1
127854  94.305  -77.719  52.405  1
127855  94.330  -77.710  52.385  1
127856  94.355  -77.700  52.365  1
127857  94.376  -77.695  52.346  1
127858  94.393  -77.693  52.328  1
127859  94.410  -77.691  52.309  1
127860  94.427  -77.689  52.292  1
127861  94.444  -77.688  52.275  1
127862  94.464  -77.679  52.260  1
127863  94.494  -77.645  52.245  1
127864  94.492  -77.655  52.231  1
127865  94.490  -77.664  52.217  1
127866  94.489  -77.674  52.204  1
127867  94.498  -77.675  52.188  1
127868  94.520  -77.666  52.171  1
127869  94.554  -77.654  52.153  1
127870  94.592  -77.641  52.132  1
127871  94.630  -77.627  52.111  1
127872  94.668  -77.614  52.090  1
127873  94.702  -77.597  52.066  1
127874  94.728  -77.596  52.043  1
127875  94.636  -77.613  52.020  1
127876  94.602  -77.628  51.997  1
127877  94.616  -77.672  51.974  1
127878  94.634  -77.722  51.948  1
127879  94.650  -77.736  51.922  1
127880  94.665  -77.722  51.896  1
127881  94.680  -77.708  51.869  1
127882  94.695  -77.695  51.843  1
127883  94.709  -77.681  51.814  1
127884  94.724  -77.667  51.785  1
127885  94.738  -77.658  51.754  1
127886  94.744  -77.664  51.722  1
127887  94.757  -77.671  51.688  1
127888  94.779  -77.677  51.654  1
127889  94.791  -77.674  51.622  1
127890  94.787  -77.655  51.590  1
127891  94.783  -77.636  51.556  1
127892  94.779  -77.617  51.524  1
127893  94.777  -77.600  51.491  1
127894  94.804  -77.618  51.456  1
127895  94.836  -77.654  51.418  1
127896  94.872  -77.675  51.379  1
127897  94.906  -77.696  51.340  1
127898  94.941  -77.719  51.301  1
127899  94.973  -77.745  51.262  1
127900  94.952  -77.745  51.224  1
127901  94.980  -77.714  51.184  1
127902  95.008  -77.683  51.143  1
127903  95.037  -77.653  51.102  1
127904  95.065  -77.622  51.061  1
127905  95.080  -77.634  51.021  1
127906  95.073  -77.672  50.980  1
127907  95.060  -77.731  50.939  1
127908  95.077  -77.743  50.897  1
127909  95.108  -77.715  50.855  1
127910  95.127  -77.716  50.815  1
127911  95.147  -77.716  50.775  1
127912  95.167  -77.717  50.736  1
127913  95.186  -77.717  50.697  1
127914  95.205  -77.718  50.658  1
127915  95.212  -77.714  50.619  1
127916  95.217  -77.710  50.581  1
127917  95.223  -77.706  50.544  1
127918  95.229  -77.703  50.507  1
127919  95.234  -77.699  50.471  1
127920  95.251  -77.690  50.436  1
127921  95.276  -77.677  50.401  1
127922  95.301  -77.664  50.366  1
127923  95.326  -77.652  50.331  1
127924  95.351  -77.639  50.298  1
127925  95.376  -77.627  50.265  1
127926  95.398  -77.614  50.233  1
127927  95.405  -77.606  50.201  1
127928  95.412  -77.599  50.170  1
127929  95.420  -77.590  50.138  1
127930  95.447  -77.543  50.107  1
127931  95.492  -77.523  50.077  1
127932  95.537  -77.502  50.047  1
127933  95.582  -77.482  50.017  1
127934  95.619  -77.464  49.988  1
127935  95.635  -77.453  49.959  1
127936  95.672  -77.462  49.931  1
127937  95.692  -77.491  49.901  1
127938  95.674  -77.515  49.873  1
127939  95.658  -77.535  49.845  1
127940  95.645  -77.541  49.818  1
127941  95.633  -77.546  49.789  1
127942  95.641  -77.557  49.760  1
127943  95.668  -77.558  49.730  1
127944  95.679  -77.584  49.699  1
127945  95.665  -77.613  49.667  1
127946  95.658  -77.623  49.636  1
127947  95.659  -77.628  49.605  1
127948  95.660  -77.633  49.575  1
127949  95.661  -77.638  49.546  1
127950  95.662  -77.643  49.518  1
127951  95.670  -77.645  49.491  1
127952  95.678  -77.645  49.464  1
127953  95.687  -77.646  49.437  1
127954  95.696  -77.647  49.411  1
127955  95.705  -77.648  49.384  1
127956  95.714  -77.649  49.355  1
127957  95.722  -77.652  49.326  1
127958  95.730  -77.659  49.294  1
127959  95.737  -77.666  49.262  1
127960  95.745  -77.674  49.227  1
127961  95.763  -77.680  49.189  1
127962  95.780  -77.688  49.150  1
127963  95.802  -77.698  49.112  1
127964  95.827  -77.711  49.075  1
127965  95.852  -77.724  49.037  1
127966  95.877  -77.736  49.001  1
127967  95.900  -77.744  48.965  1
127968  95.922  -77.752  48.928  1
127969  95.945  -77.761  48.891  1
127970  95.968  -77.769  48.855  1
127971  95.991  -77.777  48.820  1
127972  96.014  -77.786  48.785  1
127973  96.036  -77.794  48.749  1
127974  96.059  -77.802  48.714  1
127975  96.082  -77.811  48.678  1
127976  96.103  -77.821  48.642  1
127977  96.123  -77.834  48.608  1
127978  96.144  -77.846  48.574  1
127979  96.158  -77.852  48.540  1
127980  96.164  -77.849  48.507  1
127981  96.170  -77.848  48.475  1
127982  96.164  -77.868  48.444  1
127983  96.158  -77.887  48.413  1
127984  96.165  -77.887  48.385  1
127985  96.172  -77.887  48.357  1
127986  96.179  -77.886  48.330  1
127987  96.185  -77.884  48.301  1
127988  96.198  -77.890  48.272  1
127989  96.225  -77.915  48.243  1
127990  96.252  -77.940  48.215  1
127991  96.278  -77.965  48.190  1
127992  96.306  -77.990  48.166  1
127993  96.324  -78.004  48.143  1
127994  96.326  -77.999  48.120  1
127995  96.329  -77.993  48.096  1
127996  96.331  -77.988  48.073  1
127997  96.328  -77.985  48.050  1
127998  96.326  -77.981  48.029  1
127999  96.323  -77.978  48.010  1
128000  96.320  -77.975  47.990  1
128001  96.318  -77.971  47.969  1
128002  96.322  -77.969  47.948  1
128003  96.340  -77.971  47.927  1
128004  96.368  -77.975  47.908  1
128005  96.396  -77.979  47.888  1
128006  96.424  -77.983  47.867  1
128007  96.450  -77.988  47.845  1
128008  96.460  -77.998  47.822  1
128009  96.469  -78.009  47.796  1
128010  96.479  -78.018  47.769  1
128011  96.488  -78.028  47.742  1
128012  96.496  -78.029  47.717  1
128013  96.499  -78.013  47.689  1
128014  96.502  -77.997  47.662  1
128015  96.505  -77.981  47.636  1
128016  96.508  -77.965  47.611  1
128017  96.528  -77.961  47.586  1
128018  96.559  -77.963  47.561  1
128019  96.590  -77.965  47.537  1
128020  96.620  -77.968  47.514  1
128021  96.639  -77.970  47.490  1
128022  96.651  -77.978  47.467  1
128023  96.661  -77.999  47.442  1
128024  96.666  -78.025  47.418  1
128025  96.671  -78.051  47.395  1
128026  96.676  -78.077  47.372  1
128027  96.687  -78.092  47.348  1
128028  96.700  -78.102  47.324  1
128029  96.715  -78.112  47.299  1
128030  96.728  -78.122  47.272  1
128031  96.742  -78.133  47.245  1
128032  96.756  -78.143  47.218  1
128033  96.769  -78.153  47.192  1
128034  96.783  -78.163  47.165  1
128035  96.797  -78.174  47.139  1
128036  96.811  -78.184  47.114  1
128037  96.823  -78.196  47.089  1
128038  96.840  -78.209  47.064  1
128039  96.859  -78.221  47.037  1
128040  96.877  -78.233  47.009  1
128041  96.895  -78.245  46.981  1
128042  96.912  -78.259  46.953  1
128043  96.930  -78.272  46.926  1
128044  96.948  -78.286  46.903  1
128045  96.965  -78.300  46.882  1
128046  96.983  -78.313  46.861  1
128047  96.999  -78.322  46.840  1
128048  97.016  -78.332  46.816  1
128049  97.045  -78.345  46.793  1
128050  97.074  -78.360  46.769  1
128051  97.103  -78.374  46.745  1
128052  97.132  -78.388  46.720  1
128053  97.169  -78.397  46.696  1
128054  97.211  -78.403  46.672  1
128055  97.252  -78.409  46.649  1
128056  97.294  -78.415  46.626  1
128057  97.335  -78.421  46.603  1
128058  97.377  -78.427  46.582  1
128059  97.418  -78.432  46.562  1
128060  97.460  -78.426  46.543  1
128061  97.501  -78.410  46.526  1
128062  97.562  -78.406  46.511  1
128063  97.590  -78.410  46.495  1
128064  97.613  -78.415  46.479  1
128065  97.636  -78.420  46.462  1
128066  97.660  -78.424  46.444  1
128067  97.683  -78.429  46.425  1
128068  97.706  -78.434  46.406  1
128069  97.730  -78.438  46.387  1
128070  97.779  -78.457  46.368  1
128071  97.805  -78.449  46.349  1
128072  97.847  -78.463  46.330  1
128073  97.886  -78.453  46.312  1
128074  97.931  -78.460  46.294  1
128075  97.975  -78.469  46.277  1
128076  98.018  -78.480  46.261  1
128077  98.051  -78.507  46.244  1
128078  98.089  -78.493  46.229  1
128079  98.123  -78.471  46.213  1
128080  98.136  -78.455  46.198  1
128081  98.117  -78.451  46.183  1
128082  98.109  -78.440  46.168  1
128083  98.110  -78.423  46.154  1
128084  98.113  -78.422  46.141  1
128085  98.119  -78.427  46.127  1
128086  98.142  -78.438  46.111  1
128087  98.159  -78.445  46.096  1
128088  98.153  -78.435  46.080  1
128089  98.209  -78.413  46.064  1
128090  98.271  -78.397  46.048  1
128091  98.306  -78.392  46.031  1
128092  98.309  -78.389  46.014  1
128093  98.311  -78.386  45.996  1
128094  98.314  -78.384  45.977  1
128095  98.315  -78.382  45.958  1
128096  98.314  -78.386  45.938  1
128097  98.313  -78.390  45.918  1
128098  98.319  -78.394  45.898  1
128099  98.331  -78.398  45.878  1
128100  98.351  -78.413  45.858  1
128101  98.374  -78.436  45.838  1
128102  98.395  -78.456  45.817  1
128103  98.408  -78.469  45.796  1
128104  98.421  -78.482  45.775  1
128105  98.421  -78.502  45.754  1
128106  98.425  -78.515  45.733  1
128107  98.440  -78.520  45.713  1
128108  98.455  -78.526  45.694  1
128109  98.467  -78.532  45.674  1
128110  98.480  -78.538  45.654  1
128111  98.492  -78.544  45.634  1
128112  98.504  -78.549  45.614  1
128113  98.518  -78.557  45.593  1
128114  98.533  -78.567  45.573  1
128115  98.549  -78.577  45.553  1
128116  98.557  -78.560  45.533  1
128117  98.563  -78.539  45.515  1
128118  98.571  -78.522  45.496  1
128119  98.582  -78.535  45.477  1
128120  98.593  -78.556  45.459  1
128121  98.604  -78.577  45.441  1
128122  98.624  -78.576  45.423  1
128123  98.663  -78.545  45.405  1
128124  98.704  -78.510  45.387  1
128125  98.739  -78.494  45.370  1
128126  98.764  -78.505  45.353  1
128127  98.788  -78.517  45.336  1
128128  98.821  -78.526  45.320  1
128129  98.846  -78.529  45.304  1
128130  98.838  -78.511  45.288  1
128131  98.837  -78.498  45.273  1
128132  98.846  -78.532  45.257  1
128133  98.855  -78.567  45.242  1
128134  98.864  -78.602  45.228  1
128135  98.875  -78.634  45.213  1
128136  98.937  -78.611  45.199  1
128137  99.000  -78.587  45.186  1
128138  99.062  -78.564  45.174  1
128139  99.082  -78.568  45.162  1
128140  99.101  -78.573  45.150  1
128141  99.121  -78.579  45.136  1
128142  99.140  -78.584  45.124  1
128143  99.159  -78.589  45.112  1
128144  99.178  -78.594  45.100  1
128145  99.197  -78.599  45.087  1
128146  99.217  -78.604  45.075  1
128147  99.253  -78.602  45.064  1
128148  99.233  -78.653  45.052  1
128149  99.217  -78.667  45.041  1
128150  99.200  -78.683  45.029  1
128151  99.208  -78.681  45.016  1
128152  99.249  -78.685  45.003  1
128153  99.304  -78.704  44.989  1
128154  99.358  -78.723  44.976  1
128155  99.413  -78.741  44.964  1
128156  99.468  -78.760  44.950  1
128157  99.522  -78.779  44.937  1
128158  99.577  -78.797  44.924  1
128159  99.632  -78.816  44.912  1
128160  99.686  -78.835  44.899  1
128161  99.738  -78.852  44.886  1
128162  99.755  -78.868  44.873  1
128163  99.781  -78.903  44.861  1
128164  99.801  -78.926  44.849  1
128165  99.822  -78.949  44.838  1
128166  99.838  -78.965  44.827  1
128167  99.852  -78.975  44.818  1
128168  99.865  -78.985  44.809  1
128169  99.878  -78.995  44.801  1
128170  99.891  -79.005  44.794  1
128171  99.904  -79.015  44.788  1
128172  99.917  -79.024  44.782  1
128173  99.930  -79.034  44.776  1
128174  99.943  -79.044  44.771  1
128175  99.957  -79.054  44.765  1
128176  99.984  -79.059  44.761  1
128177  100.023  -79.071  44.756  1
128178  100.033  -79.095  44.752  1
128179  100.062  -79.113  44.748  1
128180  100.091  -79.131  44.744  1
128181  100.121  -79.150  44.740  1
128182  100.150  -79.168  44.735  1
128183  100.180  -79.186  44.731  1
128184  100.209  -79.205  44.726  1
128185  100.238  -79.219  44.722  1
128186  100.265  -79.224  44.717  1
128187  100.292  -79.229  44.712  1
128188  100.320  -79.234  44.706  1
128189  100.347  -79.241  44.700  1
128190  100.374  -79.246  44.694  1
128191  100.406  -79.253  44.687  1
128478  93.409  -78.125  53.895  1
128479  93.418  -78.122  53.882  1
128515  93.845  -77.844  53.239  1
128516  93.858  -77.840  53.220  1
128517  93.871  -77.835  53.202  1
128518  93.884  -77.831  53.183  1
128519  93.897  -77.827  53.164  1
128520  93.910  -77.822  53.144  1
128521  93.922  -77.818  53.126  1
128522  93.935  -77.814  53.107  1
128523  93.948  -77.809  53.088  1
128524  93.961  -77.805  53.070  1
128525  93.974  -77.801  53.051  1
128526  93.986  -77.797  53.032  1
128527  93.983  -77.796  53.013  1
128528  93.981  -77.795  52.994  1
128529  93.978  -77.793  52.974  1
128530  93.976  -77.793  52.955  1
128531  93.974  -77.791  52.936  1
128532  93.971  -77.790  52.915  1
128533  93.969  -77.790  52.895  1
128534  93.967  -77.789  52.874  1
128535  93.970  -77.799  52.853  1
128536  93.983  -77.805  52.832  1
128537  93.998  -77.809  52.810  1
128538  94.014  -77.813  52.789  1
128539  94.030  -77.818  52.768  1
128540  94.046  -77.822  52.746  1
128541  94.062  -77.826  52.724  1
128542  94.068  -77.823  52.702  1
128543  94.070  -77.815  52.679  1
128544  94.071  -77.806  52.657  1
128545  94.072  -77.799  52.635  1
128546  94.073  -77.790  52.612  1
128547  94.107  -77.775  52.591  1
128548  94.132  -77.766  52.569  1
128549  94.156  -77.757  52.547  1
128550  94.182  -77.748  52.525  1
128551  94.206  -77.739  52.503  1
128552  94.231  -77.730  52.483  1
128553  94.257  -77.721  52.462  1
128554  94.281  -77.711  52.441  1
128555  94.307  -77.702  52.420  1
128556  94.326  -77.697  52.401  1
128557  94.343  -77.696  52.382  1
128558  94.360  -77.694  52.363  1
128559  94.378  -77.692  52.345  1
128560  94.395  -77.690  52.328  1
128561  94.412  -77.688  52.311  1
128562  94.429  -77.686  52.295  1
128563  94.458  -77.657  52.280  1
128564  94.480  -77.633  52.266  1
128565  94.478  -77.643  52.252  1
128566  94.477  -77.653  52.239  1
128567  94.475  -77.663  52.225  1
128568  94.475  -77.673  52.211  1
128569  94.488  -77.660  52.196  1
128570  94.504  -77.640  52.178  1
128571  94.520  -77.620  52.158  1
128572  94.536  -77.600  52.137  1
128573  94.552  -77.580  52.116  1
128574  94.699  -77.587  52.093  1
128575  94.680  -77.607  52.071  1
128576  94.597  -77.627  52.050  1
128577  94.604  -77.675  52.027  1
128578  94.622  -77.725  52.003  1
128579  94.640  -77.776  51.977  1
128580  94.655  -77.771  51.950  1
128581  94.670  -77.757  51.924  1
128582  94.685  -77.744  51.897  1
128583  94.700  -77.730  51.869  1
128584  94.715  -77.717  51.841  1
128585  94.730  -77.703  51.812  1
128586  94.745  -77.689  51.781  1
128587  94.759  -77.676  51.748  1
128588  94.773  -77.664  51.714  1
128589  94.787  -77.671  51.680  1
128590  94.789  -77.658  51.647  1
128591  94.785  -77.639  51.615  1
128592  94.781  -77.620  51.584  1
128593  94.777  -77.602  51.553  1
128594  94.773  -77.583  51.521  1
128595  94.799  -77.602  51.484  1
128596  94.834  -77.624  51.446  1
128597  94.868  -77.644  51.408  1
128598  94.904  -77.665  51.369  1
128599  94.938  -77.688  51.331  1
128600  94.971  -77.713  51.293  1
128601  94.995  -77.700  51.253  1
128602  95.018  -77.672  51.211  1
128603  95.041  -77.644  51.170  1
128604  95.064  -77.616  51.128  1
128605  95.087  -77.588  51.087  1
128606  95.099  -77.588  51.046  1
128607  95.090  -77.645  51.005  1
128608  95.076  -77.705  50.964  1
128609  95.088  -77.729  50.922  1
128610  95.112  -77.735  50.879  1
128611  95.140  -77.716  50.837  1
128612  95.160  -77.716  50.797  1
128613  95.179  -77.717  50.757  1
128614  95.199  -77.717  50.718  1
128615  95.205  -77.714  50.679  1
128616  95.211  -77.710  50.639  1
128617  95.216  -77.706  50.601  1
128618  95.222  -77.703  50.563  1
128619  95.228  -77.699  50.526  1
128620  95.233  -77.696  50.490  1
128621  95.258  -77.683  50.454  1
128622  95.283  -77.670  50.419  1
128623  95.308  -77.657  50.382  1
128624  95.333  -77.645  50.347  1
128625  95.358  -77.632  50.313  1
128626  95.383  -77.619  50.280  1
128627  95.408  -77.606  50.247  1
128628  95.416  -77.598  50.215  1
128629  95.424  -77.589  50.183  1
128630  95.439  -77.567  50.151  1
128631  95.470  -77.525  50.120  1
128632  95.515  -77.504  50.089  1
128633  95.560  -77.484  50.058  1
128634  95.594  -77.467  50.028  1
128635  95.610  -77.457  49.999  1
128636  95.627  -77.445  49.969  1
128637  95.644  -77.436  49.940  1
128638  95.706  -77.469  49.910  1
128639  95.740  -77.500  49.881  1
128640  95.726  -77.514  49.854  1
128641  95.713  -77.519  49.826  1
128642  95.703  -77.530  49.797  1
128643  95.694  -77.548  49.769  1
128644  95.685  -77.566  49.741  1
128645  95.680  -77.591  49.710  1
128646  95.678  -77.602  49.679  1
128647  95.681  -77.605  49.647  1
128648  95.681  -77.610  49.616  1
128649  95.682  -77.614  49.586  1
128650  95.683  -77.620  49.557  1
128651  95.684  -77.625  49.529  1
128652  95.685  -77.630  49.500  1
128653  95.686  -77.635  49.474  1
128654  95.687  -77.640  49.447  1
128655  95.689  -77.644  49.420  1
128656  95.698  -77.645  49.392  1
128657  95.707  -77.645  49.364  1
128658  95.716  -77.646  49.334  1
128659  95.725  -77.649  49.303  1
128660  95.732  -77.655  49.271  1
128661  95.740  -77.662  49.237  1
128662  95.757  -77.670  49.199  1
128663  95.778  -77.680  49.160  1
128664  95.804  -77.692  49.122  1
128665  95.829  -77.705  49.084  1
128666  95.854  -77.718  49.047  1
128667  95.879  -77.728  49.011  1
128668  95.901  -77.736  48.974  1
128669  95.924  -77.745  48.938  1
128670  95.947  -77.753  48.901  1
128671  95.969  -77.762  48.865  1
128672  95.992  -77.771  48.829  1
128673  96.015  -77.779  48.793  1
128674  96.038  -77.787  48.757  1
128675  96.060  -77.796  48.722  1
128676  96.083  -77.804  48.687  1
128677  96.106  -77.812  48.652  1
128678  96.129  -77.821  48.618  1
128679  96.149  -77.834  48.584  1
128680  96.169  -77.846  48.550  1
128681  96.176  -77.843  48.516  1
128682  96.178  -77.849  48.484  1
128683  96.172  -77.869  48.452  1
128684  96.166  -77.889  48.421  1
128685  96.169  -77.895  48.393  1
128686  96.176  -77.894  48.365  1
128687  96.183  -77.893  48.337  1
128688  96.190  -77.892  48.308  1
128689  96.211  -77.909  48.280  1
128690  96.238  -77.934  48.251  1
128691  96.265  -77.959  48.223  1
128692  96.292  -77.984  48.198  1
128693  96.304  -77.991  48.174  1
128694  96.307  -77.986  48.149  1
128695  96.309  -77.981  48.125  1
128696  96.311  -77.975  48.101  1
128697  96.314  -77.970  48.077  1
128698  96.311  -77.966  48.055  1
128699  96.309  -77.962  48.034  1
128700  96.306  -77.959  48.014  1
128701  96.303  -77.956  47.994  1
128702  96.301  -77.953  47.974  1
128703  96.303  -77.949  47.952  1
128704  96.325  -77.953  47.931  1
128705  96.350  -77.957  47.912  1
128706  96.378  -77.962  47.892  1
128707  96.406  -77.966  47.873  1
128708  96.435  -77.970  47.851  1
128709  96.463  -77.975  47.829  1
128710  96.477  -77.983  47.803  1
128711  96.486  -77.993  47.777  1
128712  96.496  -78.003  47.751  1
128713  96.506  -78.012  47.727  1
128714  96.509  -77.996  47.700  1
128715  96.512  -77.980  47.674  1
128716  96.515  -77.964  47.648  1
128717  96.528  -77.955  47.623  1
128718  96.559  -77.958  47.599  1
128719  96.589  -77.960  47.575  1
128720  96.615  -77.962  47.550  1
128721  96.625  -77.963  47.528  1
128722  96.637  -77.965  47.504  1
128723  96.647  -77.967  47.481  1
128724  96.662  -77.984  47.455  1
128725  96.676  -78.002  47.432  1
128726  96.685  -78.025  47.409  1
128727  96.690  -78.050  47.386  1
128728  96.695  -78.076  47.361  1
128729  96.709  -78.087  47.336  1
128730  96.722  -78.097  47.311  1
128731  96.736  -78.107  47.284  1
128732  96.750  -78.118  47.257  1
128733  96.763  -78.128  47.230  1
128734  96.777  -78.139  47.204  1
128735  96.791  -78.149  47.177  1
128736  96.805  -78.159  47.151  1
128737  96.822  -78.173  47.125  1
128738  96.833  -78.191  47.100  1
128739  96.851  -78.204  47.074  1
128740  96.869  -78.218  47.047  1
128741  96.887  -78.232  47.019  1
128742  96.904  -78.245  46.991  1
128743  96.922  -78.259  46.963  1
128744  96.940  -78.272  46.938  1
128745  96.957  -78.286  46.915  1
128746  96.973  -78.294  46.895  1
128747  96.987  -78.300  46.875  1
128748  97.004  -78.308  46.856  1
128749  97.021  -78.318  46.834  1
128750  97.045  -78.330  46.811  1
128751  97.074  -78.344  46.788  1
128752  97.103  -78.359  46.764  1
128753  97.132  -78.373  46.740  1
128754  97.172  -78.379  46.716  1
128755  97.214  -78.385  46.691  1
128756  97.255  -78.391  46.667  1
128757  97.297  -78.398  46.645  1
128758  97.338  -78.403  46.623  1
128759  97.380  -78.409  46.602  1
128760  97.421  -78.415  46.581  1
128761  97.463  -78.421  46.564  1
128762  97.504  -78.416  46.549  1
128763  97.548  -78.401  46.532  1
128764  97.602  -78.400  46.514  1
128765  97.625  -78.404  46.497  1
128766  97.648  -78.409  46.480  1
128767  97.671  -78.414  46.463  1
128768  97.695  -78.419  46.445  1
128769  97.718  -78.423  46.426  1
128770  97.741  -78.428  46.408  1
128771  97.770  -78.442  46.389  1
128772  97.831  -78.507  46.370  1
128773  97.869  -78.510  46.351  1
128774  97.906  -78.496  46.332  1
128775  97.943  -78.483  46.315  1
128776  97.981  -78.470  46.298  1
128777  98.017  -78.460  46.281  1
128778  98.050  -78.464  46.265  1
128779  98.082  -78.470  46.249  1
128780  98.114  -78.470  46.234  1
128781  98.115  -78.455  46.218  1
128782  98.117  -78.438  46.203  1
128783  98.119  -78.420  46.189  1
128784  98.120  -78.403  46.175  1
128785  98.123  -78.398  46.161  1
128786  98.126  -78.403  46.146  1
128787  98.130  -78.408  46.131  1
128788  98.133  -78.413  46.114  1
128789  98.144  -78.415  46.098  1
128790  98.217  -78.391  46.082  1
128791  98.269  -78.375  46.066  1
128792  98.301  -78.365  46.049  1
128793  98.307  -78.363  46.031  1
128794  98.313  -78.363  46.013  1
128795  98.319  -78.361  45.994  1
128796  98.327  -78.357  45.974  1
128797  98.315  -78.369  45.955  1
128798  98.310  -78.376  45.934  1
128799  98.309  -78.380  45.914  1
128800  98.319  -78.384  45.894  1
128801  98.340  -78.402  45.874  1
128802  98.364  -78.424  45.854  1
128803  98.387  -78.447  45.833  1
128804  98.402  -78.461  45.813  1
128805  98.415  -78.475  45.792  1
128806  98.404  -78.501  45.771  1
128807  98.415  -78.510  45.749  1
128808  98.430  -78.515  45.729  1
128809  98.445  -78.520  45.710  1
128810  98.458  -78.526  45.689  1
128811  98.470  -78.532  45.669  1
128812  98.483  -78.538  45.649  1
128813  98.497  -78.545  45.629  1
128814  98.512  -78.556  45.608  1
128815  98.527  -78.566  45.587  1
128816  98.540  -78.565  45.567  1
128817  98.547  -78.544  45.547  1
128818  98.554  -78.523  45.528  1
128819  98.557  -78.482  45.508  1
128820  98.568  -78.501  45.489  1
128821  98.581  -78.526  45.470  1
128822  98.598  -78.558  45.452  1
128823  98.632  -78.564  45.434  1
128824  98.674  -78.532  45.416  1
128825  98.715  -78.497  45.398  1
128826  98.752  -78.474  45.381  1
128827  98.777  -78.486  45.363  1
128828  98.801  -78.498  45.346  1
128829  98.826  -78.510  45.329  1
128830  98.851  -78.521  45.313  1
128831  98.869  -78.514  45.297  1
128832  98.869  -78.495  45.282  1
128833  98.877  -78.507  45.267  1
128834  98.886  -78.519  45.251  1
128835  98.895  -78.531  45.237  1
128836  98.903  -78.543  45.223  1
128837  98.958  -78.588  45.209  1
128838  99.020  -78.570  45.196  1
128839  99.070  -78.555  45.184  1
128840  99.089  -78.561  45.171  1
128841  99.109  -78.566  45.159  1
128842  99.128  -78.571  45.147  1
128843  99.147  -78.576  45.134  1
128844  99.166  -78.581  45.122  1
128845  99.186  -78.586  45.109  1
128846  99.205  -78.592  45.097  1
128847  99.224  -78.596  45.085  1
128848  99.243  -78.601  45.073  1
128849  99.256  -78.620  45.062  1
128850  99.239  -78.635  45.051  1
128851  99.223  -78.649  45.039  1
128852  99.206  -78.664  45.026  1
128853  99.248  -78.682  45.013  1
128854  99.302  -78.700  45.000  1
128855  99.357  -78.719  44.986  1
128856  99.412  -78.738  44.973  1
128857  99.466  -78.756  44.959  1
128858  99.521  -78.775  44.946  1
128859  99.575  -78.794  44.932  1
128860  99.630  -78.812  44.919  1
128861  99.685  -78.831  44.906  1
128862  99.739  -78.850  44.894  1
128863  99.768  -78.867  44.881  1
128864  99.792  -78.896  44.868  1
128865  99.812  -78.919  44.857  1
128866  99.827  -78.931  44.845  1
128867  99.840  -78.941  44.834  1
128868  99.853  -78.951  44.825  1
128869  99.866  -78.961  44.816  1
128870  99.879  -78.971  44.808  1
128871  99.893  -78.981  44.800  1
128872  99.906  -78.991  44.794  1
128873  99.919  -79.001  44.788  1
128874  99.932  -79.011  44.782  1
128875  99.945  -79.021  44.776  1
128876  99.959  -79.031  44.770  1
128877  99.985  -79.036  44.766  1
128878  100.015  -79.052  44.762  1
128879  100.034  -79.073  44.758  1
128880  100.064  -79.091  44.753  1
128881  100.093  -79.109  44.749  1
128882  100.123  -79.128  44.745  1
128883  100.152  -79.146  44.740  1
128884  100.182  -79.165  44.736  1
128885  100.211  -79.183  44.731  1
128886  100.240  -79.198  44.727  1
128887  100.267  -79.204  44.722  1
128888  100.295  -79.209  44.716  1
128889  100.322  -79.215  44.710  1
128890  100.349  -79.220  44.704  1
128891  100.376  -79.226  44.698  1
128892  100.413  -79.235  44.690  1
129175  93.340  -78.145  53.951  1
129176  93.363  -78.133  53.941  1
129177  93.387  -78.121  53.931  1
129178  93.399  -78.116  53.918  1
129179  93.409  -78.114  53.905  1
129180  93.419  -78.112  53.892  1
129181  93.428  -78.109  53.880  1
129182  93.438  -78.106  53.866  1
129183  93.444  -78.102  53.853  1
129184  93.445  -78.091  53.840  1
129215  93.833  -77.837  53.270  1
129216  93.846  -77.833  53.251  1
129217  93.859  -77.828  53.231  1
129218  93.871  -77.824  53.212  1
129219  93.885  -77.820  53.194  1
129220  93.897  -77.815  53.176  1
129221  93.910  -77.812  53.157  1
129222  93.923  -77.807  53.138  1
129223  93.936  -77.802  53.120  1
129224  93.949  -77.799  53.101  1
129225  93.962  -77.794  53.083  1
129226  93.975  -77.790  53.065  1
129227  93.986  -77.786  53.046  1
129228  93.984  -77.785  53.028  1
129229  93.981  -77.783  53.009  1
129230  93.979  -77.783  52.990  1
129231  93.977  -77.781  52.971  1
129232  93.974  -77.780  52.951  1
129233  93.972  -77.779  52.931  1
129234  93.969  -77.778  52.911  1
129235  93.967  -77.777  52.890  1
129236  93.970  -77.786  52.869  1
129237  93.986  -77.790  52.847  1
129238  94.001  -77.794  52.826  1
129239  94.017  -77.799  52.804  1
129240  94.033  -77.802  52.783  1
129241  94.049  -77.807  52.761  1
129242  94.065  -77.811  52.739  1
129243  94.070  -77.806  52.717  1
129244  94.071  -77.798  52.695  1
129245  94.072  -77.790  52.673  1
129246  94.073  -77.782  52.650  1
129247  94.074  -77.774  52.628  1
129248  94.108  -77.758  52.606  1
129249  94.133  -77.749  52.584  1
129250  94.158  -77.740  52.562  1
129251  94.183  -77.731  52.541  1
129252  94.208  -77.722  52.519  1
129253  94.233  -77.713  52.499  1
129254  94.258  -77.703  52.478  1
129255  94.277  -77.699  52.458  1
129256  94.294  -77.698  52.436  1
129257  94.311  -77.696  52.417  1
129258  94.328  -77.694  52.399  1
129259  94.345  -77.692  52.382  1
129260  94.362  -77.690  52.364  1
129261  94.380  -77.689  52.347  1
129262  94.397  -77.687  52.331  1
129263  94.417  -77.677  52.315  1
129264  94.452  -77.636  52.301  1
129265  94.466  -77.622  52.288  1
129266  94.465  -77.632  52.275  1
129267  94.463  -77.642  52.262  1
129268  94.465  -77.651  52.249  1
129269  94.473  -77.659  52.235  1
129270  94.485  -77.652  52.222  1
129271  94.501  -77.633  52.204  1
129272  94.517  -77.613  52.185  1
129273  94.533  -77.593  52.165  1
129274  94.590  -77.582  52.144  1
129275  94.666  -77.602  52.121  1
129276  94.582  -77.622  52.100  1
129277  94.591  -77.676  52.080  1
129278  94.611  -77.728  52.057  1
129279  94.628  -77.779  52.033  1
129280  94.646  -77.820  52.008  1
129281  94.661  -77.806  51.982  1
129282  94.676  -77.793  51.955  1
129283  94.690  -77.779  51.928  1
129284  94.705  -77.765  51.901  1
129285  94.720  -77.752  51.873  1
129286  94.735  -77.739  51.844  1
129287  94.750  -77.725  51.812  1
129288  94.765  -77.711  51.778  1
129289  94.780  -77.698  51.743  1
129290  94.786  -77.658  51.709  1
129291  94.803  -77.667  51.675  1
129292  94.799  -77.648  51.642  1
129293  94.794  -77.629  51.612  1
129294  94.790  -77.609  51.581  1
129295  94.786  -77.575  51.549  1
129296  94.805  -77.575  51.512  1
129297  94.831  -77.592  51.474  1
129298  94.866  -77.614  51.437  1
129299  94.901  -77.634  51.401  1
129300  94.936  -77.656  51.364  1
129301  94.968  -77.680  51.326  1
129302  95.001  -77.670  51.287  1
129303  95.024  -77.641  51.244  1
129304  95.047  -77.613  51.201  1
129305  95.069  -77.585  51.159  1
129306  95.076  -77.572  51.117  1
129307  95.078  -77.576  51.074  1
129308  95.105  -77.619  51.033  1
129309  95.092  -77.678  50.992  1
129310  95.084  -77.730  50.948  1
129311  95.124  -77.716  50.905  1
129312  95.147  -77.721  50.862  1
129313  95.172  -77.717  50.821  1
129314  95.192  -77.717  50.781  1
129315  95.199  -77.714  50.740  1
129316  95.204  -77.710  50.701  1
129317  95.210  -77.706  50.661  1
129318  95.215  -77.702  50.622  1
129319  95.221  -77.699  50.584  1
129320  95.227  -77.696  50.546  1
129321  95.241  -77.688  50.509  1
129322  95.266  -77.675  50.473  1
129323  95.290  -77.662  50.437  1
129324  95.316  -77.649  50.401  1
129325  95.341  -77.637  50.366  1
129326  95.366  -77.624  50.331  1
129327  95.391  -77.611  50.296  1
129328  95.416  -77.599  50.263  1
129329  95.427  -77.589  50.230  1
129330  95.435  -77.581  50.198  1
129331  95.458  -77.542  50.166  1
129332  95.493  -77.507  50.134  1
129333  95.539  -77.486  50.102  1
129334  95.569  -77.471  50.071  1
129335  95.585  -77.460  50.041  1
129336  95.602  -77.448  50.011  1
129337  95.618  -77.438  49.981  1
129338  95.634  -77.426  49.951  1
129339  95.678  -77.442  49.921  1
129340  95.750  -77.486  49.892  1
129341  95.763  -77.515  49.863  1
129342  95.749  -77.531  49.834  1
129343  95.734  -77.547  49.806  1
129344  95.719  -77.563  49.779  1
129345  95.702  -77.573  49.751  1
129346  95.678  -77.595  49.722  1
129347  95.678  -77.603  49.691  1
129348  95.681  -77.606  49.659  1
129349  95.685  -77.608  49.627  1
129350  95.688  -77.611  49.597  1
129351  95.692  -77.614  49.568  1
129352  95.695  -77.617  49.539  1
129353  95.699  -77.619  49.510  1
129354  95.702  -77.622  49.484  1
129355  95.706  -77.625  49.457  1
129356  95.709  -77.627  49.430  1
129357  95.711  -77.632  49.402  1
129358  95.712  -77.636  49.373  1
129359  95.713  -77.642  49.343  1
129360  95.718  -77.645  49.313  1
129361  95.727  -77.645  49.281  1
129362  95.735  -77.652  49.247  1
129363  95.755  -77.661  49.210  1
129364  95.780  -77.674  49.171  1
129365  95.806  -77.686  49.133  1
129366  95.831  -77.699  49.095  1
129367  95.856  -77.711  49.058  1
129368  95.880  -77.721  49.021  1
129369  95.903  -77.730  48.984  1
129370  95.925  -77.738  48.948  1
129371  95.948  -77.746  48.911  1
129372  95.971  -77.755  48.875  1
129373  95.993  -77.763  48.839  1
129374  96.017  -77.771  48.802  1
129375  96.039  -77.780  48.766  1
129376  96.062  -77.788  48.730  1
129377  96.085  -77.797  48.695  1
129378  96.107  -77.805  48.661  1
129379  96.130  -77.814  48.627  1
129380  96.153  -77.822  48.594  1
129381  96.174  -77.833  48.560  1
129382  96.188  -77.837  48.526  1
129383  96.186  -77.850  48.494  1
129384  96.180  -77.870  48.462  1
129385  96.174  -77.890  48.430  1
129386  96.173  -77.902  48.402  1
129387  96.180  -77.901  48.373  1
129388  96.187  -77.900  48.345  1
129389  96.197  -77.904  48.316  1
129390  96.225  -77.929  48.288  1
129391  96.251  -77.954  48.261  1
129392  96.278  -77.978  48.233  1
129393  96.285  -77.978  48.209  1
129394  96.287  -77.973  48.183  1
129395  96.290  -77.967  48.157  1
129396  96.292  -77.962  48.132  1
129397  96.294  -77.956  48.108  1
129398  96.297  -77.951  48.084  1
129399  96.294  -77.947  48.061  1
129400  96.292  -77.944  48.041  1
129401  96.289  -77.940  48.020  1
129402  96.287  -77.937  47.999  1
129403  96.284  -77.934  47.979  1
129404  96.303  -77.930  47.957  1
129405  96.324  -77.933  47.936  1
129406  96.346  -77.938  47.915  1
129407  96.368  -77.943  47.896  1
129408  96.390  -77.949  47.875  1
129409  96.416  -77.953  47.854  1
129410  96.445  -77.957  47.833  1
129411  96.473  -77.962  47.809  1
129412  96.494  -77.968  47.785  1
129413  96.504  -77.978  47.761  1
129414  96.513  -77.988  47.736  1
129415  96.518  -77.978  47.711  1
129416  96.521  -77.962  47.686  1
129417  96.528  -77.949  47.660  1
129418  96.558  -77.952  47.635  1
129419  96.589  -77.954  47.611  1
129420  96.601  -77.956  47.587  1
129421  96.612  -77.957  47.563  1
129422  96.623  -77.959  47.541  1
129423  96.633  -77.960  47.518  1
129424  96.644  -77.962  47.494  1
129425  96.658  -77.975  47.469  1
129426  96.672  -77.992  47.445  1
129427  96.687  -78.009  47.422  1
129428  96.701  -78.026  47.398  1
129429  96.709  -78.050  47.372  1
129430  96.717  -78.071  47.346  1
129431  96.730  -78.081  47.320  1
129432  96.744  -78.092  47.295  1
129433  96.758  -78.102  47.269  1
129434  96.771  -78.112  47.243  1
129435  96.789  -78.126  47.215  1
129436  96.807  -78.139  47.188  1
129437  96.825  -78.153  47.162  1
129438  96.836  -78.170  47.136  1
129439  96.845  -78.189  47.109  1
129440  96.861  -78.204  47.083  1
129441  96.878  -78.218  47.056  1
129442  96.896  -78.231  47.028  1
129443  96.913  -78.244  47.000  1
129444  96.932  -78.258  46.973  1
129445  96.947  -78.266  46.949  1
129446  96.961  -78.272  46.925  1
129447  96.976  -78.279  46.906  1
129448  96.992  -78.286  46.886  1
129449  97.009  -78.295  46.867  1
129450  97.027  -78.305  46.848  1
129451  97.045  -78.315  46.827  1
129452  97.074  -78.329  46.804  1
129453  97.103  -78.343  46.782  1
129454  97.134  -78.356  46.759  1
129455  97.175  -78.362  46.734  1
129456  97.217  -78.368  46.710  1
129457  97.258  -78.373  46.688  1
129458  97.300  -78.379  46.667  1
129459  97.342  -78.385  46.644  1
129460  97.383  -78.391  46.622  1
129461  97.424  -78.398  46.601  1
129462  97.466  -78.404  46.584  1
129463  97.507  -78.409  46.567  1
129464  97.548  -78.405  46.550  1
129465  97.596  -78.392  46.532  1
129466  97.637  -78.394  46.514  1
129467  97.660  -78.399  46.497  1
129468  97.683  -78.404  46.480  1
129469  97.707  -78.408  46.463  1
129470  97.730  -78.413  46.446  1
129471  97.753  -78.418  46.429  1
129472  97.802  -78.465  46.410  1
129473  97.832  -78.492  46.390  1
129474  97.857  -78.486  46.370  1
129475  97.891  -78.476  46.352  1
129476  97.929  -78.462  46.336  1
129477  97.966  -78.449  46.319  1
129478  98.003  -78.436  46.302  1
129479  98.037  -78.437  46.286  1
129480  98.070  -78.441  46.270  1
129481  98.101  -78.445  46.255  1
129482  98.115  -78.435  46.240  1
129483  98.127  -78.418  46.225  1
129484  98.128  -78.400  46.210  1
129485  98.130  -78.382  46.195  1
129486  98.132  -78.375  46.181  1
129487  98.135  -78.380  46.165  1
129488  98.139  -78.385  46.149  1
129489  98.141  -78.391  46.133  1
129490  98.145  -78.400  46.116  1
129491  98.176  -78.388  46.099  1
129492  98.209  -78.376  46.083  1
129493  98.262  -78.360  46.065  1
129494  98.314  -78.343  46.047  1
129495  98.321  -78.341  46.029  1
129496  98.327  -78.340  46.010  1
129497  98.339  -78.332  45.991  1
129498  98.331  -78.340  45.971  1
129499  98.319  -78.352  45.951  1
129500  98.308  -78.364  45.930  1
129501  98.307  -78.370  45.911  1
129502  98.329  -78.390  45.890  1
129503  98.353  -78.413  45.869  1
129504  98.376  -78.435  45.849  1
129505  98.396  -78.454  45.829  1
129506  98.408  -78.468  45.809  1
129507  98.388  -78.499  45.788  1
129508  98.404  -78.504  45.767  1
129509  98.419  -78.509  45.746  1
129510  98.434  -78.514  45.725  1
129511  98.448  -78.520  45.706  1
129512  98.461  -78.526  45.686  1
129513  98.475  -78.534  45.665  1
129514  98.491  -78.545  45.644  1
129515  98.506  -78.554  45.622  1
129516  98.521  -78.564  45.601  1
129517  98.530  -78.550  45.581  1
129518  98.536  -78.527  45.561  1
129519  98.537  -78.467  45.541  1
129520  98.548  -78.446  45.522  1
129521  98.565  -78.479  45.502  1
129522  98.582  -78.511  45.482  1
129523  98.599  -78.543  45.463  1
129524  98.639  -78.538  45.445  1
129525  98.686  -78.518  45.427  1
129526  98.727  -78.483  45.410  1
129527  98.766  -78.455  45.392  1
129528  98.790  -78.467  45.374  1
129529  98.815  -78.479  45.357  1
129530  98.840  -78.490  45.341  1
129531  98.865  -78.500  45.324  1
129532  98.884  -78.476  45.308  1
129533  98.894  -78.485  45.293  1
129534  98.902  -78.498  45.278  1
129535  98.910  -78.512  45.263  1
129536  98.918  -78.526  45.248  1
129537  98.933  -78.538  45.234  1
129538  98.988  -78.540  45.221  1
129539  99.043  -78.543  45.208  1
129540  99.078  -78.548  45.195  1
129541  99.097  -78.553  45.183  1
129542  99.116  -78.558  45.170  1
129543  99.136  -78.563  45.158  1
129544  99.155  -78.568  45.145  1
129545  99.174  -78.573  45.133  1
129546  99.194  -78.578  45.119  1
129547  99.213  -78.582  45.107  1
129548  99.232  -78.588  45.095  1
129549  99.252  -78.592  45.083  1
129550  99.268  -78.601  45.072  1
129551  99.257  -78.621  45.060  1
129552  99.238  -78.641  45.049  1
129553  99.219  -78.661  45.036  1
129554  99.265  -78.670  45.024  1
129555  99.323  -78.703  45.010  1
129556  99.373  -78.720  44.997  1
129557  99.423  -78.738  44.983  1
129558  99.473  -78.755  44.969  1
129559  99.522  -78.772  44.955  1
129560  99.574  -78.790  44.942  1
129561  99.629  -78.809  44.928  1
129562  99.683  -78.827  44.914  1
129563  99.738  -78.846  44.901  1
129564  99.782  -78.865  44.889  1
129565  99.802  -78.888  44.877  1
129566  99.816  -78.898  44.866  1
129567  99.829  -78.908  44.854  1
129568  99.842  -78.918  44.843  1
129569  99.855  -78.927  44.834  1
129570  99.868  -78.937  44.825  1
129571  99.881  -78.947  44.816  1
129572  99.895  -78.957  44.808  1
129573  99.908  -78.967  44.801  1
129574  99.921  -78.977  44.794  1
129575  99.934  -78.987  44.788  1
129576  99.947  -78.996  44.783  1
129577  99.960  -79.006  44.777  1
129578  99.986  -79.014  44.772  1
129579  100.007  -79.033  44.768  1
129580  100.037  -79.051  44.763  1
129581  100.066  -79.069  44.758  1
129582  100.096  -79.087  44.754  1
129583  100.125  -79.106  44.749  1
129584  100.154  -79.124  44.745  1
129585  100.184  -79.143  44.740  1
129586  100.213  -79.161  44.736  1
129587  100.243  -79.178  44.731  1
129588  100.270  -79.184  44.726  1
129589  100.297  -79.190  44.720  1
129590  100.325  -79.195  44.714  1
129591  100.352  -79.200  44.708  1
129592  100.382  -79.207  44.701  1
129593  100.420  -79.217  44.694  1
129874  93.292  -78.158  53.979  1
129875  93.315  -78.147  53.970  1
129876  93.339  -78.134  53.960  1
129877  93.362  -78.122  53.950  1
129878  93.386  -78.111  53.941  1
129879  93.400  -78.106  53.928  1
129880  93.409  -78.103  53.915  1
129881  93.419  -78.101  53.902  1
129882  93.429  -78.098  53.890  1
129883  93.438  -78.096  53.876  1
129884  93.440  -78.089  53.863  1
129885  93.446  -78.076  53.850  1
129886  93.457  -78.060  53.835  1
129887  93.467  -78.045  53.819  1
129888  93.477  -78.029  53.804  1
129889  93.487  -78.014  53.787  1
129916  93.834  -77.826  53.281  1
129917  93.847  -77.821  53.262  1
129918  93.859  -77.817  53.243  1
129919  93.872  -77.813  53.224  1
129920  93.885  -77.808  53.205  1
129921  93.898  -77.804  53.187  1
129922  93.911  -77.800  53.169  1
129923  93.924  -77.796  53.151  1
129924  93.936  -77.791  53.133  1
129925  93.949  -77.787  53.115  1
129926  93.962  -77.783  53.098  1
129927  93.975  -77.779  53.079  1
129928  93.987  -77.774  53.060  1
129929  93.984  -77.774  53.043  1
129930  93.982  -77.772  53.025  1
129931  93.979  -77.771  53.008  1
129932  93.977  -77.770  52.988  1
129933  93.975  -77.769  52.968  1
129934  93.972  -77.768  52.948  1
129935  93.970  -77.767  52.928  1
129936  93.967  -77.766  52.906  1
129937  93.973  -77.771  52.885  1
129938  93.989  -77.774  52.863  1
129939  94.005  -77.779  52.842  1
129940  94.020  -77.783  52.820  1
129941  94.036  -77.787  52.799  1
129942  94.052  -77.792  52.777  1
129943  94.068  -77.796  52.755  1
129944  94.071  -77.790  52.733  1
129945  94.072  -77.781  52.711  1
129946  94.073  -77.773  52.689  1
129947  94.074  -77.765  52.666  1
129948  94.075  -77.757  52.644  1
129949  94.110  -77.742  52.622  1
129950  94.135  -77.733  52.600  1
129951  94.159  -77.724  52.578  1
129952  94.185  -77.714  52.557  1
129953  94.209  -77.705  52.536  1
129954  94.227  -77.702  52.516  1
129955  94.245  -77.700  52.495  1
129956  94.262  -77.699  52.475  1
129957  94.279  -77.696  52.455  1
129958  94.296  -77.695  52.436  1
129959  94.313  -77.693  52.418  1
129960  94.330  -77.691  52.401  1
129961  94.347  -77.689  52.385  1
129962  94.364  -77.687  52.368  1
129963  94.382  -77.686  52.352  1
129964  94.411  -77.655  52.338  1
129965  94.445  -77.614  52.325  1
129966  94.453  -77.611  52.313  1
129967  94.451  -77.621  52.301  1
129968  94.456  -77.630  52.290  1
129969  94.464  -77.637  52.277  1
129970  94.472  -77.645  52.263  1
129971  94.482  -77.645  52.249  1
129972  94.498  -77.626  52.233  1
129973  94.513  -77.605  52.214  1
129974  94.530  -77.586  52.194  1
129975  94.650  -77.596  52.172  1
129976  94.567  -77.617  52.150  1
129977  94.574  -77.670  52.129  1
129978  94.597  -77.728  52.108  1
129979  94.617  -77.782  52.086  1
129980  94.635  -77.833  52.064  1
129981  94.651  -77.855  52.041  1
129982  94.666  -77.842  52.017  1
129983  94.681  -77.828  51.989  1
129984  94.696  -77.815  51.963  1
129985  94.711  -77.801  51.936  1
129986  94.725  -77.787  51.909  1
129987  94.741  -77.774  51.879  1
129988  94.755  -77.760  51.846  1
129989  94.762  -77.718  51.810  1
129990  94.764  -77.660  51.774  1
129991  94.773  -77.635  51.739  1
129992  94.813  -77.674  51.705  1
129993  94.832  -77.687  51.670  1
129994  94.828  -77.668  51.639  1
129995  94.825  -77.617  51.608  1
129996  94.822  -77.555  51.576  1
129997  94.845  -77.551  51.539  1
129998  94.884  -77.586  51.502  1
129999  94.886  -77.592  51.466  1
130000  94.898  -77.604  51.433  1
130001  94.933  -77.625  51.396  1
130002  94.973  -77.645  51.359  1
130003  95.007  -77.639  51.320  1
130004  95.030  -77.611  51.277  1
130005  95.052  -77.583  51.234  1
130006  95.060  -77.568  51.191  1
130007  95.057  -77.564  51.147  1
130008  95.057  -77.564  51.103  1
130009  95.084  -77.608  51.061  1
130010  95.108  -77.652  51.020  1
130011  95.095  -77.711  50.977  1
130012  95.136  -77.696  50.933  1
130013  95.159  -77.702  50.890  1
130014  95.183  -77.708  50.847  1
130015  95.189  -77.710  50.805  1
130016  95.198  -77.710  50.764  1
130017  95.204  -77.706  50.723  1
130018  95.209  -77.702  50.684  1
130019  95.215  -77.699  50.644  1
130020  95.220  -77.696  50.605  1
130021  95.226  -77.692  50.567  1
130022  95.248  -77.680  50.530  1
130023  95.273  -77.667  50.493  1
130024  95.298  -77.655  50.457  1
130025  95.323  -77.642  50.421  1
130026  95.348  -77.629  50.385  1
130027  95.373  -77.617  50.350  1
130028  95.398  -77.604  50.315  1
130029  95.423  -77.591  50.282  1
130030  95.439  -77.581  50.248  1
130031  95.450  -77.566  50.215  1
130032  95.477  -77.517  50.182  1
130033  95.517  -77.489  50.150  1
130034  95.544  -77.474  50.118  1
130035  95.560  -77.463  50.086  1
130036  95.577  -77.451  50.055  1
130037  95.593  -77.441  50.024  1
130038  95.609  -77.429  49.994  1
130039  95.625  -77.418  49.964  1
130040  95.665  -77.429  49.933  1
130041  95.766  -77.500  49.903  1
130042  95.772  -77.526  49.874  1
130043  95.758  -77.542  49.845  1
130044  95.743  -77.558  49.816  1
130045  95.729  -77.571  49.788  1
130046  95.700  -77.577  49.759  1
130047  95.677  -77.599  49.732  1
130048  95.678  -77.605  49.703  1
130049  95.682  -77.608  49.671  1
130050  95.685  -77.610  49.640  1
130051  95.689  -77.613  49.609  1
130052  95.692  -77.615  49.580  1
130053  95.696  -77.618  49.551  1
130054  95.699  -77.620  49.522  1
130055  95.703  -77.624  49.494  1
130056  95.706  -77.627  49.467  1
130057  95.710  -77.629  49.439  1
130058  95.713  -77.632  49.411  1
130059  95.717  -77.634  49.382  1
130060  95.721  -77.637  49.353  1
130061  95.724  -77.639  49.322  1
130062  95.728  -77.642  49.290  1
130063  95.734  -77.644  49.257  1
130064  95.758  -77.655  49.221  1
130065  95.783  -77.668  49.182  1
130066  95.808  -77.680  49.144  1
130067  95.833  -77.693  49.106  1
130068  95.859  -77.705  49.069  1
130069  95.881  -77.714  49.032  1
130070  95.904  -77.722  48.995  1
130071  95.927  -77.730  48.958  1
130072  95.950  -77.740  48.920  1
130073  95.972  -77.748  48.884  1
130074  95.995  -77.756  48.848  1
130075  96.018  -77.765  48.812  1
130076  96.041  -77.773  48.777  1
130077  96.063  -77.781  48.741  1
130078  96.086  -77.790  48.705  1
130079  96.109  -77.798  48.669  1
130080  96.131  -77.806  48.637  1
130081  96.155  -77.815  48.604  1
130082  96.177  -77.823  48.571  1
130083  96.199  -77.832  48.538  1
130084  96.194  -77.851  48.505  1
130085  96.188  -77.871  48.473  1
130086  96.182  -77.891  48.442  1
130087  96.177  -77.909  48.413  1
130088  96.184  -77.909  48.385  1
130089  96.191  -77.908  48.356  1
130090  96.210  -77.923  48.327  1
130091  96.238  -77.948  48.299  1
130092  96.262  -77.970  48.271  1
130093  96.265  -77.965  48.243  1
130094  96.267  -77.959  48.218  1
130095  96.269  -77.954  48.191  1
130096  96.272  -77.949  48.165  1
130097  96.274  -77.943  48.140  1
130098  96.277  -77.938  48.115  1
130099  96.279  -77.933  48.091  1
130100  96.277  -77.929  48.068  1
130101  96.275  -77.925  48.048  1
130102  96.272  -77.922  48.027  1
130103  96.269  -77.918  48.005  1
130104  96.282  -77.915  47.984  1
130105  96.303  -77.910  47.962  1
130106  96.324  -77.913  47.940  1
130107  96.346  -77.918  47.919  1
130108  96.368  -77.924  47.899  1
130109  96.389  -77.929  47.877  1
130110  96.411  -77.934  47.856  1
130111  96.433  -77.939  47.834  1
130112  96.455  -77.944  47.814  1
130113  96.483  -77.949  47.792  1
130114  96.511  -77.953  47.769  1
130115  96.521  -77.963  47.745  1
130116  96.527  -77.961  47.720  1
130117  96.530  -77.945  47.696  1
130118  96.558  -77.946  47.670  1
130119  96.577  -77.948  47.646  1
130120  96.588  -77.949  47.622  1
130121  96.599  -77.951  47.598  1
130122  96.609  -77.952  47.573  1
130123  96.620  -77.953  47.549  1
130124  96.631  -77.955  47.526  1
130125  96.642  -77.956  47.502  1
130126  96.654  -77.965  47.479  1
130127  96.668  -77.981  47.455  1
130128  96.683  -77.999  47.431  1
130129  96.697  -78.016  47.407  1
130130  96.712  -78.034  47.382  1
130131  96.727  -78.050  47.357  1
130132  96.738  -78.065  47.331  1
130133  96.756  -78.078  47.304  1
130134  96.773  -78.092  47.277  1
130135  96.792  -78.106  47.250  1
130136  96.809  -78.119  47.223  1
130137  96.827  -78.132  47.196  1
130138  96.839  -78.149  47.170  1
130139  96.848  -78.169  47.144  1
130140  96.856  -78.188  47.117  1
130141  96.870  -78.203  47.089  1
130142  96.888  -78.217  47.062  1
130143  96.905  -78.231  47.035  1
130144  96.921  -78.238  47.008  1
130145  96.936  -78.244  46.983  1
130146  96.950  -78.251  46.959  1
130147  96.965  -78.257  46.937  1
130148  96.980  -78.263  46.916  1
130149  96.997  -78.272  46.897  1
130150  97.015  -78.282  46.879  1
130151  97.032  -78.291  46.861  1
130152  97.049  -78.301  46.841  1
130153  97.074  -78.313  46.820  1
130154  97.102  -78.328  46.798  1
130155  97.137  -78.338  46.776  1
130156  97.178  -78.344  46.753  1
130157  97.220  -78.350  46.730  1
130158  97.261  -78.356  46.708  1
130159  97.303  -78.362  46.688  1
130160  97.345  -78.368  46.666  1
130161  97.386  -78.374  46.643  1
130162  97.427  -78.379  46.622  1
130163  97.469  -78.385  46.604  1
130164  97.510  -78.391  46.586  1
130165  97.552  -78.398  46.569  1
130166  97.593  -78.394  46.552  1
130167  97.645  -78.385  46.534  1
130168  97.672  -78.388  46.516  1
130169  97.695  -78.393  46.500  1
130170  97.718  -78.398  46.483  1
130171  97.741  -78.403  46.466  1
130172  97.774  -78.422  46.450  1
130173  97.816  -78.463  46.430  1
130174  97.825  -78.464  46.410  1
130175  97.850  -78.459  46.391  1
130176  97.880  -78.451  46.373  1
130177  97.914  -78.441  46.357  1
130178  97.951  -78.428  46.341  1
130179  97.989  -78.415  46.324  1
130180  98.024  -78.410  46.308  1
130181  98.057  -78.413  46.293  1
130182  98.084  -78.418  46.277  1
130183  98.097  -78.417  46.262  1
130184  98.114  -78.399  46.246  1
130185  98.132  -78.381  46.231  1
130186  98.139  -78.363  46.216  1
130187  98.141  -78.351  46.200  1
130188  98.144  -78.357  46.184  1
130189  98.143  -78.366  46.167  1
130190  98.139  -78.376  46.151  1
130191  98.148  -78.388  46.133  1
130192  98.178  -78.376  46.116  1
130193  98.209  -78.364  46.099  1
130194  98.240  -78.352  46.081  1
130195  98.271  -78.341  46.063  1
130196  98.306  -78.328  46.045  1
130197  98.336  -78.319  46.027  1
130198  98.348  -78.309  46.008  1
130199  98.347  -78.310  45.988  1
130200  98.337  -78.326  45.968  1
130201  98.333  -78.347  45.947  1
130202  98.329  -78.370  45.927  1
130203  98.334  -78.387  45.907  1
130204  98.343  -78.401  45.886  1
130205  98.366  -78.423  45.865  1
130206  98.389  -78.445  45.845  1
130207  98.391  -78.467  45.824  1
130208  98.378  -78.494  45.804  1
130209  98.393  -78.498  45.783  1
130210  98.408  -78.504  45.763  1
130211  98.424  -78.508  45.742  1
130212  98.439  -78.514  45.722  1
130213  98.454  -78.523  45.701  1
130214  98.469  -78.533  45.680  1
130215  98.485  -78.543  45.659  1
130216  98.500  -78.553  45.637  1
130217  98.513  -78.555  45.616  1
130218  98.519  -78.523  45.595  1
130219  98.535  -78.480  45.575  1
130220  98.563  -78.448  45.554  1
130221  98.575  -78.432  45.534  1
130222  98.566  -78.463  45.515  1
130223  98.583  -78.496  45.494  1
130224  98.600  -78.529  45.475  1
130225  98.646  -78.513  45.457  1
130226  98.693  -78.495  45.440  1
130227  98.738  -78.470  45.422  1
130228  98.779  -78.435  45.404  1
130229  98.804  -78.448  45.386  1
130230  98.829  -78.459  45.369  1
130231  98.854  -78.468  45.353  1
130232  98.881  -78.465  45.336  1
130233  98.900  -78.438  45.320  1
130234  98.913  -78.468  45.305  1
130235  98.925  -78.497  45.290  1
130236  98.934  -78.510  45.275  1
130237  98.942  -78.524  45.260  1
130238  98.966  -78.534  45.246  1
130239  99.021  -78.536  45.232  1
130240  99.074  -78.534  45.220  1
130241  99.088  -78.538  45.207  1
130242  99.108  -78.542  45.195  1
130243  99.127  -78.548  45.183  1
130244  99.146  -78.552  45.170  1
130245  99.166  -78.557  45.157  1
130246  99.185  -78.562  45.144  1
130247  99.205  -78.567  45.131  1
130248  99.224  -78.573  45.118  1
130249  99.243  -78.577  45.106  1
130250  99.263  -78.582  45.094  1
130251  99.268  -78.600  45.083  1
130252  99.270  -78.620  45.071  1
130253  99.251  -78.640  45.059  1
130254  99.233  -78.660  45.047  1
130255  99.274  -78.656  45.035  1
130256  99.339  -78.681  45.022  1
130257  99.401  -78.722  45.008  1
130258  99.452  -78.743  44.994  1
130259  99.502  -78.761  44.980  1
130260  99.552  -78.778  44.966  1
130261  99.602  -78.795  44.952  1
130262  99.652  -78.812  44.939  1
130263  99.702  -78.830  44.926  1
130264  99.752  -78.847  44.913  1
130265  99.797  -78.858  44.900  1
130266  99.804  -78.871  44.888  1
130267  99.817  -78.876  44.877  1
130268  99.830  -78.884  44.865  1
130269  99.843  -78.894  44.854  1
130270  99.857  -78.904  44.844  1
130271  99.870  -78.914  44.835  1
130272  99.883  -78.924  44.826  1
130273  99.896  -78.933  44.818  1
130274  99.909  -78.943  44.810  1
130275  99.922  -78.953  44.803  1
130276  99.935  -78.963  44.796  1
130277  99.948  -78.973  44.790  1
130278  99.962  -78.983  44.785  1
130279  99.987  -78.991  44.779  1
130280  100.010  -79.011  44.774  1
130281  100.039  -79.029  44.769  1
130282  100.069  -79.047  44.764  1
130283  100.098  -79.065  44.759  1
130284  100.127  -79.084  44.755  1
130285  100.157  -79.103  44.750  1
130286  100.186  -79.121  44.746  1
130287  100.216  -79.139  44.740  1
130288  100.245  -79.157  44.735  1
130289  100.273  -79.164  44.730  1
130290  100.300  -79.169  44.724  1
130291  100.327  -79.175  44.717  1
130292  100.354  -79.181  44.710  1
130293  100.388  -79.189  44.703  1
130294  100.427  -79.199  44.695  1
130295  100.465  -79.209  44.687  1
130573  93.243  -78.172  54.008  1
130574  93.267  -78.159  53.999  1
130575  93.291  -78.148  53.989  1
130576  93.314  -78.136  53.980  1
130577  93.338  -78.124  53.969  1
130578  93.362  -78.112  53.959  1
130579  93.386  -78.100  53.950  1
130580  93.400  -78.095  53.936  1
130581  93.410  -78.092  53.923  1
130582  93.419  -78.090  53.911  1
130583  93.429  -78.087  53.898  1
130584  93.438  -78.085  53.885  1
130585  93.437  -78.075  53.872  1
130586  93.447  -78.060  53.859  1
130587  93.458  -78.044  53.844  1
130588  93.468  -78.029  53.829  1
130589  93.478  -78.013  53.813  1
130590  93.489  -77.998  53.798  1
130591  93.507  -77.984  53.783  1
130616  93.822  -77.818  53.311  1
130617  93.834  -77.815  53.292  1
130618  93.847  -77.810  53.274  1
130619  93.860  -77.806  53.255  1
130620  93.873  -77.802  53.236  1
130621  93.886  -77.797  53.218  1
130622  93.899  -77.793  53.200  1
130623  93.911  -77.789  53.181  1
130624  93.924  -77.784  53.164  1
130625  93.937  -77.780  53.146  1
130626  93.950  -77.776  53.129  1
130627  93.963  -77.771  53.112  1
130628  93.976  -77.768  53.094  1
130629  93.987  -77.763  53.077  1
130630  93.985  -77.762  53.060  1
130631  93.982  -77.761  53.045  1
130632  93.980  -77.760  53.028  1
130633  93.978  -77.759  53.009  1
130634  93.975  -77.758  52.989  1
130635  93.973  -77.757  52.968  1
130636  93.970  -77.755  52.947  1
130637  93.968  -77.754  52.925  1
130638  93.976  -77.755  52.903  1
130639  93.992  -77.759  52.880  1
130640  94.008  -77.764  52.858  1
130641  94.024  -77.768  52.836  1
130642  94.040  -77.772  52.815  1
130643  94.055  -77.777  52.794  1
130644  94.071  -77.781  52.772  1
130645  94.072  -77.773  52.750  1
130646  94.073  -77.765  52.728  1
130647  94.074  -77.756  52.706  1
130648  94.076  -77.749  52.683  1
130649  94.077  -77.740  52.660  1
130650  94.111  -77.725  52.638  1
130651  94.136  -77.716  52.616  1
130652  94.161  -77.706  52.594  1
130653  94.178  -77.705  52.573  1
130654  94.195  -77.702  52.553  1
130655  94.212  -77.701  52.532  1
130656  94.229  -77.699  52.512  1
130657  94.247  -77.697  52.492  1
130658  94.264  -77.696  52.473  1
130659  94.281  -77.693  52.455  1
130660  94.298  -77.692  52.438  1
130661  94.315  -77.690  52.421  1
130662  94.332  -77.688  52.405  1
130663  94.349  -77.686  52.390  1
130664  94.370  -77.675  52.375  1
130665  94.405  -77.633  52.362  1
130666  94.439  -77.592  52.352  1
130667  94.439  -77.600  52.342  1
130668  94.447  -77.608  52.332  1
130669  94.455  -77.616  52.323  1
130670  94.463  -77.624  52.311  1
130671  94.471  -77.631  52.298  1
130672  94.479  -77.638  52.283  1
130673  94.494  -77.618  52.266  1
130674  94.510  -77.599  52.248  1
130675  94.587  -77.591  52.227  1
130676  94.552  -77.611  52.204  1
130677  94.557  -77.663  52.182  1
130678  94.579  -77.722  52.161  1
130679  94.603  -77.780  52.142  1
130680  94.623  -77.836  52.122  1
130681  94.641  -77.887  52.102  1
130682  94.657  -77.890  52.080  1
130683  94.672  -77.877  52.057  1
130684  94.686  -77.863  52.030  1
130685  94.701  -77.850  52.003  1
130686  94.716  -77.837  51.975  1
130687  94.731  -77.823  51.944  1
130688  94.739  -77.787  51.911  1
130689  94.741  -77.729  51.877  1
130690  94.743  -77.672  51.841  1
130691  94.747  -77.620  51.804  1
130692  94.761  -77.611  51.769  1
130693  94.795  -77.641  51.735  1
130694  94.843  -77.696  51.701  1
130695  94.863  -77.659  51.667  1
130696  94.861  -77.597  51.633  1
130697  94.858  -77.536  51.599  1
130698  94.876  -77.520  51.562  1
130699  94.915  -77.555  51.528  1
130700  94.955  -77.591  51.494  1
130701  94.965  -77.604  51.461  1
130702  94.958  -77.610  51.426  1
130703  94.982  -77.620  51.389  1
130704  95.013  -77.608  51.351  1
130705  95.036  -77.580  51.310  1
130706  95.044  -77.564  51.268  1
130707  95.041  -77.560  51.224  1
130708  95.038  -77.555  51.179  1
130709  95.036  -77.552  51.134  1
130710  95.062  -77.595  51.090  1
130711  95.089  -77.639  51.048  1
130712  95.111  -77.684  51.006  1
130713  95.138  -77.689  50.963  1
130714  95.171  -77.683  50.919  1
130715  95.145  -77.673  50.874  1
130716  95.164  -77.680  50.831  1
130717  95.176  -77.684  50.788  1
130718  95.188  -77.686  50.746  1
130719  95.200  -77.689  50.706  1
130720  95.211  -77.692  50.667  1
130721  95.219  -77.692  50.627  1
130722  95.231  -77.686  50.589  1
130723  95.255  -77.673  50.551  1
130724  95.280  -77.660  50.514  1
130725  95.306  -77.647  50.478  1
130726  95.331  -77.634  50.442  1
130727  95.355  -77.621  50.406  1
130728  95.381  -77.609  50.371  1
130729  95.406  -77.596  50.336  1
130730  95.430  -77.583  50.302  1
130731  95.450  -77.572  50.268  1
130732  95.469  -77.541  50.234  1
130733  95.496  -77.493  50.200  1
130734  95.519  -77.477  50.167  1
130735  95.536  -77.468  50.135  1
130736  95.554  -77.461  50.103  1
130737  95.572  -77.452  50.071  1
130738  95.590  -77.444  50.039  1
130739  95.608  -77.436  50.008  1
130740  95.628  -77.429  49.977  1
130741  95.681  -77.444  49.946  1
130742  95.783  -77.514  49.916  1
130743  95.781  -77.536  49.886  1
130744  95.767  -77.552  49.856  1
130745  95.752  -77.568  49.827  1
130746  95.727  -77.574  49.798  1
130747  95.698  -77.580  49.769  1
130748  95.675  -77.604  49.743  1
130749  95.679  -77.606  49.714  1
130750  95.682  -77.609  49.684  1
130751  95.686  -77.611  49.653  1
130752  95.689  -77.614  49.623  1
130753  95.693  -77.617  49.593  1
130754  95.696  -77.620  49.563  1
130755  95.700  -77.622  49.534  1
130756  95.703  -77.625  49.505  1
130757  95.707  -77.628  49.477  1
130758  95.710  -77.630  49.449  1
130759  95.714  -77.633  49.420  1
130760  95.718  -77.636  49.392  1
130761  95.721  -77.639  49.362  1
130762  95.724  -77.641  49.331  1
130763  95.732  -77.642  49.299  1
130764  95.742  -77.643  49.266  1
130765  95.760  -77.650  49.232  1
130766  95.785  -77.662  49.193  1
130767  95.811  -77.675  49.155  1
130768  95.836  -77.687  49.118  1
130769  95.860  -77.699  49.080  1
130770  95.883  -77.707  49.043  1
130771  95.905  -77.715  49.006  1
130772  95.928  -77.724  48.969  1
130773  95.951  -77.732  48.931  1
130774  95.974  -77.740  48.894  1
130775  95.996  -77.749  48.858  1
130776  96.019  -77.757  48.822  1
130777  96.042  -77.765  48.787  1
130778  96.065  -77.774  48.751  1
130779  96.088  -77.783  48.716  1
130780  96.110  -77.791  48.679  1
130781  96.133  -77.799  48.647  1
130782  96.158  -77.808  48.615  1
130783  96.182  -77.818  48.582  1
130784  96.192  -77.828  48.549  1
130785  96.197  -77.851  48.517  1
130786  96.196  -77.872  48.485  1
130787  96.190  -77.892  48.454  1
130788  96.184  -77.912  48.425  1
130789  96.188  -77.916  48.396  1
130790  96.197  -77.918  48.367  1
130791  96.224  -77.943  48.338  1
130792  96.243  -77.957  48.309  1
130793  96.245  -77.952  48.281  1
130794  96.248  -77.946  48.253  1
130795  96.250  -77.941  48.227  1
130796  96.252  -77.936  48.201  1
130797  96.255  -77.931  48.174  1
130798  96.257  -77.924  48.149  1
130799  96.259  -77.919  48.123  1
130800  96.262  -77.914  48.099  1
130801  96.260  -77.910  48.075  1
130802  96.258  -77.907  48.055  1
130803  96.255  -77.903  48.034  1
130804  96.261  -77.899  48.012  1
130805  96.282  -77.895  47.990  1
130806  96.303  -77.890  47.968  1
130807  96.324  -77.893  47.946  1
130808  96.346  -77.899  47.924  1
130809  96.368  -77.904  47.903  1
130810  96.389  -77.909  47.881  1
130811  96.411  -77.915  47.860  1
130812  96.433  -77.919  47.838  1
130813  96.455  -77.924  47.818  1
130814  96.476  -77.930  47.797  1
130815  96.498  -77.935  47.776  1
130816  96.521  -77.940  47.754  1
130817  96.537  -77.944  47.730  1
130818  96.553  -77.940  47.706  1
130819  96.564  -77.941  47.681  1
130820  96.575  -77.943  47.656  1
130821  96.585  -77.944  47.631  1
130822  96.596  -77.946  47.606  1
130823  96.607  -77.947  47.580  1
130824  96.617  -77.949  47.555  1
130825  96.628  -77.950  47.532  1
130826  96.639  -77.952  47.508  1
130827  96.650  -77.955  47.485  1
130828  96.664  -77.971  47.462  1
130829  96.679  -77.989  47.437  1
130830  96.693  -78.006  47.413  1
130831  96.708  -78.023  47.389  1
130832  96.723  -78.040  47.364  1
130833  96.746  -78.056  47.339  1
130834  96.773  -78.072  47.312  1
130835  96.794  -78.085  47.284  1
130836  96.811  -78.099  47.257  1
130837  96.829  -78.112  47.231  1
130838  96.842  -78.128  47.204  1
130839  96.851  -78.147  47.177  1
130840  96.859  -78.167  47.151  1
130841  96.868  -78.186  47.124  1
130842  96.880  -78.203  47.096  1
130843  96.895  -78.210  47.068  1
130844  96.909  -78.216  47.041  1
130845  96.925  -78.223  47.016  1
130846  96.939  -78.229  46.992  1
130847  96.954  -78.236  46.969  1
130848  96.969  -78.242  46.948  1
130849  96.985  -78.250  46.927  1
130850  97.003  -78.260  46.908  1
130851  97.020  -78.269  46.891  1
130852  97.037  -78.279  46.874  1
130853  97.055  -78.288  46.855  1
130854  97.073  -78.298  46.834  1
130855  97.102  -78.312  46.813  1
130856  97.140  -78.320  46.793  1
130857  97.182  -78.326  46.772  1
130858  97.223  -78.332  46.751  1
130859  97.264  -78.338  46.729  1
130860  97.306  -78.344  46.708  1
130861  97.348  -78.350  46.686  1
130862  97.389  -78.356  46.665  1
130863  97.431  -78.362  46.644  1
130864  97.472  -78.368  46.624  1
130865  97.513  -78.374  46.606  1
130866  97.555  -78.380  46.590  1
130867  97.596  -78.385  46.575  1
130868  97.638  -78.383  46.558  1
130869  97.683  -78.378  46.540  1
130870  97.707  -78.383  46.522  1
130871  97.730  -78.388  46.503  1
130872  97.753  -78.392  46.486  1
130873  97.799  -78.436  46.471  1
130874  97.809  -78.437  46.452  1
130875  97.818  -78.438  46.432  1
130876  97.843  -78.432  46.412  1
130877  97.873  -78.425  46.393  1
130878  97.903  -78.416  46.380  1
130879  97.937  -78.407  46.364  1
130880  97.974  -78.394  46.347  1
130881  98.011  -78.382  46.331  1
130882  98.043  -78.385  46.315  1
130883  98.068  -78.391  46.300  1
130884  98.078  -78.399  46.283  1
130885  98.096  -78.381  46.267  1
130886  98.113  -78.363  46.252  1
130887  98.131  -78.344  46.236  1
130888  98.148  -78.329  46.219  1
130889  98.144  -78.340  46.202  1
130890  98.141  -78.351  46.185  1
130891  98.137  -78.362  46.168  1
130892  98.150  -78.375  46.151  1
130893  98.181  -78.363  46.134  1
130894  98.212  -78.351  46.116  1
130895  98.242  -78.339  46.098  1
130896  98.273  -78.328  46.079  1
130897  98.303  -78.316  46.061  1
130898  98.334  -78.305  46.044  1
130899  98.344  -78.306  46.025  1
130900  98.355  -78.298  46.006  1
130901  98.372  -78.328  45.986  1
130902  98.382  -78.363  45.966  1
130903  98.378  -78.385  45.946  1
130904  98.377  -78.407  45.925  1
130905  98.387  -78.420  45.904  1
130906  98.396  -78.435  45.882  1
130907  98.392  -78.433  45.861  1
130908  98.373  -78.458  45.841  1
130909  98.371  -78.495  45.820  1
130910  98.410  -78.505  45.800  1
130911  98.432  -78.513  45.780  1
130912  98.445  -78.511  45.760  1
130913  98.449  -78.499  45.739  1
130914  98.457  -78.506  45.718  1
130915  98.469  -78.523  45.696  1
130916  98.481  -78.539  45.674  1
130917  98.494  -78.551  45.652  1
130918  98.511  -78.530  45.631  1
130919  98.538  -78.498  45.610  1
130920  98.566  -78.467  45.589  1
130921  98.594  -78.434  45.568  1
130922  98.605  -78.418  45.547  1
130923  98.570  -78.448  45.527  1
130924  98.584  -78.481  45.507  1
130925  98.605  -78.506  45.488  1
130926  98.653  -78.488  45.470  1
130927  98.700  -78.470  45.452  1
130928  98.748  -78.451  45.434  1
130929  98.791  -78.421  45.417  1
130930  98.817  -78.429  45.399  1
130931  98.843  -78.437  45.383  1
130932  98.870  -78.434  45.366  1
130933  98.898  -78.431  45.349  1
130934  98.915  -78.401  45.333  1
130935  98.932  -78.447  45.318  1
130936  98.948  -78.492  45.303  1
130937  98.957  -78.508  45.288  1
130938  98.966  -78.522  45.273  1
130939  98.999  -78.529  45.259  1
130940  99.054  -78.532  45.246  1
130941  99.102  -78.517  45.233  1
130942  99.109  -78.523  45.220  1
130943  99.118  -78.532  45.208  1
130944  99.138  -78.537  45.196  1
130945  99.157  -78.542  45.183  1
130946  99.177  -78.547  45.170  1
130947  99.196  -78.552  45.157  1
130948  99.215  -78.557  45.144  1
130949  99.234  -78.562  45.131  1
130950  99.254  -78.567  45.119  1
130951  99.264  -78.579  45.107  1
130952  99.267  -78.599  45.095  1
130953  99.270  -78.619  45.085  1
130954  99.265  -78.639  45.073  1
130955  99.246  -78.658  45.061  1
130956  99.280  -78.658  45.049  1
130957  99.351  -78.652  45.034  1
130958  99.413  -78.692  45.020  1
130959  99.474  -78.733  45.006  1
130960  99.532  -78.766  44.992  1
130961  99.582  -78.783  44.978  1
130962  99.632  -78.801  44.964  1
130963  99.682  -78.818  44.951  1
130964  99.731  -78.835  44.939  1
130965  99.785  -78.849  44.926  1
130966  99.822  -78.846  44.914  1
130967  99.808  -78.874  44.902  1
130968  99.818  -78.888  44.890  1
130969  99.831  -78.893  44.878  1
130970  99.844  -78.897  44.867  1
130971  99.858  -78.902  44.856  1
130972  99.871  -78.907  44.846  1
130973  99.884  -78.912  44.837  1
130974  99.898  -78.916  44.830  1
130975  99.911  -78.921  44.822  1
130976  99.924  -78.929  44.814  1
130977  99.937  -78.939  44.805  1
130978  99.950  -78.949  44.799  1
130979  99.964  -78.959  44.793  1
130980  99.983  -78.971  44.787  1
130981  100.012  -78.989  44.781  1
130982  100.042  -79.007  44.776  1
130983  100.071  -79.025  44.770  1
130984  100.101  -79.043  44.765  1
130985  100.130  -79.062  44.761  1
130986  100.159  -79.081  44.757  1
130987  100.189  -79.099  44.752  1
130988  100.218  -79.117  44.746  1
130989  100.248  -79.135  44.740  1
130990  100.275  -79.144  44.735  1
130991  100.302  -79.150  44.729  1
130992  100.330  -79.155  44.722  1
130993  100.357  -79.160  44.715  1
130994  100.395  -79.171  44.707  1
130995  100.434  -79.181  44.699  1
130996  100.473  -79.196  44.690  1
130997  100.512  -79.212  44.682  1
131273  93.219  -78.173  54.027  1
131274  93.243  -78.161  54.018  1
131275  93.267  -78.150  54.008  1
131276  93.290  -78.138  53.998  1
131277  93.314  -78.125  53.988  1
131278  93.338  -78.114  53.979  1
131279  93.361  -78.102  53.969  1
131280  93.385  -78.090  53.959  1
131281  93.400  -78.084  53.945  1
131282  93.410  -78.081  53.932  1
131283  93.419  -78.079  53.920  1
131284  93.429  -78.077  53.907  1
131285  93.435  -78.072  53.894  1
131286  93.439  -78.059  53.882  1
131287  93.449  -78.044  53.868  1
131288  93.460  -78.029  53.853  1
131289  93.470  -78.013  53.838  1
131290  93.480  -77.998  53.822  1
131291  93.491  -77.982  53.807  1
131292  93.508  -77.971  53.792  1
131293  93.520  -77.962  53.777  1
131294  93.532  -77.954  53.762  1
131298  93.578  -77.921  53.692  1
131299  93.589  -77.912  53.674  1
131300  93.601  -77.905  53.657  1
131301  93.613  -77.896  53.640  1
131302  93.624  -77.888  53.620  1
131303  93.636  -77.880  53.600  1
131304  93.648  -77.871  53.581  1
131317  93.822  -77.808  53.322  1
131318  93.835  -77.803  53.304  1
131319  93.848  -77.799  53.285  1
131320  93.860  -77.795  53.266  1
131321  93.873  -77.790  53.248  1
131322  93.887  -77.786  53.230  1
131323  93.899  -77.782  53.212  1
131324  93.912  -77.777  53.194  1
131325  93.925  -77.774  53.177  1
131326  93.938  -77.769  53.160  1
131327  93.951  -77.765  53.143  1
131328  93.964  -77.761  53.126  1
131329  93.976  -77.756  53.110  1
131330  93.988  -77.752  53.095  1
131331  93.985  -77.751  53.080  1
131332  93.983  -77.750  53.064  1
131333  93.980  -77.749  53.047  1
131334  93.978  -77.748  53.028  1
131335  93.976  -77.746  53.009  1
131336  93.975  -77.743  52.988  1
131337  93.975  -77.740  52.966  1
131338  93.975  -77.737  52.943  1
131339  93.977  -77.735  52.920  1
131340  93.993  -77.740  52.897  1
131341  94.009  -77.745  52.876  1
131342  94.025  -77.750  52.855  1
131343  94.041  -77.755  52.834  1
131344  94.058  -77.760  52.813  1
131345  94.073  -77.764  52.791  1
131346  94.074  -77.756  52.768  1
131347  94.075  -77.748  52.745  1
131348  94.076  -77.740  52.723  1
131349  94.077  -77.732  52.700  1
131350  94.078  -77.724  52.677  1
131351  94.112  -77.708  52.655  1
131352  94.129  -77.707  52.632  1
131353  94.146  -77.705  52.611  1
131354  94.163  -77.703  52.590  1
131355  94.180  -77.702  52.569  1
131356  94.197  -77.699  52.549  1
131357  94.214  -77.698  52.529  1
131358  94.231  -77.696  52.510  1
131359  94.248  -77.694  52.491  1
131360  94.265  -77.692  52.474  1
131361  94.282  -77.690  52.457  1
131362  94.299  -77.689  52.441  1
131363  94.317  -77.687  52.427  1
131364  94.334  -77.685  52.413  1
131365  94.364  -77.653  52.401  1
131366  94.399  -77.611  52.389  1
131367  94.430  -77.577  52.380  1
131368  94.437  -77.586  52.372  1
131369  94.445  -77.594  52.366  1
131370  94.453  -77.602  52.359  1
131371  94.461  -77.610  52.348  1
131372  94.469  -77.617  52.335  1
131373  94.477  -77.625  52.318  1
131374  94.491  -77.611  52.300  1
131375  94.507  -77.592  52.280  1
131376  94.538  -77.605  52.260  1
131377  94.540  -77.657  52.237  1
131378  94.562  -77.716  52.216  1
131379  94.585  -77.774  52.196  1
131380  94.608  -77.834  52.177  1
131381  94.629  -77.890  52.157  1
131382  94.647  -77.940  52.137  1
131383  94.662  -77.926  52.116  1
131384  94.677  -77.912  52.093  1
131385  94.692  -77.899  52.066  1
131386  94.707  -77.885  52.038  1
131387  94.717  -77.855  52.009  1
131388  94.719  -77.799  51.977  1
131389  94.721  -77.741  51.943  1
131390  94.723  -77.683  51.908  1
131391  94.724  -77.626  51.874  1
131392  94.734  -77.598  51.837  1
131393  94.748  -77.589  51.803  1
131394  94.777  -77.608  51.769  1
131395  94.833  -77.657  51.734  1
131396  94.888  -77.615  51.697  1
131397  94.897  -77.577  51.661  1
131398  94.895  -77.516  51.626  1
131399  94.907  -77.489  51.591  1
131400  94.947  -77.524  51.557  1
131401  94.986  -77.560  51.523  1
131402  95.012  -77.599  51.486  1
131403  94.984  -77.610  51.449  1
131404  94.990  -77.595  51.412  1
131405  95.019  -77.577  51.375  1
131406  95.029  -77.561  51.335  1
131407  95.026  -77.556  51.294  1
131408  95.023  -77.551  51.251  1
131409  95.020  -77.548  51.208  1
131410  95.016  -77.543  51.164  1
131411  95.041  -77.584  51.119  1
131412  95.067  -77.627  51.076  1
131413  95.094  -77.671  51.034  1
131414  95.125  -77.702  50.990  1
131415  95.137  -77.649  50.946  1
131416  95.118  -77.642  50.901  1
131417  95.136  -77.649  50.858  1
131418  95.152  -77.655  50.815  1
131419  95.164  -77.658  50.773  1
131420  95.176  -77.661  50.731  1
131421  95.187  -77.664  50.690  1
131422  95.210  -77.677  50.651  1
131423  95.234  -77.667  50.612  1
131424  95.259  -77.657  50.574  1
131425  95.285  -77.645  50.538  1
131426  95.311  -77.634  50.501  1
131427  95.336  -77.623  50.465  1
131428  95.362  -77.611  50.429  1
131429  95.388  -77.601  50.394  1
131430  95.413  -77.589  50.359  1
131431  95.438  -77.576  50.324  1
131432  95.461  -77.564  50.290  1
131433  95.483  -77.532  50.256  1
131434  95.501  -77.510  50.221  1
131435  95.519  -77.488  50.187  1
131436  95.537  -77.478  50.153  1
131437  95.555  -77.470  50.119  1
131438  95.573  -77.462  50.088  1
131439  95.591  -77.454  50.056  1
131440  95.609  -77.446  50.024  1
131441  95.655  -77.455  49.991  1
131442  95.706  -77.468  49.960  1
131443  95.800  -77.528  49.930  1
131444  95.791  -77.547  49.900  1
131445  95.776  -77.563  49.869  1
131446  95.754  -77.572  49.839  1
131447  95.725  -77.577  49.810  1
131448  95.696  -77.583  49.781  1
131449  95.676  -77.605  49.753  1
131450  95.679  -77.608  49.727  1
131451  95.683  -77.611  49.698  1
131452  95.686  -77.613  49.667  1
131453  95.690  -77.616  49.637  1
131454  95.693  -77.618  49.606  1
131455  95.697  -77.621  49.575  1
131456  95.700  -77.624  49.545  1
131457  95.703  -77.627  49.516  1
131458  95.707  -77.630  49.487  1
131459  95.710  -77.632  49.459  1
131460  95.714  -77.635  49.430  1
131461  95.718  -77.637  49.401  1
131462  95.721  -77.640  49.371  1
131463  95.731  -77.641  49.339  1
131464  95.740  -77.642  49.308  1
131465  95.750  -77.642  49.275  1
131466  95.762  -77.644  49.241  1
131467  95.788  -77.656  49.203  1
131468  95.813  -77.669  49.166  1
131469  95.838  -77.682  49.129  1
131470  95.862  -77.691  49.093  1
131471  95.884  -77.699  49.055  1
131472  95.907  -77.708  49.017  1
131473  95.930  -77.717  48.980  1
131474  95.953  -77.725  48.942  1
131475  95.975  -77.733  48.905  1
131476  95.998  -77.742  48.869  1
131477  96.021  -77.750  48.832  1
131478  96.043  -77.758  48.796  1
131479  96.066  -77.767  48.761  1
131480  96.089  -77.775  48.726  1
131481  96.116  -77.784  48.690  1
131482  96.143  -77.794  48.658  1
131483  96.164  -77.803  48.626  1
131484  96.174  -77.814  48.594  1
131485  96.183  -77.825  48.560  1
131486  96.188  -77.848  48.528  1
131487  96.193  -77.871  48.497  1
131488  96.198  -77.893  48.466  1
131489  96.192  -77.913  48.437  1
131490  96.192  -77.924  48.408  1
131491  96.210  -77.937  48.378  1
131492  96.223  -77.944  48.349  1
131493  96.226  -77.939  48.319  1
131494  96.228  -77.934  48.290  1
131495  96.230  -77.928  48.263  1
131496  96.233  -77.922  48.236  1
131497  96.235  -77.917  48.210  1
131498  96.237  -77.912  48.184  1
131499  96.240  -77.906  48.157  1
131500  96.242  -77.901  48.131  1
131501  96.244  -77.896  48.107  1
131502  96.243  -77.891  48.084  1
131503  96.241  -77.888  48.062  1
131504  96.240  -77.884  48.041  1
131505  96.261  -77.880  48.020  1
131506  96.282  -77.875  47.998  1
131507  96.302  -77.871  47.976  1
131508  96.324  -77.874  47.953  1
131509  96.345  -77.879  47.930  1
131510  96.368  -77.884  47.909  1
131511  96.389  -77.890  47.887  1
131512  96.411  -77.895  47.865  1
131513  96.433  -77.899  47.843  1
131514  96.454  -77.905  47.822  1
131515  96.476  -77.910  47.801  1
131516  96.498  -77.915  47.782  1
131517  96.519  -77.925  47.763  1
131518  96.542  -77.936  47.740  1
131519  96.550  -77.935  47.716  1
131520  96.561  -77.937  47.691  1
131521  96.572  -77.938  47.665  1
131522  96.583  -77.940  47.638  1
131523  96.593  -77.941  47.611  1
131524  96.604  -77.942  47.584  1
131525  96.615  -77.943  47.559  1
131526  96.625  -77.945  47.535  1
131527  96.636  -77.946  47.511  1
131528  96.647  -77.948  47.487  1
131529  96.661  -77.962  47.464  1
131530  96.675  -77.979  47.440  1
131531  96.689  -77.996  47.416  1
131532  96.704  -78.013  47.393  1
131533  96.719  -78.031  47.368  1
131534  96.744  -78.046  47.343  1
131535  96.771  -78.061  47.317  1
131536  96.798  -78.075  47.291  1
131537  96.826  -78.091  47.265  1
131538  96.845  -78.106  47.237  1
131539  96.852  -78.124  47.211  1
131540  96.858  -78.141  47.183  1
131541  96.864  -78.158  47.156  1
131542  96.870  -78.175  47.129  1
131543  96.883  -78.188  47.102  1
131544  96.898  -78.195  47.076  1
131545  96.913  -78.201  47.049  1
131546  96.928  -78.208  47.024  1
131547  96.943  -78.214  47.001  1
131548  96.958  -78.221  46.979  1
131549  96.973  -78.228  46.958  1
131550  96.991  -78.237  46.939  1
131551  97.008  -78.247  46.921  1
131552  97.025  -78.256  46.905  1
131553  97.043  -78.266  46.889  1
131554  97.061  -78.275  46.871  1
131555  97.078  -78.285  46.852  1
131556  97.102  -78.297  46.831  1
131557  97.143  -78.303  46.811  1
131558  97.185  -78.309  46.791  1
131559  97.226  -78.315  46.771  1
131560  97.267  -78.321  46.749  1
131561  97.309  -78.326  46.727  1
131562  97.351  -78.332  46.707  1
131563  97.392  -78.338  46.688  1
131564  97.434  -78.344  46.670  1
131565  97.475  -78.351  46.651  1
131566  97.516  -78.356  46.632  1
131567  97.558  -78.362  46.616  1
131568  97.599  -78.368  46.601  1
131569  97.641  -78.374  46.584  1
131570  97.682  -78.372  46.565  1
131571  97.719  -78.373  46.547  1
131572  97.742  -78.377  46.527  1
131573  97.777  -78.401  46.508  1
131574  97.792  -78.409  46.490  1
131575  97.801  -78.410  46.471  1
131576  97.811  -78.410  46.453  1
131577  97.835  -78.405  46.435  1
131578  97.866  -78.398  46.417  1
131579  97.896  -78.390  46.403  1
131580  97.927  -78.382  46.388  1
131581  97.959  -78.373  46.371  1
131582  97.997  -78.360  46.355  1
131583  98.030  -78.358  46.338  1
131584  98.052  -78.365  46.322  1
131585  98.062  -78.374  46.305  1
131586  98.077  -78.363  46.288  1
131587  98.095  -78.344  46.272  1
131588  98.114  -78.327  46.256  1
131589  98.142  -78.318  46.239  1
131590  98.143  -78.326  46.221  1
131591  98.139  -78.337  46.203  1
131592  98.135  -78.347  46.187  1
131593  98.153  -78.361  46.169  1
131594  98.183  -78.351  46.151  1
131595  98.214  -78.338  46.134  1
131596  98.244  -78.327  46.115  1
131597  98.275  -78.315  46.096  1
131598  98.306  -78.304  46.078  1
131599  98.328  -78.329  46.061  1
131600  98.336  -78.319  46.042  1
131601  98.344  -78.309  46.022  1
131602  98.354  -78.300  46.003  1
131603  98.369  -78.322  45.984  1
131604  98.389  -78.366  45.963  1
131605  98.408  -78.410  45.942  1
131606  98.402  -78.406  45.920  1
131607  98.389  -78.394  45.899  1
131608  98.374  -78.407  45.878  1
131609  98.357  -78.454  45.857  1
131610  98.342  -78.501  45.837  1
131611  98.391  -78.514  45.816  1
131612  98.443  -78.509  45.796  1
131613  98.455  -78.495  45.777  1
131614  98.458  -78.483  45.757  1
131615  98.465  -78.483  45.736  1
131616  98.477  -78.499  45.713  1
131617  98.488  -78.516  45.690  1
131618  98.503  -78.531  45.666  1
131619  98.539  -78.514  45.644  1
131620  98.569  -78.484  45.623  1
131621  98.597  -78.452  45.601  1
131622  98.625  -78.420  45.581  1
131623  98.636  -78.404  45.560  1
131624  98.600  -78.435  45.539  1
131625  98.584  -78.466  45.520  1
131626  98.612  -78.481  45.501  1
131627  98.659  -78.463  45.483  1
131628  98.707  -78.445  45.466  1
131629  98.755  -78.426  45.448  1
131630  98.802  -78.407  45.430  1
131631  98.832  -78.405  45.412  1
131632  98.859  -78.402  45.396  1
131633  98.887  -78.399  45.379  1
131634  98.915  -78.396  45.363  1
131635  98.934  -78.381  45.347  1
131636  98.950  -78.426  45.331  1
131637  98.967  -78.471  45.317  1
131638  98.981  -78.507  45.302  1
131639  98.989  -78.520  45.287  1
131640  99.032  -78.526  45.274  1
131641  99.082  -78.515  45.261  1
131642  99.130  -78.500  45.248  1
131643  99.143  -78.503  45.235  1
131644  99.129  -78.522  45.222  1
131645  99.148  -78.526  45.209  1
131646  99.167  -78.532  45.196  1
131647  99.187  -78.536  45.183  1
131648  99.206  -78.542  45.170  1
131649  99.226  -78.546  45.157  1
131650  99.245  -78.551  45.145  1
131651  99.261  -78.559  45.132  1
131652  99.264  -78.579  45.120  1
131653  99.267  -78.598  45.108  1
131654  99.270  -78.617  45.098  1
131655  99.273  -78.637  45.087  1
131656  99.259  -78.658  45.076  1
131657  99.286  -78.659  45.063  1
131658  99.359  -78.643  45.048  1
131659  99.424  -78.663  45.033  1
131660  99.486  -78.704  45.018  1
131661  99.548  -78.744  45.004  1
131662  99.610  -78.785  44.990  1
131663  99.661  -78.806  44.977  1
131664  99.711  -78.824  44.964  1
131665  99.761  -78.841  44.952  1
131666  99.860  -78.803  44.940  1
131667  99.847  -78.832  44.930  1
131668  99.833  -78.861  44.918  1
131669  99.820  -78.896  44.906  1
131670  99.832  -78.905  44.894  1
131671  99.845  -78.910  44.883  1
131672  99.858  -78.915  44.872  1
131673  99.871  -78.919  44.862  1
131674  99.885  -78.924  44.852  1
131675  99.898  -78.928  44.844  1
131676  99.912  -78.933  44.835  1
131677  99.925  -78.937  44.826  1
131678  99.938  -78.943  44.818  1
131679  99.951  -78.947  44.810  1
131680  99.968  -78.950  44.803  1
131681  99.986  -78.950  44.797  1
131682  100.014  -78.967  44.791  1
131683  100.044  -78.985  44.785  1
131684  100.073  -79.003  44.779  1
131685  100.103  -79.022  44.773  1
131686  100.132  -79.040  44.769  1
131687  100.161  -79.059  44.764  1
131688  100.191  -79.077  44.758  1
131689  100.220  -79.095  44.752  1
131690  100.250  -79.113  44.746  1
131691  100.278  -79.124  44.740  1
131692  100.305  -79.130  44.734  1
131693  100.332  -79.135  44.727  1
131694  100.363  -79.142  44.719  1
131695  100.402  -79.153  44.711  1
131696  100.441  -79.165  44.703  1
131697  100.480  -79.182  44.694  1
131698  100.519  -79.199  44.685  1
131973  93.195  -78.175  54.043  1
131974  93.219  -78.163  54.036  1
131975  93.242  -78.151  54.026  1
131976  93.266  -78.139  54.016  1
131977  93.290  -78.128  54.006  1
131978  93.313  -78.116  53.996  1
131979  93.337  -78.103  53.987  1
131980  93.360  -78.092  53.977  1
131981  93.384  -78.080  53.967  1
131982  93.400  -78.073  53.954  1
131983  93.410  -78.071  53.942  1
131984  93.420  -78.068  53.930  1
131985  93.429  -78.065  53.917  1
131986  93.432  -78.059  53.904  1
131987  93.440  -78.044  53.891  1
131988  93.450  -78.028  53.878  1
131989  93.461  -78.013  53.863  1
131990  93.471  -77.997  53.847  1
131991  93.481  -77.982  53.832  1
131992  93.496  -77.967  53.816  1
131993  93.509  -77.958  53.801  1
131994  93.521  -77.949  53.786  1
131995  93.533  -77.941  53.770  1
131996  93.544  -77.933  53.753  1
131997  93.556  -77.924  53.735  1
131998  93.567  -77.916  53.718  1
131999  93.579  -77.908  53.701  1
132000  93.590  -77.899  53.682  1
132001  93.602  -77.891  53.665  1
132002  93.614  -77.884  53.649  1
132003  93.625  -77.875  53.629  1
132004  93.637  -77.867  53.610  1
132005  93.650  -77.859  53.590  1
132006  93.665  -77.852  53.572  1
132007  93.681  -77.844  53.552  1
132008  93.694  -77.839  53.532  1
132009  93.707  -77.835  53.512  1
132018  93.823  -77.796  53.334  1
132019  93.836  -77.792  53.315  1
132020  93.848  -77.788  53.296  1
132021  93.861  -77.783  53.278  1
132022  93.874  -77.779  53.260  1
132023  93.887  -77.775  53.242  1
132024  93.900  -77.771  53.224  1
132025  93.913  -77.766  53.207  1
132026  93.925  -77.762  53.190  1
132027  93.938  -77.758  53.173  1
132028  93.951  -77.753  53.157  1
132029  93.964  -77.749  53.142  1
132030  93.977  -77.745  53.127  1
132031  93.988  -77.741  53.113  1
132032  93.986  -77.740  53.098  1
132033  93.983  -77.739  53.082  1
132034  93.982  -77.736  53.065  1
132035  93.982  -77.733  53.045  1
132036  93.982  -77.730  53.026  1
132037  93.982  -77.727  53.006  1
132038  93.982  -77.724  52.985  1
132039  93.982  -77.721  52.961  1
132040  93.982  -77.718  52.938  1
132041  93.993  -77.721  52.916  1
132042  94.010  -77.726  52.894  1
132043  94.026  -77.730  52.874  1
132044  94.041  -77.736  52.853  1
132045  94.055  -77.741  52.832  1
132046  94.070  -77.745  52.810  1
132047  94.082  -77.737  52.788  1
132048  94.082  -77.730  52.765  1
132049  94.083  -77.721  52.742  1
132050  94.083  -77.714  52.718  1
132051  94.122  -77.687  52.695  1
132052  94.134  -77.684  52.672  1
132053  94.147  -77.685  52.648  1
132054  94.161  -77.686  52.627  1
132055  94.169  -77.690  52.606  1
132056  94.166  -77.699  52.585  1
132057  94.182  -77.699  52.565  1
132058  94.199  -77.696  52.546  1
132059  94.216  -77.695  52.528  1
132060  94.233  -77.693  52.510  1
132061  94.250  -77.691  52.493  1
132062  94.267  -77.689  52.477  1
132063  94.284  -77.687  52.462  1
132064  94.301  -77.686  52.449  1
132065  94.323  -77.674  52.437  1
132066  94.357  -77.631  52.426  1
132067  94.378  -77.589  52.419  1
132068  94.414  -77.572  52.414  1
132069  94.451  -77.555  52.409  1
132070  94.459  -77.564  52.402  1
132071  94.452  -77.588  52.396  1
132072  94.460  -77.595  52.386  1
132073  94.468  -77.604  52.372  1
132074  94.476  -77.611  52.353  1
132075  94.488  -77.604  52.332  1
132076  94.523  -77.600  52.311  1
132077  94.522  -77.651  52.290  1
132078  94.545  -77.709  52.269  1
132079  94.568  -77.768  52.251  1
132080  94.591  -77.827  52.232  1
132081  94.614  -77.886  52.213  1
132082  94.636  -77.943  52.192  1
132083  94.652  -77.975  52.170  1
132084  94.668  -77.962  52.148  1
132085  94.682  -77.948  52.125  1
132086  94.695  -77.925  52.100  1
132087  94.696  -77.868  52.071  1
132088  94.698  -77.810  52.040  1
132089  94.700  -77.752  52.008  1
132090  94.702  -77.696  51.975  1
132091  94.704  -77.638  51.941  1
132092  94.707  -77.583  51.908  1
132093  94.721  -77.574  51.872  1
132094  94.735  -77.565  51.838  1
132095  94.759  -77.575  51.803  1
132096  94.843  -77.599  51.766  1
132097  94.905  -77.557  51.729  1
132098  94.917  -77.523  51.692  1
132099  94.928  -77.491  51.656  1
132100  94.938  -77.457  51.623  1
132101  94.970  -77.495  51.589  1
132102  94.983  -77.538  51.553  1
132103  94.997  -77.580  51.514  1
132104  94.998  -77.605  51.474  1
132105  94.999  -77.570  51.436  1
132106  95.013  -77.557  51.399  1
132107  95.010  -77.552  51.360  1
132108  95.006  -77.548  51.319  1
132109  95.003  -77.544  51.278  1
132110  95.000  -77.539  51.237  1
132111  94.997  -77.535  51.193  1
132112  95.020  -77.572  51.149  1
132113  95.046  -77.615  51.106  1
132114  95.077  -77.658  51.064  1
132115  95.053  -77.705  51.018  1
132116  95.063  -77.636  50.973  1
132117  95.092  -77.614  50.929  1
132118  95.109  -77.619  50.886  1
132119  95.128  -77.627  50.842  1
132120  95.139  -77.630  50.799  1
132121  95.160  -77.636  50.757  1
132122  95.189  -77.656  50.716  1
132123  95.214  -77.659  50.677  1
132124  95.235  -77.645  50.638  1
132125  95.260  -77.633  50.600  1
132126  95.286  -77.622  50.564  1
132127  95.312  -77.611  50.527  1
132128  95.337  -77.600  50.490  1
132129  95.363  -77.589  50.454  1
132130  95.389  -77.577  50.418  1
132131  95.414  -77.567  50.384  1
132132  95.440  -77.555  50.348  1
132133  95.471  -77.554  50.314  1
132134  95.486  -77.545  50.279  1
132135  95.502  -77.536  50.244  1
132136  95.520  -77.517  50.209  1
132137  95.538  -77.495  50.174  1
132138  95.556  -77.480  50.141  1
132139  95.574  -77.472  50.107  1
132140  95.592  -77.464  50.074  1
132141  95.629  -77.467  50.041  1
132142  95.681  -77.480  50.008  1
132143  95.733  -77.493  49.976  1
132144  95.815  -77.542  49.944  1
132145  95.800  -77.558  49.913  1
132146  95.781  -77.569  49.882  1
132147  95.752  -77.575  49.852  1
132148  95.723  -77.580  49.823  1
132149  95.694  -77.586  49.795  1
132150  95.676  -77.607  49.768  1
132151  95.680  -77.609  49.740  1
132152  95.683  -77.612  49.711  1
132153  95.686  -77.614  49.682  1
132154  95.690  -77.617  49.650  1
132155  95.693  -77.620  49.619  1
132156  95.697  -77.623  49.587  1
132157  95.700  -77.626  49.556  1
132158  95.704  -77.628  49.527  1
132159  95.707  -77.631  49.497  1
132160  95.711  -77.633  49.468  1
132161  95.714  -77.636  49.439  1
132162  95.719  -77.639  49.409  1
132163  95.729  -77.639  49.379  1
132164  95.739  -77.639  49.347  1
132165  95.749  -77.640  49.316  1
132166  95.758  -77.641  49.284  1
132167  95.768  -77.641  49.251  1
132168  95.790  -77.651  49.214  1
132169  95.815  -77.663  49.178  1
132170  95.840  -77.676  49.142  1
132171  95.863  -77.684  49.105  1
132172  95.886  -77.692  49.067  1
132173  95.908  -77.701  49.030  1
132174  95.931  -77.709  48.992  1
132175  95.954  -77.718  48.954  1
132176  95.977  -77.726  48.918  1
132177  96.000  -77.734  48.881  1
132178  96.022  -77.743  48.845  1
132179  96.047  -77.752  48.809  1
132180  96.074  -77.761  48.773  1
132181  96.101  -77.771  48.737  1
132182  96.127  -77.780  48.702  1
132183  96.145  -77.790  48.669  1
132184  96.155  -77.799  48.636  1
132185  96.165  -77.809  48.604  1
132186  96.174  -77.822  48.571  1
132187  96.179  -77.845  48.540  1
132188  96.184  -77.868  48.508  1
132189  96.189  -77.890  48.477  1
132190  96.194  -77.913  48.448  1
132191  96.197  -77.931  48.419  1
132192  96.203  -77.931  48.388  1
132193  96.206  -77.925  48.358  1
132194  96.208  -77.920  48.328  1
132195  96.210  -77.915  48.298  1
132196  96.213  -77.909  48.271  1
132197  96.216  -77.904  48.244  1
132198  96.218  -77.899  48.218  1
132199  96.220  -77.893  48.191  1
132200  96.223  -77.888  48.165  1
132201  96.225  -77.882  48.140  1
132202  96.227  -77.877  48.115  1
132203  96.227  -77.873  48.092  1
132204  96.224  -77.869  48.071  1
132205  96.240  -77.865  48.051  1
132206  96.261  -77.861  48.030  1
132207  96.282  -77.856  48.008  1
132208  96.302  -77.852  47.984  1
132209  96.324  -77.854  47.961  1
132210  96.345  -77.859  47.939  1
132211  96.367  -77.865  47.917  1
132212  96.389  -77.870  47.895  1
132213  96.411  -77.875  47.873  1
132214  96.433  -77.880  47.850  1
132215  96.454  -77.890  47.827  1
132216  96.475  -77.902  47.805  1
132217  96.496  -77.915  47.784  1
132218  96.517  -77.927  47.762  1
132219  96.543  -77.935  47.739  1
132220  96.551  -77.934  47.716  1
132221  96.558  -77.931  47.692  1
132222  96.569  -77.933  47.666  1
132223  96.580  -77.934  47.640  1
132224  96.591  -77.936  47.614  1
132225  96.601  -77.937  47.589  1
132226  96.612  -77.939  47.564  1
132227  96.623  -77.940  47.540  1
132228  96.633  -77.942  47.517  1
132229  96.644  -77.943  47.493  1
132230  96.657  -77.952  47.469  1
132231  96.671  -77.969  47.445  1
132232  96.685  -77.986  47.420  1
132233  96.700  -78.003  47.397  1
132234  96.715  -78.021  47.373  1
132235  96.742  -78.035  47.348  1
132236  96.769  -78.050  47.323  1
132237  96.797  -78.065  47.298  1
132238  96.824  -78.080  47.271  1
132239  96.848  -78.095  47.244  1
132240  96.850  -78.109  47.217  1
132241  96.856  -78.125  47.189  1
132242  96.862  -78.143  47.161  1
132243  96.868  -78.160  47.136  1
132244  96.882  -78.173  47.110  1
132245  96.902  -78.180  47.084  1
132246  96.917  -78.186  47.059  1
132247  96.932  -78.193  47.034  1
132248  96.947  -78.199  47.011  1
132249  96.961  -78.206  46.989  1
132250  96.978  -78.214  46.969  1
132251  96.996  -78.224  46.951  1
132252  97.014  -78.233  46.933  1
132253  97.031  -78.243  46.916  1
132254  97.048  -78.253  46.901  1
132255  97.066  -78.262  46.885  1
132256  97.084  -78.272  46.867  1
132257  97.106  -78.282  46.847  1
132258  97.147  -78.288  46.828  1
132259  97.188  -78.292  46.809  1
132260  97.229  -78.297  46.789  1
132261  97.271  -78.303  46.768  1
132262  97.312  -78.309  46.748  1
132263  97.354  -78.315  46.729  1
132264  97.395  -78.321  46.711  1
132265  97.437  -78.326  46.695  1
132266  97.478  -78.332  46.676  1
132267  97.520  -78.338  46.658  1
132268  97.561  -78.344  46.641  1
132269  97.602  -78.351  46.626  1
132270  97.644  -78.357  46.609  1
132271  97.685  -78.362  46.591  1
132272  97.729  -78.363  46.572  1
132273  97.754  -78.367  46.552  1
132274  97.776  -78.382  46.532  1
132275  97.785  -78.382  46.511  1
132276  97.794  -78.383  46.493  1
132277  97.804  -78.384  46.475  1
132278  97.828  -78.379  46.458  1
132279  97.858  -78.371  46.441  1
132280  97.889  -78.363  46.426  1
132281  97.919  -78.355  46.411  1
132282  97.949  -78.347  46.395  1
132283  97.982  -78.338  46.379  1
132284  98.018  -78.331  46.361  1
132285  98.036  -78.338  46.344  1
132286  98.045  -78.347  46.327  1
132287  98.059  -78.344  46.309  1
132288  98.077  -78.326  46.292  1
132289  98.105  -78.317  46.276  1
132290  98.133  -78.308  46.259  1
132291  98.141  -78.311  46.241  1
132292  98.137  -78.322  46.223  1
132293  98.137  -78.334  46.205  1
132294  98.156  -78.347  46.187  1
132295  98.185  -78.338  46.169  1
132296  98.216  -78.326  46.152  1
132297  98.247  -78.314  46.132  1
132298  98.278  -78.302  46.114  1
132299  98.305  -78.311  46.096  1
132300  98.320  -78.341  46.077  1
132301  98.328  -78.332  46.058  1
132302  98.336  -78.322  46.039  1
132303  98.344  -78.313  46.020  1
132304  98.352  -78.303  46.000  1
132305  98.367  -78.317  45.979  1
132306  98.386  -78.360  45.958  1
132307  98.390  -78.376  45.937  1
132308  98.377  -78.357  45.915  1
132309  98.359  -78.406  45.893  1
132310  98.341  -78.454  45.872  1
132311  98.324  -78.502  45.851  1
132312  98.363  -78.520  45.830  1
132313  98.416  -78.499  45.810  1
132314  98.464  -78.479  45.791  1
132315  98.468  -78.467  45.772  1
132316  98.473  -78.460  45.752  1
132317  98.484  -78.476  45.729  1
132318  98.496  -78.492  45.706  1
132319  98.521  -78.501  45.681  1
132320  98.558  -78.485  45.658  1
132321  98.594  -78.463  45.636  1
132322  98.628  -78.438  45.614  1
132323  98.655  -78.406  45.594  1
132324  98.666  -78.390  45.573  1
132325  98.631  -78.421  45.552  1
132326  98.595  -78.451  45.533  1
132327  98.619  -78.456  45.514  1
132328  98.666  -78.438  45.496  1
132329  98.718  -78.416  45.479  1
132330  98.771  -78.392  45.461  1
132331  98.816  -78.376  45.443  1
132332  98.842  -78.378  45.426  1
132333  98.876  -78.368  45.410  1
132334  98.904  -78.365  45.393  1
132335  98.932  -78.362  45.377  1
132336  98.953  -78.360  45.361  1
132337  98.969  -78.405  45.345  1
132338  98.986  -78.450  45.331  1
132339  99.002  -78.495  45.316  1
132340  99.013  -78.519  45.302  1
132341  99.062  -78.514  45.288  1
132342  99.110  -78.498  45.275  1
132343  99.158  -78.482  45.263  1
132344  99.177  -78.482  45.250  1
132345  99.145  -78.509  45.237  1
132346  99.159  -78.516  45.223  1
132347  99.178  -78.521  45.210  1
132348  99.198  -78.526  45.196  1
132349  99.217  -78.531  45.183  1
132350  99.236  -78.536  45.170  1
132351  99.256  -78.541  45.158  1
132352  99.261  -78.558  45.145  1
132353  99.264  -78.578  45.133  1
132354  99.267  -78.597  45.122  1
132355  99.270  -78.617  45.110  1
132356  99.273  -78.636  45.100  1
132357  99.273  -78.656  45.089  1
132358  99.292  -78.661  45.076  1
132359  99.365  -78.645  45.062  1
132360  99.436  -78.634  45.048  1
132361  99.498  -78.674  45.033  1
132362  99.560  -78.714  45.018  1
132363  99.622  -78.755  45.004  1
132364  99.683  -78.796  44.991  1
132365  99.741  -78.829  44.979  1
132366  99.842  -78.798  44.968  1
132367  99.885  -78.790  44.957  1
132368  99.871  -78.819  44.945  1
132369  99.857  -78.847  44.934  1
132370  99.844  -78.876  44.922  1
132371  99.832  -78.918  44.911  1
132372  99.845  -78.923  44.899  1
132373  99.859  -78.927  44.887  1
132374  99.872  -78.932  44.876  1
132375  99.886  -78.937  44.866  1
132376  99.899  -78.941  44.856  1
132377  99.912  -78.946  44.847  1
132378  99.930  -78.949  44.838  1
132379  99.950  -78.952  44.830  1
132380  99.970  -78.955  44.821  1
132381  99.979  -78.942  44.814  1
132382  99.994  -78.939  44.807  1
132383  100.020  -78.951  44.800  1
132384  100.046  -78.963  44.794  1
132385  100.075  -78.982  44.788  1
132386  100.105  -79.000  44.782  1
132387  100.134  -79.018  44.776  1
132388  100.163  -79.037  44.771  1
132389  100.193  -79.055  44.765  1
132390  100.222  -79.073  44.759  1
132391  100.252  -79.091  44.753  1
132392  100.280  -79.104  44.747  1
132393  100.308  -79.109  44.740  1
132394  100.335  -79.115  44.732  1
132395  100.370  -79.125  44.725  1
132396  100.409  -79.135  44.717  1
132397  100.448  -79.152  44.708  1
132398  100.487  -79.169  44.698  1
132399  100.527  -79.185  44.689  1
132400  100.564  -79.203  44.678  1
132673  93.171  -78.176  54.059  1
132674  93.195  -78.165  54.051  1
132675  93.218  -78.153  54.044  1
132676  93.241  -78.141  54.034  1
132677  93.265  -78.129  54.025  1
132678  93.289  -78.117  54.015  1
132679  93.312  -78.105  54.005  1
132680  93.336  -78.094  53.996  1
132681  93.360  -78.081  53.986  1
132682  93.383  -78.069  53.976  1
132683  93.401  -78.062  53.963  1
132684  93.410  -78.059  53.951  1
132685  93.420  -78.057  53.939  1
132686  93.430  -78.055  53.926  1
132687  93.431  -78.044  53.913  1
132688  93.442  -78.028  53.900  1
132689  93.452  -78.012  53.888  1
132690  93.462  -77.997  53.872  1
132691  93.473  -77.982  53.856  1
132692  93.483  -77.966  53.841  1
132693  93.499  -77.953  53.826  1
132694  93.510  -77.945  53.810  1
132695  93.522  -77.937  53.795  1
132696  93.534  -77.928  53.779  1
132697  93.545  -77.920  53.761  1
132698  93.557  -77.912  53.745  1
132699  93.568  -77.903  53.728  1
132700  93.580  -77.895  53.709  1
132701  93.591  -77.887  53.692  1
132702  93.603  -77.878  53.674  1
132703  93.615  -77.870  53.657  1
132704  93.626  -77.862  53.638  1
132705  93.638  -77.854  53.619  1
132706  93.652  -77.846  53.600  1
132707  93.667  -77.839  53.582  1
132708  93.682  -77.832  53.562  1
132709  93.695  -77.827  53.542  1
132710  93.708  -77.824  53.522  1
132719  93.823  -77.785  53.345  1
132720  93.836  -77.780  53.326  1
132721  93.849  -77.777  53.307  1
132722  93.862  -77.772  53.290  1
132723  93.874  -77.768  53.272  1
132724  93.888  -77.764  53.254  1
132725  93.900  -77.759  53.237  1
132726  93.913  -77.755  53.219  1
132727  93.926  -77.751  53.202  1
132728  93.939  -77.746  53.185  1
132729  93.952  -77.743  53.170  1
132730  93.965  -77.738  53.155  1
132731  93.978  -77.733  53.141  1
132732  93.989  -77.730  53.129  1
132733  93.989  -77.727  53.114  1
132734  93.989  -77.724  53.097  1
132735  93.989  -77.721  53.078  1
132736  93.989  -77.718  53.058  1
132737  93.989  -77.714  53.040  1
132738  93.989  -77.711  53.021  1
132739  93.989  -77.708  53.000  1
132740  93.989  -77.705  52.980  1
132741  93.989  -77.702  52.959  1
132742  93.994  -77.702  52.937  1
132743  94.008  -77.707  52.915  1
132744  94.023  -77.711  52.893  1
132745  94.037  -77.717  52.872  1
132746  94.052  -77.722  52.851  1
132747  94.066  -77.726  52.830  1
132748  94.083  -77.718  52.808  1
132749  94.090  -77.711  52.785  1
132750  94.091  -77.702  52.762  1
132751  94.091  -77.695  52.737  1
132752  94.121  -77.667  52.712  1
132753  94.124  -77.672  52.688  1
132754  94.137  -77.673  52.665  1
132755  94.151  -77.674  52.643  1
132756  94.165  -77.675  52.622  1
132757  94.178  -77.676  52.602  1
132758  94.192  -77.677  52.583  1
132759  94.205  -77.678  52.564  1
132760  94.219  -77.679  52.546  1
132761  94.232  -77.680  52.529  1
132762  94.246  -77.681  52.513  1
132763  94.260  -77.682  52.498  1
132764  94.273  -77.683  52.484  1
132765  94.287  -77.684  52.473  1
132766  94.298  -77.638  52.462  1
132767  94.323  -77.602  52.454  1
132768  94.360  -77.585  52.449  1
132769  94.396  -77.568  52.447  1
132770  94.433  -77.551  52.444  1
132771  94.469  -77.535  52.439  1
132772  94.500  -77.524  52.432  1
132773  94.488  -77.551  52.421  1
132774  94.477  -77.579  52.405  1
132775  94.474  -77.598  52.385  1
132776  94.485  -77.597  52.364  1
132777  94.505  -77.644  52.344  1
132778  94.528  -77.703  52.325  1
132779  94.551  -77.761  52.308  1
132780  94.573  -77.821  52.291  1
132781  94.596  -77.880  52.273  1
132782  94.619  -77.938  52.254  1
132783  94.642  -77.997  52.233  1
132784  94.658  -78.010  52.211  1
132785  94.672  -77.994  52.189  1
132786  94.674  -77.937  52.166  1
132787  94.676  -77.880  52.138  1
132788  94.678  -77.822  52.109  1
132789  94.680  -77.765  52.077  1
132790  94.682  -77.707  52.044  1
132791  94.684  -77.649  52.010  1
132792  94.686  -77.592  51.977  1
132793  94.694  -77.561  51.945  1
132794  94.708  -77.551  51.910  1
132795  94.722  -77.542  51.874  1
132796  94.741  -77.542  51.837  1
132797  94.853  -77.542  51.798  1
132798  94.923  -77.498  51.760  1
132799  94.934  -77.465  51.724  1
132800  94.943  -77.477  51.690  1
132801  94.945  -77.451  51.659  1
132802  94.961  -77.465  51.624  1
132803  94.982  -77.496  51.585  1
132804  95.002  -77.527  51.544  1
132805  95.007  -77.545  51.502  1
132806  95.001  -77.553  51.462  1
132807  95.023  -77.569  51.423  1
132808  94.991  -77.545  51.383  1
132809  94.988  -77.540  51.344  1
132810  94.985  -77.536  51.306  1
132811  94.982  -77.531  51.266  1
132812  94.978  -77.526  51.222  1
132813  94.999  -77.561  51.181  1
132814  95.035  -77.603  51.139  1
132815  95.085  -77.645  51.095  1
132816  94.991  -77.711  51.048  1
132817  95.079  -77.662  51.001  1
132818  95.104  -77.646  50.958  1
132819  95.113  -77.630  50.914  1
132820  95.121  -77.614  50.870  1
132821  95.137  -77.609  50.826  1
132822  95.167  -77.636  50.783  1
132823  95.195  -77.652  50.743  1
132824  95.216  -77.637  50.704  1
132825  95.237  -77.623  50.665  1
132826  95.261  -77.611  50.627  1
132827  95.287  -77.599  50.591  1
132828  95.313  -77.588  50.554  1
132829  95.338  -77.577  50.516  1
132830  95.364  -77.566  50.479  1
132831  95.390  -77.555  50.444  1
132832  95.415  -77.543  50.409  1
132833  95.447  -77.542  50.374  1
132834  95.479  -77.543  50.339  1
132835  95.495  -77.534  50.304  1
132836  95.511  -77.526  50.268  1
132837  95.526  -77.517  50.232  1
132838  95.542  -77.508  50.197  1
132839  95.557  -77.498  50.163  1
132840  95.575  -77.482  50.128  1
132841  95.604  -77.480  50.093  1
132842  95.655  -77.493  50.059  1
132843  95.707  -77.506  50.025  1
132844  95.759  -77.519  49.992  1
132845  95.824  -77.552  49.959  1
132846  95.808  -77.567  49.927  1
132847  95.779  -77.573  49.897  1
132848  95.750  -77.578  49.866  1
132849  95.722  -77.584  49.836  1
132850  95.693  -77.589  49.807  1
132851  95.676  -77.608  49.780  1
132852  95.680  -77.611  49.752  1
132853  95.683  -77.614  49.723  1
132854  95.687  -77.616  49.693  1
132855  95.690  -77.619  49.663  1
132856  95.694  -77.622  49.631  1
132857  95.697  -77.624  49.600  1
132858  95.701  -77.627  49.569  1
132859  95.704  -77.630  49.538  1
132860  95.708  -77.633  49.508  1
132861  95.711  -77.635  49.478  1
132862  95.717  -77.637  49.448  1
132863  95.727  -77.638  49.417  1
132864  95.737  -77.638  49.386  1
132865  95.747  -77.639  49.354  1
132866  95.757  -77.639  49.324  1
132867  95.767  -77.639  49.292  1
132868  95.776  -77.640  49.259  1
132869  95.792  -77.645  49.223  1
132870  95.817  -77.658  49.189  1
132871  95.842  -77.668  49.154  1
132872  95.865  -77.677  49.117  1
132873  95.887  -77.685  49.080  1
132874  95.910  -77.694  49.043  1
132875  95.933  -77.702  49.005  1
132876  95.955  -77.711  48.967  1
132877  95.978  -77.719  48.931  1
132878  96.005  -77.728  48.895  1
132879  96.032  -77.738  48.858  1
132880  96.059  -77.747  48.823  1
132881  96.086  -77.756  48.786  1
132882  96.112  -77.766  48.750  1
132883  96.126  -77.776  48.714  1
132884  96.136  -77.786  48.681  1
132885  96.147  -77.796  48.648  1
132886  96.156  -77.805  48.615  1
132887  96.165  -77.819  48.583  1
132888  96.170  -77.842  48.551  1
132889  96.175  -77.865  48.520  1
132890  96.180  -77.887  48.489  1
132891  96.185  -77.910  48.459  1
132892  96.197  -77.925  48.429  1
132893  96.197  -77.920  48.399  1
132894  96.196  -77.912  48.368  1
132895  96.195  -77.905  48.337  1
132896  96.194  -77.897  48.307  1
132897  96.195  -77.890  48.279  1
132898  96.198  -77.885  48.252  1
132899  96.200  -77.880  48.226  1
132900  96.203  -77.874  48.200  1
132901  96.205  -77.869  48.174  1
132902  96.207  -77.864  48.149  1
132903  96.210  -77.859  48.125  1
132904  96.209  -77.854  48.102  1
132905  96.220  -77.850  48.082  1
132906  96.240  -77.846  48.061  1
132907  96.261  -77.841  48.040  1
132908  96.282  -77.837  48.017  1
132909  96.302  -77.832  47.994  1
132910  96.324  -77.835  47.971  1
132911  96.345  -77.840  47.947  1
132912  96.367  -77.845  47.925  1
132913  96.388  -77.854  47.903  1
132914  96.409  -77.867  47.880  1
132915  96.431  -77.879  47.857  1
132916  96.452  -77.891  47.833  1
132917  96.473  -77.904  47.811  1
132918  96.494  -77.916  47.788  1
132919  96.517  -77.928  47.765  1
132920  96.544  -77.934  47.742  1
132921  96.552  -77.933  47.718  1
132922  96.559  -77.931  47.694  1
132923  96.568  -77.929  47.669  1
132924  96.577  -77.930  47.643  1
132925  96.588  -77.931  47.618  1
132926  96.599  -77.933  47.594  1
132927  96.609  -77.934  47.570  1
132928  96.620  -77.935  47.546  1
132929  96.631  -77.937  47.522  1
132930  96.642  -77.938  47.498  1
132931  96.653  -77.942  47.474  1
132932  96.667  -77.959  47.450  1
132933  96.682  -77.976  47.426  1
132934  96.696  -77.993  47.402  1
132935  96.713  -78.010  47.378  1
132936  96.741  -78.025  47.353  1
132937  96.768  -78.040  47.329  1
132938  96.795  -78.055  47.303  1
132939  96.838  -78.072  47.278  1
132940  96.854  -78.085  47.251  1
132941  96.853  -78.097  47.223  1
132942  96.854  -78.110  47.195  1
132943  96.860  -78.128  47.168  1
132944  96.866  -78.145  47.144  1
132945  96.881  -78.157  47.118  1
132946  96.905  -78.165  47.093  1
132947  96.921  -78.171  47.068  1
132948  96.936  -78.178  47.044  1
132949  96.950  -78.184  47.021  1
132950  96.966  -78.192  46.999  1
132951  96.984  -78.201  46.979  1
132952  97.002  -78.211  46.962  1
132953  97.019  -78.220  46.945  1
132954  97.036  -78.230  46.928  1
132955  97.053  -78.240  46.912  1
132956  97.070  -78.253  46.897  1
132957  97.087  -78.265  46.880  1
132958  97.103  -78.278  46.864  1
132959  97.156  -78.283  46.845  1
132960  97.197  -78.288  46.826  1
132961  97.238  -78.293  46.807  1
132962  97.279  -78.298  46.788  1
132963  97.320  -78.303  46.768  1
132964  97.361  -78.308  46.751  1
132965  97.402  -78.313  46.735  1
132966  97.443  -78.318  46.719  1
132967  97.485  -78.322  46.700  1
132968  97.525  -78.328  46.683  1
132969  97.567  -78.332  46.667  1
132970  97.607  -78.338  46.651  1
132971  97.649  -78.342  46.634  1
132972  97.689  -78.347  46.616  1
132973  97.731  -78.352  46.598  1
132974  97.759  -78.354  46.578  1
132975  97.769  -78.354  46.558  1
132976  97.778  -78.355  46.537  1
132977  97.787  -78.356  46.519  1
132978  97.797  -78.357  46.500  1
132979  97.820  -78.351  46.482  1
132980  97.851  -78.344  46.465  1
132981  97.881  -78.336  46.449  1
132982  97.912  -78.329  46.434  1
132983  97.942  -78.321  46.418  1
132984  97.972  -78.313  46.401  1
132985  98.005  -78.304  46.384  1
132986  98.020  -78.311  46.367  1
132987  98.029  -78.320  46.349  1
132988  98.040  -78.326  46.331  1
132989  98.068  -78.317  46.313  1
132990  98.095  -78.307  46.296  1
132991  98.123  -78.298  46.279  1
132992  98.139  -78.297  46.261  1
132993  98.135  -78.308  46.243  1
132994  98.140  -78.319  46.224  1
132995  98.159  -78.333  46.205  1
132996  98.188  -78.325  46.187  1
132997  98.219  -78.313  46.169  1
132998  98.249  -78.301  46.150  1
132999  98.280  -78.290  46.131  1
133000  98.299  -78.341  46.112  1
133001  98.311  -78.355  46.093  1
133002  98.319  -78.345  46.074  1
133003  98.327  -78.335  46.054  1
133004  98.336  -78.326  46.035  1
133005  98.344  -78.316  46.015  1
133006  98.352  -78.306  45.993  1
133007  98.364  -78.311  45.972  1
133008  98.380  -78.347  45.951  1
133009  98.365  -78.345  45.930  1
133010  98.346  -78.398  45.909  1
133011  98.327  -78.450  45.888  1
133012  98.308  -78.501  45.866  1
133013  98.336  -78.511  45.846  1
133014  98.388  -78.490  45.825  1
133015  98.441  -78.469  45.805  1
133016  98.478  -78.451  45.786  1
133017  98.481  -78.439  45.766  1
133018  98.492  -78.453  45.743  1
133019  98.503  -78.470  45.720  1
133020  98.540  -78.473  45.695  1
133021  98.577  -78.457  45.671  1
133022  98.613  -78.435  45.649  1
133023  98.649  -78.412  45.627  1
133024  98.685  -78.389  45.606  1
133025  98.697  -78.376  45.585  1
133026  98.662  -78.401  45.565  1
133027  98.630  -78.416  45.546  1
133028  98.647  -78.408  45.528  1
133029  98.700  -78.385  45.510  1
133030  98.752  -78.360  45.493  1
133031  98.801  -78.341  45.475  1
133032  98.820  -78.354  45.458  1
133033  98.839  -78.367  45.441  1
133034  98.873  -78.358  45.423  1
133035  98.911  -78.342  45.407  1
133036  98.948  -78.327  45.391  1
133037  98.972  -78.338  45.375  1
133038  98.988  -78.384  45.359  1
133039  99.004  -78.429  45.344  1
133040  99.021  -78.475  45.330  1
133041  99.042  -78.512  45.316  1
133042  99.090  -78.496  45.303  1
133043  99.138  -78.481  45.290  1
133044  99.186  -78.466  45.277  1
133045  99.210  -78.462  45.265  1
133046  99.179  -78.489  45.252  1
133047  99.169  -78.505  45.238  1
133048  99.189  -78.510  45.226  1
133049  99.208  -78.516  45.212  1
133050  99.228  -78.520  45.198  1
133051  99.247  -78.526  45.185  1
133052  99.258  -78.538  45.173  1
133053  99.261  -78.557  45.160  1
133054  99.264  -78.576  45.148  1
133055  99.267  -78.596  45.136  1
133056  99.270  -78.616  45.124  1
133057  99.273  -78.636  45.113  1
133058  99.276  -78.655  45.101  1
133059  99.298  -78.662  45.088  1
133060  99.371  -78.646  45.074  1
133061  99.443  -78.630  45.060  1
133062  99.510  -78.645  45.046  1
133063  99.572  -78.686  45.031  1
133064  99.634  -78.726  45.018  1
133065  99.693  -78.764  45.005  1
133066  99.746  -78.808  44.993  1
133067  99.800  -78.843  44.982  1
133068  99.882  -78.818  44.971  1
133069  99.887  -78.827  44.961  1
133070  99.878  -78.843  44.949  1
133071  99.868  -78.862  44.938  1
133072  99.854  -78.891  44.926  1
133073  99.846  -78.935  44.914  1
133074  99.859  -78.940  44.901  1
133075  99.873  -78.945  44.889  1
133076  99.891  -78.948  44.879  1
133077  99.911  -78.950  44.867  1
133078  99.931  -78.953  44.858  1
133079  99.951  -78.956  44.849  1
133080  99.971  -78.959  44.841  1
133081  99.981  -78.947  44.832  1
133082  99.987  -78.928  44.824  1
133083  100.003  -78.927  44.816  1
133084  100.029  -78.939  44.809  1
133085  100.054  -78.951  44.802  1
133086  100.080  -78.963  44.796  1
133087  100.107  -78.978  44.790  1
133088  100.136  -78.996  44.784  1
133089  100.166  -79.015  44.778  1
133090  100.195  -79.033  44.772  1
133091  100.225  -79.051  44.766  1
133092  100.254  -79.069  44.760  1
133093  100.283  -79.084  44.753  1
133094  100.311  -79.090  44.745  1
133095  100.339  -79.096  44.738  1
133096  100.378  -79.106  44.730  1
133097  100.416  -79.122  44.721  1
133098  100.456  -79.138  44.712  1
133099  100.495  -79.155  44.702  1
133100  100.530  -79.173  44.692  1
133101  100.562  -79.193  44.681  1
133102  100.595  -79.212  44.670  1
133373  93.146  -78.178  54.075  1
133374  93.170  -78.166  54.068  1
133375  93.194  -78.154  54.060  1
133376  93.217  -78.142  54.053  1
133377  93.241  -78.131  54.043  1
133378  93.265  -78.119  54.034  1
133379  93.288  -78.106  54.024  1
133380  93.312  -78.095  54.015  1
133381  93.336  -78.083  54.006  1
133382  93.359  -78.071  53.996  1
133383  93.383  -78.059  53.986  1
133384  93.401  -78.051  53.973  1
133385  93.411  -78.049  53.960  1
133386  93.420  -78.047  53.948  1
133387  93.426  -78.041  53.935  1
133388  93.433  -78.028  53.922  1
133389  93.443  -78.012  53.910  1
133390  93.453  -77.997  53.897  1
133391  93.464  -77.981  53.882  1
133392  93.474  -77.966  53.866  1
133393  93.485  -77.950  53.850  1
133394  93.500  -77.940  53.836  1
133395  93.512  -77.931  53.820  1
133396  93.523  -77.924  53.805  1
133397  93.535  -77.915  53.789  1
133398  93.547  -77.907  53.771  1
133399  93.558  -77.899  53.754  1
133400  93.570  -77.890  53.737  1
133401  93.581  -77.882  53.719  1
133402  93.593  -77.874  53.702  1
133403  93.605  -77.865  53.684  1
133404  93.616  -77.857  53.667  1
133405  93.628  -77.849  53.648  1
133406  93.639  -77.841  53.628  1
133407  93.653  -77.834  53.609  1
133408  93.669  -77.826  53.591  1
133409  93.683  -77.821  53.572  1
133410  93.695  -77.817  53.552  1
133411  93.708  -77.812  53.532  1
133412  93.721  -77.808  53.512  1
133420  93.824  -77.774  53.356  1
133421  93.837  -77.770  53.337  1
133422  93.850  -77.765  53.319  1
133423  93.862  -77.761  53.302  1
133424  93.875  -77.757  53.284  1
133425  93.888  -77.752  53.266  1
133426  93.901  -77.748  53.249  1
133427  93.914  -77.744  53.232  1
133428  93.927  -77.740  53.215  1
133429  93.939  -77.735  53.198  1
133430  93.949  -77.730  53.182  1
133431  93.961  -77.725  53.167  1
133432  93.971  -77.721  53.154  1
133433  93.985  -77.716  53.142  1
133434  93.990  -77.718  53.127  1
133435  93.995  -77.719  53.110  1
133436  93.998  -77.718  53.091  1
133437  93.998  -77.715  53.072  1
133438  93.998  -77.712  53.054  1
133439  93.998  -77.708  53.036  1
133440  93.997  -77.705  53.017  1
133441  93.997  -77.702  52.997  1
133442  93.997  -77.699  52.976  1
133443  94.001  -77.695  52.955  1
133444  94.007  -77.689  52.932  1
133445  94.019  -77.692  52.910  1
133446  94.034  -77.698  52.889  1
133447  94.049  -77.702  52.868  1
133448  94.063  -77.707  52.847  1
133449  94.080  -77.699  52.826  1
133450  94.097  -77.692  52.803  1
133451  94.099  -77.684  52.781  1
133452  94.114  -77.665  52.755  1
133453  94.116  -77.648  52.729  1
133454  94.120  -77.655  52.704  1
133455  94.127  -77.661  52.681  1
133456  94.141  -77.662  52.659  1
133457  94.154  -77.663  52.638  1
133458  94.168  -77.664  52.619  1
133459  94.182  -77.665  52.600  1
133460  94.195  -77.666  52.582  1
133461  94.209  -77.667  52.565  1
133462  94.222  -77.668  52.548  1
133463  94.236  -77.669  52.533  1
133464  94.259  -77.659  52.520  1
133465  94.298  -77.631  52.507  1
133466  94.344  -77.625  52.497  1
133467  94.341  -77.620  52.489  1
133468  94.362  -77.602  52.482  1
133469  94.384  -77.584  52.480  1
133470  94.405  -77.567  52.479  1
133471  94.426  -77.548  52.477  1
133472  94.451  -77.531  52.473  1
133473  94.488  -77.514  52.466  1
133474  94.524  -77.498  52.453  1
133475  94.529  -77.511  52.436  1
133476  94.518  -77.538  52.416  1
133477  94.490  -77.574  52.398  1
133478  94.488  -77.666  52.379  1
133479  94.509  -77.755  52.363  1
133480  94.536  -77.815  52.349  1
133481  94.564  -77.873  52.332  1
133482  94.591  -77.932  52.314  1
133483  94.618  -77.990  52.296  1
133484  94.645  -78.050  52.274  1
133485  94.652  -78.006  52.253  1
133486  94.654  -77.949  52.231  1
133487  94.655  -77.891  52.207  1
133488  94.657  -77.834  52.179  1
133489  94.660  -77.776  52.148  1
133490  94.662  -77.719  52.116  1
133491  94.664  -77.661  52.080  1
133492  94.666  -77.604  52.046  1
133493  94.668  -77.546  52.012  1
133494  94.681  -77.537  51.981  1
133495  94.695  -77.528  51.945  1
133496  94.709  -77.519  51.907  1
133497  94.723  -77.510  51.868  1
133498  94.861  -77.489  51.828  1
133499  94.932  -77.553  51.792  1
133500  94.940  -77.572  51.759  1
133501  94.942  -77.539  51.728  1
133502  94.943  -77.495  51.695  1
133503  94.943  -77.452  51.659  1
133504  94.964  -77.483  51.621  1
133505  94.984  -77.514  51.579  1
133506  94.993  -77.535  51.538  1
133507  94.992  -77.545  51.498  1
133508  95.019  -77.564  51.460  1
133509  95.045  -77.583  51.421  1
133510  95.072  -77.602  51.382  1
133511  95.037  -77.577  51.342  1
133512  94.997  -77.546  51.302  1
133513  94.960  -77.519  51.260  1
133514  95.006  -77.560  51.217  1
133515  95.091  -77.632  51.172  1
133516  95.116  -77.650  51.125  1
133517  95.005  -77.694  51.078  1
133518  95.093  -77.643  51.032  1
133519  95.114  -77.639  50.986  1
133520  95.125  -77.642  50.941  1
133521  95.135  -77.629  50.897  1
133522  95.145  -77.615  50.853  1
133523  95.176  -77.644  50.810  1
133524  95.197  -77.630  50.770  1
133525  95.218  -77.614  50.731  1
133526  95.239  -77.600  50.693  1
133527  95.262  -77.588  50.654  1
133528  95.287  -77.577  50.617  1
133529  95.313  -77.565  50.580  1
133530  95.339  -77.554  50.543  1
133531  95.365  -77.542  50.508  1
133532  95.390  -77.532  50.472  1
133533  95.422  -77.532  50.436  1
133534  95.455  -77.532  50.401  1
133535  95.486  -77.532  50.366  1
133536  95.504  -77.524  50.330  1
133537  95.519  -77.515  50.293  1
133538  95.535  -77.506  50.256  1
133539  95.550  -77.497  50.220  1
133540  95.566  -77.489  50.186  1
133541  95.582  -77.479  50.151  1
133542  95.629  -77.494  50.114  1
133543  95.681  -77.512  50.078  1
133544  95.733  -77.530  50.043  1
133545  95.785  -77.545  50.009  1
133546  95.833  -77.563  49.975  1
133547  95.806  -77.570  49.943  1
133548  95.777  -77.576  49.912  1
133549  95.748  -77.581  49.880  1
133550  95.720  -77.587  49.849  1
133551  95.691  -77.592  49.820  1
133552  95.677  -77.610  49.791  1
133553  95.680  -77.612  49.763  1
133554  95.684  -77.615  49.733  1
133555  95.687  -77.617  49.703  1
133556  95.691  -77.620  49.673  1
133557  95.694  -77.624  49.644  1
133558  95.698  -77.626  49.613  1
133559  95.701  -77.629  49.581  1
133560  95.705  -77.631  49.550  1
133561  95.708  -77.634  49.518  1
133562  95.716  -77.636  49.487  1
133563  95.725  -77.636  49.456  1
133564  95.735  -77.636  49.425  1
133565  95.745  -77.637  49.394  1
133566  95.755  -77.637  49.362  1
133567  95.765  -77.638  49.331  1
133568  95.775  -77.639  49.300  1
133569  95.785  -77.639  49.267  1
133570  95.795  -77.639  49.232  1
133571  95.820  -77.652  49.200  1
133572  95.843  -77.661  49.166  1
133573  95.866  -77.670  49.130  1
133574  95.889  -77.678  49.094  1
133575  95.911  -77.686  49.057  1
133576  95.937  -77.696  49.019  1
133577  95.963  -77.705  48.981  1
133578  95.990  -77.714  48.944  1
133579  96.017  -77.724  48.908  1
133580  96.044  -77.733  48.871  1
133581  96.071  -77.743  48.836  1
133582  96.098  -77.752  48.800  1
133583  96.108  -77.761  48.763  1
133584  96.118  -77.771  48.727  1
133585  96.128  -77.782  48.694  1
133586  96.138  -77.792  48.661  1
133587  96.148  -77.802  48.627  1
133588  96.156  -77.817  48.595  1
133589  96.161  -77.839  48.563  1
133590  96.166  -77.862  48.531  1
133591  96.171  -77.884  48.501  1
133592  96.180  -77.902  48.470  1
133593  96.194  -77.914  48.440  1
133594  96.199  -77.914  48.409  1
133595  96.198  -77.906  48.378  1
133596  96.197  -77.899  48.347  1
133597  96.196  -77.891  48.317  1
133598  96.195  -77.884  48.287  1
133599  96.194  -77.876  48.261  1
133600  96.194  -77.868  48.234  1
133601  96.193  -77.861  48.209  1
133602  96.192  -77.853  48.183  1
133603  96.191  -77.846  48.159  1
133604  96.192  -77.840  48.135  1
133605  96.198  -77.835  48.113  1
133606  96.219  -77.830  48.092  1
133607  96.240  -77.826  48.071  1
133608  96.260  -77.821  48.050  1
133609  96.281  -77.817  48.027  1
133610  96.302  -77.812  48.004  1
133611  96.323  -77.818  47.980  1
133612  96.344  -77.831  47.956  1
133613  96.365  -77.843  47.933  1
133614  96.386  -77.856  47.911  1
133615  96.407  -77.868  47.888  1
133616  96.429  -77.881  47.864  1
133617  96.450  -77.893  47.840  1
133618  96.471  -77.906  47.817  1
133619  96.492  -77.918  47.794  1
133620  96.519  -77.928  47.771  1
133621  96.545  -77.934  47.746  1
133622  96.553  -77.932  47.722  1
133623  96.561  -77.931  47.697  1
133624  96.569  -77.928  47.673  1
133625  96.576  -77.927  47.648  1
133626  96.585  -77.926  47.623  1
133627  96.596  -77.928  47.599  1
133628  96.607  -77.929  47.575  1
133629  96.617  -77.931  47.551  1
133630  96.628  -77.932  47.527  1
133631  96.639  -77.934  47.502  1
133632  96.650  -77.935  47.478  1
133633  96.663  -77.949  47.455  1
133634  96.678  -77.966  47.432  1
133635  96.692  -77.984  47.408  1
133636  96.712  -78.000  47.383  1
133637  96.739  -78.015  47.358  1
133638  96.766  -78.029  47.333  1
133639  96.800  -78.045  47.308  1
133640  96.853  -78.064  47.283  1
133641  96.861  -78.076  47.256  1
133642  96.859  -78.087  47.229  1
133643  96.857  -78.099  47.202  1
133644  96.858  -78.112  47.176  1
133645  96.864  -78.129  47.151  1
133646  96.880  -78.141  47.127  1
133647  96.904  -78.149  47.102  1
133648  96.924  -78.156  47.078  1
133649  96.939  -78.163  47.054  1
133650  96.954  -78.169  47.031  1
133651  96.972  -78.178  47.009  1
133652  96.990  -78.188  46.990  1
133653  97.007  -78.197  46.972  1
133654  97.024  -78.210  46.955  1
133655  97.040  -78.222  46.938  1
133656  97.056  -78.234  46.923  1
133657  97.073  -78.247  46.908  1
133658  97.090  -78.259  46.893  1
133659  97.106  -78.272  46.879  1
133660  97.165  -78.279  46.861  1
133661  97.206  -78.284  46.843  1
133662  97.247  -78.289  46.825  1
133663  97.288  -78.294  46.807  1
133664  97.329  -78.299  46.788  1
133665  97.370  -78.304  46.771  1
133666  97.410  -78.307  46.756  1
133667  97.449  -78.308  46.740  1
133668  97.488  -78.309  46.723  1
133669  97.527  -78.310  46.706  1
133670  97.566  -78.311  46.691  1
133671  97.605  -78.313  46.675  1
133672  97.644  -78.313  46.658  1
133673  97.681  -78.314  46.640  1
133674  97.710  -78.313  46.623  1
133675  97.740  -78.311  46.604  1
133676  97.760  -78.326  46.584  1
133677  97.771  -78.329  46.565  1
133678  97.780  -78.329  46.546  1
133679  97.789  -78.329  46.528  1
133680  97.813  -78.325  46.509  1
133681  97.844  -78.317  46.491  1
133682  97.874  -78.309  46.474  1
133683  97.904  -78.301  46.457  1
133684  97.935  -78.294  46.441  1
133685  97.968  -78.286  46.424  1
133686  97.996  -78.280  46.407  1
133687  98.008  -78.285  46.389  1
133688  98.018  -78.295  46.371  1
133689  98.032  -78.304  46.353  1
133690  98.059  -78.307  46.334  1
133691  98.086  -78.298  46.316  1
133692  98.114  -78.288  46.298  1
133693  98.137  -78.282  46.280  1
133694  98.133  -78.293  46.261  1
133695  98.143  -78.306  46.242  1
133696  98.162  -78.319  46.223  1
133697  98.191  -78.312  46.205  1
133698  98.221  -78.300  46.187  1
133699  98.252  -78.288  46.168  1
133700  98.275  -78.318  46.148  1
133701  98.294  -78.370  46.129  1
133702  98.303  -78.368  46.109  1
133703  98.311  -78.358  46.090  1
133704  98.319  -78.348  46.070  1
133705  98.327  -78.338  46.050  1
133706  98.336  -78.329  46.030  1
133707  98.344  -78.319  46.008  1
133708  98.352  -78.309  45.987  1
133709  98.361  -78.306  45.966  1
133710  98.353  -78.338  45.946  1
133711  98.336  -78.388  45.925  1
133712  98.332  -78.435  45.904  1
133713  98.327  -78.482  45.882  1
133714  98.338  -78.493  45.861  1
133715  98.361  -78.481  45.840  1
133716  98.414  -78.460  45.819  1
133717  98.466  -78.438  45.800  1
133718  98.491  -78.423  45.778  1
133719  98.499  -78.429  45.755  1
133720  98.521  -78.441  45.732  1
133721  98.559  -78.444  45.707  1
133722  98.595  -78.429  45.684  1
133723  98.631  -78.407  45.661  1
133724  98.667  -78.384  45.640  1
133725  98.702  -78.360  45.618  1
133726  98.725  -78.331  45.597  1
133727  98.701  -78.344  45.578  1
133728  98.671  -78.357  45.560  1
133729  98.681  -78.353  45.542  1
133730  98.734  -78.329  45.524  1
133731  98.786  -78.307  45.506  1
133732  98.805  -78.319  45.488  1
133733  98.824  -78.332  45.471  1
133734  98.843  -78.345  45.455  1
133735  98.865  -78.354  45.437  1
133736  98.904  -78.338  45.420  1
133737  98.941  -78.322  45.405  1
133738  98.962  -78.351  45.390  1
133739  98.976  -78.401  45.374  1
133740  98.989  -78.449  45.360  1
133741  99.011  -78.478  45.346  1
133742  99.033  -78.504  45.331  1
133743  99.114  -78.481  45.317  1
133744  99.166  -78.463  45.304  1
133745  99.214  -78.448  45.292  1
133746  99.244  -78.442  45.280  1
133747  99.212  -78.469  45.267  1
133748  99.180  -78.495  45.255  1
133749  99.200  -78.500  45.243  1
133750  99.219  -78.505  45.229  1
133751  99.238  -78.510  45.215  1
133752  99.255  -78.517  45.202  1
133753  99.258  -78.537  45.189  1
133754  99.261  -78.556  45.176  1
133755  99.264  -78.576  45.163  1
133756  99.267  -78.595  45.151  1
133757  99.270  -78.615  45.138  1
133758  99.273  -78.634  45.125  1
133759  99.286  -78.645  45.113  1
133760  99.323  -78.648  45.101  1
133761  99.385  -78.640  45.086  1
133762  99.449  -78.632  45.072  1
133763  99.522  -78.615  45.059  1
133764  99.581  -78.653  45.044  1
133765  99.630  -78.677  45.031  1
133766  99.663  -78.718  45.019  1
133767  99.752  -78.786  45.006  1
133768  99.783  -78.815  44.995  1
133769  99.841  -78.862  44.985  1
133770  99.898  -78.849  44.976  1
133771  99.890  -78.865  44.963  1
133772  99.880  -78.881  44.951  1
133773  99.871  -78.896  44.939  1
133774  99.868  -78.906  44.926  1
133775  99.873  -78.949  44.913  1
133776  99.893  -78.952  44.902  1
133777  99.913  -78.955  44.891  1
133778  99.933  -78.958  44.880  1
133779  99.953  -78.960  44.870  1
133780  99.973  -78.963  44.860  1
133781  99.983  -78.952  44.851  1
133782  99.989  -78.933  44.842  1
133783  99.994  -78.915  44.834  1
133784  100.012  -78.915  44.826  1
133785  100.037  -78.927  44.818  1
133786  100.063  -78.940  44.812  1
133787  100.088  -78.952  44.805  1
133788  100.114  -78.964  44.799  1
133789  100.140  -78.976  44.793  1
133790  100.168  -78.993  44.786  1
133791  100.198  -79.011  44.780  1
133792  100.227  -79.029  44.773  1
133793  100.257  -79.047  44.766  1
133794  100.285  -79.065  44.759  1
133795  100.313  -79.070  44.751  1
133796  100.346  -79.078  44.743  1
133797  100.385  -79.091  44.734  1
133798  100.424  -79.108  44.725  1
133799  100.462  -79.125  44.716  1
133800  100.494  -79.144  44.706  1
133801  100.527  -79.163  44.695  1
133802  100.559  -79.182  44.683  1
133803  100.592  -79.202  44.671  1
133804  100.624  -79.221  44.660  1
134073  93.127  -78.180  54.092  1
134074  93.146  -78.168  54.085  1
134075  93.169  -78.156  54.077  1
134076  93.193  -78.144  54.070  1
134077  93.217  -78.132  54.062  1
134078  93.240  -78.120  54.053  1
134079  93.264  -78.108  54.044  1
134080  93.288  -78.097  54.034  1
134081  93.311  -78.084  54.024  1
134082  93.335  -78.073  54.015  1
134083  93.359  -78.061  54.005  1
134084  93.382  -78.049  53.996  1
134085  93.401  -78.040  53.983  1
134086  93.411  -78.038  53.970  1
134087  93.421  -78.035  53.958  1
134088  93.424  -78.028  53.945  1
134089  93.434  -78.012  53.933  1
134090  93.444  -77.996  53.920  1
134091  93.455  -77.981  53.908  1
134092  93.465  -77.965  53.892  1
134093  93.475  -77.950  53.876  1
134094  93.490  -77.935  53.861  1
134095  93.501  -77.927  53.846  1
134096  93.513  -77.918  53.830  1
134097  93.524  -77.910  53.815  1
134098  93.536  -77.902  53.799  1
134099  93.548  -77.894  53.781  1
134100  93.559  -77.886  53.763  1
134101  93.571  -77.877  53.746  1
134102  93.582  -77.869  53.729  1
134103  93.594  -77.861  53.711  1
134104  93.606  -77.852  53.694  1
134105  93.617  -77.844  53.676  1
134106  93.629  -77.836  53.658  1
134107  93.640  -77.827  53.639  1
134108  93.655  -77.821  53.619  1
134109  93.670  -77.814  53.601  1
134110  93.683  -77.809  53.582  1
134111  93.696  -77.805  53.562  1
134112  93.709  -77.801  53.543  1
134113  93.721  -77.797  53.523  1
134121  93.825  -77.762  53.367  1
134122  93.837  -77.758  53.349  1
134123  93.850  -77.754  53.332  1
134124  93.863  -77.749  53.313  1
134125  93.876  -77.746  53.296  1
134126  93.889  -77.741  53.278  1
134127  93.899  -77.736  53.260  1
134128  93.910  -77.731  53.244  1
134129  93.921  -77.727  53.227  1
134130  93.931  -77.721  53.210  1
134131  93.942  -77.717  53.194  1
134132  93.953  -77.712  53.180  1
134133  93.965  -77.708  53.167  1
134134  93.979  -77.703  53.154  1
134135  93.986  -77.704  53.139  1
134136  93.991  -77.705  53.122  1
134137  93.996  -77.706  53.103  1
134138  94.000  -77.708  53.085  1
134139  94.005  -77.709  53.067  1
134140  94.006  -77.706  53.049  1
134141  94.006  -77.703  53.031  1
134142  94.006  -77.700  53.011  1
134143  94.006  -77.697  52.991  1
134144  94.011  -77.692  52.970  1
134145  94.017  -77.686  52.947  1
134146  94.023  -77.681  52.926  1
134147  94.031  -77.679  52.905  1
134148  94.045  -77.683  52.885  1
134149  94.060  -77.688  52.864  1
134150  94.076  -77.680  52.843  1
134151  94.094  -77.673  52.821  1
134152  94.105  -77.664  52.798  1
134153  94.108  -77.646  52.772  1
134154  94.111  -77.629  52.747  1
134155  94.115  -77.637  52.721  1
134156  94.118  -77.649  52.699  1
134157  94.131  -77.650  52.677  1
134158  94.144  -77.652  52.657  1
134159  94.158  -77.652  52.637  1
134160  94.172  -77.653  52.619  1
134161  94.185  -77.655  52.602  1
134162  94.199  -77.655  52.586  1
134163  94.238  -77.627  52.569  1
134164  94.276  -77.599  52.555  1
134165  94.316  -77.570  52.543  1
134166  94.354  -77.542  52.532  1
134167  94.391  -77.589  52.524  1
134168  94.382  -77.620  52.518  1
134169  94.403  -77.602  52.514  1
134170  94.424  -77.584  52.512  1
134171  94.445  -77.567  52.509  1
134172  94.466  -77.548  52.504  1
134173  94.487  -77.531  52.499  1
134174  94.508  -77.513  52.493  1
134175  94.529  -77.495  52.481  1
134176  94.550  -77.477  52.466  1
134177  94.557  -77.477  52.449  1
134178  94.521  -77.518  52.431  1
134179  94.485  -77.560  52.416  1
134180  94.483  -77.652  52.403  1
134181  94.498  -77.772  52.390  1
134182  94.514  -77.892  52.374  1
134183  94.535  -77.985  52.356  1
134184  94.562  -78.044  52.337  1
134185  94.590  -78.103  52.316  1
134186  94.610  -78.024  52.296  1
134187  94.630  -77.918  52.275  1
134188  94.637  -77.846  52.250  1
134189  94.639  -77.788  52.220  1
134190  94.641  -77.730  52.189  1
134191  94.643  -77.673  52.155  1
134192  94.645  -77.616  52.117  1
134193  94.647  -77.558  52.081  1
134194  94.654  -77.523  52.047  1
134195  94.669  -77.514  52.013  1
134196  94.683  -77.505  51.977  1
134197  94.697  -77.496  51.939  1
134198  94.710  -77.487  51.898  1
134199  94.713  -77.486  51.859  1
134200  94.902  -77.614  51.825  1
134201  94.938  -77.627  51.794  1
134202  94.939  -77.583  51.766  1
134203  94.940  -77.540  51.731  1
134204  94.941  -77.497  51.694  1
134205  94.945  -77.470  51.656  1
134206  94.966  -77.500  51.615  1
134207  94.979  -77.525  51.573  1
134208  94.983  -77.536  51.534  1
134209  95.010  -77.555  51.498  1
134210  95.036  -77.575  51.458  1
134211  95.063  -77.594  51.418  1
134212  95.090  -77.613  51.378  1
134213  95.117  -77.632  51.337  1
134214  95.092  -77.614  51.295  1
134215  95.136  -77.652  51.251  1
134216  95.130  -77.643  51.206  1
134217  95.124  -77.635  51.158  1
134218  95.092  -77.639  51.111  1
134219  95.107  -77.624  51.064  1
134220  95.123  -77.624  51.016  1
134221  95.134  -77.627  50.969  1
134222  95.146  -77.630  50.924  1
134223  95.157  -77.628  50.881  1
134224  95.178  -77.621  50.838  1
134225  95.199  -77.607  50.797  1
134226  95.220  -77.592  50.757  1
134227  95.241  -77.578  50.719  1
134228  95.263  -77.564  50.682  1
134229  95.288  -77.553  50.646  1
134230  95.314  -77.542  50.610  1
134231  95.340  -77.531  50.573  1
134232  95.366  -77.520  50.537  1
134233  95.398  -77.520  50.501  1
134234  95.430  -77.520  50.465  1
134235  95.462  -77.520  50.428  1
134236  95.494  -77.521  50.391  1
134237  95.513  -77.514  50.354  1
134238  95.528  -77.504  50.317  1
134239  95.544  -77.495  50.281  1
134240  95.559  -77.487  50.244  1
134241  95.574  -77.478  50.209  1
134242  95.600  -77.476  50.173  1
134243  95.653  -77.495  50.136  1
134244  95.705  -77.514  50.099  1
134245  95.757  -77.532  50.063  1
134246  95.810  -77.550  50.027  1
134247  95.826  -77.566  49.993  1
134248  95.804  -77.573  49.959  1
134249  95.775  -77.579  49.925  1
134250  95.746  -77.585  49.893  1
134251  95.718  -77.590  49.862  1
134252  95.689  -77.596  49.831  1
134253  95.677  -77.611  49.801  1
134254  95.681  -77.614  49.770  1
134255  95.684  -77.617  49.740  1
134256  95.688  -77.620  49.710  1
134257  95.691  -77.622  49.681  1
134258  95.695  -77.625  49.652  1
134259  95.698  -77.627  49.622  1
134260  95.702  -77.630  49.590  1
134261  95.705  -77.633  49.559  1
134262  95.713  -77.634  49.529  1
134263  95.724  -77.634  49.498  1
134264  95.734  -77.635  49.466  1
134265  95.743  -77.636  49.434  1
134266  95.753  -77.636  49.402  1
134267  95.763  -77.636  49.369  1
134268  95.773  -77.636  49.337  1
134269  95.783  -77.637  49.307  1
134270  95.793  -77.638  49.276  1
134271  95.803  -77.638  49.245  1
134272  95.822  -77.645  49.212  1
134273  95.844  -77.654  49.179  1
134274  95.868  -77.663  49.144  1
134275  95.895  -77.672  49.108  1
134276  95.921  -77.681  49.071  1
134277  95.948  -77.691  49.033  1
134278  95.975  -77.700  48.995  1
134279  96.002  -77.709  48.958  1
134280  96.029  -77.719  48.922  1
134281  96.055  -77.728  48.885  1
134282  96.080  -77.738  48.849  1
134283  96.090  -77.748  48.813  1
134284  96.100  -77.758  48.777  1
134285  96.109  -77.768  48.741  1
134286  96.119  -77.777  48.707  1
134287  96.129  -77.788  48.674  1
134288  96.139  -77.798  48.640  1
134289  96.147  -77.814  48.607  1
134290  96.152  -77.837  48.574  1
134291  96.157  -77.859  48.542  1
134292  96.164  -77.880  48.510  1
134293  96.178  -77.891  48.480  1
134294  96.192  -77.902  48.450  1
134295  96.201  -77.908  48.419  1
134296  96.200  -77.900  48.387  1
134297  96.199  -77.893  48.357  1
134298  96.198  -77.885  48.327  1
134299  96.197  -77.877  48.296  1
134300  96.196  -77.870  48.269  1
134301  96.195  -77.862  48.243  1
134302  96.195  -77.855  48.217  1
134303  96.194  -77.847  48.192  1
134304  96.193  -77.840  48.168  1
134305  96.193  -77.833  48.145  1
134306  96.208  -77.829  48.123  1
134307  96.230  -77.825  48.103  1
134308  96.250  -77.821  48.081  1
134309  96.271  -77.817  48.059  1
134310  96.293  -77.813  48.037  1
134311  96.310  -77.812  48.014  1
134312  96.323  -77.821  47.990  1
134313  96.342  -77.833  47.966  1
134314  96.363  -77.846  47.943  1
134315  96.384  -77.858  47.920  1
134316  96.405  -77.871  47.897  1
134317  96.427  -77.883  47.874  1
134318  96.448  -77.896  47.849  1
134319  96.469  -77.908  47.825  1
134320  96.491  -77.920  47.801  1
134321  96.521  -77.928  47.777  1
134322  96.547  -77.933  47.754  1
134323  96.554  -77.931  47.730  1
134324  96.562  -77.930  47.705  1
134325  96.570  -77.928  47.680  1
134326  96.578  -77.926  47.655  1
134327  96.585  -77.924  47.631  1
134328  96.593  -77.923  47.607  1
134329  96.604  -77.924  47.582  1
134330  96.615  -77.925  47.558  1
134331  96.625  -77.927  47.533  1
134332  96.636  -77.928  47.509  1
134333  96.647  -77.930  47.485  1
134334  96.659  -77.939  47.460  1
134335  96.674  -77.956  47.437  1
134336  96.688  -77.973  47.413  1
134337  96.710  -77.989  47.388  1
134338  96.737  -78.004  47.364  1
134339  96.764  -78.019  47.339  1
134340  96.815  -78.037  47.314  1
134341  96.868  -78.056  47.288  1
134342  96.867  -78.067  47.262  1
134343  96.865  -78.078  47.236  1
134344  96.863  -78.089  47.210  1
134345  96.861  -78.100  47.185  1
134346  96.862  -78.114  47.160  1
134347  96.879  -78.126  47.136  1
134348  96.903  -78.133  47.112  1
134349  96.928  -78.141  47.087  1
134350  96.943  -78.147  47.065  1
134351  96.960  -78.156  47.042  1
134352  96.977  -78.166  47.021  1
134353  96.994  -78.178  47.000  1
134354  97.010  -78.191  46.982  1
134355  97.027  -78.203  46.965  1
134356  97.043  -78.216  46.948  1
134357  97.060  -78.228  46.933  1
134358  97.076  -78.241  46.918  1
134359  97.093  -78.253  46.904  1
134360  97.109  -78.266  46.891  1
134361  97.151  -78.275  46.876  1
134362  97.207  -78.265  46.860  1
134363  97.246  -78.266  46.842  1
134364  97.285  -78.267  46.824  1
134365  97.324  -78.268  46.806  1
134366  97.363  -78.269  46.791  1
134367  97.402  -78.270  46.776  1
134368  97.441  -78.272  46.760  1
134369  97.480  -78.272  46.743  1
134370  97.519  -78.274  46.727  1
134371  97.558  -78.275  46.714  1
134372  97.596  -78.276  46.698  1
134373  97.626  -78.275  46.682  1
134374  97.656  -78.273  46.665  1
134375  97.685  -78.272  46.648  1
134376  97.715  -78.270  46.629  1
134377  97.739  -78.279  46.611  1
134378  97.758  -78.294  46.592  1
134379  97.773  -78.302  46.573  1
134380  97.782  -78.303  46.554  1
134381  97.806  -78.297  46.535  1
134382  97.836  -78.290  46.516  1
134383  97.867  -78.282  46.498  1
134384  97.905  -78.275  46.480  1
134385  97.949  -78.266  46.464  1
134386  97.967  -78.262  46.447  1
134387  97.984  -78.258  46.429  1
134388  97.998  -78.260  46.411  1
134389  98.008  -78.269  46.392  1
134390  98.024  -78.278  46.374  1
134391  98.051  -78.282  46.355  1
134392  98.077  -78.288  46.336  1
134393  98.104  -78.279  46.318  1
134394  98.132  -78.269  46.298  1
134395  98.131  -78.279  46.279  1
134396  98.146  -78.291  46.260  1
134397  98.165  -78.305  46.242  1
134398  98.193  -78.300  46.224  1
134399  98.224  -78.288  46.205  1
134400  98.251  -78.295  46.187  1
134401  98.270  -78.347  46.166  1
134402  98.287  -78.391  46.146  1
134403  98.295  -78.381  46.126  1
134404  98.303  -78.371  46.107  1
134405  98.311  -78.361  46.087  1
134406  98.319  -78.351  46.066  1
134407  98.327  -78.341  46.046  1
134408  98.336  -78.332  46.025  1
134409  98.344  -78.322  46.003  1
134410  98.351  -78.310  45.982  1
134411  98.394  -78.304  45.961  1
134412  98.384  -78.354  45.940  1
134413  98.374  -78.404  45.918  1
134414  98.365  -78.454  45.897  1
134415  98.376  -78.465  45.876  1
134416  98.397  -78.453  45.855  1
134417  98.418  -78.442  45.834  1
134418  98.439  -78.429  45.813  1
134419  98.492  -78.408  45.791  1
134420  98.507  -78.406  45.768  1
134421  98.539  -78.412  45.745  1
134422  98.577  -78.415  45.721  1
134423  98.614  -78.401  45.696  1
134424  98.650  -78.379  45.673  1
134425  98.680  -78.353  45.652  1
134426  98.704  -78.322  45.630  1
134427  98.727  -78.293  45.609  1
134428  98.730  -78.282  45.590  1
134429  98.714  -78.298  45.572  1
134430  98.716  -78.298  45.554  1
134431  98.769  -78.274  45.537  1
134432  98.790  -78.285  45.519  1
134433  98.809  -78.297  45.501  1
134434  98.828  -78.311  45.484  1
134435  98.847  -78.324  45.468  1
134436  98.866  -78.337  45.451  1
134437  98.896  -78.333  45.434  1
134438  98.931  -78.326  45.419  1
134439  98.944  -78.376  45.405  1
134440  98.962  -78.413  45.390  1
134441  98.985  -78.438  45.375  1
134442  99.007  -78.464  45.361  1
134443  99.030  -78.490  45.346  1
134444  99.087  -78.487  45.332  1
134445  99.182  -78.451  45.319  1
134446  99.242  -78.431  45.307  1
134447  99.278  -78.422  45.294  1
134448  99.246  -78.448  45.283  1
134449  99.214  -78.475  45.272  1
134450  99.210  -78.489  45.261  1
134451  99.229  -78.495  45.247  1
134452  99.249  -78.499  45.233  1
134453  99.255  -78.517  45.220  1
134454  99.258  -78.535  45.207  1
134455  99.261  -78.555  45.194  1
134456  99.264  -78.575  45.180  1
134457  99.271  -78.592  45.166  1
134458  99.287  -78.600  45.152  1
134459  99.303  -78.609  45.139  1
134460  99.320  -78.617  45.126  1
134461  99.365  -78.617  45.113  1
134462  99.428  -78.609  45.099  1
134463  99.491  -78.601  45.085  1
134464  99.540  -78.597  45.072  1
134465  99.570  -78.596  45.057  1
134466  99.599  -78.633  45.044  1
134467  99.621  -78.688  45.032  1
134468  99.745  -78.757  45.020  1
134469  99.769  -78.781  45.007  1
134470  99.826  -78.828  44.997  1
134471  99.884  -78.874  44.987  1
134472  99.901  -78.886  44.975  1
134473  99.899  -78.893  44.964  1
134474  99.901  -78.896  44.952  1
134475  99.903  -78.899  44.938  1
134476  99.905  -78.933  44.926  1
134477  99.914  -78.959  44.914  1
134478  99.934  -78.962  44.903  1
134479  99.955  -78.965  44.891  1
134480  99.974  -78.968  44.881  1
134481  99.986  -78.957  44.871  1
134482  99.991  -78.938  44.861  1
134483  99.996  -78.920  44.853  1
134484  100.001  -78.901  44.845  1
134485  100.020  -78.904  44.837  1
134486  100.046  -78.916  44.828  1
134487  100.072  -78.928  44.822  1
134488  100.098  -78.940  44.815  1
134489  100.123  -78.952  44.808  1
134490  100.148  -78.965  44.801  1
134491  100.174  -78.977  44.794  1
134492  100.200  -78.989  44.787  1
134493  100.229  -79.007  44.780  1
134494  100.259  -79.025  44.772  1
134495  100.288  -79.044  44.764  1
134496  100.316  -79.050  44.757  1
134497  100.353  -79.061  44.748  1
134498  100.392  -79.078  44.739  1
134499  100.427  -79.096  44.730  1
134500  100.459  -79.115  44.720  1
134501  100.492  -79.134  44.709  1
134502  100.524  -79.153  44.698  1
134503  100.557  -79.172  44.686  1
134504  100.589  -79.191  44.673  1
134505  100.622  -79.211  44.661  1
134772  93.097  -78.194  54.118  1
134773  93.112  -78.181  54.110  1
134774  93.126  -78.169  54.102  1
134775  93.145  -78.157  54.094  1
134776  93.169  -78.146  54.087  1
134777  93.193  -78.134  54.079  1
134778  93.216  -78.122  54.072  1
134779  93.240  -78.110  54.063  1
134780  93.264  -78.098  54.054  1
134781  93.287  -78.086  54.044  1
134782  93.310  -78.075  54.035  1
134783  93.334  -78.062  54.025  1
134784  93.358  -78.050  54.016  1
134785  93.381  -78.039  54.006  1
134786  93.402  -78.029  53.994  1
134787  93.411  -78.027  53.982  1
134788  93.421  -78.025  53.969  1
134789  93.425  -78.012  53.957  1
134790  93.436  -77.996  53.945  1
134791  93.446  -77.981  53.932  1
134792  93.456  -77.965  53.918  1
134793  93.467  -77.950  53.903  1
134794  93.477  -77.934  53.887  1
134795  93.491  -77.922  53.871  1
134796  93.502  -77.914  53.856  1
134797  93.514  -77.906  53.840  1
134798  93.525  -77.897  53.825  1
134799  93.537  -77.889  53.809  1
134800  93.549  -77.881  53.791  1
134801  93.561  -77.873  53.774  1
134802  93.572  -77.865  53.756  1
134803  93.584  -77.856  53.739  1
134804  93.595  -77.848  53.721  1
134805  93.607  -77.840  53.703  1
134806  93.619  -77.831  53.686  1
134807  93.630  -77.823  53.668  1
134808  93.642  -77.815  53.649  1
134809  93.657  -77.808  53.629  1
134810  93.671  -77.802  53.611  1
134811  93.684  -77.799  53.591  1
134812  93.697  -77.794  53.572  1
134813  93.709  -77.790  53.554  1
134814  93.722  -77.786  53.534  1
134815  93.735  -77.781  53.514  1
134822  93.825  -77.752  53.379  1
134823  93.838  -77.747  53.360  1
134824  93.848  -77.742  53.343  1
134825  93.859  -77.737  53.325  1
134826  93.870  -77.733  53.308  1
134827  93.880  -77.727  53.291  1
134828  93.892  -77.723  53.273  1
134829  93.902  -77.718  53.256  1
134830  93.913  -77.713  53.239  1
134831  93.924  -77.708  53.222  1
134832  93.934  -77.703  53.207  1
134833  93.946  -77.699  53.192  1
134834  93.960  -77.695  53.177  1
134835  93.974  -77.690  53.163  1
134836  93.982  -77.690  53.149  1
134837  93.986  -77.691  53.133  1
134838  93.991  -77.692  53.115  1
134839  93.996  -77.694  53.096  1
134840  94.001  -77.696  53.078  1
134841  94.006  -77.696  53.059  1
134842  94.011  -77.698  53.041  1
134843  94.014  -77.698  53.022  1
134844  94.015  -77.694  53.003  1
134845  94.022  -77.689  52.983  1
134846  94.028  -77.683  52.962  1
134847  94.033  -77.678  52.942  1
134848  94.039  -77.673  52.922  1
134849  94.045  -77.667  52.901  1
134850  94.056  -77.670  52.881  1
134851  94.070  -77.663  52.860  1
134852  94.072  -77.661  52.838  1
134853  94.075  -77.658  52.815  1
134854  94.078  -77.645  52.790  1
134855  94.088  -77.626  52.765  1
134856  94.119  -77.614  52.741  1
134857  94.114  -77.632  52.718  1
134858  94.121  -77.639  52.697  1
134859  94.135  -77.639  52.677  1
134860  94.148  -77.641  52.658  1
134861  94.177  -77.624  52.640  1
134862  94.216  -77.595  52.623  1
134863  94.255  -77.567  52.607  1
134864  94.289  -77.545  52.592  1
134865  94.321  -77.526  52.579  1
134866  94.345  -77.517  52.568  1
134867  94.346  -77.527  52.559  1
134868  94.328  -77.579  52.553  1
134869  94.347  -77.606  52.549  1
134870  94.368  -77.588  52.546  1
134871  94.389  -77.570  52.541  1
134872  94.410  -77.552  52.536  1
134873  94.431  -77.534  52.532  1
134874  94.452  -77.517  52.527  1
134875  94.473  -77.498  52.521  1
134876  94.497  -77.483  52.511  1
134877  94.540  -77.469  52.499  1
134878  94.546  -77.458  52.483  1
134879  94.539  -77.466  52.469  1
134880  94.516  -77.504  52.456  1
134881  94.480  -77.545  52.444  1
134882  94.478  -77.637  52.431  1
134883  94.493  -77.758  52.415  1
134884  94.509  -77.877  52.398  1
134885  94.525  -77.998  52.379  1
134886  94.541  -78.118  52.357  1
134887  94.555  -78.081  52.336  1
134888  94.574  -77.975  52.316  1
134889  94.594  -77.869  52.291  1
134890  94.613  -77.764  52.259  1
134891  94.623  -77.685  52.225  1
134892  94.625  -77.627  52.188  1
134893  94.626  -77.570  52.149  1
134894  94.628  -77.513  52.112  1
134895  94.642  -77.500  52.076  1
134896  94.655  -77.491  52.041  1
134897  94.676  -77.487  52.005  1
134898  94.716  -77.500  51.968  1
134899  94.757  -77.514  51.929  1
134900  94.801  -77.530  51.892  1
134901  94.904  -77.600  51.858  1
134902  94.965  -77.635  51.828  1
134903  94.951  -77.611  51.799  1
134904  94.937  -77.586  51.765  1
134905  94.938  -77.542  51.728  1
134906  94.938  -77.499  51.691  1
134907  94.948  -77.487  51.651  1
134908  94.965  -77.515  51.609  1
134909  94.974  -77.529  51.570  1
134910  95.001  -77.548  51.535  1
134911  95.028  -77.567  51.495  1
134912  95.054  -77.586  51.453  1
134913  95.081  -77.605  51.411  1
134914  95.105  -77.623  51.370  1
134915  95.140  -77.616  51.328  1
134916  95.142  -77.634  51.285  1
134917  95.139  -77.628  51.240  1
134918  95.133  -77.619  51.195  1
134919  95.127  -77.611  51.146  1
134920  95.120  -77.605  51.096  1
134921  95.132  -77.608  51.047  1
134922  95.144  -77.611  50.999  1
134923  95.155  -77.614  50.953  1
134924  95.179  -77.617  50.909  1
134925  95.188  -77.602  50.867  1
134926  95.201  -77.585  50.824  1
134927  95.222  -77.570  50.783  1
134928  95.243  -77.556  50.745  1
134929  95.264  -77.542  50.709  1
134930  95.289  -77.530  50.675  1
134931  95.315  -77.519  50.640  1
134932  95.341  -77.509  50.603  1
134933  95.374  -77.509  50.567  1
134934  95.406  -77.509  50.531  1
134935  95.438  -77.510  50.494  1
134936  95.470  -77.510  50.456  1
134937  95.502  -77.510  50.419  1
134938  95.521  -77.503  50.381  1
134939  95.537  -77.495  50.343  1
134940  95.552  -77.486  50.307  1
134941  95.568  -77.476  50.270  1
134942  95.584  -77.467  50.234  1
134943  95.624  -77.477  50.197  1
134944  95.677  -77.496  50.159  1
134945  95.729  -77.514  50.122  1
134946  95.781  -77.533  50.085  1
134947  95.808  -77.549  50.047  1
134948  95.807  -77.564  50.011  1
134949  95.802  -77.577  49.976  1
134950  95.773  -77.582  49.940  1
134951  95.745  -77.588  49.907  1
134952  95.716  -77.593  49.874  1
134953  95.687  -77.599  49.842  1
134954  95.678  -77.613  49.811  1
134955  95.681  -77.615  49.779  1
134956  95.685  -77.618  49.748  1
134957  95.688  -77.621  49.718  1
134958  95.692  -77.624  49.689  1
134959  95.695  -77.627  49.660  1
134960  95.698  -77.629  49.631  1
134961  95.702  -77.632  49.600  1
134962  95.712  -77.633  49.569  1
134963  95.722  -77.633  49.538  1
134964  95.732  -77.633  49.507  1
134965  95.742  -77.633  49.475  1
134966  95.752  -77.634  49.442  1
134967  95.761  -77.635  49.410  1
134968  95.771  -77.635  49.377  1
134969  95.781  -77.636  49.346  1
134970  95.792  -77.636  49.316  1
134971  95.801  -77.636  49.286  1
134972  95.811  -77.637  49.255  1
134973  95.826  -77.639  49.224  1
134974  95.853  -77.649  49.192  1
134975  95.880  -77.658  49.158  1
134976  95.906  -77.667  49.122  1
134977  95.933  -77.677  49.085  1
134978  95.960  -77.686  49.047  1
134979  95.987  -77.696  49.009  1
134980  96.014  -77.705  48.972  1
134981  96.041  -77.714  48.935  1
134982  96.061  -77.724  48.899  1
134983  96.071  -77.733  48.863  1
134984  96.081  -77.744  48.827  1
134985  96.091  -77.754  48.791  1
134986  96.101  -77.764  48.755  1
134987  96.111  -77.774  48.721  1
134988  96.120  -77.783  48.687  1
134989  96.130  -77.793  48.653  1
134990  96.138  -77.811  48.620  1
134991  96.143  -77.834  48.587  1
134992  96.148  -77.856  48.554  1
134993  96.161  -77.868  48.521  1
134994  96.176  -77.881  48.491  1
134995  96.190  -77.892  48.460  1
134996  96.203  -77.902  48.429  1
134997  96.202  -77.894  48.398  1
134998  96.201  -77.887  48.367  1
134999  96.200  -77.879  48.337  1
135000  96.199  -77.871  48.306  1
135001  96.198  -77.864  48.280  1
135002  96.197  -77.856  48.253  1
135003  96.196  -77.849  48.227  1
135004  96.196  -77.841  48.202  1
135005  96.195  -77.834  48.177  1
135006  96.203  -77.831  48.154  1
135007  96.221  -77.827  48.131  1
135008  96.242  -77.823  48.111  1
135009  96.263  -77.819  48.089  1
135010  96.285  -77.815  48.067  1
135011  96.305  -77.811  48.045  1
135012  96.314  -77.815  48.022  1
135013  96.326  -77.823  47.999  1
135014  96.344  -77.835  47.975  1
135015  96.362  -77.847  47.952  1
135016  96.382  -77.860  47.929  1
135017  96.403  -77.872  47.906  1
135018  96.425  -77.885  47.883  1
135019  96.446  -77.897  47.859  1
135020  96.467  -77.910  47.835  1
135021  96.493  -77.919  47.810  1
135022  96.523  -77.927  47.786  1
135023  96.548  -77.932  47.763  1
135024  96.556  -77.931  47.738  1
135025  96.564  -77.929  47.713  1
135026  96.571  -77.927  47.688  1
135027  96.579  -77.925  47.663  1
135028  96.587  -77.924  47.638  1
135029  96.594  -77.921  47.614  1
135030  96.602  -77.920  47.589  1
135031  96.612  -77.921  47.565  1
135032  96.622  -77.922  47.540  1
135033  96.633  -77.924  47.516  1
135034  96.644  -77.925  47.491  1
135035  96.655  -77.929  47.467  1
135036  96.670  -77.946  47.443  1
135037  96.684  -77.963  47.419  1
135038  96.708  -77.979  47.394  1
135039  96.735  -77.993  47.369  1
135040  96.777  -78.010  47.345  1
135041  96.829  -78.029  47.320  1
135042  96.875  -78.047  47.294  1
135043  96.873  -78.058  47.269  1
135044  96.871  -78.069  47.243  1
135045  96.869  -78.080  47.218  1
135046  96.867  -78.091  47.193  1
135047  96.865  -78.103  47.169  1
135048  96.879  -78.112  47.146  1
135049  96.903  -78.119  47.122  1
135050  96.927  -78.125  47.098  1
135051  96.947  -78.134  47.076  1
135052  96.964  -78.147  47.054  1
135053  96.980  -78.159  47.031  1
135054  96.997  -78.171  47.010  1
135055  97.014  -78.183  46.992  1
135056  97.031  -78.195  46.975  1
135057  97.047  -78.207  46.958  1
135058  97.064  -78.219  46.943  1
135059  97.081  -78.232  46.929  1
135060  97.097  -78.244  46.915  1
135061  97.114  -78.256  46.903  1
135062  97.134  -78.260  46.889  1
135063  97.194  -78.233  46.875  1
135064  97.237  -78.229  46.859  1
135065  97.277  -78.231  46.841  1
135066  97.315  -78.232  46.824  1
135067  97.355  -78.233  46.810  1
135068  97.393  -78.234  46.796  1
135069  97.433  -78.235  46.779  1
135070  97.472  -78.237  46.762  1
135071  97.511  -78.238  46.747  1
135072  97.542  -78.237  46.735  1
135073  97.572  -78.235  46.720  1
135074  97.601  -78.234  46.705  1
135075  97.631  -78.232  46.689  1
135076  97.662  -78.234  46.672  1
135077  97.695  -78.240  46.654  1
135078  97.732  -78.244  46.636  1
135079  97.750  -78.252  46.619  1
135080  97.758  -78.263  46.599  1
135081  97.775  -78.275  46.579  1
135082  97.799  -78.271  46.559  1
135083  97.842  -78.263  46.539  1
135084  97.885  -78.255  46.521  1
135085  97.923  -78.248  46.503  1
135086  97.939  -78.244  46.486  1
135087  97.956  -78.239  46.469  1
135088  97.973  -78.235  46.450  1
135089  97.988  -78.235  46.432  1
135090  97.998  -78.244  46.413  1
135091  98.017  -78.251  46.394  1
135092  98.043  -78.257  46.375  1
135093  98.069  -78.262  46.356  1
135094  98.095  -78.267  46.337  1
135095  98.123  -78.260  46.317  1
135096  98.131  -78.264  46.296  1
135097  98.149  -78.278  46.276  1
135098  98.168  -78.291  46.258  1
135099  98.196  -78.287  46.241  1
135100  98.226  -78.275  46.222  1
135101  98.245  -78.324  46.203  1
135102  98.265  -78.376  46.183  1
135103  98.279  -78.404  46.163  1
135104  98.287  -78.394  46.144  1
135105  98.295  -78.384  46.123  1
135106  98.303  -78.374  46.104  1
135107  98.311  -78.364  46.084  1
135108  98.319  -78.355  46.063  1
135109  98.321  -78.342  46.041  1
135110  98.326  -78.330  46.019  1
135111  98.350  -78.321  45.998  1
135112  98.413  -78.298  45.976  1
135113  98.456  -78.306  45.955  1
135114  98.439  -78.357  45.934  1
135115  98.388  -78.416  45.913  1
135116  98.390  -78.427  45.892  1
135117  98.415  -78.417  45.870  1
135118  98.441  -78.407  45.848  1
135119  98.466  -78.397  45.827  1
135120  98.492  -78.387  45.804  1
135121  98.516  -78.380  45.780  1
135122  98.558  -78.383  45.756  1
135123  98.596  -78.386  45.733  1
135124  98.632  -78.373  45.709  1
135125  98.659  -78.345  45.686  1
135126  98.683  -78.316  45.664  1
135127  98.710  -78.294  45.642  1
135128  98.737  -78.272  45.622  1
135129  98.730  -78.259  45.603  1
135130  98.693  -78.253  45.584  1
135131  98.751  -78.243  45.567  1
135132  98.776  -78.250  45.550  1
135133  98.794  -78.263  45.533  1
135134  98.813  -78.276  45.515  1
135135  98.832  -78.289  45.498  1
135136  98.851  -78.302  45.482  1
135137  98.870  -78.315  45.466  1
135138  98.889  -78.328  45.449  1
135139  98.914  -78.347  45.434  1
135140  98.936  -78.373  45.420  1
135141  98.959  -78.399  45.405  1
135142  98.982  -78.425  45.390  1
135143  99.004  -78.451  45.375  1
135144  99.026  -78.476  45.361  1
135145  99.061  -78.492  45.348  1
135146  99.156  -78.457  45.335  1
135147  99.251  -78.422  45.322  1
135148  99.312  -78.401  45.309  1
135149  99.280  -78.428  45.297  1
135150  99.248  -78.454  45.286  1
135151  99.221  -78.479  45.276  1
135152  99.240  -78.484  45.264  1
135153  99.252  -78.496  45.251  1
135154  99.255  -78.515  45.238  1
135155  99.258  -78.535  45.224  1
135156  99.271  -78.546  45.211  1
135157  99.287  -78.554  45.197  1
135158  99.303  -78.564  45.182  1
135159  99.320  -78.572  45.168  1
135160  99.336  -78.580  45.154  1
135161  99.352  -78.589  45.140  1
135162  99.407  -78.586  45.126  1
135163  99.471  -78.579  45.112  1
135164  99.523  -78.573  45.098  1
135165  99.553  -78.573  45.085  1
135166  99.559  -78.592  45.071  1
135167  99.562  -78.614  45.058  1
135168  99.646  -78.677  45.045  1
135169  99.738  -78.728  45.033  1
135170  99.755  -78.747  45.020  1
135171  99.812  -78.794  45.008  1
135172  99.869  -78.839  44.998  1
135173  99.916  -78.873  44.987  1
135174  99.933  -78.886  44.976  1
135175  99.935  -78.888  44.964  1
135176  99.937  -78.890  44.951  1
135177  99.939  -78.912  44.940  1
135178  99.945  -78.945  44.928  1
135179  99.956  -78.968  44.915  1
135180  99.976  -78.971  44.903  1
135181  99.988  -78.962  44.893  1
135182  99.993  -78.943  44.883  1
135183  99.998  -78.924  44.873  1
135184  100.003  -78.905  44.864  1
135185  100.008  -78.887  44.855  1
135186  100.029  -78.892  44.847  1
135187  100.055  -78.904  44.839  1
135188  100.080  -78.916  44.832  1
135189  100.106  -78.928  44.825  1
135190  100.132  -78.940  44.817  1
135191  100.157  -78.952  44.810  1
135192  100.183  -78.965  44.802  1
135193  100.208  -78.977  44.795  1
135194  100.234  -78.989  44.788  1
135195  100.261  -79.004  44.779  1
135196  100.290  -79.022  44.771  1
135197  100.321  -79.031  44.762  1
135198  100.359  -79.048  44.753  1
135199  100.392  -79.067  44.743  1
135200  100.424  -79.086  44.733  1
135201  100.457  -79.105  44.723  1
135202  100.489  -79.124  44.712  1
135203  100.522  -79.143  44.700  1
135204  100.554  -79.162  44.687  1
135205  100.586  -79.181  44.675  1
135206  100.619  -79.200  44.663  1
135207  100.651  -79.219  44.649  1
135472  93.082  -78.196  54.134  1
135473  93.096  -78.184  54.127  1
135474  93.111  -78.172  54.120  1
135475  93.125  -78.159  54.111  1
135476  93.145  -78.147  54.104  1
135477  93.168  -78.135  54.097  1
135478  93.192  -78.123  54.089  1
135479  93.215  -78.112  54.081  1
135480  93.239  -78.100  54.072  1
135481  93.263  -78.087  54.063  1
135482  93.286  -78.076  54.055  1
135483  93.310  -78.064  54.045  1
135484  93.334  -78.052  54.036  1
135485  93.357  -78.040  54.027  1
135486  93.381  -78.028  54.017  1
135487  93.402  -78.018  54.006  1
135488  93.411  -78.016  53.994  1
135489  93.417  -78.012  53.981  1
135490  93.427  -77.996  53.969  1
135491  93.437  -77.981  53.957  1
135492  93.447  -77.965  53.944  1
135493  93.458  -77.949  53.930  1
135494  93.468  -77.934  53.914  1
135495  93.479  -77.918  53.898  1
135496  93.492  -77.909  53.882  1
135497  93.504  -77.901  53.866  1
135498  93.515  -77.893  53.851  1
135499  93.527  -77.884  53.835  1
135500  93.539  -77.876  53.820  1
135501  93.550  -77.868  53.802  1
135502  93.562  -77.860  53.784  1
135503  93.573  -77.852  53.766  1
135504  93.585  -77.843  53.748  1
135505  93.596  -77.835  53.731  1
135506  93.608  -77.827  53.714  1
135507  93.620  -77.818  53.696  1
135508  93.631  -77.810  53.678  1
135509  93.644  -77.802  53.659  1
135510  93.658  -77.796  53.640  1
135511  93.672  -77.791  53.620  1
135512  93.684  -77.787  53.601  1
135513  93.697  -77.783  53.582  1
135514  93.710  -77.779  53.564  1
135515  93.723  -77.774  53.545  1
135516  93.735  -77.770  53.525  1
135523  93.820  -77.738  53.390  1
135524  93.830  -77.733  53.372  1
135525  93.841  -77.729  53.355  1
135526  93.852  -77.724  53.337  1
135527  93.862  -77.719  53.321  1
135528  93.873  -77.714  53.304  1
135529  93.884  -77.709  53.285  1
135530  93.895  -77.705  53.268  1
135531  93.905  -77.699  53.252  1
135532  93.916  -77.695  53.235  1
135533  93.927  -77.689  53.219  1
135534  93.940  -77.686  53.204  1
135535  93.954  -77.682  53.189  1
135536  93.968  -77.677  53.174  1
135537  93.977  -77.676  53.159  1
135538  93.982  -77.677  53.143  1
135539  93.987  -77.679  53.126  1
135540  93.992  -77.680  53.106  1
135541  93.997  -77.682  53.087  1
135542  94.002  -77.683  53.068  1
135543  94.007  -77.684  53.049  1
135544  94.011  -77.686  53.030  1
135545  94.027  -77.676  53.012  1
135546  94.037  -77.669  52.994  1
135547  94.043  -77.664  52.975  1
135548  94.049  -77.659  52.957  1
135549  94.055  -77.654  52.937  1
135550  94.060  -77.649  52.917  1
135551  94.062  -77.644  52.897  1
135552  94.052  -77.646  52.876  1
135553  94.043  -77.651  52.855  1
135554  94.045  -77.648  52.832  1
135555  94.048  -77.643  52.810  1
135556  94.068  -77.622  52.787  1
135557  94.119  -77.597  52.763  1
135558  94.126  -77.604  52.740  1
135559  94.117  -77.623  52.719  1
135560  94.144  -77.608  52.699  1
135561  94.176  -77.589  52.680  1
135562  94.208  -77.570  52.663  1
135563  94.240  -77.551  52.646  1
135564  94.270  -77.534  52.630  1
135565  94.284  -77.538  52.617  1
135566  94.297  -77.542  52.604  1
135567  94.302  -77.550  52.594  1
135568  94.292  -77.555  52.586  1
135569  94.293  -77.551  52.583  1
135570  94.312  -77.592  52.581  1
135571  94.333  -77.573  52.578  1
135572  94.354  -77.556  52.571  1
135573  94.375  -77.538  52.565  1
135574  94.396  -77.520  52.560  1
135575  94.417  -77.502  52.556  1
135576  94.451  -77.490  52.550  1
135577  94.494  -77.476  52.542  1
135578  94.537  -77.463  52.532  1
135579  94.530  -77.453  52.519  1
135580  94.523  -77.443  52.508  1
135581  94.515  -77.455  52.497  1
135582  94.507  -77.490  52.486  1
135583  94.475  -77.530  52.473  1
135584  94.473  -77.623  52.457  1
135585  94.489  -77.743  52.440  1
135586  94.504  -77.863  52.421  1
135587  94.518  -77.890  52.398  1
135588  94.531  -77.848  52.376  1
135589  94.543  -77.806  52.353  1
135590  94.555  -77.765  52.326  1
135591  94.568  -77.723  52.293  1
135592  94.580  -77.680  52.256  1
135593  94.596  -77.609  52.219  1
135594  94.608  -77.524  52.181  1
135595  94.615  -77.486  52.145  1
135596  94.645  -77.491  52.110  1
135597  94.686  -77.504  52.076  1
135598  94.727  -77.517  52.039  1
135599  94.768  -77.531  52.001  1
135600  94.809  -77.545  51.961  1
135601  94.849  -77.558  51.922  1
135602  94.907  -77.586  51.887  1
135603  94.992  -77.642  51.855  1
135604  94.978  -77.617  51.826  1
135605  94.964  -77.592  51.793  1
135606  94.950  -77.568  51.757  1
135607  94.936  -77.544  51.720  1
135608  94.936  -77.501  51.678  1
135609  94.950  -77.504  51.638  1
135610  94.965  -77.520  51.600  1
135611  94.992  -77.539  51.566  1
135612  95.019  -77.558  51.527  1
135613  95.035  -77.573  51.488  1
135614  95.049  -77.587  51.449  1
135615  95.090  -77.575  51.409  1
135616  95.125  -77.561  51.367  1
135617  95.112  -77.586  51.324  1
135618  95.127  -77.597  51.282  1
135619  95.141  -77.604  51.235  1
135620  95.135  -77.595  51.183  1
135621  95.130  -77.589  51.130  1
135622  95.142  -77.592  51.078  1
135623  95.158  -77.595  51.030  1
135624  95.182  -77.599  50.983  1
135625  95.206  -77.604  50.938  1
135626  95.215  -77.589  50.893  1
135627  95.221  -77.569  50.851  1
135628  95.227  -77.549  50.810  1
135629  95.245  -77.533  50.771  1
135630  95.265  -77.519  50.733  1
135631  95.290  -77.508  50.699  1
135632  95.317  -77.498  50.666  1
135633  95.349  -77.498  50.633  1
135634  95.381  -77.498  50.597  1
135635  95.413  -77.498  50.561  1
135636  95.446  -77.498  50.525  1
135637  95.477  -77.499  50.488  1
135638  95.510  -77.499  50.449  1
135639  95.530  -77.493  50.411  1
135640  95.545  -77.484  50.372  1
135641  95.561  -77.475  50.335  1
135642  95.577  -77.466  50.299  1
135643  95.596  -77.461  50.262  1
135644  95.649  -77.479  50.223  1
135645  95.701  -77.497  50.184  1
135646  95.753  -77.515  50.145  1
135647  95.790  -77.533  50.107  1
135648  95.789  -77.547  50.068  1
135649  95.788  -77.561  50.031  1
135650  95.788  -77.576  49.993  1
135651  95.771  -77.586  49.957  1
135652  95.743  -77.591  49.921  1
135653  95.714  -77.597  49.887  1
135654  95.685  -77.602  49.854  1
135655  95.678  -77.614  49.822  1
135656  95.681  -77.617  49.790  1
135657  95.685  -77.620  49.758  1
135658  95.688  -77.623  49.728  1
135659  95.692  -77.625  49.698  1
135660  95.695  -77.628  49.669  1
135661  95.700  -77.630  49.640  1
135662  95.710  -77.630  49.609  1
135663  95.720  -77.631  49.578  1
135664  95.730  -77.632  49.548  1
135665  95.740  -77.632  49.516  1
135666  95.750  -77.633  49.482  1
135667  95.760  -77.633  49.450  1
135668  95.770  -77.633  49.419  1
135669  95.779  -77.634  49.387  1
135670  95.790  -77.634  49.357  1
135671  95.802  -77.633  49.327  1
135672  95.816  -77.632  49.297  1
135673  95.830  -77.630  49.266  1
135674  95.845  -77.633  49.235  1
135675  95.865  -77.644  49.204  1
135676  95.891  -77.653  49.171  1
135677  95.918  -77.662  49.136  1
135678  95.945  -77.672  49.099  1
135679  95.972  -77.681  49.061  1
135680  95.999  -77.691  49.023  1
135681  96.026  -77.700  48.986  1
135682  96.043  -77.710  48.949  1
135683  96.053  -77.720  48.913  1
135684  96.062  -77.730  48.878  1
135685  96.073  -77.740  48.841  1
135686  96.082  -77.749  48.805  1
135687  96.092  -77.760  48.770  1
135688  96.102  -77.770  48.735  1
135689  96.112  -77.780  48.701  1
135690  96.122  -77.790  48.667  1
135691  96.129  -77.808  48.633  1
135692  96.134  -77.830  48.599  1
135693  96.145  -77.846  48.566  1
135694  96.159  -77.858  48.532  1
135695  96.173  -77.869  48.501  1
135696  96.188  -77.881  48.471  1
135697  96.202  -77.892  48.440  1
135698  96.204  -77.888  48.409  1
135699  96.203  -77.881  48.378  1
135700  96.202  -77.873  48.347  1
135701  96.201  -77.865  48.317  1
135702  96.200  -77.858  48.291  1
135703  96.199  -77.850  48.264  1
135704  96.198  -77.843  48.237  1
135705  96.198  -77.836  48.212  1
135706  96.206  -77.832  48.187  1
135707  96.214  -77.829  48.163  1
135708  96.234  -77.825  48.139  1
135709  96.255  -77.821  48.117  1
135710  96.276  -77.817  48.096  1
135711  96.297  -77.813  48.074  1
135712  96.312  -77.812  48.052  1
135713  96.319  -77.818  48.030  1
135714  96.329  -77.825  48.007  1
135715  96.347  -77.837  47.984  1
135716  96.365  -77.849  47.962  1
135717  96.383  -77.862  47.938  1
135718  96.401  -77.874  47.915  1
135719  96.422  -77.887  47.893  1
135720  96.444  -77.899  47.869  1
135721  96.465  -77.912  47.845  1
135722  96.495  -77.919  47.821  1
135723  96.525  -77.927  47.797  1
135724  96.549  -77.932  47.772  1
135725  96.557  -77.930  47.747  1
135726  96.565  -77.928  47.722  1
135727  96.573  -77.926  47.696  1
135728  96.580  -77.924  47.671  1
135729  96.588  -77.923  47.645  1
135730  96.595  -77.921  47.621  1
135731  96.603  -77.919  47.597  1
135732  96.611  -77.918  47.572  1
135733  96.620  -77.917  47.547  1
135734  96.630  -77.918  47.522  1
135735  96.642  -77.920  47.498  1
135736  96.652  -77.921  47.475  1
135737  96.666  -77.936  47.450  1
135738  96.680  -77.953  47.425  1
135739  96.707  -77.968  47.401  1
135740  96.738  -77.984  47.376  1
135741  96.791  -78.003  47.351  1
135742  96.844  -78.021  47.327  1
135743  96.881  -78.037  47.302  1
135744  96.879  -78.048  47.276  1
135745  96.877  -78.059  47.251  1
135746  96.875  -78.071  47.227  1
135747  96.873  -78.082  47.203  1
135748  96.874  -78.096  47.178  1
135749  96.890  -78.106  47.156  1
135750  96.914  -78.112  47.134  1
135751  96.938  -78.119  47.111  1
135752  96.954  -78.119  47.088  1
135753  96.971  -78.129  47.064  1
135754  96.988  -78.141  47.042  1
135755  97.005  -78.153  47.022  1
135756  97.022  -78.166  47.003  1
135757  97.038  -78.178  46.986  1
135758  97.055  -78.190  46.970  1
135759  97.072  -78.202  46.954  1
135760  97.088  -78.214  46.940  1
135761  97.105  -78.226  46.926  1
135762  97.121  -78.238  46.914  1
135763  97.144  -78.234  46.901  1
135764  97.172  -78.215  46.888  1
135765  97.229  -78.194  46.874  1
135766  97.268  -78.194  46.859  1
135767  97.307  -78.196  46.843  1
135768  97.347  -78.197  46.828  1
135769  97.385  -78.198  46.813  1
135770  97.425  -78.199  46.798  1
135771  97.458  -78.199  46.784  1
135772  97.488  -78.197  46.770  1
135773  97.517  -78.196  46.757  1
135774  97.548  -78.198  46.742  1
135775  97.581  -78.204  46.727  1
135776  97.614  -78.210  46.710  1
135777  97.647  -78.216  46.692  1
135778  97.679  -78.224  46.674  1
135779  97.718  -78.227  46.656  1
135780  97.758  -78.228  46.638  1
135781  97.783  -78.235  46.619  1
135782  97.791  -78.245  46.600  1
135783  97.821  -78.244  46.582  1
135784  97.865  -78.236  46.564  1
135785  97.894  -78.230  46.547  1
135786  97.912  -78.225  46.528  1
135787  97.928  -78.221  46.510  1
135788  97.945  -78.217  46.491  1
135789  97.961  -78.213  46.471  1
135790  97.978  -78.210  46.452  1
135791  97.988  -78.219  46.434  1
135792  98.009  -78.225  46.414  1
135793  98.035  -78.231  46.395  1
135794  98.062  -78.236  46.375  1
135795  98.088  -78.241  46.355  1
135796  98.114  -78.247  46.335  1
135797  98.134  -78.250  46.314  1
135798  98.153  -78.264  46.292  1
135799  98.171  -78.277  46.274  1
135800  98.198  -78.274  46.256  1
135801  98.221  -78.301  46.238  1
135802  98.240  -78.354  46.219  1
135803  98.259  -78.406  46.198  1
135804  98.271  -78.416  46.179  1
135805  98.279  -78.407  46.159  1
135806  98.287  -78.397  46.138  1
135807  98.295  -78.388  46.119  1
135808  98.297  -78.375  46.100  1
135809  98.298  -78.362  46.080  1
135810  98.303  -78.350  46.058  1
135811  98.326  -78.340  46.036  1
135812  98.350  -78.331  46.013  1
135813  98.411  -78.309  45.991  1
135814  98.484  -78.279  45.970  1
135815  98.442  -78.322  45.950  1
135816  98.391  -78.382  45.929  1
135817  98.399  -78.387  45.908  1
135818  98.424  -78.377  45.885  1
135819  98.450  -78.367  45.862  1
135820  98.475  -78.357  45.840  1
135821  98.491  -78.354  45.816  1
135822  98.504  -78.353  45.792  1
135823  98.530  -78.353  45.768  1
135824  98.586  -78.357  45.744  1
135825  98.633  -78.348  45.721  1
135826  98.671  -78.331  45.698  1
135827  98.698  -78.309  45.677  1
135828  98.725  -78.287  45.655  1
135829  98.752  -78.265  45.635  1
135830  98.725  -78.257  45.616  1
135831  98.695  -78.234  45.597  1
135832  98.757  -78.209  45.580  1
135833  98.783  -78.235  45.563  1
135834  98.802  -78.248  45.547  1
135835  98.820  -78.261  45.529  1
135836  98.840  -78.274  45.512  1
135837  98.858  -78.287  45.496  1
135838  98.877  -78.300  45.481  1
135839  98.897  -78.313  45.465  1
135840  98.915  -78.335  45.450  1
135841  98.933  -78.360  45.435  1
135842  98.955  -78.385  45.420  1
135843  98.978  -78.411  45.405  1
135844  99.001  -78.437  45.391  1
135845  99.023  -78.463  45.379  1
135846  99.046  -78.489  45.365  1
135847  99.129  -78.463  45.351  1
135848  99.224  -78.428  45.338  1
135849  99.279  -78.413  45.325  1
135850  99.283  -78.423  45.313  1
135851  99.282  -78.435  45.301  1
135852  99.250  -78.461  45.290  1
135853  99.249  -78.476  45.279  1
135854  99.255  -78.492  45.267  1
135855  99.272  -78.501  45.253  1
135856  99.288  -78.509  45.240  1
135857  99.304  -78.518  45.226  1
135858  99.321  -78.526  45.212  1
135859  99.337  -78.535  45.197  1
135860  99.353  -78.544  45.184  1
135861  99.369  -78.552  45.170  1
135862  99.385  -78.561  45.156  1
135863  99.450  -78.555  45.140  1
135864  99.505  -78.549  45.126  1
135865  99.528  -78.554  45.112  1
135866  99.532  -78.576  45.099  1
135867  99.545  -78.597  45.085  1
135868  99.582  -78.617  45.071  1
135869  99.699  -78.678  45.058  1
135870  99.737  -78.702  45.045  1
135871  99.741  -78.711  45.032  1
135872  99.798  -78.755  45.021  1
135873  99.856  -78.799  45.009  1
135874  99.911  -78.840  44.998  1
135875  99.932  -78.855  44.988  1
135876  99.954  -78.870  44.977  1
135877  99.972  -78.883  44.966  1
135878  99.973  -78.890  44.954  1
135879  99.980  -78.924  44.941  1
135880  99.986  -78.957  44.929  1
135881  99.990  -78.967  44.918  1
135882  99.995  -78.949  44.906  1
135883  100.000  -78.930  44.896  1
135884  100.005  -78.911  44.886  1
135885  100.010  -78.892  44.877  1
135886  100.015  -78.873  44.868  1
135887  100.038  -78.880  44.859  1
135888  100.064  -78.893  44.850  1
135889  100.089  -78.905  44.843  1
135890  100.115  -78.917  44.835  1
135891  100.140  -78.929  44.827  1
135892  100.166  -78.941  44.819  1
135893  100.192  -78.953  44.812  1
135894  100.217  -78.965  44.804  1
135895  100.243  -78.977  44.795  1
135896  100.268  -78.990  44.786  1
135897  100.294  -79.002  44.777  1
135898  100.324  -79.018  44.768  1
135899  100.357  -79.037  44.758  1
135900  100.389  -79.056  44.748  1
135901  100.422  -79.076  44.738  1
135902  100.454  -79.095  44.726  1
135903  100.487  -79.114  44.714  1
135904  100.519  -79.133  44.702  1
135905  100.552  -79.152  44.689  1
135906  100.584  -79.172  44.677  1
135907  100.617  -79.190  44.664  1
135908  100.649  -79.209  44.650  1
136170  93.040  -78.214  54.161  1
136171  93.054  -78.210  54.155  1
136172  93.068  -78.197  54.148  1
136173  93.081  -78.185  54.142  1
136174  93.095  -78.173  54.135  1
136175  93.110  -78.161  54.128  1
136176  93.124  -78.149  54.120  1
136177  93.144  -78.137  54.113  1
136178  93.167  -78.125  54.106  1
136179  93.191  -78.113  54.097  1
136180  93.215  -78.101  54.091  1
136181  93.238  -78.089  54.082  1
136182  93.262  -78.078  54.072  1
136183  93.286  -78.065  54.064  1
136184  93.309  -78.053  54.055  1
136185  93.333  -78.042  54.046  1
136186  93.357  -78.030  54.037  1
136187  93.380  -78.018  54.029  1
136188  93.402  -78.008  54.018  1
136189  93.412  -78.005  54.006  1
136190  93.418  -77.996  53.995  1
136191  93.428  -77.981  53.982  1
136192  93.438  -77.965  53.969  1
136193  93.449  -77.949  53.956  1
136194  93.459  -77.934  53.941  1
136195  93.469  -77.918  53.925  1
136196  93.482  -77.905  53.909  1
136197  93.493  -77.896  53.892  1
136198  93.505  -77.888  53.877  1
136199  93.516  -77.880  53.861  1
136200  93.528  -77.871  53.845  1
136201  93.540  -77.863  53.830  1
136202  93.551  -77.855  53.813  1
136203  93.563  -77.846  53.795  1
136204  93.574  -77.839  53.777  1
136205  93.586  -77.830  53.759  1
136206  93.597  -77.822  53.741  1
136207  93.609  -77.814  53.724  1
136208  93.621  -77.805  53.707  1
136209  93.632  -77.797  53.688  1
136210  93.646  -77.790  53.669  1
136211  93.659  -77.784  53.650  1
136212  93.672  -77.780  53.632  1
136213  93.685  -77.776  53.613  1
136214  93.698  -77.771  53.594  1
136215  93.711  -77.768  53.575  1
136216  93.723  -77.763  53.556  1
136217  93.736  -77.758  53.536  1
136218  93.747  -77.754  53.516  1
136224  93.812  -77.725  53.404  1
136225  93.823  -77.720  53.385  1
136226  93.833  -77.715  53.367  1
136227  93.844  -77.710  53.350  1
136228  93.855  -77.705  53.333  1
136229  93.865  -77.701  53.316  1
136230  93.876  -77.696  53.298  1
136231  93.887  -77.691  53.281  1
136232  93.898  -77.686  53.264  1
136233  93.908  -77.681  53.247  1
136234  93.921  -77.677  53.231  1
136235  93.935  -77.673  53.215  1
136236  93.948  -77.668  53.200  1
136237  93.963  -77.664  53.184  1
136238  93.973  -77.662  53.169  1
136239  93.978  -77.664  53.152  1
136240  93.983  -77.665  53.135  1
136241  93.988  -77.667  53.115  1
136242  93.993  -77.667  53.095  1
136243  93.998  -77.669  53.076  1
136244  94.002  -77.671  53.056  1
136245  94.012  -77.666  53.038  1
136246  94.028  -77.654  53.021  1
136247  94.048  -77.642  53.004  1
136248  94.062  -77.633  52.987  1
136249  94.068  -77.628  52.969  1
136250  94.074  -77.624  52.951  1
136251  94.076  -77.618  52.933  1
136252  94.075  -77.613  52.913  1
136253  94.073  -77.608  52.892  1
136254  94.060  -77.613  52.872  1
136255  94.041  -77.623  52.852  1
136256  94.023  -77.633  52.831  1
136257  94.049  -77.619  52.810  1
136258  94.099  -77.594  52.788  1
136259  94.145  -77.572  52.767  1
136260  94.163  -77.569  52.745  1
136261  94.175  -77.564  52.725  1
136262  94.190  -77.558  52.707  1
136263  94.209  -77.555  52.690  1
136264  94.222  -77.559  52.672  1
136265  94.236  -77.562  52.655  1
136266  94.250  -77.566  52.642  1
136267  94.262  -77.569  52.630  1
136268  94.263  -77.563  52.621  1
136269  94.264  -77.557  52.614  1
136270  94.266  -77.550  52.615  1
136271  94.277  -77.577  52.614  1
136272  94.298  -77.559  52.612  1
136273  94.319  -77.542  52.605  1
136274  94.340  -77.523  52.598  1
136275  94.369  -77.509  52.592  1
136276  94.404  -77.498  52.588  1
136277  94.449  -77.484  52.583  1
136278  94.495  -77.470  52.576  1
136279  94.522  -77.457  52.567  1
136280  94.514  -77.448  52.556  1
136281  94.507  -77.438  52.547  1
136282  94.499  -77.428  52.539  1
136283  94.492  -77.445  52.529  1
136284  94.484  -77.479  52.516  1
136285  94.470  -77.515  52.500  1
136286  94.468  -77.608  52.482  1
136287  94.483  -77.689  52.463  1
136288  94.495  -77.646  52.438  1
136289  94.508  -77.605  52.413  1
136290  94.520  -77.563  52.388  1
136291  94.533  -77.521  52.358  1
136292  94.547  -77.494  52.323  1
136293  94.564  -77.488  52.286  1
136294  94.580  -77.483  52.247  1
136295  94.597  -77.476  52.213  1
136296  94.635  -77.494  52.179  1
136297  94.683  -77.513  52.145  1
136298  94.732  -77.531  52.112  1
136299  94.778  -77.548  52.074  1
136300  94.819  -77.562  52.034  1
136301  94.860  -77.576  51.993  1
136302  94.901  -77.589  51.953  1
136303  94.942  -77.602  51.916  1
136304  95.014  -77.644  51.882  1
136305  95.005  -77.624  51.852  1
136306  94.991  -77.599  51.819  1
136307  94.977  -77.575  51.784  1
136308  94.963  -77.550  51.747  1
136309  94.949  -77.526  51.705  1
136310  94.935  -77.501  51.666  1
136311  94.949  -77.510  51.629  1
136312  94.964  -77.523  51.595  1
136313  94.979  -77.538  51.558  1
136314  94.993  -77.552  51.521  1
136315  95.039  -77.535  51.483  1
136316  95.117  -77.483  51.443  1
136317  95.109  -77.504  51.402  1
136318  95.097  -77.530  51.361  1
136319  95.094  -77.550  51.320  1
136320  95.112  -77.560  51.273  1
136321  95.130  -77.570  51.221  1
136322  95.139  -77.573  51.167  1
136323  95.162  -77.577  51.113  1
136324  95.185  -77.581  51.062  1
136325  95.209  -77.586  51.014  1
136326  95.233  -77.590  50.967  1
136327  95.243  -77.575  50.923  1
136328  95.249  -77.555  50.880  1
136329  95.255  -77.536  50.838  1
136330  95.261  -77.516  50.797  1
136331  95.267  -77.497  50.760  1
136332  95.293  -77.486  50.724  1
136333  95.325  -77.487  50.690  1
136334  95.357  -77.487  50.658  1
136335  95.389  -77.487  50.626  1
136336  95.421  -77.488  50.593  1
136337  95.453  -77.488  50.557  1
136338  95.485  -77.488  50.521  1
136339  95.517  -77.488  50.482  1
136340  95.539  -77.483  50.443  1
136341  95.554  -77.473  50.404  1
136342  95.570  -77.464  50.365  1
136343  95.585  -77.456  50.327  1
136344  95.620  -77.461  50.289  1
136345  95.672  -77.479  50.248  1
136346  95.725  -77.498  50.209  1
136347  95.771  -77.516  50.170  1
136348  95.770  -77.530  50.130  1
136349  95.770  -77.545  50.090  1
136350  95.769  -77.559  50.051  1
136351  95.768  -77.573  50.013  1
136352  95.767  -77.588  49.975  1
136353  95.741  -77.594  49.938  1
136354  95.712  -77.600  49.903  1
136355  95.683  -77.605  49.868  1
136356  95.678  -77.616  49.836  1
136357  95.682  -77.619  49.802  1
136358  95.685  -77.621  49.770  1
136359  95.689  -77.624  49.738  1
136360  95.692  -77.627  49.707  1
136361  95.698  -77.629  49.677  1
136362  95.708  -77.629  49.648  1
136363  95.719  -77.630  49.617  1
136364  95.728  -77.630  49.586  1
136365  95.738  -77.630  49.555  1
136366  95.748  -77.631  49.523  1
136367  95.758  -77.631  49.490  1
136368  95.768  -77.632  49.459  1
136369  95.780  -77.631  49.429  1
136370  95.795  -77.630  49.399  1
136371  95.809  -77.628  49.370  1
136372  95.823  -77.627  49.340  1
136373  95.837  -77.625  49.311  1
136374  95.851  -77.623  49.279  1
136375  95.866  -77.627  49.248  1
136376  95.882  -77.639  49.217  1
136377  95.903  -77.649  49.183  1
136378  95.930  -77.658  49.149  1
136379  95.957  -77.667  49.112  1
136380  95.984  -77.677  49.074  1
136381  96.011  -77.686  49.036  1
136382  96.024  -77.696  48.999  1
136383  96.034  -77.705  48.963  1
136384  96.044  -77.716  48.927  1
136385  96.054  -77.726  48.892  1
136386  96.064  -77.736  48.856  1
136387  96.074  -77.746  48.819  1
136388  96.084  -77.755  48.783  1
136389  96.094  -77.766  48.748  1
136390  96.103  -77.776  48.714  1
136391  96.113  -77.786  48.680  1
136392  96.120  -77.805  48.646  1
136393  96.128  -77.824  48.612  1
136394  96.143  -77.835  48.578  1
136395  96.157  -77.846  48.544  1
136396  96.171  -77.858  48.512  1
136397  96.185  -77.869  48.481  1
136398  96.200  -77.881  48.451  1
136399  96.206  -77.882  48.420  1
136400  96.205  -77.874  48.389  1
136401  96.204  -77.867  48.358  1
136402  96.203  -77.859  48.329  1
136403  96.202  -77.852  48.302  1
136404  96.201  -77.845  48.275  1
136405  96.200  -77.837  48.249  1
136406  96.208  -77.834  48.223  1
136407  96.216  -77.830  48.197  1
136408  96.226  -77.827  48.173  1
136409  96.247  -77.823  48.149  1
136410  96.268  -77.818  48.127  1
136411  96.289  -77.815  48.105  1
136412  96.310  -77.811  48.083  1
136413  96.317  -77.815  48.060  1
136414  96.323  -77.821  48.038  1
136415  96.332  -77.827  48.015  1
136416  96.350  -77.840  47.992  1
136417  96.368  -77.852  47.970  1
136418  96.386  -77.865  47.948  1
136419  96.403  -77.877  47.926  1
136420  96.421  -77.889  47.903  1
136421  96.442  -77.901  47.879  1
136422  96.467  -77.912  47.856  1
136423  96.497  -77.919  47.831  1
136424  96.527  -77.926  47.808  1
136425  96.550  -77.931  47.782  1
136426  96.558  -77.929  47.756  1
136427  96.566  -77.928  47.731  1
136428  96.574  -77.926  47.706  1
136429  96.581  -77.924  47.680  1
136430  96.589  -77.922  47.654  1
136431  96.597  -77.920  47.630  1
136432  96.604  -77.918  47.605  1
136433  96.612  -77.917  47.581  1
136434  96.619  -77.915  47.556  1
136435  96.628  -77.914  47.531  1
136436  96.639  -77.915  47.506  1
136437  96.650  -77.917  47.482  1
136438  96.662  -77.926  47.458  1
136439  96.678  -77.943  47.433  1
136440  96.705  -77.958  47.409  1
136441  96.753  -77.976  47.384  1
136442  96.806  -77.994  47.359  1
136443  96.859  -78.012  47.335  1
136444  96.887  -78.028  47.310  1
136445  96.885  -78.039  47.284  1
136446  96.883  -78.050  47.260  1
136447  96.881  -78.062  47.236  1
136448  96.882  -78.076  47.212  1
136449  96.883  -78.091  47.188  1
136450  96.901  -78.100  47.166  1
136451  96.925  -78.106  47.143  1
136452  96.945  -78.109  47.120  1
136453  96.958  -78.107  47.098  1
136454  96.979  -78.112  47.076  1
136455  96.996  -78.123  47.054  1
136456  97.013  -78.135  47.034  1
136457  97.029  -78.147  47.015  1
136458  97.046  -78.159  46.998  1
136459  97.063  -78.172  46.981  1
136460  97.079  -78.184  46.966  1
136461  97.096  -78.196  46.951  1
136462  97.112  -78.208  46.938  1
136463  97.129  -78.220  46.924  1
136464  97.155  -78.207  46.911  1
136465  97.182  -78.188  46.900  1
136466  97.210  -78.169  46.888  1
136467  97.260  -78.158  46.875  1
136468  97.299  -78.159  46.861  1
136469  97.338  -78.160  46.846  1
136470  97.373  -78.161  46.832  1
136471  97.403  -78.159  46.818  1
136472  97.435  -78.163  46.804  1
136473  97.467  -78.169  46.791  1
136474  97.500  -78.175  46.778  1
136475  97.533  -78.181  46.763  1
136476  97.566  -78.187  46.747  1
136477  97.598  -78.193  46.730  1
136478  97.632  -78.200  46.712  1
136479  97.664  -78.207  46.694  1
136480  97.704  -78.210  46.676  1
136481  97.744  -78.211  46.658  1
136482  97.785  -78.213  46.641  1
136483  97.816  -78.217  46.623  1
136484  97.846  -78.216  46.606  1
136485  97.867  -78.212  46.589  1
136486  97.883  -78.207  46.572  1
136487  97.900  -78.203  46.552  1
136488  97.917  -78.199  46.532  1
136489  97.933  -78.194  46.513  1
136490  97.950  -78.190  46.493  1
136491  97.967  -78.185  46.473  1
136492  97.978  -78.194  46.454  1
136493  98.001  -78.200  46.434  1
136494  98.027  -78.205  46.414  1
136495  98.054  -78.210  46.394  1
136496  98.080  -78.216  46.373  1
136497  98.097  -78.240  46.353  1
136498  98.125  -78.246  46.331  1
136499  98.153  -78.252  46.309  1
136500  98.174  -78.263  46.290  1
136501  98.197  -78.279  46.271  1
136502  98.216  -78.331  46.252  1
136503  98.235  -78.383  46.233  1
136504  98.253  -78.435  46.212  1
136505  98.263  -78.429  46.192  1
136506  98.271  -78.420  46.172  1
136507  98.273  -78.407  46.152  1
136508  98.274  -78.395  46.134  1
136509  98.275  -78.382  46.116  1
136510  98.279  -78.369  46.097  1
136511  98.303  -78.360  46.075  1
136512  98.326  -78.351  46.053  1
136513  98.350  -78.341  46.029  1
136514  98.409  -78.319  46.007  1
136515  98.456  -78.294  45.986  1
136516  98.445  -78.288  45.965  1
136517  98.393  -78.347  45.944  1
136518  98.408  -78.347  45.922  1
136519  98.433  -78.337  45.899  1
136520  98.456  -78.329  45.876  1
136521  98.468  -78.328  45.853  1
136522  98.482  -78.327  45.829  1
136523  98.495  -78.326  45.805  1
136524  98.508  -78.325  45.781  1
136525  98.543  -78.326  45.757  1
136526  98.592  -78.320  45.734  1
136527  98.631  -78.303  45.711  1
136528  98.669  -78.285  45.689  1
136529  98.708  -78.268  45.668  1
136530  98.744  -78.258  45.648  1
136531  98.737  -78.209  45.629  1
136532  98.708  -78.178  45.610  1
136533  98.753  -78.175  45.593  1
136534  98.780  -78.202  45.577  1
136535  98.806  -78.228  45.560  1
136536  98.830  -78.250  45.543  1
136537  98.849  -78.263  45.526  1
136538  98.867  -78.275  45.510  1
136539  98.886  -78.288  45.494  1
136540  98.906  -78.301  45.479  1
136541  98.924  -78.326  45.464  1
136542  98.941  -78.350  45.449  1
136543  98.959  -78.374  45.435  1
136544  98.978  -78.398  45.420  1
136545  98.997  -78.423  45.407  1
136546  99.020  -78.449  45.395  1
136547  99.043  -78.474  45.381  1
136548  99.103  -78.468  45.367  1
136549  99.179  -78.443  45.353  1
136550  99.183  -78.453  45.341  1
136551  99.186  -78.463  45.328  1
136552  99.196  -78.470  45.315  1
136553  99.232  -78.462  45.304  1
136554  99.264  -78.455  45.293  1
136555  99.291  -78.449  45.281  1
136556  99.305  -78.468  45.268  1
136557  99.321  -78.481  45.254  1
136558  99.337  -78.490  45.240  1
136559  99.353  -78.498  45.226  1
136560  99.369  -78.507  45.212  1
136561  99.386  -78.516  45.199  1
136562  99.402  -78.524  45.186  1
136563  99.426  -78.532  45.172  1
136564  99.488  -78.526  45.156  1
136565  99.502  -78.539  45.141  1
136566  99.524  -78.559  45.127  1
136567  99.562  -78.579  45.113  1
136568  99.600  -78.600  45.100  1
136569  99.637  -78.620  45.086  1
136570  99.766  -78.688  45.072  1
136571  99.752  -78.686  45.059  1
136572  99.759  -78.693  45.046  1
136573  99.785  -78.715  45.035  1
136574  99.843  -78.759  45.024  1
136575  99.901  -78.803  45.012  1
136576  99.927  -78.822  45.001  1
136577  99.949  -78.837  44.990  1
136578  99.971  -78.852  44.978  1
136579  99.992  -78.867  44.966  1
136580  100.000  -78.887  44.954  1
136581  99.999  -78.912  44.943  1
136582  99.999  -78.938  44.931  1
136583  100.002  -78.934  44.920  1
136584  100.007  -78.916  44.910  1
136585  100.012  -78.897  44.900  1
136586  100.017  -78.878  44.891  1
136587  100.023  -78.859  44.881  1
136588  100.047  -78.869  44.871  1
136589  100.072  -78.881  44.862  1
136590  100.098  -78.893  44.854  1
136591  100.123  -78.905  44.846  1
136592  100.149  -78.918  44.838  1
136593  100.174  -78.930  44.829  1
136594  100.200  -78.942  44.822  1
136595  100.226  -78.954  44.813  1
136596  100.251  -78.966  44.803  1
136597  100.283  -78.979  44.794  1
136598  100.309  -78.992  44.784  1
136599  100.322  -79.009  44.773  1
136600  100.354  -79.028  44.763  1
136601  100.387  -79.046  44.753  1
136602  100.419  -79.065  44.742  1
136603  100.452  -79.085  44.730  1
136604  100.484  -79.104  44.718  1
136605  100.516  -79.123  44.705  1
136606  100.549  -79.142  44.692  1
136607  100.581  -79.161  44.679  1
136608  100.614  -79.181  44.665  1
136609  100.646  -79.200  44.651  1
136867  92.985  -78.219  54.195  1
136868  92.998  -78.215  54.189  1
136869  93.012  -78.210  54.181  1
136870  93.025  -78.205  54.174  1
136871  93.039  -78.200  54.168  1
136872  93.053  -78.195  54.162  1
136873  93.067  -78.188  54.156  1
136874  93.081  -78.175  54.150  1
136875  93.095  -78.163  54.143  1
136876  93.109  -78.150  54.135  1
136877  93.123  -78.138  54.128  1
136878  93.143  -78.126  54.121  1
136879  93.167  -78.115  54.114  1
136880  93.191  -78.103  54.105  1
136881  93.214  -78.091  54.099  1
136882  93.238  -78.079  54.090  1
136883  93.262  -78.067  54.081  1
136884  93.285  -78.056  54.073  1
136885  93.309  -78.044  54.065  1
136886  93.332  -78.031  54.057  1
136887  93.356  -78.020  54.049  1
136888  93.379  -78.008  54.041  1
136889  93.402  -77.996  54.031  1
136890  93.412  -77.994  54.019  1
136891  93.420  -77.980  54.007  1
136892  93.430  -77.965  53.995  1
136893  93.440  -77.949  53.982  1
136894  93.450  -77.934  53.968  1
136895  93.461  -77.918  53.953  1
136896  93.471  -77.902  53.936  1
136897  93.483  -77.892  53.919  1
136898  93.495  -77.884  53.902  1
136899  93.506  -77.875  53.887  1
136900  93.518  -77.867  53.871  1
136901  93.530  -77.859  53.856  1
136902  93.541  -77.850  53.840  1
136903  93.553  -77.842  53.823  1
136904  93.564  -77.834  53.805  1
136905  93.576  -77.825  53.788  1
136906  93.587  -77.818  53.770  1
136907  93.599  -77.809  53.752  1
136908  93.611  -77.801  53.735  1
136909  93.622  -77.793  53.718  1
136910  93.634  -77.784  53.699  1
136911  93.647  -77.777  53.680  1
136912  93.660  -77.774  53.662  1
136913  93.673  -77.769  53.643  1
136914  93.686  -77.765  53.624  1
136915  93.697  -77.760  53.605  1
136916  93.707  -77.755  53.587  1
136917  93.718  -77.750  53.567  1
136918  93.729  -77.746  53.547  1
136919  93.740  -77.740  53.528  1
136926  93.815  -77.706  53.399  1
136927  93.826  -77.702  53.381  1
136928  93.836  -77.697  53.363  1
136929  93.847  -77.692  53.346  1
136930  93.858  -77.687  53.329  1
136931  93.868  -77.682  53.311  1
136932  93.879  -77.677  53.294  1
136933  93.890  -77.672  53.277  1
136934  93.902  -77.667  53.260  1
136935  93.915  -77.664  53.243  1
136936  93.929  -77.660  53.227  1
136937  93.943  -77.655  53.211  1
136938  93.957  -77.652  53.193  1
136939  93.969  -77.649  53.176  1
136940  93.974  -77.650  53.159  1
136941  93.979  -77.652  53.141  1
136942  93.984  -77.653  53.121  1
136943  93.989  -77.654  53.103  1
136944  93.993  -77.655  53.084  1
136945  93.999  -77.656  53.064  1
136946  94.014  -77.643  53.046  1
136947  94.030  -77.631  53.028  1
136948  94.050  -77.620  53.012  1
136949  94.069  -77.608  52.996  1
136950  94.087  -77.598  52.980  1
136951  94.090  -77.592  52.964  1
136952  94.089  -77.588  52.947  1
136953  94.087  -77.583  52.928  1
136954  94.086  -77.577  52.908  1
136955  94.084  -77.573  52.888  1
136956  94.069  -77.579  52.870  1
136957  94.050  -77.589  52.851  1
136958  94.045  -77.600  52.832  1
136959  94.110  -77.568  52.812  1
136960  94.184  -77.530  52.792  1
136961  94.175  -77.544  52.770  1
136962  94.165  -77.558  52.750  1
136963  94.187  -77.549  52.733  1
136964  94.199  -77.551  52.715  1
136965  94.213  -77.555  52.698  1
136966  94.227  -77.558  52.680  1
136967  94.233  -77.564  52.668  1
136968  94.242  -77.551  52.656  1
136969  94.249  -77.549  52.646  1
136970  94.238  -77.557  52.640  1
136971  94.238  -77.551  52.640  1
136972  94.242  -77.558  52.640  1
136973  94.263  -77.545  52.638  1
136974  94.287  -77.529  52.633  1
136975  94.322  -77.517  52.626  1
136976  94.357  -77.505  52.620  1
136977  94.403  -77.492  52.616  1
136978  94.450  -77.477  52.612  1
136979  94.496  -77.463  52.606  1
136980  94.505  -77.452  52.598  1
136981  94.498  -77.442  52.588  1
136982  94.491  -77.432  52.580  1
136983  94.484  -77.423  52.572  1
136984  94.476  -77.414  52.564  1
136985  94.469  -77.434  52.553  1
136986  94.461  -77.469  52.538  1
136987  94.453  -77.503  52.521  1
136988  94.468  -77.510  52.500  1
136989  94.484  -77.504  52.474  1
136990  94.501  -77.498  52.446  1
136991  94.518  -77.492  52.417  1
136992  94.535  -77.486  52.384  1
136993  94.551  -77.480  52.349  1
136994  94.568  -77.475  52.313  1
136995  94.585  -77.469  52.277  1
136996  94.602  -77.463  52.244  1
136997  94.644  -77.496  52.211  1
136998  94.692  -77.515  52.177  1
136999  94.740  -77.533  52.145  1
137000  94.788  -77.551  52.107  1
137001  94.837  -77.570  52.066  1
137002  94.885  -77.589  52.024  1
137003  94.933  -77.607  51.984  1
137004  94.982  -77.626  51.947  1
137005  95.030  -77.644  51.911  1
137006  95.026  -77.633  51.878  1
137007  95.004  -77.613  51.844  1
137008  94.982  -77.592  51.808  1
137009  94.960  -77.572  51.771  1
137010  94.938  -77.551  51.730  1
137011  94.964  -77.490  51.692  1
137012  94.908  -77.489  51.657  1
137013  94.923  -77.502  51.623  1
137014  94.937  -77.517  51.587  1
137015  94.988  -77.495  51.551  1
137016  95.065  -77.443  51.514  1
137017  95.106  -77.424  51.473  1
137018  95.094  -77.449  51.434  1
137019  95.081  -77.474  51.395  1
137020  95.068  -77.499  51.356  1
137021  95.079  -77.513  51.310  1
137022  95.098  -77.523  51.259  1
137023  95.128  -77.536  51.204  1
137024  95.168  -77.548  51.148  1
137025  95.190  -77.551  51.095  1
137026  95.213  -77.555  51.044  1
137027  95.236  -77.558  50.996  1
137028  95.244  -77.541  50.952  1
137029  95.252  -77.523  50.908  1
137030  95.259  -77.504  50.865  1
137031  95.267  -77.486  50.823  1
137032  95.280  -77.475  50.786  1
137033  95.302  -77.476  50.749  1
137034  95.332  -77.476  50.713  1
137035  95.365  -77.476  50.680  1
137036  95.397  -77.476  50.651  1
137037  95.428  -77.476  50.620  1
137038  95.461  -77.476  50.586  1
137039  95.493  -77.477  50.550  1
137040  95.525  -77.477  50.512  1
137041  95.547  -77.472  50.473  1
137042  95.563  -77.464  50.434  1
137043  95.579  -77.454  50.394  1
137044  95.594  -77.445  50.355  1
137045  95.644  -77.462  50.315  1
137046  95.696  -77.480  50.274  1
137047  95.749  -77.499  50.234  1
137048  95.752  -77.514  50.195  1
137049  95.751  -77.528  50.154  1
137050  95.751  -77.542  50.112  1
137051  95.750  -77.557  50.072  1
137052  95.749  -77.571  50.033  1
137053  95.749  -77.586  49.993  1
137054  95.739  -77.598  49.956  1
137055  95.710  -77.603  49.919  1
137056  95.681  -77.609  49.884  1
137057  95.679  -77.617  49.850  1
137058  95.682  -77.620  49.816  1
137059  95.686  -77.623  49.782  1
137060  95.689  -77.626  49.750  1
137061  95.697  -77.627  49.719  1
137062  95.707  -77.627  49.688  1
137063  95.716  -77.628  49.657  1
137064  95.727  -77.628  49.626  1
137065  95.737  -77.629  49.595  1
137066  95.746  -77.630  49.564  1
137067  95.758  -77.629  49.533  1
137068  95.772  -77.627  49.500  1
137069  95.787  -77.626  49.470  1
137070  95.801  -77.624  49.440  1
137071  95.815  -77.622  49.413  1
137072  95.829  -77.620  49.383  1
137073  95.843  -77.619  49.354  1
137074  95.858  -77.617  49.324  1
137075  95.872  -77.616  49.292  1
137076  95.887  -77.621  49.261  1
137077  95.902  -77.633  49.229  1
137078  95.917  -77.643  49.196  1
137079  95.942  -77.653  49.162  1
137080  95.969  -77.662  49.125  1
137081  95.995  -77.672  49.088  1
137082  96.006  -77.682  49.049  1
137083  96.016  -77.692  49.012  1
137084  96.026  -77.702  48.976  1
137085  96.035  -77.711  48.940  1
137086  96.045  -77.722  48.905  1
137087  96.055  -77.732  48.869  1
137088  96.065  -77.742  48.833  1
137089  96.075  -77.752  48.797  1
137090  96.085  -77.761  48.762  1
137091  96.095  -77.772  48.728  1
137092  96.105  -77.782  48.694  1
137093  96.112  -77.801  48.660  1
137094  96.126  -77.812  48.625  1
137095  96.141  -77.824  48.591  1
137096  96.155  -77.835  48.557  1
137097  96.169  -77.846  48.524  1
137098  96.183  -77.858  48.493  1
137099  96.197  -77.870  48.462  1
137100  96.208  -77.876  48.431  1
137101  96.207  -77.868  48.400  1
137102  96.206  -77.862  48.370  1
137103  96.205  -77.854  48.340  1
137104  96.204  -77.846  48.313  1
137105  96.203  -77.839  48.286  1
137106  96.210  -77.835  48.260  1
137107  96.219  -77.831  48.233  1
137108  96.227  -77.828  48.208  1
137109  96.239  -77.824  48.183  1
137110  96.260  -77.821  48.158  1
137111  96.281  -77.817  48.136  1
137112  96.302  -77.812  48.114  1
137113  96.315  -77.813  48.092  1
137114  96.321  -77.818  48.069  1
137115  96.328  -77.824  48.047  1
137116  96.335  -77.830  48.024  1
137117  96.353  -77.842  48.000  1
137118  96.371  -77.854  47.978  1
137119  96.389  -77.867  47.957  1
137120  96.406  -77.879  47.935  1
137121  96.425  -77.891  47.913  1
137122  96.442  -77.903  47.890  1
137123  96.470  -77.911  47.866  1
137124  96.499  -77.918  47.842  1
137125  96.529  -77.926  47.818  1
137126  96.552  -77.931  47.792  1
137127  96.559  -77.928  47.767  1
137128  96.567  -77.927  47.741  1
137129  96.575  -77.925  47.716  1
137130  96.583  -77.923  47.689  1
137131  96.590  -77.921  47.664  1
137132  96.598  -77.919  47.639  1
137133  96.605  -77.918  47.614  1
137134  96.613  -77.916  47.590  1
137135  96.621  -77.914  47.565  1
137136  96.628  -77.912  47.541  1
137137  96.636  -77.911  47.516  1
137138  96.647  -77.912  47.491  1
137139  96.658  -77.916  47.467  1
137140  96.676  -77.933  47.442  1
137141  96.715  -77.949  47.418  1
137142  96.767  -77.968  47.394  1
137143  96.821  -77.986  47.369  1
137144  96.874  -78.005  47.344  1
137145  96.893  -78.018  47.319  1
137146  96.891  -78.030  47.294  1
137147  96.890  -78.042  47.270  1
137148  96.891  -78.056  47.246  1
137149  96.891  -78.071  47.223  1
137150  96.892  -78.085  47.199  1
137151  96.912  -78.094  47.177  1
137152  96.936  -78.100  47.154  1
137153  96.950  -78.097  47.131  1
137154  96.962  -78.095  47.109  1
137155  96.983  -78.100  47.088  1
137156  97.003  -78.106  47.067  1
137157  97.020  -78.118  47.047  1
137158  97.037  -78.130  47.028  1
137159  97.053  -78.142  47.010  1
137160  97.070  -78.154  46.994  1
137161  97.087  -78.166  46.978  1
137162  97.103  -78.178  46.963  1
137163  97.120  -78.191  46.949  1
137164  97.138  -78.200  46.935  1
137165  97.165  -78.181  46.922  1
137166  97.193  -78.162  46.912  1
137167  97.221  -78.143  46.902  1
137168  97.250  -78.123  46.890  1
137169  97.289  -78.122  46.877  1
137170  97.321  -78.127  46.864  1
137171  97.354  -78.133  46.851  1
137172  97.387  -78.139  46.838  1
137173  97.419  -78.145  46.825  1
137174  97.452  -78.151  46.811  1
137175  97.485  -78.157  46.796  1
137176  97.517  -78.163  46.781  1
137177  97.550  -78.169  46.766  1
137178  97.583  -78.176  46.749  1
137179  97.616  -78.184  46.731  1
137180  97.650  -78.191  46.715  1
137181  97.690  -78.192  46.698  1
137182  97.731  -78.194  46.681  1
137183  97.771  -78.196  46.664  1
137184  97.811  -78.197  46.648  1
137185  97.832  -78.207  46.632  1
137186  97.855  -78.189  46.614  1
137187  97.872  -78.184  46.594  1
137188  97.888  -78.180  46.574  1
137189  97.905  -78.176  46.554  1
137190  97.922  -78.172  46.535  1
137191  97.939  -78.167  46.515  1
137192  97.955  -78.163  46.495  1
137193  97.967  -78.169  46.474  1
137194  97.994  -78.174  46.454  1
137195  98.020  -78.179  46.433  1
137196  98.046  -78.184  46.412  1
137197  98.049  -78.238  46.391  1
137198  98.077  -78.244  46.371  1
137199  98.105  -78.250  46.349  1
137200  98.133  -78.256  46.327  1
137201  98.169  -78.263  46.306  1
137202  98.197  -78.297  46.285  1
137203  98.213  -78.356  46.265  1
137204  98.229  -78.412  46.245  1
137205  98.246  -78.453  46.224  1
137206  98.249  -78.440  46.204  1
137207  98.250  -78.427  46.184  1
137208  98.251  -78.414  46.165  1
137209  98.252  -78.401  46.147  1
137210  98.255  -78.388  46.129  1
137211  98.279  -78.379  46.110  1
137212  98.303  -78.369  46.089  1
137213  98.326  -78.360  46.066  1
137214  98.350  -78.351  46.044  1
137215  98.407  -78.330  46.022  1
137216  98.428  -78.308  46.001  1
137217  98.426  -78.288  45.979  1
137218  98.396  -78.313  45.958  1
137219  98.417  -78.307  45.935  1
137220  98.434  -78.304  45.912  1
137221  98.446  -78.302  45.888  1
137222  98.459  -78.301  45.865  1
137223  98.473  -78.300  45.841  1
137224  98.486  -78.299  45.817  1
137225  98.499  -78.298  45.794  1
137226  98.512  -78.297  45.770  1
137227  98.551  -78.293  45.746  1
137228  98.589  -78.275  45.723  1
137229  98.628  -78.274  45.702  1
137230  98.665  -78.274  45.681  1
137231  98.698  -78.255  45.660  1
137232  98.716  -78.184  45.641  1
137233  98.722  -78.123  45.623  1
137234  98.750  -78.141  45.606  1
137235  98.776  -78.168  45.589  1
137236  98.803  -78.195  45.573  1
137237  98.830  -78.222  45.557  1
137238  98.856  -78.248  45.539  1
137239  98.877  -78.264  45.523  1
137240  98.896  -78.277  45.507  1
137241  98.915  -78.291  45.492  1
137242  98.932  -78.315  45.478  1
137243  98.950  -78.340  45.463  1
137244  98.969  -78.364  45.450  1
137245  98.987  -78.388  45.435  1
137246  99.005  -78.413  45.421  1
137247  99.022  -78.437  45.409  1
137248  99.041  -78.461  45.395  1
137249  99.077  -78.474  45.382  1
137250  99.097  -78.475  45.368  1
137251  99.134  -78.467  45.354  1
137252  99.170  -78.460  45.341  1
137253  99.207  -78.452  45.330  1
137254  99.243  -78.445  45.319  1
137255  99.272  -78.438  45.308  1
137256  99.299  -78.432  45.295  1
137257  99.327  -78.426  45.281  1
137258  99.354  -78.420  45.268  1
137259  99.377  -78.423  45.254  1
137260  99.392  -78.442  45.239  1
137261  99.406  -78.460  45.225  1
137262  99.420  -78.479  45.212  1
137263  99.435  -78.496  45.200  1
137264  99.471  -78.502  45.187  1
137265  99.504  -78.522  45.173  1
137266  99.542  -78.542  45.158  1
137267  99.579  -78.562  45.143  1
137268  99.617  -78.582  45.129  1
137269  99.655  -78.603  45.115  1
137270  99.693  -78.623  45.101  1
137271  99.781  -78.670  45.087  1
137272  99.778  -78.674  45.074  1
137273  99.785  -78.682  45.061  1
137274  99.791  -78.689  45.049  1
137275  99.830  -78.720  45.037  1
137276  99.888  -78.764  45.025  1
137277  99.922  -78.789  45.013  1
137278  99.944  -78.804  45.002  1
137279  99.966  -78.819  44.991  1
137280  99.984  -78.834  44.979  1
137281  99.999  -78.849  44.967  1
137282  100.011  -78.866  44.956  1
137283  100.010  -78.892  44.945  1
137284  100.010  -78.917  44.934  1
137285  100.014  -78.902  44.924  1
137286  100.019  -78.883  44.914  1
137287  100.025  -78.865  44.904  1
137288  100.030  -78.846  44.894  1
137289  100.055  -78.857  44.884  1
137290  100.081  -78.869  44.875  1
137291  100.107  -78.881  44.867  1
137292  100.132  -78.893  44.858  1
137293  100.157  -78.905  44.849  1
137294  100.183  -78.918  44.840  1
137295  100.209  -78.930  44.831  1
137296  100.234  -78.942  44.822  1
137297  100.280  -78.957  44.813  1
137298  100.308  -78.970  44.802  1
137299  100.318  -78.984  44.792  1
137300  100.329  -79.002  44.781  1
137301  100.352  -79.018  44.769  1
137302  100.384  -79.037  44.758  1
137303  100.417  -79.056  44.746  1
137304  100.449  -79.075  44.734  1
137305  100.482  -79.093  44.721  1
137306  100.514  -79.113  44.708  1
137307  100.547  -79.132  44.695  1
137308  100.579  -79.151  44.681  1
137309  100.612  -79.170  44.667  1
137310  100.644  -79.190  44.653  1
137565  92.943  -78.220  54.217  1
137566  92.956  -78.215  54.212  1
137567  92.970  -78.210  54.207  1
137568  92.984  -78.206  54.201  1
137569  92.997  -78.200  54.195  1
137570  93.011  -78.196  54.188  1
137571  93.024  -78.191  54.181  1
137572  93.038  -78.186  54.175  1
137573  93.052  -78.181  54.169  1
137574  93.066  -78.177  54.163  1
137575  93.080  -78.165  54.157  1
137576  93.094  -78.153  54.150  1
137577  93.108  -78.141  54.143  1
137578  93.122  -78.128  54.135  1
137579  93.143  -78.116  54.128  1
137580  93.166  -78.104  54.121  1
137581  93.190  -78.093  54.114  1
137582  93.213  -78.081  54.107  1
137583  93.237  -78.069  54.099  1
137584  93.261  -78.057  54.090  1
137585  93.284  -78.045  54.082  1
137586  93.308  -78.033  54.075  1
137587  93.332  -78.022  54.068  1
137588  93.355  -78.009  54.060  1
137589  93.379  -77.997  54.053  1
137590  93.403  -77.986  54.043  1
137591  93.411  -77.980  54.031  1
137592  93.421  -77.965  54.020  1
137593  93.431  -77.949  54.007  1
137594  93.441  -77.934  53.994  1
137595  93.451  -77.918  53.981  1
137596  93.462  -77.902  53.966  1
137597  93.473  -77.887  53.949  1
137598  93.484  -77.879  53.932  1
137599  93.496  -77.871  53.915  1
137600  93.507  -77.862  53.899  1
137601  93.519  -77.854  53.883  1
137602  93.531  -77.846  53.868  1
137603  93.542  -77.837  53.852  1
137604  93.554  -77.829  53.835  1
137605  93.565  -77.821  53.818  1
137606  93.577  -77.812  53.799  1
137607  93.588  -77.804  53.782  1
137608  93.600  -77.796  53.764  1
137609  93.612  -77.788  53.747  1
137610  93.623  -77.780  53.731  1
137611  93.635  -77.771  53.711  1
137612  93.646  -77.766  53.692  1
137613  93.657  -77.761  53.674  1
137614  93.667  -77.756  53.655  1
137615  93.678  -77.752  53.636  1
137616  93.689  -77.746  53.618  1
137617  93.700  -77.742  53.599  1
137618  93.710  -77.736  53.579  1
137619  93.721  -77.732  53.559  1
137620  93.732  -77.727  53.540  1
137621  93.743  -77.722  53.521  1
137627  93.807  -77.693  53.412  1
137628  93.818  -77.688  53.395  1
137629  93.829  -77.683  53.377  1
137630  93.839  -77.678  53.360  1
137631  93.850  -77.674  53.343  1
137632  93.861  -77.668  53.326  1
137633  93.871  -77.664  53.308  1
137634  93.883  -77.659  53.291  1
137635  93.896  -77.655  53.274  1
137636  93.910  -77.651  53.257  1
137637  93.924  -77.647  53.240  1
137638  93.937  -77.642  53.223  1
137639  93.952  -77.639  53.204  1
137640  93.965  -77.635  53.187  1
137641  93.970  -77.636  53.169  1
137642  93.975  -77.638  53.151  1
137643  93.980  -77.639  53.133  1
137644  93.984  -77.640  53.115  1
137645  93.989  -77.642  53.096  1
137646  94.001  -77.634  53.077  1
137647  94.016  -77.621  53.058  1
137648  94.032  -77.608  53.039  1
137649  94.051  -77.597  53.022  1
137650  94.071  -77.586  53.006  1
137651  94.088  -77.575  52.990  1
137652  94.094  -77.567  52.974  1
137653  94.099  -77.558  52.958  1
137654  94.100  -77.552  52.940  1
137655  94.099  -77.547  52.921  1
137656  94.097  -77.542  52.902  1
137657  94.095  -77.537  52.884  1
137658  94.078  -77.545  52.866  1
137659  94.072  -77.556  52.849  1
137660  94.077  -77.567  52.832  1
137661  94.143  -77.551  52.813  1
137662  94.139  -77.561  52.793  1
137663  94.170  -77.545  52.774  1
137664  94.183  -77.544  52.755  1
137665  94.192  -77.545  52.739  1
137666  94.205  -77.548  52.723  1
137667  94.211  -77.555  52.706  1
137668  94.185  -77.557  52.694  1
137669  94.216  -77.536  52.682  1
137670  94.250  -77.520  52.671  1
137671  94.239  -77.527  52.664  1
137672  94.227  -77.535  52.663  1
137673  94.215  -77.542  52.662  1
137674  94.240  -77.536  52.660  1
137675  94.275  -77.524  52.657  1
137676  94.311  -77.513  52.652  1
137677  94.357  -77.498  52.648  1
137678  94.404  -77.485  52.643  1
137679  94.451  -77.470  52.640  1
137680  94.497  -77.456  52.634  1
137681  94.489  -77.446  52.626  1
137682  94.482  -77.437  52.618  1
137683  94.475  -77.427  52.610  1
137684  94.468  -77.417  52.602  1
137685  94.460  -77.407  52.595  1
137686  94.453  -77.398  52.585  1
137687  94.445  -77.423  52.571  1
137688  94.441  -77.457  52.554  1
137689  94.468  -77.482  52.532  1
137690  94.489  -77.491  52.504  1
137691  94.505  -77.485  52.474  1
137692  94.522  -77.479  52.442  1
137693  94.539  -77.473  52.409  1
137694  94.556  -77.467  52.376  1
137695  94.572  -77.461  52.343  1
137696  94.589  -77.455  52.311  1
137697  94.609  -77.456  52.278  1
137698  94.652  -77.498  52.245  1
137699  94.701  -77.517  52.211  1
137700  94.749  -77.536  52.177  1
137701  94.797  -77.554  52.138  1
137702  94.846  -77.573  52.098  1
137703  94.894  -77.591  52.056  1
137704  94.943  -77.609  52.015  1
137705  94.991  -77.628  51.977  1
137706  95.024  -77.636  51.940  1
137707  95.044  -77.636  51.905  1
137708  95.022  -77.616  51.870  1
137709  95.000  -77.595  51.835  1
137710  95.008  -77.544  51.798  1
137711  94.979  -77.482  51.760  1
137712  94.957  -77.445  51.722  1
137713  94.894  -77.479  51.685  1
137714  94.882  -77.481  51.650  1
137715  94.936  -77.454  51.613  1
137716  95.015  -77.403  51.577  1
137717  95.093  -77.352  51.540  1
137718  95.091  -77.368  51.501  1
137719  95.078  -77.393  51.463  1
137720  95.066  -77.418  51.428  1
137721  95.053  -77.444  51.391  1
137722  95.046  -77.466  51.346  1
137723  95.064  -77.476  51.296  1
137724  95.106  -77.492  51.241  1
137725  95.163  -77.512  51.183  1
137726  95.192  -77.520  51.127  1
137727  95.215  -77.523  51.075  1
137728  95.237  -77.525  51.027  1
137729  95.245  -77.506  50.979  1
137730  95.252  -77.488  50.934  1
137731  95.260  -77.470  50.891  1
137732  95.276  -77.464  50.849  1
137733  95.298  -77.464  50.808  1
137734  95.320  -77.464  50.770  1
137735  95.342  -77.465  50.733  1
137736  95.372  -77.465  50.699  1
137737  95.404  -77.465  50.670  1
137738  95.437  -77.466  50.640  1
137739  95.468  -77.466  50.610  1
137740  95.500  -77.466  50.575  1
137741  95.533  -77.467  50.538  1
137742  95.556  -77.462  50.500  1
137743  95.571  -77.453  50.462  1
137744  95.587  -77.444  50.421  1
137745  95.616  -77.445  50.380  1
137746  95.668  -77.463  50.339  1
137747  95.721  -77.482  50.299  1
137748  95.734  -77.497  50.259  1
137749  95.733  -77.511  50.219  1
137750  95.732  -77.526  50.177  1
137751  95.732  -77.540  50.135  1
137752  95.731  -77.555  50.094  1
137753  95.730  -77.569  50.053  1
137754  95.730  -77.584  50.013  1
137755  95.729  -77.599  49.974  1
137756  95.708  -77.606  49.937  1
137757  95.679  -77.612  49.900  1
137758  95.679  -77.619  49.865  1
137759  95.683  -77.622  49.830  1
137760  95.686  -77.624  49.796  1
137761  95.695  -77.625  49.763  1
137762  95.705  -77.626  49.732  1
137763  95.715  -77.627  49.700  1
137764  95.725  -77.627  49.668  1
137765  95.736  -77.627  49.636  1
137766  95.750  -77.625  49.604  1
137767  95.765  -77.624  49.573  1
137768  95.779  -77.621  49.543  1
137769  95.793  -77.620  49.511  1
137770  95.807  -77.618  49.481  1
137771  95.821  -77.617  49.452  1
137772  95.836  -77.615  49.425  1
137773  95.850  -77.614  49.396  1
137774  95.864  -77.611  49.366  1
137775  95.878  -77.610  49.336  1
137776  95.892  -77.608  49.305  1
137777  95.907  -77.615  49.273  1
137778  95.923  -77.627  49.241  1
137779  95.939  -77.637  49.209  1
137780  95.954  -77.649  49.174  1
137781  95.977  -77.658  49.137  1
137782  95.987  -77.667  49.100  1
137783  95.997  -77.678  49.062  1
137784  96.007  -77.688  49.025  1
137785  96.017  -77.698  48.989  1
137786  96.027  -77.708  48.954  1
137787  96.037  -77.718  48.918  1
137788  96.046  -77.728  48.882  1
137789  96.056  -77.738  48.846  1
137790  96.066  -77.748  48.810  1
137791  96.076  -77.758  48.776  1
137792  96.086  -77.768  48.741  1
137793  96.096  -77.778  48.707  1
137794  96.109  -77.790  48.673  1
137795  96.124  -77.801  48.639  1
137796  96.138  -77.812  48.605  1
137797  96.153  -77.824  48.570  1
137798  96.167  -77.836  48.537  1
137799  96.181  -77.847  48.505  1
137800  96.195  -77.859  48.474  1
137801  96.209  -77.870  48.443  1
137802  96.209  -77.863  48.412  1
137803  96.208  -77.855  48.382  1
137804  96.207  -77.848  48.351  1
137805  96.206  -77.840  48.324  1
137806  96.213  -77.836  48.298  1
137807  96.221  -77.833  48.271  1
137808  96.229  -77.830  48.245  1
137809  96.237  -77.827  48.219  1
137810  96.251  -77.823  48.194  1
137811  96.272  -77.818  48.169  1
137812  96.294  -77.815  48.146  1
137813  96.313  -77.812  48.124  1
137814  96.320  -77.817  48.102  1
137815  96.326  -77.822  48.078  1
137816  96.332  -77.827  48.056  1
137817  96.338  -77.833  48.033  1
137818  96.356  -77.844  48.010  1
137819  96.374  -77.856  47.987  1
137820  96.391  -77.868  47.966  1
137821  96.409  -77.881  47.944  1
137822  96.428  -77.893  47.922  1
137823  96.449  -77.904  47.900  1
137824  96.477  -77.912  47.876  1
137825  96.506  -77.918  47.852  1
137826  96.534  -77.926  47.828  1
137827  96.556  -77.929  47.802  1
137828  96.565  -77.929  47.777  1
137829  96.571  -77.927  47.752  1
137830  96.576  -77.924  47.726  1
137831  96.584  -77.922  47.699  1
137832  96.591  -77.921  47.673  1
137833  96.599  -77.919  47.648  1
137834  96.607  -77.917  47.624  1
137835  96.614  -77.915  47.599  1
137836  96.622  -77.914  47.575  1
137837  96.630  -77.912  47.551  1
137838  96.638  -77.910  47.526  1
137839  96.645  -77.908  47.501  1
137840  96.655  -77.909  47.477  1
137841  96.676  -77.922  47.452  1
137842  96.729  -77.941  47.428  1
137843  96.783  -77.959  47.404  1
137844  96.835  -77.978  47.379  1
137845  96.889  -77.996  47.354  1
137846  96.899  -78.009  47.330  1
137847  96.898  -78.022  47.305  1
137848  96.899  -78.037  47.281  1
137849  96.900  -78.051  47.258  1
137850  96.901  -78.065  47.234  1
137851  96.902  -78.080  47.210  1
137852  96.924  -78.087  47.188  1
137853  96.947  -78.094  47.166  1
137854  96.954  -78.086  47.144  1
137855  96.967  -78.083  47.121  1
137856  96.987  -78.087  47.100  1
137857  97.008  -78.093  47.079  1
137858  97.028  -78.100  47.060  1
137859  97.044  -78.112  47.041  1
137860  97.061  -78.124  47.023  1
137861  97.078  -78.136  47.006  1
137862  97.094  -78.148  46.989  1
137863  97.111  -78.160  46.974  1
137864  97.127  -78.172  46.960  1
137865  97.148  -78.174  46.947  1
137866  97.176  -78.155  46.934  1
137867  97.204  -78.135  46.923  1
137868  97.231  -78.116  46.913  1
137869  97.252  -78.103  46.904  1
137870  97.273  -78.103  46.893  1
137871  97.306  -78.109  46.882  1
137872  97.338  -78.116  46.870  1
137873  97.371  -78.122  46.857  1
137874  97.404  -78.128  46.844  1
137875  97.437  -78.134  46.830  1
137876  97.469  -78.140  46.816  1
137877  97.502  -78.146  46.800  1
137878  97.535  -78.153  46.785  1
137879  97.568  -78.160  46.769  1
137880  97.601  -78.168  46.753  1
137881  97.636  -78.173  46.737  1
137882  97.676  -78.175  46.721  1
137883  97.717  -78.177  46.704  1
137884  97.757  -78.178  46.687  1
137885  97.788  -78.193  46.671  1
137886  97.807  -78.206  46.654  1
137887  97.822  -78.209  46.636  1
137888  97.837  -78.213  46.616  1
137889  97.858  -78.202  46.596  1
137890  97.891  -78.159  46.576  1
137891  97.911  -78.149  46.556  1
137892  97.927  -78.144  46.535  1
137893  97.944  -78.141  46.514  1
137894  97.959  -78.142  46.493  1
137895  97.986  -78.147  46.472  1
137896  97.994  -78.189  46.451  1
137897  98.000  -78.237  46.431  1
137898  98.028  -78.242  46.409  1
137899  98.056  -78.248  46.388  1
137900  98.094  -78.255  46.366  1
137901  98.134  -78.263  46.344  1
137902  98.173  -78.269  46.322  1
137903  98.203  -78.298  46.300  1
137904  98.219  -78.357  46.279  1
137905  98.235  -78.416  46.258  1
137906  98.238  -78.449  46.237  1
137907  98.227  -78.447  46.217  1
137908  98.228  -78.434  46.197  1
137909  98.229  -78.421  46.177  1
137910  98.231  -78.408  46.159  1
137911  98.255  -78.398  46.140  1
137912  98.279  -78.389  46.121  1
137913  98.302  -78.380  46.101  1
137914  98.326  -78.370  46.079  1
137915  98.350  -78.361  46.057  1
137916  98.402  -78.341  46.036  1
137917  98.400  -78.322  46.015  1
137918  98.398  -78.303  45.993  1
137919  98.402  -78.281  45.971  1
137920  98.416  -78.280  45.948  1
137921  98.430  -78.279  45.924  1
137922  98.444  -78.279  45.901  1
137923  98.458  -78.279  45.877  1
137924  98.472  -78.278  45.853  1
137925  98.486  -78.277  45.830  1
137926  98.500  -78.276  45.807  1
137927  98.514  -78.276  45.783  1
137928  98.525  -78.269  45.759  1
137929  98.554  -78.277  45.736  1
137930  98.585  -78.283  45.713  1
137931  98.623  -78.283  45.693  1
137932  98.652  -78.252  45.672  1
137933  98.687  -78.184  45.653  1
137934  98.727  -78.116  45.634  1
137935  98.746  -78.143  45.618  1
137936  98.773  -78.159  45.602  1
137937  98.800  -78.176  45.586  1
137938  98.826  -78.193  45.569  1
137939  98.853  -78.215  45.551  1
137940  98.879  -78.241  45.534  1
137941  98.905  -78.266  45.518  1
137942  98.923  -78.281  45.504  1
137943  98.941  -78.305  45.490  1
137944  98.959  -78.329  45.477  1
137945  98.978  -78.354  45.464  1
137946  98.999  -78.378  45.449  1
137947  99.022  -78.402  45.434  1
137948  99.044  -78.426  45.420  1
137949  99.067  -78.450  45.407  1
137950  99.087  -78.458  45.394  1
137951  99.108  -78.458  45.382  1
137952  99.144  -78.451  45.368  1
137953  99.181  -78.443  45.356  1
137954  99.217  -78.435  45.344  1
137955  99.253  -78.428  45.333  1
137956  99.280  -78.422  45.320  1
137957  99.308  -78.416  45.307  1
137958  99.335  -78.410  45.294  1
137959  99.363  -78.403  45.280  1
137960  99.390  -78.397  45.267  1
137961  99.418  -78.391  45.252  1
137962  99.445  -78.385  45.238  1
137963  99.464  -78.396  45.225  1
137964  99.478  -78.415  45.214  1
137965  99.521  -78.454  45.201  1
137966  99.559  -78.496  45.188  1
137967  99.597  -78.538  45.174  1
137968  99.635  -78.565  45.160  1
137969  99.673  -78.586  45.145  1
137970  99.710  -78.606  45.130  1
137971  99.748  -78.626  45.116  1
137972  99.797  -78.655  45.102  1
137973  99.804  -78.662  45.089  1
137974  99.810  -78.670  45.077  1
137975  99.817  -78.677  45.063  1
137976  99.824  -78.685  45.050  1
137977  99.874  -78.724  45.038  1
137978  99.917  -78.756  45.027  1
137979  99.939  -78.771  45.015  1
137980  99.959  -78.786  45.003  1
137981  99.975  -78.801  44.990  1
137982  99.991  -78.815  44.980  1
137983  100.007  -78.830  44.969  1
137984  100.022  -78.845  44.958  1
137985  100.021  -78.871  44.948  1
137986  100.022  -78.888  44.938  1
137987  100.027  -78.869  44.927  1
137988  100.032  -78.851  44.917  1
137989  100.039  -78.833  44.906  1
137990  100.064  -78.846  44.897  1
137991  100.089  -78.858  44.888  1
137992  100.115  -78.870  44.879  1
137993  100.141  -78.882  44.870  1
137994  100.167  -78.894  44.860  1
137995  100.192  -78.906  44.850  1
137996  100.231  -78.921  44.841  1
137997  100.277  -78.936  44.831  1
137998  100.308  -78.949  44.822  1
137999  100.318  -78.959  44.810  1
138000  100.328  -78.976  44.799  1
138001  100.338  -78.995  44.788  1
138002  100.352  -79.009  44.776  1
138003  100.382  -79.027  44.764  1
138004  100.414  -79.046  44.751  1
138005  100.446  -79.065  44.738  1
138006  100.479  -79.084  44.724  1
138007  100.511  -79.103  44.711  1
138008  100.544  -79.122  44.698  1
138009  100.576  -79.141  44.684  1
138010  100.609  -79.160  44.669  1
138011  100.641  -79.179  44.655  1
138265  92.928  -78.210  54.229  1
138266  92.942  -78.206  54.222  1
138267  92.955  -78.201  54.217  1
138268  92.969  -78.197  54.212  1
138269  92.983  -78.191  54.207  1
138270  92.997  -78.187  54.201  1
138271  93.010  -78.182  54.194  1
138272  93.024  -78.177  54.187  1
138273  93.038  -78.172  54.181  1
138274  93.051  -78.168  54.175  1
138275  93.065  -78.163  54.169  1
138276  93.079  -78.154  54.163  1
138277  93.093  -78.142  54.157  1
138278  93.107  -78.130  54.150  1
138279  93.121  -78.118  54.142  1
138280  93.142  -78.106  54.135  1
138281  93.165  -78.094  54.128  1
138282  93.189  -78.082  54.121  1
138283  93.213  -78.070  54.115  1
138284  93.236  -78.059  54.108  1
138285  93.260  -78.047  54.099  1
138286  93.284  -78.034  54.092  1
138287  93.307  -78.023  54.086  1
138288  93.331  -78.011  54.079  1
138289  93.355  -77.999  54.071  1
138290  93.378  -77.987  54.064  1
138291  93.402  -77.975  54.055  1
138292  93.412  -77.964  54.044  1
138293  93.422  -77.949  54.032  1
138294  93.432  -77.933  54.019  1
138295  93.443  -77.918  54.006  1
138296  93.452  -77.903  53.994  1
138297  93.461  -77.891  53.980  1
138298  93.471  -77.878  53.963  1
138299  93.480  -77.866  53.946  1
138300  93.491  -77.859  53.929  1
138301  93.502  -77.850  53.912  1
138302  93.513  -77.842  53.897  1
138303  93.524  -77.834  53.881  1
138304  93.535  -77.825  53.866  1
138305  93.546  -77.818  53.850  1
138306  93.557  -77.809  53.832  1
138307  93.568  -77.801  53.814  1
138308  93.579  -77.793  53.796  1
138309  93.590  -77.785  53.778  1
138310  93.601  -77.777  53.761  1
138311  93.609  -77.759  53.743  1
138312  93.626  -77.760  53.724  1
138313  93.638  -77.752  53.705  1
138314  93.649  -77.748  53.686  1
138315  93.660  -77.743  53.667  1
138316  93.671  -77.738  53.649  1
138317  93.681  -77.733  53.631  1
138318  93.692  -77.728  53.613  1
138319  93.703  -77.723  53.593  1
138320  93.713  -77.718  53.573  1
138321  93.724  -77.714  53.554  1
138322  93.735  -77.708  53.535  1
138323  93.746  -77.704  53.517  1
138326  93.778  -77.689  53.463  1
138327  93.789  -77.684  53.444  1
138328  93.799  -77.680  53.426  1
138329  93.810  -77.674  53.408  1
138330  93.821  -77.670  53.391  1
138331  93.832  -77.664  53.374  1
138332  93.842  -77.660  53.358  1
138333  93.853  -77.655  53.341  1
138334  93.864  -77.650  53.323  1
138335  93.876  -77.646  53.305  1
138336  93.891  -77.642  53.288  1
138337  93.904  -77.638  53.271  1
138338  93.918  -77.634  53.254  1
138339  93.932  -77.630  53.236  1
138340  93.946  -77.626  53.217  1
138341  93.960  -77.622  53.199  1
138342  93.966  -77.623  53.181  1
138343  93.971  -77.624  53.163  1
138344  93.975  -77.625  53.145  1
138345  93.980  -77.627  53.128  1
138346  93.988  -77.624  53.109  1
138347  94.003  -77.611  53.090  1
138348  94.018  -77.599  53.071  1
138349  94.034  -77.586  53.053  1
138350  94.053  -77.575  53.035  1
138351  94.072  -77.564  53.018  1
138352  94.083  -77.555  53.002  1
138353  94.088  -77.547  52.985  1
138354  94.092  -77.539  52.969  1
138355  94.097  -77.530  52.951  1
138356  94.102  -77.521  52.934  1
138357  94.106  -77.513  52.916  1
138358  94.108  -77.506  52.898  1
138359  94.106  -77.501  52.882  1
138360  94.099  -77.512  52.867  1
138361  94.104  -77.523  52.852  1
138362  94.113  -77.559  52.836  1
138363  94.143  -77.548  52.818  1
138364  94.168  -77.537  52.798  1
138365  94.178  -77.539  52.779  1
138366  94.187  -77.539  52.763  1
138367  94.195  -77.542  52.748  1
138368  94.146  -77.567  52.733  1
138369  94.150  -77.538  52.720  1
138370  94.191  -77.519  52.708  1
138371  94.231  -77.500  52.696  1
138372  94.240  -77.498  52.687  1
138373  94.228  -77.505  52.684  1
138374  94.214  -77.526  52.682  1
138375  94.228  -77.532  52.681  1
138376  94.264  -77.520  52.680  1
138377  94.311  -77.506  52.677  1
138378  94.358  -77.492  52.674  1
138379  94.405  -77.478  52.672  1
138380  94.452  -77.464  52.669  1
138381  94.481  -77.451  52.663  1
138382  94.474  -77.441  52.654  1
138383  94.466  -77.432  52.645  1
138384  94.459  -77.422  52.637  1
138385  94.452  -77.412  52.629  1
138386  94.445  -77.402  52.621  1
138387  94.437  -77.393  52.612  1
138388  94.430  -77.383  52.600  1
138389  94.435  -77.409  52.583  1
138390  94.461  -77.433  52.560  1
138391  94.487  -77.458  52.531  1
138392  94.510  -77.471  52.499  1
138393  94.527  -77.466  52.466  1
138394  94.543  -77.460  52.435  1
138395  94.560  -77.454  52.405  1
138396  94.577  -77.448  52.375  1
138397  94.594  -77.442  52.345  1
138398  94.619  -77.454  52.311  1
138399  94.661  -77.501  52.278  1
138400  94.709  -77.519  52.245  1
138401  94.758  -77.538  52.208  1
138402  94.806  -77.556  52.169  1
138403  94.854  -77.575  52.129  1
138404  94.903  -77.593  52.087  1
138405  94.948  -77.610  52.046  1
138406  94.981  -77.617  52.008  1
138407  95.014  -77.624  51.971  1
138408  95.046  -77.631  51.936  1
138409  95.042  -77.599  51.900  1
138410  95.026  -77.558  51.865  1
138411  95.009  -77.516  51.829  1
138412  94.993  -77.474  51.791  1
138413  94.966  -77.441  51.753  1
138414  94.931  -77.415  51.715  1
138415  94.948  -77.427  51.680  1
138416  94.963  -77.363  51.643  1
138417  95.041  -77.312  51.606  1
138418  95.088  -77.287  51.569  1
138419  95.075  -77.313  51.530  1
138420  95.063  -77.338  51.495  1
138421  95.050  -77.363  51.460  1
138422  95.038  -77.388  51.425  1
138423  95.025  -77.413  51.381  1
138424  95.032  -77.429  51.331  1
138425  95.083  -77.448  51.277  1
138426  95.140  -77.468  51.218  1
138427  95.195  -77.488  51.160  1
138428  95.217  -77.491  51.107  1
138429  95.237  -77.490  51.057  1
138430  95.245  -77.471  51.008  1
138431  95.252  -77.453  50.963  1
138432  95.273  -77.451  50.919  1
138433  95.295  -77.452  50.876  1
138434  95.316  -77.452  50.833  1
138435  95.338  -77.453  50.792  1
138436  95.360  -77.454  50.753  1
138437  95.382  -77.454  50.718  1
138438  95.412  -77.454  50.687  1
138439  95.444  -77.454  50.657  1
138440  95.476  -77.455  50.629  1
138441  95.508  -77.455  50.595  1
138442  95.540  -77.455  50.559  1
138443  95.565  -77.451  50.522  1
138444  95.581  -77.442  50.484  1
138445  95.596  -77.433  50.445  1
138446  95.640  -77.446  50.406  1
138447  95.692  -77.464  50.368  1
138448  95.716  -77.480  50.328  1
138449  95.714  -77.495  50.286  1
138450  95.714  -77.509  50.244  1
138451  95.713  -77.523  50.200  1
138452  95.712  -77.538  50.160  1
138453  95.711  -77.552  50.119  1
138454  95.711  -77.567  50.077  1
138455  95.710  -77.582  50.035  1
138456  95.709  -77.596  49.995  1
138457  95.706  -77.610  49.956  1
138458  95.678  -77.616  49.918  1
138459  95.680  -77.620  49.881  1
138460  95.683  -77.624  49.845  1
138461  95.693  -77.624  49.811  1
138462  95.703  -77.624  49.777  1
138463  95.714  -77.624  49.745  1
138464  95.729  -77.623  49.713  1
138465  95.743  -77.620  49.680  1
138466  95.757  -77.619  49.647  1
138467  95.771  -77.617  49.616  1
138468  95.785  -77.616  49.584  1
138469  95.800  -77.614  49.551  1
138470  95.814  -77.613  49.519  1
138471  95.828  -77.611  49.489  1
138472  95.842  -77.609  49.460  1
138473  95.856  -77.608  49.431  1
138474  95.871  -77.606  49.403  1
138475  95.885  -77.605  49.374  1
138476  95.899  -77.603  49.345  1
138477  95.913  -77.601  49.315  1
138478  95.928  -77.610  49.284  1
138479  95.944  -77.620  49.253  1
138480  95.959  -77.631  49.219  1
138481  95.968  -77.645  49.183  1
138482  95.978  -77.655  49.147  1
138483  95.989  -77.664  49.110  1
138484  96.000  -77.674  49.072  1
138485  96.010  -77.684  49.037  1
138486  96.020  -77.694  49.002  1
138487  96.031  -77.704  48.967  1
138488  96.041  -77.714  48.931  1
138489  96.051  -77.724  48.896  1
138490  96.061  -77.733  48.861  1
138491  96.072  -77.744  48.825  1
138492  96.082  -77.754  48.790  1
138493  96.093  -77.764  48.756  1
138494  96.096  -77.773  48.722  1
138495  96.109  -77.782  48.688  1
138496  96.122  -77.791  48.653  1
138497  96.136  -77.801  48.618  1
138498  96.150  -77.813  48.583  1
138499  96.165  -77.824  48.551  1
138500  96.179  -77.836  48.519  1
138501  96.193  -77.847  48.487  1
138502  96.207  -77.859  48.456  1
138503  96.211  -77.857  48.425  1
138504  96.210  -77.849  48.394  1
138505  96.209  -77.842  48.363  1
138506  96.215  -77.837  48.336  1
138507  96.223  -77.834  48.309  1
138508  96.231  -77.831  48.283  1
138509  96.239  -77.827  48.257  1
138510  96.247  -77.824  48.231  1
138511  96.264  -77.821  48.205  1
138512  96.285  -77.817  48.181  1
138513  96.306  -77.812  48.157  1
138514  96.318  -77.815  48.135  1
138515  96.324  -77.820  48.112  1
138516  96.330  -77.825  48.090  1
138517  96.337  -77.830  48.067  1
138518  96.343  -77.836  48.043  1
138519  96.359  -77.846  48.020  1
138520  96.376  -77.859  47.998  1
138521  96.394  -77.871  47.976  1
138522  96.412  -77.884  47.954  1
138523  96.430  -77.896  47.932  1
138524  96.456  -77.904  47.908  1
138525  96.484  -77.912  47.884  1
138526  96.513  -77.918  47.859  1
138527  96.538  -77.924  47.835  1
138528  96.556  -77.920  47.812  1
138529  96.573  -77.921  47.787  1
138530  96.592  -77.928  47.762  1
138531  96.602  -77.930  47.736  1
138532  96.608  -77.928  47.710  1
138533  96.614  -77.925  47.684  1
138534  96.619  -77.923  47.658  1
138535  96.625  -77.921  47.634  1
138536  96.631  -77.918  47.609  1
138537  96.637  -77.916  47.585  1
138538  96.643  -77.914  47.561  1
138539  96.648  -77.912  47.537  1
138540  96.654  -77.909  47.512  1
138541  96.660  -77.907  47.488  1
138542  96.691  -77.915  47.463  1
138543  96.744  -77.933  47.439  1
138544  96.797  -77.951  47.414  1
138545  96.850  -77.970  47.390  1
138546  96.903  -77.988  47.365  1
138547  96.907  -78.002  47.341  1
138548  96.907  -78.016  47.317  1
138549  96.908  -78.031  47.294  1
138550  96.909  -78.046  47.270  1
138551  96.910  -78.060  47.247  1
138552  96.911  -78.075  47.224  1
138553  96.935  -78.081  47.202  1
138554  96.951  -78.082  47.180  1
138555  96.959  -78.075  47.158  1
138556  96.971  -78.071  47.136  1
138557  96.992  -78.075  47.114  1
138558  97.013  -78.081  47.093  1
138559  97.033  -78.085  47.074  1
138560  97.052  -78.094  47.055  1
138561  97.069  -78.106  47.036  1
138562  97.085  -78.119  47.019  1
138563  97.102  -78.131  47.002  1
138564  97.118  -78.143  46.986  1
138565  97.135  -78.155  46.972  1
138566  97.159  -78.147  46.958  1
138567  97.186  -78.128  46.945  1
138568  97.214  -78.109  46.935  1
138569  97.238  -78.094  46.925  1
138570  97.246  -78.090  46.917  1
138571  97.257  -78.086  46.909  1
138572  97.290  -78.092  46.898  1
138573  97.323  -78.098  46.887  1
138574  97.356  -78.104  46.874  1
138575  97.388  -78.110  46.861  1
138576  97.421  -78.116  46.847  1
138577  97.454  -78.122  46.833  1
138578  97.487  -78.129  46.818  1
138579  97.520  -78.137  46.803  1
138580  97.553  -78.144  46.789  1
138581  97.586  -78.151  46.773  1
138582  97.623  -78.156  46.758  1
138583  97.663  -78.157  46.742  1
138584  97.703  -78.159  46.725  1
138585  97.739  -78.166  46.708  1
138586  97.764  -78.191  46.692  1
138587  97.783  -78.204  46.675  1
138588  97.798  -78.207  46.656  1
138589  97.812  -78.211  46.637  1
138590  97.827  -78.214  46.617  1
138591  97.842  -78.218  46.597  1
138592  97.857  -78.221  46.575  1
138593  97.891  -78.178  46.554  1
138594  97.925  -78.135  46.532  1
138595  97.946  -78.128  46.511  1
138596  97.942  -78.194  46.490  1
138597  97.951  -78.235  46.469  1
138598  97.980  -78.241  46.449  1
138599  98.020  -78.248  46.427  1
138600  98.059  -78.255  46.405  1
138601  98.098  -78.263  46.382  1
138602  98.138  -78.269  46.359  1
138603  98.177  -78.276  46.337  1
138604  98.210  -78.300  46.315  1
138605  98.226  -78.358  46.293  1
138606  98.242  -78.416  46.272  1
138607  98.238  -78.436  46.251  1
138608  98.224  -78.436  46.230  1
138609  98.210  -78.436  46.209  1
138610  98.208  -78.428  46.188  1
138611  98.231  -78.418  46.170  1
138612  98.255  -78.409  46.151  1
138613  98.279  -78.399  46.131  1
138614  98.302  -78.390  46.110  1
138615  98.326  -78.380  46.089  1
138616  98.350  -78.371  46.067  1
138617  98.374  -78.356  46.047  1
138618  98.372  -78.330  46.026  1
138619  98.371  -78.297  46.005  1
138620  98.425  -78.272  45.983  1
138621  98.441  -78.270  45.961  1
138622  98.455  -78.269  45.937  1
138623  98.469  -78.269  45.913  1
138624  98.483  -78.269  45.889  1
138625  98.497  -78.268  45.865  1
138626  98.511  -78.267  45.842  1
138627  98.525  -78.266  45.818  1
138628  98.538  -78.260  45.795  1
138629  98.548  -78.244  45.771  1
138630  98.560  -78.244  45.747  1
138631  98.589  -78.252  45.725  1
138632  98.618  -78.260  45.705  1
138633  98.654  -78.256  45.685  1
138634  98.695  -78.188  45.665  1
138635  98.733  -78.130  45.646  1
138636  98.745  -78.167  45.630  1
138637  98.770  -78.185  45.615  1
138638  98.797  -78.202  45.599  1
138639  98.823  -78.219  45.583  1
138640  98.850  -78.235  45.565  1
138641  98.876  -78.252  45.548  1
138642  98.903  -78.269  45.531  1
138643  98.937  -78.279  45.516  1
138644  98.968  -78.294  45.502  1
138645  98.990  -78.318  45.488  1
138646  99.012  -78.342  45.475  1
138647  99.034  -78.366  45.460  1
138648  99.057  -78.390  45.446  1
138649  99.079  -78.414  45.431  1
138650  99.100  -78.431  45.418  1
138651  99.120  -78.432  45.406  1
138652  99.139  -78.432  45.394  1
138653  99.158  -78.432  45.382  1
138654  99.192  -78.426  45.370  1
138655  99.228  -78.419  45.358  1
138656  99.261  -78.411  45.346  1
138657  99.289  -78.405  45.332  1
138658  99.316  -78.399  45.319  1
138659  99.344  -78.393  45.306  1
138660  99.371  -78.387  45.292  1
138661  99.399  -78.380  45.279  1
138662  99.426  -78.374  45.265  1
138663  99.456  -78.373  45.252  1
138664  99.487  -78.375  45.239  1
138665  99.518  -78.382  45.227  1
138666  99.560  -78.416  45.215  1
138667  99.603  -78.451  45.202  1
138668  99.645  -78.487  45.190  1
138669  99.688  -78.523  45.176  1
138670  99.727  -78.563  45.162  1
138671  99.766  -78.604  45.147  1
138672  99.803  -78.630  45.133  1
138673  99.824  -78.643  45.119  1
138674  99.830  -78.651  45.106  1
138675  99.837  -78.658  45.093  1
138676  99.843  -78.666  45.079  1
138677  99.850  -78.673  45.066  1
138678  99.861  -78.684  45.053  1
138679  99.912  -78.723  45.040  1
138680  99.934  -78.738  45.029  1
138681  99.950  -78.752  45.017  1
138682  99.967  -78.767  45.005  1
138683  99.982  -78.782  44.994  1
138684  99.998  -78.797  44.983  1
138685  100.014  -78.811  44.972  1
138686  100.030  -78.826  44.961  1
138687  100.032  -78.850  44.951  1
138688  100.034  -78.855  44.941  1
138689  100.040  -78.836  44.930  1
138690  100.047  -78.822  44.920  1
138691  100.073  -78.834  44.911  1
138692  100.099  -78.846  44.901  1
138693  100.124  -78.858  44.892  1
138694  100.149  -78.871  44.882  1
138695  100.183  -78.883  44.871  1
138696  100.228  -78.899  44.861  1
138697  100.274  -78.914  44.851  1
138698  100.307  -78.927  44.841  1
138699  100.317  -78.938  44.830  1
138700  100.327  -78.949  44.818  1
138701  100.337  -78.968  44.806  1
138702  100.348  -78.987  44.794  1
138703  100.360  -79.004  44.782  1
138704  100.379  -79.016  44.769  1
138705  100.412  -79.035  44.756  1
138706  100.444  -79.055  44.742  1
138707  100.477  -79.074  44.728  1
138708  100.509  -79.093  44.715  1
138709  100.542  -79.112  44.701  1
138710  100.574  -79.131  44.686  1
138711  100.607  -79.150  44.671  1
138712  100.639  -79.169  44.656  1
138966  92.927  -78.197  54.233  1
138967  92.941  -78.192  54.227  1
138968  92.955  -78.187  54.222  1
138969  92.969  -78.182  54.217  1
138970  92.982  -78.178  54.212  1
138971  92.996  -78.173  54.207  1
138972  93.009  -78.168  54.200  1
138973  93.023  -78.163  54.193  1
138974  93.037  -78.159  54.187  1
138975  93.051  -78.153  54.181  1
138976  93.064  -78.149  54.175  1
138977  93.078  -78.144  54.169  1
138978  93.092  -78.132  54.163  1
138979  93.106  -78.120  54.156  1
138980  93.120  -78.107  54.149  1
138981  93.141  -78.096  54.142  1
138982  93.165  -78.084  54.135  1
138983  93.189  -78.072  54.129  1
138984  93.212  -78.060  54.123  1
138985  93.236  -78.048  54.116  1
138986  93.260  -78.036  54.107  1
138987  93.283  -78.025  54.101  1
138988  93.307  -78.012  54.095  1
138989  93.331  -78.000  54.089  1
138990  93.354  -77.989  54.082  1
138991  93.377  -77.977  54.075  1
138992  93.400  -77.962  54.066  1
138993  93.408  -77.957  54.056  1
138994  93.416  -77.945  54.044  1
138995  93.424  -77.932  54.033  1
138996  93.432  -77.920  54.021  1
138997  93.440  -77.908  54.009  1
138998  93.448  -77.896  53.994  1
138999  93.466  -77.884  53.978  1
139000  93.473  -77.868  53.961  1
139001  93.481  -77.852  53.945  1
139002  93.490  -77.839  53.928  1
139003  93.501  -77.830  53.912  1
139004  93.512  -77.823  53.897  1
139005  93.523  -77.815  53.882  1
139006  93.534  -77.806  53.866  1
139007  93.545  -77.798  53.848  1
139008  93.556  -77.790  53.831  1
139009  93.567  -77.782  53.811  1
139010  93.576  -77.771  53.793  1
139011  93.580  -77.743  53.775  1
139012  93.599  -77.745  53.757  1
139013  93.617  -77.748  53.738  1
139014  93.632  -77.738  53.719  1
139015  93.641  -77.734  53.700  1
139016  93.652  -77.729  53.680  1
139017  93.663  -77.724  53.662  1
139018  93.674  -77.719  53.644  1
139019  93.684  -77.714  53.626  1
139020  93.695  -77.710  53.607  1
139021  93.706  -77.705  53.588  1
139022  93.716  -77.700  53.569  1
139023  93.727  -77.695  53.550  1
139024  93.738  -77.690  53.532  1
139025  93.749  -77.686  53.514  1
139026  93.760  -77.680  53.496  1
139027  93.770  -77.676  53.478  1
139028  93.781  -77.671  53.460  1
139029  93.792  -77.666  53.442  1
139030  93.802  -77.661  53.424  1
139031  93.814  -77.656  53.407  1
139032  93.824  -77.652  53.390  1
139033  93.835  -77.646  53.373  1
139034  93.846  -77.642  53.355  1
139035  93.857  -77.637  53.338  1
139036  93.871  -77.633  53.321  1
139037  93.885  -77.629  53.303  1
139038  93.899  -77.625  53.286  1
139039  93.913  -77.621  53.268  1
139040  93.927  -77.617  53.250  1
139041  93.940  -77.613  53.231  1
139042  93.955  -77.609  53.213  1
139043  93.962  -77.609  53.196  1
139044  93.966  -77.610  53.178  1
139045  93.971  -77.611  53.160  1
139046  93.976  -77.613  53.142  1
139047  93.990  -77.602  53.123  1
139048  94.005  -77.589  53.105  1
139049  94.020  -77.577  53.086  1
139050  94.035  -77.564  53.068  1
139051  94.055  -77.552  53.050  1
139052  94.068  -77.543  53.032  1
139053  94.077  -77.535  53.015  1
139054  94.082  -77.526  52.999  1
139055  94.086  -77.518  52.981  1
139056  94.091  -77.510  52.964  1
139057  94.096  -77.501  52.948  1
139058  94.100  -77.492  52.932  1
139059  94.105  -77.484  52.916  1
139060  94.112  -77.476  52.901  1
139061  94.140  -77.476  52.887  1
139062  94.128  -77.500  52.873  1
139063  94.133  -77.520  52.859  1
139064  94.148  -77.535  52.842  1
139065  94.163  -77.532  52.823  1
139066  94.179  -77.531  52.804  1
139067  94.198  -77.529  52.788  1
139068  94.188  -77.534  52.773  1
139069  94.155  -77.530  52.760  1
139070  94.133  -77.530  52.749  1
139071  94.165  -77.503  52.737  1
139072  94.206  -77.484  52.725  1
139073  94.240  -77.468  52.714  1
139074  94.227  -77.486  52.707  1
139075  94.213  -77.514  52.704  1
139076  94.218  -77.528  52.702  1
139077  94.265  -77.514  52.703  1
139078  94.312  -77.499  52.702  1
139079  94.359  -77.485  52.700  1
139080  94.406  -77.471  52.699  1
139081  94.453  -77.457  52.696  1
139082  94.465  -77.445  52.691  1
139083  94.458  -77.436  52.684  1
139084  94.451  -77.426  52.676  1
139085  94.443  -77.417  52.668  1
139086  94.435  -77.407  52.659  1
139087  94.428  -77.397  52.650  1
139088  94.421  -77.387  52.642  1
139089  94.415  -77.375  52.628  1
139090  94.427  -77.370  52.610  1
139091  94.455  -77.385  52.586  1
139092  94.481  -77.410  52.556  1
139093  94.507  -77.435  52.525  1
139094  94.531  -77.452  52.493  1
139095  94.548  -77.446  52.465  1
139096  94.564  -77.441  52.436  1
139097  94.581  -77.435  52.407  1
139098  94.598  -77.429  52.376  1
139099  94.628  -77.452  52.343  1
139100  94.670  -77.501  52.310  1
139101  94.718  -77.521  52.276  1
139102  94.767  -77.540  52.239  1
139103  94.815  -77.558  52.199  1
139104  94.863  -77.577  52.157  1
139105  94.906  -77.591  52.116  1
139106  94.938  -77.599  52.078  1
139107  94.971  -77.606  52.041  1
139108  95.005  -77.603  52.005  1
139109  95.036  -77.598  51.969  1
139110  95.046  -77.581  51.934  1
139111  95.030  -77.539  51.899  1
139112  95.013  -77.497  51.862  1
139113  94.996  -77.455  51.824  1
139114  94.970  -77.422  51.786  1
139115  94.939  -77.395  51.748  1
139116  94.939  -77.357  51.713  1
139117  95.068  -77.367  51.675  1
139118  95.100  -77.276  51.637  1
139119  95.068  -77.246  51.599  1
139120  95.055  -77.273  51.562  1
139121  95.042  -77.299  51.527  1
139122  95.029  -77.325  51.493  1
139123  95.017  -77.351  51.458  1
139124  95.003  -77.378  51.414  1
139125  95.006  -77.386  51.365  1
139126  95.060  -77.404  51.312  1
139127  95.117  -77.424  51.253  1
139128  95.174  -77.444  51.193  1
139129  95.220  -77.459  51.137  1
139130  95.238  -77.455  51.086  1
139131  95.247  -77.439  51.037  1
139132  95.269  -77.439  50.990  1
139133  95.290  -77.440  50.945  1
139134  95.313  -77.441  50.903  1
139135  95.334  -77.442  50.858  1
139136  95.356  -77.442  50.814  1
139137  95.378  -77.442  50.773  1
139138  95.400  -77.443  50.737  1
139139  95.422  -77.444  50.704  1
139140  95.452  -77.444  50.674  1
139141  95.484  -77.444  50.645  1
139142  95.516  -77.444  50.612  1
139143  95.548  -77.445  50.577  1
139144  95.573  -77.441  50.542  1
139145  95.589  -77.432  50.504  1
139146  95.612  -77.429  50.467  1
139147  95.664  -77.447  50.431  1
139148  95.697  -77.464  50.394  1
139149  95.696  -77.478  50.355  1
139150  95.695  -77.492  50.314  1
139151  95.695  -77.507  50.271  1
139152  95.694  -77.521  50.227  1
139153  95.693  -77.536  50.186  1
139154  95.692  -77.551  50.145  1
139155  95.692  -77.565  50.104  1
139156  95.691  -77.580  50.059  1
139157  95.690  -77.594  50.017  1
139158  95.690  -77.608  49.977  1
139159  95.676  -77.620  49.937  1
139160  95.682  -77.621  49.899  1
139161  95.692  -77.622  49.862  1
139162  95.706  -77.620  49.827  1
139163  95.721  -77.618  49.792  1
139164  95.735  -77.617  49.759  1
139165  95.749  -77.615  49.726  1
139166  95.763  -77.614  49.693  1
139167  95.777  -77.612  49.660  1
139168  95.792  -77.610  49.627  1
139169  95.806  -77.608  49.595  1
139170  95.820  -77.607  49.561  1
139171  95.834  -77.605  49.529  1
139172  95.848  -77.604  49.499  1
139173  95.863  -77.602  49.469  1
139174  95.877  -77.600  49.439  1
139175  95.891  -77.599  49.409  1
139176  95.905  -77.597  49.379  1
139177  95.919  -77.595  49.350  1
139178  95.934  -77.594  49.319  1
139179  95.949  -77.604  49.290  1
139180  95.964  -77.614  49.260  1
139181  95.970  -77.630  49.227  1
139182  95.970  -77.649  49.191  1
139183  95.983  -77.655  49.155  1
139184  95.996  -77.662  49.119  1
139185  96.008  -77.670  49.083  1
139186  96.018  -77.680  49.048  1
139187  96.028  -77.689  49.013  1
139188  96.039  -77.700  48.979  1
139189  96.049  -77.710  48.944  1
139190  96.059  -77.720  48.910  1
139191  96.070  -77.730  48.875  1
139192  96.080  -77.740  48.839  1
139193  96.090  -77.749  48.805  1
139194  96.093  -77.758  48.771  1
139195  96.096  -77.767  48.737  1
139196  96.109  -77.777  48.702  1
139197  96.122  -77.786  48.667  1
139198  96.136  -77.795  48.632  1
139199  96.149  -77.804  48.596  1
139200  96.163  -77.814  48.564  1
139201  96.177  -77.824  48.533  1
139202  96.191  -77.836  48.501  1
139203  96.205  -77.847  48.469  1
139204  96.213  -77.851  48.438  1
139205  96.212  -77.843  48.406  1
139206  96.218  -77.839  48.376  1
139207  96.226  -77.836  48.349  1
139208  96.234  -77.832  48.322  1
139209  96.242  -77.829  48.296  1
139210  96.250  -77.826  48.270  1
139211  96.258  -77.822  48.244  1
139212  96.277  -77.818  48.218  1
139213  96.298  -77.815  48.193  1
139214  96.316  -77.812  48.169  1
139215  96.322  -77.818  48.146  1
139216  96.328  -77.823  48.124  1
139217  96.335  -77.828  48.102  1
139218  96.341  -77.834  48.078  1
139219  96.347  -77.839  48.054  1
139220  96.362  -77.849  48.031  1
139221  96.379  -77.861  48.008  1
139222  96.397  -77.873  47.986  1
139223  96.415  -77.886  47.964  1
139224  96.435  -77.897  47.941  1
139225  96.463  -77.904  47.917  1
139226  96.491  -77.912  47.892  1
139227  96.519  -77.918  47.868  1
139228  96.539  -77.918  47.843  1
139229  96.557  -77.916  47.820  1
139230  96.572  -77.906  47.796  1
139231  96.590  -77.913  47.771  1
139232  96.609  -77.920  47.746  1
139233  96.627  -77.928  47.720  1
139234  96.640  -77.931  47.695  1
139235  96.646  -77.928  47.669  1
139236  96.651  -77.926  47.645  1
139237  96.657  -77.924  47.620  1
139238  96.663  -77.921  47.596  1
139239  96.668  -77.919  47.572  1
139240  96.674  -77.917  47.547  1
139241  96.680  -77.915  47.523  1
139242  96.686  -77.912  47.500  1
139243  96.708  -77.917  47.475  1
139244  96.760  -77.934  47.450  1
139245  96.813  -77.952  47.426  1
139246  96.866  -77.969  47.402  1
139247  96.904  -77.981  47.378  1
139248  96.916  -77.996  47.353  1
139249  96.917  -78.011  47.329  1
139250  96.918  -78.025  47.306  1
139251  96.919  -78.040  47.283  1
139252  96.920  -78.054  47.260  1
139253  96.922  -78.069  47.238  1
139254  96.946  -78.075  47.216  1
139255  96.956  -78.070  47.194  1
139256  96.964  -78.062  47.172  1
139257  96.975  -78.059  47.150  1
139258  96.996  -78.063  47.128  1
139259  97.017  -78.069  47.107  1
139260  97.037  -78.073  47.088  1
139261  97.058  -78.078  47.068  1
139262  97.076  -78.089  47.049  1
139263  97.093  -78.101  47.031  1
139264  97.109  -78.113  47.015  1
139265  97.126  -78.125  46.999  1
139266  97.143  -78.138  46.984  1
139267  97.169  -78.121  46.970  1
139268  97.197  -78.102  46.957  1
139269  97.223  -78.085  46.946  1
139270  97.232  -78.081  46.937  1
139271  97.241  -78.076  46.928  1
139272  97.249  -78.072  46.922  1
139273  97.275  -78.075  46.913  1
139274  97.308  -78.081  46.902  1
139275  97.341  -78.087  46.890  1
139276  97.373  -78.093  46.877  1
139277  97.406  -78.099  46.863  1
139278  97.439  -78.106  46.849  1
139279  97.472  -78.113  46.836  1
139280  97.505  -78.120  46.821  1
139281  97.538  -78.128  46.806  1
139282  97.571  -78.134  46.791  1
139283  97.609  -78.138  46.778  1
139284  97.649  -78.141  46.763  1
139285  97.689  -78.142  46.745  1
139286  97.715  -78.164  46.728  1
139287  97.739  -78.188  46.711  1
139288  97.758  -78.203  46.694  1
139289  97.773  -78.206  46.677  1
139290  97.788  -78.210  46.656  1
139291  97.803  -78.213  46.635  1
139292  97.818  -78.216  46.614  1
139293  97.832  -78.219  46.592  1
139294  97.848  -78.222  46.569  1
139295  97.862  -78.226  46.548  1
139296  97.889  -78.200  46.528  1
139297  97.905  -78.234  46.507  1
139298  97.945  -78.241  46.486  1
139299  97.984  -78.247  46.464  1
139300  98.024  -78.255  46.442  1
139301  98.063  -78.262  46.420  1
139302  98.102  -78.269  46.397  1
139303  98.142  -78.276  46.374  1
139304  98.181  -78.283  46.353  1
139305  98.216  -78.300  46.330  1
139306  98.232  -78.360  46.308  1
139307  98.248  -78.418  46.286  1
139308  98.237  -78.424  46.264  1
139309  98.224  -78.424  46.243  1
139310  98.210  -78.424  46.222  1
139311  98.224  -78.410  46.200  1
139312  98.253  -78.402  46.181  1
139313  98.276  -78.394  46.161  1
139314  98.298  -78.385  46.141  1
139315  98.321  -78.377  46.120  1
139316  98.344  -78.369  46.099  1
139317  98.351  -78.364  46.077  1
139318  98.347  -78.348  46.057  1
139319  98.345  -78.316  46.036  1
139320  98.377  -78.287  46.015  1
139321  98.448  -78.263  45.994  1
139322  98.466  -78.260  45.972  1
139323  98.480  -78.260  45.948  1
139324  98.494  -78.260  45.925  1
139325  98.508  -78.259  45.901  1
139326  98.522  -78.258  45.877  1
139327  98.536  -78.257  45.853  1
139328  98.550  -78.254  45.830  1
139329  98.560  -78.238  45.806  1
139330  98.570  -78.221  45.782  1
139331  98.567  -78.211  45.759  1
139332  98.596  -78.219  45.737  1
139333  98.625  -78.227  45.717  1
139334  98.662  -78.226  45.697  1
139335  98.703  -78.194  45.677  1
139336  98.739  -78.144  45.658  1
139337  98.750  -78.181  45.642  1
139338  98.768  -78.212  45.627  1
139339  98.794  -78.228  45.612  1
139340  98.820  -78.244  45.597  1
139341  98.847  -78.261  45.580  1
139342  98.874  -78.277  45.562  1
139343  98.912  -78.284  45.545  1
139344  98.947  -78.294  45.528  1
139345  98.982  -78.304  45.513  1
139346  99.017  -78.314  45.498  1
139347  99.047  -78.330  45.484  1
139348  99.069  -78.354  45.470  1
139349  99.091  -78.378  45.455  1
139350  99.114  -78.402  45.440  1
139351  99.133  -78.404  45.428  1
139352  99.152  -78.404  45.417  1
139353  99.171  -78.405  45.406  1
139354  99.191  -78.405  45.394  1
139355  99.210  -78.406  45.383  1
139356  99.238  -78.401  45.371  1
139357  99.269  -78.395  45.358  1
139358  99.297  -78.388  45.345  1
139359  99.325  -78.383  45.332  1
139360  99.356  -78.385  45.318  1
139361  99.386  -78.385  45.305  1
139362  99.417  -78.387  45.292  1
139363  99.448  -78.388  45.278  1
139364  99.479  -78.389  45.264  1
139365  99.510  -78.391  45.251  1
139366  99.541  -78.392  45.240  1
139367  99.573  -78.413  45.228  1
139368  99.615  -78.447  45.215  1
139369  99.657  -78.482  45.203  1
139370  99.701  -78.518  45.190  1
139371  99.744  -78.554  45.176  1
139372  99.786  -78.589  45.162  1
139373  99.829  -78.625  45.149  1
139374  99.840  -78.633  45.134  1
139375  99.850  -78.640  45.120  1
139376  99.860  -78.647  45.107  1
139377  99.869  -78.655  45.094  1
139378  99.875  -78.662  45.081  1
139379  99.882  -78.669  45.067  1
139380  99.906  -78.689  45.054  1
139381  99.926  -78.705  45.043  1
139382  99.942  -78.720  45.031  1
139383  99.958  -78.734  45.020  1
139384  99.974  -78.749  45.008  1
139385  99.990  -78.764  44.997  1
139386  100.005  -78.778  44.986  1
139387  100.021  -78.793  44.975  1
139388  100.037  -78.808  44.965  1
139389  100.043  -78.829  44.954  1
139390  100.047  -78.823  44.944  1
139391  100.056  -78.810  44.935  1
139392  100.081  -78.822  44.926  1
139393  100.107  -78.834  44.916  1
139394  100.135  -78.847  44.905  1
139395  100.180  -78.862  44.894  1
139396  100.225  -78.877  44.882  1
139397  100.271  -78.893  44.872  1
139398  100.306  -78.906  44.860  1
139399  100.316  -78.917  44.849  1
139400  100.326  -78.927  44.838  1
139401  100.336  -78.941  44.826  1
139402  100.347  -78.960  44.813  1
139403  100.357  -78.979  44.801  1
139404  100.368  -78.999  44.788  1
139405  100.384  -79.010  44.774  1
139406  100.409  -79.025  44.761  1
139407  100.441  -79.044  44.747  1
139408  100.474  -79.064  44.733  1
139409  100.506  -79.083  44.718  1
139410  100.539  -79.102  44.703  1
139411  100.571  -79.121  44.689  1
139412  100.604  -79.140  44.674  1
139413  100.636  -79.159  44.659  1
139666  92.913  -78.188  54.243  1
139667  92.927  -78.183  54.237  1
139668  92.940  -78.178  54.231  1
139669  92.954  -78.173  54.226  1
139670  92.968  -78.169  54.221  1
139671  92.981  -78.164  54.216  1
139672  92.995  -78.159  54.210  1
139673  93.009  -78.154  54.204  1
139674  93.022  -78.150  54.197  1
139675  93.036  -78.144  54.192  1
139676  93.050  -78.140  54.186  1
139677  93.063  -78.135  54.180  1
139678  93.077  -78.130  54.175  1
139679  93.091  -78.122  54.169  1
139680  93.105  -78.109  54.162  1
139681  93.119  -78.097  54.155  1
139682  93.141  -78.085  54.148  1
139683  93.164  -78.073  54.142  1
139684  93.188  -78.062  54.137  1
139685  93.212  -78.050  54.131  1
139686  93.235  -78.038  54.124  1
139687  93.259  -78.026  54.116  1
139688  93.282  -78.014  54.109  1
139689  93.306  -78.003  54.104  1
139690  93.330  -77.990  54.098  1
139691  93.353  -77.977  54.092  1
139692  93.373  -77.959  54.085  1
139693  93.393  -77.943  54.077  1
139694  93.398  -77.947  54.067  1
139695  93.404  -77.949  54.056  1
139696  93.413  -77.937  54.045  1
139697  93.421  -77.924  54.034  1
139698  93.429  -77.912  54.022  1
139699  93.437  -77.899  54.007  1
139700  93.461  -77.890  53.992  1
139701  93.468  -77.874  53.976  1
139702  93.476  -77.858  53.960  1
139703  93.483  -77.842  53.944  1
139704  93.491  -77.825  53.929  1
139705  93.499  -77.812  53.914  1
139706  93.510  -77.803  53.900  1
139707  93.521  -77.795  53.884  1
139708  93.533  -77.787  53.866  1
139709  93.544  -77.779  53.847  1
139710  93.549  -77.755  53.828  1
139711  93.552  -77.727  53.809  1
139712  93.570  -77.730  53.790  1
139713  93.590  -77.736  53.772  1
139714  93.609  -77.736  53.753  1
139715  93.624  -77.727  53.733  1
139716  93.636  -77.719  53.714  1
139717  93.644  -77.715  53.695  1
139718  93.655  -77.711  53.676  1
139719  93.666  -77.706  53.657  1
139720  93.677  -77.701  53.640  1
139721  93.688  -77.696  53.622  1
139722  93.698  -77.691  53.603  1
139723  93.709  -77.686  53.584  1
139724  93.720  -77.682  53.565  1
139725  93.730  -77.677  53.547  1
139726  93.741  -77.672  53.530  1
139727  93.752  -77.667  53.511  1
139728  93.763  -77.662  53.494  1
139729  93.773  -77.657  53.476  1
139730  93.784  -77.652  53.458  1
139731  93.795  -77.648  53.440  1
139732  93.805  -77.642  53.423  1
139733  93.817  -77.638  53.406  1
139734  93.827  -77.633  53.389  1
139735  93.838  -77.628  53.371  1
139736  93.852  -77.624  53.354  1
139737  93.865  -77.620  53.337  1
139738  93.880  -77.616  53.319  1
139739  93.894  -77.612  53.302  1
139740  93.907  -77.608  53.284  1
139741  93.921  -77.604  53.267  1
139742  93.935  -77.600  53.249  1
139743  93.949  -77.595  53.231  1
139744  93.957  -77.595  53.213  1
139745  93.962  -77.596  53.195  1
139746  93.967  -77.598  53.178  1
139747  93.977  -77.592  53.160  1
139748  93.992  -77.580  53.142  1
139749  94.007  -77.567  53.124  1
139750  94.022  -77.554  53.106  1
139751  94.037  -77.541  53.087  1
139752  94.054  -77.530  53.068  1
139753  94.063  -77.523  53.051  1
139754  94.071  -77.515  53.034  1
139755  94.075  -77.506  53.018  1
139756  94.080  -77.498  53.000  1
139757  94.084  -77.489  52.984  1
139758  94.089  -77.481  52.968  1
139759  94.098  -77.474  52.952  1
139760  94.119  -77.473  52.938  1
139761  94.146  -77.472  52.925  1
139762  94.178  -77.472  52.911  1
139763  94.210  -77.473  52.896  1
139764  94.243  -77.473  52.882  1
139765  94.220  -77.500  52.866  1
139766  94.222  -77.511  52.849  1
139767  94.245  -77.508  52.829  1
139768  94.247  -77.501  52.812  1
139769  94.211  -77.510  52.798  1
139770  94.198  -77.526  52.788  1
139771  94.173  -77.530  52.780  1
139772  94.169  -77.520  52.769  1
139773  94.196  -77.491  52.756  1
139774  94.207  -77.436  52.743  1
139775  94.197  -77.448  52.734  1
139776  94.189  -77.480  52.727  1
139777  94.217  -77.511  52.724  1
139778  94.266  -77.507  52.724  1
139779  94.313  -77.492  52.724  1
139780  94.360  -77.478  52.723  1
139781  94.407  -77.464  52.722  1
139782  94.454  -77.450  52.720  1
139783  94.449  -77.440  52.717  1
139784  94.441  -77.430  52.712  1
139785  94.434  -77.420  52.706  1
139786  94.427  -77.411  52.697  1
139787  94.420  -77.401  52.688  1
139788  94.412  -77.392  52.678  1
139789  94.408  -77.374  52.669  1
139790  94.404  -77.357  52.655  1
139791  94.416  -77.353  52.635  1
139792  94.445  -77.363  52.610  1
139793  94.473  -77.373  52.581  1
139794  94.501  -77.387  52.552  1
139795  94.527  -77.412  52.524  1
139796  94.552  -77.433  52.496  1
139797  94.569  -77.427  52.467  1
139798  94.585  -77.421  52.436  1
139799  94.602  -77.416  52.403  1
139800  94.638  -77.450  52.369  1
139801  94.680  -77.499  52.336  1
139802  94.727  -77.523  52.302  1
139803  94.775  -77.542  52.265  1
139804  94.824  -77.561  52.225  1
139805  94.863  -77.573  52.186  1
139806  94.896  -77.580  52.148  1
139807  94.930  -77.578  52.112  1
139808  94.964  -77.574  52.077  1
139809  94.998  -77.570  52.043  1
139810  95.024  -77.564  52.009  1
139811  95.043  -77.555  51.974  1
139812  95.033  -77.520  51.938  1
139813  95.017  -77.478  51.901  1
139814  95.000  -77.436  51.862  1
139815  94.974  -77.404  51.823  1
139816  94.949  -77.374  51.784  1
139817  94.950  -77.336  51.748  1
139818  94.950  -77.298  51.710  1
139819  95.042  -77.296  51.671  1
139820  95.016  -77.332  51.633  1
139821  95.023  -77.343  51.594  1
139822  95.023  -77.347  51.559  1
139823  95.023  -77.351  51.524  1
139824  95.024  -77.355  51.488  1
139825  95.024  -77.359  51.445  1
139826  95.033  -77.371  51.397  1
139827  95.062  -77.387  51.343  1
139828  95.111  -77.398  51.284  1
139829  95.160  -77.410  51.224  1
139830  95.209  -77.421  51.167  1
139831  95.243  -77.427  51.114  1
139832  95.265  -77.428  51.064  1
139833  95.287  -77.429  51.016  1
139834  95.309  -77.429  50.969  1
139835  95.331  -77.429  50.925  1
139836  95.352  -77.430  50.879  1
139837  95.374  -77.430  50.835  1
139838  95.396  -77.431  50.793  1
139839  95.418  -77.432  50.756  1
139840  95.440  -77.432  50.722  1
139841  95.462  -77.432  50.690  1
139842  95.491  -77.433  50.658  1
139843  95.524  -77.433  50.626  1
139844  95.556  -77.433  50.593  1
139845  95.582  -77.431  50.558  1
139846  95.598  -77.422  50.522  1
139847  95.635  -77.429  50.488  1
139848  95.679  -77.447  50.454  1
139849  95.678  -77.461  50.417  1
139850  95.677  -77.476  50.380  1
139851  95.676  -77.490  50.340  1
139852  95.676  -77.505  50.299  1
139853  95.675  -77.520  50.256  1
139854  95.674  -77.534  50.213  1
139855  95.673  -77.548  50.172  1
139856  95.673  -77.563  50.131  1
139857  95.672  -77.577  50.085  1
139858  95.671  -77.592  50.041  1
139859  95.672  -77.604  49.998  1
139860  95.678  -77.613  49.958  1
139861  95.695  -77.617  49.918  1
139862  95.710  -77.615  49.880  1
139863  95.726  -77.614  49.844  1
139864  95.741  -77.611  49.807  1
139865  95.756  -77.609  49.773  1
139866  95.770  -77.608  49.739  1
139867  95.784  -77.606  49.706  1
139868  95.798  -77.605  49.672  1
139869  95.812  -77.603  49.639  1
139870  95.826  -77.602  49.605  1
139871  95.841  -77.599  49.572  1
139872  95.855  -77.598  49.540  1
139873  95.869  -77.596  49.509  1
139874  95.883  -77.595  49.479  1
139875  95.897  -77.593  49.447  1
139876  95.912  -77.592  49.415  1
139877  95.926  -77.589  49.384  1
139878  95.940  -77.588  49.354  1
139879  95.954  -77.586  49.323  1
139880  95.970  -77.598  49.295  1
139881  95.972  -77.615  49.266  1
139882  95.972  -77.634  49.233  1
139883  95.975  -77.650  49.197  1
139884  95.987  -77.657  49.162  1
139885  96.001  -77.663  49.127  1
139886  96.013  -77.670  49.092  1
139887  96.026  -77.676  49.058  1
139888  96.036  -77.686  49.024  1
139889  96.046  -77.696  48.990  1
139890  96.057  -77.705  48.957  1
139891  96.067  -77.716  48.923  1
139892  96.078  -77.726  48.888  1
139893  96.088  -77.736  48.853  1
139894  96.091  -77.744  48.819  1
139895  96.093  -77.753  48.785  1
139896  96.096  -77.761  48.751  1
139897  96.110  -77.771  48.716  1
139898  96.123  -77.780  48.681  1
139899  96.136  -77.790  48.646  1
139900  96.150  -77.799  48.610  1
139901  96.163  -77.808  48.578  1
139902  96.176  -77.818  48.546  1
139903  96.189  -77.827  48.515  1
139904  96.203  -77.837  48.483  1
139905  96.215  -77.845  48.451  1
139906  96.220  -77.840  48.420  1
139907  96.228  -77.837  48.390  1
139908  96.236  -77.834  48.363  1
139909  96.244  -77.830  48.336  1
139910  96.252  -77.827  48.310  1
139911  96.260  -77.824  48.284  1
139912  96.269  -77.821  48.257  1
139913  96.290  -77.816  48.232  1
139914  96.311  -77.812  48.207  1
139915  96.320  -77.815  48.183  1
139916  96.327  -77.821  48.159  1
139917  96.333  -77.826  48.136  1
139918  96.339  -77.831  48.113  1
139919  96.346  -77.837  48.090  1
139920  96.352  -77.842  48.066  1
139921  96.364  -77.851  48.041  1
139922  96.382  -77.863  48.019  1
139923  96.400  -77.875  47.996  1
139924  96.418  -77.887  47.973  1
139925  96.442  -77.897  47.950  1
139926  96.471  -77.904  47.926  1
139927  96.499  -77.912  47.902  1
139928  96.519  -77.912  47.877  1
139929  96.539  -77.913  47.852  1
139930  96.559  -77.913  47.828  1
139931  96.572  -77.896  47.805  1
139932  96.589  -77.898  47.781  1
139933  96.607  -77.905  47.757  1
139934  96.626  -77.912  47.731  1
139935  96.645  -77.919  47.705  1
139936  96.663  -77.927  47.681  1
139937  96.677  -77.931  47.657  1
139938  96.683  -77.929  47.632  1
139939  96.689  -77.927  47.608  1
139940  96.694  -77.924  47.583  1
139941  96.700  -77.922  47.558  1
139942  96.706  -77.920  47.535  1
139943  96.712  -77.918  47.512  1
139944  96.724  -77.918  47.487  1
139945  96.777  -77.935  47.464  1
139946  96.830  -77.953  47.440  1
139947  96.881  -77.970  47.415  1
139948  96.897  -77.974  47.391  1
139949  96.911  -77.990  47.367  1
139950  96.925  -78.006  47.342  1
139951  96.928  -78.020  47.319  1
139952  96.929  -78.034  47.296  1
139953  96.929  -78.049  47.273  1
139954  96.933  -78.062  47.252  1
139955  96.953  -78.066  47.230  1
139956  96.961  -78.059  47.208  1
139957  96.969  -78.051  47.187  1
139958  96.979  -78.047  47.166  1
139959  97.001  -78.051  47.142  1
139960  97.021  -78.056  47.121  1
139961  97.042  -78.061  47.101  1
139962  97.063  -78.066  47.082  1
139963  97.083  -78.072  47.062  1
139964  97.100  -78.083  47.044  1
139965  97.117  -78.095  47.027  1
139966  97.134  -78.107  47.012  1
139967  97.152  -78.114  46.997  1
139968  97.180  -78.095  46.983  1
139969  97.208  -78.076  46.970  1
139970  97.217  -78.072  46.959  1
139971  97.226  -78.067  46.949  1
139972  97.235  -78.062  46.939  1
139973  97.243  -78.058  46.930  1
139974  97.259  -78.057  46.921  1
139975  97.292  -78.063  46.914  1
139976  97.325  -78.069  46.906  1
139977  97.358  -78.075  46.893  1
139978  97.391  -78.082  46.880  1
139979  97.424  -78.089  46.866  1
139980  97.457  -78.097  46.851  1
139981  97.490  -78.104  46.837  1
139982  97.523  -78.111  46.823  1
139983  97.556  -78.119  46.810  1
139984  97.595  -78.121  46.796  1
139985  97.635  -78.123  46.781  1
139986  97.666  -78.138  46.764  1
139987  97.690  -78.162  46.748  1
139988  97.714  -78.186  46.730  1
139989  97.734  -78.202  46.712  1
139990  97.749  -78.205  46.693  1
139991  97.764  -78.208  46.672  1
139992  97.779  -78.212  46.650  1
139993  97.793  -78.215  46.628  1
139994  97.808  -78.218  46.608  1
139995  97.823  -78.222  46.586  1
139996  97.838  -78.225  46.566  1
139997  97.865  -78.231  46.545  1
139998  97.909  -78.241  46.522  1
139999  97.949  -78.247  46.500  1
140000  97.988  -78.254  46.478  1
140001  98.028  -78.262  46.456  1
140002  98.067  -78.269  46.433  1
140003  98.106  -78.276  46.411  1
140004  98.146  -78.283  46.389  1
140005  98.185  -78.290  46.368  1
140006  98.223  -78.302  46.345  1
140007  98.239  -78.360  46.322  1
140008  98.251  -78.411  46.299  1
140009  98.237  -78.411  46.277  1
140010  98.223  -78.411  46.256  1
140011  98.210  -78.397  46.234  1
140012  98.212  -78.373  46.212  1
140013  98.322  -78.387  46.192  1
140014  98.334  -78.375  46.172  1
140015  98.329  -78.359  46.151  1
140016  98.337  -78.354  46.130  1
140017  98.331  -78.353  46.109  1
140018  98.323  -78.352  46.088  1
140019  98.319  -78.333  46.068  1
140020  98.329  -78.302  46.046  1
140021  98.401  -78.278  46.026  1
140022  98.472  -78.253  46.004  1
140023  98.491  -78.250  45.981  1
140024  98.505  -78.250  45.959  1
140025  98.519  -78.250  45.936  1
140026  98.533  -78.249  45.912  1
140027  98.547  -78.248  45.888  1
140028  98.561  -78.247  45.865  1
140029  98.571  -78.232  45.841  1
140030  98.581  -78.215  45.816  1
140031  98.591  -78.197  45.794  1
140032  98.590  -78.184  45.771  1
140033  98.602  -78.186  45.749  1
140034  98.631  -78.194  45.729  1
140035  98.670  -78.191  45.709  1
140036  98.711  -78.186  45.689  1
140037  98.744  -78.158  45.670  1
140038  98.756  -78.196  45.653  1
140039  98.768  -78.233  45.638  1
140040  98.791  -78.254  45.623  1
140041  98.818  -78.271  45.609  1
140042  98.848  -78.284  45.593  1
140043  98.886  -78.291  45.577  1
140044  98.923  -78.298  45.559  1
140045  98.957  -78.309  45.543  1
140046  98.992  -78.319  45.527  1
140047  99.027  -78.329  45.511  1
140048  99.062  -78.339  45.496  1
140049  99.097  -78.350  45.482  1
140050  99.127  -78.366  45.468  1
140051  99.147  -78.377  45.454  1
140052  99.166  -78.377  45.440  1
140053  99.185  -78.377  45.428  1
140054  99.202  -78.379  45.417  1
140055  99.217  -78.382  45.405  1
140056  99.232  -78.385  45.395  1
140057  99.248  -78.388  45.384  1
140058  99.286  -78.397  45.372  1
140059  99.317  -78.398  45.358  1
140060  99.348  -78.399  45.345  1
140061  99.379  -78.401  45.331  1
140062  99.410  -78.402  45.318  1
140063  99.441  -78.403  45.305  1
140064  99.472  -78.404  45.291  1
140065  99.503  -78.406  45.277  1
140066  99.534  -78.407  45.263  1
140067  99.564  -78.408  45.252  1
140068  99.596  -78.423  45.240  1
140069  99.629  -78.445  45.228  1
140070  99.670  -78.478  45.217  1
140071  99.713  -78.514  45.203  1
140072  99.756  -78.550  45.190  1
140073  99.798  -78.586  45.176  1
140074  99.837  -78.617  45.163  1
140075  99.847  -78.624  45.149  1
140076  99.857  -78.631  45.134  1
140077  99.867  -78.638  45.121  1
140078  99.877  -78.645  45.108  1
140079  99.888  -78.652  45.095  1
140080  99.898  -78.659  45.082  1
140081  99.907  -78.667  45.070  1
140082  99.923  -78.677  45.058  1
140083  99.936  -78.689  45.046  1
140084  99.949  -78.701  45.034  1
140085  99.965  -78.716  45.023  1
140086  99.981  -78.730  45.011  1
140087  99.997  -78.745  45.000  1
140088  100.013  -78.760  44.990  1
140089  100.028  -78.774  44.980  1
140090  100.045  -78.789  44.969  1
140091  100.054  -78.808  44.959  1
140092  100.064  -78.799  44.949  1
140093  100.090  -78.811  44.939  1
140094  100.132  -78.825  44.928  1
140095  100.177  -78.840  44.917  1
140096  100.223  -78.855  44.905  1
140097  100.268  -78.871  44.893  1
140098  100.305  -78.885  44.881  1
140099  100.316  -78.896  44.869  1
140100  100.326  -78.906  44.857  1
140101  100.335  -78.917  44.845  1
140102  100.346  -78.933  44.832  1
140103  100.356  -78.952  44.820  1
140104  100.367  -78.971  44.807  1
140105  100.378  -78.990  44.794  1
140106  100.392  -79.005  44.779  1
140107  100.408  -79.016  44.765  1
140108  100.439  -79.034  44.751  1
140109  100.472  -79.053  44.736  1
140110  100.504  -79.072  44.722  1
140111  100.537  -79.092  44.707  1
140112  100.569  -79.111  44.692  1
140113  100.602  -79.130  44.677  1
140114  100.634  -79.149  44.661  1
140366  92.899  -78.178  54.252  1
140367  92.912  -78.174  54.245  1
140368  92.926  -78.169  54.239  1
140369  92.940  -78.164  54.234  1
140370  92.953  -78.159  54.229  1
140371  92.967  -78.154  54.224  1
140372  92.981  -78.150  54.219  1
140373  92.994  -78.145  54.214  1
140374  93.008  -78.141  54.208  1
140375  93.021  -78.135  54.202  1
140376  93.035  -78.131  54.196  1
140377  93.049  -78.126  54.190  1
140378  93.063  -78.121  54.186  1
140379  93.076  -78.116  54.181  1
140380  93.090  -78.112  54.175  1
140381  93.104  -78.099  54.167  1
140382  93.118  -78.087  54.161  1
140383  93.140  -78.075  54.155  1
140384  93.163  -78.063  54.150  1
140385  93.187  -78.051  54.144  1
140386  93.211  -78.040  54.139  1
140387  93.234  -78.028  54.133  1
140388  93.258  -78.015  54.125  1
140389  93.282  -78.004  54.119  1
140390  93.305  -77.991  54.113  1
140391  93.326  -77.973  54.108  1
140392  93.347  -77.955  54.101  1
140393  93.368  -77.937  54.095  1
140394  93.384  -77.925  54.087  1
140395  93.390  -77.930  54.077  1
140396  93.396  -77.934  54.067  1
140397  93.401  -77.938  54.056  1
140398  93.409  -77.928  54.044  1
140399  93.417  -77.916  54.033  1
140400  93.441  -77.910  54.019  1
140401  93.455  -77.896  54.005  1
140402  93.463  -77.881  53.990  1
140403  93.471  -77.864  53.974  1
140404  93.478  -77.848  53.959  1
140405  93.486  -77.831  53.945  1
140406  93.493  -77.815  53.930  1
140407  93.501  -77.799  53.916  1
140408  93.509  -77.784  53.900  1
140409  93.516  -77.766  53.882  1
140410  93.523  -77.745  53.864  1
140411  93.531  -77.726  53.845  1
140412  93.543  -77.714  53.826  1
140413  93.563  -77.721  53.807  1
140414  93.583  -77.727  53.789  1
140415  93.600  -77.724  53.769  1
140416  93.615  -77.714  53.749  1
140417  93.630  -77.705  53.729  1
140418  93.639  -77.701  53.710  1
140419  93.647  -77.697  53.692  1
140420  93.658  -77.692  53.674  1
140421  93.669  -77.687  53.655  1
140422  93.680  -77.683  53.637  1
140423  93.691  -77.678  53.618  1
140424  93.701  -77.673  53.600  1
140425  93.712  -77.668  53.582  1
140426  93.723  -77.663  53.564  1
140427  93.733  -77.658  53.546  1
140428  93.744  -77.653  53.528  1
140429  93.755  -77.649  53.511  1
140430  93.766  -77.644  53.493  1
140431  93.776  -77.639  53.475  1
140432  93.787  -77.634  53.457  1
140433  93.798  -77.629  53.440  1
140434  93.808  -77.624  53.423  1
140435  93.820  -77.620  53.406  1
140436  93.832  -77.615  53.388  1
140437  93.846  -77.611  53.371  1
140438  93.860  -77.607  53.354  1
140439  93.874  -77.603  53.337  1
140440  93.888  -77.599  53.319  1
140441  93.902  -77.595  53.302  1
140442  93.916  -77.591  53.285  1
140443  93.929  -77.587  53.267  1
140444  93.943  -77.583  53.250  1
140445  93.953  -77.581  53.233  1
140446  93.958  -77.583  53.215  1
140447  93.964  -77.583  53.198  1
140448  93.979  -77.570  53.181  1
140449  93.994  -77.557  53.163  1
140450  94.009  -77.544  53.145  1
140451  94.024  -77.531  53.127  1
140452  94.038  -77.517  53.109  1
140453  94.048  -77.511  53.091  1
140454  94.058  -77.503  53.074  1
140455  94.065  -77.495  53.057  1
140456  94.069  -77.486  53.040  1
140457  94.074  -77.478  53.022  1
140458  94.084  -77.472  53.006  1
140459  94.106  -77.470  52.991  1
140460  94.127  -77.468  52.976  1
140461  94.151  -77.467  52.962  1
140462  94.183  -77.467  52.948  1
140463  94.216  -77.467  52.935  1
140464  94.248  -77.468  52.921  1
140465  94.280  -77.468  52.907  1
140466  94.313  -77.469  52.892  1
140467  94.345  -77.469  52.875  1
140468  94.339  -77.474  52.857  1
140469  94.228  -77.451  52.840  1
140470  94.215  -77.469  52.827  1
140471  94.208  -77.490  52.817  1
140472  94.200  -77.511  52.810  1
140473  94.190  -77.529  52.801  1
140474  94.191  -77.507  52.789  1
140475  94.182  -77.495  52.776  1
140476  94.174  -77.479  52.766  1
140477  94.168  -77.458  52.756  1
140478  94.210  -77.473  52.748  1
140479  94.267  -77.500  52.745  1
140480  94.314  -77.486  52.742  1
140481  94.361  -77.471  52.741  1
140482  94.408  -77.457  52.742  1
140483  94.440  -77.445  52.741  1
140484  94.433  -77.435  52.739  1
140485  94.426  -77.425  52.737  1
140486  94.418  -77.415  52.733  1
140487  94.411  -77.406  52.725  1
140488  94.406  -77.391  52.716  1
140489  94.402  -77.374  52.706  1
140490  94.398  -77.357  52.695  1
140491  94.394  -77.339  52.680  1
140492  94.404  -77.335  52.660  1
140493  94.433  -77.345  52.634  1
140494  94.462  -77.354  52.607  1
140495  94.490  -77.364  52.581  1
140496  94.519  -77.374  52.555  1
140497  94.547  -77.389  52.527  1
140498  94.573  -77.413  52.496  1
140499  94.590  -77.408  52.463  1
140500  94.607  -77.402  52.428  1
140501  94.647  -77.448  52.393  1
140502  94.690  -77.497  52.358  1
140503  94.736  -77.526  52.324  1
140504  94.784  -77.545  52.288  1
140505  94.821  -77.555  52.251  1
140506  94.854  -77.553  52.215  1
140507  94.889  -77.549  52.181  1
140508  94.923  -77.545  52.146  1
140509  94.958  -77.542  52.113  1
140510  94.992  -77.538  52.081  1
140511  95.012  -77.530  52.047  1
140512  95.031  -77.521  52.013  1
140513  95.037  -77.501  51.977  1
140514  95.021  -77.460  51.938  1
140515  95.004  -77.417  51.899  1
140516  94.977  -77.385  51.859  1
140517  94.959  -77.354  51.821  1
140518  94.960  -77.316  51.784  1
140519  94.960  -77.278  51.745  1
140520  94.965  -77.250  51.706  1
140521  94.996  -77.269  51.667  1
140522  95.044  -77.322  51.628  1
140523  95.045  -77.326  51.591  1
140524  95.045  -77.329  51.555  1
140525  95.046  -77.334  51.518  1
140526  95.046  -77.338  51.472  1
140527  95.061  -77.356  51.422  1
140528  95.077  -77.376  51.369  1
140529  95.119  -77.389  51.310  1
140530  95.168  -77.400  51.252  1
140531  95.207  -77.405  51.195  1
140532  95.235  -77.407  51.141  1
140533  95.264  -77.409  51.090  1
140534  95.295  -77.413  51.040  1
140535  95.325  -77.417  50.992  1
140536  95.348  -77.418  50.946  1
140537  95.371  -77.419  50.900  1
140538  95.392  -77.420  50.855  1
140539  95.414  -77.420  50.813  1
140540  95.436  -77.420  50.774  1
140541  95.458  -77.421  50.739  1
140542  95.480  -77.422  50.705  1
140543  95.501  -77.422  50.670  1
140544  95.531  -77.423  50.636  1
140545  95.563  -77.423  50.603  1
140546  95.591  -77.420  50.569  1
140547  95.607  -77.412  50.534  1
140548  95.660  -77.430  50.501  1
140549  95.660  -77.445  50.468  1
140550  95.659  -77.459  50.434  1
140551  95.658  -77.474  50.396  1
140552  95.657  -77.489  50.357  1
140553  95.657  -77.503  50.316  1
140554  95.656  -77.517  50.275  1
140555  95.655  -77.532  50.236  1
140556  95.655  -77.545  50.197  1
140557  95.658  -77.553  50.156  1
140558  95.662  -77.561  50.111  1
140559  95.665  -77.569  50.065  1
140560  95.668  -77.577  50.022  1
140561  95.677  -77.588  49.980  1
140562  95.700  -77.608  49.938  1
140563  95.719  -77.615  49.899  1
140564  95.734  -77.613  49.861  1
140565  95.749  -77.611  49.824  1
140566  95.764  -77.608  49.788  1
140567  95.779  -77.606  49.754  1
140568  95.795  -77.604  49.720  1
140569  95.810  -77.602  49.685  1
140570  95.825  -77.600  49.650  1
140571  95.840  -77.598  49.616  1
140572  95.855  -77.595  49.581  1
140573  95.870  -77.593  49.547  1
140574  95.885  -77.591  49.515  1
140575  95.901  -77.589  49.484  1
140576  95.916  -77.587  49.451  1
140577  95.931  -77.585  49.420  1
140578  95.946  -77.583  49.391  1
140579  95.961  -77.581  49.362  1
140580  95.975  -77.581  49.332  1
140581  95.975  -77.600  49.304  1
140582  95.974  -77.619  49.273  1
140583  95.974  -77.638  49.240  1
140584  95.979  -77.652  49.204  1
140585  95.992  -77.658  49.169  1
140586  96.005  -77.664  49.133  1
140587  96.018  -77.671  49.098  1
140588  96.030  -77.677  49.066  1
140589  96.043  -77.683  49.035  1
140590  96.054  -77.692  49.002  1
140591  96.064  -77.702  48.969  1
140592  96.075  -77.711  48.936  1
140593  96.086  -77.721  48.902  1
140594  96.088  -77.730  48.866  1
140595  96.090  -77.739  48.833  1
140596  96.092  -77.747  48.800  1
140597  96.097  -77.756  48.766  1
140598  96.110  -77.765  48.730  1
140599  96.123  -77.774  48.695  1
140600  96.136  -77.784  48.661  1
140601  96.150  -77.793  48.626  1
140602  96.163  -77.802  48.593  1
140603  96.177  -77.812  48.561  1
140604  96.190  -77.821  48.529  1
140605  96.202  -77.830  48.497  1
140606  96.219  -77.837  48.466  1
140607  96.230  -77.838  48.435  1
140608  96.238  -77.835  48.404  1
140609  96.246  -77.831  48.377  1
140610  96.254  -77.828  48.350  1
140611  96.262  -77.825  48.324  1
140612  96.270  -77.822  48.298  1
140613  96.282  -77.818  48.271  1
140614  96.303  -77.815  48.246  1
140615  96.318  -77.814  48.221  1
140616  96.325  -77.819  48.197  1
140617  96.331  -77.824  48.173  1
140618  96.337  -77.830  48.149  1
140619  96.344  -77.834  48.126  1
140620  96.350  -77.840  48.102  1
140621  96.357  -77.845  48.078  1
140622  96.367  -77.853  48.055  1
140623  96.385  -77.865  48.032  1
140624  96.403  -77.877  48.008  1
140625  96.421  -77.890  47.984  1
140626  96.450  -77.897  47.961  1
140627  96.478  -77.904  47.936  1
140628  96.500  -77.906  47.912  1
140629  96.520  -77.907  47.887  1
140630  96.540  -77.908  47.863  1
140631  96.560  -77.909  47.838  1
140632  96.573  -77.893  47.814  1
140633  96.587  -77.882  47.789  1
140634  96.606  -77.890  47.765  1
140635  96.624  -77.897  47.740  1
140636  96.643  -77.904  47.715  1
140637  96.661  -77.912  47.691  1
140638  96.680  -77.918  47.668  1
140639  96.698  -77.926  47.644  1
140640  96.715  -77.931  47.620  1
140641  96.721  -77.930  47.596  1
140642  96.726  -77.928  47.572  1
140643  96.732  -77.925  47.549  1
140644  96.738  -77.923  47.525  1
140645  96.743  -77.921  47.501  1
140646  96.793  -77.937  47.477  1
140647  96.846  -77.954  47.454  1
140648  96.874  -77.962  47.429  1
140649  96.891  -77.966  47.405  1
140650  96.904  -77.982  47.381  1
140651  96.919  -77.998  47.357  1
140652  96.932  -78.014  47.333  1
140653  96.938  -78.029  47.311  1
140654  96.939  -78.044  47.288  1
140655  96.944  -78.056  47.266  1
140656  96.958  -78.055  47.245  1
140657  96.966  -78.047  47.224  1
140658  96.973  -78.039  47.202  1
140659  96.984  -78.034  47.180  1
140660  97.005  -78.039  47.158  1
140661  97.025  -78.044  47.136  1
140662  97.046  -78.049  47.116  1
140663  97.067  -78.054  47.096  1
140664  97.088  -78.059  47.076  1
140665  97.108  -78.065  47.058  1
140666  97.124  -78.078  47.041  1
140667  97.141  -78.090  47.024  1
140668  97.163  -78.087  47.010  1
140669  97.190  -78.069  46.996  1
140670  97.202  -78.062  46.983  1
140671  97.211  -78.058  46.971  1
140672  97.220  -78.053  46.960  1
140673  97.229  -78.050  46.950  1
140674  97.238  -78.045  46.940  1
140675  97.246  -78.040  46.931  1
140676  97.277  -78.045  46.924  1
140677  97.309  -78.051  46.918  1
140678  97.343  -78.059  46.906  1
140679  97.376  -78.065  46.894  1
140680  97.408  -78.073  46.881  1
140681  97.442  -78.080  46.866  1
140682  97.475  -78.087  46.853  1
140683  97.508  -78.095  46.841  1
140684  97.541  -78.102  46.830  1
140685  97.581  -78.104  46.815  1
140686  97.617  -78.111  46.800  1
140687  97.641  -78.135  46.783  1
140688  97.665  -78.160  46.766  1
140689  97.689  -78.184  46.748  1
140690  97.710  -78.200  46.729  1
140691  97.724  -78.203  46.709  1
140692  97.739  -78.207  46.688  1
140693  97.754  -78.210  46.665  1
140694  97.769  -78.213  46.644  1
140695  97.784  -78.217  46.624  1
140696  97.798  -78.220  46.603  1
140697  97.816  -78.224  46.582  1
140698  97.862  -78.235  46.560  1
140699  97.909  -78.247  46.536  1
140700  97.951  -78.254  46.514  1
140701  97.992  -78.262  46.492  1
140702  98.032  -78.269  46.469  1
140703  98.071  -78.275  46.447  1
140704  98.110  -78.283  46.425  1
140705  98.150  -78.290  46.403  1
140706  98.190  -78.297  46.382  1
140707  98.229  -78.304  46.359  1
140708  98.246  -78.362  46.336  1
140709  98.251  -78.399  46.313  1
140710  98.237  -78.399  46.291  1
140711  98.223  -78.393  46.268  1
140712  98.211  -78.364  46.246  1
140713  98.199  -78.335  46.223  1
140714  98.309  -78.350  46.203  1
140715  98.419  -78.364  46.183  1
140716  98.413  -78.350  46.162  1
140717  98.324  -78.343  46.141  1
140718  98.302  -78.341  46.120  1
140719  98.296  -78.339  46.099  1
140720  98.292  -78.318  46.079  1
140721  98.353  -78.293  46.058  1
140722  98.424  -78.269  46.036  1
140723  98.494  -78.244  46.014  1
140724  98.516  -78.241  45.992  1
140725  98.529  -78.241  45.970  1
140726  98.544  -78.240  45.947  1
140727  98.558  -78.239  45.923  1
140728  98.572  -78.238  45.900  1
140729  98.583  -78.225  45.876  1
140730  98.593  -78.209  45.852  1
140731  98.603  -78.191  45.828  1
140732  98.613  -78.175  45.806  1
140733  98.621  -78.158  45.783  1
140734  98.609  -78.153  45.761  1
140735  98.638  -78.162  45.740  1
140736  98.678  -78.156  45.720  1
140737  98.719  -78.151  45.700  1
140738  98.748  -78.176  45.681  1
140739  98.762  -78.210  45.664  1
140740  98.774  -78.247  45.648  1
140741  98.788  -78.280  45.633  1
140742  98.822  -78.291  45.620  1
140743  98.859  -78.297  45.606  1
140744  98.897  -78.304  45.591  1
140745  98.933  -78.313  45.574  1
140746  98.968  -78.324  45.557  1
140747  99.003  -78.334  45.541  1
140748  99.038  -78.344  45.525  1
140749  99.072  -78.354  45.510  1
140750  99.107  -78.365  45.496  1
140751  99.133  -78.365  45.482  1
140752  99.149  -78.367  45.468  1
140753  99.164  -78.370  45.453  1
140754  99.179  -78.373  45.440  1
140755  99.194  -78.376  45.428  1
140756  99.208  -78.379  45.417  1
140757  99.223  -78.382  45.407  1
140758  99.254  -78.389  45.396  1
140759  99.287  -78.397  45.384  1
140760  99.323  -78.406  45.371  1
140761  99.371  -78.415  45.357  1
140762  99.402  -78.416  45.344  1
140763  99.433  -78.418  45.331  1
140764  99.464  -78.419  45.317  1
140765  99.495  -78.420  45.304  1
140766  99.526  -78.422  45.291  1
140767  99.557  -78.423  45.276  1
140768  99.588  -78.424  45.265  1
140769  99.619  -78.432  45.254  1
140770  99.652  -78.454  45.242  1
140771  99.684  -78.476  45.231  1
140772  99.725  -78.510  45.217  1
140773  99.768  -78.545  45.203  1
140774  99.811  -78.581  45.190  1
140775  99.844  -78.608  45.177  1
140776  99.854  -78.615  45.163  1
140777  99.864  -78.622  45.149  1
140778  99.874  -78.629  45.137  1
140779  99.885  -78.636  45.124  1
140780  99.894  -78.644  45.112  1
140781  99.904  -78.653  45.100  1
140782  99.911  -78.660  45.088  1
140783  99.924  -78.667  45.076  1
140784  99.951  -78.677  45.064  1
140785  99.965  -78.689  45.051  1
140786  99.978  -78.702  45.039  1
140787  99.991  -78.714  45.027  1
140788  100.004  -78.726  45.015  1
140789  100.017  -78.738  45.004  1
140790  100.031  -78.750  44.993  1
140791  100.044  -78.762  44.983  1
140792  100.057  -78.775  44.972  1
140793  100.084  -78.789  44.963  1
140794  100.129  -78.804  44.952  1
140795  100.174  -78.819  44.940  1
140796  100.220  -78.834  44.928  1
140797  100.265  -78.849  44.916  1
140798  100.305  -78.863  44.903  1
140799  100.315  -78.874  44.890  1
140800  100.325  -78.884  44.878  1
140801  100.335  -78.895  44.865  1
140802  100.345  -78.905  44.852  1
140803  100.355  -78.925  44.839  1
140804  100.366  -78.944  44.826  1
140805  100.376  -78.964  44.813  1
140806  100.387  -78.983  44.798  1
140807  100.399  -78.999  44.784  1
140808  100.415  -79.011  44.770  1
140809  100.436  -79.024  44.755  1
140810  100.469  -79.043  44.740  1
140811  100.501  -79.062  44.725  1
140812  100.534  -79.081  44.710  1
140813  100.566  -79.101  44.695  1
140814  100.599  -79.120  44.680  1
140815  100.631  -79.139  44.664  1
141067  92.892  -78.166  54.254  1
141068  92.908  -78.160  54.247  1
141069  92.925  -78.155  54.241  1
141070  92.939  -78.150  54.236  1
141071  92.952  -78.145  54.233  1
141072  92.966  -78.141  54.227  1
141073  92.980  -78.136  54.222  1
141074  92.994  -78.131  54.218  1
141075  93.007  -78.126  54.211  1
141076  93.021  -78.122  54.206  1
141077  93.035  -78.117  54.201  1
141078  93.048  -78.112  54.195  1
141079  93.062  -78.107  54.190  1
141080  93.075  -78.103  54.186  1
141081  93.089  -78.097  54.180  1
141082  93.103  -78.089  54.173  1
141083  93.117  -78.077  54.167  1
141084  93.139  -78.065  54.161  1
141085  93.163  -78.053  54.156  1
141086  93.187  -78.041  54.151  1
141087  93.210  -78.029  54.146  1
141088  93.234  -78.017  54.141  1
141089  93.258  -78.006  54.134  1
141090  93.279  -77.987  54.128  1
141091  93.299  -77.969  54.122  1
141092  93.321  -77.951  54.116  1
141093  93.342  -77.933  54.111  1
141094  93.362  -77.915  54.104  1
141095  93.376  -77.907  54.096  1
141096  93.381  -77.912  54.086  1
141097  93.387  -77.915  54.075  1
141098  93.393  -77.920  54.064  1
141099  93.399  -77.924  54.053  1
141100  93.405  -77.921  54.042  1
141101  93.443  -77.918  54.030  1
141102  93.450  -77.902  54.016  1
141103  93.458  -77.887  54.001  1
141104  93.462  -77.869  53.986  1
141105  93.465  -77.851  53.973  1
141106  93.468  -77.834  53.959  1
141107  93.478  -77.814  53.946  1
141108  93.488  -77.793  53.931  1
141109  93.498  -77.774  53.915  1
141110  93.512  -77.764  53.898  1
141111  93.522  -77.750  53.880  1
141112  93.530  -77.731  53.862  1
141113  93.538  -77.711  53.843  1
141114  93.555  -77.712  53.825  1
141115  93.575  -77.718  53.806  1
141116  93.591  -77.713  53.786  1
141117  93.607  -77.703  53.766  1
141118  93.621  -77.693  53.745  1
141119  93.634  -77.686  53.726  1
141120  93.642  -77.683  53.708  1
141121  93.651  -77.679  53.690  1
141122  93.661  -77.674  53.672  1
141123  93.672  -77.669  53.653  1
141124  93.683  -77.664  53.635  1
141125  93.694  -77.659  53.616  1
141126  93.704  -77.655  53.598  1
141127  93.715  -77.649  53.581  1
141128  93.726  -77.645  53.564  1
141129  93.736  -77.640  53.546  1
141130  93.748  -77.635  53.528  1
141131  93.758  -77.630  53.511  1
141132  93.769  -77.625  53.493  1
141133  93.780  -77.620  53.475  1
141134  93.790  -77.616  53.458  1
141135  93.801  -77.611  53.441  1
141136  93.813  -77.606  53.425  1
141137  93.827  -77.602  53.407  1
141138  93.841  -77.599  53.390  1
141139  93.855  -77.594  53.373  1
141140  93.868  -77.590  53.355  1
141141  93.883  -77.586  53.338  1
141142  93.896  -77.582  53.322  1
141143  93.910  -77.578  53.306  1
141144  93.924  -77.574  53.288  1
141145  93.938  -77.570  53.272  1
141146  93.949  -77.567  53.257  1
141147  93.954  -77.569  53.239  1
141148  93.966  -77.561  53.222  1
141149  93.981  -77.548  53.205  1
141150  93.996  -77.535  53.188  1
141151  94.009  -77.520  53.170  1
141152  94.020  -77.502  53.151  1
141153  94.031  -77.495  53.134  1
141154  94.042  -77.489  53.117  1
141155  94.053  -77.483  53.100  1
141156  94.058  -77.474  53.082  1
141157  94.070  -77.469  53.065  1
141158  94.092  -77.467  53.047  1
141159  94.113  -77.465  53.030  1
141160  94.134  -77.464  53.014  1
141161  94.156  -77.462  53.000  1
141162  94.189  -77.462  52.986  1
141163  94.221  -77.463  52.973  1
141164  94.253  -77.463  52.961  1
141165  94.286  -77.464  52.948  1
141166  94.318  -77.464  52.934  1
141167  94.350  -77.464  52.919  1
141168  94.353  -77.457  52.904  1
141169  94.323  -77.434  52.887  1
141170  94.227  -77.407  52.871  1
141171  94.220  -77.428  52.856  1
141172  94.211  -77.452  52.846  1
141173  94.202  -77.482  52.839  1
141174  94.196  -77.512  52.830  1
141175  94.193  -77.504  52.820  1
141176  94.187  -77.484  52.807  1
141177  94.182  -77.463  52.797  1
141178  94.179  -77.444  52.788  1
141179  94.216  -77.448  52.778  1
141180  94.261  -77.462  52.770  1
141181  94.316  -77.479  52.764  1
141182  94.362  -77.464  52.759  1
141183  94.409  -77.451  52.758  1
141184  94.424  -77.439  52.757  1
141185  94.417  -77.429  52.756  1
141186  94.410  -77.420  52.755  1
141187  94.403  -77.408  52.752  1
141188  94.399  -77.391  52.747  1
141189  94.395  -77.373  52.740  1
141190  94.391  -77.357  52.730  1
141191  94.387  -77.339  52.719  1
141192  94.383  -77.322  52.705  1
141193  94.393  -77.316  52.686  1
141194  94.422  -77.326  52.663  1
141195  94.451  -77.336  52.638  1
141196  94.479  -77.346  52.612  1
141197  94.507  -77.356  52.585  1
141198  94.536  -77.366  52.554  1
141199  94.565  -77.376  52.521  1
141200  94.593  -77.390  52.487  1
141201  94.615  -77.397  52.451  1
141202  94.657  -77.446  52.414  1
141203  94.699  -77.495  52.377  1
141204  94.745  -77.528  52.341  1
141205  94.779  -77.528  52.308  1
141206  94.814  -77.524  52.278  1
141207  94.848  -77.520  52.247  1
141208  94.882  -77.517  52.215  1
141209  94.917  -77.513  52.180  1
141210  94.951  -77.509  52.148  1
141211  94.980  -77.504  52.117  1
141212  94.999  -77.495  52.084  1
141213  95.018  -77.487  52.050  1
141214  95.037  -77.479  52.014  1
141215  95.024  -77.441  51.975  1
141216  95.007  -77.399  51.935  1
141217  94.981  -77.366  51.896  1
141218  94.969  -77.332  51.858  1
141219  94.970  -77.294  51.822  1
141220  94.970  -77.257  51.781  1
141221  94.987  -77.254  51.741  1
141222  95.004  -77.253  51.702  1
141223  95.030  -77.264  51.663  1
141224  95.067  -77.304  51.624  1
141225  95.067  -77.309  51.586  1
141226  95.068  -77.313  51.547  1
141227  95.073  -77.321  51.498  1
141228  95.090  -77.341  51.447  1
141229  95.106  -77.361  51.392  1
141230  95.129  -77.378  51.336  1
141231  95.166  -77.382  51.278  1
141232  95.193  -77.383  51.222  1
141233  95.220  -77.384  51.168  1
141234  95.248  -77.385  51.115  1
141235  95.276  -77.388  51.064  1
141236  95.307  -77.392  51.014  1
141237  95.338  -77.396  50.967  1
141238  95.369  -77.400  50.920  1
141239  95.399  -77.404  50.875  1
141240  95.429  -77.407  50.832  1
141241  95.454  -77.409  50.792  1
141242  95.476  -77.410  50.756  1
141243  95.498  -77.410  50.720  1
141244  95.520  -77.410  50.684  1
141245  95.542  -77.411  50.648  1
141246  95.571  -77.412  50.614  1
141247  95.600  -77.410  50.580  1
141248  95.631  -77.413  50.547  1
141249  95.641  -77.428  50.515  1
141250  95.640  -77.443  50.483  1
141251  95.639  -77.457  50.450  1
141252  95.639  -77.472  50.413  1
141253  95.638  -77.486  50.375  1
141254  95.641  -77.494  50.335  1
141255  95.644  -77.502  50.294  1
141256  95.648  -77.511  50.257  1
141257  95.651  -77.518  50.219  1
141258  95.654  -77.526  50.180  1
141259  95.658  -77.534  50.136  1
141260  95.661  -77.542  50.090  1
141261  95.664  -77.551  50.046  1
141262  95.675  -77.563  50.002  1
141263  95.699  -77.583  49.959  1
141264  95.723  -77.602  49.919  1
141265  95.742  -77.612  49.880  1
141266  95.757  -77.610  49.842  1
141267  95.772  -77.608  49.805  1
141268  95.788  -77.605  49.769  1
141269  95.803  -77.604  49.734  1
141270  95.818  -77.602  49.699  1
141271  95.833  -77.599  49.663  1
141272  95.848  -77.597  49.626  1
141273  95.864  -77.595  49.590  1
141274  95.879  -77.592  49.554  1
141275  95.894  -77.591  49.521  1
141276  95.909  -77.589  49.488  1
141277  95.924  -77.586  49.455  1
141278  95.939  -77.584  49.424  1
141279  95.954  -77.582  49.394  1
141280  95.969  -77.580  49.365  1
141281  95.977  -77.584  49.339  1
141282  95.977  -77.603  49.310  1
141283  95.976  -77.623  49.279  1
141284  95.976  -77.642  49.246  1
141285  95.984  -77.652  49.210  1
141286  95.996  -77.659  49.176  1
141287  96.009  -77.665  49.143  1
141288  96.022  -77.672  49.110  1
141289  96.035  -77.678  49.079  1
141290  96.047  -77.684  49.048  1
141291  96.060  -77.691  49.016  1
141292  96.073  -77.698  48.983  1
141293  96.083  -77.708  48.949  1
141294  96.086  -77.716  48.915  1
141295  96.088  -77.724  48.880  1
141296  96.089  -77.733  48.848  1
141297  96.091  -77.742  48.815  1
141298  96.097  -77.750  48.780  1
141299  96.110  -77.760  48.745  1
141300  96.124  -77.769  48.711  1
141301  96.137  -77.778  48.676  1
141302  96.150  -77.788  48.641  1
141303  96.164  -77.797  48.609  1
141304  96.176  -77.806  48.576  1
141305  96.188  -77.815  48.544  1
141306  96.203  -77.824  48.512  1
141307  96.222  -77.827  48.481  1
141308  96.236  -77.831  48.450  1
141309  96.249  -77.833  48.419  1
141310  96.257  -77.830  48.392  1
141311  96.265  -77.827  48.365  1
141312  96.273  -77.823  48.338  1
141313  96.281  -77.820  48.312  1
141314  96.295  -77.816  48.286  1
141315  96.315  -77.812  48.261  1
141316  96.323  -77.817  48.236  1
141317  96.329  -77.822  48.212  1
141318  96.335  -77.827  48.188  1
141319  96.342  -77.833  48.164  1
141320  96.348  -77.838  48.140  1
141321  96.355  -77.843  48.116  1
141322  96.361  -77.849  48.092  1
141323  96.370  -77.855  48.068  1
141324  96.388  -77.868  48.045  1
141325  96.406  -77.880  48.021  1
141326  96.429  -77.890  47.997  1
141327  96.457  -77.897  47.973  1
141328  96.480  -77.900  47.949  1
141329  96.501  -77.901  47.923  1
141330  96.521  -77.902  47.898  1
141331  96.541  -77.902  47.875  1
141332  96.561  -77.903  47.850  1
141333  96.575  -77.889  47.825  1
141334  96.587  -77.873  47.801  1
141335  96.604  -77.874  47.775  1
141336  96.623  -77.881  47.751  1
141337  96.642  -77.889  47.727  1
141338  96.660  -77.896  47.703  1
141339  96.678  -77.903  47.680  1
141340  96.697  -77.911  47.656  1
141341  96.716  -77.918  47.633  1
141342  96.734  -77.925  47.609  1
141343  96.752  -77.932  47.585  1
141344  96.758  -77.930  47.561  1
141345  96.763  -77.928  47.537  1
141346  96.769  -77.926  47.514  1
141347  96.810  -77.938  47.491  1
141348  96.851  -77.951  47.468  1
141349  96.868  -77.953  47.444  1
141350  96.884  -77.959  47.420  1
141351  96.898  -77.975  47.396  1
141352  96.912  -77.991  47.372  1
141353  96.926  -78.007  47.349  1
141354  96.940  -78.023  47.326  1
141355  96.948  -78.038  47.303  1
141356  96.955  -78.050  47.281  1
141357  96.963  -78.043  47.260  1
141358  96.970  -78.035  47.239  1
141359  96.978  -78.028  47.218  1
141360  96.989  -78.022  47.195  1
141361  97.009  -78.027  47.173  1
141362  97.030  -78.032  47.152  1
141363  97.050  -78.037  47.131  1
141364  97.071  -78.042  47.111  1
141365  97.092  -78.047  47.091  1
141366  97.113  -78.052  47.073  1
141367  97.132  -78.059  47.055  1
141368  97.149  -78.072  47.038  1
141369  97.173  -78.061  47.023  1
141370  97.186  -78.053  47.009  1
141371  97.195  -78.050  46.996  1
141372  97.205  -78.045  46.984  1
141373  97.214  -78.040  46.972  1
141374  97.223  -78.036  46.960  1
141375  97.232  -78.031  46.950  1
141376  97.241  -78.027  46.942  1
141377  97.261  -78.028  46.934  1
141378  97.294  -78.034  46.928  1
141379  97.327  -78.042  46.918  1
141380  97.361  -78.050  46.907  1
141381  97.393  -78.056  46.894  1
141382  97.427  -78.064  46.881  1
141383  97.460  -78.072  46.869  1
141384  97.493  -78.078  46.859  1
141385  97.527  -78.084  46.849  1
141386  97.568  -78.087  46.834  1
141387  97.593  -78.109  46.818  1
141388  97.616  -78.134  46.802  1
141389  97.641  -78.158  46.785  1
141390  97.664  -78.182  46.765  1
141391  97.685  -78.199  46.745  1
141392  97.700  -78.202  46.725  1
141393  97.715  -78.206  46.704  1
141394  97.730  -78.209  46.682  1
141395  97.744  -78.213  46.661  1
141396  97.759  -78.216  46.639  1
141397  97.774  -78.219  46.618  1
141398  97.813  -78.228  46.596  1
141399  97.860  -78.239  46.573  1
141400  97.906  -78.250  46.551  1
141401  97.952  -78.261  46.529  1
141402  97.994  -78.269  46.507  1
141403  98.035  -78.275  46.484  1
141404  98.075  -78.282  46.463  1
141405  98.115  -78.290  46.441  1
141406  98.154  -78.297  46.418  1
141407  98.194  -78.304  46.395  1
141408  98.233  -78.311  46.372  1
141409  98.252  -78.363  46.349  1
141410  98.250  -78.386  46.326  1
141411  98.237  -78.386  46.303  1
141412  98.224  -78.360  46.281  1
141413  98.211  -78.332  46.258  1
141414  98.199  -78.303  46.235  1
141415  98.296  -78.313  46.214  1
141416  98.406  -78.327  46.193  1
141417  98.501  -78.343  46.172  1
141418  98.426  -78.341  46.150  1
141419  98.340  -78.333  46.130  1
141420  98.268  -78.327  46.109  1
141421  98.304  -78.308  46.088  1
141422  98.375  -78.284  46.067  1
141423  98.446  -78.260  46.046  1
141424  98.517  -78.235  46.024  1
141425  98.541  -78.231  46.001  1
141426  98.555  -78.231  45.980  1
141427  98.569  -78.230  45.957  1
141428  98.583  -78.229  45.934  1
141429  98.594  -78.219  45.911  1
141430  98.604  -78.203  45.887  1
141431  98.615  -78.185  45.863  1
141432  98.625  -78.169  45.840  1
141433  98.635  -78.151  45.817  1
141434  98.645  -78.134  45.795  1
141435  98.629  -78.125  45.773  1
141436  98.646  -78.128  45.751  1
141437  98.687  -78.122  45.731  1
141438  98.725  -78.173  45.712  1
141439  98.742  -78.211  45.692  1
141440  98.756  -78.244  45.675  1
141441  98.773  -78.275  45.658  1
141442  98.798  -78.295  45.643  1
141443  98.833  -78.304  45.630  1
141444  98.871  -78.311  45.618  1
141445  98.908  -78.319  45.604  1
141446  98.943  -78.329  45.588  1
141447  98.978  -78.339  45.570  1
141448  99.013  -78.349  45.555  1
141449  99.048  -78.360  45.539  1
141450  99.077  -78.363  45.525  1
141451  99.101  -78.362  45.510  1
141452  99.126  -78.361  45.497  1
141453  99.141  -78.364  45.483  1
141454  99.155  -78.367  45.468  1
141455  99.170  -78.369  45.454  1
141456  99.185  -78.373  45.441  1
141457  99.200  -78.376  45.428  1
141458  99.228  -78.382  45.418  1
141459  99.260  -78.390  45.407  1
141460  99.293  -78.398  45.395  1
141461  99.325  -78.406  45.384  1
141462  99.358  -78.414  45.370  1
141463  99.411  -78.426  45.358  1
141464  99.456  -78.434  45.345  1
141465  99.488  -78.435  45.332  1
141466  99.518  -78.436  45.319  1
141467  99.549  -78.438  45.305  1
141468  99.580  -78.439  45.290  1
141469  99.611  -78.440  45.278  1
141470  99.642  -78.442  45.266  1
141471  99.675  -78.463  45.254  1
141472  99.707  -78.485  45.243  1
141473  99.739  -78.507  45.229  1
141474  99.780  -78.541  45.216  1
141475  99.823  -78.576  45.203  1
141476  99.851  -78.599  45.191  1
141477  99.861  -78.606  45.178  1
141478  99.871  -78.613  45.165  1
141479  99.881  -78.620  45.152  1
141480  99.891  -78.630  45.141  1
141481  99.900  -78.639  45.129  1
141482  99.907  -78.645  45.117  1
141483  99.914  -78.652  45.105  1
141484  99.921  -78.659  45.093  1
141485  99.948  -78.668  45.081  1
141486  99.980  -78.677  45.068  1
141487  99.993  -78.689  45.054  1
141488  100.006  -78.702  45.042  1
141489  100.019  -78.714  45.030  1
141490  100.032  -78.727  45.017  1
141491  100.045  -78.739  45.007  1
141492  100.059  -78.751  44.996  1
141493  100.077  -78.764  44.985  1
141494  100.125  -78.780  44.975  1
141495  100.171  -78.797  44.964  1
141496  100.217  -78.812  44.952  1
141497  100.262  -78.827  44.939  1
141498  100.304  -78.842  44.927  1
141499  100.314  -78.852  44.913  1
141500  100.324  -78.863  44.900  1
141501  100.334  -78.874  44.887  1
141502  100.344  -78.884  44.874  1
141503  100.354  -78.898  44.860  1
141504  100.365  -78.917  44.847  1
141505  100.375  -78.937  44.833  1
141506  100.386  -78.955  44.819  1
141507  100.396  -78.975  44.805  1
141508  100.407  -78.994  44.791  1
141509  100.423  -79.006  44.775  1
141510  100.439  -79.017  44.760  1
141511  100.466  -79.034  44.744  1
141512  100.499  -79.053  44.729  1
141513  100.531  -79.071  44.714  1
141514  100.564  -79.090  44.699  1
141515  100.596  -79.110  44.683  1
141516  100.629  -79.129  44.667  1
141767  92.862  -78.160  54.259  1
141768  92.879  -78.155  54.254  1
141769  92.896  -78.150  54.248  1
141770  92.912  -78.144  54.243  1
141771  92.928  -78.138  54.238  1
141772  92.945  -78.133  54.233  1
141773  92.961  -78.128  54.228  1
141774  92.978  -78.122  54.224  1
141775  92.993  -78.117  54.219  1
141776  93.006  -78.112  54.214  1
141777  93.020  -78.108  54.209  1
141778  93.034  -78.103  54.203  1
141779  93.048  -78.098  54.198  1
141780  93.061  -78.094  54.193  1
141781  93.075  -78.088  54.189  1
141782  93.088  -78.084  54.184  1
141783  93.102  -78.078  54.178  1
141784  93.116  -78.066  54.172  1
141785  93.139  -78.054  54.166  1
141786  93.162  -78.043  54.161  1
141787  93.186  -78.031  54.157  1
141788  93.210  -78.018  54.153  1
141789  93.231  -78.002  54.148  1
141790  93.252  -77.984  54.142  1
141791  93.273  -77.965  54.136  1
141792  93.294  -77.947  54.130  1
141793  93.315  -77.929  54.124  1
141794  93.336  -77.917  54.118  1
141795  93.355  -77.910  54.112  1
141796  93.358  -77.899  54.103  1
141797  93.353  -77.907  54.093  1
141798  93.358  -77.912  54.082  1
141799  93.363  -77.916  54.072  1
141800  93.369  -77.921  54.062  1
141801  93.376  -77.924  54.050  1
141802  93.414  -77.917  54.039  1
141803  93.417  -77.899  54.027  1
141804  93.425  -77.880  54.013  1
141805  93.435  -77.860  53.999  1
141806  93.446  -77.840  53.986  1
141807  93.457  -77.821  53.972  1
141808  93.467  -77.800  53.958  1
141809  93.477  -77.780  53.944  1
141810  93.488  -77.761  53.928  1
141811  93.501  -77.751  53.911  1
141812  93.515  -77.743  53.895  1
141813  93.529  -77.736  53.878  1
141814  93.537  -77.717  53.860  1
141815  93.548  -77.703  53.842  1
141816  93.568  -77.710  53.824  1
141817  93.583  -77.701  53.803  1
141818  93.597  -77.692  53.782  1
141819  93.613  -77.682  53.761  1
141820  93.628  -77.672  53.743  1
141821  93.637  -77.668  53.724  1
141822  93.644  -77.664  53.706  1
141823  93.654  -77.661  53.689  1
141824  93.664  -77.655  53.671  1
141825  93.675  -77.651  53.652  1
141826  93.686  -77.645  53.634  1
141827  93.697  -77.641  53.616  1
141828  93.707  -77.636  53.599  1
141829  93.718  -77.631  53.582  1
141830  93.729  -77.627  53.565  1
141831  93.740  -77.621  53.547  1
141832  93.751  -77.617  53.529  1
141833  93.761  -77.612  53.512  1
141834  93.772  -77.607  53.494  1
141835  93.783  -77.602  53.477  1
141836  93.793  -77.597  53.460  1
141837  93.807  -77.593  53.443  1
141838  93.822  -77.589  53.426  1
141839  93.835  -77.585  53.409  1
141840  93.849  -77.581  53.392  1
141841  93.863  -77.577  53.375  1
141842  93.877  -77.573  53.359  1
141843  93.891  -77.569  53.343  1
141844  93.905  -77.565  53.327  1
141845  93.918  -77.561  53.311  1
141846  93.932  -77.557  53.297  1
141847  93.945  -77.554  53.283  1
141848  93.953  -77.551  53.268  1
141849  93.968  -77.538  53.253  1
141850  93.980  -77.522  53.237  1
141851  93.991  -77.504  53.220  1
141852  94.001  -77.486  53.202  1
141853  94.012  -77.479  53.183  1
141854  94.024  -77.473  53.164  1
141855  94.035  -77.467  53.146  1
141856  94.055  -77.466  53.127  1
141857  94.078  -77.464  53.109  1
141858  94.100  -77.463  53.091  1
141859  94.121  -77.461  53.073  1
141860  94.142  -77.459  53.056  1
141861  94.163  -77.457  53.040  1
141862  94.194  -77.457  53.026  1
141863  94.226  -77.458  53.012  1
141864  94.259  -77.458  53.000  1
141865  94.291  -77.459  52.989  1
141866  94.316  -77.457  52.976  1
141867  94.318  -77.450  52.963  1
141868  94.319  -77.442  52.949  1
141869  94.320  -77.435  52.935  1
141870  94.316  -77.425  52.920  1
141871  94.227  -77.385  52.904  1
141872  94.217  -77.415  52.888  1
141873  94.207  -77.445  52.875  1
141874  94.201  -77.475  52.867  1
141875  94.203  -77.496  52.858  1
141876  94.201  -77.489  52.849  1
141877  94.195  -77.467  52.836  1
141878  94.189  -77.447  52.828  1
141879  94.197  -77.434  52.819  1
141880  94.234  -77.439  52.809  1
141881  94.270  -77.442  52.798  1
141882  94.312  -77.452  52.788  1
141883  94.363  -77.457  52.781  1
141884  94.411  -77.444  52.776  1
141885  94.408  -77.433  52.773  1
141886  94.401  -77.424  52.770  1
141887  94.397  -77.407  52.768  1
141888  94.393  -77.390  52.767  1
141889  94.389  -77.373  52.764  1
141890  94.384  -77.356  52.760  1
141891  94.380  -77.338  52.752  1
141892  94.376  -77.322  52.742  1
141893  94.372  -77.304  52.728  1
141894  94.382  -77.298  52.710  1
141895  94.410  -77.308  52.688  1
141896  94.439  -77.318  52.663  1
141897  94.468  -77.328  52.637  1
141898  94.496  -77.338  52.609  1
141899  94.525  -77.348  52.577  1
141900  94.550  -77.359  52.543  1
141901  94.573  -77.371  52.507  1
141902  94.616  -77.376  52.470  1
141903  94.664  -77.413  52.432  1
141904  94.706  -77.460  52.396  1
141905  94.738  -77.500  52.363  1
141906  94.772  -77.496  52.336  1
141907  94.807  -77.492  52.309  1
141908  94.841  -77.488  52.280  1
141909  94.876  -77.484  52.246  1
141910  94.910  -77.480  52.212  1
141911  94.945  -77.476  52.180  1
141912  94.968  -77.470  52.149  1
141913  94.987  -77.461  52.119  1
141914  95.006  -77.453  52.086  1
141915  95.025  -77.445  52.050  1
141916  95.028  -77.422  52.012  1
141917  95.012  -77.380  51.972  1
141918  94.985  -77.348  51.933  1
141919  94.979  -77.311  51.895  1
141920  94.980  -77.273  51.857  1
141921  94.992  -77.261  51.817  1
141922  95.009  -77.259  51.778  1
141923  95.026  -77.257  51.738  1
141924  95.043  -77.255  51.697  1
141925  95.063  -77.258  51.658  1
141926  95.090  -77.288  51.618  1
141927  95.090  -77.291  51.578  1
141928  95.101  -77.306  51.528  1
141929  95.117  -77.326  51.474  1
141930  95.128  -77.348  51.419  1
141931  95.134  -77.366  51.362  1
141932  95.151  -77.360  51.306  1
141933  95.178  -77.360  51.250  1
141934  95.206  -77.362  51.194  1
141935  95.233  -77.363  51.140  1
141936  95.261  -77.365  51.088  1
141937  95.289  -77.367  51.037  1
141938  95.320  -77.371  50.986  1
141939  95.350  -77.375  50.939  1
141940  95.381  -77.379  50.895  1
141941  95.412  -77.382  50.851  1
141942  95.442  -77.386  50.809  1
141943  95.473  -77.390  50.771  1
141944  95.503  -77.395  50.734  1
141945  95.534  -77.398  50.698  1
141946  95.560  -77.400  50.662  1
141947  95.582  -77.401  50.626  1
141948  95.608  -77.400  50.593  1
141949  95.623  -77.412  50.562  1
141950  95.622  -77.426  50.531  1
141951  95.624  -77.436  50.499  1
141952  95.627  -77.443  50.466  1
141953  95.631  -77.451  50.431  1
141954  95.634  -77.460  50.395  1
141955  95.637  -77.467  50.356  1
141956  95.640  -77.476  50.314  1
141957  95.643  -77.483  50.275  1
141958  95.647  -77.492  50.239  1
141959  95.650  -77.500  50.202  1
141960  95.654  -77.508  50.160  1
141961  95.657  -77.516  50.115  1
141962  95.660  -77.524  50.070  1
141963  95.674  -77.539  50.025  1
141964  95.698  -77.558  49.981  1
141965  95.721  -77.577  49.940  1
141966  95.745  -77.597  49.901  1
141967  95.765  -77.609  49.861  1
141968  95.780  -77.607  49.823  1
141969  95.796  -77.605  49.785  1
141970  95.811  -77.603  49.748  1
141971  95.826  -77.601  49.713  1
141972  95.841  -77.599  49.675  1
141973  95.856  -77.596  49.637  1
141974  95.872  -77.594  49.599  1
141975  95.887  -77.592  49.561  1
141976  95.902  -77.590  49.526  1
141977  95.917  -77.588  49.491  1
141978  95.932  -77.586  49.458  1
141979  95.947  -77.583  49.427  1
141980  95.962  -77.581  49.396  1
141981  95.975  -77.581  49.366  1
141982  95.978  -77.589  49.342  1
141983  95.979  -77.602  49.314  1
141984  95.979  -77.624  49.284  1
141985  95.978  -77.645  49.252  1
141986  95.988  -77.654  49.217  1
141987  96.001  -77.661  49.183  1
141988  96.013  -77.668  49.152  1
141989  96.026  -77.676  49.121  1
141990  96.038  -77.683  49.090  1
141991  96.051  -77.690  49.059  1
141992  96.063  -77.698  49.027  1
141993  96.076  -77.705  48.995  1
141994  96.085  -77.702  48.962  1
141995  96.085  -77.711  48.928  1
141996  96.087  -77.719  48.894  1
141997  96.089  -77.727  48.862  1
141998  96.090  -77.736  48.829  1
141999  96.098  -77.745  48.795  1
142000  96.111  -77.754  48.760  1
142001  96.124  -77.764  48.726  1
142002  96.137  -77.773  48.691  1
142003  96.149  -77.782  48.657  1
142004  96.161  -77.791  48.624  1
142005  96.173  -77.800  48.591  1
142006  96.185  -77.809  48.559  1
142007  96.211  -77.814  48.528  1
142008  96.226  -77.818  48.497  1
142009  96.240  -77.821  48.466  1
142010  96.254  -77.826  48.434  1
142011  96.267  -77.827  48.407  1
142012  96.275  -77.824  48.380  1
142013  96.283  -77.821  48.353  1
142014  96.291  -77.818  48.326  1
142015  96.307  -77.814  48.302  1
142016  96.321  -77.815  48.277  1
142017  96.327  -77.820  48.251  1
142018  96.334  -77.825  48.228  1
142019  96.340  -77.830  48.204  1
142020  96.346  -77.836  48.179  1
142021  96.353  -77.841  48.155  1
142022  96.359  -77.846  48.131  1
142023  96.366  -77.852  48.106  1
142024  96.373  -77.858  48.082  1
142025  96.391  -77.870  48.059  1
142026  96.409  -77.882  48.035  1
142027  96.436  -77.890  48.010  1
142028  96.461  -77.894  47.985  1
142029  96.481  -77.895  47.961  1
142030  96.501  -77.896  47.936  1
142031  96.521  -77.896  47.911  1
142032  96.541  -77.897  47.888  1
142033  96.561  -77.898  47.863  1
142034  96.576  -77.886  47.838  1
142035  96.589  -77.869  47.813  1
142036  96.603  -77.859  47.788  1
142037  96.621  -77.866  47.763  1
142038  96.640  -77.874  47.739  1
142039  96.658  -77.881  47.717  1
142040  96.677  -77.888  47.693  1
142041  96.695  -77.896  47.669  1
142042  96.714  -77.902  47.645  1
142043  96.733  -77.910  47.621  1
142044  96.751  -77.918  47.597  1
142045  96.769  -77.924  47.573  1
142046  96.788  -77.932  47.549  1
142047  96.795  -77.931  47.527  1
142048  96.826  -77.939  47.505  1
142049  96.845  -77.943  47.482  1
142050  96.862  -77.946  47.459  1
142051  96.878  -77.952  47.435  1
142052  96.892  -77.968  47.412  1
142053  96.905  -77.984  47.389  1
142054  96.919  -78.000  47.365  1
142055  96.933  -78.015  47.341  1
142056  96.947  -78.031  47.318  1
142057  96.959  -78.039  47.297  1
142058  96.968  -78.031  47.276  1
142059  96.975  -78.024  47.255  1
142060  96.983  -78.015  47.233  1
142061  96.993  -78.010  47.210  1
142062  97.013  -78.015  47.188  1
142063  97.034  -78.020  47.167  1
142064  97.055  -78.025  47.146  1
142065  97.076  -78.030  47.127  1
142066  97.096  -78.035  47.108  1
142067  97.117  -78.040  47.089  1
142068  97.138  -78.045  47.071  1
142069  97.156  -78.054  47.054  1
142070  97.171  -78.045  47.039  1
142071  97.180  -78.040  47.024  1
142072  97.189  -78.036  47.010  1
142073  97.198  -78.031  46.997  1
142074  97.208  -78.027  46.985  1
142075  97.218  -78.024  46.974  1
142076  97.228  -78.021  46.962  1
142077  97.238  -78.018  46.952  1
142078  97.255  -78.018  46.944  1
142079  97.281  -78.021  46.936  1
142080  97.312  -78.026  46.927  1
142081  97.346  -78.033  46.916  1
142082  97.378  -78.040  46.904  1
142083  97.412  -78.047  46.893  1
142084  97.445  -78.055  46.884  1
142085  97.478  -78.062  46.874  1
142086  97.513  -78.067  46.864  1
142087  97.544  -78.083  46.850  1
142088  97.568  -78.107  46.835  1
142089  97.592  -78.131  46.818  1
142090  97.615  -78.156  46.800  1
142091  97.640  -78.180  46.780  1
142092  97.661  -78.197  46.760  1
142093  97.675  -78.201  46.740  1
142094  97.690  -78.204  46.720  1
142095  97.705  -78.207  46.699  1
142096  97.720  -78.211  46.677  1
142097  97.735  -78.214  46.654  1
142098  97.764  -78.221  46.631  1
142099  97.810  -78.232  46.609  1
142100  97.857  -78.244  46.587  1
142101  97.903  -78.254  46.565  1
142102  97.950  -78.266  46.544  1
142103  97.995  -78.275  46.522  1
142104  98.036  -78.282  46.500  1
142105  98.078  -78.289  46.477  1
142106  98.119  -78.297  46.455  1
142107  98.158  -78.304  46.432  1
142108  98.198  -78.311  46.409  1
142109  98.237  -78.318  46.385  1
142110  98.259  -78.364  46.362  1
142111  98.250  -78.374  46.339  1
142112  98.237  -78.357  46.316  1
142113  98.224  -78.329  46.293  1
142114  98.212  -78.299  46.270  1
142115  98.199  -78.270  46.248  1
142116  98.283  -78.275  46.225  1
142117  98.372  -78.291  46.203  1
142118  98.450  -78.308  46.182  1
142119  98.468  -78.331  46.159  1
142120  98.405  -78.344  46.139  1
142121  98.322  -78.334  46.118  1
142122  98.327  -78.299  46.097  1
142123  98.398  -78.275  46.076  1
142124  98.469  -78.250  46.055  1
142125  98.541  -78.226  46.033  1
142126  98.565  -78.222  46.010  1
142127  98.579  -78.221  45.989  1
142128  98.593  -78.220  45.968  1
142129  98.606  -78.213  45.945  1
142130  98.616  -78.197  45.922  1
142131  98.626  -78.179  45.898  1
142132  98.636  -78.163  45.874  1
142133  98.646  -78.146  45.851  1
142134  98.656  -78.128  45.828  1
142135  98.666  -78.112  45.807  1
142136  98.659  -78.100  45.786  1
142137  98.653  -78.100  45.764  1
142138  98.692  -78.159  45.744  1
142139  98.724  -78.212  45.723  1
142140  98.737  -78.245  45.703  1
142141  98.763  -78.265  45.686  1
142142  98.788  -78.285  45.670  1
142143  98.814  -78.304  45.655  1
142144  98.844  -78.318  45.640  1
142145  98.882  -78.325  45.627  1
142146  98.918  -78.334  45.614  1
142147  98.953  -78.344  45.599  1
142148  98.988  -78.354  45.584  1
142149  99.020  -78.361  45.568  1
142150  99.045  -78.360  45.553  1
142151  99.070  -78.359  45.539  1
142152  99.095  -78.358  45.525  1
142153  99.118  -78.358  45.511  1
142154  99.132  -78.361  45.496  1
142155  99.147  -78.363  45.482  1
142156  99.162  -78.366  45.468  1
142157  99.177  -78.369  45.454  1
142158  99.202  -78.375  45.441  1
142159  99.234  -78.383  45.430  1
142160  99.267  -78.391  45.419  1
142161  99.299  -78.399  45.407  1
142162  99.331  -78.407  45.395  1
142163  99.364  -78.415  45.383  1
142164  99.396  -78.423  45.371  1
142165  99.446  -78.435  45.358  1
142166  99.500  -78.446  45.345  1
142167  99.542  -78.452  45.332  1
142168  99.573  -78.454  45.318  1
142169  99.604  -78.455  45.303  1
142170  99.635  -78.456  45.290  1
142171  99.665  -78.457  45.278  1
142172  99.697  -78.473  45.266  1
142173  99.730  -78.495  45.254  1
142174  99.762  -78.517  45.241  1
142175  99.795  -78.539  45.228  1
142176  99.836  -78.573  45.216  1
142177  99.858  -78.590  45.204  1
142178  99.868  -78.597  45.192  1
142179  99.877  -78.606  45.180  1
142180  99.887  -78.615  45.168  1
142181  99.896  -78.624  45.157  1
142182  99.904  -78.632  45.145  1
142183  99.911  -78.639  45.134  1
142184  99.918  -78.645  45.122  1
142185  99.925  -78.651  45.110  1
142186  99.941  -78.660  45.097  1
142187  99.972  -78.669  45.083  1
142188  100.004  -78.679  45.069  1
142189  100.021  -78.690  45.056  1
142190  100.034  -78.702  45.044  1
142191  100.047  -78.714  45.031  1
142192  100.060  -78.727  45.020  1
142193  100.074  -78.739  45.008  1
142194  100.118  -78.755  44.997  1
142195  100.165  -78.772  44.986  1
142196  100.212  -78.789  44.975  1
142197  100.259  -78.805  44.963  1
142198  100.303  -78.821  44.950  1
142199  100.314  -78.831  44.937  1
142200  100.324  -78.842  44.924  1
142201  100.334  -78.852  44.911  1
142202  100.344  -78.863  44.897  1
142203  100.353  -78.874  44.883  1
142204  100.364  -78.890  44.869  1
142205  100.374  -78.909  44.855  1
142206  100.385  -78.929  44.841  1
142207  100.395  -78.948  44.826  1
142208  100.406  -78.967  44.811  1
142209  100.416  -78.987  44.797  1
142210  100.430  -79.000  44.781  1
142211  100.446  -79.012  44.765  1
142212  100.464  -79.023  44.749  1
142213  100.496  -79.043  44.733  1
142214  100.528  -79.062  44.718  1
142215  100.561  -79.081  44.703  1
142216  100.594  -79.100  44.686  1
142217  100.626  -79.118  44.670  1
142467  92.833  -78.154  54.262  1
142468  92.850  -78.149  54.258  1
142469  92.866  -78.144  54.254  1
142470  92.882  -78.138  54.248  1
142471  92.899  -78.133  54.243  1
142472  92.916  -78.128  54.239  1
142473  92.932  -78.122  54.233  1
142474  92.948  -78.116  54.229  1
142475  92.965  -78.111  54.225  1
142476  92.982  -78.106  54.221  1
142477  92.998  -78.100  54.215  1
142478  93.014  -78.095  54.210  1
142479  93.031  -78.090  54.205  1
142480  93.047  -78.084  54.200  1
142481  93.060  -78.079  54.196  1
142482  93.074  -78.075  54.192  1
142483  93.087  -78.070  54.187  1
142484  93.101  -78.065  54.182  1
142485  93.115  -78.056  54.177  1
142486  93.138  -78.044  54.171  1
142487  93.162  -78.032  54.166  1
142488  93.184  -78.016  54.162  1
142489  93.205  -77.998  54.158  1
142490  93.225  -77.980  54.154  1
142491  93.246  -77.970  54.147  1
142492  93.266  -77.964  54.141  1
142493  93.286  -77.957  54.135  1
142494  93.306  -77.951  54.131  1
142495  93.326  -77.945  54.124  1
142496  93.358  -77.883  54.117  1
142497  93.348  -77.893  54.109  1
142498  93.338  -77.903  54.099  1
142499  93.328  -77.915  54.090  1
142500  93.318  -77.925  54.080  1
142501  93.316  -77.933  54.070  1
142502  93.342  -77.926  54.059  1
142503  93.382  -77.907  54.049  1
142504  93.404  -77.887  54.038  1
142505  93.415  -77.867  54.025  1
142506  93.425  -77.847  54.012  1
142507  93.435  -77.827  53.998  1
142508  93.446  -77.808  53.984  1
142509  93.457  -77.787  53.970  1
142510  93.467  -77.768  53.957  1
142511  93.477  -77.748  53.942  1
142512  93.491  -77.739  53.926  1
142513  93.505  -77.731  53.911  1
142514  93.518  -77.723  53.895  1
142515  93.533  -77.715  53.878  1
142516  93.544  -77.702  53.861  1
142517  93.559  -77.699  53.843  1
142518  93.574  -77.689  53.822  1
142519  93.589  -77.680  53.801  1
142520  93.604  -77.670  53.780  1
142521  93.619  -77.661  53.761  1
142522  93.632  -77.653  53.742  1
142523  93.639  -77.649  53.724  1
142524  93.647  -77.646  53.707  1
142525  93.657  -77.642  53.689  1
142526  93.667  -77.637  53.671  1
142527  93.679  -77.633  53.653  1
142528  93.689  -77.627  53.635  1
142529  93.700  -77.623  53.618  1
142530  93.711  -77.617  53.601  1
142531  93.721  -77.613  53.584  1
142532  93.732  -77.608  53.567  1
142533  93.743  -77.603  53.549  1
142534  93.754  -77.599  53.532  1
142535  93.764  -77.593  53.514  1
142536  93.775  -77.589  53.497  1
142537  93.788  -77.584  53.480  1
142538  93.802  -77.580  53.463  1
142539  93.816  -77.577  53.446  1
142540  93.830  -77.572  53.429  1
142541  93.844  -77.568  53.412  1
142542  93.857  -77.564  53.396  1
142543  93.871  -77.560  53.381  1
142544  93.885  -77.556  53.365  1
142545  93.899  -77.552  53.349  1
142546  93.913  -77.548  53.335  1
142547  93.927  -77.544  53.322  1
142548  93.940  -77.540  53.311  1
142549  93.952  -77.525  53.297  1
142550  93.962  -77.507  53.283  1
142551  93.973  -77.489  53.268  1
142552  93.983  -77.471  53.252  1
142553  93.994  -77.463  53.234  1
142554  94.005  -77.457  53.216  1
142555  94.030  -77.457  53.196  1
142556  94.055  -77.457  53.177  1
142557  94.081  -77.457  53.158  1
142558  94.107  -77.458  53.140  1
142559  94.128  -77.457  53.121  1
142560  94.149  -77.455  53.102  1
142561  94.171  -77.453  53.084  1
142562  94.199  -77.453  53.067  1
142563  94.231  -77.453  53.052  1
142564  94.264  -77.454  53.041  1
142565  94.281  -77.450  53.030  1
142566  94.282  -77.442  53.020  1
142567  94.283  -77.436  53.008  1
142568  94.285  -77.428  52.995  1
142569  94.286  -77.420  52.982  1
142570  94.288  -77.413  52.968  1
142571  94.289  -77.405  52.953  1
142572  94.223  -77.379  52.937  1
142573  94.213  -77.408  52.922  1
142574  94.206  -77.439  52.907  1
142575  94.208  -77.467  52.894  1
142576  94.210  -77.478  52.883  1
142577  94.208  -77.473  52.874  1
142578  94.202  -77.451  52.865  1
142579  94.197  -77.430  52.858  1
142580  94.215  -77.423  52.850  1
142581  94.252  -77.428  52.839  1
142582  94.288  -77.432  52.828  1
142583  94.325  -77.437  52.819  1
142584  94.362  -77.442  52.810  1
142585  94.400  -77.438  52.799  1
142586  94.394  -77.424  52.789  1
142587  94.390  -77.407  52.782  1
142588  94.386  -77.390  52.779  1
142589  94.382  -77.373  52.778  1
142590  94.378  -77.356  52.778  1
142591  94.373  -77.338  52.776  1
142592  94.369  -77.321  52.770  1
142593  94.365  -77.304  52.761  1
142594  94.361  -77.287  52.748  1
142595  94.370  -77.281  52.730  1
142596  94.397  -77.291  52.709  1
142597  94.420  -77.304  52.684  1
142598  94.442  -77.316  52.658  1
142599  94.465  -77.329  52.629  1
142600  94.488  -77.341  52.597  1
142601  94.510  -77.353  52.561  1
142602  94.533  -77.365  52.524  1
142603  94.591  -77.364  52.488  1
142604  94.664  -77.357  52.451  1
142605  94.721  -77.363  52.418  1
142606  94.739  -77.432  52.389  1
142607  94.766  -77.464  52.366  1
142608  94.801  -77.459  52.341  1
142609  94.835  -77.455  52.311  1
142610  94.869  -77.451  52.276  1
142611  94.904  -77.448  52.243  1
142612  94.936  -77.443  52.212  1
142613  94.956  -77.436  52.183  1
142614  94.974  -77.427  52.153  1
142615  94.993  -77.419  52.121  1
142616  95.013  -77.411  52.085  1
142617  95.031  -77.403  52.047  1
142618  95.015  -77.361  52.008  1
142619  94.989  -77.329  51.969  1
142620  94.989  -77.291  51.930  1
142621  94.996  -77.267  51.893  1
142622  95.014  -77.265  51.853  1
142623  95.031  -77.263  51.813  1
142624  95.048  -77.261  51.772  1
142625  95.065  -77.260  51.731  1
142626  95.082  -77.257  51.692  1
142627  95.099  -77.256  51.651  1
142628  95.113  -77.271  51.610  1
142629  95.126  -77.292  51.558  1
142630  95.129  -77.316  51.505  1
142631  95.131  -77.341  51.449  1
142632  95.138  -77.356  51.393  1
142633  95.155  -77.350  51.336  1
142634  95.171  -77.344  51.279  1
142635  95.191  -77.340  51.220  1
142636  95.219  -77.341  51.164  1
142637  95.246  -77.342  51.110  1
142638  95.274  -77.344  51.058  1
142639  95.302  -77.346  51.008  1
142640  95.332  -77.350  50.961  1
142641  95.363  -77.354  50.916  1
142642  95.394  -77.357  50.873  1
142643  95.424  -77.361  50.830  1
142644  95.455  -77.365  50.789  1
142645  95.485  -77.370  50.750  1
142646  95.516  -77.373  50.713  1
142647  95.547  -77.377  50.678  1
142648  95.578  -77.381  50.643  1
142649  95.607  -77.389  50.610  1
142650  95.616  -77.398  50.580  1
142651  95.617  -77.402  50.551  1
142652  95.620  -77.409  50.520  1
142653  95.623  -77.417  50.486  1
142654  95.627  -77.425  50.453  1
142655  95.630  -77.433  50.417  1
142656  95.633  -77.441  50.378  1
142657  95.636  -77.449  50.336  1
142658  95.639  -77.457  50.299  1
142659  95.643  -77.465  50.262  1
142660  95.646  -77.473  50.225  1
142661  95.649  -77.481  50.183  1
142662  95.653  -77.489  50.139  1
142663  95.656  -77.497  50.094  1
142664  95.673  -77.514  50.049  1
142665  95.696  -77.533  50.006  1
142666  95.720  -77.552  49.964  1
142667  95.744  -77.572  49.922  1
142668  95.767  -77.592  49.882  1
142669  95.789  -77.606  49.842  1
142670  95.804  -77.604  49.803  1
142671  95.819  -77.602  49.765  1
142672  95.834  -77.600  49.727  1
142673  95.849  -77.598  49.688  1
142674  95.865  -77.595  49.648  1
142675  95.880  -77.593  49.607  1
142676  95.895  -77.592  49.568  1
142677  95.910  -77.589  49.531  1
142678  95.925  -77.587  49.495  1
142679  95.940  -77.585  49.461  1
142680  95.955  -77.583  49.429  1
142681  95.970  -77.580  49.399  1
142682  95.976  -77.586  49.369  1
142683  95.979  -77.593  49.341  1
142684  95.982  -77.602  49.313  1
142685  95.981  -77.624  49.286  1
142686  95.980  -77.645  49.256  1
142687  95.990  -77.663  49.223  1
142688  96.003  -77.677  49.190  1
142689  96.015  -77.683  49.158  1
142690  96.027  -77.691  49.126  1
142691  96.040  -77.699  49.095  1
142692  96.052  -77.705  49.064  1
142693  96.065  -77.713  49.035  1
142694  96.080  -77.699  49.004  1
142695  96.087  -77.695  48.972  1
142696  96.088  -77.704  48.940  1
142697  96.088  -77.713  48.908  1
142698  96.088  -77.722  48.877  1
142699  96.090  -77.730  48.844  1
142700  96.098  -77.740  48.810  1
142701  96.110  -77.749  48.776  1
142702  96.122  -77.758  48.741  1
142703  96.134  -77.767  48.706  1
142704  96.146  -77.777  48.671  1
142705  96.158  -77.786  48.639  1
142706  96.170  -77.795  48.606  1
142707  96.194  -77.799  48.574  1
142708  96.215  -77.804  48.544  1
142709  96.229  -77.808  48.512  1
142710  96.244  -77.812  48.481  1
142711  96.258  -77.816  48.450  1
142712  96.272  -77.820  48.422  1
142713  96.286  -77.822  48.396  1
142714  96.294  -77.819  48.369  1
142715  96.302  -77.816  48.343  1
142716  96.319  -77.812  48.317  1
142717  96.325  -77.818  48.292  1
142718  96.332  -77.823  48.267  1
142719  96.338  -77.828  48.244  1
142720  96.344  -77.834  48.220  1
142721  96.351  -77.839  48.195  1
142722  96.358  -77.844  48.171  1
142723  96.364  -77.849  48.146  1
142724  96.370  -77.855  48.121  1
142725  96.376  -77.860  48.096  1
142726  96.394  -77.872  48.072  1
142727  96.415  -77.883  48.048  1
142728  96.442  -77.889  48.024  1
142729  96.462  -77.890  47.999  1
142730  96.482  -77.890  47.975  1
142731  96.502  -77.891  47.950  1
142732  96.522  -77.891  47.925  1
142733  96.542  -77.892  47.902  1
142734  96.562  -77.893  47.876  1
142735  96.577  -77.882  47.851  1
142736  96.590  -77.865  47.827  1
142737  96.603  -77.849  47.803  1
142738  96.620  -77.851  47.777  1
142739  96.639  -77.859  47.752  1
142740  96.657  -77.865  47.729  1
142741  96.675  -77.873  47.705  1
142742  96.694  -77.881  47.681  1
142743  96.713  -77.887  47.657  1
142744  96.731  -77.895  47.633  1
142745  96.749  -77.902  47.610  1
142746  96.768  -77.909  47.587  1
142747  96.787  -77.917  47.564  1
142748  96.805  -77.924  47.542  1
142749  96.822  -77.931  47.520  1
142750  96.838  -77.934  47.498  1
142751  96.856  -77.937  47.475  1
142752  96.872  -77.945  47.453  1
142753  96.885  -77.961  47.429  1
142754  96.899  -77.977  47.405  1
142755  96.911  -77.990  47.381  1
142756  96.920  -77.997  47.357  1
142757  96.929  -78.004  47.334  1
142758  96.938  -78.011  47.314  1
142759  96.953  -78.010  47.291  1
142760  96.970  -78.007  47.270  1
142761  96.987  -78.003  47.249  1
142762  96.997  -77.998  47.229  1
142763  97.018  -78.003  47.207  1
142764  97.038  -78.008  47.184  1
142765  97.059  -78.012  47.163  1
142766  97.080  -78.017  47.145  1
142767  97.100  -78.022  47.125  1
142768  97.120  -78.026  47.105  1
142769  97.141  -78.031  47.088  1
142770  97.161  -78.041  47.071  1
142771  97.171  -78.038  47.055  1
142772  97.181  -78.035  47.039  1
142773  97.191  -78.032  47.025  1
142774  97.202  -78.029  47.012  1
142775  97.212  -78.026  47.000  1
142776  97.222  -78.023  46.987  1
142777  97.232  -78.020  46.976  1
142778  97.244  -78.015  46.965  1
142779  97.267  -78.012  46.955  1
142780  97.289  -78.025  46.946  1
142781  97.313  -78.033  46.936  1
142782  97.342  -78.033  46.926  1
142783  97.369  -78.033  46.915  1
142784  97.397  -78.033  46.905  1
142785  97.430  -78.038  46.896  1
142786  97.463  -78.046  46.888  1
142787  97.495  -78.056  46.878  1
142788  97.519  -78.081  46.865  1
142789  97.543  -78.105  46.849  1
142790  97.567  -78.129  46.832  1
142791  97.591  -78.153  46.815  1
142792  97.615  -78.178  46.794  1
142793  97.636  -78.197  46.775  1
142794  97.651  -78.200  46.756  1
142795  97.666  -78.203  46.736  1
142796  97.680  -78.206  46.714  1
142797  97.696  -78.210  46.691  1
142798  97.715  -78.214  46.668  1
142799  97.761  -78.225  46.645  1
142800  97.808  -78.236  46.623  1
142801  97.855  -78.247  46.602  1
142802  97.901  -78.259  46.580  1
142803  97.948  -78.270  46.558  1
142804  97.994  -78.281  46.536  1
142805  98.037  -78.289  46.514  1
142806  98.079  -78.297  46.491  1
142807  98.121  -78.304  46.469  1
142808  98.162  -78.310  46.446  1
142809  98.202  -78.318  46.422  1
142810  98.241  -78.325  46.399  1
142811  98.264  -78.362  46.375  1
142812  98.250  -78.354  46.351  1
142813  98.238  -78.325  46.328  1
142814  98.225  -78.296  46.305  1
142815  98.212  -78.267  46.283  1
142816  98.201  -78.238  46.260  1
142817  98.243  -78.241  46.237  1
142818  98.321  -78.257  46.214  1
142819  98.399  -78.274  46.192  1
142820  98.477  -78.291  46.168  1
142821  98.437  -78.319  46.146  1
142822  98.384  -78.345  46.125  1
142823  98.370  -78.312  46.105  1
142824  98.422  -78.266  46.085  1
142825  98.493  -78.241  46.065  1
142826  98.564  -78.217  46.043  1
142827  98.590  -78.212  46.020  1
142828  98.604  -78.211  45.998  1
142829  98.618  -78.207  45.976  1
142830  98.628  -78.191  45.954  1
142831  98.638  -78.173  45.932  1
142832  98.648  -78.156  45.908  1
142833  98.658  -78.140  45.885  1
142834  98.668  -78.122  45.863  1
142835  98.678  -78.106  45.840  1
142836  98.688  -78.088  45.819  1
142837  98.689  -78.074  45.797  1
142838  98.689  -78.114  45.775  1
142839  98.706  -78.196  45.754  1
142840  98.728  -78.235  45.734  1
142841  98.753  -78.254  45.716  1
142842  98.779  -78.274  45.698  1
142843  98.804  -78.294  45.682  1
142844  98.830  -78.313  45.667  1
142845  98.856  -78.332  45.652  1
142846  98.893  -78.339  45.638  1
142847  98.928  -78.348  45.624  1
142848  98.963  -78.359  45.610  1
142849  98.989  -78.359  45.595  1
142850  99.014  -78.357  45.582  1
142851  99.039  -78.357  45.568  1
142852  99.064  -78.355  45.553  1
142853  99.088  -78.354  45.540  1
142854  99.109  -78.355  45.525  1
142855  99.124  -78.357  45.510  1
142856  99.139  -78.360  45.495  1
142857  99.153  -78.363  45.481  1
142858  99.175  -78.368  45.467  1
142859  99.208  -78.376  45.454  1
142860  99.240  -78.384  45.441  1
142861  99.273  -78.392  45.430  1
142862  99.305  -78.401  45.419  1
142863  99.337  -78.408  45.407  1
142864  99.370  -78.416  45.396  1
142865  99.402  -78.424  45.383  1
142866  99.435  -78.432  45.371  1
142867  99.482  -78.443  45.359  1
142868  99.535  -78.454  45.345  1
142869  99.588  -78.467  45.330  1
142870  99.627  -78.471  45.315  1
142871  99.658  -78.473  45.303  1
142872  99.689  -78.473  45.290  1
142873  99.720  -78.482  45.277  1
142874  99.753  -78.504  45.265  1
142875  99.785  -78.526  45.253  1
142876  99.818  -78.548  45.241  1
142877  99.850  -78.571  45.230  1
142878  99.864  -78.582  45.217  1
142879  99.873  -78.592  45.205  1
142880  99.883  -78.601  45.194  1
142881  99.892  -78.610  45.184  1
142882  99.900  -78.618  45.171  1
142883  99.907  -78.624  45.159  1
142884  99.914  -78.631  45.148  1
142885  99.921  -78.638  45.136  1
142886  99.928  -78.645  45.123  1
142887  99.935  -78.651  45.110  1
142888  99.965  -78.661  45.097  1
142889  99.997  -78.670  45.082  1
142890  100.028  -78.680  45.069  1
142891  100.049  -78.691  45.057  1
142892  100.062  -78.703  45.044  1
142893  100.075  -78.715  45.032  1
142894  100.111  -78.730  45.020  1
142895  100.158  -78.747  45.008  1
142896  100.206  -78.764  44.997  1
142897  100.253  -78.781  44.985  1
142898  100.292  -78.799  44.973  1
142899  100.312  -78.811  44.961  1
142900  100.322  -78.821  44.948  1
142901  100.333  -78.832  44.934  1
142902  100.343  -78.842  44.921  1
142903  100.353  -78.852  44.907  1
142904  100.363  -78.863  44.891  1
142905  100.373  -78.882  44.877  1
142906  100.384  -78.902  44.863  1
142907  100.395  -78.921  44.848  1
142908  100.405  -78.940  44.833  1
142909  100.415  -78.959  44.818  1
142910  100.426  -78.978  44.803  1
142911  100.438  -78.996  44.788  1
142912  100.454  -79.006  44.772  1
142913  100.471  -79.018  44.755  1
142914  100.494  -79.032  44.739  1
142915  100.526  -79.051  44.723  1
142916  100.559  -79.071  44.707  1
142917  100.591  -79.090  44.690  1
142918  100.624  -79.109  44.675  1
142919  100.656  -79.128  44.659  1
143168  92.820  -78.144  54.260  1
143169  92.837  -78.138  54.256  1
143170  92.853  -78.132  54.253  1
143171  92.870  -78.127  54.247  1
143172  92.886  -78.122  54.241  1
143173  92.903  -78.116  54.237  1
143174  92.919  -78.111  54.234  1
143175  92.936  -78.106  54.229  1
143176  92.952  -78.100  54.225  1
143177  92.969  -78.094  54.221  1
143178  92.985  -78.089  54.216  1
143179  93.002  -78.084  54.211  1
143180  93.018  -78.078  54.207  1
143181  93.035  -78.073  54.202  1
143182  93.051  -78.068  54.198  1
143183  93.068  -78.062  54.194  1
143184  93.084  -78.056  54.190  1
143185  93.100  -78.051  54.187  1
143186  93.114  -78.046  54.182  1
143187  93.136  -78.031  54.176  1
143188  93.156  -78.023  54.170  1
143189  93.176  -78.017  54.166  1
143190  93.196  -78.011  54.162  1
143191  93.216  -78.004  54.158  1
143192  93.236  -77.998  54.153  1
143193  93.256  -77.992  54.146  1
143194  93.276  -77.985  54.141  1
143195  93.296  -77.979  54.136  1
143196  93.319  -77.962  54.131  1
143197  93.349  -77.876  54.125  1
143198  93.339  -77.887  54.117  1
143199  93.329  -77.898  54.108  1
143200  93.319  -77.909  54.098  1
143201  93.303  -77.938  54.088  1
143202  93.301  -77.927  54.079  1
143203  93.308  -77.912  54.070  1
143204  93.346  -77.893  54.060  1
143205  93.386  -77.874  54.049  1
143206  93.404  -77.854  54.036  1
143207  93.414  -77.834  54.024  1
143208  93.425  -77.815  54.009  1
143209  93.435  -77.795  53.995  1
143210  93.446  -77.774  53.983  1
143211  93.456  -77.755  53.970  1
143212  93.467  -77.735  53.956  1
143213  93.480  -77.726  53.942  1
143214  93.494  -77.718  53.927  1
143215  93.508  -77.711  53.912  1
143216  93.522  -77.702  53.897  1
143217  93.536  -77.695  53.880  1
143218  93.551  -77.687  53.862  1
143219  93.565  -77.677  53.842  1
143220  93.580  -77.668  53.820  1
143221  93.595  -77.658  53.799  1
143222  93.610  -77.649  53.780  1
143223  93.625  -77.639  53.761  1
143224  93.634  -77.635  53.744  1
143225  93.642  -77.631  53.727  1
143226  93.650  -77.628  53.709  1
143227  93.660  -77.624  53.691  1
143228  93.671  -77.619  53.674  1
143229  93.682  -77.614  53.656  1
143230  93.692  -77.609  53.639  1
143231  93.703  -77.605  53.621  1
143232  93.714  -77.599  53.604  1
143233  93.724  -77.595  53.587  1
143234  93.735  -77.589  53.570  1
143235  93.746  -77.585  53.552  1
143236  93.757  -77.580  53.535  1
143237  93.769  -77.576  53.517  1
143238  93.783  -77.571  53.501  1
143239  93.796  -77.567  53.484  1
143240  93.811  -77.564  53.468  1
143241  93.824  -77.559  53.451  1
143242  93.838  -77.555  53.435  1
143243  93.852  -77.551  53.418  1
143244  93.866  -77.547  53.402  1
143245  93.880  -77.543  53.387  1
143246  93.894  -77.539  53.372  1
143247  93.908  -77.535  53.359  1
143248  93.923  -77.526  53.347  1
143249  93.939  -77.508  53.338  1
143250  93.947  -77.490  53.327  1
143251  93.954  -77.473  53.313  1
143252  93.965  -77.456  53.299  1
143253  93.978  -77.448  53.284  1
143254  94.004  -77.448  53.267  1
143255  94.030  -77.448  53.249  1
143256  94.055  -77.449  53.230  1
143257  94.081  -77.449  53.211  1
143258  94.106  -77.450  53.191  1
143259  94.132  -77.450  53.172  1
143260  94.157  -77.451  53.153  1
143261  94.179  -77.449  53.133  1
143262  94.204  -77.448  53.113  1
143263  94.237  -77.448  53.095  1
143264  94.245  -77.442  53.080  1
143265  94.247  -77.436  53.069  1
143266  94.248  -77.428  53.060  1
143267  94.250  -77.420  53.051  1
143268  94.251  -77.413  53.040  1
143269  94.252  -77.406  53.028  1
143270  94.254  -77.398  53.015  1
143271  94.255  -77.391  53.002  1
143272  94.257  -77.383  52.988  1
143273  94.219  -77.372  52.972  1
143274  94.211  -77.401  52.956  1
143275  94.214  -77.431  52.941  1
143276  94.216  -77.457  52.925  1
143277  94.217  -77.460  52.911  1
143278  94.216  -77.456  52.900  1
143279  94.210  -77.435  52.892  1
143280  94.204  -77.414  52.887  1
143281  94.233  -77.414  52.881  1
143282  94.270  -77.418  52.870  1
143283  94.307  -77.423  52.857  1
143284  94.343  -77.427  52.847  1
143285  94.380  -77.432  52.839  1
143286  94.393  -77.423  52.829  1
143287  94.389  -77.405  52.816  1
143288  94.386  -77.388  52.804  1
143289  94.382  -77.370  52.793  1
143290  94.378  -77.353  52.790  1
143291  94.374  -77.336  52.787  1
143292  94.370  -77.319  52.784  1
143293  94.367  -77.301  52.780  1
143294  94.363  -77.284  52.772  1
143295  94.372  -77.273  52.760  1
143296  94.391  -77.268  52.744  1
143297  94.413  -77.280  52.722  1
143298  94.435  -77.292  52.698  1
143299  94.458  -77.304  52.672  1
143300  94.481  -77.317  52.644  1
143301  94.503  -77.329  52.613  1
143302  94.526  -77.341  52.578  1
143303  94.547  -77.350  52.541  1
143304  94.567  -77.351  52.505  1
143305  94.637  -77.345  52.472  1
143306  94.710  -77.334  52.444  1
143307  94.743  -77.355  52.419  1
143308  94.761  -77.424  52.397  1
143309  94.794  -77.426  52.369  1
143310  94.828  -77.423  52.338  1
143311  94.862  -77.419  52.302  1
143312  94.897  -77.415  52.273  1
143313  94.924  -77.409  52.245  1
143314  94.943  -77.401  52.216  1
143315  94.962  -77.393  52.188  1
143316  94.981  -77.385  52.154  1
143317  95.000  -77.377  52.118  1
143318  95.019  -77.369  52.080  1
143319  95.019  -77.342  52.041  1
143320  94.999  -77.307  52.003  1
143321  95.001  -77.273  51.965  1
143322  95.019  -77.272  51.928  1
143323  95.036  -77.269  51.888  1
143324  95.053  -77.268  51.847  1
143325  95.070  -77.266  51.805  1
143326  95.087  -77.264  51.765  1
143327  95.104  -77.262  51.725  1
143328  95.113  -77.260  51.685  1
143329  95.126  -77.261  51.642  1
143330  95.129  -77.285  51.590  1
143331  95.131  -77.310  51.536  1
143332  95.134  -77.335  51.480  1
143333  95.142  -77.347  51.425  1
143334  95.158  -77.341  51.368  1
143335  95.175  -77.334  51.308  1
143336  95.191  -77.328  51.246  1
143337  95.207  -77.321  51.188  1
143338  95.232  -77.320  51.133  1
143339  95.259  -77.322  51.080  1
143340  95.286  -77.323  51.030  1
143341  95.315  -77.325  50.982  1
143342  95.345  -77.329  50.938  1
143343  95.376  -77.332  50.895  1
143344  95.406  -77.336  50.852  1
143345  95.437  -77.340  50.809  1
143346  95.468  -77.345  50.768  1
143347  95.498  -77.348  50.730  1
143348  95.529  -77.352  50.695  1
143349  95.559  -77.356  50.661  1
143350  95.588  -77.370  50.628  1
143351  95.614  -77.392  50.598  1
143352  95.621  -77.400  50.569  1
143353  95.623  -77.404  50.540  1
143354  95.625  -77.408  50.507  1
143355  95.627  -77.412  50.474  1
143356  95.629  -77.416  50.438  1
143357  95.631  -77.420  50.398  1
143358  95.632  -77.423  50.355  1
143359  95.635  -77.430  50.319  1
143360  95.638  -77.439  50.283  1
143361  95.642  -77.446  50.246  1
143362  95.645  -77.454  50.205  1
143363  95.649  -77.463  50.162  1
143364  95.652  -77.470  50.118  1
143365  95.672  -77.489  50.074  1
143366  95.695  -77.508  50.030  1
143367  95.719  -77.527  49.987  1
143368  95.742  -77.547  49.945  1
143369  95.766  -77.567  49.904  1
143370  95.790  -77.586  49.863  1
143371  95.812  -77.604  49.822  1
143372  95.827  -77.602  49.782  1
143373  95.842  -77.599  49.741  1
143374  95.858  -77.597  49.700  1
143375  95.873  -77.595  49.659  1
143376  95.888  -77.592  49.616  1
143377  95.903  -77.591  49.576  1
143378  95.918  -77.589  49.538  1
143379  95.933  -77.586  49.501  1
143380  95.949  -77.584  49.467  1
143381  95.964  -77.582  49.435  1
143382  95.974  -77.583  49.404  1
143383  95.977  -77.591  49.373  1
143384  95.981  -77.599  49.343  1
143385  95.984  -77.605  49.314  1
143386  95.984  -77.624  49.285  1
143387  95.983  -77.645  49.256  1
143388  95.993  -77.663  49.226  1
143389  96.005  -77.680  49.195  1
143390  96.016  -77.699  49.165  1
143391  96.029  -77.706  49.134  1
143392  96.041  -77.714  49.106  1
143393  96.054  -77.721  49.077  1
143394  96.068  -77.711  49.049  1
143395  96.085  -77.688  49.018  1
143396  96.090  -77.687  48.986  1
143397  96.090  -77.696  48.954  1
143398  96.091  -77.705  48.922  1
143399  96.091  -77.714  48.890  1
143400  96.095  -77.724  48.858  1
143401  96.095  -77.733  48.826  1
143402  96.107  -77.743  48.792  1
143403  96.119  -77.752  48.757  1
143404  96.131  -77.761  48.722  1
143405  96.143  -77.771  48.686  1
143406  96.155  -77.780  48.654  1
143407  96.176  -77.786  48.622  1
143408  96.203  -77.790  48.590  1
143409  96.218  -77.794  48.559  1
143410  96.233  -77.798  48.527  1
143411  96.247  -77.802  48.496  1
143412  96.261  -77.806  48.465  1
143413  96.276  -77.811  48.438  1
143414  96.291  -77.815  48.412  1
143415  96.304  -77.818  48.386  1
143416  96.312  -77.814  48.360  1
143417  96.324  -77.816  48.334  1
143418  96.330  -77.821  48.309  1
143419  96.336  -77.826  48.283  1
143420  96.343  -77.831  48.260  1
143421  96.349  -77.837  48.237  1
143422  96.356  -77.842  48.212  1
143423  96.362  -77.847  48.188  1
143424  96.368  -77.852  48.163  1
143425  96.375  -77.858  48.137  1
143426  96.381  -77.863  48.112  1
143427  96.396  -77.874  48.088  1
143428  96.422  -77.883  48.064  1
143429  96.442  -77.884  48.039  1
143430  96.462  -77.884  48.015  1
143431  96.482  -77.885  47.989  1
143432  96.503  -77.886  47.964  1
143433  96.523  -77.887  47.940  1
143434  96.543  -77.887  47.916  1
143435  96.563  -77.887  47.891  1
143436  96.579  -77.878  47.866  1
143437  96.591  -77.862  47.841  1
143438  96.604  -77.846  47.817  1
143439  96.618  -77.836  47.792  1
143440  96.637  -77.843  47.767  1
143441  96.656  -77.850  47.744  1
143442  96.674  -77.858  47.720  1
143443  96.692  -77.865  47.695  1
143444  96.711  -77.872  47.671  1
143445  96.730  -77.880  47.647  1
143446  96.748  -77.887  47.624  1
143447  96.766  -77.894  47.601  1
143448  96.785  -77.901  47.578  1
143449  96.803  -77.909  47.556  1
143450  96.818  -77.915  47.535  1
143451  96.834  -77.922  47.513  1
143452  96.850  -77.929  47.491  1
143453  96.865  -77.937  47.469  1
143454  96.874  -77.946  47.445  1
143455  96.883  -77.953  47.420  1
143456  96.892  -77.960  47.397  1
143457  96.900  -77.967  47.372  1
143458  96.909  -77.974  47.350  1
143459  96.918  -77.981  47.329  1
143460  96.929  -77.985  47.307  1
143461  96.951  -77.984  47.286  1
143462  96.974  -77.983  47.266  1
143463  96.998  -77.982  47.246  1
143464  97.018  -77.987  47.225  1
143465  97.038  -77.991  47.202  1
143466  97.058  -77.996  47.180  1
143467  97.079  -78.000  47.162  1
143468  97.099  -78.006  47.141  1
143469  97.119  -78.010  47.122  1
143470  97.140  -78.016  47.104  1
143471  97.161  -78.034  47.087  1
143472  97.175  -78.037  47.071  1
143473  97.185  -78.034  47.055  1
143474  97.195  -78.031  47.041  1
143475  97.205  -78.028  47.027  1
143476  97.215  -78.025  47.014  1
143477  97.225  -78.022  47.001  1
143478  97.235  -78.019  46.990  1
143479  97.257  -78.008  46.978  1
143480  97.281  -78.007  46.967  1
143481  97.302  -78.020  46.957  1
143482  97.323  -78.034  46.947  1
143483  97.346  -78.044  46.936  1
143484  97.373  -78.044  46.925  1
143485  97.401  -78.044  46.917  1
143486  97.430  -78.044  46.908  1
143487  97.458  -78.044  46.900  1
143488  97.470  -78.054  46.892  1
143489  97.495  -78.078  46.878  1
143490  97.518  -78.103  46.862  1
143491  97.542  -78.127  46.845  1
143492  97.566  -78.152  46.828  1
143493  97.590  -78.176  46.809  1
143494  97.611  -78.195  46.790  1
143495  97.627  -78.198  46.772  1
143496  97.641  -78.202  46.751  1
143497  97.656  -78.205  46.728  1
143498  97.671  -78.208  46.704  1
143499  97.712  -78.218  46.682  1
143500  97.759  -78.229  46.659  1
143501  97.805  -78.241  46.637  1
143502  97.852  -78.252  46.616  1
143503  97.898  -78.263  46.594  1
143504  97.945  -78.274  46.572  1
143505  97.992  -78.285  46.551  1
143506  98.038  -78.296  46.529  1
143507  98.080  -78.304  46.505  1
143508  98.122  -78.310  46.482  1
143509  98.163  -78.317  46.459  1
143510  98.205  -78.325  46.434  1
143511  98.245  -78.332  46.411  1
143512  98.264  -78.349  46.387  1
143513  98.251  -78.321  46.363  1
143514  98.243  -78.294  46.341  1
143515  98.255  -78.272  46.318  1
143516  98.267  -78.251  46.295  1
143517  98.278  -78.231  46.272  1
143518  98.258  -78.233  46.249  1
143519  98.292  -78.235  46.225  1
143520  98.348  -78.240  46.202  1
143521  98.426  -78.257  46.179  1
143522  98.454  -78.279  46.156  1
143523  98.405  -78.308  46.134  1
143524  98.423  -78.310  46.114  1
143525  98.459  -78.274  46.093  1
143526  98.515  -78.232  46.072  1
143527  98.586  -78.208  46.051  1
143528  98.615  -78.202  46.029  1
143529  98.629  -78.201  46.007  1
143530  98.639  -78.184  45.986  1
143531  98.649  -78.167  45.964  1
143532  98.659  -78.150  45.943  1
143533  98.669  -78.134  45.919  1
143534  98.679  -78.116  45.896  1
143535  98.690  -78.100  45.874  1
143536  98.700  -78.082  45.852  1
143537  98.710  -78.065  45.830  1
143538  98.719  -78.049  45.809  1
143539  98.724  -78.113  45.787  1
143540  98.727  -78.184  45.765  1
143541  98.740  -78.234  45.746  1
143542  98.767  -78.257  45.727  1
143543  98.793  -78.279  45.710  1
143544  98.819  -78.301  45.695  1
143545  98.845  -78.322  45.680  1
143546  98.871  -78.341  45.665  1
143547  98.904  -78.354  45.650  1
143548  98.933  -78.357  45.635  1
143549  98.957  -78.356  45.620  1
143550  98.982  -78.354  45.607  1
143551  99.007  -78.354  45.594  1
143552  99.032  -78.352  45.581  1
143553  99.057  -78.351  45.567  1
143554  99.082  -78.350  45.553  1
143555  99.100  -78.351  45.539  1
143556  99.115  -78.354  45.524  1
143557  99.130  -78.357  45.509  1
143558  99.149  -78.361  45.495  1
143559  99.181  -78.369  45.480  1
143560  99.214  -78.377  45.466  1
143561  99.246  -78.385  45.454  1
143562  99.279  -78.393  45.442  1
143563  99.311  -78.401  45.431  1
143564  99.343  -78.410  45.420  1
143565  99.376  -78.417  45.408  1
143566  99.408  -78.426  45.395  1
143567  99.441  -78.433  45.382  1
143568  99.473  -78.442  45.369  1
143569  99.517  -78.451  45.356  1
143570  99.570  -78.463  45.342  1
143571  99.624  -78.475  45.328  1
143572  99.677  -78.486  45.314  1
143573  99.712  -78.489  45.302  1
143574  99.743  -78.491  45.289  1
143575  99.776  -78.514  45.277  1
143576  99.808  -78.535  45.265  1
143577  99.833  -78.557  45.254  1
143578  99.855  -78.579  45.242  1
143579  99.869  -78.578  45.229  1
143580  99.878  -78.587  45.218  1
143581  99.888  -78.596  45.207  1
143582  99.896  -78.604  45.197  1
143583  99.903  -78.611  45.185  1
143584  99.910  -78.617  45.173  1
143585  99.917  -78.624  45.161  1
143586  99.924  -78.631  45.150  1
143587  99.931  -78.637  45.137  1
143588  99.939  -78.644  45.124  1
143589  99.958  -78.652  45.110  1
143590  99.990  -78.661  45.095  1
143591  100.021  -78.671  45.082  1
143592  100.053  -78.681  45.070  1
143593  100.077  -78.691  45.057  1
143594  100.104  -78.705  45.044  1
143595  100.150  -78.722  45.032  1
143596  100.188  -78.741  45.020  1
143597  100.226  -78.759  45.007  1
143598  100.264  -78.777  44.995  1
143599  100.296  -78.794  44.983  1
143600  100.315  -78.805  44.971  1
143601  100.328  -78.816  44.958  1
143602  100.339  -78.827  44.944  1
143603  100.349  -78.836  44.929  1
143604  100.359  -78.846  44.915  1
143605  100.370  -78.856  44.900  1
143606  100.383  -78.874  44.885  1
143607  100.394  -78.893  44.870  1
143608  100.404  -78.913  44.855  1
143609  100.414  -78.932  44.840  1
143610  100.425  -78.952  44.825  1
143611  100.435  -78.971  44.810  1
143612  100.446  -78.990  44.794  1
143613  100.462  -79.002  44.778  1
143614  100.478  -79.012  44.762  1
143615  100.494  -79.024  44.746  1
143616  100.524  -79.041  44.729  1
143617  100.556  -79.060  44.712  1
143618  100.588  -79.080  44.696  1
143619  100.621  -79.099  44.679  1
143620  100.653  -79.118  44.664  1
143621  100.686  -79.137  44.647  1
143622  100.718  -79.156  44.631  1
143868  92.786  -78.116  54.262  1
143869  92.804  -78.119  54.258  1
143870  92.823  -78.122  54.253  1
143871  92.840  -78.122  54.250  1
143872  92.857  -78.116  54.245  1
143873  92.873  -78.110  54.240  1
143874  92.890  -78.105  54.236  1
143875  92.906  -78.100  54.232  1
143876  92.923  -78.094  54.228  1
143877  92.939  -78.089  54.224  1
143878  92.956  -78.084  54.221  1
143879  92.972  -78.078  54.216  1
143880  92.989  -78.072  54.212  1
143881  93.005  -78.067  54.208  1
143882  93.022  -78.062  54.203  1
143883  93.038  -78.056  54.199  1
143884  93.055  -78.051  54.196  1
143885  93.071  -78.045  54.194  1
143886  93.088  -78.040  54.192  1
143887  93.106  -78.038  54.186  1
143888  93.126  -78.040  54.180  1
143889  93.146  -78.044  54.175  1
143890  93.166  -78.045  54.170  1
143891  93.187  -78.039  54.166  1
143892  93.207  -78.032  54.163  1
143893  93.227  -78.026  54.158  1
143894  93.247  -78.020  54.153  1
143895  93.267  -78.013  54.148  1
143896  93.287  -78.007  54.143  1
143897  93.325  -77.918  54.139  1
143898  93.339  -77.871  54.134  1
143899  93.324  -77.897  54.127  1
143900  93.307  -77.932  54.119  1
143901  93.300  -77.936  54.109  1
143902  93.299  -77.921  54.100  1
143903  93.298  -77.906  54.091  1
143904  93.300  -77.892  54.082  1
143905  93.316  -77.879  54.072  1
143906  93.350  -77.861  54.061  1
143907  93.390  -77.841  54.049  1
143908  93.404  -77.821  54.035  1
143909  93.414  -77.802  54.022  1
143910  93.425  -77.781  54.009  1
143911  93.435  -77.761  53.997  1
143912  93.445  -77.742  53.986  1
143913  93.456  -77.722  53.973  1
143914  93.470  -77.713  53.959  1
143915  93.484  -77.705  53.945  1
143916  93.497  -77.698  53.930  1
143917  93.511  -77.690  53.914  1
143918  93.525  -77.683  53.899  1
143919  93.542  -77.675  53.881  1
143920  93.557  -77.665  53.861  1
143921  93.572  -77.656  53.839  1
143922  93.587  -77.646  53.819  1
143923  93.602  -77.637  53.800  1
143924  93.617  -77.627  53.782  1
143925  93.630  -77.620  53.764  1
143926  93.637  -77.617  53.748  1
143927  93.645  -77.613  53.731  1
143928  93.653  -77.610  53.713  1
143929  93.663  -77.605  53.695  1
143930  93.674  -77.601  53.678  1
143931  93.685  -77.595  53.661  1
143932  93.695  -77.591  53.644  1
143933  93.706  -77.586  53.626  1
143934  93.717  -77.581  53.609  1
143935  93.727  -77.577  53.592  1
143936  93.738  -77.571  53.574  1
143937  93.749  -77.567  53.556  1
143938  93.763  -77.562  53.539  1
143939  93.777  -77.558  53.523  1
143940  93.791  -77.555  53.507  1
143941  93.805  -77.551  53.490  1
143942  93.819  -77.546  53.474  1
143943  93.833  -77.542  53.457  1
143944  93.846  -77.539  53.441  1
143945  93.860  -77.534  53.425  1
143946  93.874  -77.529  53.410  1
143947  93.890  -77.521  53.396  1
143948  93.905  -77.510  53.382  1
143949  93.921  -77.494  53.370  1
143950  93.939  -77.473  53.359  1
143951  93.948  -77.454  53.348  1
143952  93.955  -77.438  53.337  1
143953  93.960  -77.434  53.325  1
143954  93.988  -77.436  53.312  1
143955  94.015  -77.437  53.296  1
143956  94.044  -77.438  53.278  1
143957  94.072  -77.439  53.260  1
143958  94.100  -77.440  53.243  1
143959  94.128  -77.441  53.224  1
143960  94.156  -77.442  53.205  1
143961  94.183  -77.443  53.185  1
143962  94.208  -77.443  53.164  1
143963  94.210  -77.436  53.144  1
143964  94.211  -77.428  53.125  1
143965  94.213  -77.420  53.109  1
143966  94.214  -77.414  53.097  1
143967  94.215  -77.406  53.089  1
143968  94.217  -77.398  53.083  1
143969  94.218  -77.391  53.073  1
143970  94.220  -77.384  53.062  1
143971  94.221  -77.376  53.050  1
143972  94.222  -77.369  53.037  1
143973  94.224  -77.361  53.023  1
143974  94.216  -77.365  53.008  1
143975  94.219  -77.394  52.991  1
143976  94.221  -77.423  52.976  1
143977  94.223  -77.439  52.958  1
143978  94.224  -77.442  52.942  1
143979  94.223  -77.440  52.928  1
143980  94.218  -77.419  52.920  1
143981  94.214  -77.399  52.915  1
143982  94.251  -77.404  52.909  1
143983  94.288  -77.408  52.900  1
143984  94.324  -77.413  52.886  1
143985  94.361  -77.417  52.875  1
143986  94.376  -77.415  52.866  1
143987  94.385  -77.401  52.857  1
143988  94.391  -77.384  52.845  1
143989  94.387  -77.367  52.830  1
143990  94.383  -77.350  52.813  1
143991  94.380  -77.332  52.804  1
143992  94.376  -77.315  52.797  1
143993  94.372  -77.298  52.790  1
143994  94.370  -77.282  52.785  1
143995  94.389  -77.276  52.776  1
143996  94.407  -77.270  52.765  1
143997  94.425  -77.265  52.749  1
143998  94.445  -77.266  52.729  1
143999  94.468  -77.279  52.707  1
144000  94.491  -77.291  52.682  1
144001  94.513  -77.304  52.655  1
144002  94.536  -77.316  52.625  1
144003  94.557  -77.326  52.593  1
144004  94.574  -77.328  52.560  1
144005  94.591  -77.329  52.529  1
144006  94.617  -77.329  52.501  1
144007  94.687  -77.323  52.476  1
144008  94.742  -77.314  52.452  1
144009  94.764  -77.348  52.426  1
144010  94.787  -77.395  52.395  1
144011  94.822  -77.390  52.363  1
144012  94.856  -77.386  52.331  1
144013  94.891  -77.382  52.304  1
144014  94.912  -77.375  52.276  1
144015  94.930  -77.367  52.248  1
144016  94.950  -77.359  52.219  1
144017  94.969  -77.351  52.185  1
144018  94.987  -77.342  52.148  1
144019  95.006  -77.335  52.110  1
144020  95.023  -77.324  52.072  1
144021  95.009  -77.287  52.035  1
144022  95.023  -77.278  51.999  1
144023  95.040  -77.276  51.961  1
144024  95.057  -77.274  51.921  1
144025  95.069  -77.273  51.880  1
144026  95.076  -77.271  51.838  1
144027  95.084  -77.270  51.798  1
144028  95.090  -77.260  51.758  1
144029  95.097  -77.240  51.718  1
144030  95.123  -77.256  51.675  1
144031  95.131  -77.279  51.622  1
144032  95.134  -77.304  51.567  1
144033  95.136  -77.328  51.512  1
144034  95.145  -77.338  51.458  1
144035  95.162  -77.331  51.399  1
144036  95.179  -77.325  51.338  1
144037  95.195  -77.319  51.275  1
144038  95.211  -77.312  51.214  1
144039  95.228  -77.306  51.158  1
144040  95.245  -77.300  51.105  1
144041  95.272  -77.301  51.051  1
144042  95.300  -77.302  51.005  1
144043  95.327  -77.304  50.961  1
144044  95.358  -77.307  50.919  1
144045  95.388  -77.311  50.874  1
144046  95.419  -77.316  50.831  1
144047  95.450  -77.320  50.789  1
144048  95.480  -77.323  50.748  1
144049  95.511  -77.327  50.712  1
144050  95.542  -77.331  50.678  1
144051  95.568  -77.350  50.647  1
144052  95.595  -77.373  50.616  1
144053  95.621  -77.395  50.588  1
144054  95.627  -77.402  50.559  1
144055  95.629  -77.406  50.528  1
144056  95.631  -77.410  50.495  1
144057  95.633  -77.414  50.459  1
144058  95.634  -77.418  50.418  1
144059  95.636  -77.422  50.374  1
144060  95.638  -77.426  50.336  1
144061  95.640  -77.429  50.301  1
144062  95.642  -77.433  50.266  1
144063  95.644  -77.437  50.226  1
144064  95.646  -77.442  50.184  1
144065  95.648  -77.445  50.142  1
144066  95.671  -77.464  50.099  1
144067  95.694  -77.483  50.054  1
144068  95.718  -77.502  50.010  1
144069  95.741  -77.522  49.968  1
144070  95.765  -77.542  49.926  1
144071  95.788  -77.561  49.885  1
144072  95.812  -77.580  49.842  1
144073  95.835  -77.600  49.799  1
144074  95.850  -77.599  49.756  1
144075  95.866  -77.596  49.713  1
144076  95.881  -77.594  49.670  1
144077  95.896  -77.592  49.627  1
144078  95.911  -77.590  49.585  1
144079  95.926  -77.588  49.546  1
144080  95.942  -77.586  49.509  1
144081  95.957  -77.583  49.474  1
144082  95.972  -77.581  49.442  1
144083  95.975  -77.589  49.410  1
144084  95.979  -77.595  49.378  1
144085  95.982  -77.603  49.347  1
144086  95.985  -77.611  49.316  1
144087  95.987  -77.624  49.287  1
144088  95.986  -77.645  49.258  1
144089  95.997  -77.663  49.229  1
144090  96.008  -77.680  49.201  1
144091  96.020  -77.698  49.172  1
144092  96.031  -77.716  49.144  1
144093  96.043  -77.729  49.118  1
144094  96.057  -77.723  49.091  1
144095  96.073  -77.700  49.063  1
144096  96.090  -77.677  49.033  1
144097  96.093  -77.680  49.002  1
144098  96.093  -77.689  48.970  1
144099  96.094  -77.699  48.936  1
144100  96.101  -77.707  48.904  1
144101  96.102  -77.716  48.873  1
144102  96.093  -77.728  48.842  1
144103  96.104  -77.737  48.808  1
144104  96.116  -77.746  48.773  1
144105  96.128  -77.755  48.738  1
144106  96.141  -77.765  48.702  1
144107  96.157  -77.772  48.670  1
144108  96.185  -77.776  48.638  1
144109  96.207  -77.780  48.606  1
144110  96.222  -77.784  48.574  1
144111  96.236  -77.788  48.543  1
144112  96.251  -77.793  48.512  1
144113  96.265  -77.796  48.481  1
144114  96.279  -77.801  48.455  1
144115  96.294  -77.805  48.429  1
144116  96.309  -77.809  48.403  1
144117  96.322  -77.813  48.377  1
144118  96.328  -77.819  48.351  1
144119  96.334  -77.824  48.325  1
144120  96.341  -77.830  48.300  1
144121  96.347  -77.835  48.277  1
144122  96.354  -77.840  48.253  1
144123  96.360  -77.846  48.230  1
144124  96.366  -77.851  48.205  1
144125  96.373  -77.856  48.180  1
144126  96.379  -77.862  48.154  1
144127  96.385  -77.866  48.129  1
144128  96.401  -77.876  48.105  1
144129  96.422  -77.877  48.080  1
144130  96.443  -77.878  48.056  1
144131  96.463  -77.879  48.031  1
144132  96.483  -77.880  48.005  1
144133  96.503  -77.881  47.979  1
144134  96.523  -77.881  47.954  1
144135  96.543  -77.882  47.930  1
144136  96.564  -77.883  47.906  1
144137  96.580  -77.875  47.882  1
144138  96.593  -77.859  47.857  1
144139  96.605  -77.842  47.833  1
144140  96.618  -77.825  47.807  1
144141  96.636  -77.827  47.783  1
144142  96.654  -77.835  47.759  1
144143  96.672  -77.843  47.735  1
144144  96.691  -77.849  47.711  1
144145  96.710  -77.857  47.686  1
144146  96.728  -77.864  47.662  1
144147  96.747  -77.871  47.639  1
144148  96.765  -77.879  47.615  1
144149  96.784  -77.886  47.592  1
144150  96.800  -77.893  47.570  1
144151  96.815  -77.899  47.549  1
144152  96.831  -77.906  47.528  1
144153  96.848  -77.915  47.506  1
144154  96.867  -77.926  47.484  1
144155  96.876  -77.934  47.460  1
144156  96.885  -77.940  47.435  1
144157  96.894  -77.948  47.411  1
144158  96.903  -77.956  47.387  1
144159  96.912  -77.962  47.365  1
144160  96.921  -77.970  47.345  1
144161  96.930  -77.969  47.324  1
144162  96.951  -77.968  47.303  1
144163  96.974  -77.967  47.283  1
144164  96.997  -77.966  47.262  1
144165  97.018  -77.970  47.242  1
144166  97.038  -77.975  47.221  1
144167  97.058  -77.980  47.198  1
144168  97.079  -77.984  47.177  1
144169  97.099  -77.989  47.158  1
144170  97.119  -77.993  47.139  1
144171  97.140  -78.008  47.121  1
144172  97.161  -78.025  47.104  1
144173  97.179  -78.037  47.087  1
144174  97.189  -78.034  47.072  1
144175  97.199  -78.031  47.057  1
144176  97.209  -78.028  47.042  1
144177  97.219  -78.025  47.028  1
144178  97.229  -78.022  47.015  1
144179  97.246  -78.013  47.003  1
144180  97.271  -78.000  46.991  1
144181  97.293  -78.002  46.980  1
144182  97.315  -78.015  46.970  1
144183  97.336  -78.028  46.959  1
144184  97.357  -78.042  46.948  1
144185  97.378  -78.055  46.937  1
144186  97.405  -78.056  46.929  1
144187  97.434  -78.056  46.919  1
144188  97.462  -78.056  46.910  1
144189  97.470  -78.062  46.902  1
144190  97.469  -78.076  46.890  1
144191  97.494  -78.101  46.875  1
144192  97.517  -78.125  46.859  1
144193  97.541  -78.150  46.842  1
144194  97.565  -78.174  46.823  1
144195  97.587  -78.194  46.805  1
144196  97.602  -78.197  46.785  1
144197  97.617  -78.200  46.764  1
144198  97.632  -78.203  46.741  1
144199  97.663  -78.211  46.718  1
144200  97.710  -78.222  46.696  1
144201  97.756  -78.233  46.673  1
144202  97.803  -78.244  46.651  1
144203  97.850  -78.256  46.629  1
144204  97.896  -78.267  46.606  1
144205  97.943  -78.278  46.584  1
144206  97.989  -78.289  46.562  1
144207  98.036  -78.300  46.539  1
144208  98.081  -78.310  46.517  1
144209  98.123  -78.317  46.494  1
144210  98.164  -78.324  46.471  1
144211  98.206  -78.332  46.446  1
144212  98.247  -78.338  46.422  1
144213  98.271  -78.332  46.399  1
144214  98.291  -78.310  46.376  1
144215  98.311  -78.287  46.353  1
144216  98.331  -78.265  46.330  1
144217  98.343  -78.244  46.307  1
144218  98.346  -78.229  46.283  1
144219  98.326  -78.232  46.260  1
144220  98.307  -78.234  46.237  1
144221  98.353  -78.236  46.213  1
144222  98.405  -78.239  46.190  1
144223  98.455  -78.241  46.166  1
144224  98.480  -78.244  46.144  1
144225  98.501  -78.247  46.123  1
144226  98.522  -78.248  46.101  1
144227  98.550  -78.236  46.080  1
144228  98.609  -78.200  46.059  1
144229  98.640  -78.192  46.038  1
144230  98.651  -78.178  46.016  1
144231  98.661  -78.161  45.995  1
144232  98.671  -78.144  45.974  1
144233  98.681  -78.128  45.954  1
144234  98.691  -78.110  45.931  1
144235  98.698  -78.096  45.908  1
144236  98.700  -78.085  45.885  1
144237  98.702  -78.075  45.864  1
144238  98.704  -78.065  45.842  1
144239  98.707  -78.057  45.821  1
144240  98.741  -78.099  45.799  1
144241  98.744  -78.169  45.777  1
144242  98.751  -78.231  45.757  1
144243  98.778  -78.253  45.738  1
144244  98.804  -78.275  45.721  1
144245  98.831  -78.298  45.706  1
144246  98.858  -78.321  45.692  1
144247  98.878  -78.342  45.678  1
144248  98.901  -78.351  45.664  1
144249  98.926  -78.353  45.648  1
144250  98.951  -78.352  45.633  1
144251  98.976  -78.351  45.618  1
144252  99.001  -78.350  45.605  1
144253  99.025  -78.348  45.592  1
144254  99.051  -78.347  45.579  1
144255  99.075  -78.346  45.564  1
144256  99.092  -78.348  45.550  1
144257  99.107  -78.351  45.536  1
144258  99.123  -78.354  45.521  1
144259  99.155  -78.362  45.506  1
144260  99.187  -78.370  45.492  1
144261  99.220  -78.379  45.479  1
144262  99.252  -78.386  45.466  1
144263  99.285  -78.395  45.454  1
144264  99.317  -78.402  45.443  1
144265  99.349  -78.410  45.431  1
144266  99.382  -78.419  45.419  1
144267  99.414  -78.426  45.406  1
144268  99.447  -78.435  45.393  1
144269  99.479  -78.442  45.379  1
144270  99.511  -78.451  45.366  1
144271  99.553  -78.460  45.353  1
144272  99.606  -78.472  45.340  1
144273  99.659  -78.483  45.325  1
144274  99.712  -78.495  45.313  1
144275  99.766  -78.507  45.301  1
144276  99.794  -78.523  45.288  1
144277  99.813  -78.544  45.277  1
144278  99.832  -78.566  45.265  1
144279  99.859  -78.576  45.253  1
144280  99.875  -78.573  45.241  1
144281  99.884  -78.582  45.230  1
144282  99.893  -78.590  45.220  1
144283  99.900  -78.597  45.209  1
144284  99.907  -78.604  45.199  1
144285  99.914  -78.610  45.187  1
144286  99.921  -78.617  45.175  1
144287  99.928  -78.623  45.164  1
144288  99.935  -78.630  45.151  1
144289  99.942  -78.637  45.137  1
144290  99.951  -78.644  45.122  1
144291  99.982  -78.653  45.108  1
144292  100.014  -78.663  45.095  1
144293  100.046  -78.672  45.082  1
144294  100.081  -78.683  45.069  1
144295  100.122  -78.701  45.056  1
144296  100.159  -78.719  45.044  1
144297  100.197  -78.737  45.031  1
144298  100.235  -78.755  45.017  1
144299  100.273  -78.774  45.005  1
144300  100.297  -78.787  44.992  1
144301  100.315  -78.799  44.979  1
144302  100.333  -78.811  44.966  1
144303  100.345  -78.821  44.952  1
144304  100.355  -78.831  44.937  1
144305  100.365  -78.841  44.923  1
144306  100.376  -78.851  44.907  1
144307  100.389  -78.867  44.892  1
144308  100.403  -78.886  44.877  1
144309  100.413  -78.905  44.862  1
144310  100.424  -78.924  44.847  1
144311  100.434  -78.943  44.832  1
144312  100.445  -78.963  44.817  1
144313  100.456  -78.982  44.800  1
144314  100.470  -78.996  44.784  1
144315  100.486  -79.008  44.768  1
144316  100.502  -79.018  44.752  1
144317  100.521  -79.031  44.735  1
144318  100.554  -79.050  44.718  1
144319  100.586  -79.069  44.702  1
144320  100.619  -79.089  44.684  1
144321  100.651  -79.108  44.668  1
144322  100.684  -79.127  44.652  1
144323  100.716  -79.146  44.636  1
144324  100.749  -79.165  44.620  1
144325  100.781  -79.184  44.604  1
144568  92.747  -78.069  54.263  1
144569  92.766  -78.072  54.259  1
144570  92.784  -78.075  54.255  1
144571  92.803  -78.078  54.251  1
144572  92.821  -78.081  54.247  1
144573  92.839  -78.084  54.242  1
144574  92.858  -78.087  54.238  1
144575  92.876  -78.090  54.234  1
144576  92.894  -78.088  54.231  1
144577  92.910  -78.083  54.227  1
144578  92.926  -78.078  54.223  1
144579  92.943  -78.072  54.221  1
144580  92.959  -78.067  54.217  1
144581  92.976  -78.061  54.212  1
144582  92.992  -78.056  54.208  1
144583  93.009  -78.050  54.204  1
144584  93.025  -78.045  54.201  1
144585  93.042  -78.040  54.199  1
144586  93.058  -78.034  54.197  1
144587  93.075  -78.029  54.195  1
144588  93.095  -78.032  54.190  1
144589  93.116  -78.034  54.185  1
144590  93.136  -78.037  54.180  1
144591  93.156  -78.040  54.176  1
144592  93.177  -78.043  54.172  1
144593  93.197  -78.045  54.169  1
144594  93.217  -78.048  54.165  1
144595  93.237  -78.048  54.161  1
144596  93.258  -78.041  54.157  1
144597  93.285  -77.997  54.152  1
144598  93.323  -77.902  54.148  1
144599  93.311  -77.925  54.143  1
144600  93.299  -77.945  54.139  1
144601  93.298  -77.931  54.131  1
144602  93.297  -77.916  54.122  1
144603  93.296  -77.901  54.113  1
144604  93.295  -77.887  54.104  1
144605  93.294  -77.872  54.095  1
144606  93.307  -77.859  54.085  1
144607  93.323  -77.845  54.074  1
144608  93.354  -77.828  54.061  1
144609  93.393  -77.808  54.048  1
144610  93.404  -77.789  54.035  1
144611  93.414  -77.768  54.023  1
144612  93.425  -77.749  54.012  1
144613  93.435  -77.729  54.002  1
144614  93.445  -77.709  53.990  1
144615  93.459  -77.701  53.976  1
144616  93.473  -77.692  53.962  1
144617  93.487  -77.685  53.948  1
144618  93.501  -77.677  53.933  1
144619  93.517  -77.670  53.918  1
144620  93.533  -77.662  53.901  1
144621  93.548  -77.653  53.882  1
144622  93.563  -77.644  53.862  1
144623  93.578  -77.635  53.843  1
144624  93.593  -77.625  53.824  1
144625  93.608  -77.616  53.806  1
144626  93.623  -77.606  53.788  1
144627  93.632  -77.602  53.771  1
144628  93.640  -77.599  53.754  1
144629  93.648  -77.595  53.736  1
144630  93.655  -77.592  53.719  1
144631  93.666  -77.587  53.701  1
144632  93.677  -77.582  53.684  1
144633  93.688  -77.577  53.667  1
144634  93.698  -77.573  53.650  1
144635  93.709  -77.567  53.633  1
144636  93.720  -77.563  53.615  1
144637  93.730  -77.558  53.597  1
144638  93.744  -77.554  53.580  1
144639  93.758  -77.549  53.563  1
144640  93.772  -77.545  53.546  1
144641  93.785  -77.542  53.530  1
144642  93.799  -77.537  53.513  1
144643  93.813  -77.533  53.497  1
144644  93.827  -77.530  53.480  1
144645  93.842  -77.523  53.465  1
144646  93.857  -77.515  53.450  1
144647  93.872  -77.507  53.435  1
144648  93.888  -77.494  53.422  1
144649  93.903  -77.478  53.407  1
144650  93.920  -77.459  53.393  1
144651  93.938  -77.437  53.382  1
144652  93.949  -77.419  53.369  1
144653  93.956  -77.402  53.359  1
144654  93.959  -77.415  53.349  1
144655  93.982  -77.420  53.338  1
144656  94.010  -77.421  53.323  1
144657  94.039  -77.423  53.307  1
144658  94.067  -77.423  53.291  1
144659  94.095  -77.424  53.274  1
144660  94.123  -77.426  53.255  1
144661  94.151  -77.426  53.235  1
144662  94.178  -77.428  53.215  1
144663  94.188  -77.432  53.194  1
144664  94.188  -77.428  53.174  1
144665  94.189  -77.420  53.155  1
144666  94.190  -77.413  53.138  1
144667  94.192  -77.405  53.127  1
144668  94.193  -77.398  53.119  1
144669  94.194  -77.390  53.113  1
144670  94.196  -77.382  53.104  1
144671  94.197  -77.375  53.094  1
144672  94.198  -77.367  53.084  1
144673  94.201  -77.360  53.071  1
144674  94.219  -77.352  53.057  1
144675  94.224  -77.357  53.041  1
144676  94.226  -77.387  53.025  1
144677  94.228  -77.416  53.008  1
144678  94.230  -77.421  52.991  1
144679  94.230  -77.423  52.974  1
144680  94.231  -77.423  52.959  1
144681  94.225  -77.402  52.949  1
144682  94.232  -77.389  52.942  1
144683  94.269  -77.394  52.936  1
144684  94.306  -77.398  52.927  1
144685  94.342  -77.402  52.914  1
144686  94.359  -77.401  52.902  1
144687  94.367  -77.394  52.892  1
144688  94.376  -77.378  52.884  1
144689  94.385  -77.363  52.874  1
144690  94.388  -77.346  52.860  1
144691  94.385  -77.329  52.841  1
144692  94.381  -77.311  52.822  1
144693  94.377  -77.294  52.807  1
144694  94.387  -77.284  52.796  1
144695  94.405  -77.279  52.787  1
144696  94.423  -77.273  52.778  1
144697  94.442  -77.268  52.766  1
144698  94.460  -77.262  52.752  1
144699  94.479  -77.257  52.733  1
144700  94.500  -77.266  52.714  1
144701  94.523  -77.279  52.691  1
144702  94.546  -77.291  52.666  1
144703  94.568  -77.303  52.639  1
144704  94.585  -77.304  52.611  1
144705  94.601  -77.305  52.583  1
144706  94.618  -77.307  52.556  1
144707  94.634  -77.307  52.532  1
144708  94.667  -77.307  52.509  1
144709  94.738  -77.296  52.485  1
144710  94.763  -77.302  52.455  1
144711  94.785  -77.340  52.422  1
144712  94.815  -77.357  52.390  1
144713  94.849  -77.354  52.361  1
144714  94.881  -77.349  52.335  1
144715  94.899  -77.341  52.308  1
144716  94.918  -77.333  52.280  1
144717  94.937  -77.325  52.249  1
144718  94.956  -77.316  52.214  1
144719  94.975  -77.308  52.177  1
144720  94.994  -77.301  52.139  1
144721  95.013  -77.292  52.103  1
144722  95.026  -77.285  52.067  1
144723  95.032  -77.283  52.030  1
144724  95.039  -77.282  51.992  1
144725  95.046  -77.281  51.951  1
144726  95.053  -77.279  51.911  1
144727  95.060  -77.279  51.871  1
144728  95.067  -77.259  51.831  1
144729  95.074  -77.238  51.791  1
144730  95.090  -77.235  51.751  1
144731  95.116  -77.252  51.707  1
144732  95.134  -77.273  51.654  1
144733  95.136  -77.297  51.599  1
144734  95.139  -77.322  51.543  1
144735  95.149  -77.328  51.488  1
144736  95.166  -77.322  51.429  1
144737  95.182  -77.316  51.366  1
144738  95.199  -77.309  51.301  1
144739  95.215  -77.303  51.239  1
144740  95.232  -77.296  51.181  1
144741  95.248  -77.290  51.126  1
144742  95.265  -77.284  51.075  1
144743  95.285  -77.280  51.029  1
144744  95.313  -77.282  50.985  1
144745  95.340  -77.282  50.941  1
144746  95.371  -77.286  50.896  1
144747  95.401  -77.291  50.851  1
144748  95.431  -77.294  50.808  1
144749  95.462  -77.298  50.769  1
144750  95.493  -77.302  50.733  1
144751  95.523  -77.308  50.699  1
144752  95.549  -77.331  50.666  1
144753  95.576  -77.354  50.636  1
144754  95.602  -77.376  50.608  1
144755  95.628  -77.398  50.578  1
144756  95.633  -77.404  50.547  1
144757  95.634  -77.408  50.513  1
144758  95.636  -77.412  50.477  1
144759  95.638  -77.416  50.438  1
144760  95.640  -77.420  50.396  1
144761  95.642  -77.424  50.354  1
144762  95.644  -77.428  50.316  1
144763  95.646  -77.432  50.281  1
144764  95.648  -77.436  50.244  1
144765  95.650  -77.439  50.204  1
144766  95.660  -77.449  50.163  1
144767  95.677  -77.459  50.119  1
144768  95.696  -77.467  50.074  1
144769  95.716  -77.477  50.031  1
144770  95.740  -77.497  49.990  1
144771  95.763  -77.517  49.950  1
144772  95.787  -77.536  49.907  1
144773  95.811  -77.555  49.862  1
144774  95.834  -77.575  49.817  1
144775  95.858  -77.595  49.772  1
144776  95.874  -77.595  49.726  1
144777  95.889  -77.593  49.681  1
144778  95.904  -77.592  49.637  1
144779  95.919  -77.589  49.595  1
144780  95.935  -77.587  49.555  1
144781  95.950  -77.585  49.518  1
144782  95.965  -77.583  49.483  1
144783  95.973  -77.586  49.451  1
144784  95.977  -77.593  49.418  1
144785  95.980  -77.601  49.385  1
144786  95.983  -77.608  49.352  1
144787  95.987  -77.615  49.322  1
144788  95.990  -77.624  49.294  1
144789  95.989  -77.645  49.267  1
144790  96.000  -77.663  49.236  1
144791  96.012  -77.680  49.207  1
144792  96.023  -77.698  49.178  1
144793  96.034  -77.715  49.153  1
144794  96.048  -77.725  49.130  1
144795  96.061  -77.711  49.105  1
144796  96.078  -77.689  49.078  1
144797  96.094  -77.666  49.049  1
144798  96.096  -77.674  49.018  1
144799  96.097  -77.683  48.985  1
144800  96.106  -77.691  48.952  1
144801  96.114  -77.699  48.921  1
144802  96.106  -77.710  48.889  1
144803  96.090  -77.722  48.856  1
144804  96.102  -77.731  48.823  1
144805  96.113  -77.740  48.788  1
144806  96.125  -77.750  48.754  1
144807  96.138  -77.758  48.719  1
144808  96.166  -77.762  48.687  1
144809  96.194  -77.766  48.654  1
144810  96.210  -77.771  48.622  1
144811  96.225  -77.774  48.592  1
144812  96.240  -77.779  48.561  1
144813  96.254  -77.783  48.529  1
144814  96.269  -77.787  48.498  1
144815  96.283  -77.791  48.471  1
144816  96.298  -77.795  48.445  1
144817  96.308  -77.802  48.419  1
144818  96.318  -77.808  48.393  1
144819  96.336  -77.808  48.367  1
144820  96.354  -77.807  48.341  1
144821  96.363  -77.812  48.315  1
144822  96.367  -77.820  48.293  1
144823  96.371  -77.827  48.269  1
144824  96.376  -77.835  48.246  1
144825  96.380  -77.843  48.222  1
144826  96.384  -77.850  48.198  1
144827  96.389  -77.858  48.172  1
144828  96.393  -77.865  48.146  1
144829  96.403  -77.871  48.122  1
144830  96.424  -77.872  48.098  1
144831  96.444  -77.873  48.073  1
144832  96.464  -77.874  48.048  1
144833  96.484  -77.874  48.022  1
144834  96.504  -77.875  47.997  1
144835  96.524  -77.876  47.972  1
144836  96.544  -77.877  47.947  1
144837  96.564  -77.877  47.922  1
144838  96.582  -77.871  47.898  1
144839  96.594  -77.855  47.875  1
144840  96.607  -77.838  47.850  1
144841  96.619  -77.821  47.824  1
144842  96.634  -77.812  47.799  1
144843  96.653  -77.820  47.776  1
144844  96.671  -77.827  47.752  1
144845  96.689  -77.834  47.727  1
144846  96.708  -77.842  47.703  1
144847  96.727  -77.849  47.679  1
144848  96.745  -77.856  47.654  1
144849  96.763  -77.864  47.630  1
144850  96.781  -77.871  47.607  1
144851  96.796  -77.877  47.584  1
144852  96.812  -77.884  47.562  1
144853  96.829  -77.893  47.540  1
144854  96.852  -77.906  47.519  1
144855  96.873  -77.918  47.496  1
144856  96.882  -77.924  47.472  1
144857  96.891  -77.932  47.448  1
144858  96.900  -77.940  47.425  1
144859  96.909  -77.946  47.403  1
144860  96.918  -77.954  47.382  1
144861  96.927  -77.962  47.362  1
144862  96.936  -77.956  47.342  1
144863  96.950  -77.952  47.323  1
144864  96.973  -77.951  47.302  1
144865  96.997  -77.949  47.281  1
144866  97.017  -77.953  47.260  1
144867  97.037  -77.959  47.237  1
144868  97.058  -77.963  47.214  1
144869  97.078  -77.968  47.192  1
144870  97.098  -77.972  47.173  1
144871  97.119  -77.983  47.154  1
144872  97.140  -78.000  47.136  1
144873  97.161  -78.017  47.119  1
144874  97.181  -78.034  47.103  1
144875  97.192  -78.033  47.087  1
144876  97.203  -78.030  47.073  1
144877  97.213  -78.027  47.057  1
144878  97.223  -78.024  47.043  1
144879  97.235  -78.019  47.030  1
144880  97.259  -78.006  47.018  1
144881  97.284  -77.993  47.005  1
144882  97.306  -77.996  46.994  1
144883  97.327  -78.010  46.983  1
144884  97.349  -78.023  46.971  1
144885  97.370  -78.037  46.960  1
144886  97.391  -78.050  46.949  1
144887  97.413  -78.063  46.939  1
144888  97.438  -78.069  46.930  1
144889  97.466  -78.069  46.920  1
144890  97.477  -78.074  46.911  1
144891  97.470  -78.085  46.901  1
144892  97.469  -78.099  46.887  1
144893  97.493  -78.123  46.871  1
144894  97.516  -78.147  46.854  1
144895  97.540  -78.172  46.836  1
144896  97.563  -78.192  46.818  1
144897  97.578  -78.196  46.798  1
144898  97.592  -78.199  46.776  1
144899  97.614  -78.204  46.754  1
144900  97.661  -78.215  46.731  1
144901  97.707  -78.226  46.709  1
144902  97.754  -78.238  46.686  1
144903  97.800  -78.249  46.664  1
144904  97.847  -78.260  46.641  1
144905  97.893  -78.271  46.618  1
144906  97.940  -78.282  46.595  1
144907  97.987  -78.294  46.572  1
144908  98.033  -78.304  46.549  1
144909  98.080  -78.316  46.527  1
144910  98.123  -78.324  46.504  1
144911  98.165  -78.331  46.481  1
144912  98.207  -78.338  46.457  1
144913  98.230  -78.347  46.433  1
144914  98.244  -78.339  46.410  1
144915  98.264  -78.316  46.388  1
144916  98.284  -78.294  46.365  1
144917  98.304  -78.276  46.342  1
144918  98.323  -78.265  46.318  1
144919  98.343  -78.253  46.295  1
144920  98.363  -78.241  46.271  1
144921  98.375  -78.232  46.248  1
144922  98.363  -78.235  46.224  1
144923  98.414  -78.238  46.201  1
144924  98.428  -78.221  46.177  1
144925  98.472  -78.214  46.154  1
144926  98.515  -78.207  46.132  1
144927  98.559  -78.200  46.109  1
144928  98.603  -78.193  46.089  1
144929  98.643  -78.188  46.068  1
144930  98.662  -78.173  46.046  1
144931  98.663  -78.163  46.025  1
144932  98.665  -78.153  46.004  1
144933  98.667  -78.142  45.984  1
144934  98.669  -78.132  45.963  1
144935  98.670  -78.122  45.941  1
144936  98.672  -78.111  45.919  1
144937  98.674  -78.101  45.897  1
144938  98.676  -78.091  45.875  1
144939  98.675  -78.079  45.854  1
144940  98.684  -78.078  45.832  1
144941  98.724  -78.116  45.810  1
144942  98.762  -78.155  45.789  1
144943  98.765  -78.225  45.769  1
144944  98.790  -78.250  45.749  1
144945  98.816  -78.273  45.732  1
144946  98.840  -78.295  45.717  1
144947  98.848  -78.314  45.702  1
144948  98.865  -78.326  45.688  1
144949  98.896  -78.327  45.674  1
144950  98.920  -78.340  45.661  1
144951  98.944  -78.347  45.647  1
144952  98.969  -78.347  45.632  1
144953  98.994  -78.345  45.618  1
144954  99.019  -78.344  45.604  1
144955  99.044  -78.343  45.590  1
144956  99.069  -78.342  45.576  1
144957  99.083  -78.345  45.561  1
144958  99.098  -78.347  45.547  1
144959  99.129  -78.355  45.532  1
144960  99.161  -78.363  45.518  1
144961  99.193  -78.371  45.505  1
144962  99.226  -78.379  45.492  1
144963  99.258  -78.388  45.479  1
144964  99.291  -78.395  45.467  1
144965  99.323  -78.404  45.454  1
144966  99.355  -78.411  45.442  1
144967  99.388  -78.420  45.431  1
144968  99.420  -78.428  45.418  1
144969  99.453  -78.435  45.404  1
144970  99.485  -78.444  45.390  1
144971  99.518  -78.451  45.377  1
144972  99.550  -78.460  45.364  1
144973  99.588  -78.469  45.350  1
144974  99.641  -78.480  45.336  1
144975  99.694  -78.492  45.323  1
144976  99.748  -78.504  45.311  1
144977  99.784  -78.525  45.298  1
144978  99.811  -78.552  45.287  1
144979  99.831  -78.574  45.275  1
144980  99.863  -78.575  45.263  1
144981  99.880  -78.567  45.253  1
144982  99.889  -78.576  45.242  1
144983  99.896  -78.582  45.232  1
144984  99.903  -78.589  45.223  1
144985  99.910  -78.596  45.214  1
144986  99.917  -78.603  45.202  1
144987  99.924  -78.610  45.190  1
144988  99.931  -78.617  45.177  1
144989  99.938  -78.623  45.163  1
144990  99.945  -78.630  45.150  1
144991  99.952  -78.636  45.135  1
144992  99.975  -78.645  45.120  1
144993  100.007  -78.655  45.107  1
144994  100.043  -78.665  45.094  1
144995  100.091  -78.680  45.080  1
144996  100.131  -78.697  45.067  1
144997  100.168  -78.715  45.054  1
144998  100.206  -78.733  45.041  1
144999  100.245  -78.752  45.028  1
145000  100.279  -78.769  45.015  1
145001  100.297  -78.781  45.001  1
145002  100.315  -78.793  44.987  1
145003  100.333  -78.805  44.973  1
145004  100.351  -78.816  44.959  1
145005  100.361  -78.826  44.945  1
145006  100.371  -78.836  44.930  1
145007  100.382  -78.846  44.915  1
145008  100.394  -78.858  44.900  1
145009  100.409  -78.878  44.884  1
145010  100.423  -78.897  44.869  1
145011  100.433  -78.916  44.854  1
145012  100.444  -78.936  44.839  1
145013  100.455  -78.955  44.823  1
145014  100.465  -78.974  44.806  1
145015  100.477  -78.991  44.790  1
145016  100.493  -79.002  44.774  1
145017  100.509  -79.013  44.758  1
145018  100.526  -79.024  44.740  1
145019  100.551  -79.040  44.723  1
145020  100.583  -79.059  44.707  1
145021  100.616  -79.078  44.690  1
145022  100.648  -79.097  44.673  1
145023  100.681  -79.117  44.656  1
145024  100.713  -79.136  44.640  1
145025  100.746  -79.155  44.625  1
145026  100.778  -79.174  44.609  1
145027  100.811  -79.193  44.593  1
145028  100.843  -79.212  44.577  1
145269  92.728  -78.025  54.260  1
145270  92.746  -78.028  54.256  1
145271  92.764  -78.031  54.252  1
145272  92.783  -78.034  54.248  1
145273  92.801  -78.037  54.245  1
145274  92.819  -78.040  54.240  1
145275  92.838  -78.043  54.235  1
145276  92.856  -78.046  54.232  1
145277  92.874  -78.049  54.229  1
145278  92.893  -78.052  54.225  1
145279  92.911  -78.054  54.222  1
145280  92.929  -78.057  54.220  1
145281  92.946  -78.056  54.216  1
145282  92.963  -78.050  54.212  1
145283  92.980  -78.045  54.208  1
145284  92.996  -78.039  54.205  1
145285  93.012  -78.034  54.203  1
145286  93.029  -78.028  54.202  1
145287  93.046  -78.023  54.200  1
145288  93.065  -78.023  54.198  1
145289  93.085  -78.025  54.194  1
145290  93.105  -78.028  54.191  1
145291  93.126  -78.031  54.187  1
145292  93.146  -78.034  54.183  1
145293  93.166  -78.037  54.180  1
145294  93.186  -78.039  54.178  1
145295  93.206  -78.040  54.174  1
145296  93.226  -78.039  54.170  1
145297  93.246  -78.038  54.167  1
145298  93.277  -77.999  54.163  1
145299  93.298  -77.953  54.159  1
145300  93.297  -77.940  54.155  1
145301  93.296  -77.925  54.150  1
145302  93.295  -77.911  54.144  1
145303  93.294  -77.896  54.136  1
145304  93.293  -77.881  54.127  1
145305  93.292  -77.867  54.119  1
145306  93.290  -77.852  54.109  1
145307  93.299  -77.838  54.098  1
145308  93.314  -77.824  54.087  1
145309  93.331  -77.812  54.073  1
145310  93.357  -77.795  54.061  1
145311  93.393  -77.775  54.050  1
145312  93.404  -77.755  54.039  1
145313  93.414  -77.736  54.028  1
145314  93.424  -77.716  54.017  1
145315  93.435  -77.696  54.006  1
145316  93.449  -77.688  53.993  1
145317  93.463  -77.680  53.980  1
145318  93.477  -77.673  53.966  1
145319  93.492  -77.665  53.953  1
145320  93.508  -77.658  53.938  1
145321  93.523  -77.650  53.922  1
145322  93.539  -77.641  53.905  1
145323  93.554  -77.632  53.887  1
145324  93.569  -77.623  53.868  1
145325  93.584  -77.614  53.850  1
145326  93.600  -77.604  53.832  1
145327  93.614  -77.595  53.815  1
145328  93.627  -77.586  53.798  1
145329  93.635  -77.583  53.781  1
145330  93.643  -77.580  53.764  1
145331  93.650  -77.577  53.745  1
145332  93.658  -77.573  53.727  1
145333  93.669  -77.569  53.709  1
145334  93.680  -77.564  53.692  1
145335  93.691  -77.559  53.675  1
145336  93.701  -77.554  53.657  1
145337  93.712  -77.549  53.639  1
145338  93.724  -77.545  53.621  1
145339  93.739  -77.541  53.603  1
145340  93.752  -77.536  53.586  1
145341  93.766  -77.533  53.570  1
145342  93.780  -77.529  53.554  1
145343  93.794  -77.524  53.537  1
145344  93.809  -77.517  53.522  1
145345  93.824  -77.509  53.506  1
145346  93.839  -77.501  53.492  1
145347  93.854  -77.492  53.477  1
145348  93.870  -77.478  53.463  1
145349  93.885  -77.462  53.449  1
145350  93.901  -77.445  53.433  1
145351  93.919  -77.423  53.418  1
145352  93.937  -77.402  53.405  1
145353  93.949  -77.383  53.392  1
145354  93.957  -77.367  53.381  1
145355  93.957  -77.395  53.371  1
145356  93.977  -77.404  53.362  1
145357  94.005  -77.406  53.349  1
145358  94.033  -77.407  53.335  1
145359  94.061  -77.408  53.322  1
145360  94.089  -77.409  53.305  1
145361  94.118  -77.410  53.285  1
145362  94.145  -77.411  53.265  1
145363  94.165  -77.418  53.245  1
145364  94.171  -77.421  53.225  1
145365  94.168  -77.421  53.204  1
145366  94.169  -77.414  53.184  1
145367  94.170  -77.407  53.167  1
145368  94.171  -77.399  53.155  1
145369  94.172  -77.392  53.147  1
145370  94.174  -77.384  53.142  1
145371  94.175  -77.376  53.133  1
145372  94.182  -77.369  53.125  1
145373  94.199  -77.361  53.115  1
145374  94.217  -77.354  53.103  1
145375  94.235  -77.347  53.089  1
145376  94.233  -77.355  53.074  1
145377  94.234  -77.379  53.058  1
145378  94.236  -77.401  53.041  1
145379  94.237  -77.403  53.024  1
145380  94.238  -77.404  53.007  1
145381  94.239  -77.407  52.992  1
145382  94.233  -77.386  52.979  1
145383  94.250  -77.379  52.969  1
145384  94.287  -77.383  52.960  1
145385  94.324  -77.388  52.951  1
145386  94.342  -77.387  52.938  1
145387  94.350  -77.383  52.925  1
145388  94.358  -77.372  52.915  1
145389  94.367  -77.356  52.908  1
145390  94.377  -77.340  52.900  1
145391  94.386  -77.325  52.889  1
145392  94.386  -77.307  52.873  1
145393  94.385  -77.292  52.853  1
145394  94.403  -77.286  52.834  1
145395  94.422  -77.281  52.815  1
145396  94.440  -77.276  52.800  1
145397  94.458  -77.270  52.787  1
145398  94.477  -77.265  52.774  1
145399  94.495  -77.259  52.760  1
145400  94.513  -77.254  52.744  1
145401  94.533  -77.253  52.725  1
145402  94.555  -77.266  52.705  1
145403  94.578  -77.278  52.684  1
145404  94.596  -77.281  52.661  1
145405  94.612  -77.282  52.637  1
145406  94.629  -77.283  52.612  1
145407  94.645  -77.285  52.589  1
145408  94.662  -77.285  52.565  1
145409  94.678  -77.286  52.541  1
145410  94.717  -77.285  52.516  1
145411  94.759  -77.283  52.483  1
145412  94.785  -77.289  52.450  1
145413  94.809  -77.326  52.419  1
145414  94.843  -77.321  52.393  1
145415  94.868  -77.315  52.367  1
145416  94.887  -77.307  52.340  1
145417  94.906  -77.298  52.311  1
145418  94.925  -77.291  52.279  1
145419  94.944  -77.282  52.243  1
145420  94.962  -77.286  52.205  1
145421  94.979  -77.293  52.167  1
145422  94.997  -77.300  52.134  1
145423  95.010  -77.291  52.097  1
145424  95.017  -77.291  52.059  1
145425  95.024  -77.289  52.021  1
145426  95.031  -77.288  51.981  1
145427  95.037  -77.277  51.941  1
145428  95.044  -77.257  51.902  1
145429  95.051  -77.236  51.863  1
145430  95.057  -77.216  51.824  1
145431  95.083  -77.231  51.783  1
145432  95.110  -77.248  51.738  1
145433  95.136  -77.266  51.685  1
145434  95.139  -77.291  51.630  1
145435  95.141  -77.315  51.572  1
145436  95.154  -77.319  51.516  1
145437  95.170  -77.313  51.455  1
145438  95.186  -77.306  51.391  1
145439  95.203  -77.300  51.324  1
145440  95.219  -77.293  51.262  1
145441  95.236  -77.287  51.203  1
145442  95.252  -77.281  51.148  1
145443  95.268  -77.274  51.097  1
145444  95.285  -77.268  51.052  1
145445  95.302  -77.261  51.008  1
145446  95.326  -77.260  50.963  1
145447  95.353  -77.262  50.917  1
145448  95.383  -77.266  50.872  1
145449  95.414  -77.269  50.829  1
145450  95.445  -77.273  50.789  1
145451  95.475  -77.277  50.753  1
145452  95.504  -77.288  50.719  1
145453  95.530  -77.311  50.686  1
145454  95.556  -77.334  50.653  1
145455  95.583  -77.357  50.623  1
145456  95.609  -77.379  50.593  1
145457  95.635  -77.402  50.562  1
145458  95.638  -77.407  50.529  1
145459  95.640  -77.410  50.493  1
145460  95.642  -77.414  50.455  1
145461  95.644  -77.418  50.413  1
145462  95.646  -77.422  50.371  1
145463  95.648  -77.426  50.333  1
145464  95.650  -77.430  50.298  1
145465  95.652  -77.434  50.262  1
145466  95.658  -77.441  50.222  1
145467  95.673  -77.453  50.180  1
145468  95.687  -77.464  50.137  1
145469  95.706  -77.473  50.092  1
145470  95.725  -77.480  50.050  1
145471  95.745  -77.488  50.010  1
145472  95.764  -77.496  49.971  1
145473  95.786  -77.511  49.927  1
145474  95.809  -77.530  49.881  1
145475  95.833  -77.550  49.834  1
145476  95.856  -77.570  49.787  1
145477  95.880  -77.589  49.740  1
145478  95.897  -77.593  49.694  1
145479  95.912  -77.591  49.649  1
145480  95.927  -77.589  49.606  1
145481  95.943  -77.586  49.566  1
145482  95.958  -77.584  49.529  1
145483  95.971  -77.583  49.493  1
145484  95.975  -77.591  49.460  1
145485  95.978  -77.598  49.427  1
145486  95.981  -77.605  49.393  1
145487  95.985  -77.613  49.361  1
145488  95.988  -77.620  49.332  1
145489  95.992  -77.627  49.304  1
145490  95.992  -77.645  49.278  1
145491  96.004  -77.662  49.248  1
145492  96.015  -77.680  49.219  1
145493  96.027  -77.696  49.191  1
145494  96.042  -77.701  49.166  1
145495  96.058  -77.706  49.142  1
145496  96.071  -77.692  49.117  1
145497  96.084  -77.676  49.092  1
145498  96.098  -77.658  49.063  1
145499  96.102  -77.666  49.033  1
145500  96.111  -77.674  49.000  1
145501  96.120  -77.683  48.967  1
145502  96.127  -77.691  48.936  1
145503  96.110  -77.703  48.905  1
145504  96.093  -77.716  48.872  1
145505  96.099  -77.726  48.838  1
145506  96.111  -77.735  48.804  1
145507  96.122  -77.744  48.769  1
145508  96.148  -77.749  48.734  1
145509  96.175  -77.752  48.702  1
145510  96.200  -77.756  48.670  1
145511  96.215  -77.761  48.639  1
145512  96.229  -77.765  48.608  1
145513  96.243  -77.769  48.577  1
145514  96.258  -77.773  48.546  1
145515  96.272  -77.777  48.515  1
145516  96.285  -77.782  48.488  1
145517  96.294  -77.791  48.461  1
145518  96.302  -77.799  48.435  1
145519  96.313  -77.805  48.408  1
145520  96.331  -77.804  48.382  1
145521  96.349  -77.803  48.357  1
145522  96.367  -77.802  48.332  1
145523  96.385  -77.802  48.309  1
145524  96.398  -77.804  48.286  1
145525  96.403  -77.812  48.263  1
145526  96.407  -77.819  48.239  1
145527  96.411  -77.827  48.215  1
145528  96.416  -77.834  48.190  1
145529  96.419  -77.843  48.165  1
145530  96.410  -77.863  48.140  1
145531  96.424  -77.867  48.115  1
145532  96.444  -77.868  48.090  1
145533  96.464  -77.868  48.066  1
145534  96.484  -77.869  48.040  1
145535  96.505  -77.870  48.015  1
145536  96.525  -77.871  47.990  1
145537  96.545  -77.871  47.964  1
145538  96.565  -77.872  47.940  1
145539  96.583  -77.868  47.916  1
145540  96.595  -77.851  47.891  1
145541  96.608  -77.834  47.867  1
145542  96.621  -77.818  47.842  1
145543  96.633  -77.802  47.818  1
145544  96.651  -77.805  47.794  1
145545  96.669  -77.812  47.769  1
145546  96.688  -77.819  47.745  1
145547  96.707  -77.826  47.720  1
145548  96.725  -77.834  47.696  1
145549  96.744  -77.841  47.671  1
145550  96.762  -77.848  47.647  1
145551  96.778  -77.855  47.622  1
145552  96.793  -77.862  47.599  1
145553  96.811  -77.871  47.577  1
145554  96.833  -77.884  47.555  1
145555  96.856  -77.896  47.534  1
145556  96.877  -77.908  47.511  1
145557  96.888  -77.916  47.487  1
145558  96.897  -77.924  47.463  1
145559  96.906  -77.931  47.440  1
145560  96.915  -77.938  47.419  1
145561  96.925  -77.946  47.399  1
145562  96.934  -77.949  47.380  1
145563  96.942  -77.943  47.360  1
145564  96.950  -77.936  47.341  1
145565  96.972  -77.934  47.320  1
145566  96.996  -77.934  47.299  1
145567  97.017  -77.937  47.277  1
145568  97.037  -77.942  47.254  1
145569  97.058  -77.946  47.231  1
145570  97.078  -77.951  47.209  1
145571  97.098  -77.958  47.190  1
145572  97.119  -77.975  47.171  1
145573  97.140  -77.992  47.152  1
145574  97.161  -78.009  47.135  1
145575  97.181  -78.026  47.119  1
145576  97.196  -78.032  47.103  1
145577  97.207  -78.029  47.089  1
145578  97.217  -78.026  47.073  1
145579  97.227  -78.023  47.059  1
145580  97.248  -78.012  47.046  1
145581  97.273  -77.999  47.034  1
145582  97.297  -77.985  47.020  1
145583  97.319  -77.991  47.008  1
145584  97.341  -78.005  46.997  1
145585  97.362  -78.018  46.985  1
145586  97.383  -78.031  46.973  1
145587  97.404  -78.045  46.961  1
145588  97.425  -78.058  46.950  1
145589  97.446  -78.072  46.940  1
145590  97.470  -78.080  46.930  1
145591  97.484  -78.084  46.920  1
145592  97.477  -78.096  46.910  1
145593  97.470  -78.107  46.897  1
145594  97.468  -78.121  46.882  1
145595  97.492  -78.145  46.864  1
145596  97.516  -78.169  46.848  1
145597  97.538  -78.191  46.830  1
145598  97.553  -78.194  46.810  1
145599  97.568  -78.197  46.789  1
145600  97.611  -78.208  46.766  1
145601  97.658  -78.219  46.744  1
145602  97.705  -78.231  46.721  1
145603  97.751  -78.241  46.698  1
145604  97.798  -78.253  46.675  1
145605  97.845  -78.264  46.652  1
145606  97.891  -78.275  46.628  1
145607  97.938  -78.286  46.605  1
145608  97.984  -78.297  46.581  1
145609  98.031  -78.309  46.557  1
145610  98.077  -78.319  46.534  1
145611  98.124  -78.331  46.511  1
145612  98.166  -78.338  46.488  1
145613  98.196  -78.347  46.465  1
145614  98.202  -78.357  46.443  1
145615  98.217  -78.346  46.422  1
145616  98.237  -78.332  46.399  1
145617  98.256  -78.320  46.376  1
145618  98.276  -78.309  46.352  1
145619  98.296  -78.297  46.330  1
145620  98.316  -78.282  46.307  1
145621  98.338  -78.263  46.283  1
145622  98.359  -78.247  46.259  1
145623  98.380  -78.235  46.235  1
145624  98.367  -78.210  46.211  1
145625  98.393  -78.207  46.187  1
145626  98.435  -78.204  46.165  1
145627  98.477  -78.202  46.142  1
145628  98.519  -78.199  46.119  1
145629  98.561  -78.196  46.098  1
145630  98.602  -78.193  46.077  1
145631  98.636  -78.189  46.056  1
145632  98.637  -78.178  46.035  1
145633  98.639  -78.168  46.014  1
145634  98.641  -78.158  45.993  1
145635  98.643  -78.147  45.972  1
145636  98.644  -78.138  45.950  1
145637  98.646  -78.127  45.929  1
145638  98.648  -78.116  45.908  1
145639  98.647  -78.105  45.886  1
145640  98.646  -78.093  45.865  1
145641  98.662  -78.100  45.843  1
145642  98.702  -78.137  45.822  1
145643  98.742  -78.173  45.801  1
145644  98.782  -78.211  45.780  1
145645  98.801  -78.247  45.761  1
145646  98.810  -78.266  45.743  1
145647  98.818  -78.285  45.728  1
145648  98.826  -78.304  45.712  1
145649  98.858  -78.304  45.698  1
145650  98.890  -78.304  45.685  1
145651  98.914  -78.316  45.672  1
145652  98.938  -78.329  45.659  1
145653  98.962  -78.342  45.645  1
145654  98.988  -78.341  45.631  1
145655  99.012  -78.341  45.616  1
145656  99.037  -78.339  45.602  1
145657  99.060  -78.339  45.588  1
145658  99.075  -78.341  45.573  1
145659  99.102  -78.348  45.558  1
145660  99.135  -78.356  45.544  1
145661  99.167  -78.364  45.532  1
145662  99.199  -78.373  45.519  1
145663  99.232  -78.380  45.506  1
145664  99.264  -78.388  45.493  1
145665  99.297  -78.397  45.479  1
145666  99.329  -78.404  45.465  1
145667  99.362  -78.413  45.453  1
145668  99.394  -78.420  45.442  1
145669  99.426  -78.429  45.428  1
145670  99.459  -78.437  45.414  1
145671  99.491  -78.445  45.400  1
145672  99.524  -78.453  45.387  1
145673  99.556  -78.460  45.374  1
145674  99.588  -78.469  45.360  1
145675  99.623  -78.477  45.347  1
145676  99.677  -78.489  45.335  1
145677  99.729  -78.501  45.322  1
145678  99.767  -78.522  45.309  1
145679  99.793  -78.549  45.298  1
145680  99.834  -78.586  45.286  1
145681  99.867  -78.573  45.275  1
145682  99.886  -78.562  45.265  1
145683  99.893  -78.569  45.253  1
145684  99.900  -78.576  45.244  1
145685  99.907  -78.582  45.235  1
145686  99.914  -78.589  45.227  1
145687  99.921  -78.595  45.215  1
145688  99.928  -78.602  45.202  1
145689  99.935  -78.609  45.189  1
145690  99.942  -78.616  45.175  1
145691  99.949  -78.623  45.162  1
145692  99.956  -78.630  45.148  1
145693  99.968  -78.636  45.133  1
145694  100.003  -78.647  45.119  1
145695  100.052  -78.661  45.106  1
145696  100.101  -78.676  45.091  1
145697  100.140  -78.693  45.079  1
145698  100.178  -78.712  45.065  1
145699  100.216  -78.730  45.051  1
145700  100.254  -78.749  45.039  1
145701  100.279  -78.763  45.024  1
145702  100.297  -78.774  45.009  1
145703  100.316  -78.786  44.994  1
145704  100.334  -78.798  44.981  1
145705  100.352  -78.809  44.966  1
145706  100.367  -78.821  44.952  1
145707  100.378  -78.830  44.937  1
145708  100.388  -78.840  44.922  1
145709  100.398  -78.851  44.907  1
145710  100.413  -78.870  44.891  1
145711  100.428  -78.890  44.876  1
145712  100.443  -78.908  44.861  1
145713  100.454  -78.927  44.846  1
145714  100.464  -78.947  44.830  1
145715  100.475  -78.966  44.814  1
145716  100.485  -78.986  44.797  1
145717  100.501  -78.997  44.780  1
145718  100.517  -79.009  44.763  1
145719  100.534  -79.019  44.746  1
145720  100.550  -79.031  44.729  1
145721  100.581  -79.049  44.712  1
145722  100.614  -79.068  44.696  1
145723  100.646  -79.087  44.678  1
145724  100.679  -79.106  44.662  1
145725  100.711  -79.126  44.645  1
145726  100.744  -79.145  44.629  1
145727  100.776  -79.164  44.614  1
145728  100.809  -79.183  44.598  1
145729  100.855  -79.204  44.583  1
145730  100.908  -79.210  44.568  1
145731  100.960  -79.216  44.554  1
145971  92.726  -77.984  54.252  1
145972  92.744  -77.987  54.248  1
145973  92.763  -77.990  54.245  1
145974  92.781  -77.993  54.241  1
145975  92.799  -77.996  54.237  1
145976  92.817  -77.999  54.233  1
145977  92.836  -78.002  54.230  1
145978  92.854  -78.005  54.227  1
145979  92.873  -78.007  54.224  1
145980  92.891  -78.010  54.222  1
145981  92.909  -78.013  54.219  1
145982  92.928  -78.016  54.216  1
145983  92.946  -78.019  54.212  1
145984  92.965  -78.022  54.209  1
145985  92.983  -78.025  54.207  1
145986  93.000  -78.023  54.206  1
145987  93.016  -78.017  54.205  1
145988  93.034  -78.014  54.204  1
145989  93.054  -78.017  54.202  1
145990  93.074  -78.019  54.199  1
145991  93.094  -78.019  54.197  1
145992  93.114  -78.018  54.193  1
145993  93.134  -78.018  54.191  1
145994  93.153  -78.016  54.188  1
145995  93.174  -78.015  54.186  1
145996  93.193  -78.015  54.182  1
145997  93.213  -78.013  54.179  1
145998  93.232  -78.012  54.176  1
145999  93.266  -77.964  54.173  1
146000  93.287  -77.934  54.170  1
146001  93.294  -77.920  54.166  1
146002  93.292  -77.906  54.162  1
146003  93.291  -77.890  54.155  1
146004  93.290  -77.876  54.147  1
146005  93.289  -77.862  54.139  1
146006  93.288  -77.846  54.131  1
146007  93.287  -77.832  54.121  1
146008  93.290  -77.818  54.111  1
146009  93.306  -77.805  54.099  1
146010  93.322  -77.791  54.086  1
146011  93.338  -77.777  54.074  1
146012  93.361  -77.762  54.063  1
146013  93.393  -77.743  54.053  1
146014  93.404  -77.723  54.043  1
146015  93.414  -77.703  54.032  1
146016  93.424  -77.683  54.021  1
146017  93.438  -77.675  54.008  1
146018  93.452  -77.667  53.996  1
146019  93.467  -77.660  53.984  1
146020  93.483  -77.652  53.972  1
146021  93.499  -77.645  53.959  1
146022  93.514  -77.637  53.946  1
146023  93.530  -77.630  53.930  1
146024  93.545  -77.620  53.913  1
146025  93.560  -77.611  53.894  1
146026  93.575  -77.602  53.877  1
146027  93.590  -77.592  53.861  1
146028  93.606  -77.583  53.844  1
146029  93.621  -77.573  53.828  1
146030  93.630  -77.568  53.811  1
146031  93.638  -77.565  53.794  1
146032  93.645  -77.562  53.774  1
146033  93.653  -77.558  53.755  1
146034  93.661  -77.555  53.737  1
146035  93.673  -77.550  53.718  1
146036  93.683  -77.545  53.701  1
146037  93.694  -77.540  53.682  1
146038  93.705  -77.536  53.664  1
146039  93.719  -77.532  53.645  1
146040  93.733  -77.528  53.628  1
146041  93.747  -77.523  53.611  1
146042  93.761  -77.519  53.595  1
146043  93.776  -77.511  53.579  1
146044  93.791  -77.503  53.563  1
146045  93.806  -77.495  53.548  1
146046  93.822  -77.486  53.535  1
146047  93.837  -77.477  53.521  1
146048  93.852  -77.462  53.508  1
146049  93.867  -77.446  53.494  1
146050  93.883  -77.430  53.478  1
146051  93.901  -77.410  53.462  1
146052  93.919  -77.389  53.447  1
146053  93.937  -77.367  53.433  1
146054  93.951  -77.348  53.418  1
146055  93.955  -77.347  53.405  1
146056  93.955  -77.376  53.394  1
146057  93.972  -77.389  53.384  1
146058  94.000  -77.390  53.373  1
146059  94.028  -77.392  53.361  1
146060  94.056  -77.392  53.349  1
146061  94.084  -77.394  53.334  1
146062  94.112  -77.395  53.315  1
146063  94.132  -77.401  53.295  1
146064  94.150  -77.407  53.275  1
146065  94.152  -77.410  53.254  1
146066  94.150  -77.410  53.233  1
146067  94.147  -77.409  53.212  1
146068  94.149  -77.401  53.196  1
146069  94.150  -77.394  53.182  1
146070  94.151  -77.386  53.172  1
146071  94.162  -77.379  53.168  1
146072  94.180  -77.371  53.161  1
146073  94.197  -77.363  53.153  1
146074  94.215  -77.356  53.143  1
146075  94.233  -77.348  53.133  1
146076  94.245  -77.346  53.120  1
146077  94.242  -77.355  53.105  1
146078  94.242  -77.372  53.090  1
146079  94.243  -77.382  53.073  1
146080  94.244  -77.384  53.056  1
146081  94.245  -77.386  53.040  1
146082  94.246  -77.388  53.025  1
146083  94.241  -77.370  53.010  1
146084  94.268  -77.369  52.996  1
146085  94.305  -77.373  52.984  1
146086  94.326  -77.373  52.974  1
146087  94.333  -77.370  52.960  1
146088  94.340  -77.365  52.948  1
146089  94.349  -77.350  52.937  1
146090  94.359  -77.334  52.930  1
146091  94.368  -77.318  52.923  1
146092  94.377  -77.302  52.914  1
146093  94.391  -77.291  52.901  1
146094  94.413  -77.287  52.883  1
146095  94.435  -77.282  52.863  1
146096  94.457  -77.278  52.842  1
146097  94.475  -77.273  52.823  1
146098  94.493  -77.267  52.807  1
146099  94.511  -77.262  52.792  1
146100  94.530  -77.257  52.778  1
146101  94.548  -77.251  52.763  1
146102  94.566  -77.245  52.746  1
146103  94.588  -77.252  52.728  1
146104  94.607  -77.258  52.709  1
146105  94.623  -77.259  52.690  1
146106  94.639  -77.260  52.669  1
146107  94.656  -77.261  52.646  1
146108  94.673  -77.262  52.623  1
146109  94.689  -77.263  52.599  1
146110  94.705  -77.264  52.572  1
146111  94.722  -77.266  52.545  1
146112  94.756  -77.265  52.513  1
146113  94.781  -77.271  52.482  1
146114  94.808  -77.277  52.452  1
146115  94.836  -77.288  52.425  1
146116  94.855  -77.281  52.399  1
146117  94.874  -77.277  52.372  1
146118  94.892  -77.285  52.342  1
146119  94.909  -77.291  52.309  1
146120  94.927  -77.298  52.272  1
146121  94.945  -77.305  52.234  1
146122  94.963  -77.312  52.198  1
146123  94.980  -77.319  52.162  1
146124  94.991  -77.307  52.125  1
146125  95.000  -77.298  52.086  1
146126  95.007  -77.295  52.049  1
146127  95.014  -77.275  52.009  1
146128  95.021  -77.254  51.970  1
146129  95.028  -77.234  51.932  1
146130  95.035  -77.213  51.893  1
146131  95.050  -77.210  51.853  1
146132  95.076  -77.227  51.811  1
146133  95.103  -77.244  51.765  1
146134  95.130  -77.262  51.712  1
146135  95.142  -77.284  51.657  1
146136  95.144  -77.308  51.598  1
146137  95.157  -77.310  51.539  1
146138  95.174  -77.303  51.475  1
146139  95.190  -77.297  51.409  1
146140  95.206  -77.291  51.344  1
146141  95.223  -77.284  51.282  1
146142  95.240  -77.278  51.225  1
146143  95.256  -77.271  51.170  1
146144  95.272  -77.265  51.118  1
146145  95.289  -77.259  51.073  1
146146  95.305  -77.252  51.029  1
146147  95.322  -77.246  50.984  1
146148  95.338  -77.240  50.937  1
146149  95.366  -77.241  50.892  1
146150  95.396  -77.244  50.849  1
146151  95.426  -77.248  50.808  1
146152  95.457  -77.252  50.772  1
146153  95.485  -77.269  50.738  1
146154  95.511  -77.291  50.704  1
146155  95.537  -77.314  50.669  1
146156  95.564  -77.337  50.637  1
146157  95.590  -77.360  50.605  1
146158  95.616  -77.382  50.576  1
146159  95.642  -77.405  50.543  1
146160  95.644  -77.409  50.508  1
146161  95.646  -77.413  50.469  1
146162  95.648  -77.417  50.427  1
146163  95.650  -77.420  50.388  1
146164  95.652  -77.424  50.351  1
146165  95.654  -77.428  50.317  1
146166  95.656  -77.432  50.279  1
146167  95.670  -77.445  50.239  1
146168  95.685  -77.456  50.197  1
146169  95.700  -77.468  50.155  1
146170  95.716  -77.479  50.110  1
146171  95.735  -77.486  50.069  1
146172  95.754  -77.494  50.029  1
146173  95.774  -77.502  49.991  1
146174  95.793  -77.510  49.946  1
146175  95.812  -77.517  49.900  1
146176  95.832  -77.525  49.852  1
146177  95.855  -77.545  49.803  1
146178  95.879  -77.564  49.755  1
146179  95.902  -77.584  49.707  1
146180  95.920  -77.590  49.662  1
146181  95.936  -77.588  49.617  1
146182  95.951  -77.586  49.577  1
146183  95.966  -77.583  49.540  1
146184  95.972  -77.589  49.504  1
146185  95.976  -77.595  49.470  1
146186  95.979  -77.603  49.436  1
146187  95.983  -77.610  49.403  1
146188  95.986  -77.617  49.371  1
146189  95.990  -77.625  49.341  1
146190  95.993  -77.632  49.314  1
146191  95.995  -77.645  49.289  1
146192  96.007  -77.662  49.261  1
146193  96.021  -77.672  49.232  1
146194  96.036  -77.677  49.203  1
146195  96.052  -77.683  49.177  1
146196  96.068  -77.688  49.152  1
146197  96.081  -77.672  49.127  1
146198  96.093  -77.656  49.103  1
146199  96.098  -77.653  49.076  1
146200  96.112  -77.659  49.046  1
146201  96.125  -77.666  49.014  1
146202  96.133  -77.674  48.982  1
146203  96.130  -77.684  48.951  1
146204  96.113  -77.697  48.919  1
146205  96.096  -77.709  48.887  1
146206  96.096  -77.720  48.853  1
146207  96.108  -77.729  48.819  1
146208  96.129  -77.735  48.784  1
146209  96.157  -77.739  48.749  1
146210  96.184  -77.743  48.717  1
146211  96.203  -77.747  48.686  1
146212  96.218  -77.751  48.654  1
146213  96.232  -77.755  48.624  1
146214  96.247  -77.759  48.592  1
146215  96.261  -77.763  48.561  1
146216  96.271  -77.771  48.531  1
146217  96.279  -77.779  48.503  1
146218  96.288  -77.787  48.477  1
146219  96.296  -77.796  48.450  1
146220  96.309  -77.800  48.423  1
146221  96.326  -77.800  48.399  1
146222  96.344  -77.799  48.374  1
146223  96.362  -77.799  48.349  1
146224  96.380  -77.798  48.326  1
146225  96.398  -77.797  48.303  1
146226  96.415  -77.797  48.280  1
146227  96.434  -77.796  48.256  1
146228  96.439  -77.803  48.232  1
146229  96.443  -77.811  48.208  1
146230  96.439  -77.826  48.183  1
146231  96.427  -77.848  48.158  1
146232  96.432  -77.858  48.133  1
146233  96.445  -77.862  48.108  1
146234  96.465  -77.863  48.084  1
146235  96.485  -77.864  48.059  1
146236  96.505  -77.865  48.034  1
146237  96.525  -77.865  48.008  1
146238  96.545  -77.866  47.983  1
146239  96.566  -77.867  47.959  1
146240  96.584  -77.864  47.934  1
146241  96.597  -77.848  47.909  1
146242  96.609  -77.831  47.885  1
146243  96.622  -77.815  47.861  1
146244  96.635  -77.798  47.837  1
146245  96.650  -77.789  47.812  1
146246  96.668  -77.796  47.786  1
146247  96.686  -77.804  47.762  1
146248  96.705  -77.811  47.738  1
146249  96.724  -77.818  47.714  1
146250  96.742  -77.826  47.689  1
146251  96.758  -77.833  47.664  1
146252  96.774  -77.839  47.639  1
146253  96.793  -77.849  47.616  1
146254  96.815  -77.862  47.594  1
146255  96.837  -77.874  47.572  1
146256  96.859  -77.886  47.551  1
146257  96.881  -77.899  47.527  1
146258  96.894  -77.908  47.503  1
146259  96.903  -77.915  47.479  1
146260  96.912  -77.922  47.457  1
146261  96.922  -77.930  47.436  1
146262  96.931  -77.937  47.417  1
146263  96.939  -77.937  47.398  1
146264  96.948  -77.929  47.378  1
146265  96.956  -77.922  47.358  1
146266  96.972  -77.918  47.337  1
146267  96.995  -77.918  47.315  1
146268  97.016  -77.921  47.293  1
146269  97.037  -77.925  47.271  1
146270  97.057  -77.930  47.249  1
146271  97.077  -77.934  47.227  1
146272  97.098  -77.950  47.208  1
146273  97.119  -77.967  47.189  1
146274  97.140  -77.984  47.170  1
146275  97.161  -78.001  47.152  1
146276  97.181  -78.018  47.137  1
146277  97.201  -78.031  47.122  1
146278  97.211  -78.028  47.106  1
146279  97.221  -78.025  47.090  1
146280  97.237  -78.018  47.076  1
146281  97.261  -78.004  47.063  1
146282  97.286  -77.991  47.050  1
146283  97.310  -77.978  47.036  1
146284  97.332  -77.986  47.023  1
146285  97.353  -78.000  47.012  1
146286  97.374  -78.012  46.999  1
146287  97.395  -78.026  46.987  1
146288  97.417  -78.040  46.974  1
146289  97.438  -78.053  46.962  1
146290  97.459  -78.066  46.950  1
146291  97.480  -78.080  46.939  1
146292  97.490  -78.095  46.928  1
146293  97.484  -78.107  46.916  1
146294  97.476  -78.119  46.903  1
146295  97.469  -78.130  46.888  1
146296  97.467  -78.144  46.872  1
146297  97.491  -78.168  46.857  1
146298  97.514  -78.190  46.840  1
146299  97.529  -78.193  46.821  1
146300  97.563  -78.201  46.801  1
146301  97.609  -78.213  46.779  1
146302  97.656  -78.223  46.756  1
146303  97.702  -78.235  46.733  1
146304  97.749  -78.246  46.710  1
146305  97.795  -78.257  46.687  1
146306  97.842  -78.268  46.663  1
146307  97.888  -78.279  46.639  1
146308  97.935  -78.291  46.615  1
146309  97.982  -78.301  46.590  1
146310  98.028  -78.313  46.567  1
146311  98.075  -78.324  46.545  1
146312  98.122  -78.335  46.522  1
146313  98.161  -78.345  46.498  1
146314  98.170  -78.344  46.475  1
146315  98.181  -78.339  46.454  1
146316  98.203  -78.321  46.432  1
146317  98.224  -78.302  46.411  1
146318  98.245  -78.289  46.388  1
146319  98.267  -78.278  46.363  1
146320  98.288  -78.266  46.340  1
146321  98.309  -78.254  46.318  1
146322  98.330  -78.243  46.293  1
146323  98.352  -78.232  46.270  1
146324  98.358  -78.213  46.246  1
146325  98.362  -78.200  46.221  1
146326  98.392  -78.202  46.199  1
146327  98.406  -78.210  46.175  1
146328  98.431  -78.213  46.152  1
146329  98.473  -78.211  46.129  1
146330  98.515  -78.208  46.108  1
146331  98.557  -78.205  46.087  1
146332  98.598  -78.202  46.065  1
146333  98.611  -78.194  46.045  1
146334  98.613  -78.184  46.023  1
146335  98.615  -78.173  46.001  1
146336  98.617  -78.163  45.980  1
146337  98.618  -78.153  45.959  1
146338  98.620  -78.143  45.938  1
146339  98.619  -78.131  45.917  1
146340  98.618  -78.119  45.896  1
146341  98.617  -78.106  45.875  1
146342  98.640  -78.122  45.855  1
146343  98.680  -78.158  45.835  1
146344  98.720  -78.195  45.813  1
146345  98.758  -78.227  45.792  1
146346  98.781  -78.238  45.773  1
146347  98.789  -78.257  45.754  1
146348  98.796  -78.276  45.738  1
146349  98.819  -78.283  45.723  1
146350  98.851  -78.282  45.708  1
146351  98.883  -78.282  45.696  1
146352  98.909  -78.291  45.682  1
146353  98.933  -78.304  45.669  1
146354  98.957  -78.318  45.656  1
146355  98.981  -78.331  45.642  1
146356  99.006  -78.336  45.629  1
146357  99.030  -78.335  45.615  1
146358  99.052  -78.335  45.600  1
146359  99.076  -78.341  45.586  1
146360  99.108  -78.349  45.571  1
146361  99.141  -78.357  45.557  1
146362  99.173  -78.365  45.544  1
146363  99.205  -78.373  45.531  1
146364  99.238  -78.382  45.518  1
146365  99.270  -78.389  45.505  1
146366  99.303  -78.398  45.491  1
146367  99.335  -78.406  45.477  1
146368  99.368  -78.413  45.464  1
146369  99.400  -78.422  45.452  1
146370  99.432  -78.429  45.439  1
146371  99.465  -78.438  45.425  1
146372  99.497  -78.446  45.411  1
146373  99.530  -78.454  45.398  1
146374  99.562  -78.462  45.384  1
146375  99.594  -78.470  45.371  1
146376  99.627  -78.478  45.358  1
146377  99.659  -78.486  45.346  1
146378  99.712  -78.498  45.334  1
146379  99.749  -78.519  45.322  1
146380  99.784  -78.554  45.310  1
146381  99.830  -78.595  45.298  1
146382  99.853  -78.556  45.287  1
146383  99.893  -78.557  45.276  1
146384  99.899  -78.564  45.265  1
146385  99.906  -78.571  45.255  1
146386  99.913  -78.577  45.246  1
146387  99.920  -78.584  45.238  1
146388  99.927  -78.591  45.226  1
146389  99.934  -78.597  45.214  1
146390  99.941  -78.604  45.200  1
146391  99.948  -78.611  45.186  1
146392  99.955  -78.617  45.173  1
146393  99.963  -78.623  45.159  1
146394  99.972  -78.630  45.145  1
146395  100.013  -78.643  45.131  1
146396  100.062  -78.658  45.117  1
146397  100.111  -78.672  45.103  1
146398  100.149  -78.690  45.090  1
146399  100.187  -78.708  45.076  1
146400  100.225  -78.727  45.062  1
146401  100.262  -78.745  45.049  1
146402  100.280  -78.756  45.034  1
146403  100.298  -78.768  45.019  1
146404  100.316  -78.780  45.004  1
146405  100.334  -78.791  44.990  1
146406  100.352  -78.803  44.975  1
146407  100.370  -78.814  44.960  1
146408  100.384  -78.825  44.945  1
146409  100.394  -78.835  44.929  1
146410  100.404  -78.846  44.914  1
146411  100.418  -78.861  44.899  1
146412  100.433  -78.881  44.884  1
146413  100.448  -78.901  44.869  1
146414  100.463  -78.920  44.853  1
146415  100.474  -78.940  44.837  1
146416  100.484  -78.959  44.820  1
146417  100.494  -78.977  44.804  1
146418  100.508  -78.992  44.787  1
146419  100.525  -79.003  44.769  1
146420  100.541  -79.015  44.752  1
146421  100.557  -79.025  44.735  1
146422  100.578  -79.039  44.718  1
146423  100.611  -79.059  44.701  1
146424  100.643  -79.078  44.684  1
146425  100.676  -79.096  44.668  1
146426  100.708  -79.115  44.651  1
146427  100.741  -79.134  44.635  1
146428  100.773  -79.154  44.619  1
146429  100.806  -79.173  44.603  1
146430  100.861  -79.187  44.589  1
146431  100.913  -79.194  44.574  1
146432  100.965  -79.200  44.559  1
146433  101.017  -79.206  44.545  1
146434  101.069  -79.212  44.532  1
146672  92.706  -77.940  54.248  1
146673  92.724  -77.943  54.244  1
146674  92.742  -77.946  54.241  1
146675  92.761  -77.949  54.237  1
146676  92.779  -77.952  54.234  1
146677  92.798  -77.955  54.230  1
146678  92.816  -77.958  54.228  1
146679  92.834  -77.960  54.224  1
146680  92.853  -77.963  54.222  1
146681  92.871  -77.966  54.220  1
146682  92.889  -77.969  54.218  1
146683  92.908  -77.972  54.215  1
146684  92.926  -77.975  54.212  1
146685  92.944  -77.978  54.209  1
146686  92.963  -77.982  54.207  1
146687  92.983  -77.990  54.206  1
146688  93.003  -77.996  54.206  1
146689  93.021  -77.996  54.206  1
146690  93.042  -77.996  54.204  1
146691  93.061  -77.994  54.202  1
146692  93.081  -77.993  54.200  1
146693  93.100  -77.993  54.199  1
146694  93.121  -77.992  54.196  1
146695  93.140  -77.990  54.194  1
146696  93.160  -77.990  54.192  1
146697  93.180  -77.989  54.190  1
146698  93.200  -77.987  54.187  1
146699  93.220  -77.985  54.184  1
146700  93.256  -77.930  54.182  1
146701  93.269  -77.912  54.179  1
146702  93.280  -77.899  54.176  1
146703  93.289  -77.885  54.173  1
146704  93.288  -77.871  54.165  1
146705  93.287  -77.856  54.158  1
146706  93.286  -77.841  54.150  1
146707  93.285  -77.827  54.142  1
146708  93.284  -77.812  54.132  1
146709  93.283  -77.797  54.121  1
146710  93.298  -77.784  54.110  1
146711  93.313  -77.771  54.097  1
146712  93.330  -77.757  54.086  1
146713  93.345  -77.744  54.076  1
146714  93.365  -77.730  54.067  1
146715  93.393  -77.710  54.058  1
146716  93.403  -77.690  54.048  1
146717  93.414  -77.671  54.037  1
146718  93.428  -77.663  54.026  1
146719  93.442  -77.655  54.014  1
146720  93.458  -77.648  54.003  1
146721  93.474  -77.640  53.992  1
146722  93.490  -77.633  53.980  1
146723  93.505  -77.625  53.968  1
146724  93.521  -77.617  53.954  1
146725  93.537  -77.608  53.939  1
146726  93.552  -77.599  53.924  1
146727  93.567  -77.589  53.908  1
146728  93.581  -77.580  53.892  1
146729  93.597  -77.570  53.875  1
146730  93.619  -77.558  53.861  1
146731  93.626  -77.559  53.845  1
146732  93.629  -77.561  53.827  1
146733  93.641  -77.547  53.808  1
146734  93.648  -77.544  53.788  1
146735  93.656  -77.540  53.768  1
146736  93.664  -77.536  53.748  1
146737  93.676  -77.532  53.729  1
146738  93.686  -77.527  53.710  1
146739  93.700  -77.523  53.690  1
146740  93.713  -77.519  53.672  1
146741  93.728  -77.513  53.654  1
146742  93.743  -77.505  53.637  1
146743  93.758  -77.497  53.621  1
146744  93.773  -77.489  53.605  1
146745  93.788  -77.480  53.589  1
146746  93.803  -77.473  53.575  1
146747  93.819  -77.461  53.563  1
146748  93.834  -77.445  53.550  1
146749  93.850  -77.430  53.538  1
146750  93.865  -77.414  53.524  1
146751  93.882  -77.396  53.507  1
146752  93.900  -77.375  53.491  1
146753  93.918  -77.354  53.475  1
146754  93.936  -77.332  53.462  1
146755  93.951  -77.312  53.446  1
146756  93.954  -77.328  53.432  1
146757  93.954  -77.357  53.418  1
146758  93.967  -77.373  53.406  1
146759  93.994  -77.375  53.396  1
146760  94.023  -77.376  53.385  1
146761  94.051  -77.377  53.373  1
146762  94.079  -77.378  53.358  1
146763  94.099  -77.384  53.341  1
146764  94.118  -77.391  53.323  1
146765  94.136  -77.398  53.304  1
146766  94.135  -77.398  53.282  1
146767  94.132  -77.398  53.261  1
146768  94.129  -77.398  53.240  1
146769  94.128  -77.395  53.223  1
146770  94.143  -77.388  53.207  1
146771  94.160  -77.380  53.195  1
146772  94.178  -77.373  53.187  1
146773  94.196  -77.365  53.181  1
146774  94.213  -77.358  53.175  1
146775  94.231  -77.351  53.169  1
146776  94.249  -77.343  53.160  1
146777  94.254  -77.346  53.148  1
146778  94.252  -77.355  53.134  1
146779  94.250  -77.362  53.120  1
146780  94.250  -77.363  53.103  1
146781  94.251  -77.366  53.087  1
146782  94.252  -77.368  53.072  1
146783  94.253  -77.370  53.057  1
146784  94.250  -77.354  53.040  1
146785  94.286  -77.359  53.025  1
146786  94.309  -77.360  53.010  1
146787  94.316  -77.356  52.994  1
146788  94.324  -77.352  52.981  1
146789  94.332  -77.343  52.969  1
146790  94.341  -77.327  52.959  1
146791  94.350  -77.312  52.950  1
146792  94.360  -77.297  52.942  1
146793  94.373  -77.285  52.936  1
146794  94.389  -77.275  52.927  1
146795  94.411  -77.270  52.911  1
146796  94.434  -77.266  52.893  1
146797  94.456  -77.263  52.873  1
146798  94.479  -77.259  52.853  1
146799  94.501  -77.254  52.834  1
146800  94.524  -77.251  52.817  1
146801  94.546  -77.247  52.801  1
146802  94.568  -77.243  52.786  1
146803  94.591  -77.238  52.771  1
146804  94.611  -77.235  52.755  1
146805  94.621  -77.235  52.738  1
146806  94.636  -77.236  52.721  1
146807  94.651  -77.237  52.701  1
146808  94.666  -77.238  52.680  1
146809  94.680  -77.238  52.657  1
146810  94.695  -77.240  52.631  1
146811  94.710  -77.241  52.604  1
146812  94.724  -77.241  52.575  1
146813  94.738  -77.254  52.544  1
146814  94.765  -77.257  52.514  1
146815  94.794  -77.256  52.485  1
146816  94.824  -77.265  52.458  1
146817  94.835  -77.274  52.432  1
146818  94.854  -77.285  52.404  1
146819  94.873  -77.296  52.373  1
146820  94.892  -77.307  52.339  1
146821  94.910  -77.316  52.302  1
146822  94.928  -77.323  52.265  1
146823  94.946  -77.330  52.228  1
146824  94.963  -77.335  52.190  1
146825  94.972  -77.320  52.152  1
146826  94.974  -77.296  52.113  1
146827  94.991  -77.273  52.075  1
146828  94.998  -77.252  52.036  1
146829  95.004  -77.232  51.997  1
146830  95.012  -77.211  51.957  1
146831  95.018  -77.191  51.918  1
146832  95.044  -77.206  51.877  1
146833  95.070  -77.223  51.833  1
146834  95.097  -77.241  51.786  1
146835  95.123  -77.258  51.733  1
146836  95.144  -77.277  51.678  1
146837  95.147  -77.302  51.621  1
146838  95.161  -77.301  51.560  1
146839  95.178  -77.294  51.494  1
146840  95.194  -77.288  51.427  1
146841  95.210  -77.281  51.360  1
146842  95.227  -77.275  51.299  1
146843  95.243  -77.268  51.242  1
146844  95.260  -77.262  51.188  1
146845  95.276  -77.256  51.137  1
146846  95.293  -77.249  51.091  1
146847  95.309  -77.243  51.046  1
146848  95.326  -77.236  51.002  1
146849  95.342  -77.230  50.956  1
146850  95.358  -77.224  50.912  1
146851  95.379  -77.220  50.870  1
146852  95.408  -77.223  50.829  1
146853  95.439  -77.227  50.791  1
146854  95.466  -77.250  50.755  1
146855  95.492  -77.273  50.720  1
146856  95.518  -77.295  50.685  1
146857  95.544  -77.317  50.651  1
146858  95.571  -77.340  50.620  1
146859  95.597  -77.363  50.591  1
146860  95.623  -77.385  50.558  1
146861  95.648  -77.407  50.523  1
146862  95.650  -77.411  50.484  1
146863  95.652  -77.415  50.442  1
146864  95.654  -77.419  50.403  1
146865  95.656  -77.423  50.367  1
146866  95.658  -77.426  50.332  1
146867  95.668  -77.436  50.295  1
146868  95.683  -77.448  50.256  1
146869  95.697  -77.460  50.216  1
146870  95.712  -77.472  50.174  1
146871  95.727  -77.484  50.129  1
146872  95.745  -77.492  50.088  1
146873  95.764  -77.500  50.048  1
146874  95.783  -77.508  50.008  1
146875  95.803  -77.516  49.963  1
146876  95.822  -77.523  49.917  1
146877  95.841  -77.531  49.870  1
146878  95.861  -77.539  49.821  1
146879  95.880  -77.546  49.771  1
146880  95.901  -77.559  49.722  1
146881  95.924  -77.578  49.675  1
146882  95.944  -77.587  49.631  1
146883  95.959  -77.585  49.589  1
146884  95.970  -77.586  49.550  1
146885  95.974  -77.593  49.515  1
146886  95.977  -77.601  49.480  1
146887  95.981  -77.608  49.445  1
146888  95.984  -77.615  49.412  1
146889  95.987  -77.622  49.380  1
146890  95.991  -77.630  49.350  1
146891  95.994  -77.637  49.322  1
146892  95.999  -77.643  49.298  1
146893  96.015  -77.648  49.273  1
146894  96.031  -77.653  49.245  1
146895  96.046  -77.658  49.214  1
146896  96.062  -77.664  49.184  1
146897  96.078  -77.667  49.159  1
146898  96.091  -77.652  49.135  1
146899  96.100  -77.640  49.111  1
146900  96.097  -77.650  49.085  1
146901  96.103  -77.658  49.057  1
146902  96.118  -77.664  49.027  1
146903  96.133  -77.671  48.996  1
146904  96.130  -77.680  48.965  1
146905  96.117  -77.690  48.934  1
146906  96.100  -77.703  48.901  1
146907  96.093  -77.714  48.868  1
146908  96.111  -77.721  48.835  1
146909  96.138  -77.725  48.800  1
146910  96.166  -77.729  48.763  1
146911  96.192  -77.733  48.732  1
146912  96.207  -77.737  48.701  1
146913  96.222  -77.741  48.670  1
146914  96.236  -77.745  48.639  1
146915  96.249  -77.751  48.607  1
146916  96.257  -77.759  48.575  1
146917  96.265  -77.768  48.545  1
146918  96.273  -77.776  48.518  1
146919  96.282  -77.784  48.491  1
146920  96.290  -77.793  48.465  1
146921  96.304  -77.796  48.441  1
146922  96.321  -77.796  48.416  1
146923  96.339  -77.796  48.391  1
146924  96.357  -77.795  48.365  1
146925  96.375  -77.794  48.343  1
146926  96.393  -77.793  48.320  1
146927  96.411  -77.793  48.297  1
146928  96.429  -77.793  48.274  1
146929  96.446  -77.792  48.250  1
146930  96.465  -77.791  48.226  1
146931  96.459  -77.808  48.201  1
146932  96.447  -77.831  48.178  1
146933  96.443  -77.846  48.152  1
146934  96.453  -77.853  48.128  1
146935  96.466  -77.858  48.104  1
146936  96.486  -77.859  48.078  1
146937  96.506  -77.859  48.053  1
146938  96.526  -77.860  48.028  1
146939  96.546  -77.861  48.003  1
146940  96.566  -77.862  47.979  1
146941  96.586  -77.861  47.954  1
146942  96.598  -77.844  47.929  1
146943  96.611  -77.827  47.904  1
146944  96.623  -77.811  47.879  1
146945  96.637  -77.794  47.855  1
146946  96.649  -77.777  47.831  1
146947  96.667  -77.781  47.806  1
146948  96.685  -77.788  47.781  1
146949  96.703  -77.796  47.756  1
146950  96.722  -77.803  47.732  1
146951  96.740  -77.810  47.707  1
146952  96.755  -77.817  47.682  1
146953  96.774  -77.827  47.658  1
146954  96.797  -77.840  47.634  1
146955  96.818  -77.852  47.612  1
146956  96.840  -77.864  47.590  1
146957  96.863  -77.877  47.567  1
146958  96.885  -77.889  47.543  1
146959  96.901  -77.899  47.519  1
146960  96.910  -77.906  47.495  1
146961  96.919  -77.914  47.474  1
146962  96.928  -77.921  47.453  1
146963  96.937  -77.928  47.433  1
146964  96.945  -77.923  47.414  1
146965  96.954  -77.916  47.394  1
146966  96.962  -77.909  47.374  1
146967  96.971  -77.902  47.353  1
146968  96.995  -77.901  47.333  1
146969  97.016  -77.904  47.311  1
146970  97.036  -77.909  47.288  1
146971  97.056  -77.913  47.267  1
146972  97.077  -77.924  47.246  1
146973  97.098  -77.942  47.227  1
146974  97.119  -77.959  47.208  1
146975  97.140  -77.976  47.190  1
146976  97.161  -77.993  47.172  1
146977  97.181  -78.010  47.156  1
146978  97.202  -78.027  47.141  1
146979  97.214  -78.028  47.125  1
146980  97.226  -78.023  47.110  1
146981  97.250  -78.010  47.095  1
146982  97.275  -77.996  47.080  1
146983  97.299  -77.984  47.067  1
146984  97.323  -77.970  47.053  1
146985  97.345  -77.981  47.039  1
146986  97.366  -77.994  47.027  1
146987  97.387  -78.007  47.014  1
146988  97.408  -78.021  47.000  1
146989  97.430  -78.034  46.987  1
146990  97.451  -78.047  46.975  1
146991  97.473  -78.062  46.962  1
146992  97.496  -78.080  46.949  1
146993  97.490  -78.094  46.936  1
146994  97.485  -78.109  46.923  1
146995  97.480  -78.125  46.909  1
146996  97.476  -78.141  46.895  1
146997  97.469  -78.153  46.879  1
146998  97.466  -78.166  46.865  1
146999  97.490  -78.188  46.849  1
147000  97.513  -78.194  46.831  1
147001  97.560  -78.205  46.811  1
147002  97.606  -78.216  46.790  1
147003  97.653  -78.228  46.767  1
147004  97.700  -78.238  46.744  1
147005  97.746  -78.250  46.721  1
147006  97.793  -78.261  46.697  1
147007  97.840  -78.272  46.672  1
147008  97.888  -78.284  46.649  1
147009  97.938  -78.295  46.624  1
147010  97.987  -78.307  46.600  1
147011  98.036  -78.318  46.578  1
147012  98.074  -78.324  46.557  1
147013  98.110  -78.329  46.533  1
147014  98.132  -78.329  46.510  1
147015  98.145  -78.319  46.486  1
147016  98.174  -78.308  46.465  1
147017  98.195  -78.297  46.443  1
147018  98.216  -78.285  46.421  1
147019  98.238  -78.274  46.399  1
147020  98.259  -78.262  46.374  1
147021  98.280  -78.250  46.350  1
147022  98.301  -78.239  46.327  1
147023  98.323  -78.228  46.303  1
147024  98.344  -78.216  46.280  1
147025  98.333  -78.193  46.257  1
147026  98.363  -78.194  46.233  1
147027  98.393  -78.196  46.210  1
147028  98.423  -78.197  46.186  1
147029  98.443  -78.202  46.162  1
147030  98.432  -78.221  46.140  1
147031  98.469  -78.220  46.118  1
147032  98.511  -78.217  46.096  1
147033  98.553  -78.214  46.073  1
147034  98.585  -78.210  46.053  1
147035  98.587  -78.200  46.031  1
147036  98.588  -78.189  46.009  1
147037  98.590  -78.178  45.987  1
147038  98.592  -78.169  45.966  1
147039  98.591  -78.156  45.945  1
147040  98.590  -78.144  45.924  1
147041  98.589  -78.131  45.904  1
147042  98.588  -78.119  45.883  1
147043  98.617  -78.143  45.863  1
147044  98.657  -78.180  45.844  1
147045  98.697  -78.214  45.823  1
147046  98.720  -78.225  45.803  1
147047  98.744  -78.237  45.784  1
147048  98.767  -78.248  45.765  1
147049  98.780  -78.263  45.748  1
147050  98.812  -78.262  45.734  1
147051  98.844  -78.261  45.720  1
147052  98.875  -78.260  45.706  1
147053  98.904  -78.267  45.692  1
147054  98.928  -78.280  45.679  1
147055  98.952  -78.294  45.665  1
147056  98.976  -78.307  45.652  1
147057  99.000  -78.319  45.639  1
147058  99.024  -78.332  45.626  1
147059  99.049  -78.334  45.612  1
147060  99.082  -78.342  45.598  1
147061  99.114  -78.351  45.584  1
147062  99.147  -78.358  45.569  1
147063  99.179  -78.366  45.556  1
147064  99.212  -78.374  45.544  1
147065  99.244  -78.382  45.531  1
147066  99.276  -78.391  45.517  1
147067  99.309  -78.398  45.504  1
147068  99.341  -78.407  45.490  1
147069  99.374  -78.415  45.475  1
147070  99.406  -78.423  45.463  1
147071  99.438  -78.431  45.450  1
147072  99.471  -78.438  45.437  1
147073  99.503  -78.447  45.423  1
147074  99.536  -78.455  45.409  1
147075  99.568  -78.463  45.395  1
147076  99.600  -78.471  45.382  1
147077  99.633  -78.479  45.369  1
147078  99.665  -78.487  45.357  1
147079  99.698  -78.495  45.346  1
147080  99.738  -78.522  45.335  1
147081  99.780  -78.562  45.323  1
147082  99.825  -78.603  45.312  1
147083  99.859  -78.560  45.300  1
147084  99.902  -78.555  45.288  1
147085  99.909  -78.562  45.277  1
147086  99.916  -78.568  45.267  1
147087  99.923  -78.575  45.256  1
147088  99.929  -78.582  45.246  1
147089  99.938  -78.589  45.235  1
147090  99.947  -78.595  45.222  1
147091  99.957  -78.601  45.209  1
147092  99.966  -78.608  45.196  1
147093  99.975  -78.615  45.183  1
147094  99.984  -78.622  45.170  1
147095  99.993  -78.629  45.157  1
147096  100.023  -78.640  45.143  1
147097  100.072  -78.654  45.130  1
147098  100.120  -78.668  45.116  1
147099  100.159  -78.686  45.102  1
147100  100.197  -78.705  45.088  1
147101  100.234  -78.724  45.074  1
147102  100.262  -78.738  45.060  1
147103  100.280  -78.750  45.044  1
147104  100.298  -78.761  45.029  1
147105  100.316  -78.773  45.014  1
147106  100.334  -78.785  44.999  1
147107  100.352  -78.796  44.983  1
147108  100.370  -78.808  44.968  1
147109  100.388  -78.820  44.953  1
147110  100.400  -78.830  44.937  1
147111  100.410  -78.840  44.922  1
147112  100.423  -78.854  44.907  1
147113  100.438  -78.873  44.892  1
147114  100.453  -78.893  44.877  1
147115  100.468  -78.912  44.861  1
147116  100.483  -78.931  44.844  1
147117  100.493  -78.951  44.827  1
147118  100.504  -78.970  44.810  1
147119  100.516  -78.987  44.793  1
147120  100.532  -78.998  44.776  1
147121  100.549  -79.009  44.758  1
147122  100.565  -79.021  44.741  1
147123  100.581  -79.031  44.725  1
147124  100.609  -79.048  44.708  1
147125  100.641  -79.068  44.691  1
147126  100.674  -79.087  44.674  1
147127  100.706  -79.106  44.658  1
147128  100.739  -79.125  44.642  1
147129  100.771  -79.143  44.625  1
147130  100.814  -79.165  44.610  1
147131  100.866  -79.171  44.595  1
147132  100.918  -79.177  44.580  1
147133  100.970  -79.183  44.566  1
147134  101.022  -79.190  44.551  1
147135  101.074  -79.196  44.537  1
147136  101.126  -79.202  44.523  1
147137  101.178  -79.208  44.508  1
147373  92.686  -77.896  54.244  1
147374  92.704  -77.899  54.240  1
147375  92.723  -77.902  54.237  1
147376  92.741  -77.905  54.233  1
147377  92.760  -77.908  54.230  1
147378  92.778  -77.911  54.227  1
147379  92.796  -77.914  54.225  1
147380  92.814  -77.916  54.221  1
147381  92.833  -77.919  54.219  1
147382  92.852  -77.925  54.218  1
147383  92.872  -77.933  54.217  1
147384  92.892  -77.940  54.214  1
147385  92.912  -77.947  54.211  1
147386  92.932  -77.955  54.208  1
147387  92.952  -77.962  54.206  1
147388  92.972  -77.969  54.205  1
147389  92.992  -77.977  54.205  1
147390  93.012  -77.976  54.206  1
147391  93.028  -77.971  54.204  1
147392  93.048  -77.968  54.203  1
147393  93.068  -77.968  54.203  1
147394  93.087  -77.967  54.203  1
147395  93.107  -77.966  54.202  1
147396  93.127  -77.965  54.200  1
147397  93.147  -77.964  54.199  1
147398  93.166  -77.963  54.196  1
147399  93.186  -77.962  54.194  1
147400  93.209  -77.951  54.191  1
147401  93.239  -77.905  54.189  1
147402  93.251  -77.891  54.187  1
147403  93.262  -77.877  54.184  1
147404  93.273  -77.864  54.181  1
147405  93.284  -77.851  54.174  1
147406  93.284  -77.836  54.168  1
147407  93.283  -77.821  54.160  1
147408  93.282  -77.807  54.151  1
147409  93.281  -77.792  54.140  1
147410  93.280  -77.777  54.130  1
147411  93.289  -77.764  54.119  1
147412  93.305  -77.750  54.108  1
147413  93.321  -77.737  54.099  1
147414  93.337  -77.724  54.091  1
147415  93.353  -77.710  54.082  1
147416  93.369  -77.696  54.074  1
147417  93.393  -77.677  54.064  1
147418  93.403  -77.658  54.055  1
147419  93.417  -77.650  54.044  1
147420  93.433  -77.642  54.033  1
147421  93.449  -77.635  54.023  1
147422  93.465  -77.627  54.012  1
147423  93.481  -77.620  54.001  1
147424  93.496  -77.612  53.990  1
147425  93.512  -77.605  53.978  1
147426  93.528  -77.595  53.965  1
147427  93.543  -77.586  53.951  1
147428  93.558  -77.577  53.936  1
147429  93.577  -77.566  53.921  1
147430  93.599  -77.554  53.906  1
147431  93.621  -77.541  53.891  1
147432  93.627  -77.543  53.876  1
147433  93.628  -77.548  53.858  1
147434  93.630  -77.554  53.840  1
147435  93.636  -77.549  53.821  1
147436  93.648  -77.533  53.800  1
147437  93.659  -77.522  53.781  1
147438  93.667  -77.518  53.760  1
147439  93.680  -77.514  53.740  1
147440  93.695  -77.507  53.719  1
147441  93.710  -77.499  53.699  1
147442  93.725  -77.491  53.680  1
147443  93.741  -77.483  53.663  1
147444  93.756  -77.474  53.649  1
147445  93.771  -77.467  53.633  1
147446  93.786  -77.458  53.617  1
147447  93.801  -77.445  53.601  1
147448  93.817  -77.429  53.589  1
147449  93.832  -77.415  53.577  1
147450  93.848  -77.404  53.564  1
147451  93.864  -77.394  53.550  1
147452  93.877  -77.384  53.536  1
147453  93.897  -77.355  53.520  1
147454  93.916  -77.326  53.504  1
147455  93.935  -77.297  53.491  1
147456  93.952  -77.279  53.476  1
147457  93.952  -77.308  53.460  1
147458  93.952  -77.338  53.444  1
147459  93.961  -77.358  53.429  1
147460  93.989  -77.359  53.417  1
147461  94.017  -77.360  53.406  1
147462  94.045  -77.361  53.394  1
147463  94.066  -77.367  53.380  1
147464  94.085  -77.373  53.366  1
147465  94.104  -77.380  53.350  1
147466  94.120  -77.386  53.331  1
147467  94.117  -77.387  53.309  1
147468  94.114  -77.387  53.287  1
147469  94.111  -77.387  53.267  1
147470  94.131  -77.382  53.249  1
147471  94.153  -77.378  53.232  1
147472  94.173  -77.372  53.217  1
147473  94.193  -77.367  53.206  1
147474  94.211  -77.360  53.200  1
147475  94.229  -77.352  53.196  1
147476  94.247  -77.345  53.191  1
147477  94.264  -77.337  53.184  1
147478  94.263  -77.345  53.173  1
147479  94.262  -77.346  53.161  1
147480  94.261  -77.347  53.147  1
147481  94.259  -77.347  53.131  1
147482  94.258  -77.348  53.116  1
147483  94.259  -77.349  53.102  1
147484  94.260  -77.351  53.088  1
147485  94.268  -77.345  53.070  1
147486  94.292  -77.345  53.053  1
147487  94.299  -77.341  53.036  1
147488  94.307  -77.338  53.018  1
147489  94.314  -77.334  53.004  1
147490  94.323  -77.321  52.992  1
147491  94.332  -77.305  52.984  1
147492  94.345  -77.292  52.975  1
147493  94.358  -77.280  52.968  1
147494  94.370  -77.267  52.960  1
147495  94.388  -77.258  52.950  1
147496  94.410  -77.254  52.936  1
147497  94.432  -77.251  52.919  1
147498  94.455  -77.247  52.901  1
147499  94.477  -77.242  52.882  1
147500  94.500  -77.238  52.864  1
147501  94.522  -77.235  52.847  1
147502  94.545  -77.231  52.830  1
147503  94.567  -77.226  52.815  1
147504  94.589  -77.222  52.800  1
147505  94.609  -77.218  52.785  1
147506  94.620  -77.217  52.769  1
147507  94.629  -77.216  52.752  1
147508  94.639  -77.216  52.734  1
147509  94.649  -77.216  52.713  1
147510  94.660  -77.215  52.690  1
147511  94.669  -77.214  52.664  1
147512  94.682  -77.215  52.636  1
147513  94.697  -77.216  52.607  1
147514  94.718  -77.219  52.578  1
147515  94.751  -77.229  52.549  1
147516  94.785  -77.238  52.520  1
147517  94.813  -77.248  52.492  1
147518  94.824  -77.256  52.465  1
147519  94.835  -77.264  52.436  1
147520  94.846  -77.273  52.403  1
147521  94.862  -77.283  52.369  1
147522  94.881  -77.294  52.333  1
147523  94.900  -77.305  52.296  1
147524  94.919  -77.316  52.257  1
147525  94.943  -77.302  52.217  1
147526  94.929  -77.304  52.178  1
147527  94.931  -77.281  52.139  1
147528  94.949  -77.257  52.100  1
147529  94.970  -77.233  52.061  1
147530  94.988  -77.210  52.022  1
147531  94.995  -77.189  51.981  1
147532  95.011  -77.185  51.941  1
147533  95.037  -77.202  51.898  1
147534  95.063  -77.219  51.853  1
147535  95.090  -77.237  51.805  1
147536  95.117  -77.254  51.753  1
147537  95.143  -77.272  51.698  1
147538  95.149  -77.295  51.641  1
147539  95.165  -77.291  51.580  1
147540  95.181  -77.285  51.512  1
147541  95.198  -77.278  51.444  1
147542  95.214  -77.272  51.377  1
147543  95.231  -77.266  51.317  1
147544  95.247  -77.259  51.261  1
147545  95.264  -77.253  51.208  1
147546  95.280  -77.246  51.157  1
147547  95.297  -77.240  51.110  1
147548  95.313  -77.234  51.064  1
147549  95.329  -77.227  51.020  1
147550  95.346  -77.221  50.976  1
147551  95.362  -77.214  50.933  1
147552  95.379  -77.208  50.891  1
147553  95.395  -77.201  50.850  1
147554  95.420  -77.207  50.812  1
147555  95.446  -77.230  50.774  1
147556  95.473  -77.253  50.736  1
147557  95.499  -77.276  50.699  1
147558  95.525  -77.298  50.664  1
147559  95.551  -77.321  50.631  1
147560  95.578  -77.344  50.600  1
147561  95.604  -77.367  50.568  1
147562  95.630  -77.389  50.534  1
147563  95.654  -77.409  50.497  1
147564  95.656  -77.413  50.456  1
147565  95.658  -77.417  50.419  1
147566  95.660  -77.421  50.383  1
147567  95.666  -77.428  50.348  1
147568  95.681  -77.439  50.312  1
147569  95.695  -77.451  50.274  1
147570  95.710  -77.464  50.234  1
147571  95.725  -77.476  50.192  1
147572  95.739  -77.488  50.147  1
147573  95.755  -77.498  50.106  1
147574  95.774  -77.506  50.067  1
147575  95.794  -77.514  50.027  1
147576  95.813  -77.522  49.982  1
147577  95.832  -77.530  49.936  1
147578  95.851  -77.537  49.888  1
147579  95.871  -77.545  49.836  1
147580  95.890  -77.552  49.784  1
147581  95.909  -77.560  49.734  1
147582  95.928  -77.567  49.687  1
147583  95.948  -77.576  49.643  1
147584  95.967  -77.584  49.602  1
147585  95.972  -77.591  49.563  1
147586  95.975  -77.598  49.526  1
147587  95.980  -77.602  49.490  1
147588  95.984  -77.607  49.455  1
147589  95.988  -77.612  49.420  1
147590  95.992  -77.617  49.387  1
147591  95.997  -77.621  49.357  1
147592  96.001  -77.627  49.329  1
147593  96.009  -77.630  49.303  1
147594  96.025  -77.631  49.277  1
147595  96.040  -77.635  49.250  1
147596  96.056  -77.640  49.221  1
147597  96.072  -77.645  49.191  1
147598  96.088  -77.648  49.166  1
147599  96.100  -77.632  49.142  1
147600  96.099  -77.637  49.119  1
147601  96.096  -77.647  49.094  1
147602  96.095  -77.657  49.067  1
147603  96.110  -77.663  49.037  1
147604  96.125  -77.669  49.007  1
147605  96.117  -77.679  48.977  1
147606  96.107  -77.689  48.946  1
147607  96.097  -77.699  48.914  1
147608  96.092  -77.708  48.882  1
147609  96.120  -77.711  48.849  1
147610  96.148  -77.715  48.814  1
147611  96.175  -77.719  48.779  1
147612  96.196  -77.723  48.747  1
147613  96.210  -77.727  48.716  1
147614  96.225  -77.731  48.685  1
147615  96.235  -77.739  48.652  1
147616  96.243  -77.747  48.621  1
147617  96.251  -77.756  48.590  1
147618  96.259  -77.765  48.559  1
147619  96.267  -77.773  48.533  1
147620  96.276  -77.781  48.506  1
147621  96.284  -77.790  48.480  1
147622  96.299  -77.793  48.456  1
147623  96.316  -77.792  48.431  1
147624  96.334  -77.791  48.406  1
147625  96.352  -77.791  48.381  1
147626  96.370  -77.790  48.358  1
147627  96.388  -77.790  48.336  1
147628  96.406  -77.789  48.314  1
147629  96.425  -77.788  48.291  1
147630  96.451  -77.787  48.268  1
147631  96.471  -77.787  48.244  1
147632  96.478  -77.792  48.219  1
147633  96.466  -77.814  48.196  1
147634  96.455  -77.836  48.171  1
147635  96.465  -77.842  48.146  1
147636  96.474  -77.849  48.122  1
147637  96.486  -77.854  48.098  1
147638  96.507  -77.854  48.073  1
147639  96.527  -77.855  48.048  1
147640  96.547  -77.855  48.024  1
147641  96.567  -77.856  48.000  1
147642  96.587  -77.857  47.975  1
147643  96.600  -77.840  47.950  1
147644  96.612  -77.824  47.925  1
147645  96.625  -77.807  47.899  1
147646  96.638  -77.791  47.874  1
147647  96.650  -77.774  47.850  1
147648  96.665  -77.766  47.825  1
147649  96.683  -77.773  47.800  1
147650  96.702  -77.780  47.775  1
147651  96.721  -77.788  47.751  1
147652  96.736  -77.794  47.725  1
147653  96.756  -77.805  47.701  1
147654  96.778  -77.818  47.677  1
147655  96.800  -77.830  47.652  1
147656  96.822  -77.842  47.630  1
147657  96.844  -77.855  47.607  1
147658  96.866  -77.867  47.583  1
147659  96.888  -77.880  47.559  1
147660  96.907  -77.890  47.536  1
147661  96.916  -77.898  47.514  1
147662  96.925  -77.906  47.492  1
147663  96.934  -77.913  47.471  1
147664  96.943  -77.917  47.451  1
147665  96.951  -77.909  47.432  1
147666  96.960  -77.902  47.413  1
147667  96.968  -77.896  47.392  1
147668  96.976  -77.888  47.372  1
147669  96.994  -77.885  47.351  1
147670  97.016  -77.887  47.329  1
147671  97.036  -77.892  47.307  1
147672  97.056  -77.899  47.286  1
147673  97.077  -77.917  47.266  1
147674  97.098  -77.934  47.247  1
147675  97.119  -77.951  47.228  1
147676  97.140  -77.968  47.210  1
147677  97.161  -77.985  47.192  1
147678  97.181  -78.002  47.176  1
147679  97.202  -78.019  47.161  1
147680  97.218  -78.027  47.146  1
147681  97.239  -78.016  47.130  1
147682  97.263  -78.003  47.114  1
147683  97.288  -77.989  47.099  1
147684  97.312  -77.976  47.084  1
147685  97.336  -77.962  47.070  1
147686  97.358  -77.975  47.057  1
147687  97.379  -77.989  47.043  1
147688  97.400  -78.003  47.029  1
147689  97.422  -78.015  47.015  1
147690  97.443  -78.029  47.001  1
147691  97.466  -78.047  46.988  1
147692  97.489  -78.064  46.973  1
147693  97.501  -78.079  46.959  1
147694  97.490  -78.093  46.945  1
147695  97.485  -78.109  46.930  1
147696  97.480  -78.125  46.916  1
147697  97.476  -78.140  46.901  1
147698  97.471  -78.156  46.886  1
147699  97.467  -78.172  46.872  1
147700  97.465  -78.187  46.857  1
147701  97.512  -78.198  46.840  1
147702  97.561  -78.210  46.821  1
147703  97.610  -78.221  46.800  1
147704  97.659  -78.232  46.778  1
147705  97.709  -78.244  46.754  1
147706  97.757  -78.256  46.730  1
147707  97.807  -78.267  46.705  1
147708  97.856  -78.279  46.681  1
147709  97.905  -78.290  46.658  1
147710  97.945  -78.297  46.635  1
147711  97.982  -78.302  46.612  1
147712  98.018  -78.307  46.590  1
147713  98.054  -78.312  46.568  1
147714  98.083  -78.319  46.544  1
147715  98.100  -78.313  46.520  1
147716  98.122  -78.304  46.497  1
147717  98.166  -78.293  46.476  1
147718  98.187  -78.282  46.453  1
147719  98.209  -78.269  46.431  1
147720  98.230  -78.258  46.408  1
147721  98.251  -78.247  46.385  1
147722  98.273  -78.235  46.361  1
147723  98.294  -78.224  46.338  1
147724  98.315  -78.212  46.314  1
147725  98.313  -78.191  46.292  1
147726  98.334  -78.187  46.268  1
147727  98.364  -78.188  46.244  1
147728  98.393  -78.190  46.221  1
147729  98.423  -78.191  46.196  1
147730  98.453  -78.193  46.173  1
147731  98.481  -78.194  46.150  1
147732  98.470  -78.213  46.127  1
147733  98.464  -78.229  46.104  1
147734  98.507  -78.226  46.082  1
147735  98.549  -78.223  46.060  1
147736  98.561  -78.215  46.038  1
147737  98.563  -78.205  46.016  1
147738  98.564  -78.194  45.995  1
147739  98.563  -78.182  45.973  1
147740  98.562  -78.170  45.952  1
147741  98.561  -78.158  45.930  1
147742  98.560  -78.145  45.910  1
147743  98.559  -78.133  45.891  1
147744  98.595  -78.165  45.872  1
147745  98.635  -78.201  45.853  1
147746  98.659  -78.213  45.833  1
147747  98.683  -78.224  45.814  1
147748  98.707  -78.235  45.794  1
147749  98.742  -78.244  45.775  1
147750  98.782  -78.248  45.759  1
147751  98.811  -78.246  45.744  1
147752  98.840  -78.243  45.730  1
147753  98.869  -78.240  45.717  1
147754  98.898  -78.243  45.702  1
147755  98.925  -78.257  45.688  1
147756  98.952  -78.272  45.674  1
147757  98.979  -78.288  45.661  1
147758  99.006  -78.303  45.649  1
147759  99.033  -78.317  45.637  1
147760  99.050  -78.323  45.623  1
147761  99.081  -78.330  45.610  1
147762  99.113  -78.338  45.596  1
147763  99.145  -78.346  45.582  1
147764  99.178  -78.354  45.568  1
147765  99.210  -78.362  45.556  1
147766  99.242  -78.369  45.544  1
147767  99.275  -78.377  45.530  1
147768  99.307  -78.385  45.516  1
147769  99.339  -78.393  45.502  1
147770  99.371  -78.401  45.488  1
147771  99.404  -78.409  45.474  1
147772  99.436  -78.416  45.462  1
147773  99.469  -78.425  45.448  1
147774  99.501  -78.432  45.434  1
147775  99.534  -78.440  45.421  1
147776  99.566  -78.448  45.407  1
147777  99.598  -78.456  45.394  1
147778  99.630  -78.464  45.382  1
147779  99.662  -78.472  45.371  1
147780  99.693  -78.481  45.359  1
147781  99.711  -78.517  45.348  1
147782  99.761  -78.562  45.336  1
147783  99.810  -78.594  45.325  1
147784  99.853  -78.570  45.314  1
147785  99.902  -78.551  45.303  1
147786  99.923  -78.560  45.290  1
147787  99.932  -78.567  45.279  1
147788  99.941  -78.573  45.269  1
147789  99.950  -78.580  45.257  1
147790  99.960  -78.587  45.245  1
147791  99.969  -78.594  45.233  1
147792  99.977  -78.600  45.221  1
147793  99.986  -78.607  45.208  1
147794  99.995  -78.614  45.195  1
147795  100.004  -78.620  45.183  1
147796  100.013  -78.627  45.170  1
147797  100.033  -78.636  45.155  1
147798  100.081  -78.651  45.142  1
147799  100.130  -78.665  45.129  1
147800  100.168  -78.683  45.114  1
147801  100.206  -78.702  45.100  1
147802  100.244  -78.720  45.086  1
147803  100.262  -78.732  45.071  1
147804  100.280  -78.743  45.055  1
147805  100.298  -78.755  45.040  1
147806  100.317  -78.767  45.024  1
147807  100.335  -78.778  45.009  1
147808  100.352  -78.790  44.992  1
147809  100.370  -78.802  44.977  1
147810  100.388  -78.813  44.961  1
147811  100.406  -78.825  44.945  1
147812  100.416  -78.835  44.930  1
147813  100.427  -78.846  44.915  1
147814  100.442  -78.865  44.900  1
147815  100.458  -78.884  44.884  1
147816  100.473  -78.904  44.869  1
147817  100.488  -78.924  44.852  1
147818  100.503  -78.943  44.834  1
147819  100.513  -78.962  44.818  1
147820  100.524  -78.981  44.801  1
147821  100.540  -78.993  44.784  1
147822  100.556  -79.004  44.766  1
147823  100.572  -79.015  44.749  1
147824  100.588  -79.027  44.732  1
147825  100.606  -79.038  44.715  1
147826  100.638  -79.057  44.697  1
147827  100.671  -79.076  44.681  1
147828  100.703  -79.096  44.664  1
147829  100.736  -79.115  44.648  1
147830  100.768  -79.134  44.632  1
147831  100.819  -79.148  44.616  1
147832  100.871  -79.154  44.601  1
147833  100.923  -79.160  44.586  1
147834  100.975  -79.167  44.572  1
147835  101.027  -79.173  44.558  1
147836  101.079  -79.179  44.543  1
147837  101.131  -79.185  44.529  1
147838  101.183  -79.191  44.515  1
147839  101.236  -79.198  44.500  1
147840  101.287  -79.204  44.488  1
148074  92.666  -77.852  54.239  1
148075  92.685  -77.855  54.235  1
148076  92.703  -77.858  54.231  1
148077  92.721  -77.862  54.229  1
148078  92.741  -77.868  54.226  1
148079  92.761  -77.876  54.222  1
148080  92.781  -77.884  54.220  1
148081  92.801  -77.890  54.217  1
148082  92.821  -77.898  54.216  1
148083  92.841  -77.906  54.214  1
148084  92.861  -77.912  54.213  1
148085  92.881  -77.920  54.210  1
148086  92.901  -77.928  54.207  1
148087  92.921  -77.934  54.206  1
148088  92.941  -77.942  54.205  1
148089  92.961  -77.949  54.203  1
148090  92.981  -77.957  54.202  1
148091  93.002  -77.955  54.203  1
148092  93.019  -77.949  54.204  1
148093  93.036  -77.944  54.204  1
148094  93.054  -77.942  54.204  1
148095  93.074  -77.941  54.206  1
148096  93.094  -77.940  54.206  1
148097  93.114  -77.939  54.206  1
148098  93.133  -77.938  54.205  1
148099  93.153  -77.937  54.202  1
148100  93.173  -77.936  54.200  1
148101  93.199  -77.916  54.199  1
148102  93.221  -77.883  54.197  1
148103  93.232  -77.870  54.194  1
148104  93.243  -77.856  54.191  1
148105  93.254  -77.843  54.188  1
148106  93.266  -77.829  54.182  1
148107  93.277  -77.816  54.176  1
148108  93.280  -77.802  54.168  1
148109  93.279  -77.787  54.157  1
148110  93.278  -77.772  54.148  1
148111  93.277  -77.758  54.138  1
148112  93.281  -77.743  54.128  1
148113  93.296  -77.730  54.118  1
148114  93.312  -77.717  54.110  1
148115  93.328  -77.703  54.102  1
148116  93.344  -77.689  54.094  1
148117  93.360  -77.677  54.087  1
148118  93.376  -77.663  54.080  1
148119  93.393  -77.645  54.072  1
148120  93.408  -77.637  54.062  1
148121  93.424  -77.630  54.052  1
148122  93.440  -77.623  54.042  1
148123  93.455  -77.615  54.033  1
148124  93.472  -77.608  54.023  1
148125  93.487  -77.600  54.013  1
148126  93.503  -77.592  54.004  1
148127  93.518  -77.583  53.991  1
148128  93.535  -77.574  53.977  1
148129  93.557  -77.561  53.963  1
148130  93.579  -77.549  53.949  1
148131  93.601  -77.537  53.934  1
148132  93.623  -77.524  53.919  1
148133  93.623  -77.530  53.903  1
148134  93.617  -77.540  53.886  1
148135  93.617  -77.545  53.868  1
148136  93.628  -77.534  53.850  1
148137  93.638  -77.524  53.830  1
148138  93.649  -77.514  53.810  1
148139  93.657  -77.506  53.789  1
148140  93.672  -77.497  53.768  1
148141  93.688  -77.488  53.746  1
148142  93.705  -77.478  53.726  1
148143  93.722  -77.469  53.707  1
148144  93.738  -77.461  53.690  1
148145  93.753  -77.452  53.677  1
148146  93.768  -77.444  53.661  1
148147  93.784  -77.431  53.644  1
148148  93.799  -77.420  53.628  1
148149  93.816  -77.410  53.614  1
148150  93.832  -77.399  53.601  1
148151  93.847  -77.389  53.589  1
148152  93.863  -77.378  53.575  1
148153  93.872  -77.377  53.559  1
148154  93.892  -77.348  53.543  1
148155  93.911  -77.320  53.528  1
148156  93.930  -77.291  53.515  1
148157  93.945  -77.275  53.502  1
148158  93.950  -77.289  53.487  1
148159  93.951  -77.318  53.472  1
148160  93.956  -77.342  53.457  1
148161  93.984  -77.344  53.441  1
148162  94.012  -77.345  53.426  1
148163  94.034  -77.350  53.413  1
148164  94.052  -77.357  53.400  1
148165  94.071  -77.363  53.386  1
148166  94.090  -77.370  53.371  1
148167  94.102  -77.375  53.355  1
148168  94.099  -77.375  53.333  1
148169  94.097  -77.376  53.312  1
148170  94.101  -77.365  53.292  1
148171  94.130  -77.364  53.273  1
148172  94.158  -77.363  53.256  1
148173  94.178  -77.357  53.239  1
148174  94.198  -77.351  53.226  1
148175  94.217  -77.346  53.219  1
148176  94.237  -77.340  53.215  1
148177  94.257  -77.335  53.211  1
148178  94.273  -77.329  53.206  1
148179  94.273  -77.328  53.197  1
148180  94.272  -77.329  53.186  1
148181  94.271  -77.330  53.171  1
148182  94.270  -77.332  53.157  1
148183  94.269  -77.332  53.143  1
148184  94.268  -77.332  53.130  1
148185  94.267  -77.333  53.117  1
148186  94.275  -77.332  53.100  1
148187  94.282  -77.328  53.081  1
148188  94.290  -77.324  53.063  1
148189  94.297  -77.320  53.045  1
148190  94.305  -77.314  53.030  1
148191  94.316  -77.301  53.018  1
148192  94.329  -77.288  53.010  1
148193  94.342  -77.276  53.003  1
148194  94.355  -77.263  52.995  1
148195  94.368  -77.251  52.986  1
148196  94.386  -77.242  52.975  1
148197  94.408  -77.238  52.961  1
148198  94.431  -77.235  52.947  1
148199  94.453  -77.230  52.931  1
148200  94.476  -77.226  52.914  1
148201  94.498  -77.222  52.898  1
148202  94.521  -77.219  52.881  1
148203  94.543  -77.214  52.863  1
148204  94.565  -77.210  52.847  1
148205  94.585  -77.206  52.832  1
148206  94.606  -77.201  52.817  1
148207  94.619  -77.199  52.801  1
148208  94.628  -77.199  52.785  1
148209  94.638  -77.198  52.766  1
148210  94.648  -77.197  52.745  1
148211  94.659  -77.197  52.721  1
148212  94.668  -77.197  52.694  1
148213  94.678  -77.196  52.667  1
148214  94.688  -77.196  52.639  1
148215  94.708  -77.201  52.611  1
148216  94.742  -77.210  52.582  1
148217  94.775  -77.220  52.553  1
148218  94.803  -77.229  52.525  1
148219  94.814  -77.238  52.499  1
148220  94.825  -77.246  52.470  1
148221  94.835  -77.254  52.438  1
148222  94.846  -77.263  52.401  1
148223  94.857  -77.272  52.363  1
148224  94.871  -77.281  52.324  1
148225  94.890  -77.291  52.284  1
148226  94.919  -77.257  52.244  1
148227  94.901  -77.273  52.204  1
148228  94.887  -77.278  52.164  1
148229  94.914  -77.249  52.124  1
148230  94.935  -77.225  52.083  1
148231  94.957  -77.201  52.043  1
148232  94.980  -77.172  52.003  1
148233  95.005  -77.183  51.961  1
148234  95.031  -77.198  51.917  1
148235  95.057  -77.216  51.870  1
148236  95.084  -77.233  51.823  1
148237  95.110  -77.251  51.771  1
148238  95.136  -77.268  51.717  1
148239  95.153  -77.288  51.658  1
148240  95.169  -77.282  51.595  1
148241  95.185  -77.275  51.528  1
148242  95.202  -77.269  51.460  1
148243  95.218  -77.263  51.395  1
148244  95.235  -77.256  51.336  1
148245  95.251  -77.250  51.281  1
148246  95.267  -77.243  51.229  1
148247  95.284  -77.237  51.179  1
148248  95.300  -77.230  51.131  1
148249  95.316  -77.223  51.084  1
148250  95.332  -77.216  51.040  1
148251  95.348  -77.210  50.997  1
148252  95.364  -77.203  50.955  1
148253  95.380  -77.197  50.913  1
148254  95.396  -77.190  50.872  1
148255  95.415  -77.200  50.833  1
148256  95.436  -77.217  50.793  1
148257  95.459  -77.238  50.753  1
148258  95.482  -77.258  50.714  1
148259  95.506  -77.279  50.677  1
148260  95.532  -77.301  50.641  1
148261  95.559  -77.324  50.607  1
148262  95.585  -77.347  50.575  1
148263  95.611  -77.370  50.542  1
148264  95.637  -77.392  50.508  1
148265  95.660  -77.411  50.469  1
148266  95.662  -77.415  50.434  1
148267  95.664  -77.420  50.400  1
148268  95.678  -77.432  50.365  1
148269  95.693  -77.443  50.330  1
148270  95.707  -77.455  50.292  1
148271  95.722  -77.467  50.252  1
148272  95.737  -77.479  50.211  1
148273  95.751  -77.492  50.166  1
148274  95.766  -77.504  50.125  1
148275  95.784  -77.513  50.086  1
148276  95.803  -77.520  50.046  1
148277  95.823  -77.528  50.002  1
148278  95.842  -77.536  49.955  1
148279  95.861  -77.543  49.906  1
148280  95.880  -77.551  49.852  1
148281  95.900  -77.558  49.799  1
148282  95.919  -77.566  49.748  1
148283  95.938  -77.573  49.700  1
148284  95.953  -77.577  49.656  1
148285  95.969  -77.581  49.614  1
148286  95.976  -77.583  49.575  1
148287  95.983  -77.586  49.537  1
148288  95.987  -77.590  49.500  1
148289  95.991  -77.595  49.464  1
148290  95.995  -77.600  49.429  1
148291  96.000  -77.605  49.394  1
148292  96.004  -77.609  49.363  1
148293  96.009  -77.614  49.334  1
148294  96.019  -77.617  49.307  1
148295  96.035  -77.618  49.280  1
148296  96.050  -77.620  49.254  1
148297  96.066  -77.621  49.228  1
148298  96.082  -77.627  49.199  1
148299  96.097  -77.627  49.174  1
148300  96.102  -77.624  49.150  1
148301  96.098  -77.634  49.127  1
148302  96.095  -77.645  49.102  1
148303  96.091  -77.655  49.076  1
148304  96.101  -77.661  49.047  1
148305  96.115  -77.668  49.017  1
148306  96.105  -77.678  48.988  1
148307  96.095  -77.688  48.958  1
148308  96.091  -77.696  48.927  1
148309  96.109  -77.699  48.896  1
148310  96.129  -77.702  48.862  1
148311  96.157  -77.705  48.827  1
148312  96.184  -77.709  48.794  1
148313  96.199  -77.713  48.761  1
148314  96.212  -77.719  48.730  1
148315  96.221  -77.727  48.699  1
148316  96.229  -77.736  48.667  1
148317  96.237  -77.744  48.636  1
148318  96.245  -77.753  48.605  1
148319  96.253  -77.761  48.574  1
148320  96.262  -77.770  48.547  1
148321  96.270  -77.778  48.521  1
148322  96.278  -77.787  48.495  1
148323  96.294  -77.789  48.471  1
148324  96.311  -77.788  48.446  1
148325  96.329  -77.787  48.421  1
148326  96.347  -77.787  48.397  1
148327  96.365  -77.787  48.375  1
148328  96.384  -77.786  48.353  1
148329  96.410  -77.783  48.331  1
148330  96.437  -77.781  48.308  1
148331  96.464  -77.780  48.286  1
148332  96.475  -77.783  48.262  1
148333  96.484  -77.787  48.237  1
148334  96.486  -77.797  48.213  1
148335  96.473  -77.819  48.189  1
148336  96.476  -77.830  48.165  1
148337  96.486  -77.837  48.140  1
148338  96.496  -77.844  48.117  1
148339  96.507  -77.849  48.093  1
148340  96.527  -77.850  48.068  1
148341  96.547  -77.851  48.044  1
148342  96.568  -77.851  48.020  1
148343  96.588  -77.852  47.996  1
148344  96.601  -77.837  47.971  1
148345  96.614  -77.821  47.946  1
148346  96.626  -77.804  47.920  1
148347  96.639  -77.787  47.894  1
148348  96.652  -77.771  47.870  1
148349  96.664  -77.754  47.846  1
148350  96.682  -77.758  47.821  1
148351  96.700  -77.765  47.795  1
148352  96.717  -77.772  47.770  1
148353  96.738  -77.783  47.745  1
148354  96.759  -77.796  47.721  1
148355  96.782  -77.808  47.696  1
148356  96.804  -77.820  47.670  1
148357  96.826  -77.833  47.647  1
148358  96.848  -77.845  47.623  1
148359  96.870  -77.858  47.600  1
148360  96.892  -77.870  47.577  1
148361  96.913  -77.882  47.555  1
148362  96.923  -77.890  47.533  1
148363  96.932  -77.897  47.512  1
148364  96.941  -77.904  47.490  1
148365  96.949  -77.903  47.470  1
148366  96.957  -77.896  47.451  1
148367  96.966  -77.889  47.433  1
148368  96.974  -77.882  47.412  1
148369  96.982  -77.875  47.391  1
148370  96.993  -77.869  47.370  1
148371  97.015  -77.871  47.347  1
148372  97.035  -77.875  47.326  1
148373  97.056  -77.892  47.306  1
148374  97.077  -77.909  47.286  1
148375  97.098  -77.926  47.267  1
148376  97.119  -77.943  47.248  1
148377  97.140  -77.960  47.230  1
148378  97.160  -77.977  47.212  1
148379  97.181  -77.994  47.196  1
148380  97.202  -78.009  47.180  1
148381  97.226  -78.015  47.166  1
148382  97.252  -78.009  47.150  1
148383  97.277  -77.995  47.134  1
148384  97.301  -77.982  47.118  1
148385  97.325  -77.968  47.102  1
148386  97.350  -77.957  47.089  1
148387  97.371  -77.970  47.075  1
148388  97.392  -77.984  47.060  1
148389  97.413  -77.997  47.045  1
148390  97.436  -78.013  47.030  1
148391  97.459  -78.031  47.015  1
148392  97.482  -78.048  47.000  1
148393  97.505  -78.065  46.986  1
148394  97.500  -78.078  46.971  1
148395  97.490  -78.091  46.956  1
148396  97.485  -78.107  46.940  1
148397  97.480  -78.123  46.925  1
148398  97.476  -78.139  46.909  1
148399  97.471  -78.155  46.893  1
148400  97.486  -78.172  46.879  1
148401  97.503  -78.189  46.863  1
148402  97.528  -78.204  46.846  1
148403  97.578  -78.216  46.826  1
148404  97.627  -78.227  46.806  1
148405  97.676  -78.239  46.785  1
148406  97.725  -78.250  46.762  1
148407  97.774  -78.262  46.738  1
148408  97.816  -78.269  46.715  1
148409  97.853  -78.275  46.692  1
148410  97.888  -78.280  46.669  1
148411  97.925  -78.285  46.646  1
148412  97.961  -78.290  46.623  1
148413  97.997  -78.294  46.601  1
148414  98.027  -78.301  46.578  1
148415  98.055  -78.308  46.554  1
148416  98.068  -78.299  46.532  1
148417  98.111  -78.288  46.509  1
148418  98.159  -78.278  46.487  1
148419  98.180  -78.266  46.464  1
148420  98.202  -78.254  46.441  1
148421  98.223  -78.243  46.418  1
148422  98.244  -78.232  46.394  1
148423  98.265  -78.220  46.371  1
148424  98.286  -78.208  46.348  1
148425  98.304  -78.195  46.325  1
148426  98.304  -78.179  46.303  1
148427  98.334  -78.181  46.279  1
148428  98.364  -78.182  46.255  1
148429  98.394  -78.184  46.231  1
148430  98.424  -78.185  46.207  1
148431  98.453  -78.188  46.184  1
148432  98.484  -78.189  46.161  1
148433  98.519  -78.186  46.137  1
148434  98.508  -78.205  46.114  1
148435  98.496  -78.223  46.090  1
148436  98.502  -78.235  46.068  1
148437  98.534  -78.231  46.046  1
148438  98.536  -78.220  46.024  1
148439  98.535  -78.208  46.003  1
148440  98.534  -78.196  45.981  1
148441  98.533  -78.184  45.959  1
148442  98.532  -78.171  45.938  1
148443  98.531  -78.159  45.917  1
148444  98.532  -78.150  45.899  1
148445  98.573  -78.186  45.880  1
148446  98.598  -78.200  45.862  1
148447  98.622  -78.211  45.844  1
148448  98.661  -78.219  45.824  1
148449  98.705  -78.226  45.805  1
148450  98.748  -78.233  45.786  1
148451  98.791  -78.241  45.770  1
148452  98.828  -78.243  45.755  1
148453  98.857  -78.240  45.740  1
148454  98.886  -78.238  45.726  1
148455  98.916  -78.235  45.712  1
148456  98.943  -78.247  45.697  1
148457  98.970  -78.263  45.684  1
148458  98.997  -78.278  45.672  1
148459  99.024  -78.292  45.659  1
148460  99.051  -78.307  45.646  1
148461  99.058  -78.311  45.634  1
148462  99.080  -78.314  45.621  1
148463  99.108  -78.319  45.607  1
148464  99.141  -78.328  45.593  1
148465  99.173  -78.335  45.580  1
148466  99.205  -78.343  45.568  1
148467  99.237  -78.351  45.555  1
148468  99.270  -78.359  45.542  1
148469  99.302  -78.366  45.528  1
148470  99.335  -78.375  45.513  1
148471  99.367  -78.382  45.499  1
148472  99.399  -78.391  45.486  1
148473  99.432  -78.398  45.473  1
148474  99.464  -78.406  45.460  1
148475  99.496  -78.414  45.446  1
148476  99.528  -78.422  45.434  1
148477  99.561  -78.430  45.420  1
148478  99.593  -78.438  45.408  1
148479  99.626  -78.445  45.395  1
148480  99.658  -78.454  45.384  1
148481  99.664  -78.472  45.372  1
148482  99.673  -78.506  45.361  1
148483  99.723  -78.551  45.349  1
148484  99.771  -78.564  45.338  1
148485  99.814  -78.541  45.327  1
148486  99.889  -78.539  45.316  1
148487  99.919  -78.554  45.304  1
148488  99.946  -78.564  45.293  1
148489  99.962  -78.572  45.281  1
148490  99.971  -78.579  45.269  1
148491  99.980  -78.586  45.257  1
148492  99.989  -78.592  45.246  1
148493  99.998  -78.598  45.235  1
148494  100.007  -78.605  45.221  1
148495  100.016  -78.612  45.208  1
148496  100.025  -78.619  45.196  1
148497  100.034  -78.626  45.183  1
148498  100.043  -78.633  45.168  1
148499  100.091  -78.647  45.154  1
148500  100.139  -78.661  45.140  1
148501  100.177  -78.680  45.127  1
148502  100.215  -78.698  45.112  1
148503  100.245  -78.714  45.097  1
148504  100.263  -78.725  45.081  1
148505  100.281  -78.736  45.066  1
148506  100.298  -78.749  45.050  1
148507  100.317  -78.760  45.035  1
148508  100.335  -78.772  45.019  1
148509  100.353  -78.783  45.002  1
148510  100.371  -78.795  44.986  1
148511  100.389  -78.807  44.970  1
148512  100.407  -78.818  44.954  1
148513  100.422  -78.830  44.938  1
148514  100.433  -78.839  44.923  1
148515  100.447  -78.857  44.908  1
148516  100.462  -78.877  44.892  1
148517  100.477  -78.896  44.876  1
148518  100.492  -78.915  44.859  1
148519  100.507  -78.935  44.842  1
148520  100.522  -78.954  44.826  1
148521  100.534  -78.974  44.809  1
148522  100.548  -78.988  44.792  1
148523  100.564  -78.999  44.775  1
148524  100.580  -79.010  44.757  1
148525  100.596  -79.021  44.739  1
148526  100.613  -79.033  44.722  1
148527  100.636  -79.047  44.705  1
148528  100.668  -79.066  44.688  1
148529  100.701  -79.085  44.671  1
148530  100.734  -79.105  44.655  1
148531  100.772  -79.125  44.639  1
148532  100.824  -79.131  44.623  1
148533  100.876  -79.137  44.607  1
148534  100.928  -79.143  44.593  1
148535  100.980  -79.150  44.578  1
148536  101.033  -79.156  44.564  1
148537  101.085  -79.162  44.550  1
148538  101.136  -79.169  44.535  1
148539  101.189  -79.175  44.521  1
148540  101.241  -79.181  44.508  1
148541  101.292  -79.187  44.494  1
148542  101.322  -79.200  44.481  1
148776  92.670  -77.827  54.230  1
148777  92.690  -77.834  54.226  1
148778  92.710  -77.841  54.224  1
148779  92.730  -77.849  54.221  1
148780  92.750  -77.856  54.218  1
148781  92.770  -77.863  54.215  1
148782  92.790  -77.871  54.213  1
148783  92.810  -77.878  54.212  1
148784  92.830  -77.885  54.210  1
148785  92.850  -77.893  54.209  1
148786  92.870  -77.900  54.207  1
148787  92.890  -77.907  54.204  1
148788  92.910  -77.915  54.203  1
148789  92.930  -77.922  54.202  1
148790  92.950  -77.929  54.201  1
148791  92.970  -77.937  54.200  1
148792  92.992  -77.934  54.202  1
148793  93.009  -77.929  54.202  1
148794  93.026  -77.924  54.203  1
148795  93.043  -77.918  54.205  1
148796  93.061  -77.915  54.207  1
148797  93.081  -77.915  54.208  1
148798  93.100  -77.913  54.209  1
148799  93.120  -77.912  54.208  1
148800  93.140  -77.912  54.206  1
148801  93.160  -77.910  54.206  1
148802  93.188  -77.881  54.205  1
148803  93.203  -77.862  54.204  1
148804  93.214  -77.848  54.201  1
148805  93.225  -77.834  54.198  1
148806  93.236  -77.821  54.195  1
148807  93.247  -77.808  54.190  1
148808  93.258  -77.794  54.183  1
148809  93.269  -77.780  54.174  1
148810  93.276  -77.767  54.164  1
148811  93.275  -77.752  54.156  1
148812  93.274  -77.738  54.147  1
148813  93.273  -77.723  54.138  1
148814  93.288  -77.709  54.129  1
148815  93.304  -77.696  54.121  1
148816  93.320  -77.683  54.114  1
148817  93.336  -77.670  54.106  1
148818  93.352  -77.656  54.100  1
148819  93.367  -77.642  54.094  1
148820  93.382  -77.632  54.087  1
148821  93.398  -77.624  54.078  1
148822  93.414  -77.617  54.069  1
148823  93.430  -77.609  54.060  1
148824  93.446  -77.602  54.052  1
148825  93.462  -77.594  54.042  1
148826  93.478  -77.587  54.033  1
148827  93.494  -77.580  54.024  1
148828  93.509  -77.573  54.012  1
148829  93.526  -77.565  54.000  1
148830  93.544  -77.556  53.986  1
148831  93.561  -77.546  53.972  1
148832  93.579  -77.537  53.958  1
148833  93.597  -77.528  53.944  1
148834  93.605  -77.526  53.928  1
148835  93.599  -77.537  53.910  1
148836  93.608  -77.530  53.891  1
148837  93.619  -77.520  53.873  1
148838  93.627  -77.511  53.854  1
148839  93.635  -77.503  53.834  1
148840  93.643  -77.495  53.814  1
148841  93.652  -77.486  53.793  1
148842  93.670  -77.476  53.771  1
148843  93.687  -77.467  53.752  1
148844  93.704  -77.457  53.734  1
148845  93.721  -77.448  53.718  1
148846  93.740  -77.439  53.704  1
148847  93.765  -77.426  53.688  1
148848  93.783  -77.415  53.672  1
148849  93.799  -77.404  53.654  1
148850  93.815  -77.394  53.638  1
148851  93.831  -77.383  53.625  1
148852  93.846  -77.373  53.612  1
148853  93.862  -77.362  53.599  1
148854  93.867  -77.371  53.582  1
148855  93.887  -77.341  53.566  1
148856  93.906  -77.313  53.551  1
148857  93.925  -77.284  53.538  1
148858  93.936  -77.279  53.525  1
148859  93.943  -77.286  53.512  1
148860  93.949  -77.299  53.498  1
148861  93.951  -77.327  53.483  1
148862  93.979  -77.328  53.466  1
148863  94.001  -77.332  53.449  1
148864  94.019  -77.339  53.433  1
148865  94.039  -77.346  53.419  1
148866  94.057  -77.353  53.405  1
148867  94.076  -77.360  53.391  1
148868  94.084  -77.363  53.376  1
148869  94.081  -77.363  53.356  1
148870  94.084  -77.356  53.337  1
148871  94.100  -77.348  53.318  1
148872  94.129  -77.347  53.298  1
148873  94.159  -77.346  53.279  1
148874  94.183  -77.343  53.261  1
148875  94.203  -77.337  53.247  1
148876  94.222  -77.332  53.238  1
148877  94.243  -77.326  53.232  1
148878  94.262  -77.320  53.227  1
148879  94.278  -77.314  53.223  1
148880  94.279  -77.307  53.216  1
148881  94.279  -77.306  53.206  1
148882  94.278  -77.307  53.194  1
148883  94.277  -77.308  53.179  1
148884  94.276  -77.309  53.167  1
148885  94.275  -77.310  53.155  1
148886  94.274  -77.311  53.143  1
148887  94.277  -77.310  53.128  1
148888  94.283  -77.307  53.111  1
148889  94.289  -77.304  53.093  1
148890  94.295  -77.300  53.076  1
148891  94.300  -77.296  53.061  1
148892  94.314  -77.283  53.049  1
148893  94.327  -77.271  53.038  1
148894  94.340  -77.258  53.032  1
148895  94.353  -77.246  53.024  1
148896  94.366  -77.234  53.015  1
148897  94.385  -77.226  53.001  1
148898  94.407  -77.222  52.988  1
148899  94.429  -77.218  52.976  1
148900  94.452  -77.214  52.963  1
148901  94.474  -77.210  52.948  1
148902  94.497  -77.207  52.933  1
148903  94.519  -77.202  52.917  1
148904  94.542  -77.198  52.898  1
148905  94.562  -77.194  52.881  1
148906  94.582  -77.189  52.865  1
148907  94.602  -77.185  52.850  1
148908  94.618  -77.182  52.834  1
148909  94.628  -77.181  52.817  1
148910  94.637  -77.181  52.798  1
148911  94.647  -77.180  52.776  1
148912  94.657  -77.179  52.750  1
148913  94.667  -77.179  52.724  1
148914  94.677  -77.179  52.696  1
148915  94.690  -77.181  52.670  1
148916  94.703  -77.185  52.644  1
148917  94.732  -77.193  52.615  1
148918  94.766  -77.202  52.586  1
148919  94.792  -77.211  52.558  1
148920  94.804  -77.219  52.531  1
148921  94.814  -77.228  52.502  1
148922  94.825  -77.237  52.470  1
148923  94.836  -77.245  52.433  1
148924  94.847  -77.254  52.394  1
148925  94.857  -77.262  52.353  1
148926  94.868  -77.270  52.312  1
148927  94.885  -77.272  52.271  1
148928  94.889  -77.258  52.230  1
148929  94.885  -77.224  52.189  1
148930  94.900  -77.242  52.148  1
148931  94.926  -77.232  52.106  1
148932  94.949  -77.205  52.063  1
148933  94.985  -77.166  52.020  1
148934  95.008  -77.188  51.975  1
148935  95.033  -77.204  51.929  1
148936  95.058  -77.219  51.882  1
148937  95.083  -77.235  51.835  1
148938  95.108  -77.251  51.783  1
148939  95.132  -77.266  51.729  1
148940  95.156  -77.279  51.672  1
148941  95.172  -77.272  51.609  1
148942  95.188  -77.265  51.542  1
148943  95.204  -77.258  51.476  1
148944  95.219  -77.251  51.416  1
148945  95.236  -77.244  51.361  1
148946  95.252  -77.238  51.307  1
148947  95.268  -77.231  51.255  1
148948  95.283  -77.224  51.205  1
148949  95.300  -77.217  51.156  1
148950  95.316  -77.210  51.109  1
148951  95.331  -77.204  51.064  1
148952  95.347  -77.197  51.020  1
148953  95.364  -77.190  50.977  1
148954  95.379  -77.183  50.935  1
148955  95.398  -77.185  50.894  1
148956  95.419  -77.199  50.853  1
148957  95.437  -77.214  50.813  1
148958  95.456  -77.231  50.773  1
148959  95.480  -77.251  50.734  1
148960  95.503  -77.271  50.696  1
148961  95.526  -77.291  50.659  1
148962  95.549  -77.312  50.621  1
148963  95.572  -77.332  50.585  1
148964  95.596  -77.353  50.550  1
148965  95.619  -77.373  50.517  1
148966  95.645  -77.395  50.484  1
148967  95.665  -77.414  50.451  1
148968  95.676  -77.423  50.418  1
148969  95.691  -77.435  50.384  1
148970  95.705  -77.447  50.348  1
148971  95.720  -77.459  50.310  1
148972  95.735  -77.471  50.270  1
148973  95.749  -77.483  50.228  1
148974  95.764  -77.495  50.185  1
148975  95.778  -77.508  50.145  1
148976  95.794  -77.519  50.105  1
148977  95.813  -77.526  50.064  1
148978  95.832  -77.534  50.020  1
148979  95.851  -77.542  49.974  1
148980  95.871  -77.549  49.925  1
148981  95.890  -77.556  49.870  1
148982  95.905  -77.560  49.815  1
148983  95.921  -77.564  49.763  1
148984  95.937  -77.568  49.714  1
148985  95.952  -77.572  49.669  1
148986  95.968  -77.576  49.626  1
148987  95.978  -77.579  49.586  1
148988  95.984  -77.580  49.547  1
148989  95.991  -77.583  49.511  1
148990  95.997  -77.584  49.474  1
148991  96.003  -77.588  49.438  1
148992  96.007  -77.592  49.402  1
148993  96.012  -77.597  49.369  1
148994  96.016  -77.602  49.338  1
148995  96.030  -77.604  49.309  1
148996  96.045  -77.605  49.282  1
148997  96.061  -77.607  49.257  1
148998  96.076  -77.608  49.234  1
148999  96.092  -77.610  49.208  1
149000  96.104  -77.611  49.182  1
149001  96.101  -77.622  49.157  1
149002  96.097  -77.632  49.135  1
149003  96.093  -77.642  49.110  1
149004  96.090  -77.652  49.084  1
149005  96.093  -77.661  49.057  1
149006  96.103  -77.667  49.027  1
149007  96.093  -77.677  48.999  1
149008  96.090  -77.686  48.970  1
149009  96.109  -77.688  48.941  1
149010  96.127  -77.690  48.908  1
149011  96.147  -77.693  48.874  1
149012  96.166  -77.696  48.840  1
149013  96.189  -77.699  48.807  1
149014  96.198  -77.707  48.774  1
149015  96.206  -77.716  48.743  1
149016  96.215  -77.724  48.713  1
149017  96.223  -77.733  48.683  1
149018  96.231  -77.741  48.652  1
149019  96.239  -77.749  48.620  1
149020  96.248  -77.758  48.589  1
149021  96.256  -77.767  48.562  1
149022  96.264  -77.775  48.535  1
149023  96.272  -77.783  48.509  1
149024  96.289  -77.785  48.486  1
149025  96.306  -77.784  48.461  1
149026  96.324  -77.783  48.437  1
149027  96.343  -77.783  48.414  1
149028  96.370  -77.780  48.392  1
149029  96.396  -77.779  48.370  1
149030  96.423  -77.777  48.348  1
149031  96.450  -77.775  48.326  1
149032  96.471  -77.775  48.303  1
149033  96.479  -77.779  48.279  1
149034  96.488  -77.783  48.255  1
149035  96.497  -77.787  48.232  1
149036  96.493  -77.802  48.209  1
149037  96.488  -77.819  48.186  1
149038  96.498  -77.826  48.161  1
149039  96.507  -77.833  48.137  1
149040  96.517  -77.839  48.112  1
149041  96.528  -77.845  48.088  1
149042  96.548  -77.846  48.064  1
149043  96.568  -77.846  48.041  1
149044  96.588  -77.847  48.016  1
149045  96.602  -77.834  47.991  1
149046  96.615  -77.817  47.966  1
149047  96.628  -77.800  47.941  1
149048  96.641  -77.783  47.916  1
149049  96.653  -77.767  47.891  1
149050  96.666  -77.751  47.867  1
149051  96.680  -77.743  47.842  1
149052  96.698  -77.749  47.817  1
149053  96.719  -77.761  47.791  1
149054  96.741  -77.774  47.766  1
149055  96.763  -77.786  47.741  1
149056  96.786  -77.798  47.716  1
149057  96.807  -77.811  47.691  1
149058  96.829  -77.823  47.667  1
149059  96.852  -77.836  47.643  1
149060  96.874  -77.848  47.619  1
149061  96.896  -77.861  47.596  1
149062  96.918  -77.873  47.574  1
149063  96.929  -77.881  47.551  1
149064  96.938  -77.888  47.530  1
149065  96.947  -77.896  47.508  1
149066  96.955  -77.890  47.488  1
149067  96.963  -77.883  47.469  1
149068  96.971  -77.876  47.449  1
149069  96.980  -77.868  47.430  1
149070  96.988  -77.862  47.409  1
149071  96.997  -77.855  47.386  1
149072  97.015  -77.854  47.365  1
149073  97.035  -77.866  47.346  1
149074  97.056  -77.884  47.327  1
149075  97.077  -77.900  47.307  1
149076  97.098  -77.918  47.288  1
149077  97.118  -77.930  47.269  1
149078  97.138  -77.942  47.251  1
149079  97.158  -77.953  47.234  1
149080  97.178  -77.965  47.217  1
149081  97.202  -77.972  47.201  1
149082  97.231  -77.975  47.186  1
149083  97.259  -77.978  47.169  1
149084  97.288  -77.981  47.153  1
149085  97.314  -77.975  47.137  1
149086  97.338  -77.961  47.121  1
149087  97.362  -77.952  47.106  1
149088  97.383  -77.965  47.091  1
149089  97.405  -77.980  47.076  1
149090  97.429  -77.997  47.061  1
149091  97.452  -78.015  47.045  1
149092  97.475  -78.032  47.029  1
149093  97.498  -78.050  47.014  1
149094  97.519  -78.066  46.998  1
149095  97.499  -78.076  46.982  1
149096  97.490  -78.091  46.967  1
149097  97.486  -78.106  46.950  1
149098  97.480  -78.122  46.933  1
149099  97.494  -78.139  46.917  1
149100  97.511  -78.156  46.900  1
149101  97.528  -78.173  46.884  1
149102  97.545  -78.191  46.867  1
149103  97.562  -78.207  46.850  1
149104  97.594  -78.222  46.830  1
149105  97.643  -78.234  46.811  1
149106  97.687  -78.242  46.790  1
149107  97.723  -78.247  46.769  1
149108  97.759  -78.253  46.746  1
149109  97.796  -78.257  46.724  1
149110  97.832  -78.263  46.703  1
149111  97.868  -78.267  46.680  1
149112  97.904  -78.272  46.657  1
149113  97.940  -78.278  46.634  1
149114  97.971  -78.284  46.612  1
149115  97.999  -78.291  46.588  1
149116  98.023  -78.294  46.565  1
149117  98.038  -78.284  46.543  1
149118  98.101  -78.273  46.521  1
149119  98.151  -78.262  46.498  1
149120  98.172  -78.250  46.475  1
149121  98.194  -78.239  46.452  1
149122  98.215  -78.228  46.428  1
149123  98.236  -78.216  46.404  1
149124  98.257  -78.204  46.381  1
149125  98.279  -78.193  46.358  1
149126  98.275  -78.172  46.336  1
149127  98.305  -78.173  46.313  1
149128  98.335  -78.175  46.289  1
149129  98.365  -78.176  46.265  1
149130  98.394  -78.178  46.241  1
149131  98.424  -78.180  46.218  1
149132  98.454  -78.181  46.194  1
149133  98.484  -78.183  46.172  1
149134  98.514  -78.184  46.148  1
149135  98.557  -78.178  46.124  1
149136  98.546  -78.197  46.101  1
149137  98.534  -78.216  46.078  1
149138  98.523  -78.235  46.056  1
149139  98.513  -78.230  46.034  1
149140  98.506  -78.222  46.013  1
149141  98.505  -78.210  45.991  1
149142  98.504  -78.197  45.969  1
149143  98.503  -78.184  45.947  1
149144  98.502  -78.172  45.927  1
149145  98.510  -78.171  45.907  1
149146  98.538  -78.187  45.889  1
149147  98.581  -78.194  45.871  1
149148  98.625  -78.201  45.853  1
149149  98.668  -78.209  45.834  1
149150  98.711  -78.216  45.815  1
149151  98.754  -78.222  45.796  1
149152  98.797  -78.230  45.780  1
149153  98.841  -78.237  45.765  1
149154  98.874  -78.238  45.751  1
149155  98.904  -78.235  45.737  1
149156  98.933  -78.232  45.722  1
149157  98.960  -78.238  45.707  1
149158  98.988  -78.253  45.693  1
149159  99.015  -78.268  45.680  1
149160  99.042  -78.282  45.667  1
149161  99.069  -78.297  45.655  1
149162  99.065  -78.299  45.643  1
149163  99.087  -78.301  45.630  1
149164  99.110  -78.304  45.617  1
149165  99.136  -78.309  45.604  1
149166  99.168  -78.317  45.590  1
149167  99.201  -78.325  45.578  1
149168  99.233  -78.332  45.566  1
149169  99.265  -78.341  45.553  1
149170  99.297  -78.348  45.539  1
149171  99.330  -78.357  45.524  1
149172  99.362  -78.364  45.510  1
149173  99.395  -78.372  45.498  1
149174  99.427  -78.380  45.485  1
149175  99.459  -78.388  45.472  1
149176  99.492  -78.395  45.459  1
149177  99.524  -78.404  45.446  1
149178  99.556  -78.411  45.434  1
149179  99.588  -78.420  45.421  1
149180  99.621  -78.427  45.408  1
149181  99.650  -78.436  45.397  1
149182  99.636  -78.463  45.386  1
149183  99.635  -78.495  45.375  1
149184  99.686  -78.540  45.362  1
149185  99.731  -78.534  45.351  1
149186  99.792  -78.523  45.340  1
149187  99.875  -78.529  45.329  1
149188  99.906  -78.547  45.318  1
149189  99.933  -78.557  45.306  1
149190  99.961  -78.567  45.294  1
149191  99.988  -78.576  45.282  1
149192  100.001  -78.584  45.270  1
149193  100.010  -78.590  45.258  1
149194  100.019  -78.597  45.246  1
149195  100.028  -78.604  45.233  1
149196  100.037  -78.611  45.222  1
149197  100.046  -78.617  45.209  1
149198  100.055  -78.624  45.197  1
149199  100.064  -78.631  45.182  1
149200  100.101  -78.643  45.167  1
149201  100.149  -78.658  45.153  1
149202  100.187  -78.676  45.138  1
149203  100.224  -78.695  45.123  1
149204  100.245  -78.707  45.107  1
149205  100.263  -78.718  45.092  1
149206  100.281  -78.730  45.076  1
149207  100.299  -78.742  45.060  1
149208  100.317  -78.754  45.044  1
149209  100.335  -78.765  45.028  1
149210  100.353  -78.777  45.011  1
149211  100.371  -78.789  44.994  1
149212  100.389  -78.800  44.978  1
149213  100.407  -78.812  44.962  1
149214  100.425  -78.824  44.946  1
149215  100.439  -78.834  44.931  1
149216  100.452  -78.849  44.915  1
149217  100.467  -78.868  44.899  1
149218  100.482  -78.888  44.883  1
149219  100.497  -78.907  44.867  1
149220  100.512  -78.927  44.851  1
149221  100.527  -78.946  44.834  1
149222  100.542  -78.965  44.816  1
149223  100.555  -78.983  44.799  1
149224  100.571  -78.994  44.783  1
149225  100.587  -79.005  44.765  1
149226  100.604  -79.016  44.747  1
149227  100.620  -79.028  44.729  1
149228  100.636  -79.039  44.712  1
149229  100.666  -79.056  44.695  1
149230  100.698  -79.075  44.678  1
149231  100.731  -79.094  44.662  1
149232  100.777  -79.109  44.646  1
149233  100.829  -79.115  44.630  1
149234  100.882  -79.121  44.615  1
149235  100.933  -79.128  44.600  1
149236  100.986  -79.134  44.586  1
149237  101.038  -79.140  44.572  1
149238  101.090  -79.146  44.557  1
149239  101.142  -79.152  44.543  1
149240  101.194  -79.159  44.529  1
149241  101.246  -79.165  44.515  1
149242  101.297  -79.171  44.501  1
149243  101.322  -79.184  44.488  1
149477  92.659  -77.806  54.225  1
149478  92.680  -77.814  54.221  1
149479  92.699  -77.821  54.219  1
149480  92.719  -77.828  54.217  1
149481  92.739  -77.836  54.214  1
149482  92.759  -77.843  54.211  1
149483  92.779  -77.851  54.210  1
149484  92.799  -77.858  54.208  1
149485  92.819  -77.865  54.207  1
149486  92.839  -77.873  54.206  1
149487  92.859  -77.880  54.204  1
149488  92.879  -77.887  54.202  1
149489  92.899  -77.895  54.200  1
149490  92.919  -77.902  54.200  1
149491  92.939  -77.909  54.199  1
149492  92.958  -77.917  54.199  1
149493  92.982  -77.914  54.201  1
149494  92.999  -77.909  54.201  1
149495  93.016  -77.903  54.202  1
149496  93.032  -77.898  54.205  1
149497  93.050  -77.893  54.206  1
149498  93.067  -77.889  54.207  1
149499  93.087  -77.887  54.209  1
149500  93.107  -77.887  54.211  1
149501  93.127  -77.886  54.211  1
149502  93.146  -77.884  54.212  1
149503  93.173  -77.853  54.212  1
149504  93.184  -77.840  54.210  1
149505  93.195  -77.827  54.208  1
149506  93.206  -77.813  54.205  1
149507  93.217  -77.799  54.201  1
149508  93.228  -77.787  54.196  1
149509  93.239  -77.773  54.189  1
149510  93.251  -77.759  54.181  1
149511  93.262  -77.746  54.173  1
149512  93.272  -77.733  54.165  1
149513  93.271  -77.718  54.157  1
149514  93.270  -77.703  54.150  1
149515  93.280  -77.689  54.141  1
149516  93.295  -77.676  54.133  1
149517  93.311  -77.662  54.126  1
149518  93.327  -77.649  54.119  1
149519  93.343  -77.636  54.113  1
149520  93.357  -77.626  54.108  1
149521  93.371  -77.617  54.102  1
149522  93.387  -77.609  54.094  1
149523  93.403  -77.602  54.085  1
149524  93.419  -77.594  54.077  1
149525  93.435  -77.586  54.068  1
149526  93.450  -77.580  54.059  1
149527  93.467  -77.572  54.051  1
149528  93.483  -77.564  54.042  1
149529  93.498  -77.555  54.030  1
149530  93.512  -77.551  54.018  1
149531  93.525  -77.548  54.005  1
149532  93.538  -77.545  53.992  1
149533  93.551  -77.541  53.978  1
149534  93.568  -77.533  53.964  1
149535  93.585  -77.524  53.948  1
149536  93.588  -77.524  53.930  1
149537  93.597  -77.516  53.911  1
149538  93.605  -77.508  53.891  1
149539  93.613  -77.499  53.872  1
149540  93.621  -77.492  53.853  1
149541  93.630  -77.483  53.834  1
149542  93.638  -77.475  53.814  1
149543  93.651  -77.466  53.792  1
149544  93.668  -77.457  53.774  1
149545  93.685  -77.447  53.758  1
149546  93.706  -77.436  53.742  1
149547  93.732  -77.423  53.727  1
149548  93.758  -77.411  53.714  1
149549  93.782  -77.398  53.698  1
149550  93.798  -77.388  53.681  1
149551  93.814  -77.377  53.663  1
149552  93.830  -77.367  53.648  1
149553  93.845  -77.356  53.634  1
149554  93.861  -77.345  53.622  1
149555  93.864  -77.360  53.607  1
149556  93.882  -77.335  53.590  1
149557  93.901  -77.306  53.573  1
149558  93.920  -77.277  53.560  1
149559  93.927  -77.284  53.547  1
149560  93.934  -77.291  53.535  1
149561  93.942  -77.298  53.523  1
149562  93.948  -77.309  53.508  1
149563  93.968  -77.316  53.491  1
149564  93.987  -77.323  53.473  1
149565  94.006  -77.329  53.454  1
149566  94.025  -77.336  53.438  1
149567  94.043  -77.343  53.424  1
149568  94.062  -77.350  53.411  1
149569  94.066  -77.352  53.396  1
149570  94.068  -77.346  53.379  1
149571  94.074  -77.333  53.361  1
149572  94.099  -77.330  53.343  1
149573  94.128  -77.329  53.323  1
149574  94.158  -77.329  53.304  1
149575  94.188  -77.328  53.285  1
149576  94.208  -77.323  53.269  1
149577  94.227  -77.317  53.259  1
149578  94.248  -77.311  53.251  1
149579  94.267  -77.306  53.245  1
149580  94.283  -77.300  53.241  1
149581  94.284  -77.293  53.234  1
149582  94.285  -77.286  53.226  1
149583  94.285  -77.284  53.215  1
149584  94.284  -77.285  53.203  1
149585  94.283  -77.285  53.192  1
149586  94.282  -77.287  53.181  1
149587  94.281  -77.288  53.170  1
149588  94.283  -77.287  53.156  1
149589  94.289  -77.284  53.142  1
149590  94.296  -77.280  53.127  1
149591  94.301  -77.277  53.113  1
149592  94.301  -77.276  53.099  1
149593  94.311  -77.266  53.086  1
149594  94.324  -77.254  53.075  1
149595  94.337  -77.241  53.065  1
149596  94.350  -77.229  53.055  1
149597  94.363  -77.216  53.045  1
149598  94.383  -77.210  53.032  1
149599  94.405  -77.206  53.022  1
149600  94.428  -77.202  53.011  1
149601  94.450  -77.198  52.999  1
149602  94.473  -77.194  52.986  1
149603  94.495  -77.190  52.971  1
149604  94.518  -77.186  52.954  1
149605  94.538  -77.182  52.935  1
149606  94.558  -77.177  52.917  1
149607  94.578  -77.172  52.900  1
149608  94.598  -77.168  52.884  1
149609  94.617  -77.164  52.868  1
149610  94.627  -77.163  52.850  1
149611  94.636  -77.163  52.829  1
149612  94.646  -77.163  52.806  1
149613  94.657  -77.162  52.780  1
149614  94.667  -77.161  52.752  1
149615  94.678  -77.163  52.726  1
149616  94.691  -77.166  52.701  1
149617  94.704  -77.170  52.675  1
149618  94.722  -77.175  52.647  1
149619  94.756  -77.184  52.618  1
149620  94.782  -77.194  52.589  1
149621  94.793  -77.202  52.561  1
149622  94.804  -77.210  52.531  1
149623  94.815  -77.219  52.499  1
149624  94.826  -77.227  52.464  1
149625  94.836  -77.235  52.424  1
149626  94.852  -77.243  52.382  1
149627  94.871  -77.250  52.340  1
149628  94.889  -77.253  52.298  1
149629  94.905  -77.248  52.257  1
149630  94.921  -77.242  52.215  1
149631  94.931  -77.235  52.172  1
149632  94.937  -77.226  52.128  1
149633  94.953  -77.204  52.082  1
149634  94.988  -77.172  52.036  1
149635  95.012  -77.194  51.989  1
149636  95.036  -77.210  51.940  1
149637  95.061  -77.225  51.891  1
149638  95.086  -77.241  51.843  1
149639  95.110  -77.248  51.790  1
149640  95.134  -77.254  51.735  1
149641  95.157  -77.259  51.680  1
149642  95.171  -77.258  51.618  1
149643  95.187  -77.251  51.554  1
149644  95.203  -77.244  51.492  1
149645  95.219  -77.238  51.437  1
149646  95.235  -77.231  51.385  1
149647  95.251  -77.225  51.333  1
149648  95.267  -77.218  51.281  1
149649  95.283  -77.211  51.231  1
149650  95.299  -77.204  51.182  1
149651  95.315  -77.197  51.134  1
149652  95.331  -77.191  51.088  1
149653  95.347  -77.184  51.042  1
149654  95.363  -77.177  50.999  1
149655  95.379  -77.170  50.957  1
149656  95.401  -77.184  50.916  1
149657  95.422  -77.198  50.874  1
149658  95.440  -77.213  50.833  1
149659  95.458  -77.228  50.792  1
149660  95.477  -77.244  50.754  1
149661  95.500  -77.264  50.716  1
149662  95.523  -77.285  50.677  1
149663  95.547  -77.305  50.637  1
149664  95.570  -77.326  50.598  1
149665  95.593  -77.346  50.563  1
149666  95.616  -77.366  50.530  1
149667  95.640  -77.386  50.500  1
149668  95.663  -77.407  50.467  1
149669  95.680  -77.424  50.433  1
149670  95.696  -77.438  50.399  1
149671  95.713  -77.450  50.363  1
149672  95.729  -77.463  50.325  1
149673  95.745  -77.475  50.287  1
149674  95.761  -77.487  50.246  1
149675  95.776  -77.499  50.203  1
149676  95.791  -77.511  50.162  1
149677  95.806  -77.523  50.123  1
149678  95.823  -77.533  50.082  1
149679  95.841  -77.539  50.039  1
149680  95.858  -77.543  49.993  1
149681  95.873  -77.547  49.944  1
149682  95.889  -77.551  49.888  1
149683  95.904  -77.555  49.833  1
149684  95.920  -77.559  49.780  1
149685  95.936  -77.563  49.729  1
149686  95.952  -77.567  49.683  1
149687  95.967  -77.571  49.639  1
149688  95.979  -77.574  49.598  1
149689  95.986  -77.576  49.559  1
149690  95.992  -77.578  49.522  1
149691  95.999  -77.580  49.485  1
149692  96.006  -77.582  49.448  1
149693  96.012  -77.583  49.411  1
149694  96.019  -77.585  49.376  1
149695  96.024  -77.589  49.343  1
149696  96.040  -77.591  49.313  1
149697  96.054  -77.592  49.285  1
149698  96.068  -77.593  49.260  1
149699  96.083  -77.594  49.236  1
149700  96.097  -77.595  49.211  1
149701  96.102  -77.606  49.187  1
149702  96.099  -77.617  49.163  1
149703  96.096  -77.629  49.138  1
149704  96.092  -77.639  49.116  1
149705  96.089  -77.649  49.092  1
149706  96.085  -77.659  49.066  1
149707  96.091  -77.667  49.036  1
149708  96.089  -77.674  49.008  1
149709  96.108  -77.677  48.980  1
149710  96.127  -77.680  48.951  1
149711  96.146  -77.682  48.919  1
149712  96.162  -77.683  48.886  1
149713  96.177  -77.683  48.851  1
149714  96.190  -77.691  48.817  1
149715  96.197  -77.701  48.786  1
149716  96.203  -77.711  48.756  1
149717  96.209  -77.721  48.727  1
149718  96.217  -77.730  48.698  1
149719  96.225  -77.738  48.666  1
149720  96.234  -77.746  48.634  1
149721  96.242  -77.755  48.603  1
149722  96.250  -77.764  48.577  1
149723  96.258  -77.772  48.551  1
149724  96.266  -77.780  48.526  1
149725  96.284  -77.780  48.503  1
149726  96.302  -77.780  48.478  1
149727  96.329  -77.778  48.454  1
149728  96.356  -77.776  48.430  1
149729  96.382  -77.774  48.409  1
149730  96.409  -77.772  48.387  1
149731  96.436  -77.771  48.366  1
149732  96.462  -77.768  48.344  1
149733  96.475  -77.771  48.320  1
149734  96.483  -77.775  48.296  1
149735  96.493  -77.780  48.272  1
149736  96.501  -77.783  48.250  1
149737  96.510  -77.788  48.227  1
149738  96.501  -77.808  48.204  1
149739  96.509  -77.815  48.181  1
149740  96.519  -77.821  48.158  1
149741  96.528  -77.827  48.134  1
149742  96.538  -77.834  48.110  1
149743  96.549  -77.840  48.087  1
149744  96.569  -77.841  48.062  1
149745  96.589  -77.842  48.038  1
149746  96.604  -77.830  48.013  1
149747  96.616  -77.813  47.989  1
149748  96.629  -77.796  47.963  1
149749  96.642  -77.780  47.938  1
149750  96.655  -77.764  47.914  1
149751  96.667  -77.747  47.889  1
149752  96.680  -77.730  47.864  1
149753  96.700  -77.739  47.839  1
149754  96.723  -77.752  47.813  1
149755  96.745  -77.764  47.787  1
149756  96.767  -77.777  47.762  1
149757  96.789  -77.789  47.737  1
149758  96.811  -77.801  47.711  1
149759  96.833  -77.814  47.687  1
149760  96.855  -77.826  47.663  1
149761  96.877  -77.839  47.640  1
149762  96.899  -77.851  47.616  1
149763  96.922  -77.864  47.593  1
149764  96.935  -77.872  47.571  1
149765  96.944  -77.880  47.549  1
149766  96.953  -77.884  47.527  1
149767  96.961  -77.877  47.507  1
149768  96.969  -77.869  47.487  1
149769  96.977  -77.862  47.466  1
149770  96.986  -77.855  47.446  1
149771  96.994  -77.848  47.425  1
149772  97.003  -77.841  47.404  1
149773  97.014  -77.840  47.384  1
149774  97.034  -77.852  47.365  1
149775  97.054  -77.863  47.347  1
149776  97.074  -77.875  47.329  1
149777  97.094  -77.887  47.310  1
149778  97.114  -77.899  47.291  1
149779  97.134  -77.910  47.274  1
149780  97.154  -77.922  47.257  1
149781  97.178  -77.929  47.239  1
149782  97.207  -77.932  47.222  1
149783  97.235  -77.934  47.206  1
149784  97.264  -77.937  47.188  1
149785  97.293  -77.940  47.172  1
149786  97.321  -77.943  47.156  1
149787  97.350  -77.946  47.139  1
149788  97.375  -77.946  47.124  1
149789  97.398  -77.964  47.108  1
149790  97.422  -77.981  47.092  1
149791  97.445  -77.999  47.077  1
149792  97.468  -78.016  47.060  1
149793  97.491  -78.033  47.044  1
149794  97.511  -78.050  47.028  1
149795  97.517  -78.065  47.011  1
149796  97.498  -78.075  46.994  1
149797  97.490  -78.090  46.977  1
149798  97.503  -78.106  46.959  1
149799  97.520  -78.124  46.942  1
149800  97.537  -78.141  46.924  1
149801  97.554  -78.158  46.906  1
149802  97.567  -78.172  46.888  1
149803  97.580  -78.187  46.871  1
149804  97.594  -78.201  46.853  1
149805  97.603  -78.212  46.835  1
149806  97.631  -78.225  46.815  1
149807  97.667  -78.230  46.794  1
149808  97.703  -78.235  46.774  1
149809  97.739  -78.240  46.753  1
149810  97.775  -78.245  46.733  1
149811  97.811  -78.250  46.713  1
149812  97.848  -78.255  46.691  1
149813  97.883  -78.260  46.669  1
149814  97.915  -78.266  46.646  1
149815  97.943  -78.273  46.623  1
149816  97.971  -78.280  46.599  1
149817  97.992  -78.279  46.577  1
149818  98.027  -78.269  46.555  1
149819  98.091  -78.258  46.532  1
149820  98.144  -78.247  46.509  1
149821  98.165  -78.235  46.486  1
149822  98.186  -78.224  46.462  1
149823  98.208  -78.212  46.439  1
149824  98.229  -78.200  46.415  1
149825  98.250  -78.189  46.391  1
149826  98.260  -78.172  46.368  1
149827  98.276  -78.166  46.347  1
149828  98.305  -78.167  46.323  1
149829  98.335  -78.169  46.299  1
149830  98.365  -78.171  46.275  1
149831  98.395  -78.172  46.252  1
149832  98.425  -78.174  46.228  1
149833  98.454  -78.175  46.205  1
149834  98.485  -78.177  46.183  1
149835  98.514  -78.178  46.158  1
149836  98.544  -78.180  46.134  1
149837  98.595  -78.170  46.111  1
149838  98.584  -78.189  46.089  1
149839  98.573  -78.200  46.067  1
149840  98.563  -78.193  46.045  1
149841  98.553  -78.186  46.023  1
149842  98.543  -78.180  46.000  1
149843  98.533  -78.173  45.979  1
149844  98.512  -78.172  45.958  1
149845  98.499  -78.168  45.937  1
149846  98.496  -78.169  45.917  1
149847  98.544  -78.176  45.898  1
149848  98.587  -78.184  45.880  1
149849  98.631  -78.191  45.862  1
149850  98.674  -78.198  45.844  1
149851  98.717  -78.205  45.825  1
149852  98.761  -78.213  45.807  1
149853  98.804  -78.219  45.792  1
149854  98.847  -78.227  45.777  1
149855  98.890  -78.234  45.763  1
149856  98.921  -78.232  45.749  1
149857  98.950  -78.229  45.733  1
149858  98.979  -78.228  45.718  1
149859  99.006  -78.243  45.703  1
149860  99.032  -78.258  45.690  1
149861  99.060  -78.272  45.676  1
149862  99.085  -78.287  45.663  1
149863  99.078  -78.287  45.651  1
149864  99.095  -78.289  45.639  1
149865  99.118  -78.292  45.627  1
149866  99.140  -78.295  45.614  1
149867  99.163  -78.298  45.600  1
149868  99.196  -78.307  45.588  1
149869  99.228  -78.314  45.576  1
149870  99.261  -78.322  45.564  1
149871  99.293  -78.330  45.549  1
149872  99.325  -78.338  45.535  1
149873  99.357  -78.346  45.521  1
149874  99.390  -78.354  45.509  1
149875  99.422  -78.361  45.496  1
149876  99.454  -78.369  45.483  1
149877  99.487  -78.377  45.471  1
149878  99.519  -78.385  45.459  1
149879  99.552  -78.393  45.447  1
149880  99.584  -78.401  45.435  1
149881  99.616  -78.409  45.422  1
149882  99.622  -78.428  45.410  1
149883  99.608  -78.455  45.399  1
149884  99.598  -78.483  45.387  1
149885  99.648  -78.528  45.375  1
149886  99.695  -78.507  45.364  1
149887  99.779  -78.512  45.353  1
149888  99.860  -78.518  45.342  1
149889  99.893  -78.541  45.331  1
149890  99.921  -78.550  45.319  1
149891  99.948  -78.560  45.306  1
149892  99.975  -78.570  45.294  1
149893  100.002  -78.579  45.283  1
149894  100.030  -78.589  45.271  1
149895  100.040  -78.595  45.258  1
149896  100.049  -78.602  45.246  1
149897  100.058  -78.609  45.234  1
149898  100.067  -78.616  45.222  1
149899  100.076  -78.623  45.210  1
149900  100.085  -78.630  45.195  1
149901  100.111  -78.639  45.181  1
149902  100.158  -78.655  45.165  1
149903  100.196  -78.673  45.149  1
149904  100.227  -78.689  45.134  1
149905  100.245  -78.700  45.118  1
149906  100.263  -78.712  45.102  1
149907  100.281  -78.724  45.087  1
149908  100.299  -78.736  45.070  1
149909  100.317  -78.747  45.053  1
149910  100.335  -78.758  45.036  1
149911  100.353  -78.771  45.019  1
149912  100.371  -78.782  45.003  1
149913  100.390  -78.794  44.987  1
149914  100.408  -78.805  44.971  1
149915  100.426  -78.817  44.955  1
149916  100.443  -78.829  44.939  1
149917  100.457  -78.841  44.923  1
149918  100.472  -78.861  44.907  1
149919  100.487  -78.880  44.891  1
149920  100.501  -78.899  44.874  1
149921  100.516  -78.918  44.858  1
149922  100.531  -78.938  44.842  1
149923  100.547  -78.957  44.825  1
149924  100.562  -78.975  44.807  1
149925  100.579  -78.989  44.790  1
149926  100.595  -79.000  44.772  1
149927  100.612  -79.011  44.754  1
149928  100.628  -79.022  44.737  1
149929  100.644  -79.034  44.720  1
149930  100.663  -79.046  44.703  1
149931  100.696  -79.065  44.686  1
149932  100.729  -79.084  44.670  1
149933  100.782  -79.092  44.653  1
149934  100.835  -79.098  44.637  1
149935  100.887  -79.104  44.622  1
149936  100.938  -79.111  44.607  1
149937  100.991  -79.117  44.593  1
149938  101.043  -79.123  44.579  1
149939  101.095  -79.129  44.564  1
149940  101.147  -79.136  44.550  1
149941  101.199  -79.142  44.536  1
149942  101.251  -79.148  44.522  1
149943  101.296  -79.156  44.508  1
149944  101.321  -79.169  44.495  1
149945  101.345  -79.183  44.482  1
150178  92.648  -77.787  54.220  1
150179  92.668  -77.794  54.217  1
150180  92.688  -77.801  54.215  1
150181  92.708  -77.808  54.213  1
150182  92.728  -77.816  54.210  1
150183  92.748  -77.823  54.208  1
150184  92.768  -77.830  54.206  1
150185  92.788  -77.838  54.205  1
150186  92.808  -77.846  54.204  1
150187  92.828  -77.852  54.203  1
150188  92.848  -77.860  54.202  1
150189  92.868  -77.868  54.201  1
150190  92.888  -77.874  54.199  1
150191  92.908  -77.882  54.198  1
150192  92.928  -77.890  54.198  1
150193  92.948  -77.896  54.198  1
150194  92.972  -77.893  54.200  1
150195  92.989  -77.887  54.201  1
150196  93.006  -77.883  54.202  1
150197  93.023  -77.877  54.204  1
150198  93.040  -77.872  54.205  1
150199  93.057  -77.867  54.206  1
150200  93.074  -77.862  54.209  1
150201  93.093  -77.861  54.213  1
150202  93.114  -77.860  54.216  1
150203  93.133  -77.859  54.217  1
150204  93.154  -77.832  54.218  1
150205  93.165  -77.818  54.217  1
150206  93.177  -77.805  54.215  1
150207  93.188  -77.792  54.211  1
150208  93.199  -77.778  54.207  1
150209  93.210  -77.765  54.202  1
150210  93.221  -77.752  54.196  1
150211  93.232  -77.738  54.189  1
150212  93.243  -77.724  54.182  1
150213  93.255  -77.711  54.175  1
150214  93.266  -77.698  54.168  1
150215  93.267  -77.683  54.161  1
150216  93.271  -77.669  54.153  1
150217  93.287  -77.655  54.146  1
150218  93.303  -77.642  54.139  1
150219  93.318  -77.630  54.132  1
150220  93.332  -77.620  54.125  1
150221  93.346  -77.611  54.119  1
150222  93.359  -77.602  54.112  1
150223  93.375  -77.594  54.105  1
150224  93.392  -77.586  54.098  1
150225  93.407  -77.579  54.090  1
150226  93.423  -77.571  54.082  1
150227  93.439  -77.564  54.073  1
150228  93.455  -77.556  54.064  1
150229  93.471  -77.548  54.055  1
150230  93.487  -77.539  54.044  1
150231  93.501  -77.533  54.032  1
150232  93.515  -77.530  54.020  1
150233  93.528  -77.526  54.008  1
150234  93.541  -77.523  53.994  1
150235  93.554  -77.519  53.980  1
150236  93.567  -77.516  53.966  1
150237  93.579  -77.510  53.948  1
150238  93.586  -77.502  53.928  1
150239  93.592  -77.495  53.908  1
150240  93.600  -77.488  53.889  1
150241  93.608  -77.479  53.871  1
150242  93.616  -77.472  53.853  1
150243  93.624  -77.464  53.834  1
150244  93.632  -77.455  53.813  1
150245  93.649  -77.446  53.796  1
150246  93.673  -77.434  53.780  1
150247  93.699  -77.421  53.765  1
150248  93.724  -77.409  53.752  1
150249  93.750  -77.396  53.739  1
150250  93.776  -77.384  53.723  1
150251  93.797  -77.372  53.706  1
150252  93.813  -77.361  53.687  1
150253  93.829  -77.351  53.671  1
150254  93.845  -77.340  53.656  1
150255  93.859  -77.332  53.642  1
150256  93.861  -77.347  53.629  1
150257  93.876  -77.328  53.613  1
150258  93.896  -77.299  53.597  1
150259  93.911  -77.282  53.582  1
150260  93.918  -77.288  53.568  1
150261  93.926  -77.295  53.554  1
150262  93.933  -77.301  53.542  1
150263  93.941  -77.302  53.528  1
150264  93.957  -77.306  53.512  1
150265  93.974  -77.313  53.495  1
150266  93.992  -77.319  53.476  1
150267  94.010  -77.326  53.459  1
150268  94.029  -77.332  53.444  1
150269  94.048  -77.339  53.430  1
150270  94.051  -77.337  53.417  1
150271  94.057  -77.323  53.402  1
150272  94.068  -77.313  53.386  1
150273  94.098  -77.312  53.368  1
150274  94.128  -77.312  53.349  1
150275  94.157  -77.311  53.329  1
150276  94.187  -77.310  53.310  1
150277  94.213  -77.308  53.293  1
150278  94.232  -77.303  53.281  1
150279  94.253  -77.297  53.273  1
150280  94.272  -77.291  53.266  1
150281  94.288  -77.285  53.260  1
150282  94.289  -77.279  53.253  1
150283  94.290  -77.271  53.246  1
150284  94.291  -77.264  53.238  1
150285  94.291  -77.261  53.229  1
150286  94.290  -77.263  53.219  1
150287  94.289  -77.263  53.209  1
150288  94.288  -77.264  53.199  1
150289  94.290  -77.264  53.187  1
150290  94.296  -77.260  53.175  1
150291  94.302  -77.257  53.164  1
150292  94.304  -77.255  53.152  1
150293  94.305  -77.254  53.139  1
150294  94.309  -77.250  53.126  1
150295  94.322  -77.237  53.115  1
150296  94.335  -77.225  53.104  1
150297  94.348  -77.212  53.093  1
150298  94.361  -77.200  53.082  1
150299  94.382  -77.194  53.068  1
150300  94.404  -77.190  53.058  1
150301  94.426  -77.186  53.049  1
150302  94.449  -77.182  53.038  1
150303  94.471  -77.178  53.025  1
150304  94.493  -77.174  53.010  1
150305  94.514  -77.169  52.992  1
150306  94.535  -77.165  52.972  1
150307  94.554  -77.160  52.953  1
150308  94.574  -77.156  52.935  1
150309  94.595  -77.151  52.917  1
150310  94.615  -77.147  52.900  1
150311  94.626  -77.146  52.881  1
150312  94.636  -77.145  52.859  1
150313  94.645  -77.144  52.835  1
150314  94.655  -77.144  52.809  1
150315  94.666  -77.144  52.782  1
150316  94.679  -77.148  52.756  1
150317  94.693  -77.151  52.732  1
150318  94.706  -77.155  52.706  1
150319  94.719  -77.159  52.677  1
150320  94.746  -77.166  52.645  1
150321  94.772  -77.175  52.616  1
150322  94.782  -77.184  52.587  1
150323  94.793  -77.192  52.557  1
150324  94.804  -77.201  52.524  1
150325  94.818  -77.208  52.488  1
150326  94.837  -77.215  52.449  1
150327  94.856  -77.222  52.407  1
150328  94.875  -77.229  52.366  1
150329  94.893  -77.234  52.325  1
150330  94.910  -77.229  52.282  1
150331  94.926  -77.223  52.239  1
150332  94.942  -77.218  52.196  1
150333  94.958  -77.213  52.150  1
150334  94.972  -77.207  52.103  1
150335  94.990  -77.180  52.055  1
150336  95.014  -77.199  52.005  1
150337  95.039  -77.211  51.952  1
150338  95.063  -77.216  51.897  1
150339  95.087  -77.222  51.846  1
150340  95.111  -77.228  51.791  1
150341  95.135  -77.234  51.735  1
150342  95.159  -77.239  51.680  1
150343  95.172  -77.240  51.621  1
150344  95.187  -77.238  51.563  1
150345  95.203  -77.232  51.507  1
150346  95.218  -77.225  51.457  1
150347  95.235  -77.218  51.409  1
150348  95.251  -77.211  51.359  1
150349  95.266  -77.204  51.308  1
150350  95.282  -77.197  51.257  1
150351  95.299  -77.191  51.207  1
150352  95.315  -77.184  51.158  1
150353  95.330  -77.177  51.112  1
150354  95.346  -77.171  51.065  1
150355  95.362  -77.164  51.021  1
150356  95.382  -77.168  50.979  1
150357  95.404  -77.183  50.938  1
150358  95.425  -77.197  50.895  1
150359  95.443  -77.213  50.853  1
150360  95.461  -77.227  50.812  1
150361  95.479  -77.241  50.774  1
150362  95.497  -77.257  50.736  1
150363  95.521  -77.278  50.696  1
150364  95.544  -77.298  50.654  1
150365  95.567  -77.318  50.615  1
150366  95.591  -77.338  50.579  1
150367  95.614  -77.359  50.545  1
150368  95.637  -77.379  50.514  1
150369  95.660  -77.400  50.480  1
150370  95.678  -77.417  50.446  1
150371  95.694  -77.434  50.412  1
150372  95.710  -77.451  50.376  1
150373  95.727  -77.464  50.339  1
150374  95.743  -77.477  50.301  1
150375  95.759  -77.489  50.262  1
150376  95.775  -77.501  50.220  1
150377  95.792  -77.514  50.180  1
150378  95.808  -77.526  50.141  1
150379  95.824  -77.533  50.100  1
150380  95.840  -77.536  50.057  1
150381  95.856  -77.539  50.011  1
150382  95.872  -77.542  49.962  1
150383  95.888  -77.546  49.906  1
150384  95.903  -77.550  49.851  1
150385  95.919  -77.555  49.797  1
150386  95.935  -77.558  49.744  1
150387  95.951  -77.562  49.697  1
150388  95.966  -77.567  49.653  1
150389  95.980  -77.570  49.612  1
150390  95.987  -77.572  49.571  1
150391  95.994  -77.573  49.533  1
150392  96.001  -77.575  49.495  1
150393  96.007  -77.577  49.457  1
150394  96.014  -77.579  49.419  1
150395  96.022  -77.579  49.383  1
150396  96.033  -77.578  49.349  1
150397  96.043  -77.577  49.318  1
150398  96.057  -77.577  49.289  1
150399  96.072  -77.579  49.262  1
150400  96.086  -77.580  49.236  1
150401  96.100  -77.572  49.212  1
150402  96.100  -77.596  49.189  1
150403  96.096  -77.611  49.166  1
150404  96.093  -77.622  49.141  1
150405  96.090  -77.633  49.119  1
150406  96.087  -77.645  49.095  1
150407  96.084  -77.656  49.070  1
150408  96.089  -77.664  49.044  1
150409  96.104  -77.664  49.016  1
150410  96.119  -77.664  48.988  1
150411  96.133  -77.664  48.959  1
150412  96.149  -77.664  48.928  1
150413  96.163  -77.664  48.895  1
150414  96.178  -77.667  48.861  1
150415  96.192  -77.679  48.828  1
150416  96.205  -77.688  48.798  1
150417  96.216  -77.697  48.769  1
150418  96.221  -77.707  48.740  1
150419  96.227  -77.718  48.711  1
150420  96.233  -77.727  48.679  1
150421  96.238  -77.737  48.648  1
150422  96.244  -77.747  48.617  1
150423  96.250  -77.757  48.592  1
150424  96.255  -77.768  48.567  1
150425  96.261  -77.777  48.543  1
150426  96.288  -77.775  48.519  1
150427  96.315  -77.774  48.494  1
150428  96.341  -77.771  48.470  1
150429  96.368  -77.770  48.446  1
150430  96.395  -77.768  48.425  1
150431  96.421  -77.765  48.404  1
150432  96.448  -77.764  48.382  1
150433  96.470  -77.763  48.360  1
150434  96.479  -77.768  48.337  1
150435  96.488  -77.771  48.313  1
150436  96.497  -77.776  48.290  1
150437  96.506  -77.780  48.268  1
150438  96.514  -77.784  48.245  1
150439  96.520  -77.790  48.223  1
150440  96.521  -77.803  48.202  1
150441  96.530  -77.810  48.179  1
150442  96.540  -77.817  48.156  1
150443  96.550  -77.823  48.133  1
150444  96.559  -77.830  48.110  1
150445  96.570  -77.836  48.085  1
150446  96.590  -77.837  48.061  1
150447  96.605  -77.826  48.037  1
150448  96.618  -77.809  48.012  1
150449  96.630  -77.793  47.987  1
150450  96.643  -77.777  47.961  1
150451  96.657  -77.762  47.936  1
150452  96.672  -77.750  47.911  1
150453  96.687  -77.738  47.886  1
150454  96.704  -77.733  47.860  1
150455  96.727  -77.743  47.834  1
150456  96.748  -77.755  47.808  1
150457  96.770  -77.767  47.782  1
150458  96.793  -77.779  47.757  1
150459  96.815  -77.792  47.732  1
150460  96.837  -77.804  47.708  1
150461  96.859  -77.817  47.684  1
150462  96.881  -77.829  47.660  1
150463  96.903  -77.842  47.636  1
150464  96.925  -77.854  47.613  1
150465  96.941  -77.864  47.591  1
150466  96.950  -77.871  47.568  1
150467  96.959  -77.870  47.547  1
150468  96.967  -77.863  47.526  1
150469  96.975  -77.856  47.505  1
150470  96.983  -77.849  47.485  1
150471  96.992  -77.842  47.463  1
150472  97.001  -77.836  47.442  1
150473  97.012  -77.834  47.422  1
150474  97.023  -77.832  47.403  1
150475  97.036  -77.832  47.385  1
150476  97.050  -77.832  47.367  1
150477  97.070  -77.843  47.350  1
150478  97.090  -77.855  47.332  1
150479  97.110  -77.867  47.314  1
150480  97.130  -77.879  47.297  1
150481  97.155  -77.886  47.280  1
150482  97.183  -77.888  47.262  1
150483  97.212  -77.891  47.243  1
150484  97.240  -77.894  47.225  1
150485  97.269  -77.897  47.207  1
150486  97.300  -77.909  47.190  1
150487  97.331  -77.921  47.174  1
150488  97.360  -77.929  47.157  1
150489  97.381  -77.929  47.142  1
150490  97.393  -77.941  47.126  1
150491  97.409  -77.959  47.109  1
150492  97.426  -77.978  47.092  1
150493  97.442  -77.996  47.074  1
150494  97.458  -78.015  47.057  1
150495  97.470  -78.034  47.041  1
150496  97.476  -78.029  47.023  1
150497  97.489  -78.040  47.006  1
150498  97.509  -78.077  46.988  1
150499  97.522  -78.091  46.970  1
150500  97.536  -78.106  46.952  1
150501  97.549  -78.120  46.933  1
150502  97.563  -78.134  46.914  1
150503  97.576  -78.149  46.895  1
150504  97.590  -78.163  46.877  1
150505  97.603  -78.178  46.858  1
150506  97.603  -78.180  46.840  1
150507  97.618  -78.200  46.820  1
150508  97.646  -78.218  46.800  1
150509  97.682  -78.223  46.781  1
150510  97.718  -78.228  46.762  1
150511  97.754  -78.233  46.742  1
150512  97.791  -78.238  46.722  1
150513  97.827  -78.243  46.702  1
150514  97.859  -78.249  46.679  1
150515  97.887  -78.256  46.656  1
150516  97.916  -78.263  46.633  1
150517  97.944  -78.270  46.610  1
150518  97.960  -78.264  46.587  1
150519  98.017  -78.253  46.565  1
150520  98.080  -78.242  46.543  1
150521  98.136  -78.232  46.520  1
150522  98.158  -78.220  46.496  1
150523  98.179  -78.208  46.473  1
150524  98.200  -78.197  46.449  1
150525  98.221  -78.185  46.425  1
150526  98.242  -78.174  46.401  1
150527  98.246  -78.159  46.378  1
150528  98.276  -78.160  46.356  1
150529  98.306  -78.162  46.332  1
150530  98.336  -78.163  46.308  1
150531  98.366  -78.165  46.284  1
150532  98.395  -78.166  46.261  1
150533  98.425  -78.168  46.237  1
150534  98.455  -78.169  46.215  1
150535  98.485  -78.171  46.193  1
150536  98.515  -78.172  46.169  1
150537  98.545  -78.174  46.145  1
150538  98.575  -78.175  46.122  1
150539  98.633  -78.162  46.100  1
150540  98.623  -78.162  46.077  1
150541  98.576  -78.173  46.055  1
150542  98.563  -78.169  46.033  1
150543  98.550  -78.165  46.010  1
150544  98.537  -78.161  45.990  1
150545  98.524  -78.156  45.970  1
150546  98.511  -78.152  45.948  1
150547  98.510  -78.158  45.927  1
150548  98.537  -78.165  45.907  1
150549  98.590  -78.173  45.888  1
150550  98.637  -78.181  45.871  1
150551  98.680  -78.188  45.853  1
150552  98.723  -78.195  45.835  1
150553  98.767  -78.202  45.818  1
150554  98.810  -78.210  45.804  1
150555  98.853  -78.216  45.789  1
150556  98.897  -78.223  45.775  1
150557  98.937  -78.229  45.760  1
150558  98.967  -78.226  45.745  1
150559  98.996  -78.223  45.730  1
150560  99.023  -78.233  45.715  1
150561  99.051  -78.248  45.701  1
150562  99.077  -78.263  45.687  1
150563  99.099  -78.275  45.673  1
150564  99.092  -78.275  45.660  1
150565  99.102  -78.277  45.648  1
150566  99.125  -78.280  45.635  1
150567  99.147  -78.283  45.622  1
150568  99.169  -78.285  45.610  1
150569  99.192  -78.288  45.598  1
150570  99.223  -78.296  45.585  1
150571  99.256  -78.304  45.574  1
150572  99.288  -78.312  45.560  1
150573  99.321  -78.319  45.546  1
150574  99.353  -78.327  45.532  1
150575  99.385  -78.335  45.520  1
150576  99.417  -78.343  45.507  1
150577  99.450  -78.351  45.495  1
150578  99.482  -78.359  45.483  1
150579  99.514  -78.366  45.472  1
150580  99.547  -78.375  45.460  1
150581  99.579  -78.382  45.447  1
150582  99.607  -78.392  45.435  1
150583  99.593  -78.420  45.422  1
150584  99.580  -78.447  45.411  1
150585  99.567  -78.474  45.399  1
150586  99.609  -78.498  45.389  1
150587  99.682  -78.495  45.377  1
150588  99.766  -78.501  45.366  1
150589  99.846  -78.508  45.355  1
150590  99.878  -78.536  45.343  1
150591  99.908  -78.543  45.331  1
150592  99.935  -78.553  45.318  1
150593  99.963  -78.563  45.306  1
150594  99.990  -78.572  45.296  1
150595  100.017  -78.582  45.283  1
150596  100.044  -78.592  45.271  1
150597  100.069  -78.601  45.258  1
150598  100.078  -78.608  45.245  1
150599  100.087  -78.614  45.233  1
150600  100.097  -78.621  45.222  1
150601  100.106  -78.628  45.208  1
150602  100.120  -78.636  45.193  1
150603  100.168  -78.651  45.178  1
150604  100.205  -78.669  45.162  1
150605  100.227  -78.682  45.146  1
150606  100.246  -78.694  45.130  1
150607  100.264  -78.705  45.113  1
150608  100.281  -78.717  45.096  1
150609  100.299  -78.729  45.079  1
150610  100.318  -78.740  45.062  1
150611  100.336  -78.752  45.045  1
150612  100.354  -78.764  45.028  1
150613  100.372  -78.776  45.011  1
150614  100.390  -78.787  44.995  1
150615  100.408  -78.799  44.979  1
150616  100.426  -78.811  44.964  1
150617  100.444  -78.822  44.948  1
150618  100.462  -78.834  44.932  1
150619  100.476  -78.852  44.916  1
150620  100.492  -78.871  44.899  1
150621  100.508  -78.888  44.882  1
150622  100.525  -78.905  44.866  1
150623  100.541  -78.921  44.849  1
150624  100.557  -78.939  44.832  1
150625  100.568  -78.960  44.815  1
150626  100.572  -78.987  44.797  1
150627  100.588  -79.012  44.780  1
150628  100.609  -79.026  44.763  1
150629  100.635  -79.017  44.745  1
150630  100.651  -79.028  44.728  1
150631  100.668  -79.040  44.711  1
150632  100.693  -79.055  44.694  1
150633  100.736  -79.069  44.678  1
150634  100.788  -79.075  44.661  1
150635  100.840  -79.081  44.645  1
150636  100.892  -79.088  44.630  1
150637  100.944  -79.094  44.616  1
150638  100.996  -79.100  44.600  1
150639  101.048  -79.106  44.585  1
150640  101.100  -79.112  44.571  1
150641  101.152  -79.119  44.558  1
150642  101.204  -79.125  44.543  1
150643  101.256  -79.131  44.529  1
150644  101.295  -79.141  44.516  1
150645  101.320  -79.155  44.503  1
150646  101.344  -79.168  44.490  1
150647  101.369  -79.181  44.477  1
150879  92.637  -77.767  54.215  1
150880  92.657  -77.774  54.213  1
150881  92.677  -77.781  54.211  1
150882  92.697  -77.789  54.209  1
150883  92.717  -77.796  54.207  1
150884  92.737  -77.803  54.205  1
150885  92.757  -77.811  54.204  1
150886  92.777  -77.818  54.202  1
150887  92.797  -77.825  54.201  1
150888  92.817  -77.833  54.201  1
150889  92.837  -77.840  54.200  1
150890  92.857  -77.847  54.199  1
150891  92.877  -77.855  54.198  1
150892  92.897  -77.862  54.198  1
150893  92.917  -77.869  54.198  1
150894  92.937  -77.877  54.199  1
150895  92.961  -77.873  54.200  1
150896  92.979  -77.867  54.200  1
150897  92.996  -77.862  54.202  1
150898  93.013  -77.856  54.204  1
150899  93.030  -77.851  54.205  1
150900  93.047  -77.846  54.207  1
150901  93.064  -77.840  54.211  1
150902  93.080  -77.836  54.216  1
150903  93.100  -77.834  54.220  1
150904  93.120  -77.833  54.223  1
150905  93.136  -77.811  54.224  1
150906  93.147  -77.797  54.223  1
150907  93.158  -77.783  54.221  1
150908  93.169  -77.771  54.218  1
150909  93.181  -77.757  54.214  1
150910  93.192  -77.743  54.209  1
150911  93.203  -77.730  54.203  1
150912  93.214  -77.717  54.196  1
150913  93.225  -77.703  54.191  1
150914  93.236  -77.689  54.185  1
150915  93.248  -77.676  54.179  1
150916  93.259  -77.663  54.173  1
150917  93.263  -77.649  54.166  1
150918  93.279  -77.635  54.160  1
150919  93.292  -77.625  54.153  1
150920  93.306  -77.615  54.146  1
150921  93.320  -77.605  54.138  1
150922  93.334  -77.596  54.130  1
150923  93.348  -77.586  54.124  1
150924  93.364  -77.579  54.116  1
150925  93.380  -77.571  54.109  1
150926  93.396  -77.564  54.102  1
150927  93.412  -77.556  54.094  1
150928  93.428  -77.548  54.086  1
150929  93.444  -77.539  54.077  1
150930  93.460  -77.531  54.066  1
150931  93.476  -77.523  54.055  1
150932  93.491  -77.514  54.042  1
150933  93.504  -77.511  54.029  1
150934  93.517  -77.508  54.018  1
150935  93.531  -77.504  54.005  1
150936  93.544  -77.501  53.993  1
150937  93.558  -77.497  53.979  1
150938  93.575  -77.492  53.962  1
150939  93.583  -77.485  53.943  1
150940  93.590  -77.477  53.924  1
150941  93.596  -77.470  53.905  1
150942  93.603  -77.463  53.887  1
150943  93.609  -77.456  53.869  1
150944  93.616  -77.448  53.852  1
150945  93.622  -77.442  53.834  1
150946  93.640  -77.432  53.817  1
150947  93.665  -77.419  53.802  1
150948  93.691  -77.407  53.788  1
150949  93.717  -77.394  53.776  1
150950  93.743  -77.382  53.763  1
150951  93.768  -77.369  53.748  1
150952  93.794  -77.356  53.731  1
150953  93.812  -77.345  53.711  1
150954  93.828  -77.335  53.694  1
150955  93.844  -77.324  53.678  1
150956  93.856  -77.320  53.663  1
150957  93.858  -77.335  53.650  1
150958  93.871  -77.321  53.635  1
150959  93.891  -77.292  53.620  1
150960  93.902  -77.286  53.605  1
150961  93.910  -77.293  53.590  1
150962  93.917  -77.299  53.575  1
150963  93.925  -77.300  53.560  1
150964  93.934  -77.294  53.545  1
150965  93.949  -77.298  53.529  1
150966  93.967  -77.304  53.512  1
150967  93.984  -77.310  53.494  1
150968  94.001  -77.316  53.478  1
150969  94.018  -77.323  53.464  1
150970  94.035  -77.327  53.452  1
150971  94.041  -77.314  53.439  1
150972  94.047  -77.301  53.425  1
150973  94.067  -77.295  53.410  1
150974  94.097  -77.294  53.393  1
150975  94.127  -77.294  53.373  1
150976  94.156  -77.294  53.354  1
150977  94.186  -77.293  53.335  1
150978  94.215  -77.292  53.318  1
150979  94.238  -77.288  53.308  1
150980  94.258  -77.282  53.300  1
150981  94.277  -77.276  53.294  1
150982  94.293  -77.271  53.288  1
150983  94.294  -77.263  53.282  1
150984  94.295  -77.257  53.276  1
150985  94.295  -77.250  53.270  1
150986  94.296  -77.243  53.261  1
150987  94.297  -77.239  53.253  1
150988  94.296  -77.240  53.243  1
150989  94.295  -77.241  53.233  1
150990  94.296  -77.241  53.223  1
150991  94.302  -77.238  53.213  1
150992  94.307  -77.235  53.204  1
150993  94.308  -77.233  53.193  1
150994  94.308  -77.232  53.182  1
150995  94.309  -77.230  53.170  1
150996  94.319  -77.220  53.158  1
150997  94.332  -77.207  53.148  1
150998  94.345  -77.195  53.137  1
150999  94.358  -77.183  53.125  1
151000  94.380  -77.178  53.108  1
151001  94.402  -77.174  53.097  1
151002  94.425  -77.170  53.087  1
151003  94.447  -77.166  53.077  1
151004  94.470  -77.162  53.064  1
151005  94.491  -77.157  53.048  1
151006  94.511  -77.153  53.030  1
151007  94.531  -77.148  53.010  1
151008  94.551  -77.144  52.989  1
151009  94.571  -77.139  52.969  1
151010  94.591  -77.135  52.950  1
151011  94.611  -77.130  52.933  1
151012  94.625  -77.128  52.912  1
151013  94.635  -77.128  52.890  1
151014  94.644  -77.127  52.865  1
151015  94.654  -77.126  52.839  1
151016  94.668  -77.129  52.813  1
151017  94.681  -77.133  52.787  1
151018  94.694  -77.137  52.763  1
151019  94.707  -77.141  52.736  1
151020  94.720  -77.144  52.705  1
151021  94.737  -77.148  52.672  1
151022  94.761  -77.157  52.641  1
151023  94.772  -77.166  52.610  1
151024  94.784  -77.174  52.577  1
151025  94.803  -77.181  52.543  1
151026  94.822  -77.188  52.507  1
151027  94.841  -77.194  52.468  1
151028  94.860  -77.201  52.427  1
151029  94.879  -77.207  52.387  1
151030  94.898  -77.214  52.346  1
151031  94.914  -77.209  52.303  1
151032  94.930  -77.204  52.259  1
151033  94.946  -77.198  52.216  1
151034  94.962  -77.193  52.169  1
151035  94.978  -77.188  52.120  1
151036  94.994  -77.182  52.069  1
151037  95.016  -77.185  52.017  1
151038  95.040  -77.191  51.961  1
151039  95.064  -77.197  51.904  1
151040  95.088  -77.202  51.850  1
151041  95.112  -77.208  51.794  1
151042  95.136  -77.213  51.740  1
151043  95.160  -77.219  51.686  1
151044  95.174  -77.220  51.632  1
151045  95.187  -77.222  51.579  1
151046  95.202  -77.219  51.528  1
151047  95.218  -77.212  51.481  1
151048  95.234  -77.205  51.433  1
151049  95.250  -77.198  51.385  1
151050  95.266  -77.191  51.334  1
151051  95.282  -77.185  51.283  1
151052  95.298  -77.178  51.233  1
151053  95.314  -77.171  51.184  1
151054  95.330  -77.164  51.137  1
151055  95.346  -77.157  51.091  1
151056  95.362  -77.153  51.045  1
151057  95.385  -77.167  51.001  1
151058  95.407  -77.182  50.958  1
151059  95.429  -77.197  50.916  1
151060  95.447  -77.212  50.875  1
151061  95.464  -77.226  50.835  1
151062  95.482  -77.241  50.795  1
151063  95.500  -77.256  50.755  1
151064  95.518  -77.270  50.714  1
151065  95.541  -77.291  50.672  1
151066  95.564  -77.311  50.635  1
151067  95.588  -77.332  50.598  1
151068  95.611  -77.352  50.561  1
151069  95.634  -77.373  50.525  1
151070  95.658  -77.393  50.492  1
151071  95.676  -77.410  50.457  1
151072  95.692  -77.427  50.421  1
151073  95.708  -77.444  50.387  1
151074  95.725  -77.461  50.351  1
151075  95.741  -77.477  50.314  1
151076  95.757  -77.492  50.276  1
151077  95.773  -77.504  50.236  1
151078  95.790  -77.516  50.197  1
151079  95.806  -77.528  50.158  1
151080  95.822  -77.536  50.118  1
151081  95.838  -77.537  50.075  1
151082  95.854  -77.539  50.029  1
151083  95.871  -77.542  49.980  1
151084  95.887  -77.544  49.925  1
151085  95.903  -77.546  49.869  1
151086  95.918  -77.549  49.814  1
151087  95.934  -77.554  49.760  1
151088  95.950  -77.558  49.712  1
151089  95.966  -77.561  49.668  1
151090  95.981  -77.565  49.626  1
151091  95.988  -77.567  49.584  1
151092  95.995  -77.569  49.544  1
151093  96.002  -77.571  49.505  1
151094  96.011  -77.570  49.466  1
151095  96.021  -77.570  49.427  1
151096  96.032  -77.568  49.391  1
151097  96.042  -77.567  49.356  1
151098  96.052  -77.565  49.322  1
151099  96.063  -77.564  49.293  1
151100  96.074  -77.564  49.264  1
151101  96.089  -77.557  49.236  1
151102  96.104  -77.549  49.209  1
151103  96.098  -77.584  49.186  1
151104  96.094  -77.605  49.164  1
151105  96.091  -77.616  49.143  1
151106  96.088  -77.627  49.118  1
151107  96.085  -77.639  49.094  1
151108  96.089  -77.631  49.071  1
151109  96.091  -77.645  49.049  1
151110  96.106  -77.645  49.023  1
151111  96.120  -77.646  48.996  1
151112  96.135  -77.646  48.966  1
151113  96.150  -77.646  48.934  1
151114  96.165  -77.646  48.901  1
151115  96.179  -77.654  48.869  1
151116  96.193  -77.665  48.838  1
151117  96.207  -77.676  48.809  1
151118  96.220  -77.685  48.781  1
151119  96.232  -77.694  48.752  1
151120  96.239  -77.703  48.721  1
151121  96.245  -77.714  48.690  1
151122  96.250  -77.724  48.660  1
151123  96.256  -77.733  48.632  1
151124  96.262  -77.743  48.608  1
151125  96.267  -77.753  48.584  1
151126  96.284  -77.760  48.559  1
151127  96.304  -77.765  48.534  1
151128  96.327  -77.767  48.510  1
151129  96.354  -77.765  48.486  1
151130  96.381  -77.763  48.462  1
151131  96.407  -77.761  48.441  1
151132  96.434  -77.759  48.420  1
151133  96.461  -77.757  48.397  1
151134  96.475  -77.759  48.374  1
151135  96.483  -77.764  48.352  1
151136  96.492  -77.768  48.330  1
151137  96.501  -77.772  48.309  1
151138  96.510  -77.776  48.288  1
151139  96.518  -77.780  48.265  1
151140  96.527  -77.784  48.244  1
151141  96.532  -77.792  48.224  1
151142  96.542  -77.799  48.202  1
151143  96.551  -77.805  48.180  1
151144  96.561  -77.812  48.156  1
151145  96.571  -77.818  48.132  1
151146  96.581  -77.824  48.108  1
151147  96.590  -77.831  48.085  1
151148  96.606  -77.823  48.060  1
151149  96.619  -77.807  48.036  1
151150  96.635  -77.795  48.010  1
151151  96.650  -77.783  47.984  1
151152  96.665  -77.771  47.959  1
151153  96.679  -77.758  47.932  1
151154  96.694  -77.746  47.907  1
151155  96.710  -77.734  47.881  1
151156  96.730  -77.740  47.854  1
151157  96.752  -77.750  47.828  1
151158  96.774  -77.761  47.802  1
151159  96.796  -77.771  47.777  1
151160  96.818  -77.782  47.753  1
151161  96.840  -77.795  47.729  1
151162  96.863  -77.807  47.704  1
151163  96.885  -77.820  47.680  1
151164  96.907  -77.832  47.657  1
151165  96.929  -77.844  47.634  1
151166  96.947  -77.855  47.611  1
151167  96.956  -77.863  47.589  1
151168  96.965  -77.857  47.567  1
151169  96.973  -77.849  47.546  1
151170  96.981  -77.843  47.525  1
151171  96.990  -77.836  47.504  1
151172  97.001  -77.834  47.483  1
151173  97.012  -77.832  47.462  1
151174  97.022  -77.830  47.442  1
151175  97.034  -77.828  47.422  1
151176  97.047  -77.827  47.404  1
151177  97.061  -77.827  47.386  1
151178  97.074  -77.827  47.370  1
151179  97.087  -77.827  47.353  1
151180  97.106  -77.836  47.335  1
151181  97.131  -77.843  47.317  1
151182  97.161  -77.849  47.300  1
151183  97.192  -77.861  47.280  1
151184  97.223  -77.873  47.261  1
151185  97.255  -77.885  47.243  1
151186  97.286  -77.897  47.226  1
151187  97.317  -77.909  47.209  1
151188  97.344  -77.914  47.192  1
151189  97.367  -77.912  47.175  1
151190  97.389  -77.912  47.160  1
151191  97.397  -77.917  47.144  1
151192  97.410  -77.931  47.127  1
151193  97.425  -77.950  47.108  1
151194  97.437  -77.969  47.090  1
151195  97.449  -77.989  47.072  1
151196  97.461  -78.009  47.054  1
151197  97.473  -78.013  47.036  1
151198  97.492  -78.017  47.019  1
151199  97.513  -78.038  47.000  1
151200  97.532  -78.068  46.981  1
151201  97.545  -78.082  46.963  1
151202  97.559  -78.097  46.943  1
151203  97.572  -78.112  46.923  1
151204  97.585  -78.126  46.903  1
151205  97.599  -78.141  46.884  1
151206  97.604  -78.147  46.865  1
151207  97.603  -78.148  46.846  1
151208  97.614  -78.162  46.826  1
151209  97.636  -78.190  46.807  1
151210  97.662  -78.211  46.788  1
151211  97.698  -78.216  46.770  1
151212  97.734  -78.221  46.750  1
151213  97.770  -78.225  46.731  1
151214  97.803  -78.232  46.711  1
151215  97.831  -78.238  46.688  1
151216  97.860  -78.245  46.665  1
151217  97.888  -78.253  46.642  1
151218  97.916  -78.259  46.620  1
151219  97.944  -78.249  46.598  1
151220  98.007  -78.238  46.576  1
151221  98.070  -78.227  46.554  1
151222  98.129  -78.216  46.530  1
151223  98.150  -78.204  46.507  1
151224  98.171  -78.193  46.482  1
151225  98.193  -78.181  46.458  1
151226  98.214  -78.170  46.435  1
151227  98.217  -78.151  46.412  1
151228  98.247  -78.153  46.388  1
151229  98.277  -78.154  46.366  1
151230  98.306  -78.156  46.341  1
151231  98.337  -78.157  46.317  1
151232  98.366  -78.159  46.293  1
151233  98.396  -78.160  46.269  1
151234  98.426  -78.162  46.246  1
151235  98.456  -78.163  46.224  1
151236  98.486  -78.165  46.202  1
151237  98.515  -78.166  46.180  1
151238  98.545  -78.168  46.157  1
151239  98.576  -78.168  46.134  1
151240  98.609  -78.160  46.111  1
151241  98.600  -78.163  46.087  1
151242  98.588  -78.158  46.065  1
151243  98.575  -78.153  46.043  1
151244  98.562  -78.150  46.020  1
151245  98.549  -78.145  46.001  1
151246  98.536  -78.141  45.980  1
151247  98.526  -78.139  45.958  1
151248  98.527  -78.147  45.939  1
151249  98.528  -78.153  45.919  1
151250  98.579  -78.161  45.900  1
151251  98.632  -78.169  45.881  1
151252  98.684  -78.177  45.864  1
151253  98.729  -78.184  45.846  1
151254  98.773  -78.191  45.829  1
151255  98.816  -78.199  45.814  1
151256  98.859  -78.206  45.799  1
151257  98.903  -78.213  45.785  1
151258  98.946  -78.220  45.771  1
151259  98.984  -78.224  45.756  1
151260  99.013  -78.221  45.741  1
151261  99.042  -78.223  45.726  1
151262  99.068  -78.238  45.712  1
151263  99.095  -78.253  45.697  1
151264  99.113  -78.264  45.683  1
151265  99.106  -78.264  45.670  1
151266  99.110  -78.265  45.657  1
151267  99.133  -78.268  45.644  1
151268  99.155  -78.271  45.632  1
151269  99.177  -78.273  45.620  1
151270  99.200  -78.276  45.607  1
151271  99.222  -78.279  45.595  1
151272  99.251  -78.285  45.583  1
151273  99.283  -78.293  45.570  1
151274  99.315  -78.301  45.556  1
151275  99.348  -78.309  45.543  1
151276  99.380  -78.317  45.532  1
151277  99.413  -78.325  45.519  1
151278  99.445  -78.332  45.507  1
151279  99.478  -78.341  45.496  1
151280  99.510  -78.348  45.484  1
151281  99.542  -78.356  45.472  1
151282  99.574  -78.364  45.460  1
151283  99.579  -78.384  45.448  1
151284  99.565  -78.411  45.434  1
151285  99.552  -78.438  45.422  1
151286  99.539  -78.465  45.411  1
151287  99.584  -78.479  45.401  1
151288  99.668  -78.485  45.390  1
151289  99.753  -78.490  45.378  1
151290  99.832  -78.498  45.367  1
151291  99.863  -78.526  45.355  1
151292  99.895  -78.536  45.343  1
151293  99.922  -78.546  45.331  1
151294  99.949  -78.556  45.319  1
151295  99.977  -78.565  45.307  1
151296  100.004  -78.575  45.294  1
151297  100.031  -78.585  45.282  1
151298  100.059  -78.595  45.268  1
151299  100.086  -78.604  45.254  1
151300  100.108  -78.613  45.242  1
151301  100.117  -78.620  45.231  1
151302  100.126  -78.626  45.219  1
151303  100.135  -78.633  45.205  1
151304  100.177  -78.647  45.189  1
151305  100.210  -78.664  45.173  1
151306  100.228  -78.676  45.157  1
151307  100.246  -78.687  45.141  1
151308  100.264  -78.699  45.124  1
151309  100.282  -78.711  45.106  1
151310  100.300  -78.722  45.088  1
151311  100.318  -78.734  45.071  1
151312  100.336  -78.745  45.054  1
151313  100.354  -78.758  45.038  1
151314  100.372  -78.769  45.021  1
151315  100.390  -78.780  45.004  1
151316  100.409  -78.793  44.987  1
151317  100.427  -78.804  44.972  1
151318  100.446  -78.815  44.956  1
151319  100.466  -78.827  44.940  1
151320  100.486  -78.836  44.924  1
151321  100.502  -78.852  44.907  1
151322  100.518  -78.869  44.890  1
151323  100.535  -78.886  44.874  1
151324  100.551  -78.903  44.857  1
151325  100.567  -78.920  44.840  1
151326  100.573  -78.946  44.823  1
151327  100.578  -78.971  44.806  1
151328  100.583  -78.998  44.790  1
151329  100.599  -79.023  44.772  1
151330  100.617  -79.049  44.755  1
151331  100.636  -79.068  44.738  1
151332  100.664  -79.056  44.720  1
151333  100.692  -79.046  44.703  1
151334  100.741  -79.053  44.687  1
151335  100.793  -79.059  44.670  1
151336  100.845  -79.065  44.654  1
151337  100.897  -79.071  44.638  1
151338  100.949  -79.078  44.623  1
151339  101.001  -79.084  44.608  1
151340  101.053  -79.090  44.594  1
151341  101.105  -79.096  44.579  1
151342  101.157  -79.103  44.565  1
151343  101.209  -79.109  44.550  1
151344  101.261  -79.115  44.536  1
151345  101.294  -79.126  44.524  1
151346  101.319  -79.140  44.511  1
151347  101.343  -79.153  44.498  1
151348  101.368  -79.166  44.484  1
151580  92.626  -77.746  54.210  1
151581  92.646  -77.754  54.209  1
151582  92.666  -77.761  54.207  1
151583  92.686  -77.768  54.205  1
151584  92.706  -77.776  54.204  1
151585  92.726  -77.783  54.202  1
151586  92.746  -77.790  54.201  1
151587  92.766  -77.798  54.200  1
151588  92.786  -77.805  54.199  1
151589  92.806  -77.812  54.199  1
151590  92.826  -77.820  54.198  1
151591  92.846  -77.827  54.198  1
151592  92.866  -77.834  54.198  1
151593  92.886  -77.842  54.198  1
151594  92.906  -77.849  54.198  1
151595  92.926  -77.857  54.199  1
151596  92.950  -77.853  54.200  1
151597  92.970  -77.846  54.201  1
151598  92.986  -77.841  54.202  1
151599  93.003  -77.836  54.205  1
151600  93.020  -77.830  54.206  1
151601  93.037  -77.825  54.209  1
151602  93.054  -77.820  54.213  1
151603  93.071  -77.815  54.220  1
151604  93.087  -77.809  54.225  1
151605  93.107  -77.802  54.228  1
151606  93.118  -77.789  54.229  1
151607  93.129  -77.776  54.228  1
151608  93.140  -77.762  54.226  1
151609  93.151  -77.749  54.223  1
151610  93.162  -77.735  54.220  1
151611  93.174  -77.722  54.215  1
151612  93.185  -77.708  54.210  1
151613  93.196  -77.696  54.204  1
151614  93.208  -77.683  54.200  1
151615  93.219  -77.671  54.195  1
151616  93.231  -77.658  54.190  1
151617  93.242  -77.645  54.185  1
151618  93.254  -77.632  54.179  1
151619  93.267  -77.620  54.174  1
151620  93.281  -77.610  54.168  1
151621  93.295  -77.600  54.160  1
151622  93.309  -77.591  54.151  1
151623  93.323  -77.581  54.143  1
151624  93.337  -77.571  54.136  1
151625  93.353  -77.564  54.128  1
151626  93.368  -77.556  54.121  1
151627  93.384  -77.548  54.114  1
151628  93.401  -77.540  54.107  1
151629  93.416  -77.532  54.099  1
151630  93.432  -77.523  54.089  1
151631  93.448  -77.515  54.079  1
151632  93.464  -77.507  54.067  1
151633  93.480  -77.498  54.053  1
151634  93.494  -77.492  54.040  1
151635  93.507  -77.489  54.029  1
151636  93.520  -77.486  54.016  1
151637  93.534  -77.483  54.003  1
151638  93.548  -77.478  53.991  1
151639  93.566  -77.473  53.975  1
151640  93.580  -77.467  53.958  1
151641  93.587  -77.460  53.940  1
151642  93.593  -77.452  53.922  1
151643  93.600  -77.445  53.905  1
151644  93.606  -77.438  53.888  1
151645  93.613  -77.431  53.872  1
151646  93.626  -77.423  53.855  1
151647  93.641  -77.414  53.838  1
151648  93.662  -77.403  53.824  1
151649  93.684  -77.392  53.811  1
151650  93.709  -77.379  53.799  1
151651  93.735  -77.367  53.788  1
151652  93.761  -77.354  53.774  1
151653  93.786  -77.341  53.756  1
151654  93.811  -77.329  53.736  1
151655  93.827  -77.319  53.718  1
151656  93.843  -77.308  53.701  1
151657  93.853  -77.307  53.683  1
151658  93.855  -77.322  53.670  1
151659  93.866  -77.314  53.656  1
151660  93.886  -77.285  53.642  1
151661  93.893  -77.291  53.628  1
151662  93.901  -77.297  53.612  1
151663  93.909  -77.298  53.595  1
151664  93.918  -77.291  53.579  1
151665  93.927  -77.286  53.562  1
151666  93.942  -77.289  53.545  1
151667  93.959  -77.295  53.528  1
151668  93.976  -77.302  53.511  1
151669  93.993  -77.308  53.497  1
151670  94.010  -77.315  53.484  1
151671  94.023  -77.304  53.472  1
151672  94.031  -77.291  53.460  1
151673  94.037  -77.278  53.447  1
151674  94.067  -77.278  53.433  1
151675  94.096  -77.277  53.417  1
151676  94.126  -77.276  53.397  1
151677  94.155  -77.276  53.378  1
151678  94.185  -77.276  53.359  1
151679  94.214  -77.275  53.343  1
151680  94.243  -77.273  53.333  1
151681  94.263  -77.268  53.326  1
151682  94.282  -77.262  53.321  1
151683  94.298  -77.256  53.318  1
151684  94.298  -77.249  53.314  1
151685  94.299  -77.242  53.311  1
151686  94.300  -77.235  53.306  1
151687  94.301  -77.229  53.299  1
151688  94.302  -77.222  53.291  1
151689  94.303  -77.216  53.283  1
151690  94.302  -77.218  53.274  1
151691  94.302  -77.218  53.266  1
151692  94.309  -77.214  53.258  1
151693  94.310  -77.213  53.249  1
151694  94.311  -77.211  53.239  1
151695  94.312  -77.210  53.227  1
151696  94.312  -77.208  53.215  1
151697  94.317  -77.203  53.204  1
151698  94.330  -77.191  53.193  1
151699  94.343  -77.179  53.181  1
151700  94.356  -77.166  53.166  1
151701  94.378  -77.162  53.148  1
151702  94.401  -77.158  53.135  1
151703  94.423  -77.153  53.125  1
151704  94.445  -77.150  53.115  1
151705  94.467  -77.145  53.102  1
151706  94.487  -77.141  53.085  1
151707  94.507  -77.136  53.067  1
151708  94.527  -77.132  53.045  1
151709  94.547  -77.127  53.023  1
151710  94.567  -77.122  53.002  1
151711  94.588  -77.118  52.983  1
151712  94.608  -77.113  52.965  1
151713  94.624  -77.110  52.945  1
151714  94.634  -77.110  52.923  1
151715  94.643  -77.110  52.898  1
151716  94.655  -77.111  52.872  1
151717  94.669  -77.115  52.845  1
151718  94.682  -77.119  52.819  1
151719  94.695  -77.122  52.794  1
151720  94.709  -77.125  52.766  1
151721  94.722  -77.129  52.733  1
151722  94.735  -77.133  52.697  1
151723  94.751  -77.139  52.663  1
151724  94.769  -77.146  52.629  1
151725  94.788  -77.153  52.594  1
151726  94.807  -77.160  52.557  1
151727  94.826  -77.166  52.520  1
151728  94.845  -77.173  52.481  1
151729  94.864  -77.180  52.442  1
151730  94.883  -77.187  52.403  1
151731  94.902  -77.194  52.362  1
151732  94.918  -77.190  52.319  1
151733  94.934  -77.185  52.275  1
151734  94.951  -77.179  52.230  1
151735  94.967  -77.174  52.182  1
151736  94.983  -77.169  52.132  1
151737  95.000  -77.166  52.079  1
151738  95.022  -77.169  52.024  1
151739  95.042  -77.172  51.968  1
151740  95.065  -77.177  51.912  1
151741  95.089  -77.182  51.856  1
151742  95.113  -77.188  51.805  1
151743  95.137  -77.194  51.754  1
151744  95.161  -77.199  51.703  1
151745  95.175  -77.201  51.654  1
151746  95.189  -77.202  51.604  1
151747  95.202  -77.204  51.555  1
151748  95.217  -77.199  51.507  1
151749  95.234  -77.192  51.460  1
151750  95.250  -77.185  51.411  1
151751  95.265  -77.179  51.361  1
151752  95.281  -77.172  51.311  1
151753  95.298  -77.165  51.260  1
151754  95.313  -77.158  51.210  1
151755  95.329  -77.151  51.163  1
151756  95.345  -77.144  51.117  1
151757  95.366  -77.152  51.071  1
151758  95.388  -77.166  51.026  1
151759  95.410  -77.182  50.982  1
151760  95.432  -77.196  50.940  1
151761  95.450  -77.211  50.899  1
151762  95.468  -77.226  50.859  1
151763  95.485  -77.240  50.818  1
151764  95.503  -77.255  50.776  1
151765  95.521  -77.269  50.734  1
151766  95.539  -77.285  50.693  1
151767  95.561  -77.304  50.657  1
151768  95.585  -77.325  50.620  1
151769  95.608  -77.345  50.582  1
151770  95.631  -77.365  50.543  1
151771  95.655  -77.385  50.506  1
151772  95.673  -77.404  50.470  1
151773  95.689  -77.420  50.433  1
151774  95.706  -77.437  50.397  1
151775  95.722  -77.454  50.360  1
151776  95.738  -77.470  50.324  1
151777  95.755  -77.487  50.288  1
151778  95.771  -77.504  50.252  1
151779  95.788  -77.518  50.215  1
151780  95.804  -77.530  50.176  1
151781  95.820  -77.537  50.136  1
151782  95.836  -77.539  50.093  1
151783  95.852  -77.541  50.047  1
151784  95.868  -77.543  49.997  1
151785  95.884  -77.545  49.942  1
151786  95.900  -77.548  49.886  1
151787  95.916  -77.550  49.831  1
151788  95.933  -77.552  49.778  1
151789  95.949  -77.555  49.729  1
151790  95.965  -77.557  49.682  1
151791  95.980  -77.561  49.638  1
151792  95.990  -77.563  49.596  1
151793  96.000  -77.562  49.555  1
151794  96.010  -77.561  49.515  1
151795  96.020  -77.561  49.475  1
151796  96.029  -77.561  49.435  1
151797  96.038  -77.560  49.397  1
151798  96.047  -77.560  49.361  1
151799  96.057  -77.560  49.327  1
151800  96.066  -77.560  49.298  1
151801  96.076  -77.558  49.267  1
151802  96.092  -77.534  49.237  1
151803  96.103  -77.534  49.208  1
151804  96.096  -77.572  49.182  1
151805  96.091  -77.598  49.159  1
151806  96.088  -77.609  49.136  1
151807  96.091  -77.606  49.112  1
151808  96.096  -77.598  49.090  1
151809  96.098  -77.601  49.069  1
151810  96.094  -77.626  49.049  1
151811  96.107  -77.627  49.025  1
151812  96.122  -77.627  48.999  1
151813  96.137  -77.628  48.971  1
151814  96.152  -77.628  48.941  1
151815  96.167  -77.629  48.911  1
151816  96.180  -77.640  48.880  1
151817  96.194  -77.652  48.848  1
151818  96.208  -77.663  48.821  1
151819  96.222  -77.673  48.792  1
151820  96.234  -77.682  48.761  1
151821  96.247  -77.690  48.731  1
151822  96.257  -77.700  48.703  1
151823  96.263  -77.710  48.674  1
151824  96.268  -77.720  48.647  1
151825  96.274  -77.730  48.623  1
151826  96.287  -77.737  48.598  1
151827  96.307  -77.743  48.574  1
151828  96.326  -77.748  48.549  1
151829  96.346  -77.753  48.525  1
151830  96.367  -77.758  48.501  1
151831  96.393  -77.756  48.477  1
151832  96.419  -77.755  48.456  1
151833  96.447  -77.752  48.434  1
151834  96.470  -77.752  48.413  1
151835  96.479  -77.755  48.391  1
151836  96.487  -77.760  48.369  1
151837  96.497  -77.764  48.349  1
151838  96.505  -77.768  48.329  1
151839  96.514  -77.772  48.309  1
151840  96.523  -77.776  48.287  1
151841  96.534  -77.780  48.266  1
151842  96.543  -77.782  48.245  1
151843  96.552  -77.788  48.223  1
151844  96.562  -77.794  48.200  1
151845  96.572  -77.801  48.177  1
151846  96.581  -77.808  48.154  1
151847  96.591  -77.814  48.131  1
151848  96.600  -77.821  48.107  1
151849  96.612  -77.825  48.082  1
151850  96.627  -77.815  48.058  1
151851  96.642  -77.802  48.032  1
151852  96.657  -77.790  48.006  1
151853  96.672  -77.778  47.980  1
151854  96.687  -77.766  47.953  1
151855  96.702  -77.754  47.927  1
151856  96.717  -77.742  47.901  1
151857  96.734  -77.736  47.874  1
151858  96.756  -77.746  47.849  1
151859  96.778  -77.757  47.823  1
151860  96.800  -77.767  47.798  1
151861  96.822  -77.777  47.774  1
151862  96.844  -77.787  47.750  1
151863  96.866  -77.798  47.725  1
151864  96.888  -77.810  47.701  1
151865  96.910  -77.822  47.678  1
151866  96.933  -77.835  47.655  1
151867  96.954  -77.847  47.632  1
151868  96.962  -77.850  47.610  1
151869  96.971  -77.843  47.587  1
151870  96.979  -77.837  47.565  1
151871  96.990  -77.834  47.544  1
151872  97.001  -77.832  47.523  1
151873  97.011  -77.830  47.502  1
151874  97.022  -77.827  47.482  1
151875  97.033  -77.825  47.461  1
151876  97.044  -77.824  47.442  1
151877  97.058  -77.824  47.423  1
151878  97.071  -77.823  47.406  1
151879  97.085  -77.823  47.389  1
151880  97.098  -77.822  47.372  1
151881  97.115  -77.825  47.355  1
151882  97.147  -77.837  47.336  1
151883  97.178  -77.849  47.318  1
151884  97.209  -77.862  47.298  1
151885  97.241  -77.874  47.279  1
151886  97.272  -77.886  47.261  1
151887  97.303  -77.898  47.244  1
151888  97.327  -77.898  47.226  1
151889  97.350  -77.897  47.210  1
151890  97.373  -77.896  47.193  1
151891  97.396  -77.895  47.177  1
151892  97.406  -77.899  47.161  1
151893  97.415  -77.910  47.144  1
151894  97.428  -77.930  47.123  1
151895  97.440  -77.949  47.105  1
151896  97.453  -77.970  47.087  1
151897  97.466  -77.988  47.068  1
151898  97.481  -78.002  47.050  1
151899  97.498  -78.012  47.032  1
151900  97.517  -78.015  47.013  1
151901  97.538  -78.037  46.993  1
151902  97.555  -78.059  46.974  1
151903  97.568  -78.074  46.954  1
151904  97.581  -78.088  46.933  1
151905  97.595  -78.103  46.912  1
151906  97.605  -78.115  46.892  1
151907  97.604  -78.116  46.872  1
151908  97.604  -78.116  46.852  1
151909  97.609  -78.125  46.833  1
151910  97.631  -78.152  46.814  1
151911  97.653  -78.180  46.795  1
151912  97.677  -78.203  46.777  1
151913  97.713  -78.209  46.759  1
151914  97.747  -78.214  46.739  1
151915  97.776  -78.221  46.719  1
151916  97.804  -78.228  46.697  1
151917  97.832  -78.235  46.674  1
151918  97.860  -78.242  46.652  1
151919  97.884  -78.244  46.631  1
151920  97.933  -78.234  46.609  1
151921  97.997  -78.222  46.586  1
151922  98.060  -78.212  46.563  1
151923  98.121  -78.200  46.540  1
151924  98.143  -78.189  46.517  1
151925  98.164  -78.178  46.493  1
151926  98.185  -78.166  46.469  1
151927  98.206  -78.154  46.446  1
151928  98.217  -78.145  46.423  1
151929  98.247  -78.147  46.399  1
151930  98.277  -78.148  46.376  1
151931  98.307  -78.150  46.351  1
151932  98.337  -78.151  46.327  1
151933  98.367  -78.153  46.304  1
151934  98.396  -78.154  46.280  1
151935  98.426  -78.156  46.257  1
151936  98.456  -78.157  46.235  1
151937  98.486  -78.159  46.212  1
151938  98.519  -78.154  46.190  1
151939  98.556  -78.140  46.167  1
151940  98.592  -78.125  46.144  1
151941  98.617  -78.137  46.121  1
151942  98.613  -78.147  46.099  1
151943  98.600  -78.142  46.077  1
151944  98.587  -78.138  46.055  1
151945  98.574  -78.134  46.033  1
151946  98.561  -78.129  46.013  1
151947  98.548  -78.125  45.992  1
151948  98.544  -78.128  45.970  1
151949  98.545  -78.135  45.951  1
151950  98.546  -78.142  45.931  1
151951  98.567  -78.150  45.912  1
151952  98.620  -78.157  45.893  1
151953  98.673  -78.166  45.875  1
151954  98.725  -78.173  45.858  1
151955  98.778  -78.181  45.840  1
151956  98.822  -78.188  45.825  1
151957  98.866  -78.196  45.810  1
151958  98.909  -78.203  45.796  1
151959  98.952  -78.210  45.781  1
151960  98.995  -78.217  45.766  1
151961  99.030  -78.218  45.751  1
151962  99.059  -78.216  45.736  1
151963  99.086  -78.228  45.722  1
151964  99.113  -78.243  45.707  1
151965  99.127  -78.252  45.693  1
151966  99.120  -78.253  45.679  1
151967  99.118  -78.253  45.667  1
151968  99.140  -78.256  45.654  1
151969  99.162  -78.259  45.642  1
151970  99.185  -78.261  45.630  1
151971  99.207  -78.264  45.618  1
151972  99.229  -78.267  45.605  1
151973  99.252  -78.269  45.593  1
151974  99.279  -78.275  45.581  1
151975  99.311  -78.282  45.567  1
151976  99.343  -78.291  45.554  1
151977  99.376  -78.298  45.544  1
151978  99.408  -78.307  45.531  1
151979  99.440  -78.314  45.520  1
151980  99.473  -78.322  45.509  1
151981  99.505  -78.330  45.496  1
151982  99.538  -78.338  45.484  1
151983  99.564  -78.348  45.472  1
151984  99.551  -78.376  45.460  1
151985  99.537  -78.402  45.448  1
151986  99.524  -78.429  45.435  1
151987  99.523  -78.454  45.424  1
151988  99.571  -78.468  45.413  1
151989  99.655  -78.473  45.402  1
151990  99.739  -78.479  45.390  1
151991  99.817  -78.487  45.379  1
151992  99.849  -78.515  45.367  1
151993  99.882  -78.529  45.355  1
151994  99.909  -78.539  45.343  1
151995  99.937  -78.548  45.331  1
151996  99.964  -78.558  45.319  1
151997  99.991  -78.568  45.305  1
151998  100.018  -78.578  45.292  1
151999  100.046  -78.588  45.279  1
152000  100.073  -78.597  45.265  1
152001  100.101  -78.607  45.252  1
152002  100.128  -78.617  45.240  1
152003  100.147  -78.625  45.229  1
152004  100.156  -78.632  45.215  1
152005  100.186  -78.644  45.200  1
152006  100.210  -78.658  45.183  1
152007  100.228  -78.669  45.168  1
152008  100.246  -78.681  45.151  1
152009  100.264  -78.692  45.134  1
152010  100.282  -78.704  45.116  1
152011  100.300  -78.716  45.098  1
152012  100.319  -78.727  45.081  1
152013  100.338  -78.739  45.064  1
152014  100.357  -78.750  45.048  1
152015  100.376  -78.761  45.030  1
152016  100.395  -78.773  45.013  1
152017  100.414  -78.785  44.997  1
152018  100.433  -78.796  44.980  1
152019  100.452  -78.808  44.963  1
152020  100.471  -78.818  44.947  1
152021  100.492  -78.825  44.931  1
152022  100.512  -78.833  44.914  1
152023  100.528  -78.851  44.898  1
152024  100.545  -78.868  44.882  1
152025  100.561  -78.884  44.865  1
152026  100.574  -78.904  44.848  1
152027  100.579  -78.930  44.831  1
152028  100.584  -78.957  44.815  1
152029  100.588  -78.983  44.798  1
152030  100.594  -79.009  44.780  1
152031  100.610  -79.034  44.763  1
152032  100.628  -79.060  44.747  1
152033  100.650  -79.068  44.730  1
152034  100.680  -79.049  44.713  1
152035  100.740  -79.043  44.696  1
152036  100.798  -79.042  44.679  1
152037  100.850  -79.049  44.663  1
152038  100.902  -79.055  44.647  1
152039  100.954  -79.061  44.631  1
152040  101.006  -79.067  44.617  1
152041  101.058  -79.073  44.602  1
152042  101.110  -79.080  44.587  1
152043  101.162  -79.086  44.573  1
152044  101.214  -79.092  44.558  1
152045  101.266  -79.098  44.544  1
152046  101.293  -79.111  44.532  1
152047  101.318  -79.125  44.518  1
152048  101.342  -79.138  44.505  1
152049  101.367  -79.152  44.492  1
152050  101.391  -79.165  44.478  1
152281  92.615  -77.727  54.205  1
152282  92.635  -77.733  54.204  1
152283  92.655  -77.741  54.203  1
152284  92.675  -77.749  54.201  1
152285  92.695  -77.756  54.201  1
152286  92.715  -77.763  54.199  1
152287  92.735  -77.771  54.199  1
152288  92.755  -77.778  54.198  1
152289  92.775  -77.785  54.197  1
152290  92.795  -77.793  54.196  1
152291  92.815  -77.800  54.197  1
152292  92.835  -77.807  54.197  1
152293  92.855  -77.815  54.196  1
152294  92.875  -77.822  54.197  1
152295  92.895  -77.829  54.198  1
152296  92.915  -77.837  54.200  1
152297  92.939  -77.834  54.201  1
152298  92.959  -77.826  54.203  1
152299  92.977  -77.821  54.204  1
152300  92.993  -77.815  54.206  1
152301  93.010  -77.810  54.208  1
152302  93.027  -77.805  54.211  1
152303  93.044  -77.799  54.216  1
152304  93.061  -77.794  54.223  1
152305  93.078  -77.789  54.229  1
152306  93.092  -77.780  54.233  1
152307  93.105  -77.774  54.234  1
152308  93.116  -77.762  54.232  1
152309  93.128  -77.749  54.230  1
152310  93.139  -77.736  54.228  1
152311  93.151  -77.724  54.226  1
152312  93.162  -77.711  54.221  1
152313  93.174  -77.699  54.216  1
152314  93.186  -77.686  54.212  1
152315  93.198  -77.673  54.208  1
152316  93.209  -77.660  54.205  1
152317  93.221  -77.647  54.201  1
152318  93.232  -77.634  54.198  1
152319  93.245  -77.622  54.193  1
152320  93.258  -77.610  54.187  1
152321  93.271  -77.597  54.181  1
152322  93.284  -77.585  54.174  1
152323  93.297  -77.576  54.166  1
152324  93.311  -77.566  54.158  1
152325  93.326  -77.556  54.151  1
152326  93.341  -77.548  54.142  1
152327  93.357  -77.541  54.134  1
152328  93.373  -77.533  54.127  1
152329  93.389  -77.524  54.120  1
152330  93.405  -77.516  54.112  1
152331  93.421  -77.507  54.103  1
152332  93.437  -77.498  54.093  1
152333  93.452  -77.490  54.080  1
152334  93.469  -77.482  54.067  1
152335  93.484  -77.474  54.054  1
152336  93.497  -77.471  54.041  1
152337  93.510  -77.467  54.028  1
152338  93.523  -77.464  54.016  1
152339  93.539  -77.459  54.004  1
152340  93.557  -77.454  53.991  1
152341  93.574  -77.448  53.975  1
152342  93.584  -77.442  53.958  1
152343  93.590  -77.434  53.942  1
152344  93.597  -77.427  53.926  1
152345  93.604  -77.420  53.910  1
152346  93.615  -77.412  53.894  1
152347  93.630  -77.403  53.877  1
152348  93.645  -77.394  53.862  1
152349  93.663  -77.385  53.848  1
152350  93.685  -77.373  53.835  1
152351  93.706  -77.363  53.822  1
152352  93.728  -77.351  53.810  1
152353  93.753  -77.339  53.797  1
152354  93.779  -77.326  53.779  1
152355  93.804  -77.314  53.760  1
152356  93.826  -77.302  53.741  1
152357  93.842  -77.291  53.722  1
152358  93.850  -77.294  53.703  1
152359  93.852  -77.310  53.689  1
152360  93.861  -77.308  53.675  1
152361  93.877  -77.288  53.660  1
152362  93.885  -77.294  53.646  1
152363  93.893  -77.295  53.631  1
152364  93.902  -77.289  53.616  1
152365  93.911  -77.284  53.600  1
152366  93.920  -77.279  53.583  1
152367  93.934  -77.281  53.565  1
152368  93.952  -77.287  53.547  1
152369  93.969  -77.293  53.530  1
152370  93.986  -77.300  53.515  1
152371  94.000  -77.294  53.502  1
152372  94.011  -77.282  53.489  1
152373  94.020  -77.269  53.479  1
152374  94.036  -77.260  53.467  1
152375  94.066  -77.260  53.453  1
152376  94.096  -77.260  53.438  1
152377  94.125  -77.259  53.421  1
152378  94.154  -77.258  53.402  1
152379  94.184  -77.257  53.383  1
152380  94.214  -77.257  53.367  1
152381  94.243  -77.257  53.357  1
152382  94.268  -77.254  53.351  1
152383  94.287  -77.248  53.347  1
152384  94.302  -77.241  53.346  1
152385  94.303  -77.235  53.346  1
152386  94.305  -77.228  53.344  1
152387  94.306  -77.221  53.341  1
152388  94.307  -77.214  53.335  1
152389  94.307  -77.207  53.329  1
152390  94.308  -77.200  53.322  1
152391  94.309  -77.194  53.316  1
152392  94.309  -77.194  53.309  1
152393  94.312  -77.192  53.302  1
152394  94.313  -77.191  53.294  1
152395  94.314  -77.189  53.282  1
152396  94.315  -77.188  53.270  1
152397  94.316  -77.186  53.258  1
152398  94.317  -77.185  53.247  1
152399  94.328  -77.174  53.235  1
152400  94.340  -77.161  53.222  1
152401  94.354  -77.150  53.206  1
152402  94.377  -77.146  53.187  1
152403  94.399  -77.141  53.172  1
152404  94.422  -77.138  53.160  1
152405  94.443  -77.134  53.150  1
152406  94.464  -77.129  53.136  1
152407  94.483  -77.124  53.120  1
152408  94.503  -77.119  53.101  1
152409  94.524  -77.115  53.079  1
152410  94.544  -77.110  53.057  1
152411  94.564  -77.106  53.036  1
152412  94.584  -77.101  53.015  1
152413  94.604  -77.097  52.996  1
152414  94.623  -77.093  52.976  1
152415  94.633  -77.092  52.954  1
152416  94.643  -77.093  52.929  1
152417  94.657  -77.097  52.903  1
152418  94.670  -77.100  52.877  1
152419  94.683  -77.103  52.850  1
152420  94.697  -77.107  52.823  1
152421  94.710  -77.111  52.793  1
152422  94.722  -77.113  52.759  1
152423  94.735  -77.116  52.721  1
152424  94.757  -77.119  52.682  1
152425  94.773  -77.125  52.643  1
152426  94.792  -77.132  52.604  1
152427  94.811  -77.138  52.565  1
152428  94.830  -77.145  52.526  1
152429  94.849  -77.152  52.487  1
152430  94.867  -77.159  52.449  1
152431  94.887  -77.166  52.410  1
152432  94.906  -77.172  52.368  1
152433  94.922  -77.171  52.326  1
152434  94.938  -77.166  52.283  1
152435  94.955  -77.160  52.236  1
152436  94.971  -77.154  52.186  1
152437  94.987  -77.149  52.134  1
152438  95.007  -77.150  52.079  1
152439  95.028  -77.153  52.025  1
152440  95.049  -77.157  51.972  1
152441  95.069  -77.160  51.919  1
152442  95.091  -77.163  51.868  1
152443  95.114  -77.168  51.824  1
152444  95.138  -77.173  51.780  1
152445  95.162  -77.179  51.735  1
152446  95.177  -77.181  51.687  1
152447  95.190  -77.182  51.638  1
152448  95.204  -77.183  51.588  1
152449  95.217  -77.185  51.537  1
152450  95.233  -77.179  51.488  1
152451  95.249  -77.172  51.439  1
152452  95.265  -77.165  51.390  1
152453  95.281  -77.158  51.339  1
152454  95.297  -77.151  51.287  1
152455  95.313  -77.144  51.237  1
152456  95.329  -77.138  51.190  1
152457  95.346  -77.136  51.143  1
152458  95.369  -77.151  51.097  1
152459  95.391  -77.166  51.052  1
152460  95.413  -77.181  51.008  1
152461  95.435  -77.195  50.966  1
152462  95.453  -77.210  50.924  1
152463  95.471  -77.225  50.883  1
152464  95.489  -77.239  50.840  1
152465  95.507  -77.254  50.797  1
152466  95.524  -77.269  50.755  1
152467  95.542  -77.284  50.716  1
152468  95.560  -77.298  50.681  1
152469  95.582  -77.317  50.643  1
152470  95.605  -77.338  50.604  1
152471  95.628  -77.358  50.561  1
152472  95.652  -77.379  50.521  1
152473  95.671  -77.397  50.482  1
152474  95.687  -77.414  50.443  1
152475  95.703  -77.430  50.406  1
152476  95.720  -77.447  50.369  1
152477  95.736  -77.464  50.333  1
152478  95.752  -77.480  50.299  1
152479  95.769  -77.497  50.266  1
152480  95.785  -77.514  50.231  1
152481  95.801  -77.530  50.194  1
152482  95.818  -77.539  50.154  1
152483  95.835  -77.540  50.110  1
152484  95.851  -77.542  50.064  1
152485  95.868  -77.544  50.014  1
152486  95.885  -77.546  49.959  1
152487  95.901  -77.548  49.904  1
152488  95.918  -77.550  49.849  1
152489  95.935  -77.552  49.796  1
152490  95.952  -77.554  49.745  1
152491  95.968  -77.556  49.697  1
152492  95.983  -77.556  49.651  1
152493  95.993  -77.558  49.608  1
152494  96.002  -77.558  49.566  1
152495  96.012  -77.558  49.524  1
152496  96.021  -77.558  49.483  1
152497  96.030  -77.558  49.442  1
152498  96.039  -77.558  49.403  1
152499  96.049  -77.558  49.367  1
152500  96.058  -77.558  49.332  1
152501  96.067  -77.558  49.301  1
152502  96.078  -77.555  49.269  1
152503  96.094  -77.527  49.238  1
152504  96.105  -77.511  49.207  1
152505  96.098  -77.551  49.181  1
152506  96.093  -77.582  49.156  1
152507  96.097  -77.573  49.131  1
152508  96.102  -77.565  49.108  1
152509  96.107  -77.557  49.087  1
152510  96.105  -77.574  49.067  1
152511  96.101  -77.599  49.048  1
152512  96.109  -77.609  49.026  1
152513  96.124  -77.609  49.002  1
152514  96.138  -77.609  48.976  1
152515  96.154  -77.610  48.948  1
152516  96.168  -77.616  48.920  1
152517  96.182  -77.627  48.890  1
152518  96.195  -77.639  48.859  1
152519  96.209  -77.650  48.831  1
152520  96.223  -77.661  48.802  1
152521  96.236  -77.670  48.771  1
152522  96.249  -77.679  48.743  1
152523  96.261  -77.687  48.715  1
152524  96.274  -77.696  48.688  1
152525  96.281  -77.706  48.662  1
152526  96.289  -77.715  48.637  1
152527  96.309  -77.721  48.613  1
152528  96.329  -77.725  48.588  1
152529  96.349  -77.730  48.564  1
152530  96.369  -77.736  48.539  1
152531  96.389  -77.741  48.515  1
152532  96.409  -77.746  48.492  1
152533  96.432  -77.748  48.471  1
152534  96.459  -77.746  48.450  1
152535  96.474  -77.748  48.429  1
152536  96.483  -77.752  48.408  1
152537  96.492  -77.756  48.387  1
152538  96.502  -77.760  48.368  1
152539  96.514  -77.763  48.348  1
152540  96.525  -77.767  48.328  1
152541  96.536  -77.770  48.307  1
152542  96.546  -77.773  48.286  1
152543  96.553  -77.774  48.264  1
152544  96.561  -77.777  48.241  1
152545  96.571  -77.784  48.217  1
152546  96.580  -77.791  48.195  1
152547  96.590  -77.797  48.172  1
152548  96.600  -77.804  48.150  1
152549  96.609  -77.810  48.127  1
152550  96.620  -77.815  48.103  1
152551  96.635  -77.818  48.078  1
152552  96.650  -77.811  48.052  1
152553  96.664  -77.799  48.026  1
152554  96.679  -77.787  48.001  1
152555  96.694  -77.774  47.974  1
152556  96.710  -77.762  47.947  1
152557  96.724  -77.750  47.921  1
152558  96.739  -77.738  47.895  1
152559  96.759  -77.743  47.870  1
152560  96.782  -77.753  47.845  1
152561  96.804  -77.763  47.819  1
152562  96.826  -77.774  47.795  1
152563  96.848  -77.783  47.771  1
152564  96.870  -77.794  47.747  1
152565  96.892  -77.805  47.722  1
152566  96.914  -77.815  47.699  1
152567  96.936  -77.825  47.676  1
152568  96.958  -77.838  47.653  1
152569  96.968  -77.837  47.631  1
152570  96.979  -77.834  47.607  1
152571  96.990  -77.832  47.585  1
152572  97.001  -77.830  47.564  1
152573  97.011  -77.827  47.543  1
152574  97.022  -77.826  47.522  1
152575  97.033  -77.824  47.502  1
152576  97.044  -77.821  47.481  1
152577  97.055  -77.820  47.461  1
152578  97.069  -77.819  47.443  1
152579  97.082  -77.819  47.425  1
152580  97.095  -77.818  47.408  1
152581  97.113  -77.821  47.390  1
152582  97.133  -77.826  47.372  1
152583  97.164  -77.837  47.354  1
152584  97.195  -77.849  47.334  1
152585  97.227  -77.862  47.315  1
152586  97.258  -77.874  47.297  1
152587  97.288  -77.884  47.279  1
152588  97.311  -77.883  47.261  1
152589  97.334  -77.882  47.244  1
152590  97.357  -77.881  47.228  1
152591  97.380  -77.879  47.211  1
152592  97.403  -77.878  47.194  1
152593  97.415  -77.882  47.178  1
152594  97.425  -77.894  47.160  1
152595  97.437  -77.914  47.139  1
152596  97.450  -77.934  47.121  1
152597  97.463  -77.953  47.103  1
152598  97.478  -77.967  47.084  1
152599  97.494  -77.981  47.065  1
152600  97.509  -77.993  47.046  1
152601  97.524  -78.007  47.026  1
152602  97.542  -78.014  47.006  1
152603  97.563  -78.034  46.985  1
152604  97.577  -78.051  46.964  1
152605  97.591  -78.065  46.943  1
152606  97.604  -78.080  46.922  1
152607  97.605  -78.083  46.902  1
152608  97.605  -78.084  46.882  1
152609  97.604  -78.084  46.861  1
152610  97.607  -78.100  46.841  1
152611  97.629  -78.125  46.821  1
152612  97.650  -78.150  46.801  1
152613  97.671  -78.175  46.783  1
152614  97.691  -78.197  46.765  1
152615  97.720  -78.203  46.745  1
152616  97.748  -78.210  46.724  1
152617  97.776  -78.218  46.703  1
152618  97.804  -78.225  46.682  1
152619  97.832  -78.232  46.661  1
152620  97.860  -78.229  46.641  1
152621  97.923  -78.218  46.619  1
152622  97.986  -78.207  46.596  1
152623  98.050  -78.196  46.572  1
152624  98.112  -78.185  46.550  1
152625  98.135  -78.174  46.527  1
152626  98.156  -78.162  46.504  1
152627  98.177  -78.150  46.480  1
152628  98.188  -78.138  46.456  1
152629  98.218  -78.139  46.433  1
152630  98.248  -78.141  46.410  1
152631  98.278  -78.142  46.386  1
152632  98.307  -78.144  46.361  1
152633  98.338  -78.145  46.338  1
152634  98.367  -78.147  46.314  1
152635  98.397  -78.148  46.291  1
152636  98.427  -78.150  46.268  1
152637  98.461  -78.141  46.246  1
152638  98.498  -78.125  46.222  1
152639  98.535  -78.111  46.199  1
152640  98.572  -78.097  46.176  1
152641  98.608  -78.082  46.154  1
152642  98.624  -78.113  46.131  1
152643  98.625  -78.131  46.110  1
152644  98.612  -78.127  46.089  1
152645  98.599  -78.122  46.068  1
152646  98.586  -78.118  46.046  1
152647  98.573  -78.113  46.025  1
152648  98.561  -78.109  46.004  1
152649  98.562  -78.116  45.981  1
152650  98.562  -78.124  45.962  1
152651  98.563  -78.131  45.943  1
152652  98.564  -78.138  45.924  1
152653  98.608  -78.146  45.906  1
152654  98.661  -78.153  45.888  1
152655  98.714  -78.162  45.870  1
152656  98.767  -78.169  45.853  1
152657  98.819  -78.178  45.836  1
152658  98.872  -78.185  45.821  1
152659  98.915  -78.192  45.806  1
152660  98.958  -78.200  45.792  1
152661  99.002  -78.206  45.776  1
152662  99.045  -78.214  45.761  1
152663  99.076  -78.213  45.746  1
152664  99.104  -78.218  45.732  1
152665  99.131  -78.233  45.718  1
152666  99.141  -78.241  45.703  1
152667  99.134  -78.241  45.688  1
152668  99.128  -78.241  45.675  1
152669  99.148  -78.244  45.663  1
152670  99.170  -78.247  45.651  1
152671  99.192  -78.249  45.639  1
152672  99.215  -78.252  45.627  1
152673  99.237  -78.255  45.615  1
152674  99.259  -78.257  45.603  1
152675  99.282  -78.260  45.591  1
152676  99.306  -78.264  45.578  1
152677  99.339  -78.272  45.565  1
152678  99.371  -78.280  45.554  1
152679  99.403  -78.288  45.542  1
152680  99.436  -78.296  45.531  1
152681  99.468  -78.304  45.520  1
152682  99.500  -78.311  45.508  1
152683  99.533  -78.319  45.496  1
152684  99.536  -78.340  45.483  1
152685  99.522  -78.366  45.471  1
152686  99.509  -78.394  45.460  1
152687  99.517  -78.417  45.448  1
152688  99.547  -78.436  45.436  1
152689  99.575  -78.455  45.425  1
152690  99.642  -78.462  45.414  1
152691  99.726  -78.468  45.403  1
152692  99.802  -78.476  45.391  1
152693  99.835  -78.505  45.379  1
152694  99.867  -78.529  45.367  1
152695  99.897  -78.532  45.354  1
152696  99.924  -78.542  45.342  1
152697  99.951  -78.551  45.330  1
152698  99.979  -78.561  45.316  1
152699  100.006  -78.571  45.303  1
152700  100.033  -78.580  45.291  1
152701  100.060  -78.590  45.276  1
152702  100.088  -78.600  45.262  1
152703  100.115  -78.610  45.249  1
152704  100.142  -78.620  45.237  1
152705  100.170  -78.629  45.224  1
152706  100.192  -78.639  45.209  1
152707  100.210  -78.651  45.193  1
152708  100.229  -78.662  45.178  1
152709  100.249  -78.673  45.161  1
152710  100.267  -78.685  45.143  1
152711  100.286  -78.697  45.125  1
152712  100.305  -78.708  45.108  1
152713  100.324  -78.720  45.090  1
152714  100.343  -78.731  45.073  1
152715  100.362  -78.742  45.057  1
152716  100.381  -78.754  45.040  1
152717  100.400  -78.765  45.022  1
152718  100.419  -78.777  45.005  1
152719  100.438  -78.788  44.989  1
152720  100.457  -78.800  44.972  1
152721  100.477  -78.809  44.955  1
152722  100.498  -78.816  44.939  1
152723  100.519  -78.823  44.923  1
152724  100.538  -78.832  44.906  1
152725  100.555  -78.849  44.890  1
152726  100.571  -78.866  44.874  1
152727  100.579  -78.890  44.857  1
152728  100.584  -78.915  44.840  1
152729  100.590  -78.942  44.823  1
152730  100.594  -78.968  44.806  1
152731  100.599  -78.994  44.789  1
152732  100.604  -79.021  44.772  1
152733  100.623  -79.040  44.755  1
152734  100.648  -79.037  44.739  1
152735  100.673  -79.034  44.722  1
152736  100.701  -79.046  44.705  1
152737  100.793  -79.037  44.688  1
152738  100.855  -79.032  44.672  1
152739  100.907  -79.038  44.656  1
152740  100.960  -79.044  44.640  1
152741  101.011  -79.050  44.625  1
152742  101.063  -79.057  44.611  1
152743  101.116  -79.063  44.596  1
152744  101.168  -79.069  44.581  1
152745  101.219  -79.075  44.566  1
152746  101.268  -79.083  44.552  1
152747  101.292  -79.096  44.539  1
152748  101.317  -79.109  44.526  1
152749  101.341  -79.123  44.513  1
152750  101.365  -79.137  44.500  1
152751  101.390  -79.150  44.487  1
152752  101.412  -79.169  44.474  1
152981  92.584  -77.699  54.200  1
152982  92.604  -77.706  54.199  1
152983  92.624  -77.714  54.199  1
152984  92.644  -77.721  54.198  1
152985  92.664  -77.728  54.197  1
152986  92.684  -77.736  54.198  1
152987  92.704  -77.743  54.197  1
152988  92.724  -77.751  54.196  1
152989  92.744  -77.758  54.196  1
152990  92.764  -77.765  54.195  1
152991  92.784  -77.773  54.195  1
152992  92.804  -77.780  54.195  1
152993  92.824  -77.787  54.195  1
152994  92.844  -77.795  54.195  1
152995  92.864  -77.802  54.196  1
152996  92.883  -77.809  54.198  1
152997  92.904  -77.817  54.201  1
152998  92.928  -77.813  54.202  1
152999  92.950  -77.805  54.203  1
153000  92.967  -77.799  54.205  1
153001  92.984  -77.794  54.208  1
153002  93.000  -77.790  54.210  1
153003  93.017  -77.784  54.214  1
153004  93.034  -77.779  54.219  1
153005  93.051  -77.774  54.226  1
153006  93.066  -77.766  54.233  1
153007  93.079  -77.757  54.238  1
153008  93.092  -77.749  54.238  1
153009  93.105  -77.743  54.236  1
153010  93.117  -77.736  54.234  1
153011  93.129  -77.727  54.232  1
153012  93.141  -77.714  54.230  1
153013  93.152  -77.701  54.227  1
153014  93.164  -77.688  54.223  1
153015  93.176  -77.675  54.220  1
153016  93.187  -77.662  54.217  1
153017  93.199  -77.650  54.215  1
153018  93.210  -77.637  54.212  1
153019  93.222  -77.624  54.211  1
153020  93.235  -77.612  54.206  1
153021  93.248  -77.599  54.201  1
153022  93.261  -77.587  54.195  1
153023  93.274  -77.575  54.188  1
153024  93.287  -77.563  54.181  1
153025  93.300  -77.551  54.173  1
153026  93.314  -77.541  54.166  1
153027  93.330  -77.533  54.157  1
153028  93.346  -77.525  54.149  1
153029  93.362  -77.516  54.142  1
153030  93.377  -77.508  54.134  1
153031  93.394  -77.499  54.126  1
153032  93.409  -77.491  54.118  1
153033  93.425  -77.483  54.108  1
153034  93.441  -77.474  54.097  1
153035  93.457  -77.466  54.084  1
153036  93.473  -77.457  54.072  1
153037  93.487  -77.452  54.060  1
153038  93.500  -77.449  54.048  1
153039  93.513  -77.445  54.036  1
153040  93.530  -77.441  54.024  1
153041  93.547  -77.435  54.011  1
153042  93.565  -77.429  53.995  1
153043  93.581  -77.423  53.980  1
153044  93.587  -77.417  53.965  1
153045  93.594  -77.409  53.949  1
153046  93.604  -77.401  53.933  1
153047  93.619  -77.392  53.917  1
153048  93.635  -77.384  53.902  1
153049  93.650  -77.375  53.886  1
153050  93.665  -77.366  53.872  1
153051  93.685  -77.355  53.859  1
153052  93.707  -77.345  53.845  1
153053  93.729  -77.333  53.833  1
153054  93.751  -77.323  53.819  1
153055  93.773  -77.311  53.803  1
153056  93.796  -77.299  53.783  1
153057  93.822  -77.287  53.763  1
153058  93.841  -77.276  53.743  1
153059  93.847  -77.282  53.724  1
153060  93.849  -77.297  53.708  1
153061  93.856  -77.301  53.693  1
153062  93.868  -77.292  53.678  1
153063  93.876  -77.293  53.663  1
153064  93.886  -77.287  53.649  1
153065  93.895  -77.282  53.635  1
153066  93.904  -77.276  53.619  1
153067  93.913  -77.270  53.602  1
153068  93.927  -77.272  53.585  1
153069  93.944  -77.279  53.566  1
153070  93.961  -77.285  53.548  1
153071  93.977  -77.284  53.532  1
153072  93.988  -77.272  53.519  1
153073  94.000  -77.259  53.507  1
153074  94.010  -77.246  53.495  1
153075  94.035  -77.243  53.483  1
153076  94.065  -77.242  53.468  1
153077  94.095  -77.241  53.453  1
153078  94.124  -77.241  53.436  1
153079  94.153  -77.241  53.418  1
153080  94.183  -77.240  53.401  1
153081  94.213  -77.239  53.387  1
153082  94.242  -77.239  53.379  1
153083  94.272  -77.238  53.373  1
153084  94.292  -77.233  53.370  1
153085  94.308  -77.227  53.369  1
153086  94.309  -77.220  53.369  1
153087  94.310  -77.213  53.370  1
153088  94.310  -77.207  53.370  1
153089  94.311  -77.200  53.367  1
153090  94.312  -77.192  53.363  1
153091  94.313  -77.185  53.360  1
153092  94.314  -77.179  53.355  1
153093  94.315  -77.172  53.349  1
153094  94.316  -77.170  53.342  1
153095  94.317  -77.169  53.335  1
153096  94.317  -77.167  53.323  1
153097  94.318  -77.166  53.310  1
153098  94.319  -77.164  53.298  1
153099  94.320  -77.163  53.286  1
153100  94.325  -77.157  53.275  1
153101  94.338  -77.144  53.262  1
153102  94.353  -77.134  53.246  1
153103  94.375  -77.129  53.224  1
153104  94.398  -77.125  53.207  1
153105  94.420  -77.122  53.193  1
153106  94.439  -77.117  53.181  1
153107  94.460  -77.113  53.168  1
153108  94.480  -77.108  53.152  1
153109  94.500  -77.103  53.134  1
153110  94.520  -77.099  53.111  1
153111  94.540  -77.094  53.089  1
153112  94.560  -77.089  53.067  1
153113  94.580  -77.085  53.046  1
153114  94.601  -77.080  53.026  1
153115  94.621  -77.075  53.006  1
153116  94.632  -77.075  52.984  1
153117  94.645  -77.078  52.959  1
153118  94.658  -77.081  52.933  1
153119  94.671  -77.085  52.906  1
153120  94.684  -77.088  52.879  1
153121  94.696  -77.090  52.850  1
153122  94.709  -77.092  52.819  1
153123  94.721  -77.094  52.783  1
153124  94.734  -77.097  52.744  1
153125  94.762  -77.101  52.703  1
153126  94.780  -77.106  52.660  1
153127  94.796  -77.111  52.616  1
153128  94.815  -77.118  52.574  1
153129  94.834  -77.125  52.532  1
153130  94.853  -77.132  52.491  1
153131  94.872  -77.138  52.450  1
153132  94.891  -77.144  52.409  1
153133  94.909  -77.151  52.367  1
153134  94.927  -77.151  52.325  1
153135  94.943  -77.146  52.283  1
153136  94.959  -77.141  52.237  1
153137  94.975  -77.135  52.187  1
153138  94.992  -77.132  52.136  1
153139  95.013  -77.135  52.083  1
153140  95.034  -77.138  52.031  1
153141  95.055  -77.141  51.982  1
153142  95.075  -77.144  51.936  1
153143  95.097  -77.147  51.893  1
153144  95.117  -77.150  51.853  1
153145  95.139  -77.153  51.813  1
153146  95.163  -77.159  51.771  1
153147  95.178  -77.161  51.723  1
153148  95.191  -77.163  51.673  1
153149  95.205  -77.163  51.622  1
153150  95.218  -77.165  51.568  1
153151  95.233  -77.166  51.520  1
153152  95.248  -77.159  51.471  1
153153  95.264  -77.152  51.421  1
153154  95.280  -77.145  51.367  1
153155  95.297  -77.138  51.315  1
153156  95.312  -77.132  51.264  1
153157  95.328  -77.125  51.217  1
153158  95.349  -77.135  51.171  1
153159  95.372  -77.150  51.126  1
153160  95.394  -77.165  51.081  1
153161  95.416  -77.180  51.036  1
153162  95.438  -77.194  50.992  1
153163  95.457  -77.210  50.949  1
153164  95.474  -77.224  50.906  1
153165  95.492  -77.238  50.860  1
153166  95.510  -77.254  50.817  1
153167  95.528  -77.268  50.777  1
153168  95.545  -77.283  50.741  1
153169  95.563  -77.298  50.704  1
153170  95.581  -77.312  50.665  1
153171  95.602  -77.331  50.623  1
153172  95.626  -77.351  50.578  1
153173  95.649  -77.372  50.535  1
153174  95.669  -77.390  50.493  1
153175  95.685  -77.407  50.452  1
153176  95.701  -77.423  50.416  1
153177  95.718  -77.440  50.379  1
153178  95.734  -77.457  50.341  1
153179  95.750  -77.473  50.307  1
153180  95.766  -77.490  50.277  1
153181  95.783  -77.503  50.245  1
153182  95.801  -77.515  50.209  1
153183  95.822  -77.527  50.169  1
153184  95.843  -77.537  50.126  1
153185  95.860  -77.539  50.080  1
153186  95.876  -77.542  50.030  1
153187  95.893  -77.543  49.978  1
153188  95.910  -77.545  49.924  1
153189  95.926  -77.547  49.869  1
153190  95.943  -77.549  49.815  1
153191  95.960  -77.551  49.762  1
153192  95.975  -77.551  49.712  1
153193  95.986  -77.545  49.664  1
153194  95.996  -77.547  49.620  1
153195  96.004  -77.555  49.576  1
153196  96.013  -77.556  49.533  1
153197  96.022  -77.556  49.491  1
153198  96.032  -77.556  49.449  1
153199  96.041  -77.556  49.409  1
153200  96.050  -77.555  49.372  1
153201  96.059  -77.555  49.337  1
153202  96.069  -77.555  49.303  1
153203  96.079  -77.552  49.271  1
153204  96.096  -77.524  49.239  1
153205  96.106  -77.504  49.207  1
153206  96.114  -77.489  49.180  1
153207  96.110  -77.517  49.155  1
153208  96.109  -77.533  49.130  1
153209  96.113  -77.524  49.107  1
153210  96.116  -77.523  49.085  1
153211  96.113  -77.548  49.064  1
153212  96.109  -77.573  49.046  1
153213  96.111  -77.591  49.027  1
153214  96.125  -77.591  49.005  1
153215  96.141  -77.591  48.981  1
153216  96.155  -77.591  48.955  1
153217  96.169  -77.602  48.928  1
153218  96.183  -77.614  48.900  1
153219  96.197  -77.625  48.868  1
153220  96.210  -77.636  48.840  1
153221  96.225  -77.648  48.811  1
153222  96.238  -77.658  48.782  1
153223  96.250  -77.667  48.755  1
153224  96.263  -77.675  48.727  1
153225  96.276  -77.684  48.700  1
153226  96.289  -77.693  48.675  1
153227  96.310  -77.700  48.651  1
153228  96.330  -77.705  48.627  1
153229  96.350  -77.710  48.602  1
153230  96.371  -77.715  48.576  1
153231  96.391  -77.720  48.552  1
153232  96.411  -77.725  48.529  1
153233  96.431  -77.730  48.507  1
153234  96.451  -77.735  48.487  1
153235  96.471  -77.740  48.467  1
153236  96.482  -77.743  48.447  1
153237  96.493  -77.746  48.426  1
153238  96.505  -77.750  48.406  1
153239  96.516  -77.753  48.386  1
153240  96.527  -77.757  48.366  1
153241  96.539  -77.761  48.346  1
153242  96.549  -77.764  48.325  1
153243  96.556  -77.765  48.303  1
153244  96.563  -77.766  48.280  1
153245  96.570  -77.768  48.255  1
153246  96.579  -77.774  48.231  1
153247  96.589  -77.780  48.208  1
153248  96.599  -77.787  48.187  1
153249  96.608  -77.793  48.167  1
153250  96.618  -77.800  48.145  1
153251  96.629  -77.805  48.122  1
153252  96.643  -77.808  48.098  1
153253  96.657  -77.810  48.071  1
153254  96.672  -77.807  48.045  1
153255  96.687  -77.795  48.019  1
153256  96.702  -77.783  47.993  1
153257  96.717  -77.771  47.968  1
153258  96.732  -77.758  47.943  1
153259  96.747  -77.746  47.917  1
153260  96.763  -77.739  47.892  1
153261  96.785  -77.749  47.866  1
153262  96.807  -77.759  47.840  1
153263  96.829  -77.770  47.816  1
153264  96.852  -77.780  47.792  1
153265  96.874  -77.790  47.768  1
153266  96.896  -77.801  47.743  1
153267  96.918  -77.811  47.720  1
153268  96.940  -77.821  47.697  1
153269  96.962  -77.831  47.674  1
153270  96.977  -77.831  47.652  1
153271  96.990  -77.830  47.629  1
153272  97.001  -77.827  47.607  1
153273  97.011  -77.826  47.585  1
153274  97.022  -77.824  47.564  1
153275  97.033  -77.821  47.542  1
153276  97.044  -77.819  47.521  1
153277  97.054  -77.818  47.501  1
153278  97.066  -77.815  47.481  1
153279  97.079  -77.815  47.462  1
153280  97.093  -77.815  47.444  1
153281  97.110  -77.818  47.426  1
153282  97.131  -77.822  47.407  1
153283  97.151  -77.827  47.388  1
153284  97.181  -77.838  47.370  1
153285  97.213  -77.850  47.351  1
153286  97.244  -77.862  47.332  1
153287  97.272  -77.868  47.314  1
153288  97.295  -77.868  47.296  1
153289  97.317  -77.866  47.278  1
153290  97.341  -77.865  47.261  1
153291  97.363  -77.864  47.245  1
153292  97.386  -77.863  47.229  1
153293  97.409  -77.862  47.211  1
153294  97.424  -77.865  47.194  1
153295  97.434  -77.878  47.176  1
153296  97.447  -77.899  47.156  1
153297  97.460  -77.918  47.138  1
153298  97.475  -77.932  47.119  1
153299  97.490  -77.945  47.099  1
153300  97.506  -77.959  47.081  1
153301  97.521  -77.972  47.061  1
153302  97.536  -77.986  47.040  1
153303  97.551  -78.000  47.020  1
153304  97.567  -78.012  46.998  1
153305  97.586  -78.028  46.977  1
153306  97.600  -78.042  46.955  1
153307  97.606  -78.050  46.934  1
153308  97.606  -78.051  46.913  1
153309  97.606  -78.066  46.892  1
153310  97.607  -78.083  46.870  1
153311  97.610  -78.101  46.849  1
153312  97.631  -78.126  46.828  1
153313  97.652  -78.151  46.808  1
153314  97.673  -78.176  46.788  1
153315  97.703  -78.173  46.770  1
153316  97.737  -78.162  46.750  1
153317  97.720  -78.200  46.729  1
153318  97.748  -78.207  46.710  1
153319  97.777  -78.214  46.691  1
153320  97.805  -78.221  46.671  1
153321  97.850  -78.213  46.651  1
153322  97.913  -78.203  46.628  1
153323  97.976  -78.191  46.605  1
153324  98.039  -78.181  46.582  1
153325  98.102  -78.169  46.559  1
153326  98.128  -78.158  46.537  1
153327  98.149  -78.147  46.514  1
153328  98.162  -78.132  46.491  1
153329  98.189  -78.131  46.467  1
153330  98.219  -78.133  46.444  1
153331  98.248  -78.134  46.420  1
153332  98.278  -78.136  46.396  1
153333  98.308  -78.138  46.372  1
153334  98.338  -78.139  46.348  1
153335  98.368  -78.141  46.324  1
153336  98.405  -78.126  46.301  1
153337  98.441  -78.112  46.279  1
153338  98.478  -78.097  46.256  1
153339  98.514  -78.083  46.233  1
153340  98.551  -78.069  46.207  1
153341  98.588  -78.053  46.185  1
153342  98.618  -78.053  46.164  1
153343  98.631  -78.089  46.142  1
153344  98.637  -78.115  46.121  1
153345  98.624  -78.111  46.100  1
153346  98.611  -78.106  46.080  1
153347  98.598  -78.102  46.058  1
153348  98.585  -78.098  46.037  1
153349  98.578  -78.098  46.015  1
153350  98.579  -78.106  45.993  1
153351  98.580  -78.112  45.974  1
153352  98.581  -78.119  45.955  1
153353  98.581  -78.127  45.936  1
153354  98.597  -78.134  45.918  1
153355  98.650  -78.142  45.899  1
153356  98.703  -78.150  45.881  1
153357  98.756  -78.158  45.864  1
153358  98.808  -78.166  45.847  1
153359  98.861  -78.174  45.831  1
153360  98.913  -78.181  45.816  1
153361  98.964  -78.189  45.801  1
153362  99.008  -78.197  45.785  1
153363  99.051  -78.203  45.770  1
153364  99.093  -78.210  45.755  1
153365  99.122  -78.208  45.741  1
153366  99.149  -78.223  45.726  1
153367  99.155  -78.229  45.712  1
153368  99.148  -78.229  45.697  1
153369  99.142  -78.229  45.684  1
153370  99.155  -78.232  45.672  1
153371  99.178  -78.234  45.660  1
153372  99.200  -78.237  45.649  1
153373  99.222  -78.240  45.636  1
153374  99.244  -78.242  45.624  1
153375  99.267  -78.245  45.613  1
153376  99.289  -78.248  45.601  1
153377  99.311  -78.250  45.588  1
153378  99.334  -78.253  45.576  1
153379  99.366  -78.262  45.565  1
153380  99.399  -78.269  45.553  1
153381  99.431  -78.277  45.543  1
153382  99.463  -78.285  45.531  1
153383  99.496  -78.293  45.519  1
153384  99.521  -78.304  45.507  1
153385  99.508  -78.331  45.494  1
153386  99.494  -78.358  45.482  1
153387  99.512  -78.379  45.471  1
153388  99.541  -78.399  45.459  1
153389  99.570  -78.418  45.447  1
153390  99.599  -78.437  45.436  1
153391  99.629  -78.451  45.426  1
153392  99.713  -78.457  45.415  1
153393  99.788  -78.467  45.403  1
153394  99.820  -78.495  45.391  1
153395  99.852  -78.523  45.379  1
153396  99.884  -78.525  45.367  1
153397  99.911  -78.535  45.354  1
153398  99.938  -78.545  45.340  1
153399  99.966  -78.554  45.327  1
153400  99.993  -78.564  45.314  1
153401  100.020  -78.573  45.300  1
153402  100.048  -78.583  45.285  1
153403  100.075  -78.593  45.271  1
153404  100.102  -78.603  45.258  1
153405  100.130  -78.613  45.245  1
153406  100.162  -78.626  45.232  1
153407  100.196  -78.642  45.217  1
153408  100.216  -78.647  45.202  1
153409  100.234  -78.655  45.186  1
153410  100.254  -78.666  45.170  1
153411  100.273  -78.677  45.152  1
153412  100.291  -78.689  45.135  1
153413  100.311  -78.701  45.118  1
153414  100.330  -78.712  45.100  1
153415  100.348  -78.724  45.082  1
153416  100.367  -78.735  45.066  1
153417  100.387  -78.746  45.049  1
153418  100.405  -78.758  45.031  1
153419  100.424  -78.769  45.014  1
153420  100.443  -78.780  44.998  1
153421  100.462  -78.792  44.980  1
153422  100.483  -78.800  44.963  1
153423  100.503  -78.807  44.947  1
153424  100.524  -78.814  44.931  1
153425  100.545  -78.821  44.915  1
153426  100.565  -78.830  44.899  1
153427  100.580  -78.848  44.882  1
153428  100.585  -78.874  44.866  1
153429  100.590  -78.901  44.849  1
153430  100.595  -78.927  44.831  1
153431  100.600  -78.953  44.815  1
153432  100.606  -78.979  44.798  1
153433  100.612  -79.006  44.781  1
153434  100.635  -79.018  44.765  1
153435  100.659  -79.014  44.748  1
153436  100.683  -79.011  44.732  1
153437  100.707  -79.007  44.715  1
153438  100.746  -79.083  44.698  1
153439  100.846  -79.032  44.681  1
153440  100.913  -79.021  44.665  1
153441  100.965  -79.028  44.649  1
153442  101.016  -79.034  44.634  1
153443  101.069  -79.040  44.619  1
153444  101.121  -79.046  44.605  1
153445  101.173  -79.053  44.590  1
153446  101.225  -79.059  44.575  1
153447  101.267  -79.068  44.561  1
153448  101.291  -79.081  44.548  1
153449  101.316  -79.095  44.534  1
153450  101.340  -79.108  44.521  1
153451  101.364  -79.122  44.508  1
153452  101.389  -79.135  44.496  1
153453  101.411  -79.156  44.482  1
153454  101.427  -79.190  44.470  1
153681  92.553  -77.672  54.193  1
153682  92.573  -77.679  54.194  1
153683  92.593  -77.686  54.194  1
153684  92.613  -77.694  54.194  1
153685  92.633  -77.701  54.194  1
153686  92.653  -77.708  54.194  1
153687  92.673  -77.716  54.195  1
153688  92.693  -77.723  54.194  1
153689  92.713  -77.730  54.194  1
153690  92.733  -77.738  54.195  1
153691  92.753  -77.745  54.194  1
153692  92.773  -77.752  54.194  1
153693  92.793  -77.760  54.195  1
153694  92.813  -77.768  54.195  1
153695  92.833  -77.774  54.195  1
153696  92.853  -77.782  54.197  1
153697  92.873  -77.790  54.199  1
153698  92.893  -77.796  54.201  1
153699  92.917  -77.793  54.203  1
153700  92.940  -77.784  54.205  1
153701  92.957  -77.779  54.207  1
153702  92.974  -77.774  54.210  1
153703  92.991  -77.768  54.213  1
153704  93.007  -77.763  54.217  1
153705  93.024  -77.758  54.222  1
153706  93.040  -77.751  54.230  1
153707  93.053  -77.742  54.237  1
153708  93.066  -77.733  54.242  1
153709  93.080  -77.724  54.243  1
153710  93.092  -77.718  54.241  1
153711  93.105  -77.711  54.239  1
153712  93.117  -77.705  54.238  1
153713  93.130  -77.699  54.237  1
153714  93.142  -77.690  54.234  1
153715  93.153  -77.678  54.231  1
153716  93.165  -77.665  54.229  1
153717  93.177  -77.652  54.227  1
153718  93.188  -77.639  54.225  1
153719  93.200  -77.627  54.223  1
153720  93.212  -77.614  54.224  1
153721  93.225  -77.602  54.220  1
153722  93.238  -77.589  54.215  1
153723  93.251  -77.577  54.209  1
153724  93.264  -77.565  54.202  1
153725  93.277  -77.552  54.196  1
153726  93.290  -77.539  54.189  1
153727  93.303  -77.526  54.181  1
153728  93.319  -77.517  54.173  1
153729  93.334  -77.508  54.165  1
153730  93.350  -77.500  54.157  1
153731  93.366  -77.492  54.149  1
153732  93.382  -77.483  54.142  1
153733  93.398  -77.475  54.135  1
153734  93.414  -77.466  54.125  1
153735  93.430  -77.457  54.114  1
153736  93.445  -77.449  54.103  1
153737  93.462  -77.441  54.092  1
153738  93.477  -77.434  54.082  1
153739  93.490  -77.430  54.071  1
153740  93.503  -77.427  54.061  1
153741  93.520  -77.422  54.050  1
153742  93.538  -77.416  54.036  1
153743  93.556  -77.410  54.021  1
153744  93.573  -77.404  54.005  1
153745  93.585  -77.398  53.991  1
153746  93.593  -77.391  53.976  1
153747  93.608  -77.382  53.960  1
153748  93.624  -77.373  53.945  1
153749  93.639  -77.364  53.930  1
153750  93.654  -77.355  53.915  1
153751  93.670  -77.346  53.900  1
153752  93.686  -77.338  53.884  1
153753  93.707  -77.326  53.869  1
153754  93.729  -77.315  53.855  1
153755  93.751  -77.304  53.841  1
153756  93.773  -77.293  53.825  1
153757  93.795  -77.282  53.805  1
153758  93.817  -77.271  53.785  1
153759  93.840  -77.260  53.766  1
153760  93.845  -77.269  53.745  1
153761  93.847  -77.285  53.728  1
153762  93.851  -77.294  53.712  1
153763  93.860  -77.291  53.697  1
153764  93.869  -77.285  53.681  1
153765  93.878  -77.279  53.666  1
153766  93.888  -77.273  53.652  1
153767  93.897  -77.268  53.637  1
153768  93.906  -77.263  53.621  1
153769  93.919  -77.263  53.603  1
153770  93.936  -77.270  53.585  1
153771  93.953  -77.274  53.566  1
153772  93.965  -77.261  53.549  1
153773  93.977  -77.248  53.535  1
153774  93.989  -77.236  53.522  1
153775  94.004  -77.226  53.510  1
153776  94.035  -77.226  53.496  1
153777  94.064  -77.225  53.481  1
153778  94.094  -77.224  53.466  1
153779  94.123  -77.223  53.449  1
153780  94.152  -77.223  53.433  1
153781  94.182  -77.222  53.418  1
153782  94.212  -77.222  53.405  1
153783  94.242  -77.221  53.398  1
153784  94.271  -77.221  53.392  1
153785  94.298  -77.219  53.388  1
153786  94.313  -77.213  53.387  1
153787  94.313  -77.206  53.386  1
153788  94.314  -77.199  53.387  1
153789  94.315  -77.192  53.388  1
153790  94.316  -77.185  53.386  1
153791  94.316  -77.177  53.384  1
153792  94.314  -77.166  53.381  1
153793  94.312  -77.155  53.377  1
153794  94.318  -77.154  53.373  1
153795  94.319  -77.151  53.368  1
153796  94.320  -77.147  53.362  1
153797  94.321  -77.145  53.353  1
153798  94.321  -77.144  53.342  1
153799  94.322  -77.142  53.331  1
153800  94.323  -77.141  53.321  1
153801  94.324  -77.139  53.310  1
153802  94.336  -77.128  53.297  1
153803  94.351  -77.117  53.281  1
153804  94.373  -77.113  53.260  1
153805  94.396  -77.110  53.241  1
153806  94.416  -77.105  53.224  1
153807  94.436  -77.100  53.209  1
153808  94.456  -77.096  53.195  1
153809  94.476  -77.091  53.180  1
153810  94.496  -77.087  53.162  1
153811  94.517  -77.082  53.139  1
153812  94.537  -77.078  53.116  1
153813  94.557  -77.073  53.093  1
153814  94.577  -77.069  53.073  1
153815  94.597  -77.064  53.053  1
153816  94.617  -77.059  53.033  1
153817  94.632  -77.059  53.011  1
153818  94.645  -77.061  52.986  1
153819  94.657  -77.064  52.960  1
153820  94.670  -77.066  52.934  1
153821  94.683  -77.069  52.906  1
153822  94.695  -77.071  52.876  1
153823  94.708  -77.073  52.843  1
153824  94.720  -77.075  52.807  1
153825  94.733  -77.078  52.768  1
153826  94.763  -77.083  52.724  1
153827  94.795  -77.088  52.678  1
153828  94.804  -77.091  52.630  1
153829  94.819  -77.097  52.583  1
153830  94.838  -77.103  52.539  1
153831  94.856  -77.110  52.494  1
153832  94.876  -77.117  52.449  1
153833  94.895  -77.124  52.407  1
153834  94.913  -77.131  52.364  1
153835  94.931  -77.132  52.321  1
153836  94.947  -77.127  52.280  1
153837  94.963  -77.122  52.236  1
153838  94.979  -77.116  52.189  1
153839  94.998  -77.116  52.139  1
153840  95.019  -77.119  52.090  1
153841  95.040  -77.122  52.043  1
153842  95.061  -77.125  52.000  1
153843  95.082  -77.128  51.958  1
153844  95.103  -77.131  51.920  1
153845  95.124  -77.134  51.883  1
153846  95.144  -77.137  51.845  1
153847  95.165  -77.141  51.804  1
153848  95.179  -77.141  51.756  1
153849  95.193  -77.142  51.705  1
153850  95.206  -77.144  51.652  1
153851  95.220  -77.145  51.598  1
153852  95.234  -77.147  51.549  1
153853  95.248  -77.146  51.500  1
153854  95.264  -77.139  51.449  1
153855  95.280  -77.132  51.395  1
153856  95.296  -77.125  51.342  1
153857  95.312  -77.119  51.291  1
153858  95.330  -77.120  51.245  1
153859  95.352  -77.135  51.199  1
153860  95.375  -77.150  51.154  1
153861  95.397  -77.164  51.108  1
153862  95.419  -77.179  51.062  1
153863  95.441  -77.194  51.017  1
153864  95.460  -77.209  50.972  1
153865  95.478  -77.223  50.927  1
153866  95.495  -77.238  50.881  1
153867  95.513  -77.253  50.839  1
153868  95.531  -77.267  50.799  1
153869  95.549  -77.282  50.763  1
153870  95.566  -77.297  50.724  1
153871  95.584  -77.311  50.683  1
153872  95.602  -77.326  50.640  1
153873  95.623  -77.344  50.594  1
153874  95.646  -77.364  50.549  1
153875  95.666  -77.383  50.505  1
153876  95.682  -77.400  50.463  1
153877  95.699  -77.417  50.428  1
153878  95.715  -77.433  50.390  1
153879  95.732  -77.450  50.354  1
153880  95.748  -77.462  50.319  1
153881  95.765  -77.475  50.288  1
153882  95.782  -77.487  50.254  1
153883  95.803  -77.499  50.218  1
153884  95.824  -77.511  50.180  1
153885  95.845  -77.523  50.138  1
153886  95.867  -77.534  50.093  1
153887  95.885  -77.539  50.044  1
153888  95.901  -77.541  49.993  1
153889  95.918  -77.542  49.940  1
153890  95.935  -77.545  49.888  1
153891  95.951  -77.546  49.834  1
153892  95.967  -77.547  49.779  1
153893  95.978  -77.541  49.728  1
153894  95.989  -77.536  49.679  1
153895  96.000  -77.536  49.633  1
153896  96.007  -77.543  49.588  1
153897  96.015  -77.551  49.544  1
153898  96.024  -77.554  49.501  1
153899  96.033  -77.554  49.458  1
153900  96.042  -77.554  49.417  1
153901  96.052  -77.553  49.379  1
153902  96.061  -77.553  49.343  1
153903  96.071  -77.553  49.308  1
153904  96.081  -77.550  49.274  1
153905  96.097  -77.521  49.242  1
153906  96.106  -77.504  49.211  1
153907  96.113  -77.489  49.184  1
153908  96.121  -77.473  49.159  1
153909  96.122  -77.482  49.132  1
153910  96.125  -77.483  49.108  1
153911  96.124  -77.496  49.084  1
153912  96.120  -77.521  49.062  1
153913  96.117  -77.547  49.042  1
153914  96.113  -77.572  49.023  1
153915  96.127  -77.573  49.003  1
153916  96.142  -77.573  48.980  1
153917  96.157  -77.577  48.955  1
153918  96.170  -77.589  48.930  1
153919  96.184  -77.600  48.903  1
153920  96.198  -77.611  48.875  1
153921  96.212  -77.623  48.847  1
153922  96.226  -77.634  48.819  1
153923  96.240  -77.645  48.791  1
153924  96.252  -77.655  48.765  1
153925  96.265  -77.664  48.739  1
153926  96.278  -77.672  48.713  1
153927  96.298  -77.682  48.689  1
153928  96.322  -77.692  48.665  1
153929  96.344  -77.699  48.640  1
153930  96.365  -77.704  48.615  1
153931  96.385  -77.709  48.591  1
153932  96.405  -77.714  48.567  1
153933  96.425  -77.719  48.544  1
153934  96.445  -77.724  48.522  1
153935  96.465  -77.729  48.503  1
153936  96.484  -77.733  48.483  1
153937  96.496  -77.736  48.463  1
153938  96.507  -77.740  48.442  1
153939  96.519  -77.744  48.424  1
153940  96.530  -77.747  48.405  1
153941  96.541  -77.751  48.386  1
153942  96.552  -77.754  48.366  1
153943  96.559  -77.755  48.343  1
153944  96.566  -77.757  48.320  1
153945  96.573  -77.758  48.295  1
153946  96.580  -77.760  48.272  1
153947  96.588  -77.764  48.248  1
153948  96.598  -77.770  48.225  1
153949  96.607  -77.777  48.204  1
153950  96.617  -77.783  48.182  1
153951  96.626  -77.790  48.161  1
153952  96.638  -77.796  48.139  1
153953  96.652  -77.798  48.116  1
153954  96.666  -77.800  48.090  1
153955  96.680  -77.802  48.064  1
153956  96.694  -77.803  48.038  1
153957  96.709  -77.791  48.014  1
153958  96.724  -77.779  47.990  1
153959  96.739  -77.767  47.965  1
153960  96.754  -77.755  47.939  1
153961  96.769  -77.743  47.913  1
153962  96.789  -77.745  47.887  1
153963  96.811  -77.755  47.861  1
153964  96.833  -77.766  47.836  1
153965  96.855  -77.776  47.812  1
153966  96.877  -77.787  47.788  1
153967  96.899  -77.797  47.764  1
153968  96.922  -77.807  47.740  1
153969  96.944  -77.818  47.717  1
153970  96.966  -77.823  47.694  1
153971  96.983  -77.823  47.672  1
153972  96.996  -77.822  47.649  1
153973  97.009  -77.821  47.627  1
153974  97.021  -77.821  47.606  1
153975  97.033  -77.819  47.585  1
153976  97.044  -77.818  47.563  1
153977  97.054  -77.815  47.542  1
153978  97.066  -77.813  47.522  1
153979  97.077  -77.812  47.502  1
153980  97.090  -77.811  47.482  1
153981  97.108  -77.814  47.463  1
153982  97.128  -77.818  47.444  1
153983  97.149  -77.823  47.425  1
153984  97.169  -77.827  47.405  1
153985  97.198  -77.838  47.386  1
153986  97.230  -77.850  47.368  1
153987  97.255  -77.853  47.349  1
153988  97.278  -77.852  47.332  1
153989  97.301  -77.851  47.314  1
153990  97.324  -77.849  47.296  1
153991  97.347  -77.849  47.279  1
153992  97.370  -77.847  47.263  1
153993  97.393  -77.846  47.246  1
153994  97.416  -77.845  47.229  1
153995  97.433  -77.847  47.211  1
153996  97.444  -77.863  47.193  1
153997  97.456  -77.883  47.174  1
153998  97.471  -77.896  47.155  1
153999  97.487  -77.910  47.135  1
154000  97.502  -77.924  47.115  1
154001  97.517  -77.937  47.096  1
154002  97.533  -77.951  47.076  1
154003  97.548  -77.965  47.055  1
154004  97.563  -77.978  47.035  1
154005  97.579  -77.992  47.013  1
154006  97.594  -78.005  46.991  1
154007  97.607  -78.018  46.968  1
154008  97.608  -78.034  46.946  1
154009  97.609  -78.051  46.924  1
154010  97.610  -78.069  46.902  1
154011  97.611  -78.086  46.880  1
154012  97.613  -78.103  46.857  1
154013  97.634  -78.128  46.835  1
154014  97.655  -78.153  46.814  1
154015  97.676  -78.170  46.792  1
154016  97.711  -78.153  46.773  1
154017  97.746  -78.141  46.754  1
154018  97.781  -78.130  46.735  1
154019  97.764  -78.166  46.717  1
154020  97.749  -78.203  46.699  1
154021  97.776  -78.209  46.680  1
154022  97.840  -78.198  46.660  1
154023  97.902  -78.188  46.636  1
154024  97.965  -78.176  46.613  1
154025  98.029  -78.166  46.591  1
154026  98.092  -78.154  46.569  1
154027  98.120  -78.143  46.546  1
154028  98.141  -78.131  46.524  1
154029  98.159  -78.124  46.501  1
154030  98.189  -78.125  46.477  1
154031  98.219  -78.127  46.453  1
154032  98.249  -78.128  46.429  1
154033  98.279  -78.130  46.406  1
154034  98.310  -78.127  46.383  1
154035  98.347  -78.112  46.359  1
154036  98.384  -78.098  46.334  1
154037  98.421  -78.084  46.310  1
154038  98.457  -78.069  46.287  1
154039  98.494  -78.054  46.264  1
154040  98.531  -78.040  46.241  1
154041  98.568  -78.025  46.218  1
154042  98.604  -78.011  46.196  1
154043  98.625  -78.030  46.175  1
154044  98.638  -78.065  46.153  1
154045  98.649  -78.100  46.132  1
154046  98.636  -78.095  46.111  1
154047  98.624  -78.091  46.091  1
154048  98.610  -78.087  46.069  1
154049  98.597  -78.082  46.047  1
154050  98.595  -78.087  46.026  1
154051  98.596  -78.094  46.004  1
154052  98.597  -78.101  45.985  1
154053  98.598  -78.108  45.967  1
154054  98.599  -78.116  45.949  1
154055  98.599  -78.122  45.930  1
154056  98.639  -78.131  45.911  1
154057  98.691  -78.138  45.892  1
154058  98.744  -78.146  45.875  1
154059  98.797  -78.154  45.858  1
154060  98.849  -78.162  45.842  1
154061  98.902  -78.169  45.826  1
154062  98.955  -78.178  45.810  1
154063  99.007  -78.185  45.794  1
154064  99.057  -78.193  45.779  1
154065  99.100  -78.200  45.764  1
154066  99.139  -78.204  45.750  1
154067  99.167  -78.213  45.735  1
154068  99.169  -78.217  45.720  1
154069  99.162  -78.218  45.706  1
154070  99.156  -78.218  45.693  1
154071  99.163  -78.219  45.680  1
154072  99.185  -78.222  45.669  1
154073  99.208  -78.225  45.658  1
154074  99.230  -78.228  45.645  1
154075  99.252  -78.230  45.634  1
154076  99.274  -78.233  45.623  1
154077  99.297  -78.236  45.612  1
154078  99.319  -78.238  45.598  1
154079  99.341  -78.241  45.586  1
154080  99.364  -78.244  45.575  1
154081  99.394  -78.251  45.564  1
154082  99.426  -78.259  45.552  1
154083  99.458  -78.267  45.540  1
154084  99.491  -78.275  45.528  1
154085  99.493  -78.295  45.516  1
154086  99.480  -78.322  45.505  1
154087  99.507  -78.342  45.493  1
154088  99.536  -78.361  45.481  1
154089  99.565  -78.380  45.470  1
154090  99.593  -78.400  45.459  1
154091  99.623  -78.419  45.447  1
154092  99.651  -78.438  45.437  1
154093  99.700  -78.446  45.426  1
154094  99.774  -78.456  45.415  1
154095  99.805  -78.484  45.402  1
154096  99.838  -78.512  45.390  1
154097  99.871  -78.518  45.377  1
154098  99.898  -78.528  45.364  1
154099  99.925  -78.538  45.351  1
154100  99.953  -78.548  45.337  1
154101  99.980  -78.557  45.324  1
154102  100.007  -78.567  45.310  1
154103  100.034  -78.576  45.295  1
154104  100.062  -78.586  45.281  1
154105  100.095  -78.601  45.267  1
154106  100.129  -78.616  45.254  1
154107  100.162  -78.630  45.239  1
154108  100.195  -78.645  45.225  1
154109  100.228  -78.660  45.210  1
154110  100.241  -78.661  45.194  1
154111  100.259  -78.664  45.178  1
154112  100.278  -78.670  45.162  1
154113  100.297  -78.681  45.145  1
154114  100.316  -78.692  45.128  1
154115  100.335  -78.704  45.110  1
154116  100.354  -78.716  45.092  1
154117  100.372  -78.727  45.074  1
154118  100.392  -78.739  45.057  1
154119  100.411  -78.750  45.040  1
154120  100.429  -78.761  45.024  1
154121  100.449  -78.773  45.007  1
154122  100.468  -78.784  44.989  1
154123  100.488  -78.791  44.972  1
154124  100.509  -78.799  44.956  1
154125  100.530  -78.805  44.939  1
154126  100.551  -78.813  44.923  1
154127  100.571  -78.820  44.907  1
154128  100.587  -78.833  44.891  1
154129  100.593  -78.859  44.875  1
154130  100.599  -78.886  44.858  1
154131  100.606  -78.912  44.840  1
154132  100.612  -78.937  44.824  1
154133  100.618  -78.964  44.808  1
154134  100.629  -78.987  44.791  1
154135  100.657  -78.997  44.775  1
154136  100.683  -79.002  44.758  1
154137  100.707  -78.998  44.741  1
154138  100.731  -78.995  44.724  1
154139  100.754  -79.074  44.707  1
154140  100.799  -79.078  44.691  1
154141  100.899  -79.027  44.675  1
154142  100.970  -79.011  44.659  1
154143  101.022  -79.018  44.644  1
154144  101.074  -79.024  44.628  1
154145  101.126  -79.030  44.613  1
154146  101.178  -79.036  44.599  1
154147  101.230  -79.042  44.584  1
154148  101.266  -79.053  44.570  1
154149  101.290  -79.066  44.556  1
154150  101.315  -79.080  44.543  1
154151  101.339  -79.093  44.529  1
154152  101.363  -79.106  44.517  1
154153  101.388  -79.120  44.505  1
154154  101.409  -79.143  44.491  1
154155  101.425  -79.177  44.479  1
154382  92.542  -77.652  54.185  1
154383  92.562  -77.659  54.187  1
154384  92.582  -77.667  54.188  1
154385  92.602  -77.674  54.189  1
154386  92.622  -77.681  54.190  1
154387  92.642  -77.689  54.190  1
154388  92.662  -77.696  54.191  1
154389  92.682  -77.703  54.191  1
154390  92.702  -77.711  54.192  1
154391  92.722  -77.718  54.193  1
154392  92.742  -77.725  54.193  1
154393  92.762  -77.733  54.194  1
154394  92.782  -77.740  54.195  1
154395  92.802  -77.747  54.196  1
154396  92.821  -77.755  54.197  1
154397  92.842  -77.762  54.199  1
154398  92.862  -77.769  54.201  1
154399  92.881  -77.777  54.203  1
154400  92.906  -77.774  54.205  1
154401  92.930  -77.764  54.208  1
154402  92.947  -77.758  54.210  1
154403  92.964  -77.753  54.213  1
154404  92.981  -77.748  54.216  1
154405  92.998  -77.743  54.220  1
154406  93.013  -77.736  54.226  1
154407  93.026  -77.727  54.234  1
154408  93.040  -77.718  54.241  1
154409  93.054  -77.709  54.246  1
154410  93.067  -77.700  54.248  1
154411  93.080  -77.693  54.248  1
154412  93.092  -77.686  54.247  1
154413  93.105  -77.680  54.246  1
154414  93.117  -77.674  54.245  1
154415  93.130  -77.667  54.242  1
154416  93.142  -77.661  54.239  1
154417  93.154  -77.655  54.238  1
154418  93.166  -77.642  54.237  1
154419  93.178  -77.629  54.236  1
154420  93.190  -77.617  54.235  1
154421  93.203  -77.604  54.235  1
154422  93.216  -77.592  54.233  1
154423  93.228  -77.580  54.228  1
154424  93.240  -77.565  54.223  1
154425  93.252  -77.551  54.217  1
154426  93.263  -77.536  54.210  1
154427  93.274  -77.521  54.203  1
154428  93.295  -77.511  54.196  1
154429  93.314  -77.503  54.188  1
154430  93.328  -77.494  54.181  1
154431  93.342  -77.485  54.173  1
154432  93.355  -77.476  54.167  1
154433  93.370  -77.467  54.160  1
154434  93.387  -77.458  54.153  1
154435  93.403  -77.450  54.144  1
154436  93.418  -77.442  54.133  1
154437  93.434  -77.433  54.124  1
154438  93.450  -77.425  54.115  1
154439  93.466  -77.417  54.106  1
154440  93.480  -77.412  54.097  1
154441  93.493  -77.408  54.087  1
154442  93.511  -77.403  54.077  1
154443  93.529  -77.397  54.062  1
154444  93.546  -77.392  54.047  1
154445  93.564  -77.386  54.032  1
154446  93.582  -77.380  54.019  1
154447  93.597  -77.372  54.003  1
154448  93.613  -77.363  53.989  1
154449  93.628  -77.354  53.975  1
154450  93.643  -77.345  53.959  1
154451  93.659  -77.336  53.944  1
154452  93.674  -77.327  53.928  1
154453  93.690  -77.318  53.913  1
154454  93.708  -77.308  53.897  1
154455  93.730  -77.298  53.882  1
154456  93.752  -77.286  53.867  1
154457  93.774  -77.275  53.851  1
154458  93.795  -77.264  53.831  1
154459  93.817  -77.253  53.810  1
154460  93.834  -77.232  53.790  1
154461  93.839  -77.215  53.769  1
154462  93.842  -77.238  53.751  1
154463  93.847  -77.267  53.734  1
154464  93.854  -77.279  53.716  1
154465  93.862  -77.277  53.699  1
154466  93.871  -77.271  53.683  1
154467  93.880  -77.266  53.667  1
154468  93.890  -77.260  53.651  1
154469  93.899  -77.254  53.635  1
154470  93.912  -77.255  53.618  1
154471  93.929  -77.261  53.600  1
154472  93.941  -77.251  53.582  1
154473  93.954  -77.238  53.565  1
154474  93.967  -77.226  53.549  1
154475  93.983  -77.216  53.535  1
154476  94.000  -77.208  53.521  1
154477  94.025  -77.206  53.506  1
154478  94.056  -77.206  53.490  1
154479  94.087  -77.205  53.477  1
154480  94.118  -77.205  53.462  1
154481  94.149  -77.205  53.447  1
154482  94.180  -77.204  53.433  1
154483  94.211  -77.204  53.422  1
154484  94.241  -77.204  53.414  1
154485  94.270  -77.203  53.408  1
154486  94.299  -77.203  53.404  1
154487  94.317  -77.198  53.402  1
154488  94.318  -77.191  53.402  1
154489  94.318  -77.183  53.402  1
154490  94.316  -77.172  53.402  1
154491  94.314  -77.161  53.400  1
154492  94.311  -77.150  53.398  1
154493  94.309  -77.139  53.395  1
154494  94.314  -77.137  53.392  1
154495  94.321  -77.137  53.389  1
154496  94.323  -77.134  53.386  1
154497  94.324  -77.130  53.383  1
154498  94.324  -77.126  53.376  1
154499  94.325  -77.122  53.368  1
154500  94.325  -77.120  53.359  1
154501  94.326  -77.119  53.351  1
154502  94.327  -77.117  53.341  1
154503  94.333  -77.110  53.328  1
154504  94.350  -77.101  53.313  1
154505  94.372  -77.097  53.291  1
154506  94.392  -77.093  53.270  1
154507  94.412  -77.088  53.250  1
154508  94.432  -77.084  53.232  1
154509  94.453  -77.079  53.216  1
154510  94.473  -77.075  53.198  1
154511  94.493  -77.070  53.179  1
154512  94.513  -77.066  53.156  1
154513  94.534  -77.061  53.133  1
154514  94.555  -77.056  53.111  1
154515  94.576  -77.053  53.089  1
154516  94.597  -77.049  53.071  1
154517  94.620  -77.044  53.051  1
154518  94.632  -77.041  53.028  1
154519  94.644  -77.043  53.004  1
154520  94.657  -77.045  52.980  1
154521  94.669  -77.047  52.953  1
154522  94.682  -77.050  52.925  1
154523  94.694  -77.052  52.894  1
154524  94.707  -77.054  52.861  1
154525  94.719  -77.056  52.826  1
154526  94.732  -77.059  52.787  1
154527  94.764  -77.064  52.743  1
154528  94.804  -77.071  52.696  1
154529  94.818  -77.075  52.647  1
154530  94.826  -77.077  52.596  1
154531  94.842  -77.082  52.548  1
154532  94.860  -77.089  52.501  1
154533  94.880  -77.096  52.455  1
154534  94.898  -77.103  52.407  1
154535  94.917  -77.110  52.361  1
154536  94.935  -77.113  52.316  1
154537  94.952  -77.108  52.274  1
154538  94.968  -77.102  52.234  1
154539  94.984  -77.097  52.191  1
154540  95.004  -77.100  52.147  1
154541  95.025  -77.103  52.104  1
154542  95.046  -77.106  52.065  1
154543  95.067  -77.109  52.026  1
154544  95.088  -77.112  51.989  1
154545  95.109  -77.115  51.951  1
154546  95.130  -77.118  51.913  1
154547  95.150  -77.122  51.875  1
154548  95.170  -77.126  51.834  1
154549  95.186  -77.128  51.786  1
154550  95.197  -77.125  51.735  1
154551  95.208  -77.124  51.681  1
154552  95.222  -77.125  51.626  1
154553  95.235  -77.126  51.574  1
154554  95.249  -77.128  51.524  1
154555  95.263  -77.125  51.474  1
154556  95.279  -77.119  51.421  1
154557  95.295  -77.112  51.369  1
154558  95.311  -77.106  51.318  1
154559  95.333  -77.119  51.271  1
154560  95.355  -77.134  51.227  1
154561  95.378  -77.149  51.181  1
154562  95.400  -77.163  51.135  1
154563  95.422  -77.179  51.088  1
154564  95.444  -77.193  51.040  1
154565  95.463  -77.208  50.993  1
154566  95.481  -77.222  50.947  1
154567  95.498  -77.237  50.901  1
154568  95.517  -77.252  50.860  1
154569  95.534  -77.266  50.821  1
154570  95.552  -77.282  50.783  1
154571  95.570  -77.296  50.741  1
154572  95.588  -77.310  50.699  1
154573  95.605  -77.326  50.655  1
154574  95.623  -77.340  50.609  1
154575  95.643  -77.357  50.563  1
154576  95.664  -77.376  50.519  1
154577  95.680  -77.393  50.477  1
154578  95.696  -77.409  50.439  1
154579  95.713  -77.421  50.402  1
154580  95.730  -77.434  50.366  1
154581  95.747  -77.446  50.332  1
154582  95.764  -77.458  50.299  1
154583  95.782  -77.471  50.263  1
154584  95.804  -77.483  50.226  1
154585  95.825  -77.495  50.189  1
154586  95.847  -77.506  50.148  1
154587  95.868  -77.518  50.105  1
154588  95.890  -77.530  50.057  1
154589  95.909  -77.538  50.007  1
154590  95.926  -77.539  49.956  1
154591  95.943  -77.542  49.905  1
154592  95.958  -77.542  49.852  1
154593  95.970  -77.536  49.796  1
154594  95.981  -77.531  49.743  1
154595  95.992  -77.525  49.693  1
154596  96.003  -77.524  49.646  1
154597  96.011  -77.532  49.601  1
154598  96.018  -77.540  49.556  1
154599  96.026  -77.548  49.511  1
154600  96.034  -77.551  49.467  1
154601  96.044  -77.551  49.425  1
154602  96.053  -77.551  49.386  1
154603  96.062  -77.551  49.349  1
154604  96.072  -77.551  49.314  1
154605  96.082  -77.547  49.279  1
154606  96.098  -77.520  49.246  1
154607  96.105  -77.504  49.215  1
154608  96.113  -77.489  49.188  1
154609  96.121  -77.473  49.161  1
154610  96.128  -77.457  49.134  1
154611  96.135  -77.445  49.109  1
154612  96.131  -77.470  49.084  1
154613  96.128  -77.495  49.060  1
154614  96.124  -77.520  49.038  1
154615  96.121  -77.545  49.018  1
154616  96.129  -77.555  48.998  1
154617  96.144  -77.555  48.976  1
154618  96.158  -77.564  48.953  1
154619  96.172  -77.576  48.929  1
154620  96.185  -77.587  48.904  1
154621  96.199  -77.599  48.879  1
154622  96.213  -77.610  48.853  1
154623  96.227  -77.621  48.826  1
154624  96.241  -77.633  48.800  1
154625  96.254  -77.642  48.775  1
154626  96.267  -77.652  48.750  1
154627  96.282  -77.661  48.725  1
154628  96.307  -77.671  48.701  1
154629  96.332  -77.681  48.677  1
154630  96.358  -77.692  48.653  1
154631  96.379  -77.698  48.629  1
154632  96.399  -77.703  48.606  1
154633  96.419  -77.708  48.583  1
154634  96.440  -77.713  48.560  1
154635  96.460  -77.718  48.538  1
154636  96.480  -77.723  48.518  1
154637  96.499  -77.727  48.499  1
154638  96.510  -77.730  48.479  1
154639  96.521  -77.734  48.459  1
154640  96.532  -77.737  48.442  1
154641  96.544  -77.741  48.424  1
154642  96.555  -77.745  48.405  1
154643  96.562  -77.746  48.385  1
154644  96.569  -77.748  48.362  1
154645  96.576  -77.749  48.337  1
154646  96.583  -77.750  48.312  1
154647  96.590  -77.752  48.289  1
154648  96.597  -77.753  48.265  1
154649  96.606  -77.760  48.242  1
154650  96.616  -77.767  48.221  1
154651  96.626  -77.773  48.199  1
154652  96.636  -77.780  48.177  1
154653  96.646  -77.786  48.155  1
154654  96.660  -77.788  48.133  1
154655  96.674  -77.790  48.108  1
154656  96.688  -77.793  48.083  1
154657  96.702  -77.795  48.058  1
154658  96.717  -77.797  48.036  1
154659  96.732  -77.787  48.011  1
154660  96.747  -77.774  47.986  1
154661  96.761  -77.762  47.960  1
154662  96.777  -77.750  47.934  1
154663  96.793  -77.741  47.908  1
154664  96.815  -77.752  47.882  1
154665  96.837  -77.762  47.856  1
154666  96.859  -77.772  47.832  1
154667  96.881  -77.783  47.808  1
154668  96.903  -77.793  47.784  1
154669  96.925  -77.803  47.760  1
154670  96.947  -77.813  47.737  1
154671  96.970  -77.814  47.715  1
154672  96.989  -77.815  47.692  1
154673  97.001  -77.814  47.669  1
154674  97.014  -77.813  47.648  1
154675  97.027  -77.812  47.627  1
154676  97.039  -77.812  47.606  1
154677  97.052  -77.812  47.584  1
154678  97.065  -77.811  47.563  1
154679  97.076  -77.809  47.542  1
154680  97.087  -77.807  47.523  1
154681  97.105  -77.810  47.503  1
154682  97.126  -77.815  47.483  1
154683  97.146  -77.819  47.463  1
154684  97.166  -77.824  47.444  1
154685  97.186  -77.828  47.424  1
154686  97.216  -77.839  47.404  1
154687  97.239  -77.838  47.385  1
154688  97.262  -77.837  47.367  1
154689  97.285  -77.836  47.349  1
154690  97.308  -77.834  47.333  1
154691  97.330  -77.834  47.314  1
154692  97.354  -77.832  47.298  1
154693  97.377  -77.831  47.281  1
154694  97.399  -77.830  47.264  1
154695  97.423  -77.829  47.247  1
154696  97.442  -77.829  47.229  1
154697  97.453  -77.847  47.211  1
154698  97.468  -77.862  47.192  1
154699  97.484  -77.875  47.173  1
154700  97.499  -77.889  47.153  1
154701  97.514  -77.902  47.132  1
154702  97.529  -77.916  47.112  1
154703  97.545  -77.930  47.091  1
154704  97.560  -77.944  47.070  1
154705  97.576  -77.959  47.050  1
154706  97.591  -77.975  47.028  1
154707  97.607  -77.990  47.005  1
154708  97.614  -78.011  46.983  1
154709  97.612  -78.036  46.960  1
154710  97.613  -78.053  46.937  1
154711  97.614  -78.071  46.914  1
154712  97.615  -78.088  46.890  1
154713  97.616  -78.106  46.867  1
154714  97.637  -78.130  46.844  1
154715  97.658  -78.155  46.821  1
154716  97.684  -78.144  46.799  1
154717  97.720  -78.132  46.779  1
154718  97.754  -78.121  46.759  1
154719  97.790  -78.109  46.740  1
154720  97.824  -78.098  46.721  1
154721  97.813  -78.129  46.705  1
154722  97.798  -78.169  46.687  1
154723  97.829  -78.183  46.667  1
154724  97.892  -78.172  46.644  1
154725  97.955  -78.161  46.622  1
154726  98.018  -78.150  46.600  1
154727  98.081  -78.139  46.578  1
154728  98.112  -78.128  46.555  1
154729  98.130  -78.116  46.532  1
154730  98.160  -78.118  46.509  1
154731  98.190  -78.119  46.485  1
154732  98.220  -78.122  46.461  1
154733  98.253  -78.113  46.438  1
154734  98.290  -78.099  46.416  1
154735  98.327  -78.084  46.393  1
154736  98.364  -78.069  46.368  1
154737  98.401  -78.055  46.343  1
154738  98.437  -78.040  46.319  1
154739  98.474  -78.026  46.297  1
154740  98.510  -78.012  46.274  1
154741  98.547  -77.996  46.251  1
154742  98.584  -77.982  46.229  1
154743  98.620  -77.970  46.207  1
154744  98.632  -78.006  46.186  1
154745  98.645  -78.042  46.164  1
154746  98.658  -78.078  46.142  1
154747  98.648  -78.079  46.122  1
154748  98.636  -78.075  46.101  1
154749  98.623  -78.071  46.079  1
154750  98.613  -78.069  46.057  1
154751  98.613  -78.075  46.036  1
154752  98.614  -78.083  46.015  1
154753  98.615  -78.090  45.997  1
154754  98.616  -78.097  45.979  1
154755  98.616  -78.104  45.961  1
154756  98.617  -78.111  45.942  1
154757  98.627  -78.119  45.923  1
154758  98.680  -78.126  45.904  1
154759  98.733  -78.134  45.885  1
154760  98.785  -78.142  45.868  1
154761  98.838  -78.150  45.852  1
154762  98.890  -78.158  45.836  1
154763  98.943  -78.166  45.819  1
154764  98.996  -78.174  45.802  1
154765  99.049  -78.181  45.787  1
154766  99.101  -78.190  45.773  1
154767  99.150  -78.197  45.759  1
154768  99.185  -78.203  45.744  1
154769  99.183  -78.206  45.729  1
154770  99.177  -78.206  45.715  1
154771  99.169  -78.206  45.702  1
154772  99.170  -78.207  45.689  1
154773  99.193  -78.210  45.678  1
154774  99.215  -78.213  45.667  1
154775  99.237  -78.216  45.655  1
154776  99.260  -78.218  45.643  1
154777  99.282  -78.221  45.633  1
154778  99.304  -78.224  45.621  1
154779  99.327  -78.226  45.607  1
154780  99.349  -78.229  45.595  1
154781  99.371  -78.232  45.584  1
154782  99.394  -78.235  45.574  1
154783  99.422  -78.241  45.562  1
154784  99.454  -78.248  45.550  1
154785  99.478  -78.260  45.537  1
154786  99.473  -78.285  45.526  1
154787  99.502  -78.304  45.514  1
154788  99.531  -78.324  45.503  1
154789  99.560  -78.343  45.492  1
154790  99.588  -78.362  45.481  1
154791  99.617  -78.382  45.470  1
154792  99.646  -78.401  45.459  1
154793  99.675  -78.420  45.448  1
154794  99.691  -78.435  45.437  1
154795  99.759  -78.445  45.426  1
154796  99.791  -78.473  45.413  1
154797  99.823  -78.502  45.400  1
154798  99.857  -78.515  45.387  1
154799  99.886  -78.521  45.374  1
154800  99.913  -78.531  45.361  1
154801  99.940  -78.541  45.347  1
154802  99.967  -78.550  45.334  1
154803  99.995  -78.560  45.320  1
154804  100.028  -78.575  45.305  1
154805  100.061  -78.589  45.292  1
154806  100.094  -78.604  45.277  1
154807  100.128  -78.619  45.262  1
154808  100.161  -78.634  45.247  1
154809  100.195  -78.648  45.232  1
154810  100.228  -78.664  45.217  1
154811  100.254  -78.673  45.202  1
154812  100.265  -78.673  45.186  1
154813  100.284  -78.677  45.170  1
154814  100.302  -78.680  45.154  1
154815  100.321  -78.685  45.136  1
154816  100.340  -78.696  45.118  1
154817  100.359  -78.708  45.100  1
154818  100.378  -78.720  45.083  1
154819  100.397  -78.731  45.066  1
154820  100.416  -78.742  45.049  1
154821  100.435  -78.754  45.032  1
154822  100.454  -78.765  45.016  1
154823  100.473  -78.775  44.998  1
154824  100.494  -78.783  44.981  1
154825  100.514  -78.789  44.964  1
154826  100.536  -78.797  44.948  1
154827  100.556  -78.804  44.932  1
154828  100.577  -78.811  44.915  1
154829  100.599  -78.818  44.900  1
154830  100.605  -78.844  44.883  1
154831  100.611  -78.870  44.866  1
154832  100.617  -78.896  44.849  1
154833  100.623  -78.922  44.833  1
154834  100.629  -78.948  44.817  1
154835  100.650  -78.964  44.801  1
154836  100.678  -78.975  44.784  1
154837  100.706  -78.986  44.767  1
154838  100.732  -78.985  44.750  1
154839  100.755  -78.982  44.733  1
154840  100.785  -79.040  44.717  1
154841  100.829  -79.046  44.701  1
154842  100.873  -79.052  44.685  1
154843  100.953  -79.021  44.669  1
154844  101.027  -79.001  44.654  1
154845  101.079  -79.007  44.638  1
154846  101.131  -79.013  44.622  1
154847  101.183  -79.019  44.607  1
154848  101.235  -79.026  44.592  1
154849  101.265  -79.038  44.578  1
154850  101.289  -79.051  44.564  1
154851  101.314  -79.065  44.551  1
154852  101.338  -79.078  44.538  1
154853  101.362  -79.092  44.525  1
154854  101.387  -79.105  44.513  1
154855  101.407  -79.130  44.500  1
154856  101.424  -79.164  44.487  1
155083  92.531  -77.632  54.177  1
155084  92.551  -77.639  54.179  1
155085  92.571  -77.646  54.181  1
155086  92.591  -77.654  54.183  1
155087  92.611  -77.661  54.185  1
155088  92.631  -77.668  54.186  1
155089  92.651  -77.676  54.187  1
155090  92.671  -77.683  54.189  1
155091  92.691  -77.690  54.191  1
155092  92.711  -77.698  54.193  1
155093  92.731  -77.705  54.193  1
155094  92.751  -77.712  54.195  1
155095  92.771  -77.720  54.196  1
155096  92.791  -77.727  54.197  1
155097  92.810  -77.734  54.199  1
155098  92.831  -77.742  54.201  1
155099  92.851  -77.749  54.203  1
155100  92.870  -77.757  54.206  1
155101  92.895  -77.754  54.208  1
155102  92.920  -77.743  54.211  1
155103  92.937  -77.738  54.214  1
155104  92.954  -77.733  54.217  1
155105  92.971  -77.727  54.220  1
155106  92.987  -77.721  54.225  1
155107  93.000  -77.711  54.231  1
155108  93.014  -77.703  54.239  1
155109  93.027  -77.694  54.246  1
155110  93.041  -77.685  54.250  1
155111  93.054  -77.677  54.254  1
155112  93.068  -77.668  54.255  1
155113  93.080  -77.661  54.256  1
155114  93.092  -77.655  54.255  1
155115  93.105  -77.649  54.254  1
155116  93.117  -77.642  54.251  1
155117  93.130  -77.636  54.249  1
155118  93.142  -77.630  54.248  1
155119  93.155  -77.623  54.248  1
155120  93.167  -77.617  54.248  1
155121  93.179  -77.605  54.247  1
155122  93.190  -77.590  54.247  1
155123  93.202  -77.576  54.246  1
155124  93.213  -77.561  54.242  1
155125  93.224  -77.547  54.237  1
155126  93.236  -77.532  54.232  1
155127  93.247  -77.517  54.226  1
155128  93.263  -77.505  54.219  1
155129  93.287  -77.497  54.214  1
155130  93.310  -77.489  54.206  1
155131  93.324  -77.479  54.199  1
155132  93.338  -77.470  54.192  1
155133  93.351  -77.461  54.187  1
155134  93.364  -77.452  54.181  1
155135  93.378  -77.443  54.175  1
155136  93.391  -77.434  54.167  1
155137  93.407  -77.426  54.157  1
155138  93.423  -77.417  54.148  1
155139  93.439  -77.408  54.141  1
155140  93.454  -77.400  54.133  1
155141  93.469  -77.394  54.125  1
155142  93.484  -77.389  54.116  1
155143  93.501  -77.384  54.105  1
155144  93.519  -77.379  54.090  1
155145  93.537  -77.373  54.075  1
155146  93.556  -77.367  54.061  1
155147  93.574  -77.360  54.047  1
155148  93.595  -77.352  54.031  1
155149  93.616  -77.343  54.018  1
155150  93.632  -77.335  54.005  1
155151  93.648  -77.326  53.989  1
155152  93.663  -77.316  53.973  1
155153  93.679  -77.307  53.957  1
155154  93.694  -77.299  53.943  1
155155  93.709  -77.290  53.926  1
155156  93.730  -77.279  53.910  1
155157  93.752  -77.268  53.895  1
155158  93.774  -77.257  53.878  1
155159  93.796  -77.246  53.859  1
155160  93.817  -77.233  53.838  1
155161  93.823  -77.196  53.817  1
155162  93.834  -77.178  53.797  1
155163  93.841  -77.191  53.777  1
155164  93.847  -77.215  53.758  1
155165  93.854  -77.226  53.738  1
155166  93.860  -77.238  53.721  1
155167  93.867  -77.248  53.703  1
155168  93.873  -77.258  53.686  1
155169  93.883  -77.252  53.669  1
155170  93.892  -77.247  53.652  1
155171  93.904  -77.247  53.635  1
155172  93.918  -77.241  53.617  1
155173  93.931  -77.229  53.599  1
155174  93.947  -77.219  53.581  1
155175  93.964  -77.209  53.564  1
155176  93.979  -77.199  53.550  1
155177  93.997  -77.191  53.534  1
155178  94.021  -77.188  53.519  1
155179  94.046  -77.186  53.503  1
155180  94.077  -77.186  53.488  1
155181  94.108  -77.185  53.472  1
155182  94.139  -77.185  53.458  1
155183  94.170  -77.185  53.445  1
155184  94.201  -77.185  53.435  1
155185  94.232  -77.185  53.428  1
155186  94.263  -77.185  53.423  1
155187  94.294  -77.184  53.420  1
155188  94.315  -77.179  53.418  1
155189  94.315  -77.167  53.417  1
155190  94.313  -77.156  53.415  1
155191  94.311  -77.145  53.413  1
155192  94.309  -77.134  53.408  1
155193  94.306  -77.123  53.403  1
155194  94.309  -77.119  53.399  1
155195  94.317  -77.119  53.397  1
155196  94.324  -77.119  53.396  1
155197  94.327  -77.117  53.396  1
155198  94.328  -77.113  53.396  1
155199  94.328  -77.110  53.393  1
155200  94.329  -77.106  53.389  1
155201  94.329  -77.101  53.384  1
155202  94.330  -77.097  53.377  1
155203  94.330  -77.095  53.368  1
155204  94.331  -77.093  53.357  1
155205  94.348  -77.085  53.341  1
155206  94.368  -77.081  53.319  1
155207  94.389  -77.076  53.296  1
155208  94.409  -77.072  53.272  1
155209  94.429  -77.067  53.251  1
155210  94.451  -77.063  53.231  1
155211  94.472  -77.059  53.212  1
155212  94.493  -77.055  53.192  1
155213  94.514  -77.050  53.168  1
155214  94.535  -77.047  53.145  1
155215  94.556  -77.042  53.123  1
155216  94.577  -77.038  53.102  1
155217  94.599  -77.034  53.084  1
155218  94.623  -77.030  53.064  1
155219  94.631  -77.025  53.041  1
155220  94.643  -77.025  53.017  1
155221  94.655  -77.026  52.993  1
155222  94.668  -77.028  52.967  1
155223  94.680  -77.031  52.939  1
155224  94.693  -77.033  52.908  1
155225  94.705  -77.035  52.874  1
155226  94.718  -77.038  52.837  1
155227  94.731  -77.040  52.797  1
155228  94.765  -77.046  52.754  1
155229  94.805  -77.053  52.707  1
155230  94.833  -77.057  52.657  1
155231  94.841  -77.060  52.605  1
155232  94.849  -77.063  52.554  1
155233  94.864  -77.069  52.505  1
155234  94.883  -77.075  52.458  1
155235  94.902  -77.081  52.411  1
155236  94.921  -77.088  52.367  1
155237  94.939  -77.094  52.324  1
155238  94.956  -77.088  52.283  1
155239  94.972  -77.083  52.246  1
155240  94.990  -77.081  52.208  1
155241  95.011  -77.084  52.169  1
155242  95.032  -77.087  52.135  1
155243  95.052  -77.090  52.101  1
155244  95.073  -77.093  52.066  1
155245  95.094  -77.096  52.027  1
155246  95.115  -77.100  51.986  1
155247  95.135  -77.103  51.945  1
155248  95.155  -77.108  51.903  1
155249  95.175  -77.113  51.859  1
155250  95.194  -77.116  51.811  1
155251  95.205  -77.114  51.761  1
155252  95.216  -77.112  51.708  1
155253  95.227  -77.110  51.652  1
155254  95.237  -77.107  51.599  1
155255  95.250  -77.108  51.547  1
155256  95.264  -77.110  51.497  1
155257  95.279  -77.106  51.446  1
155258  95.295  -77.099  51.395  1
155259  95.314  -77.103  51.345  1
155260  95.336  -77.119  51.298  1
155261  95.358  -77.133  51.254  1
155262  95.381  -77.148  51.209  1
155263  95.403  -77.163  51.162  1
155264  95.425  -77.178  51.112  1
155265  95.447  -77.192  51.061  1
155266  95.466  -77.207  51.012  1
155267  95.484  -77.222  50.965  1
155268  95.502  -77.236  50.921  1
155269  95.520  -77.251  50.879  1
155270  95.538  -77.266  50.839  1
155271  95.555  -77.281  50.797  1
155272  95.573  -77.295  50.754  1
155273  95.591  -77.310  50.710  1
155274  95.609  -77.325  50.665  1
155275  95.626  -77.339  50.620  1
155276  95.644  -77.354  50.576  1
155277  95.662  -77.368  50.534  1
155278  95.679  -77.380  50.492  1
155279  95.695  -77.393  50.451  1
155280  95.712  -77.405  50.412  1
155281  95.729  -77.417  50.376  1
155282  95.746  -77.430  50.343  1
155283  95.763  -77.442  50.309  1
155284  95.784  -77.454  50.273  1
155285  95.806  -77.466  50.234  1
155286  95.827  -77.478  50.196  1
155287  95.848  -77.490  50.156  1
155288  95.870  -77.501  50.114  1
155289  95.891  -77.514  50.068  1
155290  95.913  -77.525  50.020  1
155291  95.934  -77.537  49.971  1
155292  95.950  -77.537  49.922  1
155293  95.961  -77.532  49.868  1
155294  95.973  -77.526  49.811  1
155295  95.984  -77.520  49.757  1
155296  95.995  -77.515  49.706  1
155297  96.006  -77.513  49.658  1
155298  96.014  -77.520  49.612  1
155299  96.022  -77.529  49.567  1
155300  96.029  -77.536  49.522  1
155301  96.037  -77.545  49.478  1
155302  96.045  -77.549  49.435  1
155303  96.054  -77.548  49.394  1
155304  96.064  -77.548  49.355  1
155305  96.073  -77.548  49.320  1
155306  96.084  -77.544  49.285  1
155307  96.097  -77.520  49.252  1
155308  96.105  -77.504  49.220  1
155309  96.112  -77.489  49.191  1
155310  96.120  -77.473  49.163  1
155311  96.128  -77.461  49.136  1
155312  96.136  -77.457  49.110  1
155313  96.139  -77.459  49.084  1
155314  96.135  -77.470  49.059  1
155315  96.132  -77.494  49.034  1
155316  96.128  -77.519  49.013  1
155317  96.130  -77.536  48.992  1
155318  96.145  -77.539  48.969  1
155319  96.159  -77.551  48.948  1
155320  96.173  -77.562  48.926  1
155321  96.187  -77.573  48.904  1
155322  96.200  -77.585  48.880  1
155323  96.215  -77.596  48.858  1
155324  96.228  -77.608  48.834  1
155325  96.242  -77.619  48.810  1
155326  96.256  -77.630  48.786  1
155327  96.269  -77.639  48.761  1
155328  96.292  -77.649  48.737  1
155329  96.317  -77.660  48.713  1
155330  96.342  -77.671  48.689  1
155331  96.368  -77.680  48.666  1
155332  96.393  -77.691  48.643  1
155333  96.413  -77.697  48.621  1
155334  96.434  -77.702  48.598  1
155335  96.454  -77.706  48.575  1
155336  96.474  -77.711  48.554  1
155337  96.495  -77.716  48.534  1
155338  96.512  -77.721  48.514  1
155339  96.524  -77.724  48.494  1
155340  96.535  -77.728  48.476  1
155341  96.546  -77.731  48.460  1
155342  96.557  -77.735  48.443  1
155343  96.566  -77.736  48.424  1
155344  96.573  -77.738  48.403  1
155345  96.579  -77.740  48.379  1
155346  96.586  -77.741  48.355  1
155347  96.593  -77.743  48.330  1
155348  96.600  -77.744  48.307  1
155349  96.607  -77.745  48.284  1
155350  96.615  -77.749  48.261  1
155351  96.625  -77.756  48.240  1
155352  96.635  -77.763  48.218  1
155353  96.644  -77.769  48.195  1
155354  96.654  -77.775  48.171  1
155355  96.668  -77.778  48.150  1
155356  96.682  -77.780  48.124  1
155357  96.697  -77.783  48.101  1
155358  96.711  -77.785  48.079  1
155359  96.725  -77.787  48.057  1
155360  96.739  -77.790  48.032  1
155361  96.754  -77.783  48.007  1
155362  96.769  -77.771  47.980  1
155363  96.784  -77.758  47.954  1
155364  96.799  -77.746  47.928  1
155365  96.818  -77.748  47.902  1
155366  96.840  -77.758  47.878  1
155367  96.863  -77.768  47.853  1
155368  96.885  -77.779  47.829  1
155369  96.907  -77.790  47.804  1
155370  96.929  -77.799  47.780  1
155371  96.952  -77.804  47.758  1
155372  96.975  -77.805  47.735  1
155373  96.994  -77.805  47.713  1
155374  97.007  -77.805  47.691  1
155375  97.019  -77.805  47.669  1
155376  97.032  -77.804  47.648  1
155377  97.045  -77.803  47.627  1
155378  97.058  -77.802  47.606  1
155379  97.070  -77.802  47.584  1
155380  97.083  -77.802  47.563  1
155381  97.095  -77.799  47.543  1
155382  97.113  -77.800  47.522  1
155383  97.134  -77.805  47.502  1
155384  97.155  -77.810  47.484  1
155385  97.176  -77.815  47.463  1
155386  97.196  -77.821  47.442  1
155387  97.220  -77.821  47.423  1
155388  97.243  -77.820  47.404  1
155389  97.267  -77.819  47.385  1
155390  97.290  -77.818  47.368  1
155391  97.314  -77.818  47.351  1
155392  97.337  -77.817  47.333  1
155393  97.360  -77.815  47.316  1
155394  97.383  -77.815  47.300  1
155395  97.406  -77.813  47.283  1
155396  97.429  -77.812  47.266  1
155397  97.451  -77.812  47.248  1
155398  97.465  -77.827  47.231  1
155399  97.480  -77.840  47.211  1
155400  97.496  -77.855  47.191  1
155401  97.512  -77.871  47.170  1
155402  97.527  -77.887  47.150  1
155403  97.542  -77.902  47.128  1
155404  97.558  -77.917  47.107  1
155405  97.574  -77.932  47.085  1
155406  97.589  -77.947  47.063  1
155407  97.605  -77.962  47.042  1
155408  97.620  -77.978  47.019  1
155409  97.623  -78.002  46.995  1
155410  97.619  -78.030  46.972  1
155411  97.617  -78.056  46.948  1
155412  97.618  -78.073  46.924  1
155413  97.619  -78.091  46.899  1
155414  97.620  -78.108  46.876  1
155415  97.640  -78.132  46.852  1
155416  97.660  -78.149  46.829  1
155417  97.693  -78.123  46.806  1
155418  97.728  -78.112  46.785  1
155419  97.763  -78.100  46.766  1
155420  97.798  -78.089  46.746  1
155421  97.833  -78.078  46.727  1
155422  97.868  -78.065  46.710  1
155423  97.868  -78.090  46.693  1
155424  97.892  -78.109  46.673  1
155425  97.917  -78.128  46.651  1
155426  97.945  -78.145  46.630  1
155427  98.008  -78.134  46.608  1
155428  98.071  -78.123  46.586  1
155429  98.105  -78.112  46.563  1
155430  98.131  -78.110  46.540  1
155431  98.160  -78.112  46.517  1
155432  98.197  -78.100  46.492  1
155433  98.233  -78.084  46.469  1
155434  98.270  -78.070  46.447  1
155435  98.306  -78.056  46.425  1
155436  98.343  -78.041  46.402  1
155437  98.380  -78.027  46.377  1
155438  98.417  -78.012  46.353  1
155439  98.453  -77.997  46.330  1
155440  98.490  -77.983  46.307  1
155441  98.527  -77.968  46.284  1
155442  98.563  -77.954  46.261  1
155443  98.600  -77.940  46.239  1
155444  98.627  -77.946  46.217  1
155445  98.639  -77.983  46.195  1
155446  98.652  -78.018  46.174  1
155447  98.665  -78.054  46.152  1
155448  98.660  -78.063  46.130  1
155449  98.648  -78.059  46.109  1
155450  98.635  -78.055  46.088  1
155451  98.630  -78.057  46.067  1
155452  98.631  -78.064  46.047  1
155453  98.631  -78.072  46.027  1
155454  98.632  -78.078  46.009  1
155455  98.633  -78.086  45.991  1
155456  98.634  -78.093  45.972  1
155457  98.635  -78.100  45.953  1
155458  98.635  -78.107  45.935  1
155459  98.668  -78.115  45.915  1
155460  98.721  -78.122  45.896  1
155461  98.774  -78.131  45.878  1
155462  98.827  -78.138  45.861  1
155463  98.879  -78.147  45.845  1
155464  98.932  -78.154  45.828  1
155465  98.985  -78.162  45.812  1
155466  99.038  -78.170  45.796  1
155467  99.090  -78.178  45.781  1
155468  99.143  -78.186  45.766  1
155469  99.193  -78.194  45.752  1
155470  99.197  -78.194  45.738  1
155471  99.191  -78.194  45.724  1
155472  99.184  -78.194  45.711  1
155473  99.178  -78.195  45.698  1
155474  99.200  -78.197  45.687  1
155475  99.223  -78.200  45.676  1
155476  99.245  -78.203  45.663  1
155477  99.267  -78.206  45.652  1
155478  99.290  -78.209  45.641  1
155479  99.312  -78.212  45.630  1
155480  99.334  -78.214  45.617  1
155481  99.356  -78.217  45.605  1
155482  99.379  -78.220  45.594  1
155483  99.401  -78.222  45.583  1
155484  99.423  -78.225  45.571  1
155485  99.449  -78.230  45.559  1
155486  99.468  -78.248  45.547  1
155487  99.497  -78.267  45.535  1
155488  99.525  -78.286  45.523  1
155489  99.554  -78.306  45.513  1
155490  99.583  -78.325  45.503  1
155491  99.612  -78.344  45.492  1
155492  99.641  -78.363  45.481  1
155493  99.669  -78.382  45.470  1
155494  99.698  -78.401  45.458  1
155495  99.727  -78.421  45.447  1
155496  99.745  -78.435  45.436  1
155497  99.777  -78.463  45.423  1
155498  99.808  -78.492  45.409  1
155499  99.841  -78.516  45.396  1
155500  99.872  -78.514  45.383  1
155501  99.900  -78.524  45.371  1
155502  99.927  -78.534  45.357  1
155503  99.961  -78.548  45.343  1
155504  99.994  -78.564  45.329  1
155505  100.028  -78.578  45.315  1
155506  100.061  -78.593  45.301  1
155507  100.094  -78.608  45.286  1
155508  100.128  -78.623  45.270  1
155509  100.161  -78.637  45.256  1
155510  100.194  -78.652  45.240  1
155511  100.227  -78.667  45.224  1
155512  100.261  -78.682  45.209  1
155513  100.272  -78.684  45.193  1
155514  100.290  -78.687  45.177  1
155515  100.309  -78.690  45.160  1
155516  100.327  -78.693  45.143  1
155517  100.346  -78.696  45.126  1
155518  100.364  -78.700  45.108  1
155519  100.383  -78.711  45.091  1
155520  100.402  -78.723  45.073  1
155521  100.421  -78.735  45.056  1
155522  100.440  -78.746  45.039  1
155523  100.459  -78.758  45.023  1
155524  100.479  -78.767  45.006  1
155525  100.499  -78.774  44.989  1
155526  100.521  -78.781  44.973  1
155527  100.541  -78.788  44.956  1
155528  100.562  -78.795  44.940  1
155529  100.583  -78.802  44.924  1
155530  100.605  -78.808  44.909  1
155531  100.616  -78.828  44.892  1
155532  100.622  -78.855  44.875  1
155533  100.628  -78.880  44.858  1
155534  100.634  -78.906  44.841  1
155535  100.643  -78.930  44.826  1
155536  100.671  -78.942  44.810  1
155537  100.700  -78.952  44.793  1
155538  100.728  -78.964  44.776  1
155539  100.756  -78.973  44.759  1
155540  100.777  -78.986  44.742  1
155541  100.817  -79.006  44.726  1
155542  100.860  -79.012  44.710  1
155543  100.904  -79.018  44.695  1
155544  100.948  -79.024  44.679  1
155545  101.006  -79.015  44.664  1
155546  101.085  -78.990  44.648  1
155547  101.136  -78.996  44.631  1
155548  101.188  -79.002  44.615  1
155549  101.240  -79.009  44.601  1
155550  101.264  -79.023  44.587  1
155551  101.288  -79.037  44.573  1
155552  101.313  -79.049  44.560  1
155553  101.337  -79.063  44.547  1
155554  101.361  -79.077  44.534  1
155555  101.386  -79.090  44.521  1
155556  101.406  -79.117  44.509  1
155557  101.422  -79.151  44.496  1
155558  101.450  -79.179  44.484  1
155784  92.520  -77.611  54.166  1
155785  92.540  -77.619  54.170  1
155786  92.560  -77.627  54.173  1
155787  92.580  -77.633  54.177  1
155788  92.600  -77.641  54.179  1
155789  92.620  -77.649  54.181  1
155790  92.640  -77.656  54.184  1
155791  92.660  -77.663  54.186  1
155792  92.680  -77.671  54.189  1
155793  92.700  -77.678  54.192  1
155794  92.720  -77.685  54.194  1
155795  92.740  -77.692  54.196  1
155796  92.760  -77.700  54.198  1
155797  92.780  -77.707  54.199  1
155798  92.800  -77.714  54.201  1
155799  92.819  -77.722  54.204  1
155800  92.840  -77.729  54.207  1
155801  92.859  -77.736  54.210  1
155802  92.884  -77.734  54.213  1
155803  92.911  -77.722  54.216  1
155804  92.927  -77.717  54.220  1
155805  92.944  -77.711  54.223  1
155806  92.960  -77.705  54.227  1
155807  92.974  -77.697  54.232  1
155808  92.987  -77.688  54.238  1
155809  93.001  -77.679  54.245  1
155810  93.014  -77.670  54.251  1
155811  93.028  -77.661  54.256  1
155812  93.042  -77.652  54.261  1
155813  93.055  -77.643  54.264  1
155814  93.068  -77.636  54.266  1
155815  93.080  -77.630  54.266  1
155816  93.092  -77.624  54.265  1
155817  93.105  -77.617  54.262  1
155818  93.117  -77.611  54.260  1
155819  93.129  -77.608  54.259  1
155820  93.141  -77.605  54.260  1
155821  93.152  -77.602  54.260  1
155822  93.163  -77.587  54.260  1
155823  93.174  -77.572  54.260  1
155824  93.186  -77.558  54.260  1
155825  93.197  -77.543  54.258  1
155826  93.209  -77.528  54.253  1
155827  93.220  -77.514  54.248  1
155828  93.231  -77.499  54.243  1
155829  93.255  -77.491  54.238  1
155830  93.279  -77.483  54.233  1
155831  93.303  -77.474  54.226  1
155832  93.320  -77.465  54.219  1
155833  93.334  -77.456  54.212  1
155834  93.347  -77.447  54.208  1
155835  93.360  -77.438  54.203  1
155836  93.374  -77.429  54.198  1
155837  93.387  -77.420  54.191  1
155838  93.401  -77.410  54.182  1
155839  93.414  -77.401  54.173  1
155840  93.427  -77.392  54.166  1
155841  93.443  -77.384  54.160  1
155842  93.459  -77.376  54.152  1
155843  93.475  -77.371  54.142  1
155844  93.492  -77.365  54.131  1
155845  93.511  -77.359  54.117  1
155846  93.530  -77.353  54.103  1
155847  93.548  -77.348  54.089  1
155848  93.567  -77.341  54.075  1
155849  93.588  -77.332  54.060  1
155850  93.609  -77.323  54.047  1
155851  93.629  -77.315  54.035  1
155852  93.650  -77.306  54.019  1
155853  93.667  -77.298  54.003  1
155854  93.683  -77.288  53.987  1
155855  93.698  -77.279  53.972  1
155856  93.714  -77.270  53.956  1
155857  93.731  -77.261  53.941  1
155858  93.753  -77.250  53.926  1
155859  93.775  -77.239  53.908  1
155860  93.796  -77.228  53.889  1
155861  93.806  -77.197  53.869  1
155862  93.818  -77.183  53.849  1
155863  93.830  -77.170  53.827  1
155864  93.841  -77.150  53.806  1
155865  93.847  -77.163  53.786  1
155866  93.854  -77.174  53.764  1
155867  93.860  -77.185  53.745  1
155868  93.867  -77.197  53.727  1
155869  93.873  -77.207  53.709  1
155870  93.880  -77.219  53.690  1
155871  93.886  -77.230  53.673  1
155872  93.896  -77.232  53.656  1
155873  93.912  -77.222  53.638  1
155874  93.928  -77.212  53.618  1
155875  93.944  -77.201  53.600  1
155876  93.960  -77.191  53.583  1
155877  93.976  -77.182  53.568  1
155878  93.994  -77.173  53.552  1
155879  94.018  -77.171  53.536  1
155880  94.042  -77.169  53.520  1
155881  94.067  -77.166  53.504  1
155882  94.098  -77.166  53.488  1
155883  94.129  -77.166  53.474  1
155884  94.160  -77.166  53.461  1
155885  94.191  -77.165  53.450  1
155886  94.222  -77.164  53.441  1
155887  94.254  -77.163  53.434  1
155888  94.285  -77.163  53.431  1
155889  94.297  -77.153  53.430  1
155890  94.302  -77.141  53.428  1
155891  94.307  -77.129  53.426  1
155892  94.306  -77.118  53.424  1
155893  94.303  -77.107  53.418  1
155894  94.305  -77.100  53.410  1
155895  94.312  -77.101  53.403  1
155896  94.319  -77.101  53.398  1
155897  94.327  -77.102  53.395  1
155898  94.331  -77.100  53.395  1
155899  94.331  -77.097  53.398  1
155900  94.332  -77.092  53.399  1
155901  94.332  -77.088  53.398  1
155902  94.333  -77.085  53.396  1
155903  94.333  -77.081  53.393  1
155904  94.334  -77.077  53.385  1
155905  94.335  -77.073  53.374  1
155906  94.346  -77.069  53.360  1
155907  94.367  -77.065  53.338  1
155908  94.389  -77.061  53.313  1
155909  94.410  -77.056  53.288  1
155910  94.431  -77.053  53.263  1
155911  94.452  -77.049  53.240  1
155912  94.473  -77.044  53.219  1
155913  94.494  -77.041  53.198  1
155914  94.516  -77.036  53.175  1
155915  94.537  -77.032  53.151  1
155916  94.558  -77.028  53.129  1
155917  94.579  -77.024  53.110  1
155918  94.605  -77.020  53.090  1
155919  94.624  -77.016  53.070  1
155920  94.632  -77.010  53.049  1
155921  94.643  -77.009  53.024  1
155922  94.654  -77.009  53.000  1
155923  94.667  -77.009  52.975  1
155924  94.679  -77.012  52.947  1
155925  94.692  -77.014  52.916  1
155926  94.704  -77.016  52.881  1
155927  94.717  -77.019  52.842  1
155928  94.730  -77.021  52.801  1
155929  94.766  -77.027  52.758  1
155930  94.806  -77.034  52.712  1
155931  94.846  -77.041  52.663  1
155932  94.856  -77.044  52.611  1
155933  94.864  -77.046  52.558  1
155934  94.873  -77.049  52.508  1
155935  94.887  -77.054  52.462  1
155936  94.906  -77.061  52.418  1
155937  94.925  -77.068  52.376  1
155938  94.944  -77.075  52.337  1
155939  94.960  -77.069  52.298  1
155940  94.976  -77.064  52.264  1
155941  94.996  -77.065  52.230  1
155942  95.017  -77.068  52.198  1
155943  95.038  -77.071  52.171  1
155944  95.058  -77.074  52.140  1
155945  95.079  -77.077  52.106  1
155946  95.100  -77.081  52.067  1
155947  95.120  -77.085  52.023  1
155948  95.140  -77.090  51.980  1
155949  95.160  -77.094  51.936  1
155950  95.180  -77.099  51.890  1
155951  95.200  -77.103  51.839  1
155952  95.213  -77.103  51.788  1
155953  95.224  -77.100  51.736  1
155954  95.235  -77.098  51.679  1
155955  95.245  -77.096  51.625  1
155956  95.256  -77.094  51.572  1
155957  95.267  -77.091  51.520  1
155958  95.279  -77.091  51.470  1
155959  95.295  -77.088  51.420  1
155960  95.317  -77.103  51.371  1
155961  95.339  -77.118  51.322  1
155962  95.361  -77.132  51.277  1
155963  95.384  -77.147  51.231  1
155964  95.406  -77.162  51.185  1
155965  95.428  -77.177  51.135  1
155966  95.450  -77.191  51.083  1
155967  95.470  -77.207  51.032  1
155968  95.487  -77.221  50.985  1
155969  95.506  -77.235  50.941  1
155970  95.523  -77.251  50.898  1
155971  95.541  -77.265  50.855  1
155972  95.558  -77.280  50.810  1
155973  95.577  -77.294  50.766  1
155974  95.594  -77.309  50.721  1
155975  95.612  -77.324  50.676  1
155976  95.627  -77.335  50.632  1
155977  95.642  -77.345  50.590  1
155978  95.658  -77.356  50.548  1
155979  95.676  -77.367  50.505  1
155980  95.693  -77.378  50.463  1
155981  95.711  -77.389  50.424  1
155982  95.728  -77.401  50.387  1
155983  95.745  -77.414  50.352  1
155984  95.764  -77.426  50.316  1
155985  95.785  -77.438  50.279  1
155986  95.807  -77.450  50.240  1
155987  95.828  -77.461  50.201  1
155988  95.849  -77.473  50.161  1
155989  95.870  -77.483  50.119  1
155990  95.890  -77.494  50.076  1
155991  95.911  -77.504  50.031  1
155992  95.931  -77.515  49.985  1
155993  95.952  -77.523  49.935  1
155994  95.964  -77.522  49.880  1
155995  95.976  -77.516  49.823  1
155996  95.987  -77.511  49.769  1
155997  95.999  -77.505  49.718  1
155998  96.010  -77.501  49.670  1
155999  96.017  -77.509  49.622  1
156000  96.025  -77.517  49.575  1
156001  96.032  -77.525  49.530  1
156002  96.040  -77.533  49.484  1
156003  96.048  -77.541  49.443  1
156004  96.056  -77.546  49.403  1
156005  96.065  -77.546  49.364  1
156006  96.075  -77.546  49.327  1
156007  96.085  -77.541  49.292  1
156008  96.097  -77.520  49.257  1
156009  96.104  -77.504  49.225  1
156010  96.112  -77.489  49.196  1
156011  96.120  -77.480  49.167  1
156012  96.128  -77.476  49.139  1
156013  96.135  -77.471  49.112  1
156014  96.144  -77.467  49.086  1
156015  96.143  -77.475  49.060  1
156016  96.139  -77.486  49.034  1
156017  96.136  -77.497  49.013  1
156018  96.132  -77.518  48.992  1
156019  96.147  -77.526  48.971  1
156020  96.160  -77.537  48.952  1
156021  96.174  -77.548  48.933  1
156022  96.188  -77.560  48.913  1
156023  96.202  -77.571  48.890  1
156024  96.216  -77.583  48.868  1
156025  96.230  -77.594  48.845  1
156026  96.244  -77.606  48.822  1
156027  96.258  -77.618  48.798  1
156028  96.276  -77.628  48.774  1
156029  96.302  -77.639  48.749  1
156030  96.327  -77.649  48.725  1
156031  96.352  -77.659  48.701  1
156032  96.377  -77.670  48.679  1
156033  96.402  -77.680  48.656  1
156034  96.428  -77.690  48.634  1
156035  96.448  -77.696  48.611  1
156036  96.468  -77.700  48.588  1
156037  96.488  -77.705  48.567  1
156038  96.509  -77.710  48.548  1
156039  96.526  -77.714  48.529  1
156040  96.537  -77.718  48.510  1
156041  96.549  -77.721  48.492  1
156042  96.560  -77.725  48.476  1
156043  96.569  -77.727  48.458  1
156044  96.576  -77.729  48.438  1
156045  96.583  -77.730  48.416  1
156046  96.589  -77.732  48.393  1
156047  96.596  -77.733  48.370  1
156048  96.603  -77.734  48.347  1
156049  96.610  -77.736  48.324  1
156050  96.617  -77.737  48.302  1
156051  96.624  -77.740  48.282  1
156052  96.633  -77.746  48.262  1
156053  96.643  -77.752  48.241  1
156054  96.653  -77.759  48.218  1
156055  96.663  -77.765  48.194  1
156056  96.677  -77.768  48.170  1
156057  96.691  -77.771  48.145  1
156058  96.705  -77.773  48.122  1
156059  96.720  -77.775  48.100  1
156060  96.734  -77.777  48.078  1
156061  96.748  -77.780  48.053  1
156062  96.762  -77.783  48.028  1
156063  96.777  -77.779  48.001  1
156064  96.792  -77.767  47.975  1
156065  96.806  -77.755  47.948  1
156066  96.822  -77.744  47.923  1
156067  96.844  -77.755  47.898  1
156068  96.866  -77.765  47.873  1
156069  96.888  -77.775  47.848  1
156070  96.910  -77.786  47.824  1
156071  96.933  -77.795  47.801  1
156072  96.956  -77.796  47.778  1
156073  96.979  -77.796  47.756  1
156074  97.000  -77.797  47.734  1
156075  97.012  -77.796  47.712  1
156076  97.025  -77.796  47.690  1
156077  97.037  -77.796  47.669  1
156078  97.050  -77.795  47.648  1
156079  97.063  -77.794  47.627  1
156080  97.075  -77.795  47.606  1
156081  97.086  -77.799  47.584  1
156082  97.099  -77.790  47.563  1
156083  97.113  -77.782  47.543  1
156084  97.131  -77.782  47.522  1
156085  97.152  -77.787  47.503  1
156086  97.172  -77.793  47.482  1
156087  97.193  -77.798  47.462  1
156088  97.217  -77.797  47.442  1
156089  97.240  -77.796  47.423  1
156090  97.264  -77.796  47.405  1
156091  97.288  -77.795  47.387  1
156092  97.311  -77.794  47.370  1
156093  97.334  -77.793  47.352  1
156094  97.358  -77.793  47.335  1
156095  97.382  -77.792  47.318  1
156096  97.405  -77.791  47.301  1
156097  97.435  -77.799  47.284  1
156098  97.465  -77.808  47.267  1
156099  97.478  -77.813  47.248  1
156100  97.494  -77.828  47.229  1
156101  97.509  -77.843  47.208  1
156102  97.525  -77.859  47.187  1
156103  97.540  -77.874  47.166  1
156104  97.556  -77.889  47.144  1
156105  97.572  -77.904  47.122  1
156106  97.587  -77.920  47.100  1
156107  97.603  -77.935  47.077  1
156108  97.618  -77.950  47.056  1
156109  97.634  -77.965  47.032  1
156110  97.631  -77.993  47.007  1
156111  97.628  -78.021  46.983  1
156112  97.625  -78.048  46.958  1
156113  97.623  -78.075  46.933  1
156114  97.624  -78.093  46.909  1
156115  97.624  -78.110  46.885  1
156116  97.642  -78.134  46.861  1
156117  97.662  -78.126  46.837  1
156118  97.702  -78.103  46.815  1
156119  97.737  -78.091  46.793  1
156120  97.772  -78.080  46.773  1
156121  97.806  -78.069  46.753  1
156122  97.842  -78.056  46.733  1
156123  97.876  -78.045  46.716  1
156124  97.908  -78.028  46.697  1
156125  97.940  -78.039  46.677  1
156126  97.972  -78.055  46.658  1
156127  98.005  -78.072  46.637  1
156128  98.036  -78.089  46.616  1
156129  98.061  -78.108  46.593  1
156130  98.102  -78.100  46.570  1
156131  98.139  -78.085  46.546  1
156132  98.176  -78.071  46.523  1
156133  98.213  -78.056  46.500  1
156134  98.249  -78.042  46.479  1
156135  98.286  -78.028  46.457  1
156136  98.323  -78.012  46.434  1
156137  98.359  -77.998  46.410  1
156138  98.396  -77.984  46.386  1
156139  98.433  -77.969  46.362  1
156140  98.469  -77.955  46.339  1
156141  98.506  -77.940  46.316  1
156142  98.543  -77.925  46.294  1
156143  98.580  -77.911  46.271  1
156144  98.617  -77.896  46.249  1
156145  98.634  -77.923  46.226  1
156146  98.646  -77.959  46.204  1
156147  98.659  -77.995  46.182  1
156148  98.672  -78.031  46.161  1
156149  98.673  -78.048  46.139  1
156150  98.660  -78.044  46.118  1
156151  98.647  -78.039  46.098  1
156152  98.647  -78.046  46.078  1
156153  98.648  -78.053  46.058  1
156154  98.649  -78.060  46.039  1
156155  98.650  -78.067  46.020  1
156156  98.650  -78.075  46.001  1
156157  98.651  -78.081  45.982  1
156158  98.652  -78.089  45.963  1
156159  98.653  -78.096  45.945  1
156160  98.657  -78.103  45.925  1
156161  98.710  -78.111  45.906  1
156162  98.763  -78.119  45.888  1
156163  98.815  -78.127  45.871  1
156164  98.868  -78.134  45.854  1
156165  98.921  -78.143  45.837  1
156166  98.973  -78.150  45.821  1
156167  99.026  -78.158  45.805  1
156168  99.079  -78.166  45.789  1
156169  99.131  -78.174  45.774  1
156170  99.156  -78.178  45.761  1
156171  99.161  -78.179  45.746  1
156172  99.167  -78.180  45.733  1
156173  99.172  -78.181  45.720  1
156174  99.183  -78.182  45.707  1
156175  99.207  -78.181  45.695  1
156176  99.229  -78.183  45.684  1
156177  99.252  -78.185  45.672  1
156178  99.274  -78.188  45.661  1
156179  99.296  -78.190  45.650  1
156180  99.318  -78.192  45.638  1
156181  99.340  -78.194  45.626  1
156182  99.362  -78.197  45.614  1
156183  99.384  -78.199  45.602  1
156184  99.407  -78.201  45.591  1
156185  99.429  -78.203  45.579  1
156186  99.452  -78.209  45.567  1
156187  99.482  -78.228  45.556  1
156188  99.511  -78.247  45.545  1
156189  99.540  -78.266  45.534  1
156190  99.569  -78.286  45.522  1
156191  99.597  -78.305  45.511  1
156192  99.626  -78.324  45.501  1
156193  99.655  -78.344  45.490  1
156194  99.684  -78.363  45.479  1
156195  99.713  -78.382  45.468  1
156196  99.739  -78.408  45.457  1
156197  99.769  -78.435  45.444  1
156198  99.792  -78.477  45.432  1
156199  99.811  -78.496  45.418  1
156200  99.832  -78.508  45.405  1
156201  99.860  -78.507  45.393  1
156202  99.894  -78.523  45.380  1
156203  99.927  -78.537  45.366  1
156204  99.960  -78.552  45.351  1
156205  99.994  -78.567  45.337  1
156206  100.027  -78.582  45.323  1
156207  100.060  -78.596  45.309  1
156208  100.093  -78.611  45.294  1
156209  100.127  -78.626  45.278  1
156210  100.160  -78.641  45.264  1
156211  100.194  -78.655  45.248  1
156212  100.227  -78.670  45.232  1
156213  100.261  -78.685  45.216  1
156214  100.294  -78.700  45.200  1
156215  100.296  -78.697  45.183  1
156216  100.315  -78.700  45.167  1
156217  100.333  -78.703  45.150  1
156218  100.352  -78.707  45.133  1
156219  100.370  -78.710  45.115  1
156220  100.388  -78.713  45.097  1
156221  100.407  -78.716  45.081  1
156222  100.426  -78.727  45.064  1
156223  100.445  -78.738  45.047  1
156224  100.464  -78.750  45.029  1
156225  100.485  -78.758  45.013  1
156226  100.505  -78.765  44.997  1
156227  100.527  -78.772  44.981  1
156228  100.548  -78.779  44.965  1
156229  100.569  -78.786  44.949  1
156230  100.590  -78.793  44.933  1
156231  100.611  -78.800  44.917  1
156232  100.627  -78.813  44.900  1
156233  100.633  -78.839  44.884  1
156234  100.639  -78.865  44.867  1
156235  100.645  -78.891  44.850  1
156236  100.665  -78.908  44.834  1
156237  100.693  -78.919  44.818  1
156238  100.721  -78.930  44.801  1
156239  100.749  -78.941  44.785  1
156240  100.777  -78.952  44.768  1
156241  100.805  -78.967  44.752  1
156242  100.848  -78.972  44.735  1
156243  100.892  -78.978  44.719  1
156244  100.936  -78.984  44.703  1
156245  100.979  -78.990  44.688  1
156246  101.023  -78.996  44.672  1
156247  101.067  -79.002  44.656  1
156248  101.141  -78.980  44.640  1
156249  101.194  -78.987  44.624  1
156250  101.239  -78.994  44.610  1
156251  101.263  -79.008  44.596  1
156252  101.287  -79.021  44.582  1
156253  101.312  -79.035  44.568  1
156254  101.336  -79.048  44.556  1
156255  101.360  -79.062  44.543  1
156256  101.385  -79.075  44.530  1
156257  101.404  -79.104  44.517  1
156258  101.420  -79.138  44.505  1
156259  101.450  -79.165  44.493  1
156485  92.509  -77.592  54.155  1
156486  92.529  -77.599  54.160  1
156487  92.549  -77.606  54.164  1
156488  92.569  -77.614  54.169  1
156489  92.589  -77.621  54.173  1
156490  92.609  -77.628  54.176  1
156491  92.629  -77.636  54.180  1
156492  92.649  -77.643  54.184  1
156493  92.669  -77.651  54.188  1
156494  92.689  -77.658  54.194  1
156495  92.709  -77.665  54.195  1
156496  92.729  -77.673  54.197  1
156497  92.748  -77.680  54.201  1
156498  92.769  -77.687  54.202  1
156499  92.789  -77.695  54.204  1
156500  92.808  -77.702  54.208  1
156501  92.829  -77.709  54.212  1
156502  92.849  -77.717  54.215  1
156503  92.873  -77.714  54.218  1
156504  92.901  -77.702  54.222  1
156505  92.918  -77.696  54.227  1
156506  92.934  -77.690  54.231  1
156507  92.947  -77.682  54.236  1
156508  92.961  -77.673  54.240  1
156509  92.975  -77.664  54.247  1
156510  92.988  -77.655  54.253  1
156511  93.002  -77.646  54.258  1
156512  93.015  -77.637  54.263  1
156513  93.028  -77.628  54.268  1
156514  93.042  -77.620  54.273  1
156515  93.055  -77.612  54.275  1
156516  93.067  -77.608  54.275  1
156517  93.079  -77.604  54.275  1
156518  93.091  -77.601  54.274  1
156519  93.102  -77.598  54.272  1
156520  93.114  -77.595  54.270  1
156521  93.126  -77.591  54.271  1
156522  93.138  -77.587  54.273  1
156523  93.148  -77.570  54.273  1
156524  93.159  -77.554  54.275  1
156525  93.170  -77.539  54.275  1
156526  93.182  -77.524  54.273  1
156527  93.193  -77.510  54.270  1
156528  93.205  -77.495  54.266  1
156529  93.223  -77.484  54.262  1
156530  93.247  -77.476  54.258  1
156531  93.271  -77.468  54.253  1
156532  93.295  -77.460  54.247  1
156533  93.316  -77.451  54.241  1
156534  93.330  -77.442  54.234  1
156535  93.343  -77.433  54.231  1
156536  93.356  -77.424  54.227  1
156537  93.370  -77.415  54.223  1
156538  93.383  -77.405  54.216  1
156539  93.397  -77.396  54.207  1
156540  93.410  -77.387  54.199  1
156541  93.423  -77.378  54.190  1
156542  93.437  -77.369  54.185  1
156543  93.450  -77.360  54.178  1
156544  93.466  -77.351  54.168  1
156545  93.485  -77.345  54.156  1
156546  93.503  -77.340  54.142  1
156547  93.522  -77.334  54.129  1
156548  93.541  -77.328  54.115  1
156549  93.560  -77.320  54.102  1
156550  93.581  -77.312  54.089  1
156551  93.602  -77.304  54.076  1
156552  93.622  -77.294  54.063  1
156553  93.643  -77.286  54.049  1
156554  93.663  -77.277  54.033  1
156555  93.684  -77.269  54.017  1
156556  93.703  -77.260  54.001  1
156557  93.718  -77.251  53.985  1
156558  93.733  -77.242  53.970  1
156559  93.753  -77.232  53.955  1
156560  93.775  -77.221  53.938  1
156561  93.790  -77.197  53.919  1
156562  93.801  -77.185  53.899  1
156563  93.815  -77.177  53.879  1
156564  93.826  -77.162  53.857  1
156565  93.835  -77.145  53.836  1
156566  93.837  -77.140  53.815  1
156567  93.842  -77.148  53.794  1
156568  93.848  -77.161  53.774  1
156569  93.854  -77.173  53.756  1
156570  93.860  -77.186  53.739  1
156571  93.866  -77.198  53.720  1
156572  93.872  -77.210  53.704  1
156573  93.896  -77.210  53.686  1
156574  93.909  -77.204  53.666  1
156575  93.925  -77.194  53.646  1
156576  93.941  -77.184  53.626  1
156577  93.957  -77.174  53.608  1
156578  93.973  -77.164  53.591  1
156579  93.991  -77.157  53.575  1
156580  94.015  -77.153  53.559  1
156581  94.039  -77.151  53.542  1
156582  94.063  -77.149  53.526  1
156583  94.088  -77.146  53.509  1
156584  94.119  -77.145  53.493  1
156585  94.150  -77.144  53.480  1
156586  94.182  -77.144  53.467  1
156587  94.213  -77.143  53.455  1
156588  94.245  -77.142  53.446  1
156589  94.274  -77.141  53.441  1
156590  94.279  -77.128  53.439  1
156591  94.284  -77.116  53.438  1
156592  94.289  -77.104  53.436  1
156593  94.294  -77.092  53.433  1
156594  94.300  -77.082  53.426  1
156595  94.308  -77.083  53.417  1
156596  94.315  -77.083  53.407  1
156597  94.322  -77.084  53.400  1
156598  94.330  -77.085  53.397  1
156599  94.335  -77.083  53.396  1
156600  94.335  -77.079  53.399  1
156601  94.336  -77.075  53.402  1
156602  94.336  -77.072  53.403  1
156603  94.337  -77.068  53.402  1
156604  94.337  -77.064  53.401  1
156605  94.337  -77.060  53.395  1
156606  94.336  -77.059  53.385  1
156607  94.350  -77.055  53.371  1
156608  94.369  -77.050  53.349  1
156609  94.390  -77.047  53.325  1
156610  94.411  -77.042  53.298  1
156611  94.432  -77.038  53.271  1
156612  94.454  -77.034  53.246  1
156613  94.475  -77.030  53.223  1
156614  94.496  -77.026  53.201  1
156615  94.517  -77.022  53.178  1
156616  94.538  -77.018  53.154  1
156617  94.559  -77.013  53.130  1
156618  94.582  -77.009  53.109  1
156619  94.611  -77.006  53.090  1
156620  94.625  -77.001  53.069  1
156621  94.633  -76.996  53.046  1
156622  94.643  -76.993  53.020  1
156623  94.654  -76.993  52.996  1
156624  94.666  -76.992  52.970  1
156625  94.678  -76.993  52.942  1
156626  94.691  -76.995  52.911  1
156627  94.703  -76.997  52.875  1
156628  94.716  -77.000  52.837  1
156629  94.728  -77.003  52.795  1
156630  94.767  -77.009  52.753  1
156631  94.807  -77.016  52.709  1
156632  94.847  -77.022  52.663  1
156633  94.871  -77.026  52.613  1
156634  94.879  -77.029  52.562  1
156635  94.887  -77.032  52.512  1
156636  94.895  -77.034  52.466  1
156637  94.910  -77.040  52.427  1
156638  94.929  -77.047  52.390  1
156639  94.948  -77.053  52.354  1
156640  94.965  -77.050  52.320  1
156641  94.981  -77.046  52.286  1
156642  95.002  -77.049  52.257  1
156643  95.023  -77.052  52.232  1
156644  95.044  -77.055  52.211  1
156645  95.064  -77.059  52.181  1
156646  95.085  -77.063  52.145  1
156647  95.105  -77.067  52.106  1
156648  95.125  -77.072  52.062  1
156649  95.145  -77.076  52.019  1
156650  95.165  -77.081  51.974  1
156651  95.185  -77.085  51.925  1
156652  95.205  -77.089  51.871  1
156653  95.222  -77.091  51.818  1
156654  95.233  -77.089  51.764  1
156655  95.243  -77.087  51.707  1
156656  95.254  -77.085  51.652  1
156657  95.264  -77.082  51.597  1
156658  95.275  -77.080  51.543  1
156659  95.285  -77.078  51.494  1
156660  95.303  -77.089  51.444  1
156661  95.321  -77.103  51.394  1
156662  95.342  -77.117  51.344  1
156663  95.365  -77.132  51.296  1
156664  95.387  -77.147  51.250  1
156665  95.409  -77.161  51.204  1
156666  95.431  -77.176  51.155  1
156667  95.453  -77.191  51.103  1
156668  95.473  -77.206  51.052  1
156669  95.491  -77.220  51.004  1
156670  95.509  -77.235  50.961  1
156671  95.526  -77.250  50.916  1
156672  95.544  -77.264  50.870  1
156673  95.562  -77.279  50.824  1
156674  95.578  -77.291  50.778  1
156675  95.593  -77.301  50.733  1
156676  95.608  -77.313  50.688  1
156677  95.622  -77.323  50.645  1
156678  95.637  -77.334  50.603  1
156679  95.655  -77.345  50.561  1
156680  95.672  -77.356  50.518  1
156681  95.690  -77.367  50.476  1
156682  95.707  -77.378  50.436  1
156683  95.725  -77.389  50.398  1
156684  95.745  -77.396  50.361  1
156685  95.762  -77.405  50.324  1
156686  95.782  -77.416  50.286  1
156687  95.803  -77.426  50.248  1
156688  95.823  -77.437  50.208  1
156689  95.843  -77.448  50.167  1
156690  95.864  -77.458  50.125  1
156691  95.884  -77.469  50.083  1
156692  95.904  -77.479  50.039  1
156693  95.925  -77.490  49.993  1
156694  95.952  -77.499  49.944  1
156695  95.966  -77.504  49.889  1
156696  95.979  -77.506  49.833  1
156697  95.990  -77.500  49.780  1
156698  96.002  -77.495  49.728  1
156699  96.013  -77.489  49.679  1
156700  96.021  -77.498  49.631  1
156701  96.028  -77.506  49.584  1
156702  96.036  -77.514  49.538  1
156703  96.043  -77.522  49.493  1
156704  96.051  -77.530  49.451  1
156705  96.058  -77.538  49.412  1
156706  96.066  -77.544  49.372  1
156707  96.076  -77.544  49.335  1
156708  96.087  -77.538  49.299  1
156709  96.096  -77.520  49.263  1
156710  96.104  -77.504  49.231  1
156711  96.112  -77.499  49.200  1
156712  96.119  -77.495  49.171  1
156713  96.127  -77.491  49.142  1
156714  96.135  -77.486  49.114  1
156715  96.143  -77.482  49.088  1
156716  96.149  -77.479  49.061  1
156717  96.146  -77.491  49.035  1
156718  96.143  -77.501  49.013  1
156719  96.144  -77.511  48.993  1
156720  96.152  -77.521  48.973  1
156721  96.167  -77.534  48.956  1
156722  96.181  -77.546  48.939  1
156723  96.195  -77.558  48.921  1
156724  96.209  -77.571  48.900  1
156725  96.224  -77.583  48.878  1
156726  96.238  -77.595  48.855  1
156727  96.251  -77.605  48.832  1
156728  96.262  -77.609  48.808  1
156729  96.279  -77.617  48.784  1
156730  96.308  -77.627  48.760  1
156731  96.336  -77.638  48.735  1
156732  96.362  -77.649  48.712  1
156733  96.387  -77.658  48.690  1
156734  96.412  -77.669  48.668  1
156735  96.438  -77.680  48.644  1
156736  96.463  -77.689  48.622  1
156737  96.483  -77.694  48.601  1
156738  96.503  -77.699  48.581  1
156739  96.523  -77.704  48.563  1
156740  96.540  -77.708  48.545  1
156741  96.551  -77.712  48.526  1
156742  96.562  -77.715  48.508  1
156743  96.572  -77.718  48.491  1
156744  96.579  -77.720  48.473  1
156745  96.586  -77.721  48.453  1
156746  96.592  -77.722  48.430  1
156747  96.599  -77.724  48.408  1
156748  96.606  -77.725  48.385  1
156749  96.613  -77.727  48.363  1
156750  96.620  -77.727  48.342  1
156751  96.626  -77.729  48.321  1
156752  96.633  -77.730  48.301  1
156753  96.643  -77.736  48.283  1
156754  96.652  -77.742  48.263  1
156755  96.662  -77.749  48.240  1
156756  96.671  -77.755  48.216  1
156757  96.685  -77.758  48.192  1
156758  96.699  -77.761  48.167  1
156759  96.714  -77.763  48.144  1
156760  96.728  -77.765  48.121  1
156761  96.742  -77.768  48.099  1
156762  96.756  -77.770  48.074  1
156763  96.770  -77.772  48.048  1
156764  96.785  -77.775  48.022  1
156765  96.799  -77.775  47.995  1
156766  96.814  -77.762  47.969  1
156767  96.829  -77.750  47.943  1
156768  96.848  -77.751  47.918  1
156769  96.870  -77.761  47.893  1
156770  96.892  -77.771  47.868  1
156771  96.914  -77.781  47.843  1
156772  96.937  -77.786  47.821  1
156773  96.960  -77.787  47.798  1
156774  96.983  -77.788  47.776  1
156775  97.005  -77.789  47.755  1
156776  97.018  -77.788  47.732  1
156777  97.030  -77.788  47.711  1
156778  97.043  -77.787  47.690  1
156779  97.055  -77.787  47.669  1
156780  97.067  -77.789  47.648  1
156781  97.078  -77.793  47.626  1
156782  97.090  -77.790  47.605  1
156783  97.104  -77.781  47.584  1
156784  97.117  -77.773  47.563  1
156785  97.131  -77.765  47.543  1
156786  97.149  -77.765  47.523  1
156787  97.169  -77.770  47.501  1
156788  97.190  -77.774  47.481  1
156789  97.214  -77.774  47.461  1
156790  97.237  -77.773  47.442  1
156791  97.261  -77.772  47.424  1
156792  97.285  -77.771  47.407  1
156793  97.308  -77.771  47.389  1
156794  97.332  -77.770  47.370  1
156795  97.361  -77.777  47.354  1
156796  97.391  -77.786  47.337  1
156797  97.422  -77.794  47.319  1
156798  97.452  -77.802  47.302  1
156799  97.482  -77.812  47.284  1
156800  97.493  -77.805  47.264  1
156801  97.507  -77.815  47.244  1
156802  97.523  -77.831  47.223  1
156803  97.538  -77.846  47.202  1
156804  97.554  -77.862  47.181  1
156805  97.570  -77.877  47.159  1
156806  97.585  -77.892  47.136  1
156807  97.601  -77.907  47.114  1
156808  97.616  -77.922  47.091  1
156809  97.632  -77.937  47.069  1
156810  97.642  -77.957  47.045  1
156811  97.639  -77.984  47.021  1
156812  97.636  -78.012  46.996  1
156813  97.633  -78.040  46.970  1
156814  97.631  -78.067  46.945  1
156815  97.628  -78.094  46.920  1
156816  97.628  -78.112  46.896  1
156817  97.645  -78.128  46.871  1
156818  97.665  -78.103  46.848  1
156819  97.710  -78.082  46.824  1
156820  97.745  -78.071  46.802  1
156821  97.780  -78.059  46.781  1
156822  97.814  -78.046  46.761  1
156823  97.846  -78.029  46.741  1
156824  97.877  -78.012  46.722  1
156825  97.908  -77.994  46.702  1
156826  97.940  -77.987  46.681  1
156827  97.972  -78.003  46.662  1
156828  98.003  -78.021  46.641  1
156829  98.025  -78.042  46.619  1
156830  98.046  -78.063  46.598  1
156831  98.064  -78.067  46.574  1
156832  98.146  -78.044  46.551  1
156833  98.192  -78.028  46.529  1
156834  98.229  -78.013  46.508  1
156835  98.266  -77.999  46.487  1
156836  98.302  -77.984  46.465  1
156837  98.339  -77.970  46.443  1
156838  98.376  -77.956  46.419  1
156839  98.413  -77.940  46.394  1
156840  98.449  -77.926  46.371  1
156841  98.486  -77.912  46.347  1
156842  98.522  -77.897  46.325  1
156843  98.559  -77.883  46.303  1
156844  98.596  -77.868  46.281  1
156845  98.628  -77.863  46.258  1
156846  98.641  -77.899  46.235  1
156847  98.653  -77.935  46.212  1
156848  98.666  -77.971  46.191  1
156849  98.679  -78.007  46.170  1
156850  98.685  -78.032  46.148  1
156851  98.672  -78.028  46.128  1
156852  98.664  -78.028  46.108  1
156853  98.665  -78.034  46.088  1
156854  98.665  -78.042  46.069  1
156855  98.666  -78.049  46.049  1
156856  98.667  -78.056  46.030  1
156857  98.668  -78.063  46.011  1
156858  98.668  -78.070  45.992  1
156859  98.669  -78.078  45.973  1
156860  98.670  -78.084  45.955  1
156861  98.671  -78.092  45.935  1
156862  98.699  -78.100  45.916  1
156863  98.751  -78.107  45.897  1
156864  98.804  -78.115  45.880  1
156865  98.857  -78.123  45.863  1
156866  98.909  -78.131  45.846  1
156867  98.962  -78.139  45.829  1
156868  99.015  -78.147  45.813  1
156869  99.067  -78.154  45.798  1
156870  99.114  -78.162  45.783  1
156871  99.119  -78.163  45.769  1
156872  99.124  -78.163  45.755  1
156873  99.130  -78.165  45.741  1
156874  99.144  -78.166  45.728  1
156875  99.199  -78.166  45.716  1
156876  99.218  -78.163  45.704  1
156877  99.237  -78.159  45.693  1
156878  99.256  -78.157  45.681  1
156879  99.278  -78.159  45.670  1
156880  99.300  -78.162  45.658  1
156881  99.322  -78.163  45.646  1
156882  99.344  -78.166  45.634  1
156883  99.366  -78.168  45.623  1
156884  99.389  -78.170  45.611  1
156885  99.411  -78.172  45.599  1
156886  99.433  -78.175  45.587  1
156887  99.460  -78.188  45.576  1
156888  99.490  -78.207  45.565  1
156889  99.520  -78.227  45.555  1
156890  99.549  -78.246  45.543  1
156891  99.577  -78.265  45.532  1
156892  99.607  -78.285  45.521  1
156893  99.635  -78.304  45.511  1
156894  99.664  -78.322  45.500  1
156895  99.693  -78.342  45.488  1
156896  99.719  -78.373  45.478  1
156897  99.753  -78.391  45.465  1
156898  99.786  -78.409  45.452  1
156899  99.820  -78.426  45.440  1
156900  99.859  -78.426  45.427  1
156901  99.862  -78.464  45.414  1
156902  99.854  -78.485  45.402  1
156903  99.883  -78.506  45.388  1
156904  99.919  -78.526  45.374  1
156905  99.956  -78.548  45.360  1
156906  99.992  -78.568  45.345  1
156907  100.027  -78.586  45.331  1
156908  100.060  -78.600  45.317  1
156909  100.093  -78.615  45.302  1
156910  100.127  -78.630  45.287  1
156911  100.160  -78.645  45.273  1
156912  100.193  -78.659  45.256  1
156913  100.226  -78.674  45.240  1
156914  100.260  -78.689  45.223  1
156915  100.293  -78.704  45.206  1
156916  100.327  -78.718  45.190  1
156917  100.321  -78.711  45.174  1
156918  100.340  -78.714  45.156  1
156919  100.358  -78.717  45.139  1
156920  100.376  -78.720  45.122  1
156921  100.395  -78.723  45.104  1
156922  100.414  -78.726  45.087  1
156923  100.432  -78.730  45.070  1
156924  100.451  -78.733  45.053  1
156925  100.470  -78.742  45.036  1
156926  100.490  -78.749  45.020  1
156927  100.511  -78.756  45.004  1
156928  100.533  -78.763  44.988  1
156929  100.554  -78.770  44.973  1
156930  100.575  -78.777  44.957  1
156931  100.596  -78.783  44.941  1
156932  100.617  -78.791  44.925  1
156933  100.638  -78.798  44.908  1
156934  100.645  -78.824  44.892  1
156935  100.651  -78.849  44.876  1
156936  100.658  -78.874  44.858  1
156937  100.686  -78.886  44.842  1
156938  100.714  -78.897  44.826  1
156939  100.743  -78.908  44.810  1
156940  100.771  -78.919  44.793  1
156941  100.796  -78.932  44.777  1
156942  100.822  -78.945  44.761  1
156943  100.868  -78.949  44.745  1
156944  100.916  -78.952  44.728  1
156945  100.963  -78.954  44.711  1
156946  101.010  -78.957  44.694  1
156947  101.055  -78.962  44.679  1
156948  101.098  -78.968  44.664  1
156949  101.142  -78.974  44.648  1
156950  101.199  -78.970  44.632  1
156951  101.238  -78.979  44.618  1
156952  101.262  -78.993  44.604  1
156953  101.286  -79.006  44.591  1
156954  101.311  -79.020  44.577  1
156955  101.335  -79.034  44.565  1
156956  101.359  -79.046  44.552  1
156957  101.384  -79.060  44.539  1
156958  101.402  -79.090  44.526  1
156959  101.419  -79.125  44.513  1
156960  101.449  -79.151  44.501  1
157186  92.498  -77.572  54.143  1
157187  92.518  -77.579  54.149  1
157188  92.538  -77.586  54.154  1
157189  92.558  -77.594  54.160  1
157190  92.578  -77.601  54.165  1
157191  92.598  -77.608  54.170  1
157192  92.618  -77.616  54.175  1
157193  92.638  -77.623  54.181  1
157194  92.658  -77.630  54.186  1
157195  92.678  -77.638  54.193  1
157196  92.698  -77.645  54.195  1
157197  92.718  -77.652  54.200  1
157198  92.738  -77.660  54.204  1
157199  92.758  -77.667  54.207  1
157200  92.778  -77.674  54.210  1
157201  92.797  -77.682  54.214  1
157202  92.817  -77.689  54.218  1
157203  92.838  -77.696  54.221  1
157204  92.862  -77.694  54.226  1
157205  92.890  -77.681  54.231  1
157206  92.908  -77.676  54.236  1
157207  92.921  -77.667  54.242  1
157208  92.935  -77.658  54.247  1
157209  92.948  -77.649  54.252  1
157210  92.961  -77.640  54.258  1
157211  92.976  -77.631  54.262  1
157212  92.990  -77.624  54.266  1
157213  93.004  -77.616  54.271  1
157214  93.018  -77.608  54.276  1
157215  93.032  -77.601  54.280  1
157216  93.042  -77.597  54.284  1
157217  93.053  -77.594  54.284  1
157218  93.064  -77.590  54.284  1
157219  93.076  -77.587  54.284  1
157220  93.087  -77.584  54.283  1
157221  93.099  -77.580  54.281  1
157222  93.111  -77.577  54.282  1
157223  93.123  -77.571  54.284  1
157224  93.133  -77.554  54.286  1
157225  93.144  -77.537  54.288  1
157226  93.155  -77.520  54.289  1
157227  93.166  -77.506  54.289  1
157228  93.178  -77.492  54.287  1
157229  93.191  -77.478  54.285  1
157230  93.215  -77.470  54.282  1
157231  93.239  -77.461  54.279  1
157232  93.264  -77.454  54.276  1
157233  93.288  -77.445  54.271  1
157234  93.312  -77.437  54.265  1
157235  93.326  -77.428  54.259  1
157236  93.339  -77.419  54.254  1
157237  93.352  -77.410  54.250  1
157238  93.365  -77.401  54.247  1
157239  93.379  -77.392  54.241  1
157240  93.393  -77.382  54.233  1
157241  93.406  -77.373  54.224  1
157242  93.419  -77.364  54.214  1
157243  93.431  -77.353  54.208  1
157244  93.441  -77.339  54.200  1
157245  93.460  -77.332  54.191  1
157246  93.478  -77.326  54.180  1
157247  93.496  -77.320  54.166  1
157248  93.515  -77.314  54.153  1
157249  93.534  -77.308  54.140  1
157250  93.553  -77.301  54.129  1
157251  93.574  -77.292  54.116  1
157252  93.594  -77.283  54.104  1
157253  93.615  -77.275  54.091  1
157254  93.636  -77.266  54.078  1
157255  93.656  -77.257  54.062  1
157256  93.677  -77.249  54.045  1
157257  93.698  -77.240  54.030  1
157258  93.718  -77.232  54.014  1
157259  93.738  -77.223  53.999  1
157260  93.754  -77.214  53.984  1
157261  93.773  -77.198  53.967  1
157262  93.785  -77.188  53.949  1
157263  93.798  -77.179  53.929  1
157264  93.811  -77.171  53.909  1
157265  93.822  -77.154  53.887  1
157266  93.825  -77.148  53.865  1
157267  93.827  -77.143  53.844  1
157268  93.829  -77.138  53.825  1
157269  93.833  -77.143  53.805  1
157270  93.839  -77.156  53.788  1
157271  93.845  -77.168  53.772  1
157272  93.851  -77.181  53.755  1
157273  93.868  -77.186  53.738  1
157274  93.897  -77.185  53.720  1
157275  93.908  -77.184  53.699  1
157276  93.921  -77.176  53.678  1
157277  93.937  -77.166  53.657  1
157278  93.954  -77.157  53.638  1
157279  93.970  -77.147  53.620  1
157280  93.988  -77.139  53.603  1
157281  94.012  -77.136  53.586  1
157282  94.036  -77.134  53.568  1
157283  94.060  -77.131  53.551  1
157284  94.083  -77.127  53.533  1
157285  94.110  -77.124  53.517  1
157286  94.141  -77.123  53.502  1
157287  94.173  -77.122  53.488  1
157288  94.204  -77.122  53.474  1
157289  94.236  -77.121  53.461  1
157290  94.257  -77.116  53.452  1
157291  94.262  -77.103  53.448  1
157292  94.267  -77.091  53.445  1
157293  94.272  -77.079  53.442  1
157294  94.280  -77.071  53.439  1
157295  94.293  -77.068  53.432  1
157296  94.308  -77.066  53.424  1
157297  94.318  -77.066  53.413  1
157298  94.325  -77.066  53.405  1
157299  94.333  -77.067  53.401  1
157300  94.339  -77.066  53.399  1
157301  94.339  -77.063  53.400  1
157302  94.340  -77.059  53.402  1
157303  94.340  -77.055  53.403  1
157304  94.341  -77.050  53.403  1
157305  94.340  -77.049  53.403  1
157306  94.338  -77.047  53.398  1
157307  94.338  -77.045  53.390  1
157308  94.356  -77.041  53.378  1
157309  94.374  -77.036  53.356  1
157310  94.393  -77.032  53.332  1
157311  94.413  -77.028  53.305  1
157312  94.434  -77.024  53.277  1
157313  94.455  -77.020  53.250  1
157314  94.476  -77.016  53.226  1
157315  94.497  -77.012  53.203  1
157316  94.519  -77.007  53.179  1
157317  94.540  -77.003  53.154  1
157318  94.561  -76.999  53.130  1
157319  94.589  -76.995  53.108  1
157320  94.617  -76.992  53.088  1
157321  94.626  -76.986  53.066  1
157322  94.634  -76.981  53.041  1
157323  94.642  -76.977  53.014  1
157324  94.654  -76.976  52.988  1
157325  94.666  -76.976  52.962  1
157326  94.678  -76.975  52.933  1
157327  94.689  -76.976  52.901  1
157328  94.702  -76.978  52.865  1
157329  94.714  -76.981  52.827  1
157330  94.728  -76.984  52.785  1
157331  94.768  -76.990  52.744  1
157332  94.808  -76.997  52.702  1
157333  94.848  -77.003  52.659  1
157334  94.886  -77.009  52.612  1
157335  94.894  -77.012  52.564  1
157336  94.902  -77.015  52.518  1
157337  94.910  -77.018  52.475  1
157338  94.918  -77.021  52.441  1
157339  94.933  -77.025  52.408  1
157340  94.952  -77.032  52.375  1
157341  94.969  -77.031  52.345  1
157342  94.987  -77.030  52.313  1
157343  95.008  -77.033  52.286  1
157344  95.029  -77.036  52.262  1
157345  95.049  -77.041  52.241  1
157346  95.069  -77.044  52.212  1
157347  95.090  -77.049  52.177  1
157348  95.110  -77.053  52.136  1
157349  95.130  -77.058  52.094  1
157350  95.150  -77.063  52.051  1
157351  95.170  -77.066  52.006  1
157352  95.190  -77.071  51.956  1
157353  95.210  -77.075  51.901  1
157354  95.230  -77.079  51.847  1
157355  95.241  -77.078  51.793  1
157356  95.251  -77.075  51.739  1
157357  95.262  -77.073  51.681  1
157358  95.273  -77.071  51.623  1
157359  95.283  -77.069  51.566  1
157360  95.300  -77.079  51.513  1
157361  95.318  -77.093  51.462  1
157362  95.336  -77.106  51.411  1
157363  95.354  -77.119  51.361  1
157364  95.373  -77.132  51.310  1
157365  95.390  -77.146  51.261  1
157366  95.412  -77.160  51.213  1
157367  95.434  -77.175  51.166  1
157368  95.456  -77.190  51.117  1
157369  95.476  -77.205  51.070  1
157370  95.494  -77.219  51.025  1
157371  95.512  -77.234  50.980  1
157372  95.529  -77.248  50.934  1
157373  95.544  -77.258  50.887  1
157374  95.558  -77.269  50.839  1
157375  95.573  -77.279  50.792  1
157376  95.589  -77.290  50.747  1
157377  95.603  -77.301  50.703  1
157378  95.618  -77.312  50.660  1
157379  95.633  -77.323  50.618  1
157380  95.651  -77.333  50.576  1
157381  95.669  -77.345  50.532  1
157382  95.687  -77.354  50.490  1
157383  95.707  -77.360  50.448  1
157384  95.727  -77.367  50.408  1
157385  95.747  -77.373  50.371  1
157386  95.755  -77.380  50.334  1
157387  95.776  -77.391  50.296  1
157388  95.796  -77.401  50.257  1
157389  95.817  -77.412  50.216  1
157390  95.837  -77.423  50.174  1
157391  95.858  -77.433  50.132  1
157392  95.878  -77.444  50.089  1
157393  95.898  -77.454  50.044  1
157394  95.920  -77.465  49.997  1
157395  95.952  -77.475  49.948  1
157396  95.965  -77.479  49.896  1
157397  95.979  -77.484  49.842  1
157398  95.993  -77.489  49.789  1
157399  96.005  -77.485  49.737  1
157400  96.016  -77.479  49.688  1
157401  96.024  -77.486  49.640  1
157402  96.031  -77.495  49.593  1
157403  96.039  -77.502  49.547  1
157404  96.047  -77.511  49.503  1
157405  96.054  -77.518  49.461  1
157406  96.062  -77.526  49.421  1
157407  96.070  -77.534  49.380  1
157408  96.077  -77.542  49.343  1
157409  96.088  -77.536  49.306  1
157410  96.096  -77.523  49.270  1
157411  96.103  -77.519  49.236  1
157412  96.111  -77.514  49.205  1
157413  96.119  -77.510  49.175  1
157414  96.127  -77.505  49.145  1
157415  96.135  -77.501  49.117  1
157416  96.143  -77.496  49.090  1
157417  96.151  -77.492  49.063  1
157418  96.153  -77.495  49.036  1
157419  96.155  -77.504  49.015  1
157420  96.159  -77.513  48.995  1
157421  96.164  -77.521  48.976  1
157422  96.174  -77.533  48.959  1
157423  96.189  -77.547  48.944  1
157424  96.203  -77.560  48.928  1
157425  96.218  -77.572  48.908  1
157426  96.231  -77.583  48.887  1
157427  96.243  -77.588  48.864  1
157428  96.254  -77.592  48.840  1
157429  96.265  -77.598  48.816  1
157430  96.282  -77.605  48.793  1
157431  96.310  -77.615  48.769  1
157432  96.339  -77.626  48.745  1
157433  96.368  -77.636  48.721  1
157434  96.396  -77.648  48.700  1
157435  96.422  -77.658  48.677  1
157436  96.448  -77.668  48.653  1
157437  96.473  -77.679  48.633  1
157438  96.497  -77.688  48.614  1
157439  96.517  -77.693  48.596  1
157440  96.537  -77.698  48.579  1
157441  96.553  -77.702  48.560  1
157442  96.565  -77.705  48.542  1
157443  96.575  -77.708  48.524  1
157444  96.582  -77.710  48.507  1
157445  96.589  -77.711  48.489  1
157446  96.596  -77.713  48.469  1
157447  96.602  -77.714  48.446  1
157448  96.609  -77.715  48.424  1
157449  96.616  -77.717  48.401  1
157450  96.623  -77.718  48.380  1
157451  96.630  -77.720  48.361  1
157452  96.637  -77.721  48.340  1
157453  96.644  -77.723  48.321  1
157454  96.651  -77.725  48.303  1
157455  96.661  -77.732  48.284  1
157456  96.670  -77.739  48.261  1
157457  96.680  -77.745  48.238  1
157458  96.693  -77.748  48.214  1
157459  96.708  -77.750  48.190  1
157460  96.722  -77.753  48.166  1
157461  96.736  -77.755  48.142  1
157462  96.750  -77.758  48.119  1
157463  96.764  -77.760  48.092  1
157464  96.779  -77.762  48.066  1
157465  96.793  -77.765  48.040  1
157466  96.807  -77.768  48.014  1
157467  96.821  -77.770  47.989  1
157468  96.836  -77.758  47.963  1
157469  96.852  -77.747  47.937  1
157470  96.873  -77.757  47.912  1
157471  96.895  -77.768  47.887  1
157472  96.918  -77.776  47.863  1
157473  96.941  -77.777  47.839  1
157474  96.964  -77.778  47.818  1
157475  96.987  -77.780  47.796  1
157476  97.011  -77.780  47.773  1
157477  97.023  -77.780  47.752  1
157478  97.036  -77.779  47.731  1
157479  97.048  -77.779  47.710  1
157480  97.060  -77.783  47.689  1
157481  97.071  -77.786  47.669  1
157482  97.081  -77.790  47.648  1
157483  97.095  -77.781  47.626  1
157484  97.108  -77.773  47.604  1
157485  97.121  -77.764  47.583  1
157486  97.135  -77.755  47.563  1
157487  97.148  -77.747  47.543  1
157488  97.166  -77.747  47.522  1
157489  97.187  -77.751  47.501  1
157490  97.211  -77.750  47.481  1
157491  97.235  -77.749  47.461  1
157492  97.258  -77.749  47.443  1
157493  97.287  -77.755  47.425  1
157494  97.317  -77.764  47.407  1
157495  97.348  -77.772  47.388  1
157496  97.378  -77.780  47.371  1
157497  97.408  -77.790  47.354  1
157498  97.438  -77.798  47.336  1
157499  97.468  -77.806  47.317  1
157500  97.499  -77.815  47.298  1
157501  97.512  -77.810  47.279  1
157502  97.521  -77.803  47.258  1
157503  97.536  -77.818  47.237  1
157504  97.552  -77.834  47.216  1
157505  97.568  -77.849  47.195  1
157506  97.583  -77.865  47.173  1
157507  97.599  -77.880  47.151  1
157508  97.614  -77.895  47.129  1
157509  97.630  -77.910  47.105  1
157510  97.645  -77.925  47.082  1
157511  97.650  -77.948  47.058  1
157512  97.647  -77.975  47.034  1
157513  97.644  -78.003  47.009  1
157514  97.641  -78.031  46.983  1
157515  97.639  -78.058  46.957  1
157516  97.636  -78.086  46.931  1
157517  97.633  -78.113  46.906  1
157518  97.647  -78.105  46.882  1
157519  97.684  -78.073  46.858  1
157520  97.719  -78.062  46.834  1
157521  97.752  -78.047  46.811  1
157522  97.783  -78.030  46.789  1
157523  97.814  -78.012  46.768  1
157524  97.846  -77.996  46.748  1
157525  97.881  -77.980  46.727  1
157526  97.916  -77.965  46.707  1
157527  97.945  -77.956  46.686  1
157528  97.947  -77.962  46.666  1
157529  97.969  -77.984  46.644  1
157530  97.991  -78.005  46.623  1
157531  98.013  -78.026  46.602  1
157532  98.034  -78.047  46.579  1
157533  98.060  -78.021  46.557  1
157534  98.142  -77.997  46.536  1
157535  98.225  -77.975  46.516  1
157536  98.282  -77.956  46.495  1
157537  98.318  -77.941  46.473  1
157538  98.355  -77.927  46.450  1
157539  98.392  -77.912  46.427  1
157540  98.429  -77.898  46.403  1
157541  98.465  -77.884  46.379  1
157542  98.502  -77.868  46.356  1
157543  98.539  -77.854  46.334  1
157544  98.576  -77.840  46.312  1
157545  98.612  -77.825  46.289  1
157546  98.635  -77.840  46.266  1
157547  98.648  -77.876  46.242  1
157548  98.661  -77.912  46.220  1
157549  98.673  -77.947  46.199  1
157550  98.686  -77.984  46.178  1
157551  98.697  -78.016  46.158  1
157552  98.684  -78.012  46.138  1
157553  98.681  -78.016  46.118  1
157554  98.682  -78.023  46.099  1
157555  98.683  -78.031  46.079  1
157556  98.684  -78.037  46.059  1
157557  98.685  -78.045  46.040  1
157558  98.685  -78.052  46.021  1
157559  98.686  -78.059  46.003  1
157560  98.687  -78.066  45.984  1
157561  98.688  -78.073  45.964  1
157562  98.689  -78.081  45.944  1
157563  98.689  -78.087  45.925  1
157564  98.740  -78.096  45.906  1
157565  98.792  -78.103  45.889  1
157566  98.845  -78.111  45.872  1
157567  98.898  -78.119  45.856  1
157568  98.950  -78.127  45.840  1
157569  99.003  -78.135  45.822  1
157570  99.056  -78.143  45.807  1
157571  99.076  -78.146  45.792  1
157572  99.082  -78.147  45.778  1
157573  99.087  -78.148  45.764  1
157574  99.104  -78.149  45.749  1
157575  99.160  -78.150  45.736  1
157576  99.213  -78.150  45.723  1
157577  99.231  -78.147  45.712  1
157578  99.250  -78.144  45.701  1
157579  99.268  -78.140  45.689  1
157580  99.286  -78.137  45.678  1
157581  99.305  -78.134  45.667  1
157582  99.327  -78.135  45.655  1
157583  99.349  -78.138  45.643  1
157584  99.371  -78.140  45.631  1
157585  99.393  -78.142  45.619  1
157586  99.415  -78.144  45.607  1
157587  99.438  -78.147  45.596  1
157588  99.468  -78.167  45.585  1
157589  99.498  -78.187  45.575  1
157590  99.528  -78.206  45.564  1
157591  99.558  -78.225  45.552  1
157592  99.586  -78.244  45.541  1
157593  99.615  -78.264  45.532  1
157594  99.644  -78.283  45.521  1
157595  99.673  -78.304  45.509  1
157596  99.703  -78.329  45.497  1
157597  99.736  -78.346  45.487  1
157598  99.770  -78.364  45.474  1
157599  99.803  -78.382  45.461  1
157600  99.837  -78.400  45.447  1
157601  99.870  -78.417  45.436  1
157602  99.865  -78.438  45.423  1
157603  99.857  -78.459  45.410  1
157604  99.868  -78.480  45.396  1
157605  99.904  -78.501  45.382  1
157606  99.940  -78.522  45.368  1
157607  99.977  -78.542  45.355  1
157608  100.013  -78.563  45.341  1
157609  100.050  -78.584  45.326  1
157610  100.086  -78.604  45.310  1
157611  100.122  -78.625  45.295  1
157612  100.158  -78.646  45.280  1
157613  100.193  -78.663  45.263  1
157614  100.226  -78.677  45.247  1
157615  100.260  -78.692  45.230  1
157616  100.293  -78.707  45.213  1
157617  100.326  -78.722  45.196  1
157618  100.353  -78.733  45.179  1
157619  100.346  -78.724  45.161  1
157620  100.364  -78.727  45.144  1
157621  100.382  -78.730  45.127  1
157622  100.401  -78.733  45.110  1
157623  100.420  -78.736  45.093  1
157624  100.437  -78.738  45.076  1
157625  100.442  -78.722  45.060  1
157626  100.460  -78.727  45.043  1
157627  100.498  -78.738  45.027  1
157628  100.518  -78.747  45.011  1
157629  100.539  -78.754  44.996  1
157630  100.560  -78.761  44.980  1
157631  100.581  -78.767  44.964  1
157632  100.602  -78.775  44.948  1
157633  100.623  -78.782  44.932  1
157634  100.644  -78.789  44.916  1
157635  100.656  -78.808  44.900  1
157636  100.662  -78.833  44.884  1
157637  100.680  -78.852  44.867  1
157638  100.708  -78.863  44.849  1
157639  100.736  -78.874  44.834  1
157640  100.764  -78.886  44.818  1
157641  100.781  -78.903  44.801  1
157642  100.799  -78.921  44.785  1
157643  100.833  -78.930  44.769  1
157644  100.875  -78.937  44.752  1
157645  100.922  -78.940  44.735  1
157646  100.969  -78.943  44.719  1
157647  101.016  -78.946  44.702  1
157648  101.064  -78.948  44.687  1
157649  101.111  -78.951  44.671  1
157650  101.159  -78.953  44.656  1
157651  101.206  -78.956  44.641  1
157652  101.237  -78.965  44.626  1
157653  101.261  -78.977  44.612  1
157654  101.285  -78.991  44.599  1
157655  101.310  -79.005  44.586  1
157656  101.334  -79.018  44.573  1
157657  101.359  -79.032  44.560  1
157658  101.383  -79.045  44.547  1
157659  101.400  -79.078  44.534  1
157660  101.417  -79.112  44.522  1
157661  101.449  -79.137  44.509  1
157887  92.487  -77.551  54.129  1
157888  92.507  -77.559  54.137  1
157889  92.527  -77.567  54.144  1
157890  92.547  -77.573  54.151  1
157891  92.567  -77.581  54.156  1
157892  92.587  -77.589  54.162  1
157893  92.607  -77.595  54.170  1
157894  92.627  -77.603  54.176  1
157895  92.647  -77.611  54.183  1
157896  92.667  -77.617  54.191  1
157897  92.687  -77.625  54.196  1
157898  92.707  -77.633  54.201  1
157899  92.727  -77.639  54.207  1
157900  92.746  -77.647  54.212  1
157901  92.767  -77.655  54.216  1
157902  92.787  -77.662  54.221  1
157903  92.806  -77.669  54.225  1
157904  92.827  -77.677  54.230  1
157905  92.851  -77.674  54.234  1
157906  92.879  -77.661  54.239  1
157907  92.896  -77.653  54.244  1
157908  92.910  -77.645  54.251  1
157909  92.924  -77.638  54.257  1
157910  92.938  -77.630  54.262  1
157911  92.952  -77.623  54.268  1
157912  92.967  -77.615  54.272  1
157913  92.981  -77.608  54.275  1
157914  92.995  -77.600  54.279  1
157915  93.009  -77.592  54.283  1
157916  93.020  -77.588  54.287  1
157917  93.028  -77.584  54.289  1
157918  93.038  -77.580  54.290  1
157919  93.049  -77.577  54.291  1
157920  93.061  -77.573  54.292  1
157921  93.073  -77.570  54.292  1
157922  93.084  -77.567  54.292  1
157923  93.096  -77.564  54.293  1
157924  93.108  -77.555  54.295  1
157925  93.118  -77.538  54.299  1
157926  93.129  -77.520  54.302  1
157927  93.139  -77.504  54.304  1
157928  93.150  -77.488  54.306  1
157929  93.162  -77.473  54.304  1
157930  93.183  -77.464  54.303  1
157931  93.207  -77.455  54.302  1
157932  93.231  -77.447  54.300  1
157933  93.256  -77.439  54.298  1
157934  93.280  -77.431  54.294  1
157935  93.304  -77.423  54.289  1
157936  93.321  -77.414  54.283  1
157937  93.335  -77.404  54.277  1
157938  93.348  -77.395  54.273  1
157939  93.361  -77.386  54.271  1
157940  93.375  -77.377  54.266  1
157941  93.389  -77.368  54.258  1
157942  93.402  -77.359  54.248  1
157943  93.412  -77.345  54.237  1
157944  93.420  -77.329  54.228  1
157945  93.435  -77.320  54.220  1
157946  93.453  -77.314  54.212  1
157947  93.471  -77.307  54.202  1
157948  93.489  -77.301  54.190  1
157949  93.507  -77.294  54.178  1
157950  93.526  -77.289  54.166  1
157951  93.546  -77.281  54.154  1
157952  93.567  -77.272  54.142  1
157953  93.587  -77.263  54.129  1
157954  93.608  -77.255  54.117  1
157955  93.629  -77.246  54.104  1
157956  93.649  -77.238  54.088  1
157957  93.670  -77.229  54.072  1
157958  93.690  -77.220  54.057  1
157959  93.711  -77.211  54.042  1
157960  93.732  -77.202  54.027  1
157961  93.754  -77.193  54.014  1
157962  93.768  -77.189  53.996  1
157963  93.782  -77.182  53.977  1
157964  93.794  -77.173  53.958  1
157965  93.807  -77.165  53.937  1
157966  93.812  -77.157  53.916  1
157967  93.814  -77.151  53.894  1
157968  93.816  -77.146  53.873  1
157969  93.818  -77.141  53.855  1
157970  93.820  -77.135  53.837  1
157971  93.824  -77.138  53.821  1
157972  93.830  -77.150  53.806  1
157973  93.837  -77.162  53.791  1
157974  93.866  -77.161  53.773  1
157975  93.895  -77.160  53.755  1
157976  93.911  -77.158  53.734  1
157977  93.920  -77.157  53.711  1
157978  93.934  -77.149  53.689  1
157979  93.950  -77.139  53.669  1
157980  93.966  -77.129  53.650  1
157981  93.985  -77.122  53.632  1
157982  94.009  -77.119  53.614  1
157983  94.033  -77.116  53.596  1
157984  94.056  -77.113  53.578  1
157985  94.080  -77.108  53.561  1
157986  94.104  -77.104  53.544  1
157987  94.132  -77.102  53.529  1
157988  94.164  -77.101  53.514  1
157989  94.195  -77.100  53.497  1
157990  94.226  -77.100  53.481  1
157991  94.239  -77.091  53.468  1
157992  94.244  -77.078  53.459  1
157993  94.249  -77.066  53.452  1
157994  94.258  -77.059  53.447  1
157995  94.271  -77.056  53.441  1
157996  94.284  -77.054  53.434  1
157997  94.299  -77.052  53.426  1
157998  94.315  -77.050  53.418  1
157999  94.328  -77.049  53.412  1
158000  94.335  -77.049  53.408  1
158001  94.342  -77.050  53.406  1
158002  94.343  -77.046  53.406  1
158003  94.343  -77.041  53.405  1
158004  94.343  -77.038  53.405  1
158005  94.342  -77.037  53.405  1
158006  94.340  -77.035  53.404  1
158007  94.339  -77.033  53.399  1
158008  94.343  -77.031  53.390  1
158009  94.361  -77.026  53.378  1
158010  94.380  -77.022  53.357  1
158011  94.398  -77.018  53.333  1
158012  94.416  -77.014  53.308  1
158013  94.435  -77.009  53.281  1
158014  94.457  -77.006  53.254  1
158015  94.478  -77.001  53.228  1
158016  94.499  -76.997  53.205  1
158017  94.521  -76.993  53.179  1
158018  94.542  -76.989  53.153  1
158019  94.567  -76.985  53.128  1
158020  94.595  -76.981  53.106  1
158021  94.619  -76.977  53.084  1
158022  94.627  -76.972  53.061  1
158023  94.634  -76.966  53.035  1
158024  94.642  -76.961  53.006  1
158025  94.654  -76.960  52.978  1
158026  94.666  -76.960  52.949  1
158027  94.677  -76.959  52.920  1
158028  94.689  -76.959  52.888  1
158029  94.701  -76.960  52.853  1
158030  94.713  -76.962  52.815  1
158031  94.729  -76.965  52.774  1
158032  94.769  -76.972  52.733  1
158033  94.809  -76.978  52.693  1
158034  94.849  -76.984  52.652  1
158035  94.889  -76.991  52.609  1
158036  94.908  -76.995  52.566  1
158037  94.917  -76.998  52.525  1
158038  94.925  -77.001  52.487  1
158039  94.933  -77.003  52.456  1
158040  94.942  -77.006  52.426  1
158041  94.956  -77.012  52.397  1
158042  94.973  -77.012  52.370  1
158043  94.993  -77.014  52.341  1
158044  95.014  -77.018  52.314  1
158045  95.034  -77.022  52.290  1
158046  95.054  -77.026  52.268  1
158047  95.074  -77.031  52.241  1
158048  95.095  -77.035  52.207  1
158049  95.115  -77.040  52.167  1
158050  95.135  -77.044  52.126  1
158051  95.155  -77.048  52.083  1
158052  95.175  -77.053  52.037  1
158053  95.195  -77.057  51.986  1
158054  95.215  -77.062  51.931  1
158055  95.235  -77.066  51.877  1
158056  95.249  -77.066  51.823  1
158057  95.260  -77.063  51.768  1
158058  95.270  -77.061  51.708  1
158059  95.281  -77.059  51.648  1
158060  95.298  -77.069  51.589  1
158061  95.316  -77.083  51.534  1
158062  95.334  -77.096  51.480  1
158063  95.352  -77.110  51.427  1
158064  95.370  -77.122  51.376  1
158065  95.388  -77.136  51.325  1
158066  95.406  -77.150  51.275  1
158067  95.424  -77.163  51.226  1
158068  95.442  -77.176  51.180  1
158069  95.460  -77.190  51.135  1
158070  95.480  -77.204  51.091  1
158071  95.494  -77.215  51.047  1
158072  95.510  -77.226  51.000  1
158073  95.525  -77.236  50.952  1
158074  95.539  -77.247  50.903  1
158075  95.554  -77.257  50.854  1
158076  95.569  -77.268  50.807  1
158077  95.584  -77.279  50.761  1
158078  95.599  -77.289  50.718  1
158079  95.614  -77.300  50.675  1
158080  95.630  -77.311  50.632  1
158081  95.650  -77.318  50.589  1
158082  95.670  -77.324  50.546  1
158083  95.689  -77.331  50.503  1
158084  95.709  -77.338  50.460  1
158085  95.729  -77.344  50.419  1
158086  95.749  -77.351  50.381  1
158087  95.756  -77.357  50.342  1
158088  95.770  -77.365  50.304  1
158089  95.790  -77.376  50.265  1
158090  95.811  -77.386  50.224  1
158091  95.831  -77.397  50.183  1
158092  95.851  -77.407  50.140  1
158093  95.872  -77.418  50.097  1
158094  95.892  -77.429  50.051  1
158095  95.916  -77.439  50.004  1
158096  95.949  -77.450  49.954  1
158097  95.965  -77.455  49.902  1
158098  95.979  -77.460  49.849  1
158099  95.993  -77.464  49.797  1
158100  96.007  -77.470  49.747  1
158101  96.019  -77.469  49.697  1
158102  96.027  -77.475  49.650  1
158103  96.035  -77.483  49.603  1
158104  96.042  -77.491  49.556  1
158105  96.050  -77.499  49.512  1
158106  96.057  -77.507  49.470  1
158107  96.065  -77.515  49.429  1
158108  96.070  -77.520  49.389  1
158109  96.075  -77.525  49.351  1
158110  96.080  -77.526  49.314  1
158111  96.087  -77.519  49.276  1
158112  96.094  -77.512  49.241  1
158113  96.101  -77.506  49.209  1
158114  96.108  -77.499  49.178  1
158115  96.115  -77.492  49.149  1
158116  96.122  -77.486  49.120  1
158117  96.129  -77.479  49.092  1
158118  96.139  -77.484  49.065  1
158119  96.158  -77.494  49.038  1
158120  96.169  -77.505  49.017  1
158121  96.174  -77.515  48.997  1
158122  96.179  -77.523  48.978  1
158123  96.183  -77.532  48.961  1
158124  96.195  -77.545  48.947  1
158125  96.211  -77.558  48.932  1
158126  96.223  -77.566  48.916  1
158127  96.235  -77.570  48.894  1
158128  96.246  -77.576  48.870  1
158129  96.257  -77.581  48.846  1
158130  96.268  -77.586  48.822  1
158131  96.284  -77.592  48.800  1
158132  96.312  -77.603  48.777  1
158133  96.341  -77.614  48.752  1
158134  96.370  -77.625  48.731  1
158135  96.398  -77.636  48.709  1
158136  96.427  -77.646  48.687  1
158137  96.456  -77.657  48.666  1
158138  96.482  -77.667  48.648  1
158139  96.508  -77.678  48.629  1
158140  96.532  -77.687  48.611  1
158141  96.552  -77.692  48.594  1
158142  96.568  -77.696  48.577  1
158143  96.578  -77.699  48.560  1
158144  96.585  -77.701  48.541  1
158145  96.592  -77.702  48.524  1
158146  96.599  -77.703  48.505  1
158147  96.606  -77.705  48.483  1
158148  96.612  -77.706  48.462  1
158149  96.619  -77.708  48.441  1
158150  96.626  -77.709  48.419  1
158151  96.633  -77.711  48.398  1
158152  96.640  -77.711  48.379  1
158153  96.647  -77.713  48.360  1
158154  96.654  -77.714  48.341  1
158155  96.660  -77.716  48.323  1
158156  96.670  -77.721  48.305  1
158157  96.679  -77.728  48.284  1
158158  96.689  -77.735  48.261  1
158159  96.702  -77.738  48.237  1
158160  96.716  -77.740  48.212  1
158161  96.730  -77.743  48.187  1
158162  96.745  -77.746  48.163  1
158163  96.759  -77.748  48.138  1
158164  96.773  -77.750  48.111  1
158165  96.787  -77.752  48.085  1
158166  96.801  -77.755  48.059  1
158167  96.816  -77.758  48.034  1
158168  96.830  -77.760  48.008  1
158169  96.844  -77.762  47.982  1
158170  96.859  -77.755  47.956  1
158171  96.877  -77.753  47.931  1
158172  96.899  -77.764  47.906  1
158173  96.922  -77.768  47.882  1
158174  96.945  -77.768  47.858  1
158175  96.968  -77.770  47.837  1
158176  96.992  -77.771  47.815  1
158177  97.015  -77.772  47.794  1
158178  97.029  -77.771  47.772  1
158179  97.040  -77.773  47.751  1
158180  97.051  -77.777  47.730  1
158181  97.063  -77.780  47.710  1
158182  97.074  -77.783  47.689  1
158183  97.086  -77.781  47.668  1
158184  97.099  -77.772  47.646  1
158185  97.112  -77.764  47.625  1
158186  97.126  -77.755  47.603  1
158187  97.139  -77.747  47.583  1
158188  97.153  -77.738  47.563  1
158189  97.166  -77.730  47.542  1
158190  97.184  -77.727  47.522  1
158191  97.213  -77.733  47.501  1
158192  97.243  -77.742  47.481  1
158193  97.273  -77.750  47.462  1
158194  97.304  -77.758  47.444  1
158195  97.334  -77.768  47.425  1
158196  97.364  -77.776  47.406  1
158197  97.394  -77.784  47.389  1
158198  97.425  -77.793  47.370  1
158199  97.455  -77.802  47.352  1
158200  97.485  -77.810  47.332  1
158201  97.515  -77.818  47.313  1
158202  97.530  -77.815  47.293  1
158203  97.539  -77.807  47.272  1
158204  97.550  -77.806  47.250  1
158205  97.566  -77.821  47.229  1
158206  97.581  -77.837  47.209  1
158207  97.597  -77.852  47.187  1
158208  97.612  -77.867  47.166  1
158209  97.628  -77.882  47.143  1
158210  97.643  -77.898  47.119  1
158211  97.659  -77.913  47.095  1
158212  97.658  -77.939  47.071  1
158213  97.655  -77.967  47.047  1
158214  97.652  -77.994  47.022  1
158215  97.650  -78.022  46.996  1
158216  97.647  -78.050  46.970  1
158217  97.644  -78.077  46.943  1
158218  97.656  -78.090  46.917  1
158219  97.659  -78.075  46.892  1
158220  97.695  -78.051  46.868  1
158221  97.730  -78.036  46.845  1
158222  97.764  -78.021  46.821  1
158223  97.800  -78.006  46.798  1
158224  97.835  -77.990  46.776  1
158225  97.870  -77.975  46.754  1
158226  97.906  -77.960  46.732  1
158227  97.941  -77.945  46.712  1
158228  97.955  -77.951  46.692  1
158229  97.960  -77.956  46.671  1
158230  97.955  -77.960  46.649  1
158231  97.956  -77.968  46.627  1
158232  97.979  -77.989  46.606  1
158233  98.000  -78.010  46.584  1
158234  97.998  -77.998  46.564  1
158235  98.055  -77.974  46.544  1
158236  98.138  -77.950  46.524  1
158237  98.220  -77.928  46.503  1
158238  98.303  -77.904  46.481  1
158239  98.372  -77.884  46.458  1
158240  98.408  -77.869  46.434  1
158241  98.445  -77.855  46.411  1
158242  98.482  -77.840  46.387  1
158243  98.518  -77.826  46.365  1
158244  98.555  -77.812  46.343  1
158245  98.592  -77.796  46.320  1
158246  98.629  -77.782  46.297  1
158247  98.642  -77.816  46.274  1
158248  98.655  -77.852  46.252  1
158249  98.668  -77.888  46.229  1
158250  98.680  -77.924  46.208  1
158251  98.694  -77.960  46.189  1
158252  98.706  -77.996  46.168  1
158253  98.698  -77.998  46.148  1
158254  98.699  -78.005  46.127  1
158255  98.700  -78.012  46.109  1
158256  98.700  -78.019  46.090  1
158257  98.701  -78.026  46.070  1
158258  98.702  -78.034  46.051  1
158259  98.703  -78.040  46.032  1
158260  98.704  -78.048  46.013  1
158261  98.704  -78.055  45.994  1
158262  98.705  -78.062  45.974  1
158263  98.706  -78.069  45.954  1
158264  98.707  -78.076  45.934  1
158265  98.728  -78.084  45.915  1
158266  98.781  -78.091  45.899  1
158267  98.834  -78.100  45.882  1
158268  98.886  -78.107  45.865  1
158269  98.939  -78.116  45.849  1
158270  98.992  -78.123  45.832  1
158271  99.034  -78.129  45.816  1
158272  99.040  -78.131  45.801  1
158273  99.045  -78.131  45.787  1
158274  99.065  -78.132  45.772  1
158275  99.121  -78.133  45.758  1
158276  99.175  -78.134  45.744  1
158277  99.225  -78.133  45.731  1
158278  99.243  -78.130  45.719  1
158279  99.262  -78.127  45.708  1
158280  99.281  -78.124  45.697  1
158281  99.299  -78.120  45.686  1
158282  99.317  -78.117  45.675  1
158283  99.336  -78.114  45.663  1
158284  99.354  -78.111  45.651  1
158285  99.375  -78.111  45.639  1
158286  99.397  -78.113  45.626  1
158287  99.419  -78.116  45.615  1
158288  99.445  -78.126  45.603  1
158289  99.476  -78.146  45.594  1
158290  99.506  -78.166  45.584  1
158291  99.536  -78.185  45.573  1
158292  99.566  -78.205  45.562  1
158293  99.595  -78.224  45.551  1
158294  99.624  -78.243  45.541  1
158295  99.653  -78.266  45.529  1
158296  99.687  -78.284  45.518  1
158297  99.720  -78.302  45.507  1
158298  99.752  -78.320  45.494  1
158299  99.780  -78.339  45.482  1
158300  99.808  -78.359  45.469  1
158301  99.836  -78.379  45.455  1
158302  99.858  -78.395  45.442  1
158303  99.868  -78.412  45.430  1
158304  99.860  -78.433  45.417  1
158305  99.853  -78.454  45.403  1
158306  99.889  -78.475  45.389  1
158307  99.925  -78.496  45.376  1
158308  99.962  -78.517  45.363  1
158309  99.998  -78.537  45.349  1
158310  100.034  -78.558  45.334  1
158311  100.071  -78.579  45.319  1
158312  100.107  -78.599  45.303  1
158313  100.143  -78.620  45.287  1
158314  100.180  -78.641  45.270  1
158315  100.216  -78.661  45.254  1
158316  100.252  -78.683  45.237  1
158317  100.288  -78.703  45.219  1
158318  100.325  -78.724  45.202  1
158319  100.359  -78.740  45.184  1
158320  100.371  -78.743  45.167  1
158321  100.370  -78.737  45.150  1
158322  100.389  -78.740  45.133  1
158323  100.395  -78.726  45.116  1
158324  100.399  -78.711  45.099  1
158325  100.404  -78.695  45.083  1
158326  100.409  -78.680  45.066  1
158327  100.438  -78.708  45.049  1
158328  100.486  -78.720  45.033  1
158329  100.529  -78.731  45.018  1
158330  100.548  -78.741  45.003  1
158331  100.567  -78.750  44.988  1
158332  100.587  -78.759  44.972  1
158333  100.609  -78.766  44.956  1
158334  100.630  -78.773  44.939  1
158335  100.650  -78.780  44.924  1
158336  100.668  -78.792  44.908  1
158337  100.674  -78.818  44.891  1
158338  100.701  -78.830  44.875  1
158339  100.729  -78.841  44.858  1
158340  100.749  -78.857  44.842  1
158341  100.767  -78.874  44.826  1
158342  100.785  -78.892  44.809  1
158343  100.804  -78.908  44.793  1
158344  100.843  -78.916  44.777  1
158345  100.882  -78.924  44.760  1
158346  100.928  -78.928  44.743  1
158347  100.975  -78.930  44.727  1
158348  101.022  -78.933  44.711  1
158349  101.070  -78.937  44.695  1
158350  101.117  -78.939  44.680  1
158351  101.165  -78.942  44.665  1
158352  101.203  -78.949  44.650  1
158353  101.236  -78.950  44.634  1
158354  101.260  -78.963  44.621  1
158355  101.284  -78.976  44.607  1
158356  101.309  -78.990  44.594  1
158357  101.333  -79.003  44.581  1
158358  101.358  -79.017  44.567  1
158359  101.382  -79.031  44.554  1
158360  101.399  -79.065  44.542  1
158361  101.415  -79.100  44.530  1
158362  101.448  -79.124  44.517  1
158363  101.490  -79.143  44.505  1
158588  92.476  -77.532  54.114  1
158589  92.496  -77.539  54.122  1
158590  92.516  -77.546  54.131  1
158591  92.536  -77.554  54.138  1
158592  92.556  -77.561  54.146  1
158593  92.576  -77.568  54.154  1
158594  92.596  -77.576  54.162  1
158595  92.616  -77.583  54.171  1
158596  92.636  -77.590  54.180  1
158597  92.656  -77.598  54.188  1
158598  92.675  -77.605  54.195  1
158599  92.696  -77.612  54.202  1
158600  92.716  -77.620  54.209  1
158601  92.735  -77.627  54.217  1
158602  92.756  -77.634  54.223  1
158603  92.776  -77.642  54.228  1
158604  92.795  -77.649  54.232  1
158605  92.815  -77.657  54.238  1
158606  92.840  -77.655  54.243  1
158607  92.867  -77.644  54.247  1
158608  92.887  -77.637  54.252  1
158609  92.901  -77.630  54.259  1
158610  92.915  -77.622  54.265  1
158611  92.929  -77.614  54.271  1
158612  92.943  -77.607  54.277  1
158613  92.958  -77.599  54.281  1
158614  92.972  -77.592  54.284  1
158615  92.986  -77.584  54.288  1
158616  92.998  -77.578  54.291  1
158617  93.007  -77.574  54.293  1
158618  93.016  -77.570  54.295  1
158619  93.025  -77.567  54.297  1
158620  93.035  -77.563  54.298  1
158621  93.046  -77.560  54.298  1
158622  93.058  -77.556  54.299  1
158623  93.070  -77.553  54.300  1
158624  93.081  -77.550  54.304  1
158625  93.092  -77.538  54.308  1
158626  93.103  -77.521  54.312  1
158627  93.114  -77.504  54.316  1
158628  93.124  -77.487  54.320  1
158629  93.135  -77.470  54.323  1
158630  93.150  -77.457  54.322  1
158631  93.174  -77.449  54.322  1
158632  93.199  -77.441  54.323  1
158633  93.223  -77.432  54.323  1
158634  93.248  -77.424  54.322  1
158635  93.272  -77.417  54.318  1
158636  93.296  -77.408  54.312  1
158637  93.317  -77.400  54.306  1
158638  93.331  -77.391  54.300  1
158639  93.344  -77.382  54.297  1
158640  93.357  -77.373  54.294  1
158641  93.371  -77.363  54.290  1
158642  93.384  -77.354  54.281  1
158643  93.393  -77.338  54.270  1
158644  93.401  -77.323  54.258  1
158645  93.411  -77.308  54.248  1
158646  93.429  -77.302  54.239  1
158647  93.446  -77.295  54.232  1
158648  93.465  -77.289  54.223  1
158649  93.483  -77.282  54.212  1
158650  93.501  -77.276  54.201  1
158651  93.519  -77.269  54.190  1
158652  93.541  -77.260  54.178  1
158653  93.562  -77.251  54.165  1
158654  93.583  -77.241  54.152  1
158655  93.604  -77.232  54.140  1
158656  93.625  -77.223  54.127  1
158657  93.646  -77.214  54.113  1
158658  93.667  -77.205  54.097  1
158659  93.688  -77.196  54.082  1
158660  93.709  -77.187  54.066  1
158661  93.730  -77.178  54.051  1
158662  93.748  -77.174  54.037  1
158663  93.763  -77.177  54.019  1
158664  93.776  -77.170  54.000  1
158665  93.789  -77.163  53.981  1
158666  93.802  -77.156  53.961  1
158667  93.803  -77.153  53.941  1
158668  93.805  -77.149  53.921  1
158669  93.806  -77.146  53.902  1
158670  93.808  -77.143  53.885  1
158671  93.810  -77.138  53.869  1
158672  93.812  -77.133  53.854  1
158673  93.815  -77.133  53.840  1
158674  93.835  -77.137  53.824  1
158675  93.864  -77.135  53.807  1
158676  93.893  -77.134  53.789  1
158677  93.913  -77.133  53.769  1
158678  93.922  -77.132  53.744  1
158679  93.932  -77.130  53.721  1
158680  93.947  -77.122  53.700  1
158681  93.963  -77.111  53.682  1
158682  93.982  -77.104  53.664  1
158683  94.006  -77.102  53.645  1
158684  94.030  -77.098  53.626  1
158685  94.053  -77.094  53.608  1
158686  94.077  -77.090  53.591  1
158687  94.101  -77.085  53.574  1
158688  94.124  -77.081  53.558  1
158689  94.154  -77.080  53.541  1
158690  94.186  -77.079  53.523  1
158691  94.216  -77.078  53.503  1
158692  94.221  -77.066  53.487  1
158693  94.226  -77.054  53.473  1
158694  94.237  -77.049  53.462  1
158695  94.249  -77.046  53.453  1
158696  94.262  -77.043  53.445  1
158697  94.275  -77.041  53.437  1
158698  94.290  -77.038  53.429  1
158699  94.306  -77.036  53.422  1
158700  94.321  -77.034  53.419  1
158701  94.336  -77.032  53.416  1
158702  94.346  -77.032  53.414  1
158703  94.347  -77.028  53.413  1
158704  94.346  -77.027  53.411  1
158705  94.344  -77.025  53.409  1
158706  94.342  -77.023  53.408  1
158707  94.341  -77.021  53.405  1
158708  94.339  -77.019  53.399  1
158709  94.348  -77.016  53.390  1
158710  94.367  -77.012  53.377  1
158711  94.385  -77.008  53.357  1
158712  94.403  -77.003  53.335  1
158713  94.422  -77.000  53.310  1
158714  94.440  -76.995  53.285  1
158715  94.459  -76.991  53.260  1
158716  94.480  -76.987  53.235  1
158717  94.501  -76.983  53.210  1
158718  94.522  -76.978  53.183  1
158719  94.545  -76.975  53.157  1
158720  94.573  -76.971  53.131  1
158721  94.601  -76.967  53.109  1
158722  94.620  -76.962  53.085  1
158723  94.627  -76.957  53.060  1
158724  94.635  -76.952  53.034  1
158725  94.643  -76.947  53.002  1
158726  94.654  -76.944  52.970  1
158727  94.666  -76.944  52.939  1
158728  94.677  -76.943  52.908  1
158729  94.689  -76.943  52.875  1
158730  94.700  -76.943  52.841  1
158731  94.712  -76.943  52.805  1
158732  94.730  -76.947  52.767  1
158733  94.770  -76.953  52.725  1
158734  94.810  -76.959  52.684  1
158735  94.850  -76.966  52.644  1
158736  94.890  -76.973  52.605  1
158737  94.923  -76.978  52.569  1
158738  94.931  -76.981  52.534  1
158739  94.939  -76.984  52.500  1
158740  94.948  -76.987  52.469  1
158741  94.956  -76.990  52.443  1
158742  94.964  -76.992  52.419  1
158743  94.979  -76.995  52.395  1
158744  94.999  -77.000  52.368  1
158745  95.019  -77.003  52.341  1
158746  95.039  -77.008  52.315  1
158747  95.059  -77.012  52.294  1
158748  95.079  -77.017  52.267  1
158749  95.100  -77.022  52.235  1
158750  95.120  -77.025  52.199  1
158751  95.139  -77.030  52.159  1
158752  95.160  -77.034  52.115  1
158753  95.180  -77.039  52.067  1
158754  95.200  -77.044  52.014  1
158755  95.220  -77.047  51.960  1
158756  95.240  -77.052  51.906  1
158757  95.257  -77.054  51.851  1
158758  95.268  -77.052  51.796  1
158759  95.278  -77.050  51.734  1
158760  95.295  -77.059  51.672  1
158761  95.313  -77.073  51.612  1
158762  95.331  -77.086  51.555  1
158763  95.349  -77.100  51.499  1
158764  95.367  -77.113  51.444  1
158765  95.385  -77.126  51.391  1
158766  95.403  -77.140  51.340  1
158767  95.419  -77.151  51.289  1
158768  95.433  -77.160  51.239  1
158769  95.447  -77.170  51.194  1
158770  95.461  -77.179  51.153  1
158771  95.477  -77.191  51.111  1
158772  95.493  -77.204  51.067  1
158773  95.509  -77.214  51.018  1
158774  95.523  -77.225  50.968  1
158775  95.538  -77.235  50.919  1
158776  95.553  -77.246  50.870  1
158777  95.568  -77.257  50.822  1
158778  95.583  -77.268  50.776  1
158779  95.598  -77.279  50.732  1
158780  95.613  -77.289  50.689  1
158781  95.632  -77.290  50.646  1
158782  95.652  -77.295  50.602  1
158783  95.672  -77.301  50.559  1
158784  95.691  -77.308  50.516  1
158785  95.711  -77.315  50.473  1
158786  95.731  -77.322  50.431  1
158787  95.750  -77.328  50.392  1
158788  95.757  -77.334  50.353  1
158789  95.764  -77.340  50.314  1
158790  95.784  -77.351  50.275  1
158791  95.804  -77.361  50.235  1
158792  95.825  -77.372  50.193  1
158793  95.845  -77.382  50.150  1
158794  95.866  -77.393  50.107  1
158795  95.886  -77.404  50.060  1
158796  95.912  -77.414  50.012  1
158797  95.946  -77.425  49.962  1
158798  95.965  -77.431  49.910  1
158799  95.979  -77.436  49.857  1
158800  95.992  -77.441  49.806  1
158801  96.006  -77.445  49.757  1
158802  96.019  -77.449  49.708  1
158803  96.013  -77.445  49.661  1
158804  96.016  -77.449  49.614  1
158805  96.021  -77.454  49.567  1
158806  96.026  -77.460  49.521  1
158807  96.031  -77.464  49.478  1
158808  96.035  -77.470  49.436  1
158809  96.040  -77.475  49.397  1
158810  96.045  -77.479  49.358  1
158811  96.052  -77.473  49.320  1
158812  96.058  -77.467  49.281  1
158813  96.065  -77.460  49.245  1
158814  96.073  -77.453  49.213  1
158815  96.080  -77.446  49.182  1
158816  96.089  -77.447  49.153  1
158817  96.101  -77.457  49.123  1
158818  96.113  -77.468  49.094  1
158819  96.132  -77.478  49.067  1
158820  96.153  -77.487  49.040  1
158821  96.170  -77.497  49.018  1
158822  96.180  -77.509  48.998  1
158823  96.189  -77.521  48.980  1
158824  96.198  -77.533  48.964  1
158825  96.203  -77.542  48.950  1
158826  96.217  -77.553  48.936  1
158827  96.227  -77.557  48.919  1
158828  96.238  -77.561  48.897  1
158829  96.249  -77.564  48.874  1
158830  96.260  -77.569  48.849  1
158831  96.271  -77.574  48.825  1
158832  96.286  -77.580  48.805  1
158833  96.315  -77.591  48.783  1
158834  96.343  -77.602  48.760  1
158835  96.372  -77.613  48.740  1
158836  96.401  -77.624  48.719  1
158837  96.429  -77.634  48.699  1
158838  96.458  -77.645  48.680  1
158839  96.486  -77.656  48.661  1
158840  96.515  -77.667  48.643  1
158841  96.543  -77.677  48.625  1
158842  96.566  -77.686  48.608  1
158843  96.581  -77.690  48.593  1
158844  96.588  -77.691  48.576  1
158845  96.595  -77.692  48.558  1
158846  96.602  -77.694  48.541  1
158847  96.609  -77.696  48.521  1
158848  96.615  -77.697  48.499  1
158849  96.622  -77.699  48.478  1
158850  96.629  -77.699  48.458  1
158851  96.636  -77.701  48.438  1
158852  96.643  -77.702  48.418  1
158853  96.650  -77.704  48.399  1
158854  96.657  -77.705  48.380  1
158855  96.664  -77.707  48.361  1
158856  96.670  -77.708  48.343  1
158857  96.678  -77.711  48.325  1
158858  96.688  -77.718  48.304  1
158859  96.697  -77.724  48.283  1
158860  96.711  -77.728  48.259  1
158861  96.725  -77.730  48.234  1
158862  96.739  -77.733  48.208  1
158863  96.753  -77.736  48.182  1
158864  96.767  -77.738  48.156  1
158865  96.782  -77.740  48.130  1
158866  96.796  -77.743  48.104  1
158867  96.810  -77.745  48.078  1
158868  96.824  -77.747  48.053  1
158869  96.838  -77.750  48.027  1
158870  96.853  -77.752  48.001  1
158871  96.867  -77.755  47.975  1
158872  96.881  -77.751  47.950  1
158873  96.903  -77.758  47.925  1
158874  96.927  -77.759  47.901  1
158875  96.950  -77.760  47.877  1
158876  96.973  -77.761  47.856  1
158877  96.996  -77.762  47.835  1
158878  97.020  -77.763  47.814  1
158879  97.033  -77.767  47.792  1
158880  97.044  -77.770  47.771  1
158881  97.055  -77.774  47.751  1
158882  97.066  -77.777  47.731  1
158883  97.077  -77.780  47.710  1
158884  97.090  -77.772  47.688  1
158885  97.103  -77.764  47.667  1
158886  97.117  -77.755  47.645  1
158887  97.130  -77.746  47.623  1
158888  97.144  -77.738  47.603  1
158889  97.157  -77.730  47.583  1
158890  97.179  -77.725  47.562  1
158891  97.204  -77.727  47.542  1
158892  97.229  -77.736  47.521  1
158893  97.260  -77.746  47.501  1
158894  97.290  -77.754  47.482  1
158895  97.320  -77.762  47.462  1
158896  97.351  -77.771  47.443  1
158897  97.381  -77.780  47.424  1
158898  97.411  -77.788  47.406  1
158899  97.441  -77.796  47.387  1
158900  97.471  -77.805  47.368  1
158901  97.502  -77.814  47.348  1
158902  97.532  -77.822  47.328  1
158903  97.548  -77.821  47.307  1
158904  97.558  -77.812  47.286  1
158905  97.567  -77.804  47.265  1
158906  97.579  -77.809  47.244  1
158907  97.595  -77.824  47.223  1
158908  97.610  -77.840  47.200  1
158909  97.626  -77.855  47.179  1
158910  97.641  -77.870  47.157  1
158911  97.657  -77.885  47.132  1
158912  97.669  -77.902  47.108  1
158913  97.666  -77.931  47.084  1
158914  97.663  -77.958  47.059  1
158915  97.661  -77.985  47.034  1
158916  97.658  -78.013  47.008  1
158917  97.655  -78.040  46.981  1
158918  97.671  -78.052  46.955  1
158919  97.682  -78.051  46.929  1
158920  97.702  -78.028  46.902  1
158921  97.721  -78.029  46.878  1
158922  97.754  -78.016  46.855  1
158923  97.790  -78.001  46.832  1
158924  97.825  -77.986  46.809  1
158925  97.860  -77.971  46.786  1
158926  97.895  -77.956  46.764  1
158927  97.931  -77.940  46.742  1
158928  97.951  -77.940  46.720  1
158929  97.964  -77.946  46.698  1
158930  97.977  -77.953  46.677  1
158931  97.972  -77.956  46.655  1
158932  97.967  -77.960  46.634  1
158933  97.962  -77.964  46.613  1
158934  97.966  -77.973  46.592  1
158935  97.977  -77.979  46.571  1
158936  97.968  -77.949  46.551  1
158937  98.051  -77.927  46.530  1
158938  98.134  -77.904  46.509  1
158939  98.216  -77.881  46.487  1
158940  98.299  -77.858  46.464  1
158941  98.381  -77.834  46.442  1
158942  98.461  -77.812  46.419  1
158943  98.498  -77.797  46.396  1
158944  98.534  -77.783  46.373  1
158945  98.571  -77.768  46.350  1
158946  98.608  -77.754  46.327  1
158947  98.637  -77.757  46.304  1
158948  98.649  -77.793  46.282  1
158949  98.662  -77.828  46.260  1
158950  98.675  -77.865  46.239  1
158951  98.688  -77.900  46.218  1
158952  98.701  -77.936  46.199  1
158953  98.713  -77.972  46.179  1
158954  98.715  -77.987  46.158  1
158955  98.716  -77.993  46.137  1
158956  98.717  -78.000  46.119  1
158957  98.718  -78.008  46.099  1
158958  98.719  -78.015  46.080  1
158959  98.719  -78.022  46.062  1
158960  98.720  -78.029  46.042  1
158961  98.721  -78.037  46.022  1
158962  98.722  -78.044  46.003  1
158963  98.722  -78.051  45.983  1
158964  98.723  -78.058  45.963  1
158965  98.724  -78.065  45.943  1
158966  98.725  -78.072  45.924  1
158967  98.770  -78.080  45.908  1
158968  98.822  -78.087  45.892  1
158969  98.875  -78.096  45.875  1
158970  98.928  -78.103  45.857  1
158971  98.981  -78.112  45.840  1
158972  98.997  -78.114  45.825  1
158973  99.002  -78.116  45.810  1
158974  99.026  -78.116  45.795  1
158975  99.081  -78.116  45.781  1
158976  99.136  -78.117  45.766  1
158977  99.191  -78.117  45.751  1
158978  99.238  -78.117  45.739  1
158979  99.256  -78.114  45.727  1
158980  99.275  -78.110  45.715  1
158981  99.293  -78.107  45.704  1
158982  99.311  -78.104  45.693  1
158983  99.330  -78.101  45.682  1
158984  99.349  -78.097  45.671  1
158985  99.367  -78.094  45.659  1
158986  99.385  -78.091  45.647  1
158987  99.404  -78.088  45.635  1
158988  99.424  -78.087  45.623  1
158989  99.453  -78.106  45.613  1
158990  99.484  -78.125  45.603  1
158991  99.514  -78.144  45.593  1
158992  99.544  -78.164  45.582  1
158993  99.574  -78.184  45.571  1
158994  99.604  -78.203  45.560  1
158995  99.634  -78.223  45.549  1
158996  99.662  -78.242  45.538  1
158997  99.690  -78.262  45.526  1
158998  99.718  -78.282  45.514  1
158999  99.746  -78.300  45.501  1
159000  99.774  -78.320  45.489  1
159001  99.801  -78.340  45.476  1
159002  99.828  -78.359  45.463  1
159003  99.845  -78.374  45.450  1
159004  99.862  -78.388  45.437  1
159005  99.863  -78.407  45.424  1
159006  99.855  -78.429  45.411  1
159007  99.874  -78.450  45.397  1
159008  99.910  -78.470  45.384  1
159009  99.946  -78.491  45.370  1
159010  99.983  -78.511  45.357  1
159011  100.019  -78.532  45.342  1
159012  100.056  -78.553  45.327  1
159013  100.092  -78.573  45.311  1
159014  100.128  -78.595  45.294  1
159015  100.164  -78.615  45.277  1
159016  100.201  -78.636  45.260  1
159017  100.237  -78.657  45.243  1
159018  100.273  -78.677  45.225  1
159019  100.310  -78.698  45.208  1
159020  100.346  -78.719  45.190  1
159021  100.343  -78.724  45.173  1
159022  100.341  -78.713  45.155  1
159023  100.352  -78.698  45.138  1
159024  100.361  -78.683  45.121  1
159025  100.365  -78.667  45.104  1
159026  100.370  -78.651  45.088  1
159027  100.388  -78.661  45.071  1
159028  100.418  -78.689  45.055  1
159029  100.465  -78.701  45.040  1
159030  100.512  -78.713  45.025  1
159031  100.559  -78.724  45.009  1
159032  100.579  -78.734  44.995  1
159033  100.598  -78.744  44.979  1
159034  100.617  -78.753  44.963  1
159035  100.636  -78.763  44.947  1
159036  100.657  -78.771  44.932  1
159037  100.678  -78.777  44.915  1
159038  100.694  -78.796  44.899  1
159039  100.716  -78.811  44.883  1
159040  100.735  -78.828  44.866  1
159041  100.752  -78.846  44.850  1
159042  100.770  -78.863  44.834  1
159043  100.788  -78.880  44.818  1
159044  100.814  -78.894  44.801  1
159045  100.853  -78.902  44.785  1
159046  100.893  -78.910  44.768  1
159047  100.934  -78.916  44.751  1
159048  100.981  -78.919  44.735  1
159049  101.029  -78.922  44.719  1
159050  101.076  -78.924  44.703  1
159051  101.123  -78.927  44.688  1
159052  101.171  -78.930  44.673  1
159053  101.200  -78.943  44.657  1
159054  101.237  -78.949  44.642  1
159055  101.259  -78.948  44.629  1
159056  101.283  -78.962  44.615  1
159057  101.308  -78.974  44.602  1
159058  101.332  -78.988  44.588  1
159059  101.357  -79.002  44.575  1
159060  101.380  -79.018  44.563  1
159061  101.397  -79.052  44.550  1
159062  101.413  -79.086  44.538  1
159063  101.448  -79.110  44.525  1
159064  101.490  -79.129  44.512  1
159289  92.465  -77.511  54.097  1
159290  92.485  -77.519  54.106  1
159291  92.505  -77.526  54.116  1
159292  92.525  -77.533  54.125  1
159293  92.545  -77.541  54.135  1
159294  92.565  -77.548  54.144  1
159295  92.585  -77.556  54.153  1
159296  92.605  -77.563  54.163  1
159297  92.625  -77.570  54.174  1
159298  92.645  -77.578  54.183  1
159299  92.665  -77.585  54.192  1
159300  92.685  -77.592  54.201  1
159301  92.705  -77.600  54.209  1
159302  92.724  -77.607  54.219  1
159303  92.744  -77.614  54.227  1
159304  92.765  -77.622  54.232  1
159305  92.784  -77.629  54.237  1
159306  92.804  -77.636  54.243  1
159307  92.829  -77.634  54.248  1
159308  92.855  -77.627  54.254  1
159309  92.878  -77.623  54.259  1
159310  92.892  -77.614  54.266  1
159311  92.907  -77.606  54.272  1
159312  92.921  -77.599  54.278  1
159313  92.935  -77.591  54.284  1
159314  92.949  -77.583  54.288  1
159315  92.963  -77.576  54.292  1
159316  92.977  -77.569  54.296  1
159317  92.986  -77.565  54.299  1
159318  92.994  -77.561  54.300  1
159319  93.003  -77.558  54.302  1
159320  93.012  -77.554  54.303  1
159321  93.021  -77.549  54.304  1
159322  93.031  -77.546  54.305  1
159323  93.043  -77.542  54.307  1
159324  93.055  -77.539  54.309  1
159325  93.067  -77.536  54.314  1
159326  93.077  -77.522  54.320  1
159327  93.088  -77.504  54.325  1
159328  93.098  -77.488  54.330  1
159329  93.110  -77.471  54.335  1
159330  93.123  -77.454  54.338  1
159331  93.140  -77.438  54.340  1
159332  93.163  -77.429  54.341  1
159333  93.191  -77.426  54.342  1
159334  93.215  -77.418  54.342  1
159335  93.239  -77.410  54.342  1
159336  93.264  -77.402  54.339  1
159337  93.288  -77.394  54.334  1
159338  93.312  -77.385  54.329  1
159339  93.327  -77.376  54.324  1
159340  93.340  -77.367  54.319  1
159341  93.353  -77.358  54.314  1
159342  93.365  -77.347  54.308  1
159343  93.373  -77.331  54.300  1
159344  93.381  -77.315  54.291  1
159345  93.390  -77.299  54.279  1
159346  93.404  -77.289  54.267  1
159347  93.422  -77.283  54.258  1
159348  93.440  -77.276  54.251  1
159349  93.458  -77.270  54.244  1
159350  93.476  -77.265  54.234  1
159351  93.494  -77.260  54.223  1
159352  93.514  -77.251  54.212  1
159353  93.537  -77.238  54.199  1
159354  93.560  -77.226  54.186  1
159355  93.581  -77.217  54.173  1
159356  93.602  -77.208  54.162  1
159357  93.623  -77.199  54.150  1
159358  93.644  -77.190  54.136  1
159359  93.665  -77.181  54.121  1
159360  93.686  -77.172  54.106  1
159361  93.707  -77.163  54.090  1
159362  93.727  -77.155  54.074  1
159363  93.742  -77.157  54.060  1
159364  93.756  -77.160  54.040  1
159365  93.770  -77.159  54.021  1
159366  93.783  -77.151  54.002  1
159367  93.795  -77.144  53.983  1
159368  93.796  -77.141  53.965  1
159369  93.798  -77.138  53.946  1
159370  93.799  -77.135  53.928  1
159371  93.801  -77.132  53.912  1
159372  93.802  -77.128  53.896  1
159373  93.804  -77.125  53.882  1
159374  93.809  -77.122  53.869  1
159375  93.832  -77.114  53.854  1
159376  93.861  -77.110  53.838  1
159377  93.891  -77.109  53.821  1
159378  93.916  -77.107  53.802  1
159379  93.925  -77.106  53.779  1
159380  93.934  -77.105  53.756  1
159381  93.944  -77.103  53.735  1
159382  93.960  -77.094  53.716  1
159383  93.979  -77.087  53.698  1
159384  94.002  -77.084  53.678  1
159385  94.026  -77.080  53.658  1
159386  94.050  -77.075  53.640  1
159387  94.073  -77.071  53.623  1
159388  94.097  -77.067  53.605  1
159389  94.121  -77.063  53.588  1
159390  94.145  -77.059  53.570  1
159391  94.177  -77.058  53.550  1
159392  94.199  -77.053  53.529  1
159393  94.204  -77.041  53.509  1
159394  94.216  -77.038  53.492  1
159395  94.228  -77.035  53.477  1
159396  94.240  -77.032  53.462  1
159397  94.253  -77.029  53.452  1
159398  94.267  -77.027  53.442  1
159399  94.282  -77.025  53.433  1
159400  94.297  -77.022  53.426  1
159401  94.312  -77.021  53.425  1
159402  94.327  -77.019  53.425  1
159403  94.343  -77.016  53.424  1
159404  94.348  -77.015  53.422  1
159405  94.346  -77.013  53.417  1
159406  94.345  -77.011  53.413  1
159407  94.343  -77.009  53.411  1
159408  94.342  -77.007  53.408  1
159409  94.340  -77.006  53.400  1
159410  94.354  -77.002  53.390  1
159411  94.372  -76.998  53.377  1
159412  94.391  -76.994  53.358  1
159413  94.409  -76.990  53.337  1
159414  94.427  -76.985  53.313  1
159415  94.445  -76.981  53.289  1
159416  94.464  -76.977  53.266  1
159417  94.482  -76.972  53.241  1
159418  94.502  -76.969  53.217  1
159419  94.524  -76.964  53.190  1
159420  94.551  -76.960  53.162  1
159421  94.579  -76.956  53.136  1
159422  94.608  -76.953  53.113  1
159423  94.620  -76.948  53.088  1
159424  94.628  -76.943  53.062  1
159425  94.636  -76.937  53.035  1
159426  94.644  -76.931  53.003  1
159427  94.653  -76.928  52.969  1
159428  94.665  -76.928  52.935  1
159429  94.677  -76.928  52.901  1
159430  94.688  -76.928  52.868  1
159431  94.700  -76.927  52.835  1
159432  94.712  -76.927  52.801  1
159433  94.731  -76.928  52.764  1
159434  94.771  -76.935  52.724  1
159435  94.812  -76.942  52.684  1
159436  94.852  -76.948  52.646  1
159437  94.892  -76.955  52.611  1
159438  94.932  -76.962  52.579  1
159439  94.943  -76.963  52.546  1
159440  94.948  -76.965  52.512  1
159441  94.954  -76.968  52.483  1
159442  94.959  -76.970  52.459  1
159443  94.966  -76.971  52.437  1
159444  94.977  -76.969  52.416  1
159445  94.998  -76.976  52.391  1
159446  95.019  -76.982  52.364  1
159447  95.040  -76.988  52.338  1
159448  95.061  -76.994  52.318  1
159449  95.083  -77.000  52.293  1
159450  95.104  -77.006  52.263  1
159451  95.124  -77.012  52.229  1
159452  95.144  -77.016  52.189  1
159453  95.165  -77.021  52.144  1
159454  95.185  -77.025  52.095  1
159455  95.205  -77.029  52.043  1
159456  95.225  -77.034  51.988  1
159457  95.245  -77.038  51.932  1
159458  95.265  -77.043  51.874  1
159459  95.276  -77.041  51.816  1
159460  95.293  -77.050  51.755  1
159461  95.310  -77.063  51.694  1
159462  95.328  -77.076  51.636  1
159463  95.345  -77.089  51.579  1
159464  95.359  -77.098  51.521  1
159465  95.374  -77.108  51.464  1
159466  95.387  -77.117  51.408  1
159467  95.401  -77.126  51.355  1
159468  95.415  -77.136  51.303  1
159469  95.429  -77.145  51.255  1
159470  95.443  -77.154  51.210  1
159471  95.458  -77.165  51.168  1
159472  95.475  -77.176  51.125  1
159473  95.492  -77.191  51.078  1
159474  95.508  -77.204  51.030  1
159475  95.523  -77.214  50.982  1
159476  95.538  -77.225  50.934  1
159477  95.552  -77.235  50.886  1
159478  95.567  -77.246  50.837  1
159479  95.582  -77.257  50.791  1
159480  95.597  -77.267  50.747  1
159481  95.613  -77.276  50.703  1
159482  95.633  -77.274  50.659  1
159483  95.654  -77.273  50.616  1
159484  95.674  -77.279  50.573  1
159485  95.693  -77.285  50.529  1
159486  95.713  -77.292  50.486  1
159487  95.733  -77.299  50.445  1
159488  95.751  -77.305  50.406  1
159489  95.758  -77.311  50.367  1
159490  95.765  -77.317  50.328  1
159491  95.777  -77.326  50.288  1
159492  95.798  -77.336  50.247  1
159493  95.818  -77.347  50.205  1
159494  95.839  -77.357  50.162  1
159495  95.859  -77.368  50.118  1
159496  95.880  -77.379  50.069  1
159497  95.909  -77.389  50.020  1
159498  95.942  -77.400  49.970  1
159499  95.965  -77.407  49.919  1
159500  95.979  -77.412  49.867  1
159501  95.992  -77.417  49.816  1
159502  96.006  -77.421  49.768  1
159503  96.011  -77.422  49.720  1
159504  96.005  -77.418  49.672  1
159505  95.999  -77.414  49.624  1
159506  95.992  -77.410  49.578  1
159507  95.996  -77.414  49.530  1
159508  96.001  -77.420  49.486  1
159509  96.005  -77.425  49.445  1
159510  96.010  -77.429  49.404  1
159511  96.016  -77.427  49.364  1
159512  96.023  -77.420  49.325  1
159513  96.030  -77.414  49.287  1
159514  96.038  -77.410  49.250  1
159515  96.050  -77.420  49.217  1
159516  96.062  -77.431  49.186  1
159517  96.075  -77.442  49.156  1
159518  96.087  -77.452  49.126  1
159519  96.107  -77.461  49.097  1
159520  96.127  -77.471  49.069  1
159521  96.148  -77.480  49.043  1
159522  96.168  -77.490  49.020  1
159523  96.181  -77.501  49.000  1
159524  96.191  -77.513  48.982  1
159525  96.200  -77.525  48.966  1
159526  96.209  -77.537  48.954  1
159527  96.220  -77.544  48.939  1
159528  96.231  -77.548  48.920  1
159529  96.242  -77.551  48.898  1
159530  96.253  -77.555  48.875  1
159531  96.263  -77.558  48.851  1
159532  96.274  -77.562  48.827  1
159533  96.288  -77.568  48.809  1
159534  96.317  -77.579  48.790  1
159535  96.345  -77.589  48.769  1
159536  96.374  -77.601  48.748  1
159537  96.403  -77.611  48.729  1
159538  96.432  -77.622  48.711  1
159539  96.460  -77.633  48.693  1
159540  96.489  -77.644  48.674  1
159541  96.518  -77.655  48.656  1
159542  96.547  -77.664  48.638  1
159543  96.576  -77.674  48.623  1
159544  96.591  -77.682  48.608  1
159545  96.598  -77.683  48.592  1
159546  96.605  -77.685  48.575  1
159547  96.612  -77.686  48.557  1
159548  96.619  -77.687  48.537  1
159549  96.625  -77.689  48.516  1
159550  96.632  -77.690  48.495  1
159551  96.639  -77.692  48.474  1
159552  96.646  -77.693  48.456  1
159553  96.653  -77.695  48.438  1
159554  96.660  -77.696  48.420  1
159555  96.667  -77.697  48.400  1
159556  96.673  -77.699  48.381  1
159557  96.680  -77.700  48.361  1
159558  96.687  -77.702  48.343  1
159559  96.697  -77.708  48.323  1
159560  96.707  -77.714  48.302  1
159561  96.719  -77.718  48.279  1
159562  96.733  -77.721  48.254  1
159563  96.747  -77.723  48.228  1
159564  96.761  -77.725  48.202  1
159565  96.776  -77.728  48.175  1
159566  96.790  -77.730  48.150  1
159567  96.804  -77.733  48.124  1
159568  96.818  -77.735  48.097  1
159569  96.832  -77.737  48.071  1
159570  96.847  -77.740  48.045  1
159571  96.861  -77.743  48.019  1
159572  96.875  -77.745  47.994  1
159573  96.890  -77.747  47.969  1
159574  96.913  -77.749  47.945  1
159575  96.939  -77.750  47.921  1
159576  96.964  -77.752  47.896  1
159577  96.990  -77.752  47.874  1
159578  97.015  -77.754  47.854  1
159579  97.028  -77.758  47.834  1
159580  97.036  -77.764  47.813  1
159581  97.047  -77.768  47.792  1
159582  97.058  -77.771  47.772  1
159583  97.069  -77.774  47.752  1
159584  97.081  -77.772  47.730  1
159585  97.094  -77.763  47.709  1
159586  97.108  -77.755  47.687  1
159587  97.121  -77.746  47.665  1
159588  97.135  -77.738  47.644  1
159589  97.154  -77.732  47.623  1
159590  97.179  -77.729  47.603  1
159591  97.205  -77.726  47.582  1
159592  97.229  -77.730  47.560  1
159593  97.252  -77.740  47.539  1
159594  97.277  -77.749  47.518  1
159595  97.307  -77.758  47.498  1
159596  97.337  -77.766  47.479  1
159597  97.367  -77.774  47.460  1
159598  97.397  -77.783  47.441  1
159599  97.428  -77.792  47.421  1
159600  97.458  -77.800  47.402  1
159601  97.488  -77.808  47.382  1
159602  97.518  -77.818  47.362  1
159603  97.548  -77.826  47.342  1
159604  97.567  -77.825  47.321  1
159605  97.576  -77.818  47.299  1
159606  97.585  -77.809  47.278  1
159607  97.594  -77.801  47.257  1
159608  97.608  -77.812  47.235  1
159609  97.624  -77.827  47.213  1
159610  97.639  -77.843  47.192  1
159611  97.655  -77.858  47.169  1
159612  97.670  -77.873  47.145  1
159613  97.677  -77.894  47.121  1
159614  97.674  -77.921  47.096  1
159615  97.672  -77.949  47.070  1
159616  97.669  -77.977  47.045  1
159617  97.667  -78.003  47.018  1
159618  97.685  -78.013  46.992  1
159619  97.703  -78.023  46.966  1
159620  97.709  -78.013  46.940  1
159621  97.735  -78.000  46.914  1
159622  97.755  -78.000  46.889  1
159623  97.780  -77.996  46.866  1
159624  97.815  -77.981  46.842  1
159625  97.850  -77.966  46.819  1
159626  97.885  -77.951  46.796  1
159627  97.920  -77.936  46.773  1
159628  97.948  -77.928  46.751  1
159629  97.961  -77.935  46.728  1
159630  97.974  -77.941  46.705  1
159631  97.988  -77.948  46.684  1
159632  97.989  -77.953  46.662  1
159633  97.984  -77.956  46.641  1
159634  97.979  -77.960  46.620  1
159635  97.974  -77.964  46.599  1
159636  97.982  -77.962  46.578  1
159637  98.005  -77.969  46.557  1
159638  98.034  -77.956  46.537  1
159639  98.100  -77.920  46.515  1
159640  98.166  -77.884  46.493  1
159641  98.232  -77.849  46.471  1
159642  98.298  -77.813  46.449  1
159643  98.377  -77.787  46.426  1
159644  98.460  -77.765  46.403  1
159645  98.543  -77.741  46.379  1
159646  98.588  -77.725  46.356  1
159647  98.625  -77.711  46.333  1
159648  98.644  -77.733  46.310  1
159649  98.656  -77.769  46.289  1
159650  98.669  -77.805  46.269  1
159651  98.684  -77.843  46.248  1
159652  98.695  -77.896  46.227  1
159653  98.698  -77.938  46.210  1
159654  98.702  -77.980  46.190  1
159655  98.717  -77.987  46.169  1
159656  98.731  -77.993  46.147  1
159657  98.734  -77.990  46.128  1
159658  98.735  -77.996  46.108  1
159659  98.736  -78.003  46.090  1
159660  98.737  -78.011  46.072  1
159661  98.737  -78.018  46.052  1
159662  98.738  -78.025  46.032  1
159663  98.739  -78.032  46.012  1
159664  98.740  -78.040  45.991  1
159665  98.741  -78.047  45.970  1
159666  98.741  -78.053  45.951  1
159667  98.742  -78.061  45.934  1
159668  98.759  -78.069  45.916  1
159669  98.811  -78.076  45.900  1
159670  98.864  -78.084  45.883  1
159671  98.917  -78.092  45.866  1
159672  98.954  -78.097  45.849  1
159673  98.960  -78.099  45.833  1
159674  98.987  -78.100  45.819  1
159675  99.042  -78.100  45.803  1
159676  99.097  -78.100  45.788  1
159677  99.152  -78.101  45.773  1
159678  99.207  -78.101  45.758  1
159679  99.251  -78.100  45.746  1
159680  99.269  -78.097  45.734  1
159681  99.287  -78.094  45.723  1
159682  99.306  -78.091  45.712  1
159683  99.324  -78.087  45.701  1
159684  99.343  -78.084  45.690  1
159685  99.361  -78.081  45.678  1
159686  99.379  -78.078  45.666  1
159687  99.398  -78.075  45.654  1
159688  99.416  -78.072  45.643  1
159689  99.426  -78.078  45.632  1
159690  99.439  -78.086  45.622  1
159691  99.470  -78.106  45.611  1
159692  99.500  -78.125  45.601  1
159693  99.530  -78.145  45.590  1
159694  99.560  -78.165  45.580  1
159695  99.595  -78.184  45.569  1
159696  99.628  -78.203  45.557  1
159697  99.655  -78.223  45.546  1
159698  99.684  -78.242  45.533  1
159699  99.711  -78.262  45.521  1
159700  99.739  -78.282  45.508  1
159701  99.767  -78.301  45.496  1
159702  99.795  -78.320  45.483  1
159703  99.815  -78.337  45.471  1
159704  99.832  -78.352  45.459  1
159705  99.849  -78.366  45.446  1
159706  99.866  -78.382  45.433  1
159707  99.859  -78.403  45.420  1
159708  99.859  -78.424  45.406  1
159709  99.895  -78.445  45.392  1
159710  99.931  -78.465  45.378  1
159711  99.968  -78.486  45.363  1
159712  100.004  -78.507  45.348  1
159713  100.041  -78.527  45.333  1
159714  100.077  -78.548  45.317  1
159715  100.113  -78.569  45.301  1
159716  100.149  -78.589  45.283  1
159717  100.186  -78.610  45.265  1
159718  100.222  -78.631  45.247  1
159719  100.258  -78.651  45.230  1
159720  100.291  -78.671  45.213  1
159721  100.286  -78.680  45.195  1
159722  100.277  -78.680  45.178  1
159723  100.283  -78.667  45.161  1
159724  100.294  -78.651  45.144  1
159725  100.305  -78.636  45.127  1
159726  100.317  -78.621  45.111  1
159727  100.337  -78.617  45.094  1
159728  100.366  -78.643  45.078  1
159729  100.397  -78.670  45.063  1
159730  100.444  -78.682  45.047  1
159731  100.491  -78.694  45.032  1
159732  100.538  -78.706  45.016  1
159733  100.585  -78.717  45.002  1
159734  100.610  -78.727  44.986  1
159735  100.629  -78.737  44.971  1
159736  100.648  -78.746  44.955  1
159737  100.668  -78.756  44.939  1
159738  100.687  -78.765  44.922  1
159739  100.705  -78.779  44.906  1
159740  100.720  -78.799  44.891  1
159741  100.738  -78.817  44.874  1
159742  100.756  -78.834  44.859  1
159743  100.774  -78.852  44.843  1
159744  100.791  -78.869  44.826  1
159745  100.824  -78.880  44.809  1
159746  100.863  -78.887  44.793  1
159747  100.903  -78.895  44.777  1
159748  100.943  -78.903  44.760  1
159749  100.987  -78.908  44.743  1
159750  101.035  -78.910  44.727  1
159751  101.082  -78.913  44.711  1
159752  101.129  -78.915  44.696  1
159753  101.162  -78.925  44.680  1
159754  101.196  -78.937  44.665  1
159755  101.235  -78.946  44.650  1
159756  101.258  -78.933  44.637  1
159757  101.282  -78.946  44.623  1
159758  101.307  -78.960  44.609  1
159759  101.331  -78.973  44.596  1
159760  101.356  -78.987  44.583  1
159761  101.379  -79.005  44.570  1
159762  101.395  -79.039  44.557  1
159763  101.412  -79.073  44.545  1
159764  101.448  -79.096  44.532  1
159765  101.490  -79.115  44.520  1
159766  101.532  -79.135  44.506  1
159990  92.454  -77.492  54.079  1
159991  92.474  -77.499  54.089  1
159992  92.494  -77.506  54.100  1
159993  92.514  -77.514  54.111  1
159994  92.534  -77.521  54.122  1
159995  92.554  -77.528  54.133  1
159996  92.574  -77.536  54.144  1
159997  92.594  -77.543  54.155  1
159998  92.614  -77.550  54.166  1
159999  92.634  -77.558  54.176  1
160000  92.654  -77.565  54.187  1
160001  92.673  -77.573  54.198  1
160002  92.694  -77.580  54.208  1
160003  92.714  -77.587  54.219  1
160004  92.733  -77.595  54.228  1
160005  92.754  -77.602  54.235  1
160006  92.774  -77.609  54.241  1
160007  92.793  -77.617  54.247  1
160008  92.817  -77.614  54.253  1
160009  92.842  -77.611  54.259  1
160010  92.867  -77.607  54.265  1
160011  92.883  -77.599  54.272  1
160012  92.898  -77.590  54.278  1
160013  92.912  -77.583  54.284  1
160014  92.926  -77.575  54.290  1
160015  92.940  -77.567  54.295  1
160016  92.954  -77.560  54.299  1
160017  92.964  -77.556  54.303  1
160018  92.973  -77.551  54.306  1
160019  92.982  -77.548  54.308  1
160020  92.991  -77.544  54.309  1
160021  93.000  -77.540  54.309  1
160022  93.009  -77.536  54.310  1
160023  93.018  -77.533  54.312  1
160024  93.028  -77.529  54.316  1
160025  93.040  -77.526  54.320  1
160026  93.052  -77.522  54.325  1
160027  93.062  -77.505  54.331  1
160028  93.073  -77.489  54.338  1
160029  93.083  -77.471  54.344  1
160030  93.100  -77.455  54.349  1
160031  93.117  -77.439  54.354  1
160032  93.134  -77.423  54.358  1
160033  93.151  -77.406  54.360  1
160034  93.169  -77.391  54.361  1
160035  93.199  -77.391  54.361  1
160036  93.228  -77.391  54.362  1
160037  93.256  -77.387  54.360  1
160038  93.280  -77.379  54.357  1
160039  93.304  -77.371  54.352  1
160040  93.323  -77.362  54.346  1
160041  93.336  -77.353  54.340  1
160042  93.346  -77.339  54.333  1
160043  93.354  -77.323  54.326  1
160044  93.362  -77.307  54.320  1
160045  93.370  -77.292  54.311  1
160046  93.379  -77.277  54.300  1
160047  93.398  -77.271  54.287  1
160048  93.415  -77.266  54.277  1
160049  93.433  -77.260  54.268  1
160050  93.451  -77.255  54.260  1
160051  93.469  -77.250  54.251  1
160052  93.486  -77.244  54.242  1
160053  93.509  -77.232  54.232  1
160054  93.532  -77.219  54.219  1
160055  93.556  -77.205  54.205  1
160056  93.579  -77.193  54.193  1
160057  93.600  -77.184  54.182  1
160058  93.621  -77.175  54.170  1
160059  93.642  -77.166  54.156  1
160060  93.663  -77.157  54.143  1
160061  93.684  -77.147  54.129  1
160062  93.705  -77.138  54.113  1
160063  93.721  -77.138  54.098  1
160064  93.735  -77.141  54.082  1
160065  93.750  -77.144  54.061  1
160066  93.764  -77.147  54.041  1
160067  93.777  -77.140  54.022  1
160068  93.788  -77.134  54.004  1
160069  93.789  -77.130  53.988  1
160070  93.791  -77.127  53.970  1
160071  93.792  -77.124  53.952  1
160072  93.794  -77.120  53.936  1
160073  93.798  -77.117  53.921  1
160074  93.804  -77.114  53.907  1
160075  93.809  -77.110  53.895  1
160076  93.827  -77.104  53.881  1
160077  93.857  -77.094  53.867  1
160078  93.888  -77.085  53.851  1
160079  93.917  -77.082  53.832  1
160080  93.927  -77.081  53.810  1
160081  93.937  -77.079  53.789  1
160082  93.946  -77.078  53.767  1
160083  93.956  -77.076  53.749  1
160084  93.976  -77.069  53.731  1
160085  93.999  -77.066  53.712  1
160086  94.023  -77.061  53.691  1
160087  94.047  -77.057  53.672  1
160088  94.070  -77.053  53.654  1
160089  94.094  -77.048  53.636  1
160090  94.118  -77.044  53.617  1
160091  94.141  -77.040  53.598  1
160092  94.168  -77.037  53.578  1
160093  94.182  -77.030  53.556  1
160094  94.194  -77.027  53.533  1
160095  94.207  -77.024  53.514  1
160096  94.219  -77.021  53.496  1
160097  94.231  -77.018  53.480  1
160098  94.244  -77.015  53.466  1
160099  94.258  -77.012  53.453  1
160100  94.273  -77.011  53.442  1
160101  94.288  -77.009  53.434  1
160102  94.303  -77.006  53.430  1
160103  94.319  -77.005  53.428  1
160104  94.334  -77.002  53.426  1
160105  94.344  -76.998  53.425  1
160106  94.346  -76.998  53.422  1
160107  94.345  -76.997  53.418  1
160108  94.344  -76.996  53.415  1
160109  94.342  -76.994  53.411  1
160110  94.341  -76.992  53.404  1
160111  94.359  -76.988  53.394  1
160112  94.378  -76.984  53.381  1
160113  94.396  -76.979  53.362  1
160114  94.414  -76.975  53.341  1
160115  94.432  -76.971  53.318  1
160116  94.451  -76.967  53.295  1
160117  94.469  -76.962  53.271  1
160118  94.488  -76.958  53.248  1
160119  94.505  -76.954  53.224  1
160120  94.526  -76.950  53.197  1
160121  94.553  -76.947  53.170  1
160122  94.581  -76.943  53.144  1
160123  94.608  -76.940  53.119  1
160124  94.618  -76.934  53.092  1
160125  94.627  -76.928  53.065  1
160126  94.636  -76.922  53.039  1
160127  94.645  -76.917  53.007  1
160128  94.653  -76.912  52.972  1
160129  94.666  -76.913  52.936  1
160130  94.679  -76.916  52.900  1
160131  94.692  -76.919  52.865  1
160132  94.705  -76.922  52.833  1
160133  94.718  -76.925  52.800  1
160134  94.754  -76.931  52.764  1
160135  94.794  -76.938  52.727  1
160136  94.835  -76.945  52.690  1
160137  94.875  -76.951  52.654  1
160138  94.909  -76.943  52.622  1
160139  94.931  -76.940  52.591  1
160140  94.937  -76.942  52.560  1
160141  94.942  -76.943  52.526  1
160142  94.948  -76.946  52.498  1
160143  94.955  -76.947  52.475  1
160144  94.965  -76.945  52.454  1
160145  94.976  -76.943  52.436  1
160146  94.994  -76.947  52.413  1
160147  95.015  -76.953  52.388  1
160148  95.036  -76.959  52.362  1
160149  95.057  -76.965  52.343  1
160150  95.078  -76.972  52.320  1
160151  95.100  -76.978  52.292  1
160152  95.121  -76.984  52.258  1
160153  95.142  -76.990  52.218  1
160154  95.164  -76.997  52.172  1
160155  95.185  -77.003  52.122  1
160156  95.206  -77.009  52.068  1
160157  95.227  -77.015  52.012  1
160158  95.248  -77.021  51.954  1
160159  95.269  -77.027  51.896  1
160160  95.286  -77.036  51.836  1
160161  95.300  -77.045  51.773  1
160162  95.314  -77.055  51.713  1
160163  95.327  -77.064  51.657  1
160164  95.341  -77.073  51.599  1
160165  95.355  -77.083  51.541  1
160166  95.369  -77.092  51.482  1
160167  95.383  -77.101  51.425  1
160168  95.397  -77.111  51.370  1
160169  95.410  -77.120  51.319  1
160170  95.424  -77.129  51.271  1
160171  95.438  -77.139  51.225  1
160172  95.455  -77.150  51.182  1
160173  95.472  -77.162  51.138  1
160174  95.489  -77.175  51.092  1
160175  95.507  -77.192  51.045  1
160176  95.522  -77.203  50.998  1
160177  95.537  -77.213  50.950  1
160178  95.552  -77.224  50.901  1
160179  95.567  -77.235  50.852  1
160180  95.582  -77.246  50.805  1
160181  95.597  -77.257  50.761  1
160182  95.615  -77.260  50.717  1
160183  95.635  -77.258  50.672  1
160184  95.656  -77.256  50.628  1
160185  95.676  -77.257  50.584  1
160186  95.695  -77.263  50.541  1
160187  95.716  -77.269  50.498  1
160188  95.735  -77.276  50.458  1
160189  95.753  -77.282  50.419  1
160190  95.760  -77.289  50.381  1
160191  95.767  -77.295  50.342  1
160192  95.774  -77.301  50.303  1
160193  95.792  -77.310  50.262  1
160194  95.812  -77.321  50.219  1
160195  95.833  -77.332  50.175  1
160196  95.853  -77.342  50.130  1
160197  95.874  -77.353  50.082  1
160198  95.905  -77.363  50.034  1
160199  95.938  -77.374  49.984  1
160200  95.965  -77.383  49.933  1
160201  95.978  -77.388  49.882  1
160202  95.992  -77.392  49.831  1
160203  96.006  -77.397  49.783  1
160204  96.002  -77.394  49.735  1
160205  95.996  -77.390  49.685  1
160206  95.989  -77.386  49.636  1
160207  95.983  -77.382  49.589  1
160208  95.977  -77.379  49.541  1
160209  95.971  -77.375  49.497  1
160210  95.975  -77.379  49.454  1
160211  95.981  -77.381  49.412  1
160212  95.988  -77.374  49.371  1
160213  96.000  -77.383  49.331  1
160214  96.012  -77.394  49.292  1
160215  96.024  -77.404  49.256  1
160216  96.036  -77.415  49.223  1
160217  96.048  -77.426  49.191  1
160218  96.061  -77.436  49.160  1
160219  96.082  -77.445  49.130  1
160220  96.102  -77.454  49.100  1
160221  96.122  -77.464  49.072  1
160222  96.143  -77.473  49.045  1
160223  96.163  -77.483  49.023  1
160224  96.183  -77.492  49.003  1
160225  96.192  -77.504  48.985  1
160226  96.201  -77.517  48.970  1
160227  96.211  -77.529  48.956  1
160228  96.222  -77.533  48.939  1
160229  96.233  -77.537  48.918  1
160230  96.244  -77.541  48.894  1
160231  96.255  -77.545  48.871  1
160232  96.266  -77.548  48.850  1
160233  96.277  -77.552  48.832  1
160234  96.292  -77.555  48.816  1
160235  96.321  -77.564  48.798  1
160236  96.350  -77.573  48.777  1
160237  96.380  -77.583  48.758  1
160238  96.409  -77.593  48.740  1
160239  96.439  -77.603  48.723  1
160240  96.468  -77.612  48.705  1
160241  96.498  -77.622  48.687  1
160242  96.527  -77.632  48.669  1
160243  96.555  -77.643  48.651  1
160244  96.572  -77.664  48.636  1
160245  96.588  -77.683  48.621  1
160246  96.600  -77.680  48.606  1
160247  96.612  -77.679  48.590  1
160248  96.622  -77.678  48.572  1
160249  96.629  -77.680  48.551  1
160250  96.636  -77.681  48.530  1
160251  96.643  -77.682  48.509  1
160252  96.649  -77.683  48.491  1
160253  96.656  -77.685  48.474  1
160254  96.663  -77.686  48.458  1
160255  96.670  -77.688  48.441  1
160256  96.677  -77.689  48.419  1
160257  96.683  -77.690  48.399  1
160258  96.690  -77.692  48.380  1
160259  96.697  -77.693  48.360  1
160260  96.705  -77.697  48.341  1
160261  96.715  -77.704  48.321  1
160262  96.727  -77.708  48.298  1
160263  96.741  -77.711  48.274  1
160264  96.755  -77.713  48.248  1
160265  96.770  -77.715  48.222  1
160266  96.784  -77.718  48.195  1
160267  96.798  -77.721  48.169  1
160268  96.812  -77.723  48.144  1
160269  96.826  -77.725  48.117  1
160270  96.841  -77.727  48.091  1
160271  96.855  -77.730  48.064  1
160272  96.869  -77.733  48.039  1
160273  96.891  -77.735  48.013  1
160274  96.912  -77.738  47.988  1
160275  96.934  -77.740  47.963  1
160276  96.960  -77.742  47.939  1
160277  96.985  -77.743  47.915  1
160278  97.011  -77.744  47.893  1
160279  97.028  -77.747  47.872  1
160280  97.034  -77.754  47.852  1
160281  97.040  -77.761  47.832  1
160282  97.050  -77.765  47.812  1
160283  97.061  -77.768  47.792  1
160284  97.072  -77.771  47.771  1
160285  97.086  -77.763  47.750  1
160286  97.099  -77.755  47.729  1
160287  97.112  -77.746  47.707  1
160288  97.129  -77.739  47.686  1
160289  97.154  -77.736  47.665  1
160290  97.179  -77.733  47.643  1
160291  97.205  -77.730  47.622  1
160292  97.230  -77.727  47.601  1
160293  97.254  -77.731  47.579  1
160294  97.278  -77.741  47.557  1
160295  97.301  -77.751  47.536  1
160296  97.325  -77.761  47.515  1
160297  97.354  -77.770  47.495  1
160298  97.384  -77.778  47.476  1
160299  97.414  -77.787  47.456  1
160300  97.444  -77.796  47.436  1
160301  97.474  -77.804  47.416  1
160302  97.505  -77.812  47.396  1
160303  97.535  -77.821  47.376  1
160304  97.565  -77.830  47.356  1
160305  97.586  -77.830  47.335  1
160306  97.595  -77.822  47.313  1
160307  97.603  -77.815  47.292  1
160308  97.612  -77.806  47.270  1
160309  97.621  -77.799  47.248  1
160310  97.637  -77.815  47.227  1
160311  97.653  -77.830  47.205  1
160312  97.668  -77.845  47.182  1
160313  97.684  -77.861  47.157  1
160314  97.685  -77.885  47.132  1
160315  97.682  -77.912  47.107  1
160316  97.680  -77.940  47.080  1
160317  97.681  -77.964  47.055  1
160318  97.699  -77.974  47.028  1
160319  97.717  -77.984  47.002  1
160320  97.732  -77.989  46.976  1
160321  97.749  -77.970  46.951  1
160322  97.770  -77.971  46.925  1
160323  97.789  -77.971  46.900  1
160324  97.809  -77.971  46.876  1
160325  97.840  -77.962  46.852  1
160326  97.875  -77.946  46.828  1
160327  97.910  -77.931  46.805  1
160328  97.945  -77.917  46.783  1
160329  97.958  -77.924  46.760  1
160330  97.971  -77.930  46.736  1
160331  97.984  -77.937  46.713  1
160332  97.997  -77.943  46.691  1
160333  98.006  -77.949  46.669  1
160334  98.001  -77.953  46.649  1
160335  97.996  -77.956  46.628  1
160336  97.991  -77.960  46.606  1
160337  98.026  -77.938  46.584  1
160338  98.054  -77.965  46.563  1
160339  98.080  -77.987  46.543  1
160340  98.112  -77.971  46.521  1
160341  98.178  -77.936  46.499  1
160342  98.244  -77.900  46.476  1
160343  98.310  -77.865  46.454  1
160344  98.377  -77.829  46.431  1
160345  98.443  -77.793  46.407  1
160346  98.509  -77.758  46.383  1
160347  98.575  -77.722  46.360  1
160348  98.624  -77.690  46.338  1
160349  98.641  -77.733  46.317  1
160350  98.644  -77.775  46.296  1
160351  98.647  -77.818  46.276  1
160352  98.650  -77.859  46.256  1
160353  98.653  -77.902  46.236  1
160354  98.656  -77.943  46.219  1
160355  98.670  -77.965  46.199  1
160356  98.684  -77.972  46.178  1
160357  98.698  -77.979  46.158  1
160358  98.712  -77.987  46.138  1
160359  98.727  -77.993  46.118  1
160360  98.741  -78.000  46.099  1
160361  98.754  -78.006  46.081  1
160362  98.755  -78.006  46.061  1
160363  98.756  -78.014  46.041  1
160364  98.757  -78.021  46.020  1
160365  98.758  -78.028  45.999  1
160366  98.758  -78.035  45.979  1
160367  98.759  -78.043  45.959  1
160368  98.760  -78.050  45.942  1
160369  98.761  -78.056  45.925  1
160370  98.800  -78.065  45.908  1
160371  98.852  -78.072  45.891  1
160372  98.905  -78.080  45.874  1
160373  98.917  -78.082  45.857  1
160374  98.947  -78.083  45.841  1
160375  99.002  -78.084  45.827  1
160376  99.058  -78.084  45.811  1
160377  99.113  -78.084  45.795  1
160378  99.168  -78.084  45.780  1
160379  99.223  -78.085  45.765  1
160380  99.263  -78.084  45.753  1
160381  99.281  -78.081  45.741  1
160382  99.300  -78.078  45.730  1
160383  99.319  -78.075  45.720  1
160384  99.337  -78.072  45.709  1
160385  99.355  -78.068  45.697  1
160386  99.374  -78.065  45.686  1
160387  99.392  -78.062  45.673  1
160388  99.408  -78.062  45.662  1
160389  99.418  -78.067  45.651  1
160390  99.428  -78.072  45.641  1
160391  99.438  -78.078  45.630  1
160392  99.452  -78.086  45.620  1
160393  99.483  -78.106  45.609  1
160394  99.512  -78.125  45.598  1
160395  99.544  -78.145  45.587  1
160396  99.583  -78.165  45.576  1
160397  99.621  -78.184  45.565  1
160398  99.649  -78.203  45.553  1
160399  99.677  -78.223  45.541  1
160400  99.705  -78.243  45.529  1
160401  99.733  -78.262  45.517  1
160402  99.761  -78.282  45.504  1
160403  99.785  -78.300  45.491  1
160404  99.802  -78.315  45.478  1
160405  99.819  -78.330  45.466  1
160406  99.836  -78.344  45.455  1
160407  99.853  -78.360  45.442  1
160408  99.862  -78.377  45.428  1
160409  99.854  -78.398  45.414  1
160410  99.880  -78.419  45.399  1
160411  99.917  -78.439  45.384  1
160412  99.953  -78.460  45.369  1
160413  99.989  -78.481  45.353  1
160414  100.025  -78.501  45.338  1
160415  100.062  -78.523  45.322  1
160416  100.098  -78.543  45.305  1
160417  100.134  -78.564  45.288  1
160418  100.171  -78.585  45.270  1
160419  100.207  -78.605  45.252  1
160420  100.232  -78.623  45.235  1
160421  100.226  -78.632  45.218  1
160422  100.221  -78.640  45.200  1
160423  100.215  -78.636  45.184  1
160424  100.226  -78.621  45.167  1
160425  100.237  -78.606  45.150  1
160426  100.249  -78.591  45.134  1
160427  100.275  -78.596  45.118  1
160428  100.310  -78.611  45.102  1
160429  100.344  -78.626  45.086  1
160430  100.375  -78.651  45.071  1
160431  100.423  -78.664  45.055  1
160432  100.470  -78.675  45.039  1
160433  100.517  -78.687  45.024  1
160434  100.565  -78.698  45.009  1
160435  100.612  -78.711  44.994  1
160436  100.641  -78.720  44.977  1
160437  100.660  -78.730  44.961  1
160438  100.679  -78.740  44.947  1
160439  100.700  -78.749  44.930  1
160440  100.721  -78.756  44.914  1
160441  100.739  -78.771  44.899  1
160442  100.753  -78.792  44.882  1
160443  100.768  -78.813  44.866  1
160444  100.782  -78.833  44.850  1
160445  100.797  -78.855  44.834  1
160446  100.834  -78.865  44.817  1
160447  100.874  -78.873  44.801  1
160448  100.913  -78.880  44.785  1
160449  100.953  -78.889  44.768  1
160450  100.993  -78.896  44.751  1
160451  101.040  -78.899  44.735  1
160452  101.088  -78.901  44.719  1
160453  101.135  -78.904  44.703  1
160454  101.155  -78.921  44.688  1
160455  101.193  -78.930  44.673  1
160456  101.232  -78.940  44.658  1
160457  101.259  -78.930  44.645  1
160458  101.281  -78.931  44.631  1
160459  101.306  -78.945  44.617  1
160460  101.330  -78.959  44.604  1
160461  101.355  -78.971  44.590  1
160462  101.377  -78.992  44.577  1
160463  101.394  -79.026  44.563  1
160464  101.410  -79.060  44.551  1
160465  101.447  -79.083  44.539  1
160466  101.489  -79.102  44.527  1
160467  101.532  -79.121  44.514  1
160468  101.574  -79.140  44.502  1
160691  92.443  -77.472  54.058  1
160692  92.463  -77.479  54.070  1
160693  92.483  -77.486  54.082  1
160694  92.503  -77.494  54.094  1
160695  92.523  -77.501  54.107  1
160696  92.543  -77.508  54.119  1
160697  92.563  -77.516  54.131  1
160698  92.583  -77.523  54.144  1
160699  92.602  -77.530  54.157  1
160700  92.623  -77.538  54.169  1
160701  92.643  -77.545  54.181  1
160702  92.662  -77.552  54.193  1
160703  92.683  -77.560  54.205  1
160704  92.703  -77.567  54.216  1
160705  92.722  -77.574  54.226  1
160706  92.742  -77.582  54.234  1
160707  92.763  -77.589  54.242  1
160708  92.782  -77.596  54.250  1
160709  92.805  -77.598  54.257  1
160710  92.830  -77.594  54.263  1
160711  92.854  -77.590  54.270  1
160712  92.874  -77.584  54.277  1
160713  92.889  -77.575  54.283  1
160714  92.903  -77.567  54.290  1
160715  92.917  -77.559  54.296  1
160716  92.931  -77.551  54.301  1
160717  92.942  -77.546  54.306  1
160718  92.951  -77.542  54.310  1
160719  92.960  -77.539  54.313  1
160720  92.969  -77.535  54.315  1
160721  92.978  -77.531  54.315  1
160722  92.987  -77.527  54.316  1
160723  92.996  -77.523  54.318  1
160724  93.005  -77.519  54.321  1
160725  93.014  -77.515  54.325  1
160726  93.025  -77.512  54.331  1
160727  93.037  -77.506  54.337  1
160728  93.047  -77.489  54.343  1
160729  93.060  -77.472  54.350  1
160730  93.077  -77.456  54.356  1
160731  93.094  -77.439  54.363  1
160732  93.111  -77.423  54.369  1
160733  93.128  -77.407  54.375  1
160734  93.145  -77.390  54.378  1
160735  93.162  -77.374  54.379  1
160736  93.179  -77.357  54.380  1
160737  93.205  -77.353  54.382  1
160738  93.234  -77.353  54.382  1
160739  93.264  -77.352  54.380  1
160740  93.294  -77.352  54.374  1
160741  93.318  -77.348  54.367  1
160742  93.326  -77.331  54.359  1
160743  93.331  -77.313  54.350  1
160744  93.337  -77.294  54.344  1
160745  93.342  -77.276  54.338  1
160746  93.355  -77.266  54.331  1
160747  93.373  -77.260  54.319  1
160748  93.391  -77.255  54.306  1
160749  93.408  -77.250  54.294  1
160750  93.426  -77.245  54.284  1
160751  93.443  -77.240  54.275  1
160752  93.461  -77.235  54.266  1
160753  93.481  -77.227  54.257  1
160754  93.504  -77.213  54.248  1
160755  93.528  -77.200  54.235  1
160756  93.551  -77.187  54.222  1
160757  93.574  -77.173  54.210  1
160758  93.597  -77.160  54.200  1
160759  93.619  -77.150  54.188  1
160760  93.640  -77.141  54.176  1
160761  93.661  -77.132  54.164  1
160762  93.682  -77.123  54.150  1
160763  93.701  -77.118  54.135  1
160764  93.715  -77.121  54.119  1
160765  93.729  -77.124  54.104  1
160766  93.743  -77.127  54.084  1
160767  93.757  -77.129  54.064  1
160768  93.771  -77.128  54.044  1
160769  93.781  -77.122  54.027  1
160770  93.783  -77.119  54.009  1
160771  93.784  -77.116  53.991  1
160772  93.787  -77.113  53.974  1
160773  93.793  -77.110  53.958  1
160774  93.798  -77.106  53.943  1
160775  93.804  -77.103  53.929  1
160776  93.810  -77.100  53.918  1
160777  93.821  -77.094  53.905  1
160778  93.852  -77.085  53.891  1
160779  93.883  -77.075  53.877  1
160780  93.913  -77.065  53.857  1
160781  93.928  -77.060  53.836  1
160782  93.939  -77.058  53.816  1
160783  93.948  -77.056  53.796  1
160784  93.958  -77.055  53.779  1
160785  93.971  -77.053  53.763  1
160786  93.994  -77.049  53.746  1
160787  94.018  -77.044  53.724  1
160788  94.042  -77.041  53.705  1
160789  94.065  -77.036  53.685  1
160790  94.089  -77.032  53.665  1
160791  94.113  -77.028  53.646  1
160792  94.136  -77.023  53.625  1
160793  94.160  -77.019  53.604  1
160794  94.173  -77.016  53.582  1
160795  94.185  -77.013  53.557  1
160796  94.198  -77.010  53.536  1
160797  94.210  -77.007  53.517  1
160798  94.222  -77.004  53.500  1
160799  94.235  -77.001  53.483  1
160800  94.249  -76.999  53.468  1
160801  94.264  -76.997  53.455  1
160802  94.279  -76.995  53.445  1
160803  94.294  -76.993  53.438  1
160804  94.310  -76.990  53.434  1
160805  94.325  -76.987  53.431  1
160806  94.337  -76.983  53.429  1
160807  94.342  -76.981  53.426  1
160808  94.343  -76.981  53.423  1
160809  94.344  -76.981  53.421  1
160810  94.343  -76.980  53.417  1
160811  94.346  -76.978  53.411  1
160812  94.364  -76.974  53.401  1
160813  94.383  -76.969  53.388  1
160814  94.401  -76.965  53.370  1
160815  94.419  -76.961  53.349  1
160816  94.436  -76.957  53.327  1
160817  94.453  -76.953  53.304  1
160818  94.470  -76.949  53.280  1
160819  94.487  -76.944  53.256  1
160820  94.504  -76.940  53.232  1
160821  94.519  -76.938  53.205  1
160822  94.544  -76.935  53.178  1
160823  94.572  -76.931  53.152  1
160824  94.598  -76.928  53.126  1
160825  94.607  -76.922  53.098  1
160826  94.616  -76.916  53.070  1
160827  94.625  -76.911  53.042  1
160828  94.635  -76.905  53.009  1
160829  94.649  -76.905  52.976  1
160830  94.671  -76.912  52.942  1
160831  94.687  -76.918  52.907  1
160832  94.700  -76.921  52.872  1
160833  94.713  -76.924  52.838  1
160834  94.737  -76.928  52.806  1
160835  94.777  -76.935  52.771  1
160836  94.817  -76.939  52.736  1
160837  94.851  -76.931  52.702  1
160838  94.886  -76.924  52.670  1
160839  94.920  -76.916  52.639  1
160840  94.925  -76.918  52.607  1
160841  94.931  -76.920  52.574  1
160842  94.936  -76.922  52.542  1
160843  94.945  -76.922  52.514  1
160844  94.955  -76.921  52.490  1
160845  94.965  -76.918  52.471  1
160846  94.976  -76.917  52.453  1
160847  94.990  -76.918  52.433  1
160848  95.011  -76.925  52.412  1
160849  95.032  -76.931  52.388  1
160850  95.053  -76.937  52.369  1
160851  95.074  -76.943  52.348  1
160852  95.096  -76.949  52.321  1
160853  95.117  -76.955  52.286  1
160854  95.138  -76.961  52.245  1
160855  95.160  -76.968  52.198  1
160856  95.181  -76.974  52.146  1
160857  95.202  -76.980  52.089  1
160858  95.223  -76.986  52.032  1
160859  95.244  -76.992  51.975  1
160860  95.271  -77.000  51.917  1
160861  95.281  -77.021  51.855  1
160862  95.295  -77.030  51.791  1
160863  95.309  -77.039  51.730  1
160864  95.323  -77.049  51.675  1
160865  95.337  -77.058  51.616  1
160866  95.350  -77.067  51.558  1
160867  95.365  -77.077  51.500  1
160868  95.378  -77.086  51.441  1
160869  95.392  -77.095  51.386  1
160870  95.406  -77.105  51.334  1
160871  95.420  -77.114  51.285  1
160872  95.435  -77.125  51.239  1
160873  95.452  -77.136  51.194  1
160874  95.469  -77.148  51.149  1
160875  95.486  -77.160  51.105  1
160876  95.504  -77.175  51.059  1
160877  95.522  -77.192  51.012  1
160878  95.537  -77.203  50.964  1
160879  95.551  -77.213  50.915  1
160880  95.566  -77.224  50.866  1
160881  95.581  -77.235  50.819  1
160882  95.596  -77.245  50.775  1
160883  95.616  -77.244  50.731  1
160884  95.636  -77.242  50.685  1
160885  95.657  -77.240  50.640  1
160886  95.678  -77.238  50.597  1
160887  95.698  -77.241  50.554  1
160888  95.718  -77.247  50.512  1
160889  95.737  -77.254  50.471  1
160890  95.754  -77.260  50.432  1
160891  95.761  -77.266  50.395  1
160892  95.768  -77.273  50.357  1
160893  95.775  -77.279  50.318  1
160894  95.785  -77.285  50.276  1
160895  95.806  -77.296  50.232  1
160896  95.826  -77.307  50.187  1
160897  95.847  -77.317  50.142  1
160898  95.869  -77.328  50.095  1
160899  95.902  -77.338  50.047  1
160900  95.935  -77.349  49.999  1
160901  95.965  -77.359  49.948  1
160902  95.978  -77.363  49.897  1
160903  95.992  -77.368  49.847  1
160904  96.000  -77.370  49.798  1
160905  95.993  -77.366  49.748  1
160906  95.987  -77.362  49.698  1
160907  95.981  -77.358  49.648  1
160908  95.975  -77.354  49.600  1
160909  95.969  -77.351  49.552  1
160910  95.962  -77.347  49.506  1
160911  95.956  -77.348  49.463  1
160912  95.961  -77.357  49.420  1
160913  95.973  -77.367  49.378  1
160914  95.985  -77.378  49.337  1
160915  95.997  -77.389  49.298  1
160916  96.010  -77.399  49.262  1
160917  96.022  -77.409  49.228  1
160918  96.036  -77.420  49.195  1
160919  96.056  -77.429  49.164  1
160920  96.077  -77.439  49.133  1
160921  96.097  -77.448  49.104  1
160922  96.117  -77.457  49.076  1
160923  96.137  -77.467  49.049  1
160924  96.158  -77.476  49.027  1
160925  96.178  -77.486  49.007  1
160926  96.194  -77.496  48.988  1
160927  96.203  -77.508  48.972  1
160928  96.213  -77.519  48.957  1
160929  96.224  -77.523  48.940  1
160930  96.235  -77.526  48.919  1
160931  96.246  -77.530  48.895  1
160932  96.258  -77.534  48.872  1
160933  96.273  -77.536  48.852  1
160934  96.291  -77.537  48.836  1
160935  96.309  -77.538  48.821  1
160936  96.331  -77.541  48.803  1
160937  96.361  -77.551  48.784  1
160938  96.390  -77.561  48.767  1
160939  96.419  -77.570  48.751  1
160940  96.449  -77.580  48.734  1
160941  96.478  -77.589  48.718  1
160942  96.508  -77.599  48.700  1
160943  96.533  -77.613  48.682  1
160944  96.550  -77.635  48.665  1
160945  96.567  -77.656  48.649  1
160946  96.584  -77.677  48.634  1
160947  96.597  -77.681  48.619  1
160948  96.609  -77.679  48.603  1
160949  96.621  -77.677  48.585  1
160950  96.632  -77.676  48.564  1
160951  96.645  -77.674  48.544  1
160952  96.653  -77.674  48.524  1
160953  96.659  -77.676  48.508  1
160954  96.666  -77.677  48.492  1
160955  96.673  -77.678  48.476  1
160956  96.680  -77.680  48.459  1
160957  96.687  -77.681  48.439  1
160958  96.693  -77.683  48.419  1
160959  96.700  -77.684  48.399  1
160960  96.707  -77.686  48.378  1
160961  96.714  -77.687  48.359  1
160962  96.724  -77.693  48.339  1
160963  96.736  -77.699  48.317  1
160964  96.750  -77.701  48.293  1
160965  96.764  -77.703  48.268  1
160966  96.778  -77.705  48.242  1
160967  96.793  -77.708  48.215  1
160968  96.807  -77.710  48.188  1
160969  96.821  -77.713  48.162  1
160970  96.835  -77.715  48.136  1
160971  96.849  -77.718  48.109  1
160972  96.870  -77.721  48.082  1
160973  96.891  -77.724  48.056  1
160974  96.912  -77.727  48.031  1
160975  96.934  -77.729  48.006  1
160976  96.955  -77.732  47.982  1
160977  96.980  -77.733  47.958  1
160978  97.006  -77.734  47.933  1
160979  97.028  -77.736  47.911  1
160980  97.033  -77.743  47.890  1
160981  97.039  -77.750  47.871  1
160982  97.045  -77.757  47.851  1
160983  97.053  -77.762  47.831  1
160984  97.065  -77.765  47.811  1
160985  97.077  -77.763  47.791  1
160986  97.090  -77.754  47.770  1
160987  97.103  -77.746  47.749  1
160988  97.129  -77.743  47.728  1
160989  97.154  -77.740  47.706  1
160990  97.179  -77.736  47.685  1
160991  97.205  -77.733  47.663  1
160992  97.230  -77.730  47.641  1
160993  97.255  -77.727  47.619  1
160994  97.280  -77.733  47.597  1
160995  97.303  -77.743  47.575  1
160996  97.327  -77.753  47.554  1
160997  97.350  -77.763  47.532  1
160998  97.374  -77.773  47.512  1
160999  97.400  -77.782  47.492  1
161000  97.431  -77.790  47.471  1
161001  97.461  -77.799  47.451  1
161002  97.491  -77.808  47.431  1
161003  97.521  -77.816  47.410  1
161004  97.551  -77.824  47.389  1
161005  97.582  -77.834  47.370  1
161006  97.604  -77.836  47.350  1
161007  97.613  -77.827  47.328  1
161008  97.622  -77.820  47.306  1
161009  97.631  -77.812  47.284  1
161010  97.640  -77.803  47.262  1
161011  97.651  -77.802  47.240  1
161012  97.666  -77.818  47.218  1
161013  97.682  -77.833  47.194  1
161014  97.697  -77.849  47.168  1
161015  97.693  -77.876  47.142  1
161016  97.691  -77.904  47.116  1
161017  97.696  -77.925  47.090  1
161018  97.713  -77.935  47.064  1
161019  97.731  -77.945  47.038  1
161020  97.749  -77.955  47.013  1
161021  97.758  -77.950  46.988  1
161022  97.784  -77.941  46.963  1
161023  97.803  -77.942  46.938  1
161024  97.823  -77.942  46.913  1
161025  97.843  -77.943  46.888  1
161026  97.865  -77.942  46.863  1
161027  97.899  -77.927  46.839  1
161028  97.935  -77.912  46.815  1
161029  97.954  -77.912  46.792  1
161030  97.967  -77.918  46.768  1
161031  97.981  -77.925  46.744  1
161032  97.994  -77.932  46.720  1
161033  98.007  -77.938  46.696  1
161034  98.020  -77.945  46.675  1
161035  98.017  -77.949  46.654  1
161036  98.013  -77.953  46.633  1
161037  98.008  -77.956  46.611  1
161038  98.070  -77.914  46.589  1
161039  98.098  -77.941  46.568  1
161040  98.126  -77.968  46.547  1
161041  98.154  -77.996  46.526  1
161042  98.191  -77.987  46.504  1
161043  98.257  -77.952  46.481  1
161044  98.323  -77.916  46.458  1
161045  98.389  -77.881  46.434  1
161046  98.435  -77.846  46.410  1
161047  98.474  -77.813  46.386  1
161048  98.512  -77.780  46.365  1
161049  98.551  -77.747  46.343  1
161050  98.598  -77.740  46.323  1
161051  98.602  -77.780  46.303  1
161052  98.605  -77.823  46.282  1
161053  98.608  -77.865  46.263  1
161054  98.611  -77.907  46.245  1
161055  98.619  -77.946  46.228  1
161056  98.637  -77.951  46.208  1
161057  98.651  -77.958  46.188  1
161058  98.665  -77.965  46.167  1
161059  98.680  -77.972  46.147  1
161060  98.694  -77.979  46.127  1
161061  98.708  -77.987  46.108  1
161062  98.722  -77.993  46.090  1
161063  98.737  -78.000  46.070  1
161064  98.751  -78.008  46.049  1
161065  98.765  -78.015  46.028  1
161066  98.775  -78.017  46.008  1
161067  98.776  -78.024  45.987  1
161068  98.776  -78.031  45.968  1
161069  98.777  -78.038  45.950  1
161070  98.778  -78.046  45.933  1
161071  98.788  -78.053  45.916  1
161072  98.841  -78.061  45.899  1
161073  98.875  -78.065  45.882  1
161074  98.908  -78.066  45.864  1
161075  98.963  -78.067  45.849  1
161076  99.018  -78.067  45.834  1
161077  99.073  -78.068  45.818  1
161078  99.129  -78.069  45.803  1
161079  99.184  -78.069  45.788  1
161080  99.239  -78.069  45.774  1
161081  99.276  -78.068  45.760  1
161082  99.294  -78.065  45.748  1
161083  99.312  -78.061  45.737  1
161084  99.331  -78.058  45.727  1
161085  99.349  -78.055  45.715  1
161086  99.368  -78.052  45.704  1
161087  99.386  -78.048  45.694  1
161088  99.400  -78.050  45.681  1
161089  99.410  -78.056  45.670  1
161090  99.420  -78.062  45.659  1
161091  99.430  -78.067  45.648  1
161092  99.440  -78.072  45.638  1
161093  99.450  -78.078  45.628  1
161094  99.465  -78.087  45.617  1
161095  99.495  -78.106  45.606  1
161096  99.532  -78.126  45.594  1
161097  99.571  -78.145  45.583  1
161098  99.610  -78.165  45.572  1
161099  99.643  -78.184  45.560  1
161100  99.671  -78.204  45.548  1
161101  99.699  -78.223  45.536  1
161102  99.727  -78.243  45.524  1
161103  99.755  -78.263  45.511  1
161104  99.772  -78.278  45.498  1
161105  99.789  -78.293  45.486  1
161106  99.806  -78.308  45.474  1
161107  99.823  -78.323  45.462  1
161108  99.840  -78.338  45.449  1
161109  99.857  -78.353  45.434  1
161110  99.857  -78.372  45.420  1
161111  99.865  -78.393  45.405  1
161112  99.902  -78.413  45.389  1
161113  99.938  -78.435  45.374  1
161114  99.974  -78.455  45.358  1
161115  100.010  -78.476  45.342  1
161116  100.047  -78.497  45.325  1
161117  100.083  -78.517  45.308  1
161118  100.119  -78.538  45.292  1
161119  100.155  -78.559  45.274  1
161120  100.173  -78.574  45.256  1
161121  100.168  -78.582  45.239  1
161122  100.162  -78.592  45.223  1
161123  100.157  -78.601  45.207  1
161124  100.157  -78.590  45.190  1
161125  100.168  -78.575  45.174  1
161126  100.180  -78.560  45.157  1
161127  100.214  -78.575  45.141  1
161128  100.249  -78.590  45.126  1
161129  100.283  -78.605  45.109  1
161130  100.317  -78.620  45.094  1
161131  100.357  -78.633  45.078  1
161132  100.402  -78.645  45.062  1
161133  100.449  -78.656  45.046  1
161134  100.496  -78.668  45.031  1
161135  100.544  -78.680  45.016  1
161136  100.591  -78.692  45.000  1
161137  100.638  -78.704  44.984  1
161138  100.671  -78.714  44.968  1
161139  100.691  -78.723  44.954  1
161140  100.713  -78.730  44.937  1
161141  100.734  -78.738  44.921  1
161142  100.755  -78.746  44.906  1
161143  100.772  -78.761  44.890  1
161144  100.787  -78.783  44.874  1
161145  100.802  -78.804  44.858  1
161146  100.826  -78.822  44.842  1
161147  100.857  -78.839  44.825  1
161148  100.888  -78.855  44.809  1
161149  100.923  -78.866  44.792  1
161150  100.963  -78.874  44.776  1
161151  101.002  -78.882  44.760  1
161152  101.046  -78.886  44.743  1
161153  101.094  -78.890  44.727  1
161154  101.124  -78.901  44.712  1
161155  101.152  -78.915  44.696  1
161156  101.190  -78.924  44.681  1
161157  101.229  -78.933  44.666  1
161158  101.259  -78.930  44.652  1
161159  101.281  -78.916  44.638  1
161160  101.305  -78.930  44.624  1
161161  101.329  -78.943  44.611  1
161162  101.354  -78.957  44.598  1
161163  101.375  -78.979  44.585  1
161164  101.392  -79.013  44.572  1
161165  101.408  -79.047  44.559  1
161166  101.447  -79.068  44.547  1
161167  101.489  -79.088  44.534  1
161168  101.531  -79.107  44.520  1
161169  101.573  -79.127  44.508  1
161170  101.616  -79.146  44.496  1
161392  92.432  -77.451  54.036  1
161393  92.452  -77.459  54.050  1
161394  92.472  -77.467  54.063  1
161395  92.492  -77.473  54.076  1
161396  92.512  -77.481  54.090  1
161397  92.532  -77.489  54.103  1
161398  92.552  -77.495  54.117  1
161399  92.572  -77.503  54.132  1
161400  92.592  -77.511  54.147  1
161401  92.612  -77.517  54.160  1
161402  92.632  -77.525  54.173  1
161403  92.652  -77.533  54.185  1
161404  92.671  -77.539  54.197  1
161405  92.690  -77.544  54.208  1
161406  92.709  -77.550  54.219  1
161407  92.728  -77.555  54.228  1
161408  92.747  -77.561  54.239  1
161409  92.769  -77.569  54.247  1
161410  92.788  -77.581  54.256  1
161411  92.813  -77.579  54.264  1
161412  92.842  -77.573  54.272  1
161413  92.866  -77.570  54.280  1
161414  92.880  -77.560  54.287  1
161415  92.894  -77.551  54.294  1
161416  92.909  -77.543  54.301  1
161417  92.921  -77.537  54.307  1
161418  92.929  -77.533  54.311  1
161419  92.938  -77.530  54.315  1
161420  92.947  -77.526  54.319  1
161421  92.956  -77.521  54.321  1
161422  92.966  -77.517  54.321  1
161423  92.975  -77.514  54.322  1
161424  92.984  -77.510  54.325  1
161425  92.993  -77.506  54.329  1
161426  93.001  -77.502  54.335  1
161427  93.010  -77.498  54.342  1
161428  93.021  -77.489  54.349  1
161429  93.037  -77.473  54.355  1
161430  93.054  -77.457  54.363  1
161431  93.071  -77.440  54.370  1
161432  93.088  -77.424  54.376  1
161433  93.105  -77.407  54.383  1
161434  93.122  -77.391  54.390  1
161435  93.139  -77.375  54.394  1
161436  93.156  -77.358  54.397  1
161437  93.173  -77.342  54.399  1
161438  93.190  -77.326  54.401  1
161439  93.211  -77.315  54.401  1
161440  93.241  -77.315  54.400  1
161441  93.271  -77.315  54.393  1
161442  93.280  -77.300  54.384  1
161443  93.286  -77.282  54.375  1
161444  93.295  -77.267  54.367  1
161445  93.313  -77.262  54.360  1
161446  93.330  -77.257  54.353  1
161447  93.348  -77.251  54.346  1
161448  93.365  -77.245  54.337  1
161449  93.383  -77.240  54.324  1
161450  93.401  -77.235  54.311  1
161451  93.418  -77.229  54.299  1
161452  93.436  -77.224  54.288  1
161453  93.454  -77.219  54.279  1
161454  93.476  -77.208  54.270  1
161455  93.499  -77.194  54.260  1
161456  93.522  -77.182  54.248  1
161457  93.546  -77.168  54.237  1
161458  93.569  -77.154  54.226  1
161459  93.592  -77.141  54.216  1
161460  93.616  -77.128  54.205  1
161461  93.638  -77.116  54.194  1
161462  93.659  -77.107  54.182  1
161463  93.680  -77.099  54.169  1
161464  93.694  -77.101  54.155  1
161465  93.708  -77.104  54.139  1
161466  93.722  -77.107  54.124  1
161467  93.737  -77.110  54.105  1
161468  93.751  -77.113  54.086  1
161469  93.765  -77.116  54.066  1
161470  93.774  -77.111  54.049  1
161471  93.776  -77.108  54.031  1
161472  93.782  -77.105  54.013  1
161473  93.787  -77.101  53.996  1
161474  93.793  -77.098  53.980  1
161475  93.799  -77.095  53.965  1
161476  93.804  -77.091  53.952  1
161477  93.811  -77.088  53.941  1
161478  93.816  -77.085  53.928  1
161479  93.847  -77.075  53.915  1
161480  93.877  -77.066  53.898  1
161481  93.901  -77.056  53.878  1
161482  93.917  -77.052  53.857  1
161483  93.931  -77.047  53.836  1
161484  93.946  -77.043  53.817  1
161485  93.960  -77.040  53.802  1
161486  93.969  -77.038  53.788  1
161487  93.987  -77.035  53.773  1
161488  94.010  -77.031  53.753  1
161489  94.034  -77.027  53.734  1
161490  94.058  -77.022  53.715  1
161491  94.082  -77.018  53.695  1
161492  94.106  -77.013  53.673  1
161493  94.129  -77.009  53.651  1
161494  94.150  -77.005  53.627  1
161495  94.164  -77.002  53.603  1
161496  94.176  -76.999  53.580  1
161497  94.189  -76.996  53.559  1
161498  94.201  -76.994  53.539  1
161499  94.213  -76.990  53.521  1
161500  94.225  -76.987  53.504  1
161501  94.240  -76.985  53.487  1
161502  94.255  -76.983  53.471  1
161503  94.270  -76.981  53.459  1
161504  94.286  -76.979  53.451  1
161505  94.301  -76.976  53.444  1
161506  94.316  -76.973  53.438  1
161507  94.328  -76.969  53.434  1
161508  94.338  -76.965  53.431  1
161509  94.339  -76.965  53.428  1
161510  94.340  -76.965  53.427  1
161511  94.341  -76.965  53.424  1
161512  94.350  -76.964  53.418  1
161513  94.367  -76.959  53.408  1
161514  94.384  -76.956  53.397  1
161515  94.401  -76.951  53.379  1
161516  94.418  -76.947  53.359  1
161517  94.435  -76.943  53.338  1
161518  94.452  -76.939  53.315  1
161519  94.469  -76.934  53.292  1
161520  94.486  -76.931  53.268  1
161521  94.502  -76.928  53.245  1
161522  94.517  -76.925  53.217  1
161523  94.535  -76.923  53.190  1
161524  94.563  -76.920  53.163  1
161525  94.587  -76.915  53.136  1
161526  94.596  -76.910  53.109  1
161527  94.606  -76.904  53.081  1
161528  94.615  -76.899  53.052  1
161529  94.625  -76.893  53.019  1
161530  94.643  -76.898  52.986  1
161531  94.665  -76.906  52.953  1
161532  94.686  -76.914  52.919  1
161533  94.707  -76.922  52.886  1
161534  94.721  -76.925  52.852  1
161535  94.758  -76.927  52.819  1
161536  94.793  -76.919  52.784  1
161537  94.827  -76.912  52.750  1
161538  94.862  -76.904  52.718  1
161539  94.897  -76.897  52.687  1
161540  94.914  -76.894  52.655  1
161541  94.919  -76.896  52.623  1
161542  94.925  -76.898  52.590  1
161543  94.933  -76.898  52.557  1
161544  94.944  -76.896  52.529  1
161545  94.955  -76.894  52.505  1
161546  94.965  -76.893  52.485  1
161547  94.976  -76.891  52.469  1
161548  94.986  -76.890  52.449  1
161549  95.007  -76.896  52.430  1
161550  95.028  -76.902  52.410  1
161551  95.049  -76.908  52.392  1
161552  95.070  -76.914  52.370  1
161553  95.092  -76.920  52.343  1
161554  95.113  -76.926  52.308  1
161555  95.134  -76.932  52.265  1
161556  95.156  -76.939  52.217  1
161557  95.177  -76.945  52.164  1
161558  95.198  -76.951  52.108  1
161559  95.219  -76.957  52.051  1
161560  95.242  -76.964  51.993  1
161561  95.279  -76.976  51.934  1
161562  95.289  -76.997  51.869  1
161563  95.290  -77.015  51.806  1
161564  95.305  -77.024  51.745  1
161565  95.318  -77.033  51.689  1
161566  95.332  -77.043  51.630  1
161567  95.346  -77.052  51.572  1
161568  95.360  -77.061  51.514  1
161569  95.374  -77.071  51.456  1
161570  95.388  -77.080  51.401  1
161571  95.402  -77.089  51.347  1
161572  95.415  -77.099  51.297  1
161573  95.432  -77.110  51.248  1
161574  95.449  -77.122  51.202  1
161575  95.466  -77.134  51.157  1
161576  95.483  -77.145  51.112  1
161577  95.500  -77.160  51.068  1
161578  95.519  -77.176  51.023  1
161579  95.536  -77.191  50.977  1
161580  95.551  -77.202  50.928  1
161581  95.566  -77.213  50.881  1
161582  95.581  -77.224  50.835  1
161583  95.597  -77.230  50.789  1
161584  95.618  -77.228  50.743  1
161585  95.638  -77.226  50.698  1
161586  95.659  -77.224  50.653  1
161587  95.679  -77.222  50.611  1
161588  95.699  -77.220  50.568  1
161589  95.720  -77.224  50.526  1
161590  95.739  -77.231  50.485  1
161591  95.756  -77.238  50.446  1
161592  95.763  -77.244  50.408  1
161593  95.770  -77.250  50.371  1
161594  95.777  -77.256  50.333  1
161595  95.783  -77.262  50.290  1
161596  95.800  -77.271  50.244  1
161597  95.820  -77.282  50.198  1
161598  95.840  -77.292  50.153  1
161599  95.865  -77.303  50.108  1
161600  95.898  -77.313  50.061  1
161601  95.931  -77.324  50.013  1
161602  95.964  -77.334  49.964  1
161603  95.978  -77.339  49.913  1
161604  95.992  -77.344  49.863  1
161605  95.991  -77.342  49.814  1
161606  95.985  -77.338  49.761  1
161607  95.979  -77.335  49.711  1
161608  95.972  -77.331  49.660  1
161609  95.966  -77.326  49.611  1
161610  95.960  -77.326  49.561  1
161611  95.952  -77.334  49.514  1
161612  95.944  -77.342  49.470  1
161613  95.947  -77.351  49.427  1
161614  95.959  -77.362  49.385  1
161615  95.971  -77.373  49.344  1
161616  95.983  -77.382  49.303  1
161617  95.995  -77.393  49.266  1
161618  96.011  -77.403  49.232  1
161619  96.031  -77.413  49.200  1
161620  96.051  -77.423  49.168  1
161621  96.072  -77.432  49.137  1
161622  96.092  -77.442  49.108  1
161623  96.112  -77.451  49.080  1
161624  96.132  -77.461  49.052  1
161625  96.153  -77.470  49.031  1
161626  96.173  -77.479  49.010  1
161627  96.193  -77.489  48.990  1
161628  96.205  -77.500  48.974  1
161629  96.216  -77.509  48.958  1
161630  96.227  -77.513  48.941  1
161631  96.238  -77.517  48.921  1
161632  96.253  -77.518  48.899  1
161633  96.271  -77.519  48.876  1
161634  96.290  -77.520  48.854  1
161635  96.308  -77.520  48.839  1
161636  96.326  -77.520  48.823  1
161637  96.345  -77.521  48.807  1
161638  96.370  -77.527  48.791  1
161639  96.399  -77.537  48.776  1
161640  96.429  -77.547  48.761  1
161641  96.458  -77.557  48.746  1
161642  96.488  -77.567  48.730  1
161643  96.510  -77.583  48.713  1
161644  96.527  -77.605  48.695  1
161645  96.544  -77.626  48.678  1
161646  96.561  -77.648  48.662  1
161647  96.579  -77.669  48.648  1
161648  96.594  -77.682  48.633  1
161649  96.605  -77.680  48.616  1
161650  96.617  -77.678  48.597  1
161651  96.629  -77.676  48.577  1
161652  96.641  -77.674  48.557  1
161653  96.653  -77.672  48.539  1
161654  96.665  -77.671  48.524  1
161655  96.676  -77.669  48.508  1
161656  96.683  -77.671  48.492  1
161657  96.690  -77.672  48.477  1
161658  96.696  -77.674  48.459  1
161659  96.703  -77.674  48.439  1
161660  96.711  -77.676  48.419  1
161661  96.717  -77.677  48.397  1
161662  96.724  -77.679  48.378  1
161663  96.733  -77.683  48.358  1
161664  96.744  -77.688  48.336  1
161665  96.758  -77.691  48.312  1
161666  96.772  -77.693  48.287  1
161667  96.787  -77.696  48.261  1
161668  96.801  -77.698  48.234  1
161669  96.815  -77.700  48.207  1
161670  96.829  -77.703  48.179  1
161671  96.849  -77.705  48.152  1
161672  96.870  -77.708  48.125  1
161673  96.891  -77.711  48.098  1
161674  96.912  -77.714  48.072  1
161675  96.934  -77.718  48.047  1
161676  96.955  -77.721  48.022  1
161677  96.976  -77.723  47.999  1
161678  97.001  -77.724  47.976  1
161679  97.027  -77.726  47.952  1
161680  97.033  -77.733  47.929  1
161681  97.039  -77.739  47.909  1
161682  97.045  -77.746  47.890  1
161683  97.051  -77.752  47.871  1
161684  97.056  -77.759  47.850  1
161685  97.068  -77.762  47.830  1
161686  97.081  -77.754  47.811  1
161687  97.103  -77.749  47.790  1
161688  97.129  -77.746  47.768  1
161689  97.154  -77.743  47.747  1
161690  97.179  -77.740  47.726  1
161691  97.205  -77.737  47.704  1
161692  97.230  -77.734  47.683  1
161693  97.256  -77.731  47.661  1
161694  97.281  -77.728  47.639  1
161695  97.305  -77.736  47.616  1
161696  97.328  -77.746  47.594  1
161697  97.352  -77.755  47.572  1
161698  97.376  -77.765  47.550  1
161699  97.399  -77.775  47.529  1
161700  97.423  -77.785  47.509  1
161701  97.447  -77.794  47.486  1
161702  97.477  -77.802  47.465  1
161703  97.508  -77.812  47.444  1
161704  97.538  -77.820  47.423  1
161705  97.568  -77.828  47.402  1
161706  97.599  -77.837  47.382  1
161707  97.623  -77.841  47.361  1
161708  97.632  -77.833  47.339  1
161709  97.641  -77.824  47.318  1
161710  97.650  -77.817  47.296  1
161711  97.658  -77.808  47.274  1
161712  97.667  -77.800  47.253  1
161713  97.680  -77.805  47.229  1
161714  97.696  -77.821  47.204  1
161715  97.705  -77.840  47.179  1
161716  97.702  -77.868  47.152  1
161717  97.710  -77.886  47.126  1
161718  97.728  -77.896  47.100  1
161719  97.745  -77.906  47.074  1
161720  97.764  -77.916  47.048  1
161721  97.782  -77.926  47.024  1
161722  97.797  -77.912  47.000  1
161723  97.817  -77.912  46.976  1
161724  97.837  -77.913  46.950  1
161725  97.857  -77.913  46.925  1
161726  97.877  -77.914  46.900  1
161727  97.897  -77.915  46.874  1
161728  97.925  -77.907  46.850  1
161729  97.951  -77.900  46.825  1
161730  97.964  -77.907  46.801  1
161731  97.978  -77.914  46.777  1
161732  97.991  -77.920  46.751  1
161733  98.004  -77.927  46.726  1
161734  98.017  -77.934  46.702  1
161735  98.030  -77.940  46.679  1
161736  98.034  -77.945  46.658  1
161737  98.029  -77.949  46.636  1
161738  98.028  -77.950  46.614  1
161739  98.114  -77.890  46.592  1
161740  98.142  -77.917  46.571  1
161741  98.170  -77.944  46.549  1
161742  98.198  -77.972  46.528  1
161743  98.226  -78.000  46.507  1
161744  98.246  -78.003  46.485  1
161745  98.286  -77.972  46.461  1
161746  98.324  -77.939  46.437  1
161747  98.363  -77.906  46.413  1
161748  98.402  -77.872  46.390  1
161749  98.440  -77.839  46.369  1
161750  98.479  -77.805  46.348  1
161751  98.523  -77.792  46.328  1
161752  98.560  -77.786  46.309  1
161753  98.563  -77.828  46.289  1
161754  98.566  -77.870  46.271  1
161755  98.569  -77.912  46.253  1
161756  98.590  -77.930  46.237  1
161757  98.604  -77.937  46.217  1
161758  98.619  -77.943  46.197  1
161759  98.633  -77.951  46.177  1
161760  98.647  -77.958  46.155  1
161761  98.661  -77.965  46.135  1
161762  98.675  -77.972  46.117  1
161763  98.690  -77.979  46.099  1
161764  98.704  -77.987  46.079  1
161765  98.718  -77.993  46.058  1
161766  98.732  -78.000  46.038  1
161767  98.747  -78.008  46.017  1
161768  98.761  -78.015  45.996  1
161769  98.775  -78.022  45.977  1
161770  98.789  -78.029  45.959  1
161771  98.795  -78.034  45.941  1
161772  98.796  -78.041  45.924  1
161773  98.830  -78.049  45.907  1
161774  98.869  -78.050  45.890  1
161775  98.924  -78.050  45.872  1
161776  98.979  -78.051  45.856  1
161777  99.034  -78.051  45.841  1
161778  99.089  -78.052  45.825  1
161779  99.144  -78.052  45.809  1
161780  99.199  -78.053  45.795  1
161781  99.255  -78.053  45.781  1
161782  99.288  -78.051  45.767  1
161783  99.306  -78.048  45.755  1
161784  99.325  -78.045  45.743  1
161785  99.344  -78.042  45.732  1
161786  99.362  -78.038  45.722  1
161787  99.380  -78.035  45.712  1
161788  99.392  -78.040  45.701  1
161789  99.402  -78.045  45.690  1
161790  99.412  -78.050  45.678  1
161791  99.422  -78.056  45.667  1
161792  99.432  -78.062  45.655  1
161793  99.443  -78.067  45.646  1
161794  99.453  -78.073  45.635  1
161795  99.463  -78.078  45.624  1
161796  99.481  -78.087  45.613  1
161797  99.519  -78.106  45.601  1
161798  99.559  -78.126  45.590  1
161799  99.597  -78.146  45.578  1
161800  99.636  -78.166  45.566  1
161801  99.664  -78.184  45.554  1
161802  99.693  -78.204  45.542  1
161803  99.720  -78.224  45.530  1
161804  99.743  -78.241  45.517  1
161805  99.760  -78.256  45.505  1
161806  99.776  -78.271  45.493  1
161807  99.793  -78.286  45.481  1
161808  99.810  -78.301  45.467  1
161809  99.827  -78.316  45.454  1
161810  99.844  -78.331  45.439  1
161811  99.860  -78.346  45.425  1
161812  99.852  -78.367  45.410  1
161813  99.887  -78.388  45.395  1
161814  99.923  -78.409  45.379  1
161815  99.959  -78.429  45.362  1
161816  99.995  -78.450  45.346  1
161817  100.031  -78.471  45.329  1
161818  100.068  -78.492  45.313  1
161819  100.104  -78.512  45.296  1
161820  100.113  -78.525  45.279  1
161821  100.108  -78.534  45.263  1
161822  100.103  -78.543  45.246  1
161823  100.098  -78.552  45.230  1
161824  100.091  -78.558  45.214  1
161825  100.100  -78.544  45.197  1
161826  100.119  -78.539  45.180  1
161827  100.153  -78.554  45.164  1
161828  100.187  -78.569  45.148  1
161829  100.231  -78.583  45.133  1
161830  100.281  -78.598  45.117  1
161831  100.328  -78.611  45.101  1
161832  100.365  -78.620  45.085  1
161833  100.406  -78.631  45.068  1
161834  100.451  -78.642  45.053  1
161835  100.495  -78.653  45.037  1
161836  100.540  -78.664  45.022  1
161837  100.585  -78.676  45.007  1
161838  100.630  -78.687  44.991  1
161839  100.675  -78.698  44.975  1
161840  100.702  -78.705  44.961  1
161841  100.726  -78.713  44.944  1
161842  100.747  -78.720  44.928  1
161843  100.768  -78.728  44.912  1
161844  100.789  -78.736  44.896  1
161845  100.806  -78.753  44.881  1
161846  100.824  -78.774  44.865  1
161847  100.855  -78.789  44.849  1
161848  100.886  -78.806  44.832  1
161849  100.916  -78.822  44.816  1
161850  100.948  -78.838  44.800  1
161851  100.978  -78.855  44.784  1
161852  101.012  -78.868  44.768  1
161853  101.052  -78.875  44.752  1
161854  101.097  -78.880  44.736  1
161855  101.113  -78.897  44.720  1
161856  101.148  -78.908  44.704  1
161857  101.187  -78.918  44.689  1
161858  101.226  -78.927  44.673  1
161859  101.260  -78.930  44.660  1
161860  101.281  -78.911  44.646  1
161861  101.304  -78.915  44.632  1
161862  101.329  -78.928  44.619  1
161863  101.353  -78.942  44.606  1
161864  101.374  -78.965  44.593  1
161865  101.390  -79.000  44.579  1
161866  101.407  -79.034  44.566  1
161867  101.447  -79.055  44.554  1
161868  101.489  -79.075  44.540  1
161869  101.531  -79.093  44.527  1
161870  101.573  -79.112  44.515  1
161871  101.616  -79.132  44.502  1
161872  101.656  -79.150  44.489  1
162094  92.440  -77.438  54.028  1
162095  92.459  -77.443  54.042  1
162096  92.479  -77.448  54.057  1
162097  92.498  -77.454  54.072  1
162098  92.517  -77.460  54.086  1
162099  92.536  -77.466  54.103  1
162100  92.555  -77.471  54.119  1
162101  92.574  -77.476  54.134  1
162102  92.593  -77.483  54.149  1
162103  92.613  -77.488  54.163  1
162104  92.632  -77.493  54.176  1
162105  92.651  -77.499  54.188  1
162106  92.670  -77.504  54.200  1
162107  92.689  -77.511  54.211  1
162108  92.710  -77.518  54.221  1
162109  92.733  -77.529  54.232  1
162110  92.756  -77.540  54.241  1
162111  92.779  -77.551  54.250  1
162112  92.788  -77.564  54.259  1
162113  92.810  -77.564  54.268  1
162114  92.840  -77.558  54.277  1
162115  92.865  -77.551  54.286  1
162116  92.882  -77.539  54.294  1
162117  92.900  -77.528  54.301  1
162118  92.910  -77.523  54.307  1
162119  92.920  -77.520  54.312  1
162120  92.930  -77.516  54.316  1
162121  92.940  -77.512  54.319  1
162122  92.950  -77.508  54.322  1
162123  92.959  -77.504  54.323  1
162124  92.970  -77.501  54.326  1
162125  92.979  -77.497  54.331  1
162126  92.989  -77.493  54.336  1
162127  92.999  -77.489  54.345  1
162128  93.009  -77.485  54.354  1
162129  93.022  -77.473  54.361  1
162130  93.039  -77.457  54.368  1
162131  93.055  -77.441  54.376  1
162132  93.070  -77.425  54.383  1
162133  93.086  -77.408  54.390  1
162134  93.102  -77.392  54.396  1
162135  93.118  -77.376  54.402  1
162136  93.134  -77.359  54.406  1
162137  93.150  -77.343  54.411  1
162138  93.167  -77.326  54.415  1
162139  93.184  -77.310  54.416  1
162140  93.201  -77.294  54.417  1
162141  93.218  -77.278  54.416  1
162142  93.235  -77.269  54.408  1
162143  93.253  -77.263  54.399  1
162144  93.270  -77.257  54.389  1
162145  93.288  -77.252  54.381  1
162146  93.305  -77.247  54.373  1
162147  93.323  -77.241  54.366  1
162148  93.341  -77.235  54.358  1
162149  93.358  -77.230  54.350  1
162150  93.376  -77.225  54.337  1
162151  93.394  -77.219  54.324  1
162152  93.411  -77.214  54.311  1
162153  93.429  -77.209  54.299  1
162154  93.447  -77.203  54.288  1
162155  93.471  -77.189  54.279  1
162156  93.494  -77.175  54.271  1
162157  93.517  -77.163  54.259  1
162158  93.541  -77.149  54.248  1
162159  93.564  -77.135  54.238  1
162160  93.587  -77.122  54.229  1
162161  93.611  -77.109  54.218  1
162162  93.634  -77.095  54.208  1
162163  93.657  -77.083  54.198  1
162164  93.674  -77.081  54.186  1
162165  93.688  -77.085  54.173  1
162166  93.702  -77.088  54.159  1
162167  93.716  -77.091  54.143  1
162168  93.730  -77.093  54.126  1
162169  93.745  -77.096  54.107  1
162170  93.759  -77.099  54.088  1
162171  93.770  -77.100  54.071  1
162172  93.776  -77.097  54.054  1
162173  93.782  -77.094  54.036  1
162174  93.788  -77.091  54.019  1
162175  93.793  -77.087  54.003  1
162176  93.799  -77.084  53.989  1
162177  93.805  -77.081  53.976  1
162178  93.811  -77.077  53.964  1
162179  93.817  -77.074  53.953  1
162180  93.841  -77.066  53.938  1
162181  93.872  -77.056  53.921  1
162182  93.890  -77.048  53.900  1
162183  93.905  -77.043  53.878  1
162184  93.920  -77.039  53.857  1
162185  93.935  -77.034  53.838  1
162186  93.949  -77.031  53.823  1
162187  93.965  -77.026  53.809  1
162188  93.980  -77.022  53.795  1
162189  94.003  -77.017  53.777  1
162190  94.027  -77.012  53.758  1
162191  94.051  -77.008  53.739  1
162192  94.075  -77.003  53.719  1
162193  94.099  -76.999  53.698  1
162194  94.123  -76.994  53.676  1
162195  94.141  -76.990  53.652  1
162196  94.154  -76.987  53.627  1
162197  94.167  -76.985  53.605  1
162198  94.180  -76.982  53.585  1
162199  94.192  -76.979  53.566  1
162200  94.204  -76.976  53.546  1
162201  94.216  -76.973  53.527  1
162202  94.231  -76.972  53.509  1
162203  94.247  -76.969  53.492  1
162204  94.262  -76.967  53.477  1
162205  94.277  -76.965  53.466  1
162206  94.293  -76.962  53.458  1
162207  94.307  -76.958  53.451  1
162208  94.319  -76.954  53.446  1
162209  94.331  -76.950  53.440  1
162210  94.335  -76.948  53.435  1
162211  94.336  -76.948  53.432  1
162212  94.338  -76.948  53.430  1
162213  94.348  -76.949  53.425  1
162214  94.366  -76.946  53.417  1
162215  94.383  -76.941  53.407  1
162216  94.400  -76.937  53.391  1
162217  94.417  -76.933  53.372  1
162218  94.434  -76.929  53.351  1
162219  94.451  -76.925  53.329  1
162220  94.468  -76.921  53.308  1
162221  94.485  -76.917  53.286  1
162222  94.500  -76.915  53.263  1
162223  94.515  -76.913  53.235  1
162224  94.530  -76.911  53.206  1
162225  94.554  -76.908  53.177  1
162226  94.576  -76.903  53.151  1
162227  94.585  -76.898  53.124  1
162228  94.595  -76.893  53.097  1
162229  94.605  -76.887  53.068  1
162230  94.617  -76.884  53.035  1
162231  94.638  -76.891  53.001  1
162232  94.659  -76.899  52.968  1
162233  94.680  -76.907  52.936  1
162234  94.702  -76.914  52.904  1
162235  94.735  -76.907  52.871  1
162236  94.769  -76.900  52.836  1
162237  94.804  -76.892  52.801  1
162238  94.838  -76.884  52.768  1
162239  94.873  -76.876  52.736  1
162240  94.903  -76.870  52.704  1
162241  94.908  -76.872  52.672  1
162242  94.914  -76.875  52.638  1
162243  94.923  -76.874  52.605  1
162244  94.933  -76.871  52.571  1
162245  94.944  -76.870  52.543  1
162246  94.955  -76.868  52.518  1
162247  94.965  -76.867  52.497  1
162248  94.976  -76.865  52.480  1
162249  94.986  -76.864  52.462  1
162250  95.003  -76.867  52.444  1
162251  95.024  -76.873  52.428  1
162252  95.045  -76.879  52.411  1
162253  95.066  -76.885  52.389  1
162254  95.088  -76.891  52.361  1
162255  95.109  -76.897  52.327  1
162256  95.130  -76.903  52.282  1
162257  95.151  -76.910  52.233  1
162258  95.173  -76.916  52.180  1
162259  95.194  -76.922  52.125  1
162260  95.215  -76.928  52.067  1
162261  95.249  -76.940  52.008  1
162262  95.286  -76.952  51.946  1
162263  95.300  -76.972  51.882  1
162264  95.286  -76.999  51.819  1
162265  95.300  -77.009  51.759  1
162266  95.314  -77.018  51.701  1
162267  95.328  -77.027  51.644  1
162268  95.342  -77.036  51.586  1
162269  95.355  -77.046  51.528  1
162270  95.370  -77.055  51.470  1
162271  95.383  -77.064  51.415  1
162272  95.397  -77.074  51.361  1
162273  95.412  -77.085  51.309  1
162274  95.429  -77.096  51.260  1
162275  95.446  -77.108  51.213  1
162276  95.463  -77.119  51.167  1
162277  95.480  -77.131  51.120  1
162278  95.497  -77.143  51.076  1
162279  95.515  -77.160  51.031  1
162280  95.533  -77.176  50.986  1
162281  95.550  -77.191  50.940  1
162282  95.565  -77.202  50.895  1
162283  95.580  -77.213  50.850  1
162284  95.599  -77.214  50.804  1
162285  95.619  -77.212  50.759  1
162286  95.640  -77.210  50.714  1
162287  95.660  -77.208  50.668  1
162288  95.681  -77.206  50.624  1
162289  95.701  -77.204  50.582  1
162290  95.722  -77.202  50.541  1
162291  95.742  -77.208  50.500  1
162292  95.757  -77.215  50.460  1
162293  95.764  -77.221  50.422  1
162294  95.771  -77.227  50.384  1
162295  95.778  -77.233  50.345  1
162296  95.785  -77.239  50.302  1
162297  95.794  -77.245  50.257  1
162298  95.814  -77.256  50.211  1
162299  95.834  -77.267  50.166  1
162300  95.862  -77.277  50.121  1
162301  95.895  -77.288  50.074  1
162302  95.927  -77.298  50.026  1
162303  95.960  -77.309  49.978  1
162304  95.978  -77.315  49.929  1
162305  95.988  -77.318  49.879  1
162306  95.982  -77.314  49.831  1
162307  95.976  -77.310  49.779  1
162308  95.970  -77.307  49.728  1
162309  95.963  -77.305  49.676  1
162310  95.956  -77.313  49.623  1
162311  95.948  -77.321  49.571  1
162312  95.940  -77.329  49.524  1
162313  95.932  -77.337  49.478  1
162314  95.932  -77.346  49.433  1
162315  95.944  -77.356  49.391  1
162316  95.957  -77.367  49.349  1
162317  95.969  -77.377  49.309  1
162318  95.985  -77.387  49.271  1
162319  96.005  -77.397  49.237  1
162320  96.026  -77.406  49.204  1
162321  96.046  -77.416  49.173  1
162322  96.066  -77.425  49.141  1
162323  96.087  -77.435  49.111  1
162324  96.107  -77.444  49.083  1
162325  96.127  -77.454  49.056  1
162326  96.148  -77.463  49.034  1
162327  96.168  -77.473  49.013  1
162328  96.188  -77.482  48.993  1
162329  96.207  -77.492  48.975  1
162330  96.218  -77.498  48.955  1
162331  96.234  -77.500  48.935  1
162332  96.252  -77.501  48.915  1
162333  96.270  -77.501  48.895  1
162334  96.289  -77.502  48.874  1
162335  96.307  -77.502  48.854  1
162336  96.325  -77.503  48.837  1
162337  96.343  -77.504  48.822  1
162338  96.362  -77.504  48.808  1
162339  96.380  -77.505  48.795  1
162340  96.409  -77.514  48.783  1
162341  96.439  -77.524  48.770  1
162342  96.468  -77.534  48.756  1
162343  96.487  -77.553  48.742  1
162344  96.505  -77.574  48.725  1
162345  96.522  -77.596  48.708  1
162346  96.539  -77.617  48.691  1
162347  96.556  -77.639  48.676  1
162348  96.573  -77.661  48.662  1
162349  96.590  -77.682  48.646  1
162350  96.602  -77.680  48.628  1
162351  96.614  -77.678  48.609  1
162352  96.626  -77.677  48.590  1
162353  96.638  -77.675  48.571  1
162354  96.650  -77.673  48.553  1
162355  96.662  -77.671  48.537  1
162356  96.673  -77.669  48.521  1
162357  96.685  -77.667  48.505  1
162358  96.697  -77.665  48.490  1
162359  96.707  -77.665  48.473  1
162360  96.714  -77.667  48.455  1
162361  96.721  -77.668  48.436  1
162362  96.727  -77.669  48.415  1
162363  96.734  -77.671  48.394  1
162364  96.741  -77.673  48.373  1
162365  96.752  -77.678  48.351  1
162366  96.766  -77.681  48.327  1
162367  96.781  -77.683  48.303  1
162368  96.795  -77.686  48.278  1
162369  96.809  -77.688  48.250  1
162370  96.828  -77.691  48.223  1
162371  96.849  -77.694  48.196  1
162372  96.871  -77.696  48.169  1
162373  96.892  -77.699  48.142  1
162374  96.913  -77.702  48.116  1
162375  96.935  -77.705  48.090  1
162376  96.956  -77.708  48.065  1
162377  96.977  -77.711  48.041  1
162378  96.999  -77.714  48.017  1
162379  97.022  -77.716  47.994  1
162380  97.033  -77.721  47.971  1
162381  97.038  -77.728  47.948  1
162382  97.044  -77.735  47.927  1
162383  97.050  -77.742  47.908  1
162384  97.056  -77.749  47.889  1
162385  97.062  -77.755  47.870  1
162386  97.078  -77.756  47.850  1
162387  97.103  -77.753  47.830  1
162388  97.129  -77.751  47.809  1
162389  97.154  -77.748  47.789  1
162390  97.180  -77.745  47.768  1
162391  97.205  -77.742  47.746  1
162392  97.231  -77.739  47.724  1
162393  97.256  -77.736  47.703  1
162394  97.282  -77.733  47.681  1
162395  97.307  -77.730  47.658  1
162396  97.330  -77.738  47.635  1
162397  97.354  -77.748  47.612  1
162398  97.377  -77.757  47.589  1
162399  97.401  -77.767  47.567  1
162400  97.425  -77.777  47.546  1
162401  97.448  -77.787  47.524  1
162402  97.471  -77.796  47.501  1
162403  97.495  -77.806  47.479  1
162404  97.524  -77.815  47.458  1
162405  97.555  -77.824  47.437  1
162406  97.585  -77.832  47.415  1
162407  97.615  -77.840  47.394  1
162408  97.642  -77.846  47.373  1
162409  97.650  -77.838  47.352  1
162410  97.659  -77.830  47.330  1
162411  97.668  -77.821  47.308  1
162412  97.677  -77.814  47.286  1
162413  97.686  -77.805  47.264  1
162414  97.695  -77.797  47.239  1
162415  97.709  -77.808  47.214  1
162416  97.713  -77.831  47.189  1
162417  97.724  -77.847  47.162  1
162418  97.742  -77.857  47.136  1
162419  97.759  -77.867  47.110  1
162420  97.778  -77.877  47.084  1
162421  97.796  -77.887  47.059  1
162422  97.808  -77.888  47.035  1
162423  97.831  -77.883  47.012  1
162424  97.851  -77.884  46.989  1
162425  97.871  -77.884  46.962  1
162426  97.891  -77.884  46.937  1
162427  97.911  -77.885  46.911  1
162428  97.931  -77.886  46.886  1
162429  97.948  -77.888  46.860  1
162430  97.961  -77.896  46.835  1
162431  97.974  -77.902  46.810  1
162432  97.987  -77.909  46.785  1
162433  98.000  -77.915  46.758  1
162434  98.013  -77.922  46.732  1
162435  98.027  -77.928  46.707  1
162436  98.040  -77.935  46.682  1
162437  98.051  -77.941  46.660  1
162438  98.046  -77.945  46.637  1
162439  98.070  -77.928  46.615  1
162440  98.157  -77.867  46.593  1
162441  98.185  -77.893  46.571  1
162442  98.213  -77.920  46.548  1
162443  98.218  -77.947  46.527  1
162444  98.224  -77.958  46.506  1
162445  98.231  -77.953  46.485  1
162446  98.238  -77.948  46.463  1
162447  98.245  -77.943  46.439  1
162448  98.285  -77.918  46.416  1
162449  98.324  -77.894  46.393  1
162450  98.364  -77.870  46.372  1
162451  98.404  -77.845  46.352  1
162452  98.448  -77.844  46.333  1
162453  98.491  -77.830  46.315  1
162454  98.521  -77.834  46.296  1
162455  98.524  -77.876  46.277  1
162456  98.535  -77.911  46.260  1
162457  98.558  -77.915  46.244  1
162458  98.572  -77.922  46.225  1
162459  98.586  -77.930  46.205  1
162460  98.600  -77.937  46.185  1
162461  98.615  -77.943  46.164  1
162462  98.629  -77.951  46.144  1
162463  98.643  -77.958  46.125  1
162464  98.657  -77.965  46.107  1
162465  98.671  -77.972  46.087  1
162466  98.686  -77.979  46.067  1
162467  98.700  -77.987  46.047  1
162468  98.714  -77.993  46.026  1
162469  98.728  -78.000  46.005  1
162470  98.742  -78.008  45.986  1
162471  98.758  -78.015  45.967  1
162472  98.777  -78.022  45.950  1
162473  98.795  -78.030  45.933  1
162474  98.834  -78.037  45.915  1
162475  98.884  -78.034  45.898  1
162476  98.939  -78.034  45.880  1
162477  98.995  -78.034  45.864  1
162478  99.050  -78.035  45.848  1
162479  99.105  -78.036  45.831  1
162480  99.160  -78.036  45.816  1
162481  99.215  -78.037  45.801  1
162482  99.270  -78.037  45.788  1
162483  99.301  -78.035  45.774  1
162484  99.319  -78.031  45.761  1
162485  99.338  -78.028  45.750  1
162486  99.356  -78.025  45.738  1
162487  99.374  -78.023  45.728  1
162488  99.384  -78.028  45.719  1
162489  99.394  -78.034  45.708  1
162490  99.404  -78.040  45.698  1
162491  99.414  -78.045  45.687  1
162492  99.425  -78.050  45.675  1
162493  99.435  -78.056  45.663  1
162494  99.444  -78.062  45.653  1
162495  99.453  -78.070  45.642  1
162496  99.462  -78.077  45.632  1
162497  99.482  -78.085  45.620  1
162498  99.513  -78.095  45.608  1
162499  99.546  -78.107  45.596  1
162500  99.585  -78.126  45.584  1
162501  99.624  -78.146  45.572  1
162502  99.658  -78.166  45.560  1
162503  99.686  -78.185  45.548  1
162504  99.713  -78.203  45.536  1
162505  99.729  -78.219  45.525  1
162506  99.747  -78.234  45.512  1
162507  99.763  -78.249  45.499  1
162508  99.780  -78.264  45.486  1
162509  99.797  -78.279  45.473  1
162510  99.814  -78.294  45.459  1
162511  99.831  -78.309  45.445  1
162512  99.848  -78.324  45.430  1
162513  99.855  -78.341  45.415  1
162514  99.871  -78.363  45.400  1
162515  99.908  -78.383  45.384  1
162516  99.944  -78.404  45.367  1
162517  99.980  -78.425  45.350  1
162518  100.016  -78.445  45.334  1
162519  100.053  -78.466  45.317  1
162520  100.054  -78.476  45.301  1
162521  100.049  -78.485  45.284  1
162522  100.044  -78.495  45.268  1
162523  100.039  -78.503  45.252  1
162524  100.034  -78.512  45.236  1
162525  100.031  -78.513  45.219  1
162526  100.058  -78.517  45.202  1
162527  100.101  -78.532  45.186  1
162528  100.151  -78.546  45.170  1
162529  100.202  -78.561  45.155  1
162530  100.253  -78.574  45.139  1
162531  100.300  -78.588  45.124  1
162532  100.337  -78.598  45.107  1
162533  100.373  -78.607  45.091  1
162534  100.410  -78.617  45.074  1
162535  100.455  -78.628  45.060  1
162536  100.500  -78.639  45.044  1
162537  100.544  -78.651  45.029  1
162538  100.589  -78.662  45.013  1
162539  100.634  -78.673  44.998  1
162540  100.678  -78.680  44.982  1
162541  100.701  -78.684  44.967  1
162542  100.725  -78.692  44.950  1
162543  100.750  -78.701  44.934  1
162544  100.775  -78.709  44.918  1
162545  100.799  -78.717  44.902  1
162546  100.824  -78.726  44.887  1
162547  100.852  -78.741  44.871  1
162548  100.883  -78.757  44.854  1
162549  100.913  -78.774  44.839  1
162550  100.944  -78.790  44.823  1
162551  100.974  -78.807  44.807  1
162552  101.004  -78.824  44.791  1
162553  101.035  -78.839  44.775  1
162554  101.065  -78.856  44.759  1
162555  101.086  -78.876  44.744  1
162556  101.107  -78.892  44.728  1
162557  101.145  -78.902  44.712  1
162558  101.184  -78.911  44.696  1
162559  101.222  -78.921  44.681  1
162560  101.261  -78.930  44.667  1
162561  101.281  -78.911  44.653  1
162562  101.303  -78.900  44.639  1
162563  101.328  -78.913  44.626  1
162564  101.352  -78.927  44.613  1
162565  101.372  -78.952  44.600  1
162566  101.388  -78.987  44.586  1
162567  101.405  -79.021  44.573  1
162568  101.446  -79.041  44.560  1
162569  101.488  -79.061  44.547  1
162570  101.531  -79.080  44.533  1
162571  101.573  -79.099  44.521  1
162572  101.615  -79.118  44.508  1
162573  101.657  -79.137  44.496  1
162574  101.674  -79.143  44.484  1
162796  92.439  -77.404  54.021  1
162797  92.458  -77.409  54.037  1
162798  92.478  -77.415  54.052  1
162799  92.497  -77.420  54.068  1
162800  92.516  -77.426  54.086  1
162801  92.535  -77.432  54.103  1
162802  92.555  -77.437  54.120  1
162803  92.574  -77.443  54.136  1
162804  92.593  -77.448  54.151  1
162805  92.612  -77.454  54.166  1
162806  92.631  -77.460  54.179  1
162807  92.651  -77.467  54.191  1
162808  92.674  -77.478  54.203  1
162809  92.698  -77.489  54.214  1
162810  92.720  -77.500  54.224  1
162811  92.743  -77.511  54.233  1
162812  92.767  -77.522  54.243  1
162813  92.782  -77.534  54.252  1
162814  92.789  -77.547  54.262  1
162815  92.807  -77.550  54.272  1
162816  92.837  -77.545  54.281  1
162817  92.860  -77.536  54.291  1
162818  92.877  -77.524  54.297  1
162819  92.900  -77.514  54.304  1
162820  92.929  -77.508  54.311  1
162821  92.941  -77.503  54.314  1
162822  92.950  -77.499  54.319  1
162823  92.960  -77.495  54.322  1
162824  92.971  -77.492  54.326  1
162825  92.980  -77.488  54.330  1
162826  92.990  -77.484  54.334  1
162827  93.000  -77.480  54.340  1
162828  93.010  -77.476  54.348  1
162829  93.020  -77.472  54.356  1
162830  93.035  -77.457  54.365  1
162831  93.051  -77.442  54.374  1
162832  93.067  -77.425  54.382  1
162833  93.082  -77.409  54.391  1
162834  93.098  -77.392  54.399  1
162835  93.115  -77.376  54.406  1
162836  93.130  -77.360  54.409  1
162837  93.146  -77.344  54.414  1
162838  93.162  -77.327  54.419  1
162839  93.178  -77.311  54.425  1
162840  93.194  -77.294  54.428  1
162841  93.204  -77.280  54.428  1
162842  93.214  -77.266  54.425  1
162843  93.229  -77.257  54.418  1
162844  93.246  -77.249  54.409  1
162845  93.263  -77.242  54.400  1
162846  93.281  -77.237  54.392  1
162847  93.298  -77.232  54.384  1
162848  93.316  -77.226  54.375  1
162849  93.333  -77.220  54.367  1
162850  93.351  -77.215  54.358  1
162851  93.368  -77.210  54.347  1
162852  93.386  -77.204  54.334  1
162853  93.404  -77.199  54.321  1
162854  93.421  -77.194  54.308  1
162855  93.442  -77.184  54.297  1
162856  93.466  -77.170  54.287  1
162857  93.489  -77.157  54.278  1
162858  93.512  -77.144  54.268  1
162859  93.536  -77.130  54.257  1
162860  93.559  -77.117  54.247  1
162861  93.582  -77.103  54.238  1
162862  93.606  -77.090  54.228  1
162863  93.630  -77.080  54.218  1
162864  93.651  -77.074  54.210  1
162865  93.664  -77.077  54.200  1
162866  93.683  -77.069  54.188  1
162867  93.698  -77.072  54.174  1
162868  93.712  -77.075  54.160  1
162869  93.727  -77.078  54.143  1
162870  93.741  -77.081  54.126  1
162871  93.754  -77.082  54.109  1
162872  93.762  -77.081  54.093  1
162873  93.770  -77.080  54.076  1
162874  93.778  -77.079  54.059  1
162875  93.787  -77.078  54.042  1
162876  93.794  -77.075  54.026  1
162877  93.799  -77.072  54.013  1
162878  93.805  -77.069  54.000  1
162879  93.811  -77.066  53.990  1
162880  93.817  -77.063  53.978  1
162881  93.836  -77.056  53.964  1
162882  93.860  -77.047  53.947  1
162883  93.877  -77.039  53.925  1
162884  93.893  -77.034  53.903  1
162885  93.908  -77.031  53.880  1
162886  93.923  -77.026  53.858  1
162887  93.938  -77.022  53.841  1
162888  93.956  -77.018  53.827  1
162889  93.980  -77.013  53.814  1
162890  94.002  -77.006  53.797  1
162891  94.024  -77.000  53.779  1
162892  94.045  -76.994  53.760  1
162893  94.068  -76.988  53.740  1
162894  94.092  -76.984  53.720  1
162895  94.116  -76.979  53.699  1
162896  94.131  -76.976  53.676  1
162897  94.144  -76.974  53.651  1
162898  94.157  -76.971  53.631  1
162899  94.170  -76.969  53.612  1
162900  94.183  -76.965  53.593  1
162901  94.195  -76.962  53.574  1
162902  94.207  -76.959  53.554  1
162903  94.222  -76.957  53.535  1
162904  94.238  -76.956  53.516  1
162905  94.253  -76.953  53.498  1
162906  94.269  -76.950  53.484  1
162907  94.284  -76.947  53.473  1
162908  94.297  -76.943  53.465  1
162909  94.310  -76.939  53.459  1
162910  94.322  -76.935  53.452  1
162911  94.332  -76.931  53.444  1
162912  94.333  -76.931  53.439  1
162913  94.336  -76.933  53.436  1
162914  94.347  -76.933  53.431  1
162915  94.364  -76.931  53.424  1
162916  94.382  -76.928  53.414  1
162917  94.399  -76.924  53.400  1
162918  94.416  -76.919  53.384  1
162919  94.433  -76.915  53.366  1
162920  94.450  -76.911  53.347  1
162921  94.467  -76.907  53.327  1
162922  94.483  -76.904  53.306  1
162923  94.498  -76.902  53.283  1
162924  94.513  -76.900  53.255  1
162925  94.528  -76.898  53.227  1
162926  94.544  -76.896  53.201  1
162927  94.565  -76.892  53.175  1
162928  94.574  -76.886  53.148  1
162929  94.584  -76.881  53.119  1
162930  94.595  -76.875  53.090  1
162931  94.611  -76.877  53.057  1
162932  94.632  -76.884  53.024  1
162933  94.653  -76.892  52.990  1
162934  94.680  -76.893  52.959  1
162935  94.713  -76.886  52.926  1
162936  94.747  -76.879  52.892  1
162937  94.780  -76.872  52.857  1
162938  94.815  -76.865  52.822  1
162939  94.849  -76.856  52.789  1
162940  94.884  -76.849  52.756  1
162941  94.897  -76.849  52.722  1
162942  94.902  -76.850  52.687  1
162943  94.912  -76.850  52.654  1
162944  94.923  -76.847  52.620  1
162945  94.933  -76.846  52.585  1
162946  94.944  -76.844  52.555  1
162947  94.955  -76.843  52.528  1
162948  94.965  -76.841  52.505  1
162949  94.976  -76.839  52.487  1
162950  94.986  -76.837  52.471  1
162951  94.999  -76.838  52.456  1
162952  95.020  -76.844  52.441  1
162953  95.041  -76.850  52.425  1
162954  95.062  -76.856  52.404  1
162955  95.084  -76.862  52.376  1
162956  95.105  -76.868  52.340  1
162957  95.126  -76.875  52.296  1
162958  95.147  -76.881  52.247  1
162959  95.169  -76.887  52.195  1
162960  95.190  -76.893  52.140  1
162961  95.220  -76.903  52.081  1
162962  95.257  -76.915  52.020  1
162963  95.293  -76.928  51.957  1
162964  95.311  -76.946  51.894  1
162965  95.294  -76.975  51.833  1
162966  95.296  -76.993  51.772  1
162967  95.310  -77.002  51.714  1
162968  95.323  -77.012  51.657  1
162969  95.337  -77.021  51.599  1
162970  95.351  -77.030  51.541  1
162971  95.365  -77.040  51.484  1
162972  95.379  -77.049  51.429  1
162973  95.393  -77.058  51.376  1
162974  95.410  -77.070  51.322  1
162975  95.426  -77.081  51.273  1
162976  95.444  -77.094  51.225  1
162977  95.461  -77.105  51.177  1
162978  95.477  -77.117  51.130  1
162979  95.494  -77.128  51.085  1
162980  95.512  -77.144  51.040  1
162981  95.530  -77.160  50.996  1
162982  95.548  -77.177  50.952  1
162983  95.565  -77.191  50.909  1
162984  95.580  -77.201  50.866  1
162985  95.601  -77.198  50.820  1
162986  95.621  -77.196  50.775  1
162987  95.641  -77.194  50.729  1
162988  95.662  -77.192  50.683  1
162989  95.682  -77.190  50.638  1
162990  95.703  -77.188  50.596  1
162991  95.723  -77.186  50.555  1
162992  95.744  -77.186  50.514  1
162993  95.758  -77.192  50.474  1
162994  95.765  -77.198  50.436  1
162995  95.772  -77.204  50.398  1
162996  95.779  -77.210  50.359  1
162997  95.787  -77.216  50.316  1
162998  95.794  -77.222  50.271  1
162999  95.808  -77.231  50.224  1
163000  95.828  -77.241  50.179  1
163001  95.858  -77.252  50.134  1
163002  95.891  -77.263  50.088  1
163003  95.924  -77.273  50.041  1
163004  95.957  -77.284  49.994  1
163005  95.978  -77.291  49.945  1
163006  95.980  -77.290  49.897  1
163007  95.974  -77.286  49.848  1
163008  95.967  -77.284  49.797  1
163009  95.959  -77.291  49.745  1
163010  95.952  -77.300  49.691  1
163011  95.944  -77.307  49.636  1
163012  95.936  -77.316  49.583  1
163013  95.927  -77.323  49.534  1
163014  95.919  -77.332  49.487  1
163015  95.918  -77.340  49.441  1
163016  95.930  -77.351  49.398  1
163017  95.942  -77.361  49.356  1
163018  95.959  -77.371  49.315  1
163019  95.980  -77.380  49.277  1
163020  96.000  -77.390  49.242  1
163021  96.020  -77.399  49.209  1
163022  96.041  -77.409  49.177  1
163023  96.061  -77.418  49.146  1
163024  96.081  -77.428  49.116  1
163025  96.102  -77.437  49.087  1
163026  96.122  -77.447  49.060  1
163027  96.142  -77.457  49.037  1
163028  96.163  -77.465  49.016  1
163029  96.184  -77.473  48.996  1
163030  96.204  -77.480  48.977  1
163031  96.225  -77.482  48.955  1
163032  96.245  -77.483  48.933  1
163033  96.265  -77.483  48.912  1
163034  96.286  -77.484  48.893  1
163035  96.306  -77.485  48.874  1
163036  96.324  -77.486  48.855  1
163037  96.342  -77.486  48.837  1
163038  96.361  -77.487  48.823  1
163039  96.379  -77.488  48.810  1
163040  96.397  -77.488  48.800  1
163041  96.419  -77.492  48.790  1
163042  96.448  -77.501  48.779  1
163043  96.465  -77.523  48.767  1
163044  96.482  -77.545  48.752  1
163045  96.500  -77.566  48.736  1
163046  96.517  -77.588  48.720  1
163047  96.534  -77.609  48.704  1
163048  96.551  -77.630  48.690  1
163049  96.568  -77.652  48.675  1
163050  96.585  -77.674  48.658  1
163051  96.599  -77.681  48.640  1
163052  96.611  -77.679  48.621  1
163053  96.622  -77.677  48.602  1
163054  96.635  -77.675  48.584  1
163055  96.647  -77.674  48.566  1
163056  96.658  -77.672  48.551  1
163057  96.670  -77.670  48.534  1
163058  96.682  -77.668  48.517  1
163059  96.694  -77.666  48.501  1
163060  96.705  -77.664  48.484  1
163061  96.718  -77.662  48.466  1
163062  96.729  -77.661  48.448  1
163063  96.737  -77.661  48.429  1
163064  96.744  -77.663  48.409  1
163065  96.751  -77.664  48.388  1
163066  96.761  -77.668  48.368  1
163067  96.775  -77.671  48.343  1
163068  96.789  -77.674  48.319  1
163069  96.807  -77.676  48.294  1
163070  96.828  -77.679  48.267  1
163071  96.850  -77.682  48.240  1
163072  96.871  -77.685  48.214  1
163073  96.892  -77.688  48.187  1
163074  96.913  -77.690  48.160  1
163075  96.935  -77.693  48.134  1
163076  96.956  -77.696  48.108  1
163077  96.977  -77.699  48.084  1
163078  96.999  -77.702  48.060  1
163079  97.019  -77.704  48.036  1
163080  97.033  -77.707  48.013  1
163081  97.039  -77.712  47.990  1
163082  97.045  -77.717  47.967  1
163083  97.052  -77.722  47.946  1
163084  97.058  -77.727  47.926  1
163085  97.065  -77.732  47.908  1
163086  97.074  -77.738  47.889  1
163087  97.102  -77.746  47.869  1
163088  97.129  -77.755  47.850  1
163089  97.155  -77.752  47.829  1
163090  97.180  -77.749  47.809  1
163091  97.206  -77.746  47.788  1
163092  97.231  -77.743  47.766  1
163093  97.256  -77.740  47.744  1
163094  97.282  -77.736  47.722  1
163095  97.307  -77.733  47.700  1
163096  97.332  -77.730  47.677  1
163097  97.356  -77.740  47.653  1
163098  97.379  -77.749  47.630  1
163099  97.403  -77.759  47.607  1
163100  97.427  -77.769  47.584  1
163101  97.450  -77.779  47.562  1
163102  97.473  -77.789  47.539  1
163103  97.497  -77.799  47.515  1
163104  97.520  -77.808  47.493  1
163105  97.544  -77.818  47.471  1
163106  97.572  -77.827  47.450  1
163107  97.602  -77.836  47.428  1
163108  97.632  -77.844  47.407  1
163109  97.660  -77.851  47.385  1
163110  97.669  -77.843  47.364  1
163111  97.678  -77.835  47.343  1
163112  97.686  -77.827  47.321  1
163113  97.696  -77.819  47.298  1
163114  97.704  -77.811  47.274  1
163115  97.713  -77.802  47.248  1
163116  97.722  -77.796  47.223  1
163117  97.738  -77.808  47.197  1
163118  97.756  -77.818  47.172  1
163119  97.774  -77.828  47.146  1
163120  97.792  -77.838  47.120  1
163121  97.810  -77.848  47.094  1
163122  97.828  -77.858  47.069  1
163123  97.846  -77.853  47.046  1
163124  97.865  -77.854  47.022  1
163125  97.885  -77.854  47.000  1
163126  97.905  -77.855  46.973  1
163127  97.925  -77.856  46.947  1
163128  97.934  -77.870  46.922  1
163129  97.947  -77.876  46.896  1
163130  97.964  -77.877  46.870  1
163131  97.978  -77.883  46.844  1
163132  97.988  -77.893  46.818  1
163133  97.999  -77.902  46.791  1
163134  98.010  -77.911  46.764  1
163135  98.023  -77.917  46.738  1
163136  98.036  -77.924  46.713  1
163137  98.050  -77.931  46.688  1
163138  98.063  -77.937  46.664  1
163139  98.063  -77.941  46.641  1
163140  98.113  -77.906  46.617  1
163141  98.189  -77.854  46.594  1
163142  98.200  -77.868  46.571  1
163143  98.205  -77.896  46.548  1
163144  98.211  -77.908  46.527  1
163145  98.218  -77.902  46.506  1
163146  98.225  -77.898  46.485  1
163147  98.232  -77.893  46.464  1
163148  98.239  -77.889  46.441  1
163149  98.245  -77.884  46.418  1
163150  98.252  -77.879  46.396  1
163151  98.284  -77.859  46.375  1
163152  98.323  -77.837  46.357  1
163153  98.369  -77.849  46.338  1
163154  98.414  -77.862  46.321  1
163155  98.458  -77.869  46.302  1
163156  98.483  -77.881  46.283  1
163157  98.511  -77.894  46.266  1
163158  98.525  -77.901  46.249  1
163159  98.539  -77.908  46.232  1
163160  98.554  -77.915  46.213  1
163161  98.568  -77.922  46.192  1
163162  98.582  -77.929  46.173  1
163163  98.596  -77.937  46.153  1
163164  98.611  -77.943  46.133  1
163165  98.630  -77.951  46.114  1
163166  98.648  -77.959  46.096  1
163167  98.667  -77.965  46.076  1
163168  98.686  -77.973  46.056  1
163169  98.704  -77.981  46.035  1
163170  98.723  -77.988  46.014  1
163171  98.741  -77.995  45.994  1
163172  98.760  -78.003  45.976  1
163173  98.779  -78.010  45.958  1
163174  98.797  -78.018  45.941  1
163175  98.848  -78.027  45.923  1
163176  98.914  -78.030  45.906  1
163177  98.959  -78.022  45.888  1
163178  99.010  -78.018  45.871  1
163179  99.066  -78.019  45.855  1
163180  99.121  -78.019  45.837  1
163181  99.176  -78.020  45.823  1
163182  99.231  -78.020  45.809  1
163183  99.286  -78.021  45.795  1
163184  99.313  -78.018  45.781  1
163185  99.332  -78.015  45.768  1
163186  99.350  -78.012  45.756  1
163187  99.366  -78.012  45.746  1
163188  99.376  -78.018  45.736  1
163189  99.386  -78.023  45.725  1
163190  99.397  -78.028  45.714  1
163191  99.407  -78.034  45.703  1
163192  99.416  -78.040  45.693  1
163193  99.425  -78.047  45.681  1
163194  99.433  -78.055  45.670  1
163195  99.442  -78.062  45.660  1
163196  99.450  -78.069  45.650  1
163197  99.459  -78.077  45.638  1
163198  99.484  -78.085  45.626  1
163199  99.515  -78.095  45.614  1
163200  99.547  -78.105  45.602  1
163201  99.578  -78.114  45.591  1
163202  99.612  -78.127  45.579  1
163203  99.650  -78.146  45.567  1
163204  99.680  -78.166  45.555  1
163205  99.700  -78.182  45.544  1
163206  99.717  -78.197  45.532  1
163207  99.733  -78.212  45.519  1
163208  99.751  -78.227  45.506  1
163209  99.767  -78.242  45.492  1
163210  99.784  -78.257  45.479  1
163211  99.801  -78.272  45.465  1
163212  99.818  -78.287  45.450  1
163213  99.835  -78.302  45.435  1
163214  99.852  -78.317  45.420  1
163215  99.856  -78.337  45.404  1
163216  99.893  -78.357  45.389  1
163217  99.929  -78.378  45.372  1
163218  99.965  -78.399  45.355  1
163219  99.999  -78.419  45.339  1
163220  99.994  -78.428  45.321  1
163221  99.989  -78.437  45.306  1
163222  99.984  -78.445  45.289  1
163223  99.979  -78.454  45.272  1
163224  99.974  -78.463  45.256  1
163225  99.985  -78.479  45.239  1
163226  100.021  -78.495  45.223  1
163227  100.072  -78.509  45.206  1
163228  100.123  -78.523  45.190  1
163229  100.173  -78.537  45.174  1
163230  100.224  -78.551  45.159  1
163231  100.272  -78.565  45.144  1
163232  100.309  -78.575  45.128  1
163233  100.346  -78.585  45.112  1
163234  100.382  -78.594  45.096  1
163235  100.419  -78.604  45.080  1
163236  100.459  -78.614  45.064  1
163237  100.504  -78.626  45.049  1
163238  100.549  -78.637  45.033  1
163239  100.593  -78.648  45.018  1
163240  100.638  -78.659  45.002  1
163241  100.676  -78.655  44.986  1
163242  100.701  -78.664  44.971  1
163243  100.725  -78.672  44.954  1
163244  100.750  -78.680  44.939  1
163245  100.774  -78.689  44.923  1
163246  100.798  -78.697  44.907  1
163247  100.826  -78.708  44.892  1
163248  100.856  -78.721  44.876  1
163249  100.886  -78.738  44.860  1
163250  100.916  -78.755  44.845  1
163251  100.947  -78.771  44.829  1
163252  100.977  -78.788  44.813  1
163253  101.007  -78.804  44.797  1
163254  101.038  -78.821  44.782  1
163255  101.067  -78.823  44.766  1
163256  101.085  -78.847  44.750  1
163257  101.096  -78.880  44.735  1
163258  101.140  -78.894  44.719  1
163259  101.181  -78.905  44.704  1
163260  101.219  -78.914  44.689  1
163261  101.258  -78.924  44.675  1
163262  101.282  -78.911  44.661  1
163263  101.303  -78.891  44.647  1
163264  101.327  -78.899  44.633  1
163265  101.351  -78.912  44.619  1
163266  101.370  -78.940  44.605  1
163267  101.387  -78.974  44.592  1
163268  101.404  -79.009  44.579  1
163269  101.446  -79.028  44.566  1
163270  101.488  -79.046  44.553  1
163271  101.530  -79.066  44.539  1
163272  101.572  -79.085  44.527  1
163273  101.615  -79.105  44.514  1
163274  101.657  -79.124  44.502  1
163275  101.675  -79.130  44.491  1
163276  101.691  -79.135  44.479  1
163497  92.420  -77.364  54.000  1
163498  92.439  -77.370  54.016  1
163499  92.458  -77.376  54.033  1
163500  92.477  -77.381  54.050  1
163501  92.496  -77.386  54.068  1
163502  92.515  -77.392  54.087  1
163503  92.534  -77.398  54.105  1
163504  92.554  -77.403  54.122  1
163505  92.573  -77.409  54.138  1
163506  92.592  -77.416  54.153  1
163507  92.616  -77.426  54.169  1
163508  92.639  -77.438  54.182  1
163509  92.662  -77.448  54.194  1
163510  92.685  -77.460  54.205  1
163511  92.708  -77.471  54.215  1
163512  92.731  -77.482  54.225  1
163513  92.754  -77.493  54.235  1
163514  92.775  -77.504  54.245  1
163515  92.782  -77.517  54.254  1
163516  92.789  -77.530  54.263  1
163517  92.804  -77.536  54.273  1
163518  92.834  -77.530  54.282  1
163519  92.855  -77.520  54.290  1
163520  92.872  -77.509  54.298  1
163521  92.900  -77.501  54.305  1
163522  92.929  -77.494  54.311  1
163523  92.958  -77.487  54.317  1
163524  92.972  -77.483  54.323  1
163525  92.981  -77.479  54.328  1
163526  92.991  -77.475  54.332  1
163527  93.001  -77.471  54.337  1
163528  93.011  -77.467  54.343  1
163529  93.021  -77.463  54.350  1
163530  93.031  -77.458  54.358  1
163531  93.047  -77.442  54.368  1
163532  93.063  -77.426  54.377  1
163533  93.079  -77.410  54.386  1
163534  93.095  -77.393  54.395  1
163535  93.111  -77.377  54.402  1
163536  93.127  -77.360  54.408  1
163537  93.142  -77.344  54.412  1
163538  93.158  -77.328  54.416  1
163539  93.168  -77.313  54.420  1
163540  93.179  -77.299  54.425  1
163541  93.188  -77.285  54.429  1
163542  93.198  -77.271  54.428  1
163543  93.208  -77.257  54.423  1
163544  93.223  -77.247  54.416  1
163545  93.240  -77.239  54.407  1
163546  93.258  -77.232  54.398  1
163547  93.274  -77.225  54.391  1
163548  93.291  -77.217  54.384  1
163549  93.308  -77.210  54.377  1
163550  93.326  -77.205  54.370  1
163551  93.344  -77.200  54.361  1
163552  93.361  -77.194  54.351  1
163553  93.379  -77.188  54.341  1
163554  93.397  -77.184  54.328  1
163555  93.414  -77.179  54.316  1
163556  93.437  -77.165  54.305  1
163557  93.461  -77.152  54.294  1
163558  93.484  -77.138  54.284  1
163559  93.507  -77.125  54.273  1
163560  93.531  -77.112  54.263  1
163561  93.555  -77.101  54.253  1
163562  93.578  -77.091  54.244  1
163563  93.603  -77.081  54.235  1
163564  93.626  -77.072  54.226  1
163565  93.639  -77.078  54.219  1
163566  93.647  -77.090  54.211  1
163567  93.666  -77.082  54.201  1
163568  93.686  -77.075  54.188  1
163569  93.704  -77.068  54.175  1
163570  93.723  -77.062  54.158  1
163571  93.737  -77.065  54.142  1
163572  93.746  -77.064  54.127  1
163573  93.755  -77.063  54.112  1
163574  93.763  -77.062  54.096  1
163575  93.771  -77.060  54.080  1
163576  93.779  -77.059  54.064  1
163577  93.787  -77.058  54.048  1
163578  93.795  -77.057  54.034  1
163579  93.803  -77.056  54.022  1
163580  93.812  -77.055  54.011  1
163581  93.817  -77.051  54.000  1
163582  93.830  -77.046  53.987  1
163583  93.849  -77.038  53.972  1
163584  93.865  -77.031  53.951  1
163585  93.881  -77.026  53.928  1
163586  93.896  -77.022  53.906  1
163587  93.911  -77.018  53.882  1
163588  93.932  -77.013  53.865  1
163589  93.957  -77.009  53.849  1
163590  93.980  -77.004  53.832  1
163591  94.002  -76.997  53.814  1
163592  94.024  -76.991  53.794  1
163593  94.046  -76.984  53.775  1
163594  94.067  -76.978  53.758  1
163595  94.089  -76.972  53.739  1
163596  94.109  -76.965  53.720  1
163597  94.121  -76.962  53.699  1
163598  94.134  -76.959  53.676  1
163599  94.147  -76.956  53.657  1
163600  94.160  -76.954  53.639  1
163601  94.174  -76.952  53.621  1
163602  94.186  -76.949  53.603  1
163603  94.198  -76.946  53.584  1
163604  94.214  -76.943  53.563  1
163605  94.229  -76.941  53.541  1
163606  94.245  -76.938  53.522  1
163607  94.260  -76.936  53.505  1
163608  94.276  -76.933  53.490  1
163609  94.288  -76.929  53.479  1
163610  94.300  -76.925  53.472  1
163611  94.313  -76.920  53.464  1
163612  94.325  -76.916  53.456  1
163613  94.329  -76.915  53.449  1
163614  94.334  -76.918  53.444  1
163615  94.346  -76.918  53.438  1
163616  94.363  -76.915  53.430  1
163617  94.381  -76.912  53.422  1
163618  94.398  -76.909  53.410  1
163619  94.415  -76.906  53.397  1
163620  94.432  -76.901  53.383  1
163621  94.449  -76.897  53.366  1
163622  94.466  -76.893  53.347  1
163623  94.481  -76.891  53.325  1
163624  94.496  -76.889  53.302  1
163625  94.511  -76.887  53.275  1
163626  94.526  -76.885  53.249  1
163627  94.541  -76.884  53.224  1
163628  94.554  -76.880  53.198  1
163629  94.564  -76.875  53.170  1
163630  94.575  -76.869  53.141  1
163631  94.585  -76.864  53.112  1
163632  94.605  -76.870  53.079  1
163633  94.626  -76.878  53.046  1
163634  94.658  -76.872  53.013  1
163635  94.691  -76.865  52.983  1
163636  94.724  -76.859  52.949  1
163637  94.758  -76.852  52.915  1
163638  94.791  -76.844  52.880  1
163639  94.826  -76.837  52.845  1
163640  94.860  -76.829  52.811  1
163641  94.886  -76.824  52.776  1
163642  94.891  -76.827  52.741  1
163643  94.902  -76.825  52.704  1
163644  94.912  -76.823  52.670  1
163645  94.923  -76.821  52.636  1
163646  94.933  -76.820  52.599  1
163647  94.944  -76.818  52.567  1
163648  94.955  -76.817  52.537  1
163649  94.965  -76.815  52.512  1
163650  94.975  -76.813  52.491  1
163651  94.986  -76.812  52.475  1
163652  94.996  -76.810  52.461  1
163653  95.016  -76.815  52.446  1
163654  95.037  -76.821  52.430  1
163655  95.058  -76.828  52.409  1
163656  95.080  -76.834  52.383  1
163657  95.101  -76.840  52.349  1
163658  95.122  -76.846  52.307  1
163659  95.143  -76.853  52.260  1
163660  95.165  -76.859  52.209  1
163661  95.190  -76.866  52.154  1
163662  95.227  -76.878  52.094  1
163663  95.264  -76.890  52.032  1
163664  95.301  -76.903  51.968  1
163665  95.322  -76.920  51.907  1
163666  95.305  -76.950  51.848  1
163667  95.291  -76.978  51.788  1
163668  95.305  -76.987  51.729  1
163669  95.319  -76.996  51.671  1
163670  95.333  -77.006  51.612  1
163671  95.346  -77.015  51.554  1
163672  95.360  -77.024  51.497  1
163673  95.375  -77.034  51.443  1
163674  95.390  -77.044  51.390  1
163675  95.407  -77.056  51.338  1
163676  95.424  -77.067  51.288  1
163677  95.441  -77.079  51.238  1
163678  95.458  -77.091  51.189  1
163679  95.475  -77.103  51.142  1
163680  95.491  -77.114  51.095  1
163681  95.509  -77.128  51.051  1
163682  95.527  -77.144  51.007  1
163683  95.545  -77.161  50.964  1
163684  95.563  -77.178  50.923  1
163685  95.582  -77.185  50.881  1
163686  95.602  -77.182  50.835  1
163687  95.623  -77.181  50.789  1
163688  95.643  -77.179  50.744  1
163689  95.664  -77.176  50.698  1
163690  95.684  -77.175  50.653  1
163691  95.704  -77.172  50.610  1
163692  95.725  -77.170  50.568  1
163693  95.746  -77.169  50.528  1
163694  95.760  -77.169  50.489  1
163695  95.767  -77.175  50.450  1
163696  95.774  -77.182  50.412  1
163697  95.781  -77.188  50.373  1
163698  95.788  -77.194  50.332  1
163699  95.795  -77.200  50.285  1
163700  95.802  -77.206  50.238  1
163701  95.822  -77.216  50.192  1
163702  95.854  -77.227  50.148  1
163703  95.887  -77.238  50.103  1
163704  95.920  -77.248  50.057  1
163705  95.953  -77.258  50.010  1
163706  95.977  -77.266  49.963  1
163707  95.971  -77.263  49.915  1
163708  95.963  -77.270  49.866  1
163709  95.955  -77.279  49.815  1
163710  95.948  -77.286  49.762  1
163711  95.940  -77.294  49.707  1
163712  95.932  -77.302  49.650  1
163713  95.923  -77.310  49.596  1
163714  95.915  -77.318  49.545  1
163715  95.907  -77.326  49.496  1
163716  95.904  -77.335  49.450  1
163717  95.916  -77.345  49.406  1
163718  95.934  -77.354  49.364  1
163719  95.954  -77.364  49.323  1
163720  95.974  -77.373  49.283  1
163721  95.995  -77.383  49.248  1
163722  96.015  -77.392  49.215  1
163723  96.036  -77.401  49.182  1
163724  96.056  -77.410  49.151  1
163725  96.078  -77.417  49.121  1
163726  96.098  -77.425  49.091  1
163727  96.119  -77.432  49.064  1
163728  96.140  -77.440  49.041  1
163729  96.161  -77.448  49.020  1
163730  96.182  -77.456  49.000  1
163731  96.202  -77.463  48.980  1
163732  96.223  -77.464  48.957  1
163733  96.243  -77.464  48.934  1
163734  96.264  -77.465  48.911  1
163735  96.284  -77.466  48.893  1
163736  96.304  -77.467  48.875  1
163737  96.325  -77.467  48.857  1
163738  96.345  -77.468  48.840  1
163739  96.365  -77.469  48.825  1
163740  96.386  -77.470  48.813  1
163741  96.406  -77.470  48.805  1
163742  96.428  -77.474  48.798  1
163743  96.443  -77.493  48.788  1
163744  96.460  -77.514  48.776  1
163745  96.477  -77.536  48.762  1
163746  96.494  -77.558  48.747  1
163747  96.511  -77.579  48.731  1
163748  96.528  -77.601  48.717  1
163749  96.545  -77.622  48.702  1
163750  96.562  -77.643  48.688  1
163751  96.580  -77.664  48.671  1
163752  96.596  -77.681  48.652  1
163753  96.607  -77.680  48.633  1
163754  96.619  -77.678  48.614  1
163755  96.631  -77.676  48.596  1
163756  96.643  -77.674  48.579  1
163757  96.655  -77.672  48.564  1
163758  96.667  -77.671  48.546  1
163759  96.679  -77.668  48.528  1
163760  96.690  -77.667  48.510  1
163761  96.702  -77.665  48.492  1
163762  96.714  -77.663  48.475  1
163763  96.726  -77.661  48.458  1
163764  96.738  -77.659  48.440  1
163765  96.750  -77.658  48.422  1
163766  96.761  -77.656  48.404  1
163767  96.769  -77.658  48.385  1
163768  96.786  -77.661  48.361  1
163769  96.807  -77.664  48.336  1
163770  96.829  -77.667  48.310  1
163771  96.849  -77.669  48.284  1
163772  96.869  -77.671  48.258  1
163773  96.889  -77.673  48.232  1
163774  96.909  -77.675  48.206  1
163775  96.930  -77.677  48.179  1
163776  96.950  -77.679  48.153  1
163777  96.970  -77.680  48.127  1
163778  96.990  -77.683  48.103  1
163779  97.010  -77.684  48.080  1
163780  97.030  -77.686  48.057  1
163781  97.042  -77.689  48.033  1
163782  97.048  -77.693  48.010  1
163783  97.054  -77.699  47.987  1
163784  97.061  -77.704  47.965  1
163785  97.067  -77.708  47.945  1
163786  97.074  -77.714  47.926  1
163787  97.096  -77.722  47.907  1
163788  97.124  -77.730  47.888  1
163789  97.152  -77.739  47.870  1
163790  97.179  -77.747  47.849  1
163791  97.206  -77.749  47.829  1
163792  97.231  -77.746  47.808  1
163793  97.256  -77.743  47.786  1
163794  97.282  -77.740  47.764  1
163795  97.307  -77.737  47.742  1
163796  97.332  -77.734  47.718  1
163797  97.358  -77.732  47.694  1
163798  97.381  -77.742  47.670  1
163799  97.405  -77.752  47.647  1
163800  97.428  -77.761  47.623  1
163801  97.452  -77.771  47.599  1
163802  97.475  -77.781  47.577  1
163803  97.499  -77.791  47.554  1
163804  97.522  -77.801  47.529  1
163805  97.546  -77.811  47.506  1
163806  97.569  -77.820  47.483  1
163807  97.593  -77.830  47.461  1
163808  97.618  -77.840  47.438  1
163809  97.649  -77.848  47.417  1
163810  97.678  -77.856  47.396  1
163811  97.687  -77.848  47.374  1
163812  97.696  -77.840  47.353  1
163813  97.705  -77.832  47.330  1
163814  97.714  -77.824  47.307  1
163815  97.722  -77.814  47.283  1
163816  97.723  -77.787  47.257  1
163817  97.726  -77.763  47.232  1
163818  97.759  -77.786  47.206  1
163819  97.784  -77.791  47.180  1
163820  97.806  -77.799  47.154  1
163821  97.824  -77.809  47.127  1
163822  97.842  -77.819  47.101  1
163823  97.858  -77.825  47.077  1
163824  97.879  -77.824  47.053  1
163825  97.899  -77.824  47.031  1
163826  97.911  -77.836  47.008  1
163827  97.920  -77.849  46.981  1
163828  97.930  -77.863  46.955  1
163829  97.946  -77.864  46.929  1
163830  97.963  -77.865  46.904  1
163831  97.980  -77.865  46.877  1
163832  97.996  -77.868  46.851  1
163833  98.007  -77.877  46.824  1
163834  98.017  -77.887  46.798  1
163835  98.027  -77.897  46.770  1
163836  98.038  -77.907  46.744  1
163837  98.048  -77.917  46.719  1
163838  98.060  -77.925  46.694  1
163839  98.073  -77.932  46.670  1
163840  98.079  -77.937  46.646  1
163841  98.135  -77.902  46.621  1
163842  98.152  -77.901  46.597  1
163843  98.176  -77.893  46.573  1
163844  98.208  -77.879  46.550  1
163845  98.216  -77.873  46.528  1
163846  98.223  -77.868  46.507  1
163847  98.230  -77.863  46.486  1
163848  98.236  -77.858  46.465  1
163849  98.243  -77.852  46.443  1
163850  98.249  -77.847  46.421  1
163851  98.256  -77.842  46.399  1
163852  98.263  -77.837  46.379  1
163853  98.282  -77.837  46.361  1
163854  98.326  -77.846  46.343  1
163855  98.371  -77.857  46.325  1
163856  98.415  -77.868  46.307  1
163857  98.460  -77.879  46.289  1
163858  98.483  -77.880  46.271  1
163859  98.502  -77.887  46.254  1
163860  98.520  -77.895  46.237  1
163861  98.538  -77.902  46.219  1
163862  98.557  -77.909  46.200  1
163863  98.576  -77.917  46.180  1
163864  98.594  -77.924  46.160  1
163865  98.613  -77.931  46.141  1
163866  98.632  -77.939  46.123  1
163867  98.650  -77.946  46.104  1
163868  98.669  -77.954  46.084  1
163869  98.688  -77.961  46.064  1
163870  98.706  -77.968  46.043  1
163871  98.725  -77.976  46.022  1
163872  98.743  -77.983  46.003  1
163873  98.762  -77.990  45.984  1
163874  98.781  -77.998  45.966  1
163875  98.806  -78.006  45.949  1
163876  98.861  -78.015  45.931  1
163877  98.942  -78.027  45.914  1
163878  98.995  -78.022  45.896  1
163879  99.040  -78.014  45.879  1
163880  99.084  -78.006  45.862  1
163881  99.137  -78.003  45.845  1
163882  99.192  -78.004  45.829  1
163883  99.247  -78.004  45.814  1
163884  99.302  -78.005  45.800  1
163885  99.326  -78.002  45.786  1
163886  99.345  -77.999  45.773  1
163887  99.358  -78.001  45.762  1
163888  99.368  -78.006  45.752  1
163889  99.378  -78.012  45.741  1
163890  99.388  -78.018  45.730  1
163891  99.397  -78.025  45.719  1
163892  99.405  -78.033  45.709  1
163893  99.414  -78.040  45.699  1
163894  99.422  -78.047  45.688  1
163895  99.431  -78.055  45.676  1
163896  99.439  -78.062  45.666  1
163897  99.448  -78.069  45.657  1
163898  99.457  -78.076  45.645  1
163899  99.486  -78.086  45.631  1
163900  99.517  -78.095  45.620  1
163901  99.549  -78.105  45.609  1
163902  99.580  -78.115  45.598  1
163903  99.612  -78.124  45.586  1
163904  99.643  -78.134  45.574  1
163905  99.670  -78.145  45.564  1
163906  99.687  -78.160  45.553  1
163907  99.704  -78.175  45.540  1
163908  99.721  -78.190  45.527  1
163909  99.737  -78.205  45.513  1
163910  99.755  -78.220  45.499  1
163911  99.771  -78.235  45.485  1
163912  99.788  -78.250  45.470  1
163913  99.805  -78.265  45.454  1
163914  99.822  -78.280  45.439  1
163915  99.839  -78.295  45.425  1
163916  99.853  -78.311  45.409  1
163917  99.877  -78.332  45.393  1
163918  99.914  -78.352  45.377  1
163919  99.940  -78.370  45.360  1
163920  99.935  -78.379  45.343  1
163921  99.930  -78.388  45.326  1
163922  99.925  -78.397  45.309  1
163923  99.944  -78.415  45.292  1
163924  99.964  -78.433  45.275  1
163925  99.985  -78.451  45.258  1
163926  100.005  -78.470  45.242  1
163927  100.043  -78.485  45.225  1
163928  100.093  -78.500  45.209  1
163929  100.144  -78.514  45.193  1
163930  100.195  -78.529  45.177  1
163931  100.244  -78.542  45.162  1
163932  100.281  -78.552  45.147  1
163933  100.318  -78.562  45.131  1
163934  100.354  -78.571  45.115  1
163935  100.391  -78.581  45.100  1
163936  100.428  -78.591  45.084  1
163937  100.465  -78.601  45.068  1
163938  100.508  -78.611  45.053  1
163939  100.553  -78.623  45.037  1
163940  100.598  -78.634  45.022  1
163941  100.642  -78.645  45.006  1
163942  100.676  -78.635  44.990  1
163943  100.700  -78.643  44.975  1
163944  100.725  -78.651  44.959  1
163945  100.749  -78.660  44.943  1
163946  100.774  -78.668  44.928  1
163947  100.801  -78.679  44.912  1
163948  100.830  -78.692  44.895  1
163949  100.859  -78.704  44.880  1
163950  100.889  -78.719  44.864  1
163951  100.920  -78.736  44.850  1
163952  100.950  -78.752  44.834  1
163953  100.980  -78.768  44.818  1
163954  101.010  -78.781  44.802  1
163955  101.039  -78.783  44.787  1
163956  101.068  -78.786  44.771  1
163957  101.090  -78.803  44.756  1
163958  101.092  -78.858  44.741  1
163959  101.121  -78.880  44.725  1
163960  101.168  -78.893  44.710  1
163961  101.215  -78.908  44.695  1
163962  101.255  -78.917  44.681  1
163963  101.283  -78.910  44.667  1
163964  101.304  -78.891  44.654  1
163965  101.326  -78.883  44.639  1
163966  101.350  -78.897  44.625  1
163967  101.369  -78.927  44.611  1
163968  101.385  -78.961  44.598  1
163969  101.403  -78.994  44.584  1
163970  101.446  -79.014  44.571  1
163971  101.488  -79.033  44.558  1
163972  101.530  -79.053  44.545  1
163973  101.572  -79.071  44.533  1
163974  101.614  -79.090  44.520  1
163975  101.656  -79.110  44.508  1
163976  101.676  -79.117  44.496  1
163977  101.692  -79.122  44.485  1
164199  92.419  -77.330  53.995  1
164200  92.438  -77.335  54.013  1
164201  92.457  -77.341  54.030  1
164202  92.476  -77.347  54.050  1
164203  92.495  -77.353  54.070  1
164204  92.514  -77.358  54.089  1
164205  92.534  -77.364  54.107  1
164206  92.557  -77.376  54.124  1
164207  92.580  -77.386  54.140  1
164208  92.603  -77.398  54.157  1
164209  92.626  -77.408  54.171  1
164210  92.649  -77.420  54.184  1
164211  92.672  -77.431  54.196  1
164212  92.695  -77.442  54.207  1
164213  92.718  -77.453  54.217  1
164214  92.741  -77.464  54.227  1
164215  92.765  -77.475  54.236  1
164216  92.775  -77.487  54.246  1
164217  92.782  -77.500  54.255  1
164218  92.789  -77.512  54.265  1
164219  92.801  -77.521  54.274  1
164220  92.831  -77.516  54.282  1
164221  92.851  -77.505  54.290  1
164222  92.872  -77.495  54.298  1
164223  92.901  -77.488  54.306  1
164224  92.929  -77.481  54.314  1
164225  92.958  -77.473  54.322  1
164226  92.987  -77.467  54.329  1
164227  93.002  -77.462  54.334  1
164228  93.012  -77.458  54.340  1
164229  93.022  -77.454  54.344  1
164230  93.031  -77.450  54.351  1
164231  93.043  -77.443  54.360  1
164232  93.059  -77.426  54.369  1
164233  93.075  -77.410  54.377  1
164234  93.091  -77.394  54.387  1
164235  93.107  -77.377  54.395  1
164236  93.123  -77.361  54.402  1
164237  93.133  -77.347  54.407  1
164238  93.143  -77.332  54.411  1
164239  93.153  -77.318  54.415  1
164240  93.162  -77.304  54.418  1
164241  93.172  -77.290  54.421  1
164242  93.183  -77.276  54.423  1
164243  93.192  -77.261  54.422  1
164244  93.202  -77.248  54.415  1
164245  93.218  -77.237  54.406  1
164246  93.235  -77.229  54.397  1
164247  93.252  -77.222  54.389  1
164248  93.269  -77.215  54.383  1
164249  93.286  -77.207  54.377  1
164250  93.303  -77.200  54.371  1
164251  93.320  -77.192  54.365  1
164252  93.337  -77.185  54.358  1
164253  93.354  -77.179  54.351  1
164254  93.371  -77.173  54.343  1
164255  93.389  -77.168  54.334  1
164256  93.409  -77.160  54.323  1
164257  93.432  -77.147  54.311  1
164258  93.455  -77.133  54.299  1
164259  93.480  -77.122  54.287  1
164260  93.503  -77.113  54.275  1
164261  93.528  -77.103  54.264  1
164262  93.551  -77.093  54.254  1
164263  93.575  -77.083  54.245  1
164264  93.599  -77.073  54.237  1
164265  93.623  -77.063  54.230  1
164266  93.627  -77.082  54.224  1
164267  93.631  -77.102  54.218  1
164268  93.650  -77.095  54.210  1
164269  93.671  -77.084  54.199  1
164270  93.692  -77.072  54.186  1
164271  93.712  -77.060  54.171  1
164272  93.729  -77.053  54.157  1
164273  93.736  -77.044  54.143  1
164274  93.744  -77.042  54.127  1
164275  93.752  -77.041  54.113  1
164276  93.760  -77.040  54.098  1
164277  93.769  -77.039  54.083  1
164278  93.777  -77.038  54.067  1
164279  93.785  -77.037  54.053  1
164280  93.793  -77.035  54.040  1
164281  93.801  -77.034  54.029  1
164282  93.809  -77.034  54.019  1
164283  93.820  -77.034  54.008  1
164284  93.837  -77.030  53.995  1
164285  93.854  -77.022  53.975  1
164286  93.869  -77.018  53.953  1
164287  93.884  -77.013  53.931  1
164288  93.908  -77.009  53.908  1
164289  93.933  -77.005  53.890  1
164290  93.958  -77.001  53.873  1
164291  93.980  -76.994  53.856  1
164292  94.002  -76.988  53.835  1
164293  94.024  -76.982  53.814  1
164294  94.046  -76.975  53.794  1
164295  94.067  -76.969  53.775  1
164296  94.086  -76.960  53.757  1
164297  94.103  -76.950  53.739  1
164298  94.115  -76.948  53.720  1
164299  94.127  -76.945  53.700  1
164300  94.138  -76.943  53.683  1
164301  94.151  -76.940  53.667  1
164302  94.164  -76.937  53.651  1
164303  94.177  -76.934  53.633  1
164304  94.190  -76.932  53.614  1
164305  94.205  -76.929  53.594  1
164306  94.220  -76.927  53.572  1
164307  94.236  -76.924  53.551  1
164308  94.252  -76.922  53.532  1
164309  94.267  -76.918  53.514  1
164310  94.279  -76.915  53.499  1
164311  94.291  -76.911  53.488  1
164312  94.304  -76.906  53.477  1
164313  94.316  -76.903  53.468  1
164314  94.328  -76.900  53.461  1
164315  94.332  -76.903  53.454  1
164316  94.344  -76.902  53.446  1
164317  94.362  -76.900  53.437  1
164318  94.379  -76.897  53.429  1
164319  94.397  -76.894  53.422  1
164320  94.414  -76.892  53.413  1
164321  94.431  -76.887  53.401  1
164322  94.448  -76.884  53.386  1
164323  94.464  -76.881  53.367  1
164324  94.479  -76.878  53.345  1
164325  94.494  -76.877  53.322  1
164326  94.509  -76.875  53.296  1
164327  94.524  -76.872  53.271  1
164328  94.539  -76.870  53.246  1
164329  94.553  -76.868  53.218  1
164330  94.555  -76.863  53.190  1
164331  94.565  -76.858  53.162  1
164332  94.577  -76.856  53.135  1
164333  94.603  -76.859  53.102  1
164334  94.636  -76.852  53.069  1
164335  94.670  -76.845  53.037  1
164336  94.703  -76.837  53.007  1
164337  94.736  -76.831  52.973  1
164338  94.770  -76.824  52.939  1
164339  94.803  -76.817  52.905  1
164340  94.837  -76.809  52.869  1
164341  94.872  -76.802  52.834  1
164342  94.881  -76.802  52.798  1
164343  94.891  -76.800  52.761  1
164344  94.902  -76.799  52.723  1
164345  94.912  -76.797  52.687  1
164346  94.923  -76.796  52.652  1
164347  94.933  -76.794  52.613  1
164348  94.944  -76.793  52.578  1
164349  94.954  -76.790  52.546  1
164350  94.965  -76.789  52.518  1
164351  94.975  -76.787  52.496  1
164352  94.986  -76.786  52.479  1
164353  94.996  -76.784  52.464  1
164354  95.012  -76.787  52.448  1
164355  95.033  -76.793  52.432  1
164356  95.054  -76.799  52.411  1
164357  95.076  -76.805  52.386  1
164358  95.097  -76.811  52.355  1
164359  95.118  -76.817  52.316  1
164360  95.139  -76.824  52.271  1
164361  95.161  -76.830  52.221  1
164362  95.198  -76.842  52.167  1
164363  95.234  -76.854  52.107  1
164364  95.271  -76.866  52.044  1
164365  95.308  -76.878  51.981  1
164366  95.333  -76.894  51.921  1
164367  95.316  -76.924  51.862  1
164368  95.299  -76.953  51.803  1
164369  95.301  -76.972  51.744  1
164370  95.315  -76.981  51.685  1
164371  95.328  -76.990  51.626  1
164372  95.342  -76.999  51.567  1
164373  95.356  -77.009  51.511  1
164374  95.370  -77.018  51.457  1
164375  95.387  -77.030  51.404  1
164376  95.404  -77.041  51.352  1
164377  95.421  -77.053  51.301  1
164378  95.438  -77.065  51.251  1
164379  95.455  -77.077  51.202  1
164380  95.472  -77.088  51.153  1
164381  95.489  -77.100  51.107  1
164382  95.506  -77.112  51.061  1
164383  95.524  -77.128  51.018  1
164384  95.542  -77.144  50.975  1
164385  95.559  -77.161  50.933  1
164386  95.589  -77.168  50.890  1
164387  95.609  -77.166  50.844  1
164388  95.629  -77.164  50.799  1
164389  95.650  -77.162  50.753  1
164390  95.671  -77.160  50.708  1
164391  95.691  -77.158  50.664  1
164392  95.711  -77.156  50.621  1
164393  95.732  -77.154  50.580  1
164394  95.742  -77.158  50.542  1
164395  95.751  -77.171  50.504  1
164396  95.758  -77.184  50.465  1
164397  95.767  -77.183  50.427  1
164398  95.777  -77.182  50.388  1
164399  95.786  -77.180  50.345  1
164400  95.796  -77.179  50.299  1
164401  95.803  -77.183  50.252  1
164402  95.818  -77.191  50.207  1
164403  95.851  -77.201  50.163  1
164404  95.884  -77.212  50.118  1
164405  95.916  -77.228  50.074  1
164406  95.948  -77.244  50.029  1
164407  95.971  -77.247  49.982  1
164408  95.962  -77.255  49.934  1
164409  95.954  -77.263  49.886  1
164410  95.945  -77.272  49.835  1
164411  95.937  -77.280  49.780  1
164412  95.928  -77.288  49.723  1
164413  95.919  -77.297  49.666  1
164414  95.911  -77.305  49.609  1
164415  95.903  -77.313  49.556  1
164416  95.896  -77.321  49.505  1
164417  95.889  -77.329  49.458  1
164418  95.908  -77.338  49.414  1
164419  95.930  -77.346  49.372  1
164420  95.950  -77.354  49.332  1
164421  95.971  -77.361  49.292  1
164422  95.992  -77.370  49.256  1
164423  96.013  -77.377  49.222  1
164424  96.034  -77.385  49.188  1
164425  96.055  -77.392  49.157  1
164426  96.076  -77.400  49.126  1
164427  96.097  -77.408  49.097  1
164428  96.117  -77.416  49.069  1
164429  96.138  -77.423  49.045  1
164430  96.159  -77.431  49.023  1
164431  96.180  -77.439  49.002  1
164432  96.201  -77.445  48.982  1
164433  96.221  -77.446  48.960  1
164434  96.241  -77.447  48.938  1
164435  96.262  -77.448  48.917  1
164436  96.282  -77.448  48.898  1
164437  96.302  -77.448  48.880  1
164438  96.323  -77.449  48.862  1
164439  96.343  -77.450  48.844  1
164440  96.364  -77.451  48.830  1
164441  96.384  -77.452  48.819  1
164442  96.408  -77.459  48.811  1
164443  96.430  -77.469  48.805  1
164444  96.447  -77.485  48.797  1
164445  96.458  -77.506  48.786  1
164446  96.472  -77.527  48.773  1
164447  96.488  -77.549  48.758  1
164448  96.506  -77.570  48.743  1
164449  96.523  -77.592  48.728  1
164450  96.540  -77.614  48.714  1
164451  96.557  -77.635  48.699  1
164452  96.574  -77.656  48.682  1
164453  96.591  -77.678  48.664  1
164454  96.604  -77.680  48.645  1
164455  96.616  -77.678  48.626  1
164456  96.628  -77.677  48.609  1
164457  96.640  -77.674  48.592  1
164458  96.652  -77.673  48.575  1
164459  96.664  -77.671  48.557  1
164460  96.675  -77.669  48.539  1
164461  96.687  -77.667  48.520  1
164462  96.699  -77.665  48.503  1
164463  96.711  -77.664  48.487  1
164464  96.723  -77.661  48.470  1
164465  96.735  -77.660  48.454  1
164466  96.746  -77.658  48.437  1
164467  96.761  -77.655  48.419  1
164468  96.785  -77.659  48.400  1
164469  96.800  -77.645  48.376  1
164470  96.820  -77.648  48.352  1
164471  96.840  -77.649  48.327  1
164472  96.861  -77.652  48.300  1
164473  96.881  -77.654  48.275  1
164474  96.901  -77.655  48.249  1
164475  96.921  -77.658  48.224  1
164476  96.941  -77.659  48.197  1
164477  96.961  -77.661  48.172  1
164478  96.981  -77.663  48.147  1
164479  97.002  -77.665  48.123  1
164480  97.022  -77.667  48.099  1
164481  97.042  -77.669  48.075  1
164482  97.051  -77.670  48.052  1
164483  97.057  -77.675  48.029  1
164484  97.064  -77.680  48.007  1
164485  97.070  -77.685  47.985  1
164486  97.076  -77.690  47.965  1
164487  97.091  -77.697  47.947  1
164488  97.119  -77.705  47.928  1
164489  97.146  -77.714  47.908  1
164490  97.174  -77.723  47.889  1
164491  97.202  -77.731  47.868  1
164492  97.229  -77.740  47.847  1
164493  97.256  -77.747  47.826  1
164494  97.282  -77.744  47.804  1
164495  97.307  -77.741  47.782  1
164496  97.333  -77.738  47.759  1
164497  97.358  -77.735  47.735  1
164498  97.383  -77.734  47.711  1
164499  97.407  -77.744  47.687  1
164500  97.430  -77.754  47.663  1
164501  97.454  -77.764  47.638  1
164502  97.477  -77.774  47.614  1
164503  97.501  -77.783  47.591  1
164504  97.524  -77.793  47.567  1
164505  97.547  -77.802  47.542  1
164506  97.571  -77.812  47.518  1
164507  97.595  -77.822  47.494  1
164508  97.618  -77.832  47.471  1
164509  97.642  -77.842  47.449  1
164510  97.665  -77.852  47.428  1
164511  97.696  -77.860  47.406  1
164512  97.706  -77.853  47.384  1
164513  97.715  -77.845  47.362  1
164514  97.719  -77.826  47.338  1
164515  97.721  -77.799  47.314  1
164516  97.727  -77.775  47.291  1
164517  97.737  -77.752  47.265  1
164518  97.748  -77.741  47.240  1
164519  97.772  -77.770  47.214  1
164520  97.797  -77.775  47.187  1
164521  97.822  -77.781  47.161  1
164522  97.847  -77.787  47.135  1
164523  97.872  -77.792  47.108  1
164524  97.888  -77.801  47.084  1
164525  97.897  -77.815  47.061  1
164526  97.907  -77.828  47.038  1
164527  97.916  -77.842  47.015  1
164528  97.928  -77.851  46.988  1
164529  97.945  -77.852  46.961  1
164530  97.962  -77.852  46.935  1
164531  97.979  -77.853  46.910  1
164532  97.996  -77.854  46.884  1
164533  98.013  -77.855  46.856  1
164534  98.025  -77.862  46.829  1
164535  98.035  -77.872  46.804  1
164536  98.046  -77.882  46.777  1
164537  98.056  -77.892  46.750  1
164538  98.067  -77.902  46.725  1
164539  98.077  -77.912  46.700  1
164540  98.087  -77.921  46.676  1
164541  98.102  -77.929  46.652  1
164542  98.131  -77.919  46.627  1
164543  98.162  -77.905  46.602  1
164544  98.194  -77.890  46.577  1
164545  98.225  -77.877  46.553  1
164546  98.239  -77.868  46.532  1
164547  98.246  -77.864  46.510  1
164548  98.252  -77.859  46.489  1
164549  98.260  -77.853  46.468  1
164550  98.266  -77.848  46.446  1
164551  98.273  -77.843  46.424  1
164552  98.279  -77.837  46.403  1
164553  98.291  -77.834  46.384  1
164554  98.317  -77.836  46.365  1
164555  98.362  -77.846  46.346  1
164556  98.406  -77.857  46.328  1
164557  98.450  -77.868  46.311  1
164558  98.483  -77.868  46.292  1
164559  98.486  -77.868  46.274  1
164560  98.503  -77.875  46.256  1
164561  98.522  -77.883  46.240  1
164562  98.541  -77.890  46.223  1
164563  98.559  -77.897  46.205  1
164564  98.578  -77.905  46.187  1
164565  98.596  -77.912  46.167  1
164566  98.615  -77.919  46.149  1
164567  98.634  -77.927  46.131  1
164568  98.652  -77.934  46.112  1
164569  98.671  -77.942  46.092  1
164570  98.690  -77.949  46.072  1
164571  98.708  -77.956  46.052  1
164572  98.727  -77.964  46.031  1
164573  98.745  -77.971  46.011  1
164574  98.764  -77.978  45.993  1
164575  98.783  -77.986  45.975  1
164576  98.818  -77.993  45.957  1
164577  98.874  -78.003  45.939  1
164578  98.955  -78.015  45.922  1
164579  99.030  -78.023  45.903  1
164580  99.075  -78.015  45.886  1
164581  99.120  -78.006  45.869  1
164582  99.165  -77.998  45.852  1
164583  99.210  -77.990  45.836  1
164584  99.263  -77.988  45.821  1
164585  99.317  -77.989  45.806  1
164586  99.339  -77.986  45.792  1
164587  99.350  -77.990  45.778  1
164588  99.360  -77.996  45.767  1
164589  99.368  -78.003  45.757  1
164590  99.377  -78.011  45.746  1
164591  99.385  -78.018  45.736  1
164592  99.394  -78.025  45.726  1
164593  99.403  -78.032  45.715  1
164594  99.411  -78.040  45.705  1
164595  99.420  -78.047  45.694  1
164596  99.428  -78.054  45.683  1
164597  99.437  -78.062  45.673  1
164598  99.446  -78.069  45.663  1
164599  99.456  -78.076  45.651  1
164600  99.488  -78.086  45.639  1
164601  99.519  -78.095  45.627  1
164602  99.551  -78.105  45.617  1
164603  99.582  -78.115  45.606  1
164604  99.614  -78.124  45.594  1
164605  99.644  -78.134  45.582  1
164606  99.674  -78.148  45.571  1
164607  99.693  -78.161  45.559  1
164608  99.707  -78.172  45.547  1
164609  99.721  -78.184  45.533  1
164610  99.735  -78.196  45.519  1
164611  99.749  -78.207  45.505  1
164612  99.763  -78.219  45.490  1
164613  99.777  -78.230  45.474  1
164614  99.792  -78.244  45.459  1
164615  99.809  -78.258  45.445  1
164616  99.826  -78.273  45.429  1
164617  99.843  -78.288  45.414  1
164618  99.862  -78.306  45.398  1
164619  99.881  -78.322  45.381  1
164620  99.883  -78.333  45.365  1
164621  99.903  -78.351  45.348  1
164622  99.923  -78.369  45.331  1
164623  99.943  -78.388  45.314  1
164624  99.964  -78.407  45.296  1
164625  99.984  -78.425  45.279  1
164626  100.004  -78.443  45.262  1
164627  100.025  -78.461  45.245  1
164628  100.065  -78.477  45.229  1
164629  100.116  -78.492  45.213  1
164630  100.166  -78.506  45.197  1
164631  100.216  -78.520  45.181  1
164632  100.253  -78.529  45.165  1
164633  100.289  -78.539  45.150  1
164634  100.326  -78.548  45.135  1
164635  100.363  -78.558  45.119  1
164636  100.400  -78.568  45.103  1
164637  100.436  -78.578  45.088  1
164638  100.473  -78.588  45.073  1
164639  100.512  -78.598  45.057  1
164640  100.557  -78.609  45.041  1
164641  100.602  -78.620  45.026  1
164642  100.646  -78.632  45.011  1
164643  100.675  -78.614  44.996  1
164644  100.700  -78.623  44.980  1
164645  100.724  -78.631  44.965  1
164646  100.749  -78.639  44.949  1
164647  100.776  -78.650  44.933  1
164648  100.805  -78.662  44.918  1
164649  100.834  -78.675  44.903  1
164650  100.863  -78.687  44.887  1
164651  100.893  -78.700  44.871  1
164652  100.923  -78.717  44.855  1
164653  100.953  -78.733  44.840  1
164654  100.983  -78.742  44.824  1
164655  101.011  -78.744  44.808  1
164656  101.041  -78.747  44.793  1
164657  101.069  -78.749  44.778  1
164658  101.095  -78.760  44.763  1
164659  101.097  -78.814  44.747  1
164660  101.101  -78.865  44.732  1
164661  101.149  -78.879  44.717  1
164662  101.197  -78.893  44.702  1
164663  101.247  -78.905  44.688  1
164664  101.283  -78.910  44.674  1
164665  101.305  -78.891  44.660  1
164666  101.325  -78.872  44.646  1
164667  101.349  -78.882  44.632  1
164668  101.367  -78.914  44.618  1
164669  101.383  -78.948  44.604  1
164670  101.403  -78.981  44.590  1
164671  101.445  -79.000  44.577  1
164672  101.487  -79.019  44.564  1
164673  101.530  -79.038  44.551  1
164674  101.572  -79.058  44.538  1
164675  101.614  -79.077  44.525  1
164676  101.656  -79.096  44.513  1
164677  101.676  -79.103  44.500  1
164678  101.693  -79.109  44.489  1
164679  101.710  -79.115  44.477  1
164900  92.399  -77.291  53.972  1
164901  92.418  -77.296  53.992  1
164902  92.437  -77.302  54.010  1
164903  92.456  -77.307  54.030  1
164904  92.475  -77.313  54.051  1
164905  92.498  -77.324  54.071  1
164906  92.521  -77.335  54.090  1
164907  92.545  -77.346  54.109  1
164908  92.567  -77.357  54.127  1
164909  92.590  -77.368  54.143  1
164910  92.614  -77.379  54.159  1
164911  92.637  -77.391  54.173  1
164912  92.660  -77.401  54.187  1
164913  92.683  -77.413  54.198  1
164914  92.706  -77.424  54.209  1
164915  92.729  -77.435  54.220  1
164916  92.752  -77.446  54.228  1
164917  92.769  -77.457  54.238  1
164918  92.776  -77.470  54.248  1
164919  92.783  -77.483  54.257  1
164920  92.790  -77.495  54.266  1
164921  92.798  -77.507  54.274  1
164922  92.828  -77.501  54.282  1
164923  92.846  -77.490  54.290  1
164924  92.872  -77.482  54.300  1
164925  92.901  -77.475  54.311  1
164926  92.930  -77.467  54.321  1
164927  92.958  -77.461  54.329  1
164928  92.987  -77.453  54.335  1
164929  93.016  -77.446  54.340  1
164930  93.032  -77.441  54.344  1
164931  93.043  -77.437  54.350  1
164932  93.055  -77.427  54.357  1
164933  93.071  -77.410  54.365  1
164934  93.087  -77.395  54.373  1
164935  93.097  -77.380  54.382  1
164936  93.108  -77.366  54.391  1
164937  93.117  -77.351  54.399  1
164938  93.127  -77.338  54.405  1
164939  93.137  -77.323  54.408  1
164940  93.147  -77.309  54.411  1
164941  93.157  -77.294  54.413  1
164942  93.166  -77.280  54.413  1
164943  93.177  -77.266  54.412  1
164944  93.186  -77.252  54.409  1
164945  93.196  -77.238  54.402  1
164946  93.212  -77.228  54.391  1
164947  93.229  -77.219  54.382  1
164948  93.247  -77.213  54.375  1
164949  93.264  -77.205  54.370  1
164950  93.280  -77.197  54.365  1
164951  93.297  -77.190  54.361  1
164952  93.314  -77.183  54.357  1
164953  93.331  -77.175  54.352  1
164954  93.348  -77.168  54.348  1
164955  93.365  -77.160  54.342  1
164956  93.382  -77.153  54.335  1
164957  93.405  -77.144  54.326  1
164958  93.428  -77.134  54.314  1
164959  93.452  -77.124  54.302  1
164960  93.476  -77.114  54.289  1
164961  93.500  -77.104  54.276  1
164962  93.524  -77.094  54.265  1
164963  93.548  -77.085  54.254  1
164964  93.572  -77.075  54.247  1
164965  93.596  -77.065  54.239  1
164966  93.612  -77.067  54.233  1
164967  93.616  -77.087  54.229  1
164968  93.623  -77.094  54.223  1
164969  93.644  -77.082  54.215  1
164970  93.665  -77.070  54.204  1
164971  93.686  -77.059  54.191  1
164972  93.707  -77.047  54.176  1
164973  93.719  -77.044  54.162  1
164974  93.731  -77.039  54.150  1
164975  93.735  -77.028  54.136  1
164976  93.740  -77.019  54.123  1
164977  93.748  -77.017  54.110  1
164978  93.756  -77.016  54.095  1
164979  93.764  -77.016  54.080  1
164980  93.773  -77.014  54.066  1
164981  93.781  -77.013  54.052  1
164982  93.789  -77.012  54.042  1
164983  93.797  -77.011  54.034  1
164984  93.808  -77.012  54.025  1
164985  93.825  -77.016  54.014  1
164986  93.842  -77.014  53.996  1
164987  93.858  -77.009  53.977  1
164988  93.884  -77.005  53.956  1
164989  93.909  -77.000  53.936  1
164990  93.934  -76.997  53.917  1
164991  93.959  -76.992  53.900  1
164992  93.981  -76.985  53.882  1
164993  94.002  -76.979  53.860  1
164994  94.024  -76.973  53.837  1
164995  94.046  -76.966  53.815  1
164996  94.064  -76.956  53.795  1
164997  94.081  -76.946  53.776  1
164998  94.098  -76.936  53.757  1
164999  94.109  -76.934  53.739  1
165000  94.121  -76.931  53.721  1
165001  94.133  -76.928  53.706  1
165002  94.144  -76.926  53.692  1
165003  94.156  -76.923  53.678  1
165004  94.168  -76.921  53.662  1
165005  94.181  -76.918  53.643  1
165006  94.197  -76.915  53.623  1
165007  94.214  -76.912  53.601  1
165008  94.230  -76.909  53.579  1
165009  94.246  -76.907  53.558  1
165010  94.260  -76.904  53.539  1
165011  94.272  -76.902  53.521  1
165012  94.284  -76.899  53.507  1
165013  94.296  -76.896  53.494  1
165014  94.309  -76.892  53.482  1
165015  94.322  -76.888  53.474  1
165016  94.330  -76.887  53.465  1
165017  94.343  -76.887  53.457  1
165018  94.360  -76.884  53.449  1
165019  94.378  -76.881  53.443  1
165020  94.395  -76.879  53.435  1
165021  94.413  -76.876  53.427  1
165022  94.430  -76.874  53.417  1
165023  94.447  -76.869  53.404  1
165024  94.462  -76.868  53.386  1
165025  94.477  -76.865  53.364  1
165026  94.492  -76.863  53.342  1
165027  94.507  -76.861  53.317  1
165028  94.522  -76.859  53.291  1
165029  94.537  -76.856  53.267  1
165030  94.551  -76.854  53.240  1
165031  94.561  -76.851  53.213  1
165032  94.561  -76.846  53.185  1
165033  94.578  -76.840  53.158  1
165034  94.613  -76.832  53.125  1
165035  94.647  -76.824  53.092  1
165036  94.681  -76.817  53.060  1
165037  94.714  -76.810  53.030  1
165038  94.748  -76.803  52.997  1
165039  94.781  -76.796  52.963  1
165040  94.815  -76.789  52.930  1
165041  94.848  -76.782  52.896  1
165042  94.870  -76.778  52.860  1
165043  94.881  -76.776  52.822  1
165044  94.891  -76.774  52.783  1
165045  94.902  -76.773  52.745  1
165046  94.912  -76.771  52.706  1
165047  94.923  -76.770  52.666  1
165048  94.933  -76.768  52.627  1
165049  94.944  -76.766  52.590  1
165050  94.954  -76.765  52.556  1
165051  94.965  -76.763  52.524  1
165052  94.975  -76.762  52.501  1
165053  94.986  -76.760  52.482  1
165054  94.996  -76.758  52.465  1
165055  95.008  -76.758  52.447  1
165056  95.029  -76.764  52.429  1
165057  95.051  -76.770  52.409  1
165058  95.072  -76.776  52.386  1
165059  95.093  -76.782  52.356  1
165060  95.114  -76.788  52.322  1
165061  95.135  -76.794  52.280  1
165062  95.168  -76.806  52.231  1
165063  95.205  -76.818  52.178  1
165064  95.242  -76.830  52.118  1
165065  95.278  -76.842  52.056  1
165066  95.315  -76.854  51.995  1
165067  95.344  -76.868  51.934  1
165068  95.327  -76.898  51.875  1
165069  95.310  -76.928  51.816  1
165070  95.296  -76.956  51.757  1
165071  95.310  -76.965  51.697  1
165072  95.324  -76.975  51.638  1
165073  95.338  -76.984  51.580  1
165074  95.351  -76.993  51.525  1
165075  95.367  -77.003  51.471  1
165076  95.384  -77.016  51.418  1
165077  95.401  -77.027  51.365  1
165078  95.418  -77.039  51.314  1
165079  95.435  -77.050  51.263  1
165080  95.452  -77.063  51.214  1
165081  95.469  -77.074  51.165  1
165082  95.486  -77.086  51.118  1
165083  95.503  -77.097  51.072  1
165084  95.520  -77.112  51.028  1
165085  95.538  -77.128  50.984  1
165086  95.558  -77.144  50.941  1
165087  95.595  -77.152  50.897  1
165088  95.616  -77.150  50.852  1
165089  95.636  -77.148  50.807  1
165090  95.657  -77.146  50.762  1
165091  95.677  -77.144  50.718  1
165092  95.698  -77.142  50.674  1
165093  95.712  -77.144  50.633  1
165094  95.724  -77.147  50.593  1
165095  95.734  -77.150  50.556  1
165096  95.743  -77.163  50.519  1
165097  95.748  -77.187  50.480  1
165098  95.755  -77.200  50.441  1
165099  95.765  -77.198  50.402  1
165100  95.774  -77.197  50.358  1
165101  95.784  -77.196  50.312  1
165102  95.793  -77.194  50.266  1
165103  95.810  -77.199  50.222  1
165104  95.842  -77.215  50.178  1
165105  95.875  -77.231  50.135  1
165106  95.907  -77.247  50.091  1
165107  95.936  -77.248  50.048  1
165108  95.961  -77.237  50.003  1
165109  95.961  -77.240  49.957  1
165110  95.953  -77.248  49.909  1
165111  95.945  -77.257  49.857  1
165112  95.936  -77.265  49.801  1
165113  95.927  -77.273  49.743  1
165114  95.919  -77.282  49.683  1
165115  95.910  -77.291  49.623  1
165116  95.902  -77.299  49.568  1
165117  95.893  -77.307  49.516  1
165118  95.894  -77.317  49.468  1
165119  95.910  -77.323  49.422  1
165120  95.927  -77.329  49.380  1
165121  95.949  -77.337  49.339  1
165122  95.969  -77.345  49.299  1
165123  95.990  -77.352  49.263  1
165124  96.011  -77.360  49.228  1
165125  96.032  -77.368  49.195  1
165126  96.053  -77.376  49.164  1
165127  96.074  -77.383  49.133  1
165128  96.095  -77.391  49.104  1
165129  96.115  -77.399  49.076  1
165130  96.136  -77.407  49.053  1
165131  96.157  -77.414  49.030  1
165132  96.178  -77.422  49.007  1
165133  96.199  -77.427  48.986  1
165134  96.219  -77.428  48.965  1
165135  96.239  -77.429  48.944  1
165136  96.260  -77.429  48.925  1
165137  96.280  -77.430  48.907  1
165138  96.301  -77.431  48.887  1
165139  96.321  -77.432  48.868  1
165140  96.341  -77.432  48.850  1
165141  96.365  -77.438  48.835  1
165142  96.389  -77.445  48.823  1
165143  96.413  -77.451  48.814  1
165144  96.432  -77.464  48.809  1
165145  96.449  -77.479  48.801  1
165146  96.464  -77.496  48.791  1
165147  96.474  -77.518  48.781  1
165148  96.485  -77.540  48.768  1
165149  96.501  -77.562  48.753  1
165150  96.518  -77.583  48.738  1
165151  96.535  -77.605  48.724  1
165152  96.552  -77.627  48.707  1
165153  96.569  -77.648  48.690  1
165154  96.586  -77.669  48.673  1
165155  96.601  -77.680  48.655  1
165156  96.613  -77.679  48.637  1
165157  96.624  -77.677  48.619  1
165158  96.637  -77.675  48.602  1
165159  96.648  -77.674  48.585  1
165160  96.660  -77.671  48.568  1
165161  96.672  -77.670  48.550  1
165162  96.684  -77.667  48.532  1
165163  96.696  -77.666  48.515  1
165164  96.708  -77.664  48.499  1
165165  96.720  -77.662  48.483  1
165166  96.734  -77.660  48.467  1
165167  96.755  -77.656  48.450  1
165168  96.777  -77.652  48.432  1
165169  96.804  -77.663  48.413  1
165170  96.822  -77.656  48.391  1
165171  96.834  -77.637  48.368  1
165172  96.852  -77.632  48.344  1
165173  96.872  -77.634  48.319  1
165174  96.892  -77.636  48.294  1
165175  96.912  -77.638  48.269  1
165176  96.933  -77.640  48.243  1
165177  96.953  -77.642  48.217  1
165178  96.973  -77.644  48.192  1
165179  96.993  -77.645  48.167  1
165180  97.013  -77.648  48.142  1
165181  97.033  -77.649  48.118  1
165182  97.052  -77.651  48.094  1
165183  97.060  -77.652  48.071  1
165184  97.066  -77.657  48.048  1
165185  97.072  -77.661  48.026  1
165186  97.079  -77.667  48.006  1
165187  97.086  -77.672  47.986  1
165188  97.113  -77.680  47.968  1
165189  97.141  -77.689  47.948  1
165190  97.169  -77.698  47.928  1
165191  97.196  -77.706  47.909  1
165192  97.224  -77.715  47.887  1
165193  97.251  -77.724  47.865  1
165194  97.279  -77.732  47.844  1
165195  97.307  -77.741  47.822  1
165196  97.333  -77.742  47.798  1
165197  97.358  -77.739  47.775  1
165198  97.384  -77.736  47.752  1
165199  97.408  -77.736  47.727  1
165200  97.432  -77.746  47.703  1
165201  97.456  -77.755  47.678  1
165202  97.479  -77.765  47.653  1
165203  97.503  -77.775  47.629  1
165204  97.526  -77.785  47.605  1
165205  97.549  -77.795  47.580  1
165206  97.573  -77.805  47.555  1
165207  97.597  -77.815  47.530  1
165208  97.620  -77.824  47.505  1
165209  97.644  -77.834  47.481  1
165210  97.667  -77.844  47.459  1
165211  97.690  -77.854  47.437  1
165212  97.713  -77.862  47.415  1
165213  97.728  -77.843  47.392  1
165214  97.739  -77.819  47.368  1
165215  97.749  -77.796  47.344  1
165216  97.760  -77.773  47.321  1
165217  97.771  -77.749  47.298  1
165218  97.782  -77.727  47.272  1
165219  97.792  -77.733  47.246  1
165220  97.800  -77.758  47.220  1
165221  97.869  -77.762  47.194  1
165222  97.900  -77.768  47.167  1
165223  97.884  -77.773  47.141  1
165224  97.872  -77.784  47.115  1
165225  97.891  -77.806  47.091  1
165226  97.902  -77.821  47.067  1
165227  97.912  -77.835  47.044  1
165228  97.927  -77.839  47.020  1
165229  97.944  -77.840  46.994  1
165230  97.961  -77.840  46.967  1
165231  97.978  -77.841  46.940  1
165232  97.995  -77.842  46.916  1
165233  98.012  -77.843  46.890  1
165234  98.029  -77.843  46.863  1
165235  98.043  -77.847  46.837  1
165236  98.054  -77.857  46.811  1
165237  98.064  -77.867  46.784  1
165238  98.075  -77.877  46.758  1
165239  98.085  -77.887  46.732  1
165240  98.095  -77.896  46.707  1
165241  98.112  -77.902  46.682  1
165242  98.131  -77.909  46.658  1
165243  98.150  -77.915  46.633  1
165244  98.179  -77.902  46.608  1
165245  98.211  -77.888  46.583  1
165246  98.242  -77.874  46.558  1
165247  98.262  -77.865  46.537  1
165248  98.269  -77.859  46.516  1
165249  98.276  -77.854  46.494  1
165250  98.282  -77.849  46.472  1
165251  98.289  -77.843  46.450  1
165252  98.296  -77.838  46.428  1
165253  98.307  -77.834  46.407  1
165254  98.323  -77.832  46.389  1
165255  98.353  -77.836  46.369  1
165256  98.397  -77.846  46.351  1
165257  98.441  -77.856  46.333  1
165258  98.485  -77.867  46.314  1
165259  98.498  -77.862  46.295  1
165260  98.501  -77.862  46.277  1
165261  98.505  -77.863  46.259  1
165262  98.524  -77.871  46.243  1
165263  98.543  -77.878  46.226  1
165264  98.561  -77.885  46.209  1
165265  98.580  -77.893  46.191  1
165266  98.598  -77.900  46.173  1
165267  98.617  -77.907  46.155  1
165268  98.636  -77.915  46.138  1
165269  98.654  -77.922  46.119  1
165270  98.673  -77.930  46.099  1
165271  98.692  -77.937  46.079  1
165272  98.710  -77.944  46.060  1
165273  98.729  -77.952  46.040  1
165274  98.747  -77.959  46.020  1
165275  98.766  -77.966  46.001  1
165276  98.788  -77.974  45.983  1
165277  98.830  -77.982  45.965  1
165278  98.886  -77.991  45.947  1
165279  98.968  -78.003  45.930  1
165280  99.049  -78.015  45.911  1
165281  99.111  -78.015  45.894  1
165282  99.156  -78.007  45.877  1
165283  99.201  -77.999  45.860  1
165284  99.245  -77.990  45.844  1
165285  99.290  -77.982  45.828  1
165286  99.330  -77.974  45.813  1
165287  99.340  -77.981  45.798  1
165288  99.349  -77.988  45.783  1
165289  99.357  -77.996  45.772  1
165290  99.366  -78.003  45.762  1
165291  99.374  -78.010  45.751  1
165292  99.383  -78.018  45.742  1
165293  99.392  -78.025  45.731  1
165294  99.400  -78.032  45.721  1
165295  99.409  -78.039  45.711  1
165296  99.418  -78.047  45.701  1
165297  99.426  -78.053  45.690  1
165298  99.435  -78.061  45.679  1
165299  99.443  -78.069  45.668  1
165300  99.459  -78.076  45.657  1
165301  99.490  -78.086  45.646  1
165302  99.522  -78.095  45.636  1
165303  99.553  -78.105  45.625  1
165304  99.585  -78.115  45.613  1
165305  99.615  -78.125  45.602  1
165306  99.642  -78.135  45.590  1
165307  99.673  -78.150  45.578  1
165308  99.703  -78.166  45.566  1
165309  99.717  -78.178  45.554  1
165310  99.731  -78.189  45.540  1
165311  99.745  -78.200  45.525  1
165312  99.759  -78.213  45.510  1
165313  99.773  -78.224  45.495  1
165314  99.787  -78.235  45.479  1
165315  99.800  -78.247  45.464  1
165316  99.815  -78.259  45.450  1
165317  99.829  -78.270  45.434  1
165318  99.843  -78.282  45.419  1
165319  99.858  -78.294  45.403  1
165320  99.881  -78.307  45.386  1
165321  99.902  -78.325  45.369  1
165322  99.923  -78.343  45.352  1
165323  99.943  -78.361  45.335  1
165324  99.963  -78.379  45.318  1
165325  99.984  -78.398  45.301  1
165326  100.004  -78.416  45.284  1
165327  100.024  -78.435  45.267  1
165328  100.045  -78.453  45.251  1
165329  100.086  -78.469  45.235  1
165330  100.137  -78.482  45.219  1
165331  100.188  -78.497  45.203  1
165332  100.224  -78.507  45.186  1
165333  100.261  -78.517  45.170  1
165334  100.298  -78.526  45.154  1
165335  100.335  -78.535  45.137  1
165336  100.371  -78.545  45.122  1
165337  100.408  -78.555  45.107  1
165338  100.445  -78.565  45.092  1
165339  100.482  -78.575  45.077  1
165340  100.519  -78.584  45.062  1
165341  100.561  -78.595  45.048  1
165342  100.606  -78.607  45.033  1
165343  100.650  -78.617  45.018  1
165344  100.675  -78.594  45.003  1
165345  100.699  -78.602  44.988  1
165346  100.724  -78.611  44.973  1
165347  100.751  -78.620  44.957  1
165348  100.780  -78.633  44.941  1
165349  100.809  -78.645  44.926  1
165350  100.838  -78.658  44.911  1
165351  100.867  -78.670  44.895  1
165352  100.896  -78.683  44.878  1
165353  100.926  -78.697  44.862  1
165354  100.955  -78.702  44.847  1
165355  100.984  -78.705  44.831  1
165356  101.013  -78.708  44.816  1
165357  101.042  -78.711  44.801  1
165358  101.070  -78.713  44.785  1
165359  101.100  -78.716  44.770  1
165360  101.102  -78.770  44.755  1
165361  101.127  -78.808  44.739  1
165362  101.167  -78.836  44.724  1
165363  101.213  -78.854  44.709  1
165364  101.263  -78.865  44.695  1
165365  101.299  -78.874  44.682  1
165366  101.310  -78.878  44.668  1
165367  101.326  -78.871  44.653  1
165368  101.348  -78.867  44.639  1
165369  101.365  -78.901  44.624  1
165370  101.382  -78.935  44.609  1
165371  101.403  -78.967  44.596  1
165372  101.445  -78.986  44.583  1
165373  101.487  -79.006  44.570  1
165374  101.529  -79.024  44.557  1
165375  101.571  -79.044  44.544  1
165376  101.614  -79.063  44.531  1
165377  101.656  -79.082  44.518  1
165378  101.677  -79.090  44.506  1
165379  101.694  -79.096  44.495  1
165380  101.710  -79.102  44.483  1
165381  101.728  -79.107  44.470  1
165602  92.398  -77.257  53.970  1
165603  92.417  -77.263  53.989  1
165604  92.439  -77.273  54.010  1
165605  92.462  -77.284  54.031  1
165606  92.486  -77.295  54.052  1
165607  92.509  -77.306  54.073  1
165608  92.532  -77.317  54.092  1
165609  92.555  -77.328  54.112  1
165610  92.578  -77.339  54.128  1
165611  92.601  -77.351  54.145  1
165612  92.624  -77.361  54.161  1
165613  92.647  -77.373  54.175  1
165614  92.670  -77.384  54.188  1
165615  92.693  -77.395  54.200  1
165616  92.716  -77.406  54.211  1
165617  92.739  -77.417  54.222  1
165618  92.762  -77.428  54.231  1
165619  92.769  -77.441  54.240  1
165620  92.776  -77.453  54.250  1
165621  92.783  -77.466  54.258  1
165622  92.790  -77.478  54.266  1
165623  92.797  -77.491  54.275  1
165624  92.824  -77.486  54.283  1
165625  92.843  -77.476  54.295  1
165626  92.872  -77.469  54.307  1
165627  92.901  -77.461  54.319  1
165628  92.930  -77.454  54.329  1
165629  92.958  -77.447  54.335  1
165630  92.988  -77.440  54.339  1
165631  93.016  -77.433  54.341  1
165632  93.045  -77.426  54.347  1
165633  93.062  -77.414  54.353  1
165634  93.072  -77.399  54.360  1
165635  93.082  -77.385  54.368  1
165636  93.091  -77.370  54.376  1
165637  93.101  -77.357  54.386  1
165638  93.112  -77.342  54.395  1
165639  93.121  -77.328  54.402  1
165640  93.131  -77.313  54.405  1
165641  93.141  -77.300  54.406  1
165642  93.151  -77.285  54.406  1
165643  93.161  -77.271  54.403  1
165644  93.170  -77.257  54.399  1
165645  93.181  -77.243  54.392  1
165646  93.190  -77.229  54.386  1
165647  93.206  -77.219  54.376  1
165648  93.224  -77.210  54.368  1
165649  93.241  -77.203  54.360  1
165650  93.258  -77.195  54.356  1
165651  93.275  -77.188  54.353  1
165652  93.292  -77.181  54.350  1
165653  93.309  -77.173  54.347  1
165654  93.326  -77.166  54.345  1
165655  93.343  -77.158  54.342  1
165656  93.360  -77.151  54.339  1
165657  93.370  -77.141  54.333  1
165658  93.398  -77.134  54.324  1
165659  93.425  -77.125  54.313  1
165660  93.449  -77.116  54.301  1
165661  93.473  -77.106  54.289  1
165662  93.497  -77.096  54.276  1
165663  93.521  -77.086  54.264  1
165664  93.545  -77.076  54.254  1
165665  93.569  -77.066  54.247  1
165666  93.592  -77.056  54.241  1
165667  93.600  -77.072  54.235  1
165668  93.606  -77.083  54.232  1
165669  93.618  -77.080  54.225  1
165670  93.639  -77.069  54.217  1
165671  93.659  -77.056  54.205  1
165672  93.681  -77.045  54.192  1
165673  93.697  -77.038  54.178  1
165674  93.709  -77.034  54.165  1
165675  93.722  -77.031  54.152  1
165676  93.730  -77.023  54.140  1
165677  93.734  -77.012  54.128  1
165678  93.739  -77.002  54.117  1
165679  93.744  -76.994  54.104  1
165680  93.752  -76.993  54.089  1
165681  93.760  -76.991  54.075  1
165682  93.769  -76.990  54.062  1
165683  93.777  -76.990  54.052  1
165684  93.785  -76.988  54.044  1
165685  93.797  -76.990  54.037  1
165686  93.814  -76.994  54.030  1
165687  93.833  -76.999  54.015  1
165688  93.860  -77.000  53.998  1
165689  93.885  -76.997  53.979  1
165690  93.911  -76.992  53.960  1
165691  93.936  -76.988  53.944  1
165692  93.959  -76.983  53.927  1
165693  93.981  -76.976  53.908  1
165694  94.003  -76.970  53.886  1
165695  94.024  -76.963  53.863  1
165696  94.041  -76.953  53.841  1
165697  94.058  -76.941  53.820  1
165698  94.076  -76.931  53.798  1
165699  94.091  -76.922  53.778  1
165700  94.104  -76.919  53.759  1
165701  94.115  -76.917  53.739  1
165702  94.127  -76.914  53.725  1
165703  94.139  -76.912  53.713  1
165704  94.150  -76.909  53.702  1
165705  94.163  -76.906  53.688  1
165706  94.177  -76.903  53.671  1
165707  94.193  -76.900  53.650  1
165708  94.209  -76.898  53.629  1
165709  94.225  -76.895  53.606  1
165710  94.242  -76.892  53.585  1
165711  94.254  -76.890  53.565  1
165712  94.266  -76.887  53.546  1
165713  94.278  -76.884  53.528  1
165714  94.290  -76.881  53.513  1
165715  94.302  -76.879  53.499  1
165716  94.315  -76.876  53.489  1
165717  94.327  -76.873  53.480  1
165718  94.341  -76.871  53.472  1
165719  94.359  -76.868  53.466  1
165720  94.377  -76.866  53.460  1
165721  94.394  -76.863  53.451  1
165722  94.411  -76.861  53.442  1
165723  94.428  -76.859  53.433  1
165724  94.445  -76.856  53.421  1
165725  94.460  -76.854  53.404  1
165726  94.475  -76.852  53.384  1
165727  94.490  -76.850  53.362  1
165728  94.504  -76.847  53.337  1
165729  94.520  -76.845  53.312  1
165730  94.534  -76.843  53.288  1
165731  94.549  -76.840  53.261  1
165732  94.564  -76.838  53.235  1
165733  94.566  -76.835  53.209  1
165734  94.558  -76.838  53.180  1
165735  94.594  -76.830  53.147  1
165736  94.628  -76.821  53.115  1
165737  94.663  -76.813  53.083  1
165738  94.698  -76.805  53.052  1
165739  94.733  -76.796  53.019  1
165740  94.768  -76.788  52.987  1
165741  94.803  -76.781  52.955  1
165742  94.846  -76.766  52.921  1
165743  94.868  -76.758  52.885  1
165744  94.880  -76.752  52.847  1
165745  94.891  -76.749  52.808  1
165746  94.902  -76.747  52.767  1
165747  94.912  -76.746  52.727  1
165748  94.922  -76.743  52.685  1
165749  94.933  -76.742  52.644  1
165750  94.944  -76.740  52.605  1
165751  94.954  -76.739  52.568  1
165752  94.965  -76.737  52.533  1
165753  94.975  -76.736  52.506  1
165754  94.986  -76.734  52.484  1
165755  94.996  -76.732  52.463  1
165756  95.006  -76.730  52.443  1
165757  95.025  -76.735  52.423  1
165758  95.047  -76.741  52.402  1
165759  95.068  -76.747  52.380  1
165760  95.089  -76.753  52.354  1
165761  95.110  -76.759  52.321  1
165762  95.139  -76.768  52.282  1
165763  95.176  -76.781  52.236  1
165764  95.212  -76.793  52.183  1
165765  95.249  -76.805  52.125  1
165766  95.285  -76.817  52.065  1
165767  95.322  -76.829  52.006  1
165768  95.355  -76.843  51.947  1
165769  95.338  -76.872  51.887  1
165770  95.321  -76.902  51.827  1
165771  95.304  -76.932  51.767  1
165772  95.306  -76.950  51.707  1
165773  95.319  -76.959  51.648  1
165774  95.333  -76.969  51.591  1
165775  95.347  -76.978  51.538  1
165776  95.365  -76.990  51.483  1
165777  95.381  -77.001  51.430  1
165778  95.398  -77.013  51.378  1
165779  95.415  -77.025  51.325  1
165780  95.432  -77.037  51.274  1
165781  95.449  -77.048  51.225  1
165782  95.466  -77.059  51.177  1
165783  95.483  -77.072  51.129  1
165784  95.500  -77.083  51.082  1
165785  95.517  -77.095  51.037  1
165786  95.535  -77.112  50.992  1
165787  95.561  -77.125  50.948  1
165788  95.600  -77.134  50.903  1
165789  95.623  -77.134  50.858  1
165790  95.643  -77.132  50.813  1
165791  95.664  -77.130  50.769  1
165792  95.683  -77.128  50.727  1
165793  95.694  -77.132  50.685  1
165794  95.704  -77.136  50.645  1
165795  95.716  -77.140  50.607  1
165796  95.726  -77.144  50.570  1
165797  95.735  -77.157  50.533  1
165798  95.740  -77.179  50.494  1
165799  95.746  -77.203  50.454  1
165800  95.753  -77.215  50.415  1
165801  95.762  -77.213  50.370  1
165802  95.772  -77.213  50.324  1
165803  95.781  -77.211  50.279  1
165804  95.801  -77.218  50.236  1
165805  95.833  -77.234  50.194  1
165806  95.866  -77.250  50.152  1
165807  95.894  -77.253  50.109  1
165808  95.920  -77.241  50.068  1
165809  95.945  -77.231  50.025  1
165810  95.961  -77.226  49.980  1
165811  95.952  -77.234  49.933  1
165812  95.944  -77.242  49.881  1
165813  95.935  -77.251  49.824  1
165814  95.926  -77.259  49.763  1
165815  95.918  -77.267  49.699  1
165816  95.909  -77.276  49.638  1
165817  95.901  -77.284  49.581  1
165818  95.893  -77.292  49.528  1
165819  95.902  -77.304  49.478  1
165820  95.919  -77.310  49.431  1
165821  95.935  -77.316  49.387  1
165822  95.951  -77.322  49.346  1
165823  95.968  -77.328  49.306  1
165824  95.988  -77.335  49.269  1
165825  96.009  -77.343  49.234  1
165826  96.030  -77.351  49.202  1
165827  96.051  -77.359  49.171  1
165828  96.072  -77.367  49.141  1
165829  96.093  -77.374  49.112  1
165830  96.114  -77.382  49.084  1
165831  96.134  -77.390  49.061  1
165832  96.156  -77.398  49.038  1
165833  96.176  -77.405  49.015  1
165834  96.197  -77.409  48.993  1
165835  96.217  -77.410  48.972  1
165836  96.238  -77.410  48.952  1
165837  96.258  -77.411  48.933  1
165838  96.278  -77.412  48.915  1
165839  96.299  -77.413  48.895  1
165840  96.320  -77.416  48.874  1
165841  96.345  -77.423  48.856  1
165842  96.369  -77.429  48.841  1
165843  96.394  -77.437  48.828  1
165844  96.418  -77.445  48.816  1
165845  96.434  -77.460  48.812  1
165846  96.451  -77.475  48.804  1
165847  96.467  -77.491  48.795  1
165848  96.481  -77.508  48.788  1
165849  96.491  -77.530  48.776  1
165850  96.502  -77.553  48.762  1
165851  96.512  -77.575  48.747  1
165852  96.529  -77.596  48.733  1
165853  96.546  -77.617  48.714  1
165854  96.564  -77.639  48.697  1
165855  96.581  -77.661  48.680  1
165856  96.598  -77.681  48.664  1
165857  96.609  -77.680  48.646  1
165858  96.621  -77.677  48.628  1
165859  96.633  -77.676  48.612  1
165860  96.645  -77.674  48.596  1
165861  96.657  -77.672  48.578  1
165862  96.669  -77.671  48.561  1
165863  96.681  -77.668  48.544  1
165864  96.692  -77.667  48.526  1
165865  96.707  -77.664  48.511  1
165866  96.728  -77.660  48.496  1
165867  96.749  -77.656  48.479  1
165868  96.770  -77.652  48.461  1
165869  96.792  -77.649  48.443  1
165870  96.822  -77.667  48.425  1
165871  96.844  -77.671  48.405  1
165872  96.857  -77.652  48.383  1
165873  96.870  -77.632  48.361  1
165874  96.884  -77.617  48.339  1
165875  96.904  -77.619  48.315  1
165876  96.924  -77.620  48.290  1
165877  96.944  -77.623  48.264  1
165878  96.964  -77.624  48.238  1
165879  96.984  -77.627  48.212  1
165880  97.005  -77.628  48.187  1
165881  97.025  -77.630  48.162  1
165882  97.045  -77.632  48.138  1
165883  97.062  -77.633  48.114  1
165884  97.069  -77.633  48.091  1
165885  97.075  -77.638  48.068  1
165886  97.081  -77.643  48.047  1
165887  97.087  -77.649  48.026  1
165888  97.108  -77.656  48.007  1
165889  97.136  -77.664  47.988  1
165890  97.163  -77.673  47.968  1
165891  97.191  -77.682  47.948  1
165892  97.219  -77.690  47.928  1
165893  97.246  -77.699  47.906  1
165894  97.274  -77.708  47.883  1
165895  97.301  -77.716  47.861  1
165896  97.329  -77.724  47.838  1
165897  97.357  -77.733  47.814  1
165898  97.384  -77.740  47.791  1
165899  97.409  -77.737  47.767  1
165900  97.434  -77.738  47.742  1
165901  97.457  -77.748  47.717  1
165902  97.481  -77.758  47.693  1
165903  97.505  -77.768  47.669  1
165904  97.528  -77.777  47.644  1
165905  97.551  -77.787  47.620  1
165906  97.575  -77.797  47.595  1
165907  97.597  -77.805  47.570  1
165908  97.616  -77.812  47.545  1
165909  97.636  -77.819  47.519  1
165910  97.656  -77.826  47.493  1
165911  97.675  -77.833  47.469  1
165912  97.695  -77.840  47.446  1
165913  97.728  -77.849  47.423  1
165914  97.755  -77.840  47.399  1
165915  97.772  -77.809  47.374  1
165916  97.788  -77.778  47.350  1
165917  97.804  -77.748  47.327  1
165918  97.815  -77.724  47.304  1
165919  97.825  -77.701  47.279  1
165920  97.837  -77.717  47.253  1
165921  97.830  -77.745  47.227  1
165922  97.897  -77.749  47.200  1
165923  97.872  -77.755  47.173  1
165924  97.851  -77.762  47.146  1
165925  97.870  -77.784  47.120  1
165926  97.889  -77.807  47.094  1
165927  97.909  -77.826  47.070  1
165928  97.926  -77.827  47.046  1
165929  97.943  -77.827  47.021  1
165930  97.960  -77.828  46.997  1
165931  97.977  -77.829  46.971  1
165932  97.994  -77.830  46.944  1
165933  98.011  -77.830  46.920  1
165934  98.027  -77.831  46.894  1
165935  98.044  -77.832  46.869  1
165936  98.062  -77.833  46.843  1
165937  98.072  -77.842  46.816  1
165938  98.083  -77.852  46.790  1
165939  98.093  -77.862  46.764  1
165940  98.105  -77.871  46.737  1
165941  98.123  -77.877  46.713  1
165942  98.142  -77.882  46.688  1
165943  98.160  -77.888  46.663  1
165944  98.178  -77.893  46.639  1
165945  98.197  -77.899  46.614  1
165946  98.228  -77.886  46.589  1
165947  98.260  -77.872  46.565  1
165948  98.285  -77.860  46.543  1
165949  98.292  -77.855  46.522  1
165950  98.298  -77.849  46.500  1
165951  98.305  -77.844  46.477  1
165952  98.312  -77.839  46.455  1
165953  98.323  -77.835  46.433  1
165954  98.339  -77.833  46.412  1
165955  98.356  -77.830  46.393  1
165956  98.387  -77.835  46.374  1
165957  98.432  -77.846  46.355  1
165958  98.476  -77.856  46.337  1
165959  98.503  -77.860  46.318  1
165960  98.513  -77.856  46.298  1
165961  98.516  -77.856  46.280  1
165962  98.520  -77.856  46.263  1
165963  98.526  -77.859  46.245  1
165964  98.545  -77.866  46.228  1
165965  98.563  -77.873  46.211  1
165966  98.582  -77.881  46.194  1
165967  98.600  -77.888  46.178  1
165968  98.619  -77.896  46.161  1
165969  98.638  -77.902  46.144  1
165970  98.656  -77.910  46.125  1
165971  98.675  -77.918  46.106  1
165972  98.694  -77.924  46.087  1
165973  98.712  -77.932  46.068  1
165974  98.731  -77.940  46.048  1
165975  98.749  -77.947  46.028  1
165976  98.768  -77.954  46.009  1
165977  98.800  -77.962  45.990  1
165978  98.842  -77.970  45.972  1
165979  98.899  -77.980  45.954  1
165980  98.980  -77.991  45.936  1
165981  99.062  -78.003  45.918  1
165982  99.143  -78.015  45.901  1
165983  99.186  -78.008  45.883  1
165984  99.217  -78.000  45.866  1
165985  99.249  -77.990  45.850  1
165986  99.280  -77.982  45.834  1
165987  99.311  -77.974  45.818  1
165988  99.333  -77.981  45.802  1
165989  99.346  -77.988  45.789  1
165990  99.355  -77.995  45.777  1
165991  99.363  -78.003  45.767  1
165992  99.372  -78.010  45.757  1
165993  99.380  -78.017  45.747  1
165994  99.390  -78.025  45.737  1
165995  99.398  -78.031  45.727  1
165996  99.407  -78.039  45.716  1
165997  99.415  -78.046  45.707  1
165998  99.424  -78.053  45.697  1
165999  99.432  -78.060  45.686  1
166000  99.441  -78.068  45.674  1
166001  99.461  -78.076  45.664  1
166002  99.492  -78.086  45.654  1
166003  99.524  -78.095  45.644  1
166004  99.555  -78.105  45.632  1
166005  99.586  -78.115  45.621  1
166006  99.613  -78.125  45.610  1
166007  99.641  -78.138  45.597  1
166008  99.671  -78.153  45.585  1
166009  99.702  -78.169  45.573  1
166010  99.726  -78.183  45.560  1
166011  99.740  -78.194  45.545  1
166012  99.755  -78.206  45.530  1
166013  99.768  -78.218  45.515  1
166014  99.782  -78.229  45.499  1
166015  99.796  -78.241  45.484  1
166016  99.810  -78.253  45.469  1
166017  99.825  -78.264  45.454  1
166018  99.838  -78.275  45.438  1
166019  99.852  -78.287  45.422  1
166020  99.871  -78.301  45.407  1
166021  99.892  -78.314  45.391  1
166022  99.916  -78.326  45.375  1
166023  99.940  -78.338  45.358  1
166024  99.963  -78.353  45.340  1
166025  99.983  -78.371  45.323  1
166026  100.003  -78.389  45.306  1
166027  100.023  -78.408  45.288  1
166028  100.044  -78.426  45.272  1
166029  100.064  -78.445  45.257  1
166030  100.109  -78.460  45.242  1
166031  100.159  -78.474  45.226  1
166032  100.196  -78.484  45.209  1
166033  100.233  -78.494  45.193  1
166034  100.270  -78.504  45.176  1
166035  100.307  -78.513  45.160  1
166036  100.343  -78.523  45.143  1
166037  100.380  -78.532  45.127  1
166038  100.417  -78.542  45.112  1
166039  100.454  -78.552  45.097  1
166040  100.490  -78.561  45.083  1
166041  100.527  -78.571  45.069  1
166042  100.565  -78.581  45.055  1
166043  100.610  -78.592  45.040  1
166044  100.654  -78.604  45.026  1
166045  100.674  -78.573  45.011  1
166046  100.699  -78.581  44.996  1
166047  100.725  -78.592  44.981  1
166048  100.755  -78.604  44.965  1
166049  100.783  -78.617  44.949  1
166050  100.813  -78.629  44.934  1
166051  100.842  -78.641  44.918  1
166052  100.871  -78.654  44.902  1
166053  100.899  -78.670  44.886  1
166054  100.930  -78.680  44.871  1
166055  100.958  -78.677  44.855  1
166056  100.986  -78.674  44.839  1
166057  101.014  -78.671  44.824  1
166058  101.043  -78.673  44.809  1
166059  101.072  -78.677  44.794  1
166060  101.101  -78.679  44.778  1
166061  101.120  -78.717  44.762  1
166062  101.159  -78.745  44.747  1
166063  101.199  -78.773  44.732  1
166064  101.239  -78.801  44.717  1
166065  101.279  -78.827  44.703  1
166066  101.314  -78.836  44.689  1
166067  101.326  -78.839  44.674  1
166068  101.337  -78.843  44.659  1
166069  101.347  -78.855  44.645  1
166070  101.363  -78.888  44.629  1
166071  101.379  -78.922  44.615  1
166072  101.402  -78.953  44.601  1
166073  101.445  -78.972  44.589  1
166074  101.487  -78.992  44.576  1
166075  101.529  -79.011  44.562  1
166076  101.571  -79.030  44.550  1
166077  101.613  -79.049  44.537  1
166078  101.656  -79.068  44.524  1
166079  101.678  -79.078  44.511  1
166080  101.695  -79.083  44.501  1
166081  101.711  -79.088  44.488  1
166082  101.728  -79.094  44.475  1
166083  101.745  -79.100  44.463  1
166305  92.427  -77.244  53.989  1
166306  92.450  -77.255  54.011  1
166307  92.473  -77.266  54.033  1
166308  92.496  -77.277  54.054  1
166309  92.519  -77.288  54.075  1
166310  92.542  -77.299  54.095  1
166311  92.565  -77.310  54.113  1
166312  92.588  -77.321  54.130  1
166313  92.612  -77.332  54.148  1
166314  92.635  -77.344  54.163  1
166315  92.657  -77.354  54.177  1
166316  92.681  -77.366  54.190  1
166317  92.704  -77.376  54.202  1
166318  92.727  -77.388  54.213  1
166319  92.750  -77.399  54.223  1
166320  92.762  -77.411  54.232  1
166321  92.769  -77.423  54.243  1
166322  92.776  -77.436  54.251  1
166323  92.783  -77.448  54.261  1
166324  92.790  -77.461  54.270  1
166325  92.797  -77.473  54.278  1
166326  92.819  -77.471  54.292  1
166327  92.844  -77.463  54.305  1
166328  92.872  -77.455  54.318  1
166329  92.901  -77.448  54.327  1
166330  92.930  -77.441  54.333  1
166331  92.959  -77.434  54.337  1
166332  92.985  -77.423  54.337  1
166333  93.010  -77.412  54.341  1
166334  93.036  -77.401  54.346  1
166335  93.061  -77.389  54.352  1
166336  93.076  -77.376  54.361  1
166337  93.086  -77.361  54.369  1
166338  93.095  -77.347  54.379  1
166339  93.106  -77.332  54.390  1
166340  93.115  -77.319  54.395  1
166341  93.125  -77.304  54.397  1
166342  93.135  -77.290  54.398  1
166343  93.145  -77.276  54.397  1
166344  93.155  -77.262  54.392  1
166345  93.165  -77.248  54.384  1
166346  93.174  -77.233  54.376  1
166347  93.185  -77.219  54.370  1
166348  93.201  -77.209  54.362  1
166349  93.219  -77.201  54.354  1
166350  93.235  -77.193  54.348  1
166351  93.253  -77.185  54.345  1
166352  93.270  -77.178  54.344  1
166353  93.286  -77.171  54.343  1
166354  93.303  -77.163  54.342  1
166355  93.320  -77.156  54.340  1
166356  93.336  -77.148  54.337  1
166357  93.346  -77.138  54.333  1
166358  93.356  -77.128  54.326  1
166359  93.386  -77.122  54.317  1
166360  93.417  -77.115  54.306  1
166361  93.446  -77.107  54.294  1
166362  93.470  -77.097  54.284  1
166363  93.494  -77.088  54.273  1
166364  93.517  -77.078  54.262  1
166365  93.542  -77.068  54.252  1
166366  93.565  -77.058  54.247  1
166367  93.584  -77.056  54.242  1
166368  93.588  -77.072  54.237  1
166369  93.599  -77.071  54.233  1
166370  93.612  -77.066  54.225  1
166371  93.633  -77.055  54.214  1
166372  93.654  -77.043  54.202  1
166373  93.674  -77.032  54.189  1
166374  93.687  -77.028  54.176  1
166375  93.699  -77.025  54.164  1
166376  93.712  -77.022  54.152  1
166377  93.725  -77.018  54.140  1
166378  93.729  -77.007  54.131  1
166379  93.733  -76.997  54.121  1
166380  93.737  -76.986  54.109  1
166381  93.742  -76.976  54.096  1
166382  93.748  -76.969  54.083  1
166383  93.756  -76.968  54.071  1
166384  93.765  -76.967  54.061  1
166385  93.773  -76.965  54.054  1
166386  93.786  -76.968  54.048  1
166387  93.804  -76.972  54.043  1
166388  93.832  -76.981  54.031  1
166389  93.860  -76.988  54.018  1
166390  93.887  -76.988  54.002  1
166391  93.912  -76.984  53.985  1
166392  93.937  -76.980  53.969  1
166393  93.960  -76.974  53.951  1
166394  93.981  -76.967  53.932  1
166395  94.001  -76.959  53.910  1
166396  94.018  -76.949  53.887  1
166397  94.036  -76.937  53.865  1
166398  94.053  -76.927  53.843  1
166399  94.070  -76.916  53.821  1
166400  94.086  -76.908  53.801  1
166401  94.098  -76.906  53.781  1
166402  94.110  -76.903  53.760  1
166403  94.121  -76.900  53.745  1
166404  94.133  -76.897  53.732  1
166405  94.145  -76.895  53.722  1
166406  94.159  -76.892  53.710  1
166407  94.173  -76.889  53.695  1
166408  94.189  -76.886  53.677  1
166409  94.205  -76.883  53.656  1
166410  94.221  -76.881  53.634  1
166411  94.235  -76.878  53.611  1
166412  94.248  -76.875  53.590  1
166413  94.260  -76.872  53.570  1
166414  94.272  -76.870  53.553  1
166415  94.284  -76.867  53.537  1
166416  94.296  -76.864  53.522  1
166417  94.308  -76.862  53.510  1
166418  94.314  -76.863  53.501  1
166419  94.338  -76.857  53.494  1
166420  94.355  -76.854  53.487  1
166421  94.372  -76.852  53.481  1
166422  94.390  -76.850  53.471  1
166423  94.407  -76.846  53.460  1
166424  94.424  -76.844  53.449  1
166425  94.442  -76.842  53.437  1
166426  94.459  -76.839  53.421  1
166427  94.474  -76.837  53.403  1
166428  94.488  -76.834  53.382  1
166429  94.503  -76.833  53.358  1
166430  94.518  -76.831  53.334  1
166431  94.533  -76.828  53.310  1
166432  94.547  -76.826  53.283  1
166433  94.562  -76.824  53.258  1
166434  94.568  -76.827  53.231  1
166435  94.559  -76.831  53.202  1
166436  94.573  -76.828  53.169  1
166437  94.609  -76.819  53.137  1
166438  94.643  -76.811  53.105  1
166439  94.678  -76.802  53.074  1
166440  94.713  -76.795  53.042  1
166441  94.748  -76.787  53.010  1
166442  94.796  -76.769  52.979  1
166443  94.844  -76.752  52.945  1
166444  94.864  -76.744  52.909  1
166445  94.877  -76.738  52.871  1
166446  94.888  -76.732  52.831  1
166447  94.900  -76.726  52.790  1
166448  94.912  -76.720  52.748  1
166449  94.922  -76.718  52.705  1
166450  94.933  -76.716  52.662  1
166451  94.944  -76.715  52.620  1
166452  94.954  -76.713  52.580  1
166453  94.965  -76.712  52.543  1
166454  94.975  -76.709  52.512  1
166455  94.985  -76.708  52.485  1
166456  94.996  -76.706  52.461  1
166457  95.006  -76.705  52.437  1
166458  95.022  -76.706  52.416  1
166459  95.043  -76.712  52.394  1
166460  95.064  -76.718  52.372  1
166461  95.085  -76.724  52.347  1
166462  95.109  -76.732  52.316  1
166463  95.146  -76.744  52.280  1
166464  95.183  -76.756  52.236  1
166465  95.219  -76.768  52.185  1
166466  95.256  -76.781  52.130  1
166467  95.293  -76.793  52.073  1
166468  95.329  -76.805  52.016  1
166469  95.366  -76.817  51.958  1
166470  95.349  -76.846  51.899  1
166471  95.332  -76.877  51.838  1
166472  95.315  -76.906  51.777  1
166473  95.301  -76.934  51.718  1
166474  95.315  -76.943  51.661  1
166475  95.329  -76.953  51.605  1
166476  95.344  -76.963  51.551  1
166477  95.361  -76.975  51.496  1
166478  95.379  -76.987  51.442  1
166479  95.395  -76.999  51.388  1
166480  95.412  -77.010  51.336  1
166481  95.429  -77.022  51.285  1
166482  95.446  -77.034  51.236  1
166483  95.463  -77.046  51.189  1
166484  95.480  -77.057  51.141  1
166485  95.497  -77.069  51.094  1
166486  95.514  -77.081  51.047  1
166487  95.532  -77.096  51.002  1
166488  95.564  -77.106  50.957  1
166489  95.602  -77.116  50.912  1
166490  95.630  -77.117  50.869  1
166491  95.651  -77.116  50.824  1
166492  95.664  -77.117  50.780  1
166493  95.675  -77.121  50.737  1
166494  95.686  -77.125  50.696  1
166495  95.696  -77.128  50.658  1
166496  95.707  -77.132  50.621  1
166497  95.718  -77.136  50.585  1
166498  95.726  -77.149  50.548  1
166499  95.732  -77.172  50.510  1
166500  95.738  -77.195  50.470  1
166501  95.743  -77.219  50.430  1
166502  95.750  -77.230  50.384  1
166503  95.760  -77.229  50.339  1
166504  95.769  -77.228  50.295  1
166505  95.792  -77.236  50.253  1
166506  95.824  -77.252  50.211  1
166507  95.853  -77.257  50.169  1
166508  95.879  -77.246  50.126  1
166509  95.904  -77.235  50.086  1
166510  95.930  -77.225  50.044  1
166511  95.955  -77.213  50.000  1
166512  95.951  -77.219  49.954  1
166513  95.943  -77.228  49.904  1
166514  95.934  -77.236  49.847  1
166515  95.926  -77.244  49.784  1
166516  95.917  -77.253  49.717  1
166517  95.909  -77.261  49.654  1
166518  95.900  -77.269  49.595  1
166519  95.899  -77.279  49.540  1
166520  95.911  -77.291  49.488  1
166521  95.927  -77.298  49.441  1
166522  95.944  -77.304  49.396  1
166523  95.960  -77.309  49.353  1
166524  95.976  -77.315  49.313  1
166525  95.992  -77.321  49.276  1
166526  96.009  -77.327  49.241  1
166527  96.028  -77.334  49.209  1
166528  96.049  -77.342  49.177  1
166529  96.070  -77.350  49.148  1
166530  96.091  -77.357  49.121  1
166531  96.112  -77.365  49.093  1
166532  96.132  -77.373  49.070  1
166533  96.154  -77.381  49.048  1
166534  96.174  -77.389  49.026  1
166535  96.195  -77.391  49.004  1
166536  96.215  -77.392  48.981  1
166537  96.236  -77.392  48.959  1
166538  96.256  -77.393  48.938  1
166539  96.276  -77.394  48.920  1
166540  96.301  -77.401  48.900  1
166541  96.325  -77.408  48.880  1
166542  96.350  -77.415  48.863  1
166543  96.374  -77.422  48.847  1
166544  96.399  -77.429  48.833  1
166545  96.420  -77.440  48.820  1
166546  96.436  -77.455  48.814  1
166547  96.453  -77.470  48.806  1
166548  96.469  -77.486  48.798  1
166549  96.485  -77.501  48.792  1
166550  96.498  -77.521  48.782  1
166551  96.508  -77.543  48.769  1
166552  96.519  -77.565  48.755  1
166553  96.529  -77.587  48.739  1
166554  96.541  -77.609  48.721  1
166555  96.558  -77.630  48.703  1
166556  96.575  -77.652  48.686  1
166557  96.592  -77.674  48.670  1
166558  96.606  -77.680  48.653  1
166559  96.618  -77.678  48.636  1
166560  96.630  -77.677  48.620  1
166561  96.642  -77.674  48.605  1
166562  96.654  -77.673  48.589  1
166563  96.665  -77.671  48.572  1
166564  96.680  -77.668  48.556  1
166565  96.701  -77.664  48.538  1
166566  96.722  -77.661  48.521  1
166567  96.743  -77.656  48.506  1
166568  96.764  -77.652  48.489  1
166569  96.786  -77.649  48.472  1
166570  96.810  -77.654  48.455  1
166571  96.840  -77.672  48.438  1
166572  96.867  -77.685  48.418  1
166573  96.880  -77.666  48.398  1
166574  96.893  -77.647  48.377  1
166575  96.905  -77.627  48.356  1
166576  96.918  -77.608  48.332  1
166577  96.936  -77.603  48.307  1
166578  96.956  -77.605  48.282  1
166579  96.976  -77.607  48.257  1
166580  96.996  -77.609  48.232  1
166581  97.016  -77.611  48.207  1
166582  97.036  -77.613  48.182  1
166583  97.056  -77.614  48.158  1
166584  97.070  -77.614  48.135  1
166585  97.078  -77.614  48.112  1
166586  97.084  -77.620  48.089  1
166587  97.090  -77.625  48.067  1
166588  97.103  -77.631  48.046  1
166589  97.131  -77.639  48.026  1
166590  97.158  -77.649  48.007  1
166591  97.186  -77.657  47.987  1
166592  97.214  -77.665  47.966  1
166593  97.241  -77.674  47.946  1
166594  97.268  -77.683  47.923  1
166595  97.296  -77.691  47.900  1
166596  97.324  -77.700  47.877  1
166597  97.352  -77.708  47.854  1
166598  97.379  -77.717  47.830  1
166599  97.406  -77.726  47.807  1
166600  97.434  -77.734  47.784  1
166601  97.459  -77.740  47.759  1
166602  97.481  -77.749  47.734  1
166603  97.501  -77.755  47.709  1
166604  97.520  -77.762  47.685  1
166605  97.540  -77.769  47.660  1
166606  97.560  -77.776  47.635  1
166607  97.579  -77.783  47.611  1
166608  97.599  -77.789  47.585  1
166609  97.618  -77.796  47.559  1
166610  97.638  -77.802  47.532  1
166611  97.658  -77.809  47.505  1
166612  97.677  -77.816  47.480  1
166613  97.706  -77.825  47.455  1
166614  97.744  -77.837  47.431  1
166615  97.779  -77.841  47.406  1
166616  97.796  -77.811  47.382  1
166617  97.812  -77.780  47.358  1
166618  97.828  -77.749  47.334  1
166619  97.845  -77.718  47.310  1
166620  97.839  -77.693  47.285  1
166621  97.839  -77.721  47.260  1
166622  97.829  -77.750  47.234  1
166623  97.852  -77.746  47.206  1
166624  97.835  -77.742  47.179  1
166625  97.854  -77.762  47.152  1
166626  97.888  -77.784  47.125  1
166627  97.923  -77.805  47.097  1
166628  97.918  -77.815  47.073  1
166629  97.934  -77.816  47.048  1
166630  97.953  -77.816  47.023  1
166631  97.972  -77.817  46.999  1
166632  97.991  -77.818  46.974  1
166633  98.009  -77.818  46.948  1
166634  98.026  -77.819  46.923  1
166635  98.043  -77.820  46.898  1
166636  98.060  -77.821  46.873  1
166637  98.077  -77.821  46.848  1
166638  98.091  -77.827  46.821  1
166639  98.101  -77.837  46.795  1
166640  98.115  -77.845  46.769  1
166641  98.134  -77.850  46.743  1
166642  98.152  -77.856  46.718  1
166643  98.171  -77.862  46.693  1
166644  98.190  -77.868  46.669  1
166645  98.208  -77.873  46.644  1
166646  98.226  -77.879  46.620  1
166647  98.245  -77.884  46.596  1
166648  98.277  -77.870  46.572  1
166649  98.308  -77.855  46.550  1
166650  98.315  -77.850  46.528  1
166651  98.321  -77.845  46.505  1
166652  98.328  -77.840  46.483  1
166653  98.339  -77.836  46.461  1
166654  98.355  -77.834  46.439  1
166655  98.372  -77.831  46.417  1
166656  98.388  -77.829  46.398  1
166657  98.423  -77.835  46.378  1
166658  98.467  -77.846  46.359  1
166659  98.506  -77.854  46.340  1
166660  98.521  -77.852  46.321  1
166661  98.528  -77.850  46.301  1
166662  98.531  -77.850  46.283  1
166663  98.534  -77.850  46.267  1
166664  98.538  -77.851  46.249  1
166665  98.547  -77.854  46.231  1
166666  98.565  -77.861  46.214  1
166667  98.584  -77.868  46.196  1
166668  98.602  -77.876  46.180  1
166669  98.621  -77.884  46.164  1
166670  98.640  -77.890  46.148  1
166671  98.658  -77.898  46.130  1
166672  98.677  -77.906  46.111  1
166673  98.696  -77.913  46.092  1
166674  98.714  -77.920  46.073  1
166675  98.733  -77.928  46.053  1
166676  98.751  -77.935  46.033  1
166677  98.770  -77.942  46.014  1
166678  98.812  -77.950  45.996  1
166679  98.854  -77.959  45.978  1
166680  98.912  -77.968  45.959  1
166681  98.993  -77.980  45.941  1
166682  99.074  -77.991  45.924  1
166683  99.144  -78.001  45.907  1
166684  99.169  -78.004  45.889  1
166685  99.198  -77.999  45.872  1
166686  99.229  -77.990  45.855  1
166687  99.261  -77.981  45.839  1
166688  99.292  -77.973  45.823  1
166689  99.316  -77.981  45.807  1
166690  99.336  -77.987  45.794  1
166691  99.349  -77.995  45.783  1
166692  99.361  -78.002  45.772  1
166693  99.370  -78.009  45.762  1
166694  99.378  -78.017  45.752  1
166695  99.387  -78.024  45.742  1
166696  99.396  -78.031  45.732  1
166697  99.404  -78.038  45.722  1
166698  99.413  -78.046  45.712  1
166699  99.421  -78.053  45.703  1
166700  99.430  -78.060  45.692  1
166701  99.439  -78.067  45.681  1
166702  99.463  -78.076  45.671  1
166703  99.494  -78.086  45.662  1
166704  99.526  -78.096  45.651  1
166705  99.557  -78.105  45.640  1
166706  99.584  -78.116  45.629  1
166707  99.611  -78.127  45.617  1
166708  99.640  -78.140  45.605  1
166709  99.671  -78.156  45.592  1
166710  99.701  -78.172  45.578  1
166711  99.732  -78.187  45.566  1
166712  99.750  -78.200  45.550  1
166713  99.764  -78.211  45.535  1
166714  99.778  -78.223  45.520  1
166715  99.792  -78.235  45.505  1
166716  99.806  -78.246  45.490  1
166717  99.820  -78.257  45.475  1
166718  99.834  -78.269  45.459  1
166719  99.848  -78.281  45.443  1
166720  99.865  -78.294  45.428  1
166721  99.885  -78.307  45.412  1
166722  99.904  -78.322  45.396  1
166723  99.927  -78.334  45.379  1
166724  99.950  -78.346  45.362  1
166725  99.975  -78.358  45.345  1
166726  99.998  -78.370  45.327  1
166727  100.022  -78.383  45.310  1
166728  100.044  -78.400  45.294  1
166729  100.064  -78.418  45.278  1
166730  100.084  -78.436  45.263  1
166731  100.130  -78.451  45.247  1
166732  100.168  -78.461  45.232  1
166733  100.205  -78.471  45.216  1
166734  100.242  -78.481  45.199  1
166735  100.279  -78.490  45.183  1
166736  100.316  -78.500  45.166  1
166737  100.352  -78.510  45.151  1
166738  100.389  -78.520  45.135  1
166739  100.426  -78.529  45.119  1
166740  100.463  -78.539  45.104  1
166741  100.499  -78.548  45.089  1
166742  100.536  -78.558  45.076  1
166743  100.573  -78.568  45.063  1
166744  100.614  -78.579  45.048  1
166745  100.657  -78.586  45.034  1
166746  100.674  -78.552  45.019  1
166747  100.700  -78.562  45.003  1
166748  100.729  -78.575  44.988  1
166749  100.758  -78.587  44.973  1
166750  100.787  -78.599  44.957  1
166751  100.816  -78.615  44.942  1
166752  100.844  -78.633  44.926  1
166753  100.873  -78.649  44.910  1
166754  100.901  -78.667  44.894  1
166755  100.933  -78.672  44.879  1
166756  100.963  -78.670  44.863  1
166757  100.991  -78.667  44.847  1
166758  101.019  -78.664  44.832  1
166759  101.047  -78.662  44.817  1
166760  101.075  -78.659  44.801  1
166761  101.104  -78.657  44.785  1
166762  101.142  -78.674  44.769  1
166763  101.181  -78.703  44.754  1
166764  101.220  -78.732  44.739  1
166765  101.260  -78.761  44.725  1
166766  101.299  -78.789  44.711  1
166767  101.322  -78.815  44.696  1
166768  101.331  -78.833  44.681  1
166769  101.340  -78.844  44.666  1
166770  101.349  -78.855  44.651  1
166771  101.361  -78.875  44.636  1
166772  101.378  -78.909  44.621  1
166773  101.402  -78.940  44.607  1
166774  101.444  -78.959  44.594  1
166775  101.486  -78.978  44.581  1
166776  101.529  -78.997  44.568  1
166777  101.571  -79.016  44.554  1
166778  101.613  -79.036  44.542  1
166779  101.655  -79.055  44.529  1
166780  101.679  -79.064  44.517  1
166781  101.695  -79.070  44.506  1
166782  101.712  -79.075  44.494  1
166783  101.729  -79.081  44.481  1
166784  101.746  -79.087  44.469  1
166785  101.762  -79.092  44.457  1
167009  92.484  -77.248  54.035  1
167010  92.507  -77.259  54.056  1
167011  92.529  -77.270  54.077  1
167012  92.553  -77.281  54.097  1
167013  92.576  -77.292  54.116  1
167014  92.599  -77.304  54.134  1
167015  92.622  -77.314  54.150  1
167016  92.645  -77.326  54.165  1
167017  92.668  -77.336  54.179  1
167018  92.691  -77.348  54.193  1
167019  92.714  -77.359  54.203  1
167020  92.737  -77.370  54.214  1
167021  92.755  -77.382  54.224  1
167022  92.762  -77.394  54.235  1
167023  92.770  -77.407  54.245  1
167024  92.777  -77.419  54.255  1
167025  92.784  -77.432  54.264  1
167026  92.791  -77.444  54.274  1
167027  92.798  -77.457  54.287  1
167028  92.815  -77.457  54.302  1
167029  92.844  -77.449  54.316  1
167030  92.872  -77.442  54.324  1
167031  92.899  -77.432  54.330  1
167032  92.924  -77.420  54.333  1
167033  92.950  -77.409  54.333  1
167034  92.975  -77.398  54.333  1
167035  93.001  -77.386  54.335  1
167036  93.026  -77.374  54.340  1
167037  93.052  -77.363  54.348  1
167038  93.077  -77.351  54.356  1
167039  93.090  -77.338  54.366  1
167040  93.099  -77.323  54.377  1
167041  93.110  -77.309  54.379  1
167042  93.119  -77.295  54.381  1
167043  93.129  -77.281  54.383  1
167044  93.139  -77.266  54.382  1
167045  93.149  -77.252  54.377  1
167046  93.159  -77.238  54.369  1
167047  93.168  -77.224  54.359  1
167048  93.179  -77.210  54.354  1
167049  93.195  -77.200  54.348  1
167050  93.213  -77.191  54.343  1
167051  93.230  -77.183  54.338  1
167052  93.247  -77.175  54.337  1
167053  93.264  -77.169  54.337  1
167054  93.281  -77.161  54.337  1
167055  93.298  -77.153  54.338  1
167056  93.313  -77.145  54.335  1
167057  93.323  -77.135  54.332  1
167058  93.333  -77.125  54.327  1
167059  93.343  -77.115  54.319  1
167060  93.373  -77.109  54.309  1
167061  93.406  -77.103  54.299  1
167062  93.435  -77.095  54.288  1
167063  93.465  -77.088  54.278  1
167064  93.490  -77.079  54.268  1
167065  93.514  -77.069  54.258  1
167066  93.538  -77.059  54.251  1
167067  93.562  -77.050  54.247  1
167068  93.572  -77.060  54.242  1
167069  93.582  -77.060  54.236  1
167070  93.592  -77.059  54.230  1
167071  93.607  -77.053  54.221  1
167072  93.628  -77.041  54.210  1
167073  93.649  -77.029  54.197  1
167074  93.664  -77.023  54.184  1
167075  93.677  -77.019  54.172  1
167076  93.689  -77.016  54.161  1
167077  93.702  -77.012  54.150  1
167078  93.715  -77.009  54.139  1
167079  93.724  -77.002  54.131  1
167080  93.728  -76.991  54.124  1
167081  93.732  -76.981  54.114  1
167082  93.737  -76.971  54.102  1
167083  93.741  -76.960  54.090  1
167084  93.746  -76.950  54.079  1
167085  93.752  -76.944  54.071  1
167086  93.760  -76.943  54.064  1
167087  93.774  -76.946  54.058  1
167088  93.803  -76.954  54.054  1
167089  93.831  -76.962  54.046  1
167090  93.859  -76.970  54.036  1
167091  93.888  -76.978  54.024  1
167092  93.913  -76.975  54.008  1
167093  93.938  -76.971  53.992  1
167094  93.960  -76.965  53.974  1
167095  93.979  -76.956  53.955  1
167096  93.996  -76.944  53.932  1
167097  94.013  -76.934  53.910  1
167098  94.031  -76.923  53.888  1
167099  94.048  -76.912  53.866  1
167100  94.065  -76.901  53.845  1
167101  94.080  -76.893  53.825  1
167102  94.092  -76.891  53.804  1
167103  94.104  -76.889  53.784  1
167104  94.115  -76.886  53.767  1
167105  94.127  -76.884  53.754  1
167106  94.141  -76.881  53.744  1
167107  94.155  -76.877  53.733  1
167108  94.169  -76.874  53.719  1
167109  94.184  -76.871  53.703  1
167110  94.200  -76.868  53.684  1
167111  94.216  -76.865  53.662  1
167112  94.229  -76.863  53.639  1
167113  94.241  -76.860  53.616  1
167114  94.253  -76.858  53.596  1
167115  94.265  -76.855  53.579  1
167116  94.277  -76.853  53.564  1
167117  94.284  -76.853  53.548  1
167118  94.290  -76.855  53.534  1
167119  94.303  -76.853  53.522  1
167120  94.333  -76.843  53.513  1
167121  94.351  -76.840  53.506  1
167122  94.368  -76.837  53.500  1
167123  94.386  -76.835  53.491  1
167124  94.403  -76.833  53.478  1
167125  94.420  -76.830  53.466  1
167126  94.438  -76.828  53.453  1
167127  94.456  -76.824  53.437  1
167128  94.473  -76.822  53.419  1
167129  94.487  -76.820  53.399  1
167130  94.502  -76.818  53.377  1
167131  94.517  -76.815  53.354  1
167132  94.532  -76.813  53.330  1
167133  94.546  -76.812  53.305  1
167134  94.561  -76.809  53.279  1
167135  94.561  -76.816  53.252  1
167136  94.561  -76.822  53.222  1
167137  94.554  -76.825  53.190  1
167138  94.589  -76.817  53.158  1
167139  94.624  -76.809  53.126  1
167140  94.659  -76.801  53.095  1
167141  94.694  -76.792  53.063  1
167142  94.746  -76.772  53.032  1
167143  94.797  -76.752  53.003  1
167144  94.841  -76.738  52.968  1
167145  94.860  -76.731  52.932  1
167146  94.873  -76.725  52.893  1
167147  94.884  -76.719  52.852  1
167148  94.896  -76.713  52.811  1
167149  94.908  -76.707  52.768  1
167150  94.920  -76.701  52.725  1
167151  94.931  -76.694  52.681  1
167152  94.944  -76.689  52.635  1
167153  94.954  -76.687  52.591  1
167154  94.964  -76.685  52.552  1
167155  94.975  -76.683  52.518  1
167156  94.985  -76.682  52.487  1
167157  94.996  -76.680  52.458  1
167158  95.006  -76.679  52.431  1
167159  95.018  -76.677  52.409  1
167160  95.039  -76.683  52.386  1
167161  95.060  -76.690  52.362  1
167162  95.081  -76.696  52.338  1
167163  95.117  -76.708  52.309  1
167164  95.153  -76.720  52.274  1
167165  95.190  -76.732  52.232  1
167166  95.227  -76.744  52.185  1
167167  95.263  -76.756  52.134  1
167168  95.299  -76.770  52.080  1
167169  95.333  -76.788  52.025  1
167170  95.348  -76.808  51.969  1
167171  95.347  -76.829  51.909  1
167172  95.343  -76.851  51.848  1
167173  95.326  -76.881  51.788  1
167174  95.309  -76.910  51.730  1
167175  95.311  -76.928  51.674  1
167176  95.325  -76.937  51.619  1
167177  95.342  -76.950  51.564  1
167178  95.358  -76.961  51.508  1
167179  95.376  -76.973  51.453  1
167180  95.393  -76.984  51.398  1
167181  95.409  -76.996  51.347  1
167182  95.426  -77.008  51.297  1
167183  95.444  -77.019  51.248  1
167184  95.460  -77.031  51.200  1
167185  95.477  -77.043  51.153  1
167186  95.494  -77.055  51.105  1
167187  95.511  -77.066  51.058  1
167188  95.529  -77.080  51.012  1
167189  95.567  -77.088  50.966  1
167190  95.605  -77.097  50.922  1
167191  95.635  -77.103  50.878  1
167192  95.645  -77.106  50.835  1
167193  95.656  -77.110  50.791  1
167194  95.667  -77.113  50.748  1
167195  95.678  -77.117  50.707  1
167196  95.688  -77.121  50.671  1
167197  95.699  -77.125  50.635  1
167198  95.710  -77.128  50.599  1
167199  95.718  -77.142  50.562  1
167200  95.724  -77.165  50.525  1
167201  95.730  -77.188  50.487  1
167202  95.735  -77.212  50.446  1
167203  95.741  -77.235  50.400  1
167204  95.748  -77.246  50.355  1
167205  95.758  -77.244  50.311  1
167206  95.782  -77.255  50.269  1
167207  95.813  -77.262  50.228  1
167208  95.838  -77.251  50.186  1
167209  95.863  -77.240  50.145  1
167210  95.889  -77.229  50.105  1
167211  95.914  -77.218  50.064  1
167212  95.939  -77.207  50.021  1
167213  95.951  -77.204  49.975  1
167214  95.942  -77.213  49.926  1
167215  95.934  -77.221  49.868  1
167216  95.925  -77.229  49.804  1
167217  95.916  -77.238  49.735  1
167218  95.908  -77.246  49.670  1
167219  95.899  -77.254  49.609  1
167220  95.908  -77.266  49.552  1
167221  95.919  -77.279  49.500  1
167222  95.936  -77.285  49.451  1
167223  95.952  -77.291  49.405  1
167224  95.968  -77.296  49.361  1
167225  95.984  -77.302  49.320  1
167226  96.001  -77.308  49.283  1
167227  96.017  -77.314  49.248  1
167228  96.033  -77.320  49.217  1
167229  96.050  -77.326  49.186  1
167230  96.068  -77.333  49.157  1
167231  96.089  -77.341  49.129  1
167232  96.110  -77.348  49.103  1
167233  96.131  -77.356  49.081  1
167234  96.152  -77.363  49.060  1
167235  96.173  -77.372  49.040  1
167236  96.193  -77.373  49.020  1
167237  96.213  -77.373  48.997  1
167238  96.234  -77.374  48.972  1
167239  96.257  -77.379  48.948  1
167240  96.282  -77.386  48.927  1
167241  96.306  -77.393  48.907  1
167242  96.330  -77.401  48.887  1
167243  96.355  -77.407  48.870  1
167244  96.379  -77.414  48.854  1
167245  96.404  -77.422  48.839  1
167246  96.422  -77.436  48.826  1
167247  96.438  -77.451  48.817  1
167248  96.455  -77.466  48.809  1
167249  96.471  -77.481  48.802  1
167250  96.487  -77.496  48.795  1
167251  96.504  -77.512  48.786  1
167252  96.515  -77.533  48.774  1
167253  96.525  -77.555  48.760  1
167254  96.535  -77.577  48.745  1
167255  96.546  -77.600  48.727  1
167256  96.556  -77.622  48.710  1
167257  96.570  -77.643  48.693  1
167258  96.587  -77.665  48.678  1
167259  96.603  -77.680  48.662  1
167260  96.615  -77.679  48.646  1
167261  96.626  -77.677  48.631  1
167262  96.639  -77.675  48.616  1
167263  96.653  -77.673  48.599  1
167264  96.674  -77.668  48.583  1
167265  96.695  -77.664  48.567  1
167266  96.716  -77.661  48.550  1
167267  96.737  -77.657  48.534  1
167268  96.758  -77.652  48.519  1
167269  96.780  -77.649  48.503  1
167270  96.801  -77.645  48.486  1
167271  96.828  -77.658  48.469  1
167272  96.858  -77.677  48.452  1
167273  96.888  -77.695  48.433  1
167274  96.903  -77.680  48.414  1
167275  96.915  -77.661  48.394  1
167276  96.928  -77.642  48.372  1
167277  96.941  -77.623  48.348  1
167278  96.954  -77.603  48.324  1
167279  96.967  -77.588  48.299  1
167280  96.987  -77.589  48.275  1
167281  97.008  -77.592  48.251  1
167282  97.028  -77.593  48.227  1
167283  97.048  -77.595  48.202  1
167284  97.068  -77.597  48.178  1
167285  97.079  -77.596  48.155  1
167286  97.086  -77.596  48.132  1
167287  97.093  -77.602  48.109  1
167288  97.099  -77.607  48.087  1
167289  97.125  -77.615  48.065  1
167290  97.153  -77.624  48.045  1
167291  97.180  -77.632  48.026  1
167292  97.208  -77.641  48.005  1
167293  97.236  -77.649  47.984  1
167294  97.263  -77.658  47.963  1
167295  97.291  -77.667  47.939  1
167296  97.318  -77.675  47.916  1
167297  97.346  -77.683  47.893  1
167298  97.374  -77.692  47.870  1
167299  97.400  -77.701  47.847  1
167300  97.423  -77.711  47.823  1
167301  97.447  -77.721  47.799  1
167302  97.468  -77.729  47.775  1
167303  97.484  -77.733  47.750  1
167304  97.503  -77.739  47.725  1
167305  97.522  -77.746  47.700  1
167306  97.542  -77.752  47.675  1
167307  97.562  -77.759  47.651  1
167308  97.581  -77.766  47.626  1
167309  97.601  -77.773  47.598  1
167310  97.620  -77.780  47.572  1
167311  97.640  -77.787  47.544  1
167312  97.660  -77.793  47.517  1
167313  97.684  -77.801  47.490  1
167314  97.723  -77.812  47.464  1
167315  97.761  -77.824  47.439  1
167316  97.800  -77.836  47.413  1
167317  97.819  -77.812  47.390  1
167318  97.836  -77.781  47.366  1
167319  97.852  -77.750  47.342  1
167320  97.854  -77.724  47.317  1
167321  97.816  -77.707  47.293  1
167322  97.814  -77.727  47.267  1
167323  97.822  -77.754  47.241  1
167324  97.840  -77.758  47.213  1
167325  97.846  -77.757  47.185  1
167326  97.886  -77.765  47.157  1
167327  97.933  -77.782  47.129  1
167328  97.956  -77.800  47.102  1
167329  97.933  -77.804  47.077  1
167330  97.941  -77.805  47.052  1
167331  97.960  -77.805  47.026  1
167332  97.979  -77.806  47.001  1
167333  97.998  -77.807  46.976  1
167334  98.017  -77.808  46.951  1
167335  98.036  -77.808  46.926  1
167336  98.055  -77.809  46.901  1
167337  98.074  -77.809  46.877  1
167338  98.093  -77.810  46.852  1
167339  98.109  -77.812  46.826  1
167340  98.126  -77.818  46.801  1
167341  98.145  -77.824  46.776  1
167342  98.163  -77.830  46.750  1
167343  98.181  -77.836  46.726  1
167344  98.200  -77.841  46.701  1
167345  98.219  -77.847  46.676  1
167346  98.237  -77.852  46.652  1
167347  98.255  -77.859  46.627  1
167348  98.274  -77.865  46.603  1
167349  98.294  -77.867  46.579  1
167350  98.326  -77.853  46.555  1
167351  98.338  -77.846  46.533  1
167352  98.345  -77.841  46.511  1
167353  98.355  -77.837  46.488  1
167354  98.371  -77.834  46.466  1
167355  98.387  -77.832  46.444  1
167356  98.404  -77.830  46.423  1
167357  98.420  -77.827  46.402  1
167358  98.458  -77.834  46.383  1
167359  98.502  -77.845  46.363  1
167360  98.524  -77.847  46.344  1
167361  98.540  -77.843  46.324  1
167362  98.543  -77.843  46.305  1
167363  98.547  -77.844  46.287  1
167364  98.550  -77.844  46.270  1
167365  98.553  -77.845  46.253  1
167366  98.556  -77.845  46.235  1
167367  98.567  -77.849  46.217  1
167368  98.586  -77.856  46.199  1
167369  98.604  -77.864  46.182  1
167370  98.623  -77.871  46.166  1
167371  98.642  -77.878  46.150  1
167372  98.660  -77.886  46.134  1
167373  98.679  -77.893  46.115  1
167374  98.698  -77.901  46.096  1
167375  98.716  -77.908  46.076  1
167376  98.735  -77.915  46.056  1
167377  98.754  -77.923  46.036  1
167378  98.782  -77.931  46.017  1
167379  98.824  -77.938  46.000  1
167380  98.866  -77.946  45.982  1
167381  98.924  -77.956  45.964  1
167382  99.006  -77.968  45.947  1
167383  99.087  -77.979  45.929  1
167384  99.133  -77.986  45.912  1
167385  99.158  -77.989  45.894  1
167386  99.183  -77.992  45.877  1
167387  99.210  -77.990  45.860  1
167388  99.242  -77.981  45.843  1
167389  99.273  -77.973  45.828  1
167390  99.297  -77.980  45.813  1
167391  99.321  -77.987  45.799  1
167392  99.339  -77.994  45.787  1
167393  99.351  -78.002  45.776  1
167394  99.364  -78.009  45.767  1
167395  99.376  -78.016  45.756  1
167396  99.384  -78.024  45.746  1
167397  99.393  -78.031  45.737  1
167398  99.402  -78.038  45.727  1
167399  99.411  -78.045  45.718  1
167400  99.419  -78.053  45.708  1
167401  99.428  -78.059  45.699  1
167402  99.436  -78.067  45.688  1
167403  99.465  -78.076  45.678  1
167404  99.497  -78.086  45.669  1
167405  99.527  -78.096  45.659  1
167406  99.555  -78.106  45.648  1
167407  99.582  -78.117  45.636  1
167408  99.609  -78.128  45.624  1
167409  99.639  -78.143  45.612  1
167410  99.669  -78.159  45.598  1
167411  99.700  -78.174  45.585  1
167412  99.731  -78.190  45.570  1
167413  99.760  -78.205  45.554  1
167414  99.774  -78.216  45.539  1
167415  99.788  -78.228  45.524  1
167416  99.802  -78.240  45.509  1
167417  99.816  -78.251  45.494  1
167418  99.830  -78.263  45.479  1
167419  99.844  -78.275  45.464  1
167420  99.859  -78.287  45.448  1
167421  99.878  -78.300  45.432  1
167422  99.898  -78.314  45.416  1
167423  99.917  -78.328  45.400  1
167424  99.937  -78.341  45.383  1
167425  99.961  -78.354  45.366  1
167426  99.985  -78.366  45.349  1
167427  100.009  -78.378  45.331  1
167428  100.033  -78.390  45.315  1
167429  100.057  -78.403  45.299  1
167430  100.080  -78.415  45.285  1
167431  100.104  -78.428  45.269  1
167432  100.140  -78.438  45.253  1
167433  100.177  -78.448  45.237  1
167434  100.214  -78.458  45.221  1
167435  100.251  -78.468  45.205  1
167436  100.287  -78.477  45.189  1
167437  100.324  -78.487  45.173  1
167438  100.361  -78.497  45.157  1
167439  100.398  -78.507  45.142  1
167440  100.434  -78.517  45.126  1
167441  100.471  -78.526  45.111  1
167442  100.508  -78.535  45.096  1
167443  100.545  -78.545  45.082  1
167444  100.581  -78.555  45.069  1
167445  100.618  -78.565  45.055  1
167446  100.649  -78.523  45.041  1
167447  100.675  -78.533  45.025  1
167448  100.704  -78.545  45.010  1
167449  100.733  -78.560  44.995  1
167450  100.761  -78.577  44.980  1
167451  100.789  -78.594  44.965  1
167452  100.818  -78.611  44.949  1
167453  100.846  -78.628  44.933  1
167454  100.875  -78.645  44.917  1
167455  100.903  -78.662  44.902  1
167456  100.935  -78.664  44.886  1
167457  100.968  -78.663  44.870  1
167458  100.996  -78.661  44.855  1
167459  101.025  -78.658  44.839  1
167460  101.053  -78.655  44.823  1
167461  101.080  -78.652  44.808  1
167462  101.109  -78.647  44.792  1
167463  101.151  -78.657  44.776  1
167464  101.191  -78.686  44.760  1
167465  101.230  -78.714  44.746  1
167466  101.269  -78.743  44.732  1
167467  101.308  -78.772  44.718  1
167468  101.323  -78.797  44.702  1
167469  101.333  -78.821  44.687  1
167470  101.343  -78.844  44.673  1
167471  101.352  -78.856  44.658  1
167472  101.361  -78.868  44.642  1
167473  101.376  -78.896  44.628  1
167474  101.401  -78.926  44.614  1
167475  101.444  -78.945  44.601  1
167476  101.486  -78.964  44.587  1
167477  101.528  -78.984  44.573  1
167478  101.570  -79.002  44.560  1
167479  101.613  -79.022  44.547  1
167480  101.655  -79.041  44.534  1
167481  101.680  -79.051  44.522  1
167482  101.696  -79.056  44.511  1
167483  101.713  -79.062  44.499  1
167484  101.730  -79.068  44.486  1
167485  101.747  -79.074  44.474  1
167486  101.763  -79.079  44.462  1
167487  101.780  -79.084  44.451  1
167712  92.517  -77.241  54.060  1
167713  92.540  -77.252  54.080  1
167714  92.563  -77.263  54.100  1
167715  92.586  -77.274  54.119  1
167716  92.609  -77.285  54.137  1
167717  92.632  -77.296  54.153  1
167718  92.655  -77.307  54.167  1
167719  92.678  -77.319  54.181  1
167720  92.702  -77.329  54.194  1
167721  92.725  -77.341  54.205  1
167722  92.747  -77.352  54.216  1
167723  92.756  -77.364  54.227  1
167724  92.763  -77.377  54.239  1
167725  92.770  -77.389  54.249  1
167726  92.777  -77.402  54.258  1
167727  92.784  -77.414  54.268  1
167728  92.791  -77.427  54.282  1
167729  92.798  -77.439  54.297  1
167730  92.813  -77.441  54.312  1
167731  92.839  -77.429  54.319  1
167732  92.864  -77.417  54.324  1
167733  92.889  -77.406  54.326  1
167734  92.915  -77.395  54.326  1
167735  92.940  -77.383  54.324  1
167736  92.966  -77.371  54.324  1
167737  92.991  -77.360  54.327  1
167738  93.016  -77.348  54.333  1
167739  93.042  -77.337  54.340  1
167740  93.067  -77.326  54.348  1
167741  93.093  -77.313  54.358  1
167742  93.103  -77.300  54.359  1
167743  93.114  -77.285  54.360  1
167744  93.123  -77.271  54.360  1
167745  93.133  -77.257  54.359  1
167746  93.143  -77.243  54.355  1
167747  93.153  -77.229  54.350  1
167748  93.163  -77.214  54.344  1
167749  93.172  -77.201  54.340  1
167750  93.189  -77.191  54.337  1
167751  93.207  -77.182  54.335  1
167752  93.225  -77.173  54.333  1
167753  93.241  -77.166  54.333  1
167754  93.259  -77.159  54.334  1
167755  93.276  -77.151  54.334  1
167756  93.289  -77.143  54.334  1
167757  93.299  -77.132  54.332  1
167758  93.309  -77.122  54.328  1
167759  93.320  -77.112  54.322  1
167760  93.330  -77.101  54.312  1
167761  93.359  -77.096  54.303  1
167762  93.395  -77.091  54.293  1
167763  93.424  -77.084  54.283  1
167764  93.453  -77.076  54.272  1
167765  93.483  -77.069  54.262  1
167766  93.511  -77.061  54.254  1
167767  93.535  -77.051  54.250  1
167768  93.556  -77.045  54.247  1
167769  93.564  -77.050  54.241  1
167770  93.575  -77.048  54.234  1
167771  93.585  -77.047  54.226  1
167772  93.602  -77.039  54.216  1
167773  93.622  -77.028  54.205  1
167774  93.641  -77.018  54.192  1
167775  93.654  -77.014  54.181  1
167776  93.666  -77.010  54.170  1
167777  93.679  -77.007  54.160  1
167778  93.692  -77.003  54.151  1
167779  93.705  -77.000  54.141  1
167780  93.717  -76.996  54.133  1
167781  93.723  -76.987  54.126  1
167782  93.727  -76.976  54.118  1
167783  93.732  -76.965  54.107  1
167784  93.736  -76.955  54.097  1
167785  93.741  -76.944  54.086  1
167786  93.745  -76.934  54.079  1
167787  93.749  -76.923  54.072  1
167788  93.773  -76.928  54.066  1
167789  93.801  -76.936  54.062  1
167790  93.830  -76.943  54.055  1
167791  93.858  -76.952  54.046  1
167792  93.887  -76.960  54.037  1
167793  93.915  -76.967  54.025  1
167794  93.938  -76.962  54.011  1
167795  93.956  -76.952  53.995  1
167796  93.973  -76.940  53.976  1
167797  93.991  -76.930  53.953  1
167798  94.008  -76.919  53.931  1
167799  94.025  -76.909  53.909  1
167800  94.042  -76.897  53.888  1
167801  94.059  -76.887  53.869  1
167802  94.074  -76.880  53.850  1
167803  94.086  -76.877  53.830  1
167804  94.098  -76.875  53.809  1
167805  94.110  -76.871  53.791  1
167806  94.123  -76.868  53.777  1
167807  94.137  -76.865  53.767  1
167808  94.151  -76.862  53.757  1
167809  94.165  -76.859  53.745  1
167810  94.180  -76.856  53.731  1
167811  94.196  -76.854  53.712  1
167812  94.210  -76.851  53.691  1
167813  94.222  -76.848  53.668  1
167814  94.235  -76.846  53.644  1
167815  94.247  -76.843  53.622  1
167816  94.255  -76.843  53.606  1
167817  94.261  -76.844  53.591  1
167818  94.267  -76.846  53.575  1
167819  94.273  -76.847  53.559  1
167820  94.295  -76.841  53.545  1
167821  94.324  -76.832  53.534  1
167822  94.347  -76.826  53.526  1
167823  94.364  -76.823  53.520  1
167824  94.382  -76.821  53.510  1
167825  94.399  -76.818  53.497  1
167826  94.416  -76.816  53.484  1
167827  94.434  -76.813  53.469  1
167828  94.453  -76.810  53.453  1
167829  94.470  -76.807  53.436  1
167830  94.486  -76.805  53.418  1
167831  94.501  -76.803  53.397  1
167832  94.516  -76.801  53.375  1
167833  94.530  -76.799  53.351  1
167834  94.545  -76.796  53.325  1
167835  94.553  -76.798  53.299  1
167836  94.554  -76.805  53.272  1
167837  94.554  -76.812  53.242  1
167838  94.554  -76.818  53.211  1
167839  94.569  -76.815  53.179  1
167840  94.604  -76.807  53.147  1
167841  94.644  -76.795  53.115  1
167842  94.696  -76.775  53.085  1
167843  94.747  -76.755  53.055  1
167844  94.799  -76.736  53.025  1
167845  94.837  -76.725  52.989  1
167846  94.857  -76.718  52.951  1
167847  94.868  -76.712  52.912  1
167848  94.881  -76.705  52.871  1
167849  94.892  -76.699  52.830  1
167850  94.904  -76.693  52.787  1
167851  94.916  -76.687  52.743  1
167852  94.928  -76.681  52.696  1
167853  94.939  -76.675  52.650  1
167854  94.952  -76.669  52.606  1
167855  94.963  -76.663  52.565  1
167856  94.975  -76.658  52.529  1
167857  94.985  -76.656  52.494  1
167858  94.996  -76.655  52.462  1
167859  95.006  -76.652  52.432  1
167860  95.017  -76.651  52.405  1
167861  95.035  -76.655  52.379  1
167862  95.056  -76.661  52.354  1
167863  95.087  -76.671  52.329  1
167864  95.124  -76.683  52.300  1
167865  95.161  -76.695  52.267  1
167866  95.197  -76.708  52.228  1
167867  95.231  -76.726  52.184  1
167868  95.264  -76.745  52.136  1
167869  95.298  -76.763  52.086  1
167870  95.325  -76.783  52.033  1
167871  95.323  -76.803  51.976  1
167872  95.322  -76.824  51.916  1
167873  95.321  -76.845  51.856  1
167874  95.319  -76.865  51.798  1
167875  95.318  -76.886  51.742  1
167876  95.306  -76.912  51.687  1
167877  95.322  -76.923  51.633  1
167878  95.339  -76.935  51.576  1
167879  95.356  -76.947  51.519  1
167880  95.373  -76.959  51.464  1
167881  95.390  -76.970  51.410  1
167882  95.407  -76.981  51.359  1
167883  95.423  -76.991  51.309  1
167884  95.441  -77.002  51.261  1
167885  95.458  -77.012  51.212  1
167886  95.474  -77.023  51.164  1
167887  95.491  -77.033  51.117  1
167888  95.508  -77.044  51.069  1
167889  95.530  -77.053  51.022  1
167890  95.569  -77.064  50.976  1
167891  95.603  -77.060  50.931  1
167892  95.624  -77.091  50.887  1
167893  95.637  -77.099  50.845  1
167894  95.648  -77.103  50.802  1
167895  95.659  -77.106  50.760  1
167896  95.670  -77.110  50.720  1
167897  95.680  -77.114  50.684  1
167898  95.691  -77.118  50.648  1
167899  95.702  -77.121  50.612  1
167900  95.710  -77.135  50.576  1
167901  95.716  -77.158  50.540  1
167902  95.722  -77.182  50.503  1
167903  95.727  -77.204  50.461  1
167904  95.733  -77.228  50.416  1
167905  95.738  -77.251  50.370  1
167906  95.746  -77.261  50.326  1
167907  95.771  -77.266  50.285  1
167908  95.797  -77.256  50.245  1
167909  95.822  -77.244  50.204  1
167910  95.847  -77.234  50.164  1
167911  95.873  -77.222  50.125  1
167912  95.898  -77.212  50.084  1
167913  95.923  -77.201  50.041  1
167914  95.949  -77.190  49.996  1
167915  95.941  -77.198  49.946  1
167916  95.933  -77.207  49.888  1
167917  95.924  -77.215  49.823  1
167918  95.915  -77.223  49.753  1
167919  95.907  -77.232  49.686  1
167920  95.904  -77.241  49.623  1
167921  95.916  -77.254  49.565  1
167922  95.928  -77.266  49.511  1
167923  95.945  -77.272  49.460  1
167924  95.961  -77.278  49.413  1
167925  95.977  -77.284  49.370  1
167926  95.993  -77.289  49.328  1
167927  96.010  -77.295  49.290  1
167928  96.026  -77.301  49.255  1
167929  96.042  -77.307  49.224  1
167930  96.058  -77.313  49.194  1
167931  96.075  -77.320  49.165  1
167932  96.091  -77.325  49.138  1
167933  96.108  -77.332  49.114  1
167934  96.129  -77.339  49.094  1
167935  96.150  -77.347  49.075  1
167936  96.171  -77.354  49.056  1
167937  96.191  -77.354  49.037  1
167938  96.213  -77.357  49.013  1
167939  96.237  -77.364  48.987  1
167940  96.262  -77.371  48.958  1
167941  96.286  -77.379  48.936  1
167942  96.311  -77.385  48.915  1
167943  96.335  -77.392  48.895  1
167944  96.360  -77.400  48.877  1
167945  96.384  -77.407  48.861  1
167946  96.407  -77.415  48.846  1
167947  96.424  -77.431  48.833  1
167948  96.440  -77.446  48.822  1
167949  96.457  -77.461  48.813  1
167950  96.473  -77.476  48.805  1
167951  96.489  -77.492  48.797  1
167952  96.506  -77.507  48.790  1
167953  96.521  -77.523  48.778  1
167954  96.531  -77.546  48.763  1
167955  96.542  -77.568  48.750  1
167956  96.552  -77.590  48.733  1
167957  96.562  -77.612  48.717  1
167958  96.573  -77.634  48.702  1
167959  96.583  -77.656  48.689  1
167960  96.599  -77.678  48.673  1
167961  96.611  -77.680  48.657  1
167962  96.626  -77.677  48.643  1
167963  96.647  -77.673  48.627  1
167964  96.668  -77.669  48.611  1
167965  96.689  -77.665  48.594  1
167966  96.710  -77.661  48.577  1
167967  96.731  -77.657  48.562  1
167968  96.752  -77.653  48.548  1
167969  96.773  -77.649  48.534  1
167970  96.795  -77.645  48.518  1
167971  96.817  -77.645  48.501  1
167972  96.847  -77.663  48.484  1
167973  96.876  -77.681  48.467  1
167974  96.906  -77.699  48.449  1
167975  96.926  -77.695  48.430  1
167976  96.938  -77.676  48.410  1
167977  96.951  -77.656  48.387  1
167978  96.964  -77.637  48.364  1
167979  96.976  -77.617  48.341  1
167980  96.989  -77.599  48.316  1
167981  97.002  -77.580  48.293  1
167982  97.019  -77.574  48.270  1
167983  97.039  -77.576  48.246  1
167984  97.060  -77.578  48.222  1
167985  97.080  -77.580  48.199  1
167986  97.088  -77.578  48.175  1
167987  97.095  -77.578  48.151  1
167988  97.101  -77.583  48.127  1
167989  97.120  -77.590  48.106  1
167990  97.148  -77.599  48.085  1
167991  97.175  -77.608  48.064  1
167992  97.203  -77.616  48.044  1
167993  97.230  -77.624  48.023  1
167994  97.258  -77.633  48.002  1
167995  97.286  -77.642  47.979  1
167996  97.313  -77.650  47.955  1
167997  97.337  -77.660  47.932  1
167998  97.361  -77.670  47.909  1
167999  97.384  -77.680  47.887  1
168000  97.407  -77.689  47.862  1
168001  97.431  -77.699  47.838  1
168002  97.454  -77.708  47.814  1
168003  97.478  -77.718  47.790  1
168004  97.488  -77.718  47.765  1
168005  97.505  -77.723  47.741  1
168006  97.524  -77.730  47.716  1
168007  97.544  -77.736  47.690  1
168008  97.564  -77.743  47.666  1
168009  97.583  -77.749  47.640  1
168010  97.603  -77.756  47.612  1
168011  97.623  -77.763  47.584  1
168012  97.642  -77.770  47.556  1
168013  97.662  -77.777  47.529  1
168014  97.701  -77.789  47.503  1
168015  97.739  -77.800  47.476  1
168016  97.778  -77.812  47.449  1
168017  97.816  -77.824  47.423  1
168018  97.844  -77.813  47.398  1
168019  97.860  -77.782  47.373  1
168020  97.868  -77.753  47.349  1
168021  97.830  -77.737  47.325  1
168022  97.793  -77.721  47.300  1
168023  97.784  -77.733  47.274  1
168024  97.803  -77.754  47.247  1
168025  97.835  -77.767  47.220  1
168026  97.867  -77.779  47.192  1
168027  97.877  -77.780  47.163  1
168028  97.938  -77.793  47.135  1
168029  97.925  -77.777  47.107  1
168030  97.900  -77.774  47.081  1
168031  97.967  -77.788  47.055  1
168032  97.986  -77.790  47.029  1
168033  98.005  -77.790  47.004  1
168034  98.024  -77.792  46.980  1
168035  98.043  -77.793  46.955  1
168036  98.063  -77.793  46.930  1
168037  98.082  -77.795  46.905  1
168038  98.101  -77.796  46.881  1
168039  98.120  -77.797  46.856  1
168040  98.132  -77.799  46.830  1
168041  98.143  -77.805  46.805  1
168042  98.164  -77.808  46.781  1
168043  98.185  -77.813  46.756  1
168044  98.207  -77.817  46.732  1
168045  98.228  -77.821  46.708  1
168046  98.247  -77.827  46.684  1
168047  98.266  -77.832  46.660  1
168048  98.285  -77.838  46.635  1
168049  98.303  -77.844  46.610  1
168050  98.321  -77.849  46.585  1
168051  98.343  -77.851  46.561  1
168052  98.361  -77.842  46.539  1
168053  98.371  -77.837  46.516  1
168054  98.387  -77.835  46.493  1
168055  98.404  -77.833  46.471  1
168056  98.420  -77.830  46.450  1
168057  98.436  -77.828  46.428  1
168058  98.452  -77.826  46.407  1
168059  98.493  -77.834  46.388  1
168060  98.528  -77.841  46.368  1
168061  98.543  -77.840  46.348  1
168062  98.555  -77.837  46.328  1
168063  98.558  -77.837  46.309  1
168064  98.562  -77.838  46.291  1
168065  98.565  -77.838  46.273  1
168066  98.568  -77.839  46.257  1
168067  98.571  -77.839  46.238  1
168068  98.574  -77.840  46.220  1
168069  98.588  -77.844  46.202  1
168070  98.606  -77.852  46.184  1
168071  98.625  -77.859  46.168  1
168072  98.644  -77.866  46.152  1
168073  98.662  -77.874  46.135  1
168074  98.681  -77.881  46.117  1
168075  98.700  -77.889  46.098  1
168076  98.718  -77.896  46.077  1
168077  98.737  -77.903  46.056  1
168078  98.756  -77.911  46.037  1
168079  98.794  -77.918  46.019  1
168080  98.836  -77.927  46.001  1
168081  98.878  -77.934  45.984  1
168082  98.937  -77.944  45.967  1
168083  99.018  -77.956  45.950  1
168084  99.097  -77.968  45.933  1
168085  99.123  -77.971  45.916  1
168086  99.147  -77.974  45.899  1
168087  99.172  -77.977  45.883  1
168088  99.197  -77.980  45.866  1
168089  99.223  -77.981  45.850  1
168090  99.254  -77.972  45.834  1
168091  99.278  -77.979  45.819  1
168092  99.302  -77.987  45.804  1
168093  99.326  -77.993  45.792  1
168094  99.341  -78.001  45.781  1
168095  99.354  -78.009  45.771  1
168096  99.367  -78.015  45.762  1
168097  99.380  -78.023  45.752  1
168098  99.391  -78.031  45.742  1
168099  99.400  -78.037  45.733  1
168100  99.408  -78.045  45.724  1
168101  99.417  -78.052  45.714  1
168102  99.425  -78.059  45.705  1
168103  99.436  -78.067  45.695  1
168104  99.467  -78.076  45.685  1
168105  99.498  -78.086  45.675  1
168106  99.525  -78.097  45.666  1
168107  99.553  -78.108  45.655  1
168108  99.580  -78.119  45.644  1
168109  99.607  -78.130  45.631  1
168110  99.638  -78.145  45.618  1
168111  99.668  -78.161  45.605  1
168112  99.699  -78.177  45.591  1
168113  99.729  -78.192  45.575  1
168114  99.760  -78.208  45.559  1
168115  99.784  -78.222  45.544  1
168116  99.797  -78.234  45.528  1
168117  99.811  -78.245  45.514  1
168118  99.826  -78.257  45.498  1
168119  99.840  -78.268  45.483  1
168120  99.854  -78.280  45.467  1
168121  99.872  -78.293  45.451  1
168122  99.891  -78.307  45.435  1
168123  99.910  -78.321  45.419  1
168124  99.930  -78.335  45.404  1
168125  99.949  -78.348  45.387  1
168126  99.972  -78.361  45.370  1
168127  99.996  -78.373  45.352  1
168128  100.019  -78.385  45.335  1
168129  100.043  -78.398  45.319  1
168130  100.067  -78.410  45.303  1
168131  100.091  -78.423  45.288  1
168132  100.115  -78.427  45.273  1
168133  100.141  -78.431  45.257  1
168134  100.179  -78.440  45.242  1
168135  100.216  -78.449  45.226  1
168136  100.254  -78.459  45.210  1
168137  100.291  -78.468  45.194  1
168138  100.328  -78.477  45.179  1
168139  100.365  -78.486  45.163  1
168140  100.403  -78.496  45.148  1
168141  100.440  -78.505  45.133  1
168142  100.478  -78.514  45.118  1
168143  100.515  -78.523  45.102  1
168144  100.552  -78.533  45.088  1
168145  100.590  -78.542  45.075  1
168146  100.627  -78.551  45.061  1
168147  100.649  -78.504  45.047  1
168148  100.678  -78.522  45.031  1
168149  100.706  -78.539  45.016  1
168150  100.735  -78.556  45.001  1
168151  100.763  -78.573  44.986  1
168152  100.791  -78.590  44.971  1
168153  100.819  -78.607  44.955  1
168154  100.848  -78.624  44.939  1
168155  100.876  -78.641  44.924  1
168156  100.905  -78.657  44.908  1
168157  100.938  -78.656  44.892  1
168158  100.972  -78.655  44.877  1
168159  101.001  -78.654  44.861  1
168160  101.030  -78.651  44.844  1
168161  101.058  -78.648  44.829  1
168162  101.086  -78.645  44.813  1
168163  101.114  -78.636  44.798  1
168164  101.158  -78.648  44.783  1
168165  101.200  -78.668  44.768  1
168166  101.239  -78.697  44.753  1
168167  101.278  -78.727  44.739  1
168168  101.315  -78.755  44.724  1
168169  101.325  -78.778  44.709  1
168170  101.335  -78.802  44.693  1
168171  101.344  -78.825  44.678  1
168172  101.354  -78.849  44.664  1
168173  101.364  -78.868  44.649  1
168174  101.375  -78.883  44.634  1
168175  101.401  -78.912  44.620  1
168176  101.444  -78.931  44.606  1
168177  101.485  -78.950  44.593  1
168178  101.528  -78.970  44.579  1
168179  101.570  -78.989  44.566  1
168180  101.612  -79.008  44.552  1
168181  101.655  -79.028  44.540  1
168182  101.680  -79.037  44.528  1
168183  101.697  -79.043  44.516  1
168184  101.714  -79.049  44.504  1
168185  101.731  -79.055  44.491  1
168186  101.747  -79.060  44.479  1
168187  101.764  -79.066  44.468  1
168188  101.781  -79.071  44.456  1
168189  101.798  -79.077  44.444  1
168415  92.551  -77.234  54.083  1
168416  92.574  -77.245  54.103  1
168417  92.597  -77.256  54.122  1
168418  92.620  -77.267  54.139  1
168419  92.643  -77.279  54.155  1
168420  92.666  -77.289  54.169  1
168421  92.689  -77.301  54.181  1
168422  92.712  -77.311  54.194  1
168423  92.735  -77.323  54.206  1
168424  92.749  -77.335  54.218  1
168425  92.756  -77.347  54.229  1
168426  92.763  -77.360  54.240  1
168427  92.770  -77.373  54.250  1
168428  92.777  -77.385  54.260  1
168429  92.784  -77.398  54.273  1
168430  92.791  -77.410  54.288  1
168431  92.801  -77.418  54.302  1
168432  92.821  -77.409  54.309  1
168433  92.842  -77.401  54.313  1
168434  92.861  -77.390  54.315  1
168435  92.881  -77.379  54.315  1
168436  92.905  -77.369  54.314  1
168437  92.930  -77.357  54.313  1
168438  92.956  -77.345  54.314  1
168439  92.981  -77.334  54.318  1
168440  93.007  -77.323  54.324  1
168441  93.032  -77.311  54.330  1
168442  93.058  -77.299  54.337  1
168443  93.083  -77.288  54.337  1
168444  93.108  -77.276  54.338  1
168445  93.118  -77.262  54.338  1
168446  93.127  -77.248  54.338  1
168447  93.137  -77.233  54.336  1
168448  93.147  -77.219  54.334  1
168449  93.157  -77.205  54.333  1
168450  93.167  -77.191  54.332  1
168451  93.183  -77.181  54.331  1
168452  93.201  -77.172  54.331  1
168453  93.219  -77.164  54.331  1
168454  93.236  -77.157  54.331  1
168455  93.253  -77.149  54.332  1
168456  93.266  -77.140  54.331  1
168457  93.276  -77.129  54.328  1
168458  93.286  -77.119  54.326  1
168459  93.296  -77.109  54.321  1
168460  93.306  -77.099  54.314  1
168461  93.317  -77.088  54.305  1
168462  93.346  -77.082  54.297  1
168463  93.381  -77.078  54.290  1
168464  93.413  -77.072  54.281  1
168465  93.442  -77.064  54.269  1
168466  93.472  -77.057  54.259  1
168467  93.502  -77.050  54.252  1
168468  93.532  -77.043  54.248  1
168469  93.547  -77.039  54.244  1
168470  93.558  -77.038  54.238  1
168471  93.568  -77.036  54.229  1
168472  93.578  -77.034  54.220  1
168473  93.596  -77.025  54.211  1
168474  93.617  -77.014  54.201  1
168475  93.631  -77.009  54.190  1
168476  93.644  -77.005  54.180  1
168477  93.656  -77.001  54.170  1
168478  93.669  -76.998  54.161  1
168479  93.682  -76.994  54.153  1
168480  93.695  -76.990  54.145  1
168481  93.708  -76.987  54.137  1
168482  93.718  -76.981  54.130  1
168483  93.722  -76.971  54.123  1
168484  93.726  -76.960  54.114  1
168485  93.731  -76.950  54.103  1
168486  93.735  -76.939  54.094  1
168487  93.740  -76.928  54.086  1
168488  93.747  -76.912  54.079  1
168489  93.767  -76.910  54.073  1
168490  93.796  -76.918  54.068  1
168491  93.825  -76.926  54.061  1
168492  93.854  -76.934  54.054  1
168493  93.883  -76.942  54.046  1
168494  93.911  -76.950  54.037  1
168495  93.933  -76.947  54.025  1
168496  93.951  -76.937  54.011  1
168497  93.968  -76.926  53.995  1
168498  93.985  -76.915  53.974  1
168499  94.002  -76.904  53.952  1
168500  94.019  -76.893  53.930  1
168501  94.037  -76.883  53.910  1
168502  94.054  -76.872  53.892  1
168503  94.068  -76.865  53.874  1
168504  94.080  -76.863  53.856  1
168505  94.092  -76.860  53.834  1
168506  94.106  -76.857  53.816  1
168507  94.120  -76.854  53.801  1
168508  94.133  -76.851  53.791  1
168509  94.147  -76.848  53.782  1
168510  94.161  -76.845  53.773  1
168511  94.175  -76.842  53.761  1
168512  94.191  -76.839  53.744  1
168513  94.204  -76.837  53.722  1
168514  94.216  -76.834  53.698  1
168515  94.226  -76.833  53.673  1
168516  94.231  -76.834  53.650  1
168517  94.238  -76.836  53.632  1
168518  94.244  -76.837  53.616  1
168519  94.250  -76.838  53.602  1
168520  94.257  -76.839  53.586  1
168521  94.286  -76.830  53.571  1
168522  94.315  -76.821  53.558  1
168523  94.343  -76.812  53.547  1
168524  94.360  -76.809  53.540  1
168525  94.378  -76.806  53.530  1
168526  94.395  -76.804  53.517  1
168527  94.413  -76.802  53.502  1
168528  94.430  -76.799  53.486  1
168529  94.449  -76.796  53.469  1
168530  94.467  -76.793  53.453  1
168531  94.485  -76.790  53.437  1
168532  94.499  -76.788  53.417  1
168533  94.514  -76.786  53.395  1
168534  94.529  -76.784  53.371  1
168535  94.544  -76.781  53.345  1
168536  94.546  -76.787  53.319  1
168537  94.547  -76.794  53.292  1
168538  94.547  -76.801  53.262  1
168539  94.548  -76.808  53.231  1
168540  94.549  -76.813  53.200  1
168541  94.594  -76.798  53.168  1
168542  94.645  -76.778  53.136  1
168543  94.697  -76.759  53.107  1
168544  94.749  -76.739  53.077  1
168545  94.797  -76.721  53.046  1
168546  94.834  -76.712  53.008  1
168547  94.853  -76.705  52.969  1
168548  94.864  -76.699  52.929  1
168549  94.877  -76.693  52.888  1
168550  94.888  -76.687  52.846  1
168551  94.900  -76.680  52.803  1
168552  94.912  -76.674  52.759  1
168553  94.924  -76.668  52.711  1
168554  94.935  -76.661  52.666  1
168555  94.948  -76.655  52.623  1
168556  94.959  -76.649  52.583  1
168557  94.971  -76.643  52.544  1
168558  94.983  -76.637  52.507  1
168559  94.995  -76.631  52.470  1
168560  95.006  -76.627  52.436  1
168561  95.017  -76.625  52.404  1
168562  95.031  -76.626  52.375  1
168563  95.058  -76.634  52.348  1
168564  95.095  -76.646  52.321  1
168565  95.129  -76.663  52.291  1
168566  95.162  -76.682  52.259  1
168567  95.196  -76.701  52.223  1
168568  95.229  -76.720  52.182  1
168569  95.262  -76.739  52.136  1
168570  95.296  -76.757  52.088  1
168571  95.300  -76.777  52.035  1
168572  95.299  -76.799  51.978  1
168573  95.297  -76.819  51.920  1
168574  95.296  -76.840  51.862  1
168575  95.294  -76.860  51.806  1
168576  95.293  -76.881  51.752  1
168577  95.302  -76.895  51.697  1
168578  95.318  -76.903  51.640  1
168579  95.336  -76.909  51.583  1
168580  95.353  -76.919  51.527  1
168581  95.370  -76.930  51.474  1
168582  95.387  -76.940  51.422  1
168583  95.403  -76.950  51.371  1
168584  95.420  -76.961  51.322  1
168585  95.438  -76.971  51.274  1
168586  95.454  -76.981  51.225  1
168587  95.471  -76.992  51.177  1
168588  95.488  -77.003  51.129  1
168589  95.505  -77.012  51.083  1
168590  95.527  -77.022  51.036  1
168591  95.561  -77.002  50.990  1
168592  95.593  -76.990  50.944  1
168593  95.603  -77.046  50.900  1
168594  95.622  -77.072  50.858  1
168595  95.641  -77.100  50.816  1
168596  95.651  -77.099  50.774  1
168597  95.662  -77.103  50.734  1
168598  95.672  -77.106  50.696  1
168599  95.683  -77.110  50.660  1
168600  95.694  -77.114  50.625  1
168601  95.702  -77.128  50.590  1
168602  95.707  -77.150  50.553  1
168603  95.713  -77.174  50.514  1
168604  95.719  -77.197  50.471  1
168605  95.725  -77.220  50.428  1
168606  95.730  -77.244  50.384  1
168607  95.739  -77.260  50.341  1
168608  95.756  -77.260  50.300  1
168609  95.781  -77.249  50.260  1
168610  95.807  -77.238  50.220  1
168611  95.832  -77.228  50.180  1
168612  95.857  -77.216  50.142  1
168613  95.883  -77.206  50.101  1
168614  95.908  -77.194  50.058  1
168615  95.933  -77.184  50.012  1
168616  95.940  -77.183  49.963  1
168617  95.932  -77.191  49.905  1
168618  95.923  -77.200  49.841  1
168619  95.915  -77.208  49.770  1
168620  95.906  -77.217  49.701  1
168621  95.913  -77.229  49.637  1
168622  95.924  -77.241  49.578  1
168623  95.937  -77.253  49.523  1
168624  95.953  -77.259  49.471  1
168625  95.969  -77.265  49.423  1
168626  95.985  -77.271  49.378  1
168627  96.002  -77.277  49.336  1
168628  96.018  -77.282  49.299  1
168629  96.034  -77.288  49.264  1
168630  96.050  -77.294  49.231  1
168631  96.066  -77.301  49.202  1
168632  96.083  -77.307  49.173  1
168633  96.099  -77.312  49.146  1
168634  96.115  -77.318  49.123  1
168635  96.132  -77.324  49.108  1
168636  96.148  -77.330  49.092  1
168637  96.169  -77.335  49.073  1
168638  96.193  -77.342  49.053  1
168639  96.218  -77.349  49.027  1
168640  96.242  -77.357  48.999  1
168641  96.267  -77.363  48.969  1
168642  96.291  -77.371  48.946  1
168643  96.316  -77.378  48.924  1
168644  96.340  -77.385  48.903  1
168645  96.365  -77.392  48.887  1
168646  96.389  -77.399  48.869  1
168647  96.409  -77.410  48.854  1
168648  96.426  -77.426  48.840  1
168649  96.442  -77.442  48.828  1
168650  96.459  -77.457  48.818  1
168651  96.475  -77.472  48.808  1
168652  96.491  -77.487  48.799  1
168653  96.508  -77.502  48.791  1
168654  96.524  -77.517  48.781  1
168655  96.538  -77.536  48.768  1
168656  96.548  -77.558  48.753  1
168657  96.558  -77.580  48.739  1
168658  96.569  -77.602  48.725  1
168659  96.580  -77.624  48.711  1
168660  96.590  -77.647  48.698  1
168661  96.600  -77.669  48.684  1
168662  96.620  -77.677  48.669  1
168663  96.641  -77.673  48.654  1
168664  96.662  -77.669  48.639  1
168665  96.683  -77.665  48.623  1
168666  96.704  -77.661  48.606  1
168667  96.725  -77.657  48.589  1
168668  96.746  -77.653  48.574  1
168669  96.767  -77.649  48.560  1
168670  96.789  -77.645  48.547  1
168671  96.810  -77.641  48.532  1
168672  96.835  -77.649  48.514  1
168673  96.865  -77.667  48.497  1
168674  96.894  -77.685  48.481  1
168675  96.924  -77.703  48.463  1
168676  96.948  -77.709  48.445  1
168677  96.961  -77.690  48.425  1
168678  96.974  -77.671  48.403  1
168679  96.986  -77.652  48.379  1
168680  96.999  -77.633  48.357  1
168681  97.012  -77.613  48.334  1
168682  97.025  -77.594  48.312  1
168683  97.037  -77.574  48.288  1
168684  97.051  -77.558  48.265  1
168685  97.071  -77.561  48.241  1
168686  97.089  -77.561  48.217  1
168687  97.097  -77.559  48.192  1
168688  97.104  -77.560  48.168  1
168689  97.115  -77.565  48.145  1
168690  97.143  -77.574  48.122  1
168691  97.170  -77.583  48.101  1
168692  97.197  -77.591  48.080  1
168693  97.225  -77.600  48.059  1
168694  97.251  -77.608  48.038  1
168695  97.275  -77.618  48.017  1
168696  97.298  -77.628  47.994  1
168697  97.322  -77.638  47.971  1
168698  97.345  -77.648  47.948  1
168699  97.369  -77.658  47.925  1
168700  97.392  -77.667  47.901  1
168701  97.415  -77.677  47.877  1
168702  97.439  -77.687  47.853  1
168703  97.462  -77.697  47.828  1
168704  97.486  -77.707  47.803  1
168705  97.504  -77.712  47.779  1
168706  97.508  -77.707  47.755  1
168707  97.526  -77.713  47.731  1
168708  97.546  -77.720  47.705  1
168709  97.566  -77.727  47.679  1
168710  97.585  -77.733  47.653  1
168711  97.605  -77.740  47.624  1
168712  97.625  -77.747  47.596  1
168713  97.644  -77.754  47.569  1
168714  97.679  -77.765  47.541  1
168715  97.717  -77.776  47.514  1
168716  97.756  -77.787  47.487  1
168717  97.794  -77.799  47.459  1
168718  97.833  -77.811  47.432  1
168719  97.867  -77.815  47.406  1
168720  97.882  -77.783  47.381  1
168721  97.845  -77.768  47.356  1
168722  97.808  -77.751  47.332  1
168723  97.771  -77.734  47.307  1
168724  97.754  -77.739  47.281  1
168725  97.783  -77.754  47.254  1
168726  97.815  -77.767  47.227  1
168727  97.847  -77.779  47.199  1
168728  97.881  -77.787  47.170  1
168729  97.910  -77.803  47.141  1
168730  97.917  -77.793  47.112  1
168731  97.924  -77.760  47.085  1
168732  97.963  -77.765  47.059  1
168733  98.018  -77.776  47.034  1
168734  98.037  -77.777  47.008  1
168735  98.056  -77.778  46.984  1
168736  98.075  -77.780  46.960  1
168737  98.094  -77.780  46.934  1
168738  98.113  -77.782  46.909  1
168739  98.133  -77.783  46.884  1
168740  98.152  -77.783  46.858  1
168741  98.155  -77.788  46.833  1
168742  98.160  -77.793  46.809  1
168743  98.174  -77.798  46.785  1
168744  98.195  -77.802  46.761  1
168745  98.217  -77.806  46.738  1
168746  98.238  -77.811  46.715  1
168747  98.260  -77.815  46.692  1
168748  98.281  -77.819  46.668  1
168749  98.302  -77.824  46.643  1
168750  98.324  -77.827  46.617  1
168751  98.346  -77.832  46.592  1
168752  98.367  -77.836  46.568  1
168753  98.387  -77.838  46.545  1
168754  98.404  -77.836  46.522  1
168755  98.420  -77.834  46.498  1
168756  98.436  -77.831  46.477  1
168757  98.452  -77.829  46.455  1
168758  98.468  -77.826  46.433  1
168759  98.485  -77.824  46.412  1
168760  98.528  -77.834  46.392  1
168761  98.547  -77.834  46.373  1
168762  98.561  -77.834  46.354  1
168763  98.570  -77.831  46.333  1
168764  98.573  -77.831  46.313  1
168765  98.577  -77.832  46.295  1
168766  98.580  -77.832  46.276  1
168767  98.583  -77.833  46.258  1
168768  98.586  -77.833  46.240  1
168769  98.589  -77.834  46.221  1
168770  98.593  -77.834  46.203  1
168771  98.608  -77.840  46.185  1
168772  98.627  -77.847  46.168  1
168773  98.646  -77.854  46.151  1
168774  98.664  -77.862  46.134  1
168775  98.683  -77.869  46.117  1
168776  98.702  -77.877  46.098  1
168777  98.720  -77.884  46.079  1
168778  98.739  -77.891  46.058  1
168779  98.764  -77.899  46.039  1
168780  98.806  -77.907  46.020  1
168781  98.848  -77.915  46.002  1
168782  98.890  -77.923  45.985  1
168783  98.950  -77.933  45.969  1
168784  99.031  -77.944  45.953  1
168785  99.087  -77.952  45.937  1
168786  99.112  -77.955  45.920  1
168787  99.136  -77.958  45.903  1
168788  99.161  -77.961  45.887  1
168789  99.186  -77.964  45.871  1
168790  99.211  -77.967  45.855  1
168791  99.235  -77.971  45.839  1
168792  99.259  -77.979  45.824  1
168793  99.283  -77.986  45.809  1
168794  99.307  -77.993  45.797  1
168795  99.331  -78.000  45.786  1
168796  99.344  -78.008  45.776  1
168797  99.357  -78.015  45.767  1
168798  99.370  -78.022  45.758  1
168799  99.383  -78.030  45.748  1
168800  99.396  -78.037  45.739  1
168801  99.406  -78.044  45.730  1
168802  99.414  -78.052  45.721  1
168803  99.423  -78.059  45.712  1
168804  99.438  -78.067  45.703  1
168805  99.469  -78.076  45.693  1
168806  99.496  -78.087  45.682  1
168807  99.523  -78.098  45.671  1
168808  99.551  -78.109  45.661  1
168809  99.577  -78.120  45.650  1
168810  99.606  -78.132  45.637  1
168811  99.637  -78.148  45.625  1
168812  99.667  -78.163  45.611  1
168813  99.698  -78.179  45.596  1
168814  99.728  -78.195  45.580  1
168815  99.759  -78.210  45.565  1
168816  99.790  -78.226  45.549  1
168817  99.807  -78.238  45.533  1
168818  99.822  -78.250  45.517  1
168819  99.835  -78.262  45.503  1
168820  99.849  -78.273  45.487  1
168821  99.865  -78.286  45.470  1
168822  99.885  -78.300  45.454  1
168823  99.904  -78.313  45.438  1
168824  99.923  -78.327  45.423  1
168825  99.943  -78.341  45.407  1
168826  99.962  -78.355  45.392  1
168827  99.982  -78.369  45.374  1
168828  100.006  -78.381  45.356  1
168829  100.030  -78.393  45.339  1
168830  100.054  -78.405  45.323  1
168831  100.078  -78.417  45.308  1
168832  100.102  -78.422  45.293  1
168833  100.126  -78.425  45.279  1
168834  100.150  -78.428  45.263  1
168835  100.179  -78.433  45.247  1
168836  100.216  -78.442  45.232  1
168837  100.254  -78.451  45.215  1
168838  100.291  -78.461  45.200  1
168839  100.328  -78.470  45.184  1
168840  100.366  -78.479  45.169  1
168841  100.403  -78.489  45.154  1
168842  100.440  -78.498  45.139  1
168843  100.478  -78.507  45.124  1
168844  100.515  -78.517  45.108  1
168845  100.552  -78.526  45.094  1
168846  100.590  -78.535  45.080  1
168847  100.627  -78.545  45.066  1
168848  100.681  -78.552  45.052  1
168849  100.682  -78.517  45.037  1
168850  100.708  -78.535  45.022  1
168851  100.736  -78.551  45.006  1
168852  100.764  -78.569  44.991  1
168853  100.792  -78.586  44.976  1
168854  100.821  -78.603  44.960  1
168855  100.849  -78.620  44.945  1
168856  100.878  -78.637  44.929  1
168857  100.907  -78.649  44.913  1
168858  100.941  -78.648  44.897  1
168859  100.974  -78.648  44.881  1
168860  101.006  -78.647  44.865  1
168861  101.035  -78.644  44.850  1
168862  101.063  -78.642  44.835  1
168863  101.091  -78.639  44.820  1
168864  101.119  -78.625  44.804  1
168865  101.164  -78.639  44.789  1
168866  101.209  -78.652  44.775  1
168867  101.249  -78.680  44.760  1
168868  101.287  -78.709  44.745  1
168869  101.316  -78.736  44.730  1
168870  101.326  -78.759  44.715  1
168871  101.336  -78.783  44.699  1
168872  101.346  -78.807  44.683  1
168873  101.356  -78.830  44.669  1
168874  101.366  -78.854  44.654  1
168875  101.376  -78.877  44.640  1
168876  101.401  -78.898  44.626  1
168877  101.443  -78.918  44.612  1
168878  101.485  -78.937  44.598  1
168879  101.528  -78.955  44.584  1
168880  101.570  -78.975  44.570  1
168881  101.612  -78.994  44.558  1
168882  101.654  -79.014  44.545  1
168883  101.681  -79.024  44.533  1
168884  101.698  -79.031  44.521  1
168885  101.714  -79.036  44.509  1
168886  101.732  -79.041  44.496  1
168887  101.748  -79.047  44.484  1
168888  101.765  -79.053  44.472  1
168889  101.781  -79.059  44.460  1
168890  101.799  -79.064  44.449  1
168891  101.815  -79.069  44.437  1
169118  92.584  -77.227  54.106  1
169119  92.607  -77.238  54.124  1
169120  92.630  -77.249  54.141  1
169121  92.653  -77.260  54.156  1
169122  92.676  -77.272  54.168  1
169123  92.700  -77.282  54.182  1
169124  92.722  -77.294  54.195  1
169125  92.742  -77.305  54.208  1
169126  92.749  -77.317  54.219  1
169127  92.756  -77.330  54.229  1
169128  92.763  -77.342  54.240  1
169129  92.771  -77.355  54.250  1
169130  92.778  -77.368  54.262  1
169131  92.785  -77.380  54.275  1
169132  92.792  -77.393  54.286  1
169133  92.811  -77.385  54.292  1
169134  92.832  -77.376  54.296  1
169135  92.852  -77.368  54.298  1
169136  92.872  -77.359  54.299  1
169137  92.892  -77.350  54.299  1
169138  92.912  -77.339  54.299  1
169139  92.931  -77.329  54.301  1
169140  92.950  -77.319  54.305  1
169141  92.972  -77.308  54.309  1
169142  92.997  -77.296  54.313  1
169143  93.022  -77.285  54.318  1
169144  93.048  -77.273  54.319  1
169145  93.073  -77.262  54.319  1
169146  93.099  -77.251  54.319  1
169147  93.121  -77.238  54.321  1
169148  93.131  -77.224  54.323  1
169149  93.141  -77.210  54.324  1
169150  93.151  -77.195  54.326  1
169151  93.161  -77.182  54.327  1
169152  93.178  -77.172  54.328  1
169153  93.195  -77.163  54.330  1
169154  93.213  -77.154  54.330  1
169155  93.231  -77.147  54.330  1
169156  93.242  -77.137  54.330  1
169157  93.253  -77.127  54.328  1
169158  93.263  -77.116  54.322  1
169159  93.273  -77.106  54.317  1
169160  93.283  -77.096  54.312  1
169161  93.293  -77.086  54.305  1
169162  93.303  -77.075  54.297  1
169163  93.332  -77.069  54.290  1
169164  93.367  -77.065  54.284  1
169165  93.402  -77.059  54.276  1
169166  93.431  -77.052  54.265  1
169167  93.461  -77.045  54.256  1
169168  93.491  -77.038  54.249  1
169169  93.520  -77.031  54.244  1
169170  93.540  -77.027  54.240  1
169171  93.551  -77.025  54.234  1
169172  93.561  -77.024  54.226  1
169173  93.571  -77.022  54.217  1
169174  93.590  -77.012  54.209  1
169175  93.608  -77.003  54.201  1
169176  93.621  -77.000  54.193  1
169177  93.634  -76.996  54.185  1
169178  93.646  -76.992  54.177  1
169179  93.659  -76.989  54.169  1
169180  93.672  -76.985  54.162  1
169181  93.685  -76.981  54.155  1
169182  93.698  -76.978  54.147  1
169183  93.710  -76.975  54.139  1
169184  93.717  -76.965  54.130  1
169185  93.721  -76.955  54.121  1
169186  93.726  -76.944  54.112  1
169187  93.731  -76.932  54.103  1
169188  93.739  -76.915  54.094  1
169189  93.748  -76.901  54.085  1
169190  93.766  -76.898  54.077  1
169191  93.790  -76.900  54.072  1
169192  93.819  -76.909  54.065  1
169193  93.847  -76.916  54.058  1
169194  93.876  -76.925  54.052  1
169195  93.905  -76.933  54.046  1
169196  93.928  -76.932  54.036  1
169197  93.945  -76.922  54.024  1
169198  93.963  -76.911  54.012  1
169199  93.980  -76.900  53.993  1
169200  93.997  -76.890  53.973  1
169201  94.014  -76.879  53.951  1
169202  94.032  -76.868  53.932  1
169203  94.049  -76.857  53.915  1
169204  94.063  -76.852  53.897  1
169205  94.074  -76.849  53.880  1
169206  94.088  -76.846  53.858  1
169207  94.102  -76.843  53.841  1
169208  94.116  -76.840  53.827  1
169209  94.129  -76.837  53.816  1
169210  94.143  -76.834  53.809  1
169211  94.157  -76.831  53.801  1
169212  94.171  -76.828  53.791  1
169213  94.186  -76.824  53.775  1
169214  94.197  -76.822  53.755  1
169215  94.203  -76.824  53.732  1
169216  94.208  -76.825  53.707  1
169217  94.214  -76.827  53.682  1
169218  94.220  -76.828  53.662  1
169219  94.226  -76.830  53.644  1
169220  94.232  -76.831  53.629  1
169221  94.248  -76.828  53.614  1
169222  94.277  -76.818  53.599  1
169223  94.307  -76.809  53.584  1
169224  94.335  -76.799  53.573  1
169225  94.357  -76.795  53.564  1
169226  94.374  -76.793  53.552  1
169227  94.391  -76.790  53.538  1
169228  94.409  -76.787  53.521  1
169229  94.427  -76.784  53.503  1
169230  94.445  -76.781  53.485  1
169231  94.463  -76.779  53.469  1
169232  94.481  -76.776  53.454  1
169233  94.498  -76.773  53.435  1
169234  94.513  -76.771  53.413  1
169235  94.528  -76.769  53.390  1
169236  94.538  -76.770  53.365  1
169237  94.539  -76.776  53.339  1
169238  94.539  -76.783  53.311  1
169239  94.540  -76.790  53.283  1
169240  94.540  -76.795  53.252  1
169241  94.546  -76.797  53.221  1
169242  94.596  -76.781  53.188  1
169243  94.647  -76.762  53.156  1
169244  94.698  -76.742  53.127  1
169245  94.750  -76.722  53.097  1
169246  94.793  -76.708  53.065  1
169247  94.830  -76.699  53.026  1
169248  94.849  -76.691  52.986  1
169249  94.861  -76.685  52.945  1
169250  94.873  -76.679  52.902  1
169251  94.885  -76.673  52.860  1
169252  94.896  -76.667  52.817  1
169253  94.908  -76.661  52.772  1
169254  94.920  -76.655  52.725  1
169255  94.932  -76.649  52.683  1
169256  94.944  -76.643  52.643  1
169257  94.956  -76.636  52.606  1
169258  94.967  -76.630  52.565  1
169259  94.979  -76.624  52.524  1
169260  94.991  -76.618  52.483  1
169261  95.003  -76.612  52.443  1
169262  95.015  -76.606  52.407  1
169263  95.028  -76.602  52.374  1
169264  95.060  -76.620  52.344  1
169265  95.094  -76.639  52.314  1
169266  95.127  -76.657  52.283  1
169267  95.161  -76.676  52.252  1
169268  95.194  -76.695  52.217  1
169269  95.228  -76.714  52.178  1
169270  95.261  -76.732  52.134  1
169271  95.276  -76.752  52.087  1
169272  95.275  -76.773  52.034  1
169273  95.273  -76.793  51.979  1
169274  95.272  -76.814  51.923  1
169275  95.271  -76.835  51.868  1
169276  95.277  -76.850  51.815  1
169277  95.287  -76.864  51.760  1
169278  95.298  -76.877  51.704  1
169279  95.312  -76.890  51.646  1
169280  95.329  -76.895  51.590  1
169281  95.348  -76.897  51.536  1
169282  95.367  -76.899  51.484  1
169283  95.384  -76.909  51.435  1
169284  95.400  -76.919  51.384  1
169285  95.417  -76.930  51.335  1
169286  95.434  -76.940  51.287  1
169287  95.451  -76.951  51.239  1
169288  95.468  -76.961  51.191  1
169289  95.485  -76.972  51.143  1
169290  95.502  -76.982  51.097  1
169291  95.524  -76.991  51.050  1
169292  95.555  -76.956  51.004  1
169293  95.574  -76.942  50.959  1
169294  95.582  -77.000  50.915  1
169295  95.601  -77.028  50.873  1
169296  95.620  -77.055  50.831  1
169297  95.639  -77.082  50.790  1
169298  95.654  -77.095  50.750  1
169299  95.664  -77.099  50.711  1
169300  95.675  -77.103  50.673  1
169301  95.686  -77.106  50.637  1
169302  95.694  -77.120  50.600  1
169303  95.699  -77.144  50.563  1
169304  95.705  -77.167  50.524  1
169305  95.710  -77.190  50.481  1
169306  95.718  -77.210  50.439  1
169307  95.731  -77.219  50.397  1
169308  95.744  -77.229  50.356  1
169309  95.757  -77.238  50.315  1
169310  95.772  -77.237  50.275  1
169311  95.791  -77.232  50.235  1
169312  95.816  -77.221  50.195  1
169313  95.841  -77.210  50.158  1
169314  95.867  -77.199  50.117  1
169315  95.892  -77.188  50.074  1
169316  95.917  -77.178  50.028  1
169317  95.940  -77.169  49.978  1
169318  95.931  -77.177  49.921  1
169319  95.922  -77.185  49.858  1
169320  95.914  -77.194  49.787  1
169321  95.910  -77.203  49.716  1
169322  95.921  -77.216  49.651  1
169323  95.933  -77.229  49.590  1
169324  95.945  -77.240  49.534  1
169325  95.961  -77.246  49.483  1
169326  95.978  -77.252  49.434  1
169327  95.994  -77.258  49.387  1
169328  96.010  -77.264  49.345  1
169329  96.026  -77.269  49.307  1
169330  96.043  -77.276  49.272  1
169331  96.059  -77.282  49.239  1
169332  96.075  -77.288  49.210  1
169333  96.092  -77.294  49.181  1
169334  96.108  -77.300  49.154  1
169335  96.124  -77.307  49.130  1
169336  96.142  -77.317  49.114  1
169337  96.159  -77.328  49.098  1
169338  96.178  -77.333  49.081  1
169339  96.198  -77.335  49.059  1
169340  96.223  -77.341  49.033  1
169341  96.247  -77.349  49.005  1
169342  96.271  -77.356  48.976  1
169343  96.296  -77.363  48.953  1
169344  96.321  -77.370  48.932  1
169345  96.345  -77.377  48.912  1
169346  96.370  -77.385  48.895  1
169347  96.394  -77.392  48.878  1
169348  96.411  -77.406  48.863  1
169349  96.428  -77.421  48.848  1
169350  96.444  -77.436  48.836  1
169351  96.461  -77.452  48.825  1
169352  96.477  -77.467  48.814  1
169353  96.493  -77.483  48.804  1
169354  96.510  -77.498  48.793  1
169355  96.526  -77.513  48.783  1
169356  96.543  -77.528  48.772  1
169357  96.555  -77.548  48.759  1
169358  96.565  -77.570  48.747  1
169359  96.576  -77.593  48.735  1
169360  96.586  -77.615  48.723  1
169361  96.596  -77.637  48.710  1
169362  96.610  -77.655  48.696  1
169363  96.633  -77.665  48.681  1
169364  96.656  -77.670  48.666  1
169365  96.677  -77.665  48.651  1
169366  96.698  -77.661  48.635  1
169367  96.719  -77.658  48.618  1
169368  96.740  -77.653  48.601  1
169369  96.761  -77.649  48.585  1
169370  96.783  -77.645  48.571  1
169371  96.804  -77.642  48.557  1
169372  96.825  -77.637  48.542  1
169373  96.854  -77.653  48.526  1
169374  96.883  -77.671  48.510  1
169375  96.912  -77.689  48.494  1
169376  96.942  -77.708  48.477  1
169377  96.971  -77.724  48.459  1
169378  96.984  -77.705  48.439  1
169379  96.997  -77.686  48.418  1
169380  97.009  -77.666  48.394  1
169381  97.022  -77.647  48.373  1
169382  97.035  -77.627  48.351  1
169383  97.047  -77.608  48.330  1
169384  97.060  -77.589  48.306  1
169385  97.073  -77.570  48.282  1
169386  97.085  -77.551  48.258  1
169387  97.098  -77.543  48.234  1
169388  97.106  -77.541  48.209  1
169389  97.113  -77.541  48.184  1
169390  97.137  -77.549  48.161  1
169391  97.165  -77.558  48.139  1
169392  97.189  -77.567  48.117  1
169393  97.213  -77.577  48.095  1
169394  97.236  -77.587  48.074  1
169395  97.259  -77.597  48.052  1
169396  97.283  -77.606  48.031  1
169397  97.306  -77.616  48.009  1
169398  97.329  -77.626  47.986  1
169399  97.353  -77.636  47.963  1
169400  97.376  -77.645  47.939  1
169401  97.399  -77.655  47.916  1
169402  97.423  -77.665  47.891  1
169403  97.446  -77.675  47.867  1
169404  97.470  -77.685  47.842  1
169405  97.493  -77.695  47.817  1
169406  97.516  -77.705  47.793  1
169407  97.523  -77.702  47.769  1
169408  97.528  -77.697  47.744  1
169409  97.548  -77.704  47.719  1
169410  97.568  -77.710  47.692  1
169411  97.587  -77.717  47.665  1
169412  97.607  -77.724  47.636  1
169413  97.626  -77.730  47.608  1
169414  97.657  -77.740  47.581  1
169415  97.696  -77.752  47.553  1
169416  97.734  -77.763  47.525  1
169417  97.773  -77.775  47.497  1
169418  97.811  -77.787  47.469  1
169419  97.850  -77.799  47.441  1
169420  97.888  -77.810  47.414  1
169421  97.860  -77.797  47.388  1
169422  97.822  -77.781  47.363  1
169423  97.785  -77.765  47.339  1
169424  97.748  -77.748  47.314  1
169425  97.731  -77.741  47.288  1
169426  97.772  -77.740  47.262  1
169427  97.812  -77.736  47.235  1
169428  97.853  -77.733  47.206  1
169429  97.894  -77.731  47.177  1
169430  97.926  -77.743  47.147  1
169431  97.952  -77.772  47.118  1
169432  97.983  -77.793  47.091  1
169433  97.984  -77.750  47.065  1
169434  98.025  -77.756  47.039  1
169435  98.069  -77.764  47.015  1
169436  98.088  -77.765  46.990  1
169437  98.107  -77.766  46.965  1
169438  98.126  -77.768  46.938  1
169439  98.145  -77.768  46.912  1
169440  98.164  -77.770  46.886  1
169441  98.176  -77.772  46.860  1
169442  98.177  -77.777  46.835  1
169443  98.180  -77.782  46.811  1
169444  98.190  -77.787  46.787  1
169445  98.205  -77.792  46.763  1
169446  98.227  -77.796  46.740  1
169447  98.248  -77.800  46.718  1
169448  98.270  -77.804  46.695  1
169449  98.291  -77.808  46.672  1
169450  98.312  -77.812  46.648  1
169451  98.334  -77.817  46.623  1
169452  98.355  -77.821  46.598  1
169453  98.378  -77.824  46.574  1
169454  98.405  -77.825  46.552  1
169455  98.427  -77.827  46.529  1
169456  98.450  -77.830  46.506  1
169457  98.468  -77.830  46.483  1
169458  98.485  -77.827  46.461  1
169459  98.501  -77.824  46.439  1
169460  98.519  -77.823  46.418  1
169461  98.550  -77.828  46.398  1
169462  98.565  -77.827  46.378  1
169463  98.579  -77.826  46.358  1
169464  98.585  -77.825  46.338  1
169465  98.588  -77.825  46.317  1
169466  98.591  -77.826  46.298  1
169467  98.595  -77.826  46.279  1
169468  98.598  -77.827  46.260  1
169469  98.601  -77.827  46.241  1
169470  98.604  -77.827  46.223  1
169471  98.608  -77.827  46.203  1
169472  98.611  -77.827  46.185  1
169473  98.629  -77.835  46.167  1
169474  98.648  -77.843  46.150  1
169475  98.666  -77.849  46.133  1
169476  98.685  -77.857  46.116  1
169477  98.704  -77.865  46.098  1
169478  98.722  -77.871  46.080  1
169479  98.741  -77.879  46.060  1
169480  98.776  -77.887  46.041  1
169481  98.818  -77.895  46.022  1
169482  98.860  -77.903  46.004  1
169483  98.902  -77.911  45.987  1
169484  98.962  -77.921  45.971  1
169485  99.044  -77.933  45.955  1
169486  99.076  -77.937  45.939  1
169487  99.101  -77.940  45.923  1
169488  99.126  -77.943  45.907  1
169489  99.150  -77.946  45.891  1
169490  99.175  -77.949  45.874  1
169491  99.199  -77.957  45.858  1
169492  99.223  -77.966  45.843  1
169493  99.244  -77.975  45.828  1
169494  99.265  -77.985  45.814  1
169495  99.288  -77.993  45.803  1
169496  99.311  -78.000  45.792  1
169497  99.333  -78.007  45.782  1
169498  99.346  -78.015  45.773  1
169499  99.359  -78.022  45.763  1
169500  99.372  -78.029  45.754  1
169501  99.385  -78.037  45.744  1
169502  99.399  -78.044  45.736  1
169503  99.412  -78.051  45.728  1
169504  99.421  -78.059  45.719  1
169505  99.440  -78.067  45.710  1
169506  99.467  -78.078  45.699  1
169507  99.494  -78.088  45.688  1
169508  99.521  -78.100  45.676  1
169509  99.549  -78.110  45.666  1
169510  99.575  -78.121  45.655  1
169511  99.605  -78.135  45.643  1
169512  99.636  -78.150  45.630  1
169513  99.666  -78.166  45.616  1
169514  99.697  -78.182  45.601  1
169515  99.727  -78.197  45.585  1
169516  99.758  -78.213  45.571  1
169517  99.789  -78.229  45.555  1
169518  99.817  -78.244  45.539  1
169519  99.831  -78.256  45.523  1
169520  99.845  -78.267  45.507  1
169521  99.859  -78.279  45.491  1
169522  99.878  -78.293  45.475  1
169523  99.898  -78.307  45.458  1
169524  99.917  -78.320  45.442  1
169525  99.936  -78.334  45.426  1
169526  99.956  -78.347  45.411  1
169527  99.975  -78.362  45.396  1
169528  99.994  -78.376  45.378  1
169529  100.017  -78.388  45.361  1
169530  100.041  -78.401  45.343  1
169531  100.065  -78.413  45.329  1
169532  100.089  -78.417  45.314  1
169533  100.113  -78.420  45.300  1
169534  100.137  -78.423  45.285  1
169535  100.161  -78.426  45.269  1
169536  100.186  -78.429  45.253  1
169537  100.216  -78.435  45.237  1
169538  100.254  -78.445  45.221  1
169539  100.291  -78.454  45.205  1
169540  100.329  -78.463  45.190  1
169541  100.366  -78.473  45.175  1
169542  100.403  -78.482  45.161  1
169543  100.440  -78.491  45.146  1
169544  100.478  -78.501  45.130  1
169545  100.515  -78.510  45.113  1
169546  100.553  -78.519  45.099  1
169547  100.590  -78.528  45.085  1
169548  100.632  -78.537  45.072  1
169549  100.690  -78.545  45.057  1
169550  100.748  -78.552  45.042  1
169551  100.732  -78.530  45.027  1
169552  100.738  -78.548  45.012  1
169553  100.766  -78.565  44.997  1
169554  100.794  -78.582  44.981  1
169555  100.823  -78.599  44.966  1
169556  100.851  -78.616  44.950  1
169557  100.879  -78.633  44.934  1
169558  100.910  -78.642  44.918  1
169559  100.944  -78.641  44.901  1
169560  100.977  -78.640  44.886  1
169561  101.010  -78.639  44.870  1
169562  101.040  -78.637  44.856  1
169563  101.068  -78.635  44.842  1
169564  101.096  -78.632  44.826  1
169565  101.124  -78.615  44.811  1
169566  101.170  -78.630  44.796  1
169567  101.215  -78.643  44.781  1
169568  101.258  -78.663  44.766  1
169569  101.297  -78.692  44.751  1
169570  101.318  -78.717  44.736  1
169571  101.327  -78.741  44.719  1
169572  101.337  -78.764  44.704  1
169573  101.347  -78.788  44.689  1
169574  101.357  -78.811  44.675  1
169575  101.368  -78.836  44.660  1
169576  101.378  -78.862  44.645  1
169577  101.403  -78.884  44.631  1
169578  101.443  -78.904  44.616  1
169579  101.485  -78.923  44.603  1
169580  101.527  -78.942  44.589  1
169581  101.569  -78.962  44.575  1
169582  101.612  -78.981  44.562  1
169583  101.654  -78.999  44.550  1
169584  101.682  -79.012  44.537  1
169585  101.699  -79.017  44.525  1
169586  101.715  -79.023  44.513  1
169587  101.732  -79.028  44.500  1
169588  101.749  -79.034  44.488  1
169589  101.766  -79.040  44.476  1
169590  101.782  -79.045  44.464  1
169591  101.799  -79.051  44.452  1
169592  101.816  -79.056  44.441  1
169593  101.833  -79.062  44.430  1
169820  92.594  -77.209  54.108  1
169821  92.618  -77.220  54.126  1
169822  92.641  -77.231  54.141  1
169823  92.664  -77.242  54.155  1
169824  92.687  -77.254  54.169  1
169825  92.710  -77.264  54.183  1
169826  92.733  -77.276  54.196  1
169827  92.742  -77.288  54.208  1
169828  92.749  -77.301  54.219  1
169829  92.757  -77.313  54.228  1
169830  92.764  -77.326  54.239  1
169831  92.771  -77.338  54.250  1
169832  92.778  -77.351  54.260  1
169833  92.785  -77.363  54.269  1
169834  92.801  -77.362  54.275  1
169835  92.821  -77.353  54.279  1
169836  92.841  -77.345  54.281  1
169837  92.862  -77.335  54.282  1
169838  92.882  -77.327  54.284  1
169839  92.902  -77.318  54.286  1
169840  92.923  -77.309  54.289  1
169841  92.942  -77.299  54.291  1
169842  92.961  -77.288  54.295  1
169843  92.981  -77.278  54.298  1
169844  93.001  -77.268  54.302  1
169845  93.020  -77.257  54.303  1
169846  93.040  -77.247  54.304  1
169847  93.064  -77.236  54.306  1
169848  93.089  -77.224  54.310  1
169849  93.115  -77.213  54.314  1
169850  93.135  -77.201  54.319  1
169851  93.145  -77.186  54.323  1
169852  93.155  -77.172  54.325  1
169853  93.171  -77.162  54.328  1
169854  93.190  -77.153  54.329  1
169855  93.208  -77.144  54.328  1
169856  93.219  -77.135  54.327  1
169857  93.229  -77.124  54.325  1
169858  93.239  -77.114  54.322  1
169859  93.250  -77.103  54.316  1
169860  93.260  -77.093  54.308  1
169861  93.270  -77.083  54.301  1
169862  93.280  -77.072  54.294  1
169863  93.290  -77.063  54.288  1
169864  93.319  -77.056  54.282  1
169865  93.354  -77.051  54.276  1
169866  93.389  -77.047  54.269  1
169867  93.420  -77.041  54.261  1
169868  93.450  -77.033  54.253  1
169869  93.480  -77.026  54.246  1
169870  93.505  -77.020  54.242  1
169871  93.525  -77.016  54.238  1
169872  93.544  -77.013  54.233  1
169873  93.554  -77.011  54.225  1
169874  93.564  -77.009  54.218  1
169875  93.585  -76.998  54.212  1
169876  93.598  -76.994  54.206  1
169877  93.611  -76.990  54.200  1
169878  93.624  -76.987  54.194  1
169879  93.636  -76.983  54.188  1
169880  93.649  -76.980  54.180  1
169881  93.662  -76.976  54.175  1
169882  93.675  -76.972  54.168  1
169883  93.688  -76.969  54.160  1
169884  93.700  -76.965  54.152  1
169885  93.712  -76.960  54.143  1
169886  93.716  -76.950  54.135  1
169887  93.722  -76.936  54.125  1
169888  93.729  -76.919  54.116  1
169889  93.737  -76.903  54.106  1
169890  93.748  -76.891  54.096  1
169891  93.767  -76.888  54.087  1
169892  93.785  -76.884  54.079  1
169893  93.813  -76.891  54.070  1
169894  93.841  -76.899  54.063  1
169895  93.870  -76.907  54.056  1
169896  93.899  -76.915  54.051  1
169897  93.924  -76.917  54.043  1
169898  93.940  -76.906  54.034  1
169899  93.958  -76.896  54.026  1
169900  93.975  -76.885  54.011  1
169901  93.992  -76.875  53.994  1
169902  94.009  -76.865  53.975  1
169903  94.026  -76.853  53.956  1
169904  94.043  -76.843  53.938  1
169905  94.057  -76.837  53.920  1
169906  94.070  -76.834  53.902  1
169907  94.084  -76.831  53.881  1
169908  94.098  -76.828  53.865  1
169909  94.112  -76.825  53.853  1
169910  94.125  -76.822  53.842  1
169911  94.139  -76.819  53.835  1
169912  94.153  -76.816  53.829  1
169913  94.166  -76.814  53.821  1
169914  94.174  -76.814  53.807  1
169915  94.179  -76.815  53.788  1
169916  94.185  -76.816  53.767  1
169917  94.191  -76.818  53.743  1
169918  94.197  -76.819  53.717  1
169919  94.203  -76.821  53.694  1
169920  94.209  -76.822  53.674  1
169921  94.215  -76.823  53.658  1
169922  94.240  -76.816  53.644  1
169923  94.269  -76.807  53.628  1
169924  94.297  -76.797  53.613  1
169925  94.327  -76.788  53.602  1
169926  94.353  -76.781  53.590  1
169927  94.370  -76.778  53.576  1
169928  94.387  -76.776  53.559  1
169929  94.405  -76.773  53.540  1
169930  94.423  -76.770  53.520  1
169931  94.441  -76.768  53.501  1
169932  94.459  -76.765  53.484  1
169933  94.477  -76.762  53.469  1
169934  94.495  -76.759  53.451  1
169935  94.511  -76.756  53.430  1
169936  94.527  -76.754  53.407  1
169937  94.531  -76.759  53.382  1
169938  94.531  -76.765  53.356  1
169939  94.532  -76.771  53.329  1
169940  94.533  -76.774  53.302  1
169941  94.533  -76.777  53.271  1
169942  94.548  -76.777  53.240  1
169943  94.597  -76.765  53.207  1
169944  94.648  -76.745  53.175  1
169945  94.700  -76.725  53.145  1
169946  94.751  -76.706  53.113  1
169947  94.790  -76.695  53.079  1
169948  94.826  -76.685  53.039  1
169949  94.845  -76.678  52.999  1
169950  94.857  -76.672  52.958  1
169951  94.869  -76.666  52.915  1
169952  94.881  -76.660  52.873  1
169953  94.893  -76.654  52.830  1
169954  94.904  -76.648  52.788  1
169955  94.916  -76.642  52.746  1
169956  94.928  -76.636  52.707  1
169957  94.940  -76.629  52.669  1
169958  94.952  -76.623  52.630  1
169959  94.964  -76.617  52.589  1
169960  94.975  -76.611  52.547  1
169961  94.987  -76.605  52.504  1
169962  94.999  -76.599  52.460  1
169963  95.011  -76.596  52.418  1
169964  95.036  -76.606  52.379  1
169965  95.061  -76.616  52.344  1
169966  95.092  -76.632  52.310  1
169967  95.125  -76.651  52.277  1
169968  95.159  -76.670  52.245  1
169969  95.192  -76.689  52.210  1
169970  95.226  -76.708  52.172  1
169971  95.253  -76.727  52.129  1
169972  95.251  -76.747  52.082  1
169973  95.250  -76.768  52.032  1
169974  95.248  -76.789  51.979  1
169975  95.253  -76.806  51.926  1
169976  95.263  -76.818  51.874  1
169977  95.272  -76.832  51.822  1
169978  95.282  -76.846  51.766  1
169979  95.293  -76.859  51.709  1
169980  95.308  -76.871  51.653  1
169981  95.322  -76.884  51.600  1
169982  95.341  -76.887  51.548  1
169983  95.359  -76.888  51.497  1
169984  95.378  -76.890  51.446  1
169985  95.397  -76.891  51.397  1
169986  95.414  -76.899  51.349  1
169987  95.431  -76.909  51.301  1
169988  95.448  -76.920  51.254  1
169989  95.465  -76.931  51.206  1
169990  95.482  -76.940  51.158  1
169991  95.498  -76.951  51.112  1
169992  95.522  -76.960  51.066  1
169993  95.549  -76.917  51.020  1
169994  95.552  -76.933  50.975  1
169995  95.561  -76.957  50.931  1
169996  95.580  -76.983  50.888  1
169997  95.599  -77.009  50.847  1
169998  95.618  -77.037  50.807  1
169999  95.637  -77.064  50.768  1
170000  95.656  -77.091  50.726  1
170001  95.667  -77.095  50.686  1
170002  95.678  -77.099  50.647  1
170003  95.686  -77.113  50.609  1
170004  95.691  -77.137  50.571  1
170005  95.697  -77.160  50.532  1
170006  95.710  -77.170  50.492  1
170007  95.723  -77.180  50.452  1
170008  95.736  -77.189  50.411  1
170009  95.749  -77.199  50.370  1
170010  95.762  -77.209  50.331  1
170011  95.776  -77.213  50.290  1
170012  95.792  -77.212  50.250  1
170013  95.807  -77.210  50.211  1
170014  95.826  -77.204  50.173  1
170015  95.851  -77.193  50.132  1
170016  95.877  -77.182  50.088  1
170017  95.902  -77.171  50.042  1
170018  95.927  -77.160  49.992  1
170019  95.930  -77.163  49.936  1
170020  95.921  -77.171  49.874  1
170021  95.913  -77.179  49.802  1
170022  95.918  -77.190  49.731  1
170023  95.930  -77.203  49.664  1
170024  95.942  -77.216  49.602  1
170025  95.954  -77.228  49.546  1
170026  95.970  -77.233  49.494  1
170027  95.986  -77.239  49.444  1
170028  96.003  -77.245  49.397  1
170029  96.019  -77.251  49.354  1
170030  96.035  -77.257  49.316  1
170031  96.051  -77.263  49.280  1
170032  96.068  -77.271  49.247  1
170033  96.085  -77.281  49.218  1
170034  96.102  -77.291  49.189  1
170035  96.119  -77.301  49.161  1
170036  96.136  -77.312  49.137  1
170037  96.154  -77.322  49.117  1
170038  96.171  -77.332  49.100  1
170039  96.191  -77.335  49.084  1
170040  96.212  -77.337  49.061  1
170041  96.232  -77.339  49.035  1
170042  96.252  -77.341  49.009  1
170043  96.276  -77.348  48.983  1
170044  96.301  -77.355  48.961  1
170045  96.325  -77.363  48.940  1
170046  96.350  -77.370  48.921  1
170047  96.375  -77.377  48.903  1
170048  96.397  -77.386  48.888  1
170049  96.413  -77.401  48.873  1
170050  96.430  -77.417  48.858  1
170051  96.446  -77.432  48.845  1
170052  96.463  -77.447  48.833  1
170053  96.479  -77.463  48.822  1
170054  96.496  -77.478  48.810  1
170055  96.512  -77.493  48.797  1
170056  96.528  -77.508  48.786  1
170057  96.545  -77.523  48.775  1
170058  96.561  -77.539  48.766  1
170059  96.572  -77.561  48.756  1
170060  96.582  -77.583  48.746  1
170061  96.592  -77.605  48.735  1
170062  96.603  -77.627  48.723  1
170063  96.623  -77.639  48.709  1
170064  96.647  -77.649  48.693  1
170065  96.670  -77.658  48.677  1
170066  96.692  -77.661  48.662  1
170067  96.714  -77.658  48.646  1
170068  96.734  -77.654  48.630  1
170069  96.755  -77.650  48.612  1
170070  96.777  -77.645  48.595  1
170071  96.798  -77.642  48.580  1
170072  96.819  -77.638  48.566  1
170073  96.842  -77.639  48.551  1
170074  96.872  -77.658  48.537  1
170075  96.901  -77.676  48.522  1
170076  96.931  -77.694  48.506  1
170077  96.960  -77.712  48.490  1
170078  96.990  -77.730  48.472  1
170079  97.007  -77.719  48.452  1
170080  97.019  -77.700  48.432  1
170081  97.032  -77.680  48.409  1
170082  97.044  -77.661  48.388  1
170083  97.056  -77.642  48.367  1
170084  97.061  -77.620  48.346  1
170085  97.065  -77.599  48.322  1
170086  97.070  -77.577  48.298  1
170087  97.074  -77.556  48.275  1
170088  97.079  -77.535  48.249  1
170089  97.095  -77.527  48.224  1
170090  97.127  -77.527  48.200  1
170091  97.150  -77.536  48.178  1
170092  97.173  -77.545  48.157  1
170093  97.197  -77.555  48.135  1
170094  97.220  -77.565  48.112  1
170095  97.243  -77.575  48.088  1
170096  97.267  -77.585  48.066  1
170097  97.290  -77.595  48.045  1
170098  97.314  -77.605  48.024  1
170099  97.337  -77.614  48.001  1
170100  97.361  -77.624  47.978  1
170101  97.384  -77.633  47.954  1
170102  97.407  -77.643  47.930  1
170103  97.431  -77.653  47.905  1
170104  97.454  -77.663  47.881  1
170105  97.477  -77.673  47.856  1
170106  97.501  -77.683  47.831  1
170107  97.524  -77.692  47.806  1
170108  97.539  -77.696  47.781  1
170109  97.543  -77.690  47.756  1
170110  97.550  -77.687  47.731  1
170111  97.570  -77.694  47.705  1
170112  97.589  -77.701  47.678  1
170113  97.608  -77.708  47.650  1
170114  97.635  -77.716  47.621  1
170115  97.673  -77.727  47.593  1
170116  97.712  -77.740  47.564  1
170117  97.751  -77.751  47.536  1
170118  97.789  -77.762  47.508  1
170119  97.827  -77.774  47.479  1
170120  97.864  -77.787  47.451  1
170121  97.900  -77.797  47.424  1
170122  97.889  -77.784  47.397  1
170123  97.850  -77.768  47.371  1
170124  97.812  -77.752  47.346  1
170125  97.773  -77.736  47.320  1
170126  97.751  -77.711  47.294  1
170127  97.784  -77.683  47.268  1
170128  97.825  -77.680  47.241  1
170129  97.866  -77.677  47.211  1
170130  97.907  -77.675  47.182  1
170131  97.941  -77.682  47.153  1
170132  97.968  -77.711  47.125  1
170133  98.003  -77.741  47.098  1
170134  98.037  -77.770  47.072  1
170135  98.045  -77.744  47.047  1
170136  98.086  -77.747  47.021  1
170137  98.120  -77.752  46.996  1
170138  98.139  -77.753  46.970  1
170139  98.158  -77.754  46.944  1
170140  98.177  -77.755  46.917  1
170141  98.196  -77.756  46.890  1
170142  98.199  -77.761  46.863  1
170143  98.201  -77.765  46.838  1
170144  98.203  -77.771  46.813  1
170145  98.211  -77.775  46.788  1
170146  98.220  -77.780  46.764  1
170147  98.236  -77.785  46.742  1
170148  98.258  -77.790  46.720  1
170149  98.280  -77.793  46.698  1
170150  98.301  -77.798  46.675  1
170151  98.322  -77.802  46.652  1
170152  98.344  -77.806  46.628  1
170153  98.365  -77.811  46.604  1
170154  98.398  -77.808  46.581  1
170155  98.421  -77.810  46.558  1
170156  98.443  -77.813  46.536  1
170157  98.465  -77.815  46.513  1
170158  98.488  -77.818  46.489  1
170159  98.511  -77.821  46.467  1
170160  98.533  -77.823  46.445  1
170161  98.554  -77.823  46.424  1
170162  98.568  -77.821  46.404  1
170163  98.583  -77.821  46.383  1
170164  98.597  -77.818  46.363  1
170165  98.600  -77.819  46.342  1
170166  98.603  -77.819  46.321  1
170167  98.606  -77.820  46.301  1
170168  98.610  -77.820  46.281  1
170169  98.613  -77.821  46.262  1
170170  98.617  -77.821  46.244  1
170171  98.620  -77.821  46.225  1
170172  98.623  -77.821  46.205  1
170173  98.626  -77.821  46.185  1
170174  98.631  -77.823  46.166  1
170175  98.650  -77.830  46.149  1
170176  98.668  -77.837  46.132  1
170177  98.687  -77.845  46.115  1
170178  98.706  -77.852  46.096  1
170179  98.724  -77.860  46.078  1
170180  98.746  -77.867  46.061  1
170181  98.788  -77.875  46.043  1
170182  98.830  -77.884  46.024  1
170183  98.872  -77.891  46.005  1
170184  98.914  -77.899  45.988  1
170185  98.975  -77.909  45.971  1
170186  99.041  -77.918  45.955  1
170187  99.065  -77.921  45.940  1
170188  99.090  -77.924  45.925  1
170189  99.115  -77.928  45.908  1
170190  99.139  -77.934  45.892  1
170191  99.163  -77.943  45.876  1
170192  99.187  -77.951  45.861  1
170193  99.211  -77.960  45.846  1
170194  99.233  -77.970  45.831  1
170195  99.253  -77.979  45.819  1
170196  99.274  -77.989  45.809  1
170197  99.294  -77.998  45.799  1
170198  99.316  -78.006  45.789  1
170199  99.336  -78.014  45.779  1
170200  99.349  -78.022  45.769  1
170201  99.362  -78.028  45.759  1
170202  99.375  -78.036  45.750  1
170203  99.388  -78.044  45.742  1
170204  99.401  -78.050  45.734  1
170205  99.415  -78.057  45.725  1
170206  99.439  -78.067  45.716  1
170207  99.465  -78.079  45.705  1
170208  99.492  -78.090  45.694  1
170209  99.519  -78.100  45.683  1
170210  99.546  -78.112  45.672  1
170211  99.573  -78.122  45.660  1
170212  99.604  -78.138  45.648  1
170213  99.635  -78.153  45.635  1
170214  99.665  -78.169  45.621  1
170215  99.696  -78.184  45.606  1
170216  99.726  -78.200  45.591  1
170217  99.757  -78.216  45.577  1
170218  99.788  -78.232  45.562  1
170219  99.819  -78.247  45.546  1
170220  99.841  -78.261  45.529  1
170221  99.855  -78.272  45.512  1
170222  99.872  -78.285  45.496  1
170223  99.892  -78.299  45.481  1
170224  99.911  -78.313  45.464  1
170225  99.930  -78.327  45.447  1
170226  99.949  -78.341  45.430  1
170227  99.969  -78.354  45.414  1
170228  99.988  -78.368  45.399  1
170229  100.007  -78.382  45.382  1
170230  100.028  -78.395  45.365  1
170231  100.051  -78.408  45.350  1
170232  100.075  -78.413  45.335  1
170233  100.100  -78.416  45.320  1
170234  100.124  -78.419  45.305  1
170235  100.148  -78.422  45.291  1
170236  100.173  -78.425  45.274  1
170237  100.197  -78.428  45.258  1
170238  100.221  -78.431  45.243  1
170239  100.254  -78.438  45.227  1
170240  100.291  -78.447  45.212  1
170241  100.329  -78.456  45.197  1
170242  100.366  -78.466  45.182  1
170243  100.403  -78.475  45.168  1
170244  100.440  -78.484  45.152  1
170245  100.478  -78.493  45.136  1
170246  100.515  -78.503  45.120  1
170247  100.553  -78.512  45.106  1
170248  100.590  -78.521  45.092  1
170249  100.641  -78.529  45.078  1
170250  100.699  -78.537  45.063  1
170251  100.758  -78.545  45.048  1
170252  100.795  -78.524  45.033  1
170253  100.781  -78.542  45.018  1
170254  100.768  -78.561  45.002  1
170255  100.796  -78.578  44.987  1
170256  100.824  -78.595  44.971  1
170257  100.853  -78.612  44.955  1
170258  100.881  -78.629  44.939  1
170259  100.913  -78.634  44.922  1
170260  100.946  -78.633  44.906  1
170261  100.980  -78.633  44.892  1
170262  101.013  -78.632  44.877  1
170263  101.045  -78.630  44.863  1
170264  101.073  -78.628  44.849  1
170265  101.101  -78.621  44.832  1
170266  101.130  -78.606  44.818  1
170267  101.176  -78.620  44.803  1
170268  101.221  -78.634  44.787  1
170269  101.266  -78.648  44.771  1
170270  101.306  -78.675  44.756  1
170271  101.319  -78.698  44.740  1
170272  101.329  -78.722  44.725  1
170273  101.339  -78.746  44.709  1
170274  101.349  -78.772  44.695  1
170275  101.360  -78.798  44.680  1
170276  101.370  -78.824  44.665  1
170277  101.389  -78.846  44.651  1
170278  101.415  -78.868  44.636  1
170279  101.442  -78.890  44.622  1
170280  101.484  -78.909  44.608  1
170281  101.527  -78.928  44.594  1
170282  101.569  -78.948  44.580  1
170283  101.611  -78.967  44.566  1
170284  101.653  -78.986  44.554  1
170285  101.683  -78.998  44.541  1
170286  101.699  -79.004  44.529  1
170287  101.716  -79.009  44.517  1
170288  101.733  -79.015  44.504  1
170289  101.750  -79.021  44.491  1
170290  101.766  -79.027  44.479  1
170291  101.783  -79.032  44.467  1
170292  101.800  -79.037  44.456  1
170293  101.817  -79.043  44.444  1
170294  101.833  -79.049  44.434  1
170295  101.850  -79.055  44.421  1
170523  92.628  -77.202  54.125  1
170524  92.651  -77.213  54.139  1
170525  92.674  -77.224  54.153  1
170526  92.697  -77.235  54.168  1
170527  92.720  -77.247  54.181  1
170528  92.736  -77.258  54.193  1
170529  92.743  -77.271  54.204  1
170530  92.750  -77.283  54.214  1
170531  92.757  -77.296  54.224  1
170532  92.764  -77.308  54.234  1
170533  92.771  -77.321  54.243  1
170534  92.778  -77.334  54.252  1
170535  92.790  -77.338  54.257  1
170536  92.810  -77.329  54.261  1
170537  92.831  -77.320  54.265  1
170538  92.851  -77.312  54.267  1
170539  92.871  -77.303  54.269  1
170540  92.892  -77.294  54.272  1
170541  92.912  -77.285  54.275  1
170542  92.932  -77.277  54.278  1
170543  92.953  -77.268  54.281  1
170544  92.973  -77.258  54.284  1
170545  92.992  -77.248  54.287  1
170546  93.012  -77.238  54.289  1
170547  93.031  -77.227  54.291  1
170548  93.051  -77.217  54.293  1
170549  93.070  -77.207  54.298  1
170550  93.090  -77.196  54.304  1
170551  93.109  -77.186  54.310  1
170552  93.130  -77.175  54.315  1
170553  93.149  -77.163  54.319  1
170554  93.165  -77.152  54.323  1
170555  93.183  -77.139  54.325  1
170556  93.201  -77.126  54.324  1
170557  93.213  -77.116  54.322  1
170558  93.217  -77.110  54.321  1
170559  93.226  -77.100  54.317  1
170560  93.236  -77.091  54.310  1
170561  93.246  -77.080  54.301  1
170562  93.256  -77.070  54.293  1
170563  93.266  -77.059  54.286  1
170564  93.276  -77.050  54.281  1
170565  93.305  -77.043  54.275  1
170566  93.340  -77.038  54.269  1
170567  93.375  -77.034  54.264  1
170568  93.409  -77.028  54.258  1
170569  93.439  -77.021  54.253  1
170570  93.469  -77.014  54.248  1
170571  93.489  -77.010  54.244  1
170572  93.510  -77.006  54.241  1
170573  93.531  -77.002  54.237  1
170574  93.547  -76.999  54.231  1
170575  93.558  -76.997  54.225  1
170576  93.575  -76.988  54.221  1
170577  93.588  -76.985  54.216  1
170578  93.601  -76.981  54.212  1
170579  93.614  -76.978  54.208  1
170580  93.626  -76.974  54.202  1
170581  93.639  -76.971  54.195  1
170582  93.652  -76.967  54.190  1
170583  93.664  -76.963  54.183  1
170584  93.678  -76.959  54.175  1
170585  93.690  -76.956  54.167  1
170586  93.703  -76.951  54.159  1
170587  93.713  -76.940  54.151  1
170588  93.721  -76.924  54.141  1
170589  93.728  -76.907  54.131  1
170590  93.735  -76.890  54.121  1
170591  93.749  -76.881  54.110  1
170592  93.767  -76.878  54.099  1
170593  93.785  -76.875  54.088  1
170594  93.806  -76.874  54.078  1
170595  93.835  -76.881  54.068  1
170596  93.864  -76.890  54.061  1
170597  93.893  -76.898  54.056  1
170598  93.919  -76.902  54.049  1
170599  93.936  -76.891  54.043  1
170600  93.953  -76.881  54.036  1
170601  93.970  -76.870  54.024  1
170602  93.987  -76.859  54.010  1
170603  94.004  -76.849  53.994  1
170604  94.021  -76.839  53.976  1
170605  94.038  -76.828  53.959  1
170606  94.052  -76.823  53.942  1
170607  94.065  -76.821  53.924  1
170608  94.077  -76.819  53.904  1
170609  94.090  -76.817  53.888  1
170610  94.103  -76.815  53.876  1
170611  94.115  -76.814  53.867  1
170612  94.127  -76.812  53.860  1
170613  94.140  -76.810  53.854  1
170614  94.153  -76.808  53.847  1
170615  94.171  -76.805  53.835  1
170616  94.162  -76.808  53.819  1
170617  94.168  -76.809  53.799  1
170618  94.174  -76.810  53.777  1
170619  94.180  -76.812  53.753  1
170620  94.186  -76.813  53.729  1
170621  94.192  -76.815  53.707  1
170622  94.202  -76.814  53.688  1
170623  94.230  -76.805  53.676  1
170624  94.260  -76.796  53.661  1
170625  94.289  -76.786  53.646  1
170626  94.318  -76.777  53.633  1
170627  94.347  -76.768  53.619  1
170628  94.366  -76.764  53.602  1
170629  94.384  -76.762  53.582  1
170630  94.401  -76.759  53.560  1
170631  94.419  -76.755  53.538  1
170632  94.437  -76.753  53.517  1
170633  94.456  -76.750  53.498  1
170634  94.473  -76.747  53.482  1
170635  94.491  -76.745  53.464  1
170636  94.509  -76.742  53.444  1
170637  94.523  -76.741  53.422  1
170638  94.524  -76.746  53.398  1
170639  94.524  -76.749  53.373  1
170640  94.525  -76.752  53.346  1
170641  94.525  -76.756  53.320  1
170642  94.526  -76.759  53.289  1
170643  94.551  -76.758  53.257  1
170644  94.598  -76.748  53.225  1
170645  94.649  -76.728  53.194  1
170646  94.701  -76.709  53.162  1
170647  94.750  -76.691  53.130  1
170648  94.786  -76.681  53.093  1
170649  94.823  -76.672  53.053  1
170650  94.841  -76.665  53.012  1
170651  94.853  -76.658  52.970  1
170652  94.865  -76.652  52.927  1
170653  94.877  -76.646  52.886  1
170654  94.889  -76.640  52.845  1
170655  94.900  -76.634  52.806  1
170656  94.912  -76.628  52.768  1
170657  94.924  -76.622  52.732  1
170658  94.936  -76.616  52.695  1
170659  94.948  -76.610  52.656  1
170660  94.960  -76.604  52.615  1
170661  94.971  -76.598  52.573  1
170662  94.980  -76.592  52.528  1
170663  94.992  -76.590  52.481  1
170664  95.018  -76.600  52.436  1
170665  95.043  -76.610  52.391  1
170666  95.068  -76.620  52.349  1
170667  95.093  -76.629  52.312  1
170668  95.124  -76.645  52.277  1
170669  95.158  -76.664  52.242  1
170670  95.191  -76.683  52.205  1
170671  95.224  -76.701  52.166  1
170672  95.228  -76.721  52.124  1
170673  95.226  -76.743  52.079  1
170674  95.229  -76.760  52.031  1
170675  95.239  -76.774  51.982  1
170676  95.248  -76.787  51.931  1
170677  95.258  -76.801  51.880  1
170678  95.267  -76.814  51.826  1
170679  95.276  -76.828  51.770  1
170680  95.288  -76.840  51.715  1
170681  95.304  -76.853  51.662  1
170682  95.318  -76.866  51.611  1
170683  95.334  -76.877  51.561  1
170684  95.352  -76.878  51.511  1
170685  95.371  -76.880  51.462  1
170686  95.390  -76.881  51.414  1
170687  95.408  -76.883  51.366  1
170688  95.427  -76.884  51.318  1
170689  95.445  -76.889  51.271  1
170690  95.462  -76.900  51.223  1
170691  95.479  -76.910  51.176  1
170692  95.495  -76.920  51.130  1
170693  95.519  -76.929  51.085  1
170694  95.534  -76.906  51.039  1
170695  95.543  -76.931  50.993  1
170696  95.558  -76.950  50.948  1
170697  95.573  -76.969  50.905  1
170698  95.589  -76.988  50.863  1
170699  95.604  -77.008  50.823  1
170700  95.619  -77.027  50.783  1
170701  95.634  -77.047  50.743  1
170702  95.654  -77.073  50.703  1
170703  95.670  -77.091  50.664  1
170704  95.678  -77.106  50.625  1
170705  95.688  -77.120  50.586  1
170706  95.701  -77.130  50.546  1
170707  95.714  -77.140  50.507  1
170708  95.728  -77.150  50.467  1
170709  95.741  -77.159  50.427  1
170710  95.754  -77.169  50.387  1
170711  95.767  -77.179  50.347  1
170712  95.780  -77.188  50.307  1
170713  95.795  -77.188  50.267  1
170714  95.810  -77.186  50.226  1
170715  95.825  -77.185  50.186  1
170716  95.840  -77.183  50.144  1
170717  95.861  -77.176  50.101  1
170718  95.886  -77.165  50.056  1
170719  95.911  -77.154  50.006  1
170720  95.930  -77.147  49.952  1
170721  95.921  -77.156  49.891  1
170722  95.915  -77.165  49.818  1
170723  95.927  -77.178  49.746  1
170724  95.939  -77.190  49.678  1
170725  95.950  -77.203  49.614  1
170726  95.962  -77.215  49.558  1
170727  95.978  -77.220  49.504  1
170728  95.994  -77.226  49.454  1
170729  96.011  -77.235  49.408  1
170730  96.029  -77.244  49.365  1
170731  96.046  -77.255  49.326  1
170732  96.063  -77.265  49.290  1
170733  96.080  -77.275  49.256  1
170734  96.097  -77.285  49.226  1
170735  96.114  -77.295  49.197  1
170736  96.131  -77.306  49.168  1
170737  96.149  -77.316  49.141  1
170738  96.166  -77.326  49.120  1
170739  96.183  -77.335  49.100  1
170740  96.204  -77.338  49.080  1
170741  96.224  -77.339  49.060  1
170742  96.245  -77.341  49.036  1
170743  96.265  -77.344  49.013  1
170744  96.286  -77.346  48.990  1
170745  96.306  -77.348  48.969  1
170746  96.330  -77.355  48.950  1
170747  96.355  -77.362  48.931  1
170748  96.379  -77.370  48.914  1
170749  96.399  -77.382  48.899  1
170750  96.415  -77.397  48.883  1
170751  96.432  -77.412  48.868  1
170752  96.448  -77.427  48.855  1
170753  96.465  -77.442  48.842  1
170754  96.481  -77.457  48.830  1
170755  96.498  -77.473  48.818  1
170756  96.514  -77.489  48.804  1
170757  96.530  -77.504  48.791  1
170758  96.547  -77.519  48.780  1
170759  96.564  -77.534  48.771  1
170760  96.578  -77.551  48.763  1
170761  96.589  -77.573  48.755  1
170762  96.599  -77.595  48.747  1
170763  96.613  -77.614  48.737  1
170764  96.637  -77.624  48.723  1
170765  96.660  -77.633  48.706  1
170766  96.683  -77.642  48.689  1
170767  96.706  -77.652  48.672  1
170768  96.729  -77.654  48.657  1
170769  96.749  -77.650  48.641  1
170770  96.770  -77.646  48.623  1
170771  96.792  -77.642  48.607  1
170772  96.813  -77.638  48.592  1
170773  96.834  -77.634  48.576  1
170774  96.861  -77.644  48.561  1
170775  96.890  -77.662  48.546  1
170776  96.920  -77.680  48.531  1
170777  96.949  -77.699  48.516  1
170778  96.979  -77.717  48.499  1
170779  97.008  -77.735  48.482  1
170780  97.023  -77.724  48.464  1
170781  97.029  -77.702  48.445  1
170782  97.035  -77.680  48.424  1
170783  97.040  -77.657  48.403  1
170784  97.046  -77.635  48.382  1
170785  97.052  -77.612  48.361  1
170786  97.058  -77.590  48.336  1
170787  97.064  -77.567  48.313  1
170788  97.070  -77.545  48.289  1
170789  97.079  -77.533  48.264  1
170790  97.095  -77.523  48.239  1
170791  97.136  -77.521  48.216  1
170792  97.160  -77.529  48.194  1
170793  97.182  -77.537  48.172  1
170794  97.205  -77.545  48.149  1
170795  97.228  -77.553  48.126  1
170796  97.251  -77.563  48.103  1
170797  97.275  -77.573  48.081  1
170798  97.298  -77.583  48.059  1
170799  97.321  -77.592  48.037  1
170800  97.345  -77.602  48.015  1
170801  97.368  -77.612  47.991  1
170802  97.391  -77.621  47.968  1
170803  97.415  -77.631  47.943  1
170804  97.438  -77.641  47.919  1
170805  97.461  -77.651  47.894  1
170806  97.485  -77.661  47.868  1
170807  97.508  -77.671  47.843  1
170808  97.532  -77.680  47.817  1
170809  97.555  -77.690  47.792  1
170810  97.559  -77.685  47.767  1
170811  97.563  -77.680  47.742  1
170812  97.572  -77.677  47.716  1
170813  97.591  -77.684  47.688  1
170814  97.613  -77.692  47.661  1
170815  97.652  -77.703  47.632  1
170816  97.690  -77.715  47.604  1
170817  97.728  -77.727  47.575  1
170818  97.766  -77.739  47.546  1
170819  97.803  -77.751  47.518  1
170820  97.840  -77.763  47.490  1
170821  97.877  -77.775  47.461  1
170822  97.910  -77.782  47.433  1
170823  97.918  -77.771  47.405  1
170824  97.879  -77.755  47.379  1
170825  97.841  -77.740  47.353  1
170826  97.802  -77.724  47.327  1
170827  97.778  -77.699  47.300  1
170828  97.803  -77.645  47.274  1
170829  97.838  -77.624  47.247  1
170830  97.879  -77.621  47.217  1
170831  97.920  -77.618  47.188  1
170832  97.957  -77.621  47.159  1
170833  97.984  -77.651  47.131  1
170834  98.019  -77.680  47.104  1
170835  98.053  -77.709  47.078  1
170836  98.088  -77.739  47.053  1
170837  98.110  -77.743  47.028  1
170838  98.148  -77.738  47.002  1
170839  98.170  -77.740  46.977  1
170840  98.190  -77.741  46.951  1
170841  98.209  -77.743  46.922  1
170842  98.220  -77.745  46.894  1
170843  98.222  -77.749  46.867  1
170844  98.224  -77.754  46.841  1
170845  98.226  -77.759  46.815  1
170846  98.231  -77.764  46.790  1
170847  98.241  -77.769  46.766  1
170848  98.250  -77.774  46.744  1
170849  98.268  -77.779  46.721  1
170850  98.289  -77.783  46.699  1
170851  98.311  -77.787  46.677  1
170852  98.332  -77.791  46.655  1
170853  98.354  -77.796  46.632  1
170854  98.383  -77.794  46.609  1
170855  98.414  -77.793  46.587  1
170856  98.436  -77.796  46.563  1
170857  98.459  -77.798  46.541  1
170858  98.482  -77.801  46.518  1
170859  98.504  -77.803  46.495  1
170860  98.527  -77.806  46.472  1
170861  98.550  -77.808  46.450  1
170862  98.568  -77.813  46.429  1
170863  98.587  -77.815  46.408  1
170864  98.601  -77.814  46.387  1
170865  98.612  -77.812  46.367  1
170866  98.615  -77.813  46.346  1
170867  98.619  -77.813  46.324  1
170868  98.622  -77.814  46.304  1
170869  98.625  -77.814  46.284  1
170870  98.628  -77.815  46.265  1
170871  98.631  -77.815  46.246  1
170872  98.635  -77.815  46.226  1
170873  98.638  -77.815  46.206  1
170874  98.641  -77.815  46.185  1
170875  98.644  -77.816  46.167  1
170876  98.652  -77.818  46.148  1
170877  98.670  -77.825  46.130  1
170878  98.689  -77.833  46.113  1
170879  98.708  -77.840  46.095  1
170880  98.726  -77.848  46.077  1
170881  98.758  -77.855  46.059  1
170882  98.800  -77.863  46.042  1
170883  98.842  -77.871  46.024  1
170884  98.884  -77.879  46.006  1
170885  98.926  -77.887  45.988  1
170886  98.988  -77.897  45.971  1
170887  99.029  -77.903  45.955  1
170888  99.055  -77.906  45.940  1
170889  99.079  -77.910  45.925  1
170890  99.103  -77.919  45.909  1
170891  99.127  -77.928  45.894  1
170892  99.150  -77.937  45.877  1
170893  99.174  -77.946  45.863  1
170894  99.198  -77.955  45.849  1
170895  99.221  -77.964  45.835  1
170896  99.242  -77.974  45.824  1
170897  99.262  -77.983  45.815  1
170898  99.283  -77.993  45.806  1
170899  99.303  -78.003  45.795  1
170900  99.324  -78.012  45.785  1
170901  99.340  -78.020  45.774  1
170902  99.354  -78.027  45.764  1
170903  99.368  -78.034  45.755  1
170904  99.382  -78.040  45.747  1
170905  99.397  -78.048  45.739  1
170906  99.411  -78.055  45.731  1
170907  99.439  -78.060  45.722  1
170908  99.471  -78.070  45.712  1
170909  99.494  -78.086  45.701  1
170910  99.517  -78.102  45.690  1
170911  99.544  -78.112  45.677  1
170912  99.572  -78.125  45.665  1
170913  99.603  -78.141  45.653  1
170914  99.633  -78.156  45.639  1
170915  99.664  -78.172  45.625  1
170916  99.695  -78.188  45.610  1
170917  99.725  -78.203  45.596  1
170918  99.756  -78.219  45.581  1
170919  99.787  -78.235  45.567  1
170920  99.818  -78.250  45.551  1
170921  99.848  -78.266  45.535  1
170922  99.866  -78.279  45.519  1
170923  99.885  -78.292  45.503  1
170924  99.904  -78.306  45.486  1
170925  99.924  -78.319  45.470  1
170926  99.943  -78.333  45.453  1
170927  99.962  -78.347  45.436  1
170928  99.982  -78.361  45.420  1
170929  100.001  -78.375  45.404  1
170930  100.020  -78.388  45.388  1
170931  100.039  -78.402  45.372  1
170932  100.062  -78.407  45.357  1
170933  100.086  -78.410  45.342  1
170934  100.111  -78.413  45.327  1
170935  100.135  -78.416  45.312  1
170936  100.159  -78.420  45.297  1
170937  100.184  -78.423  45.281  1
170938  100.208  -78.426  45.265  1
170939  100.232  -78.429  45.249  1
170940  100.257  -78.432  45.234  1
170941  100.291  -78.440  45.219  1
170942  100.329  -78.449  45.205  1
170943  100.366  -78.459  45.190  1
170944  100.403  -78.468  45.175  1
170945  100.440  -78.477  45.159  1
170946  100.478  -78.486  45.143  1
170947  100.515  -78.496  45.127  1
170948  100.553  -78.505  45.115  1
170949  100.592  -78.514  45.100  1
170950  100.650  -78.522  45.085  1
170951  100.709  -78.529  45.070  1
170952  100.767  -78.536  45.054  1
170953  100.825  -78.544  45.039  1
170954  100.844  -78.537  45.024  1
170955  100.830  -78.555  45.008  1
170956  100.816  -78.573  44.992  1
170957  100.826  -78.591  44.976  1
170958  100.854  -78.608  44.961  1
170959  100.882  -78.625  44.945  1
170960  100.915  -78.626  44.928  1
170961  100.949  -78.626  44.913  1
170962  100.982  -78.625  44.899  1
170963  101.016  -78.624  44.884  1
170964  101.049  -78.623  44.870  1
170965  101.078  -78.621  44.855  1
170966  101.106  -78.610  44.839  1
170967  101.136  -78.597  44.824  1
170968  101.182  -78.611  44.808  1
170969  101.227  -78.625  44.793  1
170970  101.272  -78.639  44.777  1
170971  101.310  -78.657  44.762  1
170972  101.321  -78.682  44.746  1
170973  101.331  -78.708  44.730  1
170974  101.341  -78.733  44.715  1
170975  101.352  -78.758  44.701  1
170976  101.362  -78.784  44.686  1
170977  101.376  -78.809  44.671  1
170978  101.401  -78.831  44.656  1
170979  101.427  -78.852  44.642  1
170980  101.453  -78.874  44.627  1
170981  101.484  -78.896  44.612  1
170982  101.527  -78.915  44.598  1
170983  101.568  -78.933  44.584  1
170984  101.611  -78.953  44.571  1
170985  101.653  -78.972  44.559  1
170986  101.683  -78.985  44.546  1
170987  101.700  -78.990  44.533  1
170988  101.717  -78.996  44.521  1
170989  101.734  -79.002  44.508  1
170990  101.751  -79.008  44.496  1
170991  101.767  -79.013  44.483  1
170992  101.784  -79.019  44.471  1
170993  101.801  -79.024  44.460  1
170994  101.818  -79.030  44.449  1
170995  101.834  -79.036  44.437  1
170996  101.851  -79.041  44.425  1
170997  101.868  -79.047  44.413  1
171225  92.639  -77.184  54.122  1
171226  92.661  -77.195  54.136  1
171227  92.685  -77.207  54.151  1
171228  92.708  -77.217  54.164  1
171229  92.729  -77.229  54.176  1
171230  92.736  -77.241  54.187  1
171231  92.743  -77.254  54.197  1
171232  92.750  -77.266  54.207  1
171233  92.757  -77.279  54.216  1
171234  92.764  -77.291  54.226  1
171235  92.772  -77.304  54.233  1
171236  92.780  -77.314  54.239  1
171237  92.800  -77.306  54.244  1
171238  92.820  -77.297  54.247  1
171239  92.841  -77.288  54.250  1
171240  92.861  -77.279  54.253  1
171241  92.881  -77.271  54.256  1
171242  92.902  -77.262  54.260  1
171243  92.922  -77.253  54.263  1
171244  92.942  -77.244  54.266  1
171245  92.963  -77.235  54.269  1
171246  92.983  -77.227  54.272  1
171247  93.003  -77.218  54.275  1
171248  93.023  -77.207  54.278  1
171249  93.042  -77.197  54.281  1
171250  93.062  -77.187  54.286  1
171251  93.081  -77.176  54.292  1
171252  93.101  -77.166  54.299  1
171253  93.120  -77.156  54.304  1
171254  93.140  -77.145  54.310  1
171255  93.159  -77.135  54.315  1
171256  93.176  -77.122  54.318  1
171257  93.194  -77.109  54.317  1
171258  93.207  -77.097  54.317  1
171259  93.211  -77.091  54.316  1
171260  93.216  -77.085  54.313  1
171261  93.222  -77.078  54.304  1
171262  93.232  -77.067  54.295  1
171263  93.243  -77.056  54.286  1
171264  93.253  -77.047  54.279  1
171265  93.263  -77.036  54.275  1
171266  93.291  -77.030  54.271  1
171267  93.327  -77.025  54.267  1
171268  93.362  -77.021  54.263  1
171269  93.398  -77.016  54.260  1
171270  93.428  -77.009  54.257  1
171271  93.453  -77.003  54.254  1
171272  93.474  -77.000  54.251  1
171273  93.495  -76.996  54.249  1
171274  93.516  -76.991  54.246  1
171275  93.537  -76.987  54.241  1
171276  93.553  -76.983  54.235  1
171277  93.565  -76.979  54.231  1
171278  93.578  -76.976  54.228  1
171279  93.591  -76.972  54.227  1
171280  93.604  -76.967  54.224  1
171281  93.617  -76.962  54.218  1
171282  93.629  -76.957  54.212  1
171283  93.642  -76.952  54.207  1
171284  93.655  -76.947  54.200  1
171285  93.667  -76.941  54.192  1
171286  93.680  -76.937  54.183  1
171287  93.694  -76.932  54.177  1
171288  93.712  -76.928  54.169  1
171289  93.719  -76.911  54.159  1
171290  93.726  -76.894  54.148  1
171291  93.734  -76.878  54.137  1
171292  93.749  -76.871  54.126  1
171293  93.767  -76.868  54.114  1
171294  93.786  -76.864  54.101  1
171295  93.804  -76.861  54.087  1
171296  93.829  -76.864  54.076  1
171297  93.857  -76.872  54.067  1
171298  93.886  -76.881  54.061  1
171299  93.914  -76.886  54.055  1
171300  93.931  -76.876  54.050  1
171301  93.948  -76.865  54.044  1
171302  93.965  -76.855  54.035  1
171303  93.982  -76.844  54.023  1
171304  93.999  -76.834  54.010  1
171305  94.016  -76.823  53.995  1
171306  94.033  -76.816  53.980  1
171307  94.046  -76.814  53.964  1
171308  94.052  -76.815  53.947  1
171309  94.064  -76.813  53.927  1
171310  94.077  -76.812  53.912  1
171311  94.089  -76.810  53.900  1
171312  94.102  -76.808  53.892  1
171313  94.114  -76.806  53.884  1
171314  94.127  -76.805  53.878  1
171315  94.143  -76.802  53.872  1
171316  94.163  -76.798  53.861  1
171317  94.163  -76.798  53.847  1
171318  94.151  -76.802  53.830  1
171319  94.156  -76.802  53.810  1
171320  94.163  -76.804  53.788  1
171321  94.169  -76.806  53.764  1
171322  94.175  -76.807  53.741  1
171323  94.193  -76.802  53.722  1
171324  94.222  -76.793  53.710  1
171325  94.251  -76.784  53.696  1
171326  94.280  -76.774  53.681  1
171327  94.309  -76.765  53.666  1
171328  94.338  -76.756  53.651  1
171329  94.362  -76.749  53.631  1
171330  94.380  -76.747  53.607  1
171331  94.398  -76.744  53.580  1
171332  94.415  -76.742  53.555  1
171333  94.433  -76.739  53.531  1
171334  94.452  -76.736  53.509  1
171335  94.470  -76.733  53.491  1
171336  94.487  -76.730  53.473  1
171337  94.505  -76.727  53.453  1
171338  94.515  -76.726  53.433  1
171339  94.516  -76.728  53.411  1
171340  94.517  -76.732  53.387  1
171341  94.518  -76.735  53.362  1
171342  94.518  -76.739  53.335  1
171343  94.519  -76.742  53.305  1
171344  94.554  -76.738  53.273  1
171345  94.599  -76.731  53.242  1
171346  94.651  -76.712  53.211  1
171347  94.702  -76.693  53.179  1
171348  94.747  -76.677  53.146  1
171349  94.782  -76.668  53.110  1
171350  94.819  -76.658  53.069  1
171351  94.837  -76.652  53.026  1
171352  94.849  -76.646  52.983  1
171353  94.861  -76.640  52.940  1
171354  94.873  -76.633  52.900  1
171355  94.885  -76.627  52.862  1
171356  94.897  -76.621  52.826  1
171357  94.908  -76.615  52.792  1
171358  94.920  -76.609  52.757  1
171359  94.932  -76.602  52.721  1
171360  94.944  -76.596  52.683  1
171361  94.955  -76.590  52.643  1
171362  94.961  -76.584  52.601  1
171363  94.974  -76.584  52.556  1
171364  94.999  -76.594  52.506  1
171365  95.025  -76.604  52.458  1
171366  95.050  -76.614  52.409  1
171367  95.075  -76.623  52.360  1
171368  95.101  -76.633  52.319  1
171369  95.126  -76.643  52.280  1
171370  95.156  -76.658  52.242  1
171371  95.189  -76.677  52.203  1
171372  95.204  -76.696  52.162  1
171373  95.205  -76.715  52.120  1
171374  95.214  -76.729  52.076  1
171375  95.224  -76.743  52.031  1
171376  95.233  -76.755  51.985  1
171377  95.243  -76.769  51.936  1
171378  95.252  -76.783  51.885  1
171379  95.262  -76.796  51.830  1
171380  95.271  -76.809  51.776  1
171381  95.284  -76.823  51.723  1
171382  95.299  -76.836  51.673  1
171383  95.314  -76.849  51.625  1
171384  95.328  -76.862  51.577  1
171385  95.345  -76.869  51.529  1
171386  95.364  -76.871  51.481  1
171387  95.382  -76.872  51.433  1
171388  95.401  -76.874  51.385  1
171389  95.419  -76.875  51.337  1
171390  95.438  -76.876  51.290  1
171391  95.457  -76.878  51.242  1
171392  95.475  -76.879  51.195  1
171393  95.492  -76.890  51.149  1
171394  95.513  -76.890  51.103  1
171395  95.524  -76.904  51.058  1
171396  95.539  -76.924  51.012  1
171397  95.555  -76.943  50.966  1
171398  95.570  -76.962  50.922  1
171399  95.586  -76.981  50.880  1
171400  95.601  -77.000  50.839  1
171401  95.616  -77.019  50.799  1
171402  95.632  -77.038  50.760  1
171403  95.648  -77.056  50.721  1
171404  95.663  -77.075  50.682  1
171405  95.678  -77.086  50.642  1
171406  95.693  -77.091  50.602  1
171407  95.706  -77.100  50.562  1
171408  95.720  -77.110  50.523  1
171409  95.733  -77.119  50.484  1
171410  95.746  -77.128  50.444  1
171411  95.759  -77.138  50.404  1
171412  95.772  -77.148  50.365  1
171413  95.785  -77.158  50.325  1
171414  95.799  -77.165  50.284  1
171415  95.814  -77.163  50.243  1
171416  95.829  -77.161  50.202  1
171417  95.844  -77.160  50.159  1
171418  95.859  -77.157  50.115  1
171419  95.874  -77.156  50.070  1
171420  95.896  -77.148  50.021  1
171421  95.921  -77.137  49.967  1
171422  95.920  -77.141  49.907  1
171423  95.924  -77.152  49.834  1
171424  95.936  -77.165  49.761  1
171425  95.947  -77.177  49.692  1
171426  95.958  -77.189  49.627  1
171427  95.976  -77.201  49.569  1
171428  95.990  -77.216  49.515  1
171429  96.006  -77.229  49.465  1
171430  96.023  -77.238  49.419  1
171431  96.040  -77.249  49.376  1
171432  96.057  -77.259  49.337  1
171433  96.075  -77.269  49.301  1
171434  96.092  -77.279  49.267  1
171435  96.109  -77.290  49.236  1
171436  96.126  -77.300  49.206  1
171437  96.144  -77.310  49.177  1
171438  96.161  -77.320  49.150  1
171439  96.178  -77.331  49.127  1
171440  96.196  -77.338  49.106  1
171441  96.217  -77.340  49.085  1
171442  96.237  -77.341  49.064  1
171443  96.258  -77.344  49.042  1
171444  96.278  -77.346  49.020  1
171445  96.299  -77.348  48.997  1
171446  96.319  -77.351  48.979  1
171447  96.340  -77.353  48.961  1
171448  96.360  -77.355  48.943  1
171449  96.384  -77.361  48.926  1
171450  96.401  -77.376  48.911  1
171451  96.417  -77.392  48.896  1
171452  96.434  -77.407  48.880  1
171453  96.450  -77.423  48.867  1
171454  96.467  -77.438  48.853  1
171455  96.483  -77.453  48.841  1
171456  96.500  -77.468  48.828  1
171457  96.516  -77.484  48.814  1
171458  96.532  -77.499  48.801  1
171459  96.549  -77.514  48.788  1
171460  96.566  -77.530  48.777  1
171461  96.582  -77.545  48.769  1
171462  96.595  -77.564  48.761  1
171463  96.605  -77.586  48.753  1
171464  96.626  -77.598  48.744  1
171465  96.649  -77.607  48.730  1
171466  96.673  -77.617  48.715  1
171467  96.696  -77.626  48.698  1
171468  96.719  -77.635  48.683  1
171469  96.743  -77.645  48.667  1
171470  96.764  -77.646  48.651  1
171471  96.786  -77.642  48.633  1
171472  96.807  -77.638  48.618  1
171473  96.828  -77.634  48.603  1
171474  96.849  -77.630  48.587  1
171475  96.879  -77.649  48.571  1
171476  96.908  -77.667  48.555  1
171477  96.938  -77.685  48.539  1
171478  96.967  -77.702  48.523  1
171479  97.001  -77.719  48.507  1
171480  97.028  -77.723  48.492  1
171481  97.034  -77.700  48.475  1
171482  97.039  -77.678  48.456  1
171483  97.045  -77.655  48.436  1
171484  97.051  -77.633  48.416  1
171485  97.057  -77.611  48.395  1
171486  97.063  -77.588  48.374  1
171487  97.070  -77.571  48.349  1
171488  97.079  -77.560  48.326  1
171489  97.088  -77.548  48.302  1
171490  97.098  -77.537  48.277  1
171491  97.105  -77.522  48.253  1
171492  97.140  -77.518  48.230  1
171493  97.170  -77.523  48.208  1
171494  97.193  -77.530  48.185  1
171495  97.216  -77.539  48.162  1
171496  97.238  -77.547  48.139  1
171497  97.260  -77.555  48.117  1
171498  97.283  -77.563  48.095  1
171499  97.306  -77.571  48.073  1
171500  97.329  -77.580  48.051  1
171501  97.353  -77.590  48.028  1
171502  97.376  -77.600  48.004  1
171503  97.399  -77.610  47.980  1
171504  97.423  -77.620  47.955  1
171505  97.446  -77.629  47.930  1
171506  97.469  -77.639  47.905  1
171507  97.493  -77.649  47.880  1
171508  97.516  -77.658  47.854  1
171509  97.539  -77.668  47.828  1
171510  97.563  -77.678  47.802  1
171511  97.575  -77.679  47.777  1
171512  97.579  -77.674  47.751  1
171513  97.583  -77.668  47.725  1
171514  97.593  -77.668  47.698  1
171515  97.630  -77.680  47.671  1
171516  97.667  -77.691  47.643  1
171517  97.704  -77.703  47.614  1
171518  97.741  -77.715  47.585  1
171519  97.779  -77.727  47.555  1
171520  97.816  -77.740  47.528  1
171521  97.853  -77.752  47.499  1
171522  97.890  -77.764  47.470  1
171523  97.920  -77.767  47.442  1
171524  97.937  -77.757  47.414  1
171525  97.909  -77.742  47.387  1
171526  97.870  -77.726  47.361  1
171527  97.831  -77.711  47.335  1
171528  97.804  -77.687  47.307  1
171529  97.829  -77.633  47.279  1
171530  97.855  -77.578  47.251  1
171531  97.892  -77.565  47.223  1
171532  97.933  -77.562  47.194  1
171533  97.973  -77.561  47.165  1
171534  98.000  -77.590  47.137  1
171535  98.035  -77.620  47.110  1
171536  98.069  -77.649  47.084  1
171537  98.104  -77.678  47.059  1
171538  98.138  -77.707  47.035  1
171539  98.173  -77.736  47.009  1
171540  98.202  -77.727  46.983  1
171541  98.221  -77.728  46.957  1
171542  98.240  -77.729  46.929  1
171543  98.243  -77.733  46.901  1
171544  98.245  -77.738  46.873  1
171545  98.247  -77.743  46.845  1
171546  98.249  -77.748  46.819  1
171547  98.252  -77.752  46.794  1
171548  98.262  -77.758  46.769  1
171549  98.271  -77.763  46.746  1
171550  98.281  -77.768  46.723  1
171551  98.299  -77.772  46.700  1
171552  98.320  -77.777  46.678  1
171553  98.342  -77.780  46.656  1
171554  98.367  -77.783  46.634  1
171555  98.406  -77.776  46.612  1
171556  98.430  -77.778  46.591  1
171557  98.452  -77.780  46.568  1
171558  98.475  -77.783  46.545  1
171559  98.497  -77.786  46.523  1
171560  98.520  -77.789  46.499  1
171561  98.544  -77.788  46.476  1
171562  98.568  -77.787  46.454  1
171563  98.582  -77.798  46.433  1
171564  98.591  -77.815  46.412  1
171565  98.608  -77.819  46.392  1
171566  98.627  -77.806  46.371  1
171567  98.630  -77.807  46.350  1
171568  98.633  -77.807  46.328  1
171569  98.637  -77.808  46.307  1
171570  98.640  -77.808  46.287  1
171571  98.643  -77.808  46.267  1
171572  98.646  -77.808  46.247  1
171573  98.650  -77.808  46.227  1
171574  98.653  -77.809  46.207  1
171575  98.656  -77.809  46.186  1
171576  98.659  -77.810  46.167  1
171577  98.662  -77.810  46.148  1
171578  98.672  -77.813  46.129  1
171579  98.691  -77.821  46.112  1
171580  98.710  -77.828  46.094  1
171581  98.728  -77.836  46.075  1
171582  98.770  -77.843  46.058  1
171583  98.812  -77.852  46.041  1
171584  98.854  -77.859  46.023  1
171585  98.896  -77.868  46.005  1
171586  98.938  -77.875  45.988  1
171587  98.994  -77.884  45.971  1
171588  99.019  -77.887  45.955  1
171589  99.043  -77.896  45.939  1
171590  99.067  -77.905  45.924  1
171591  99.090  -77.913  45.910  1
171592  99.114  -77.922  45.896  1
171593  99.138  -77.931  45.880  1
171594  99.162  -77.940  45.866  1
171595  99.186  -77.949  45.852  1
171596  99.209  -77.959  45.839  1
171597  99.230  -77.968  45.829  1
171598  99.251  -77.978  45.820  1
171599  99.271  -77.987  45.811  1
171600  99.294  -77.996  45.801  1
171601  99.333  -78.002  45.790  1
171602  99.338  -78.015  45.779  1
171603  99.350  -78.025  45.768  1
171604  99.364  -78.031  45.759  1
171605  99.378  -78.038  45.751  1
171606  99.392  -78.045  45.743  1
171607  99.406  -78.052  45.735  1
171608  99.432  -78.057  45.728  1
171609  99.476  -78.060  45.717  1
171610  99.503  -78.074  45.706  1
171611  99.526  -78.090  45.695  1
171612  99.549  -78.105  45.683  1
171613  99.567  -78.119  45.670  1
171614  99.588  -78.134  45.657  1
171615  99.619  -78.149  45.643  1
171616  99.649  -78.165  45.629  1
171617  99.680  -78.180  45.615  1
171618  99.710  -78.196  45.600  1
171619  99.740  -78.211  45.586  1
171620  99.771  -78.227  45.571  1
171621  99.801  -78.242  45.556  1
171622  99.832  -78.257  45.540  1
171623  99.874  -78.280  45.525  1
171624  99.893  -78.294  45.509  1
171625  99.911  -78.307  45.492  1
171626  99.930  -78.320  45.475  1
171627  99.949  -78.334  45.458  1
171628  99.968  -78.347  45.442  1
171629  99.986  -78.360  45.426  1
171630  100.005  -78.373  45.409  1
171631  100.028  -78.385  45.394  1
171632  100.056  -78.392  45.379  1
171633  100.064  -78.403  45.364  1
171634  100.094  -78.407  45.349  1
171635  100.122  -78.412  45.334  1
171636  100.146  -78.415  45.319  1
171637  100.171  -78.418  45.303  1
171638  100.195  -78.421  45.287  1
171639  100.219  -78.424  45.272  1
171640  100.243  -78.427  45.257  1
171641  100.268  -78.430  45.241  1
171642  100.292  -78.433  45.227  1
171643  100.329  -78.442  45.212  1
171644  100.366  -78.451  45.196  1
171645  100.404  -78.461  45.181  1
171646  100.441  -78.470  45.165  1
171647  100.478  -78.479  45.149  1
171648  100.515  -78.489  45.134  1
171649  100.553  -78.498  45.121  1
171650  100.602  -78.507  45.107  1
171651  100.660  -78.514  45.093  1
171652  100.718  -78.521  45.077  1
171653  100.776  -78.529  45.062  1
171654  100.835  -78.536  45.046  1
171655  100.893  -78.544  45.030  1
171656  100.893  -78.549  45.013  1
171657  100.879  -78.567  44.998  1
171658  100.865  -78.586  44.982  1
171659  100.856  -78.604  44.967  1
171660  100.885  -78.620  44.950  1
171661  100.918  -78.619  44.934  1
171662  100.952  -78.618  44.919  1
171663  100.985  -78.617  44.906  1
171664  101.019  -78.617  44.891  1
171665  101.052  -78.616  44.876  1
171666  101.083  -78.614  44.861  1
171667  101.111  -78.598  44.846  1
171668  101.142  -78.588  44.830  1
171669  101.187  -78.601  44.813  1
171670  101.233  -78.616  44.798  1
171671  101.286  -78.630  44.784  1
171672  101.312  -78.645  44.768  1
171673  101.323  -78.669  44.753  1
171674  101.334  -78.694  44.737  1
171675  101.344  -78.720  44.721  1
171676  101.354  -78.745  44.706  1
171677  101.365  -78.771  44.692  1
171678  101.388  -78.794  44.677  1
171679  101.413  -78.815  44.662  1
171680  101.439  -78.837  44.647  1
171681  101.465  -78.858  44.632  1
171682  101.490  -78.880  44.617  1
171683  101.526  -78.901  44.603  1
171684  101.568  -78.920  44.589  1
171685  101.611  -78.940  44.576  1
171686  101.653  -78.959  44.563  1
171687  101.684  -78.972  44.550  1
171688  101.701  -78.977  44.537  1
171689  101.718  -78.984  44.525  1
171690  101.735  -78.989  44.513  1
171691  101.751  -78.994  44.500  1
171692  101.768  -79.000  44.487  1
171693  101.785  -79.006  44.475  1
171694  101.802  -79.012  44.464  1
171695  101.818  -79.017  44.453  1
171696  101.835  -79.022  44.441  1
171697  101.852  -79.028  44.429  1
171698  101.869  -79.034  44.417  1
171699  101.885  -79.040  44.404  1
171927  92.649  -77.166  54.117  1
171928  92.672  -77.177  54.133  1
171929  92.695  -77.188  54.146  1
171930  92.718  -77.199  54.158  1
171931  92.729  -77.212  54.170  1
171932  92.736  -77.224  54.180  1
171933  92.743  -77.237  54.189  1
171934  92.751  -77.249  54.198  1
171935  92.758  -77.262  54.207  1
171936  92.765  -77.274  54.214  1
171937  92.772  -77.287  54.221  1
171938  92.790  -77.282  54.225  1
171939  92.810  -77.273  54.229  1
171940  92.830  -77.264  54.232  1
171941  92.851  -77.256  54.236  1
171942  92.871  -77.247  54.240  1
171943  92.892  -77.238  54.244  1
171944  92.912  -77.229  54.247  1
171945  92.932  -77.221  54.251  1
171946  92.952  -77.212  54.254  1
171947  92.973  -77.203  54.257  1
171948  92.993  -77.194  54.260  1
171949  93.013  -77.185  54.264  1
171950  93.034  -77.177  54.267  1
171951  93.054  -77.167  54.271  1
171952  93.073  -77.157  54.277  1
171953  93.092  -77.147  54.282  1
171954  93.112  -77.136  54.287  1
171955  93.131  -77.125  54.293  1
171956  93.151  -77.116  54.299  1
171957  93.169  -77.103  54.305  1
171958  93.187  -77.091  54.309  1
171959  93.201  -77.079  54.311  1
171960  93.206  -77.073  54.311  1
171961  93.210  -77.067  54.309  1
171962  93.214  -77.061  54.299  1
171963  93.219  -77.054  54.290  1
171964  93.229  -77.044  54.281  1
171965  93.239  -77.034  54.274  1
171966  93.250  -77.023  54.271  1
171967  93.278  -77.017  54.269  1
171968  93.313  -77.012  54.267  1
171969  93.348  -77.007  54.265  1
171970  93.384  -77.003  54.264  1
171971  93.417  -76.997  54.263  1
171972  93.438  -76.993  54.260  1
171973  93.459  -76.989  54.258  1
171974  93.479  -76.984  54.257  1
171975  93.499  -76.978  54.254  1
171976  93.519  -76.973  54.250  1
171977  93.541  -76.970  54.244  1
171978  93.556  -76.963  54.240  1
171979  93.568  -76.957  54.238  1
171980  93.581  -76.953  54.239  1
171981  93.593  -76.947  54.237  1
171982  93.606  -76.942  54.233  1
171983  93.619  -76.937  54.228  1
171984  93.632  -76.931  54.223  1
171985  93.644  -76.927  54.216  1
171986  93.657  -76.922  54.208  1
171987  93.670  -76.916  54.200  1
171988  93.688  -76.915  54.193  1
171989  93.710  -76.915  54.185  1
171990  93.718  -76.899  54.175  1
171991  93.725  -76.882  54.166  1
171992  93.732  -76.865  54.155  1
171993  93.749  -76.860  54.144  1
171994  93.768  -76.857  54.131  1
171995  93.786  -76.854  54.117  1
171996  93.804  -76.851  54.102  1
171997  93.823  -76.847  54.088  1
171998  93.851  -76.855  54.076  1
171999  93.880  -76.862  54.068  1
172000  93.909  -76.871  54.062  1
172001  93.926  -76.860  54.056  1
172002  93.943  -76.850  54.050  1
172003  93.960  -76.840  54.040  1
172004  93.977  -76.829  54.030  1
172005  93.994  -76.818  54.021  1
172006  94.011  -76.811  54.011  1
172007  94.028  -76.807  53.998  1
172008  94.045  -76.803  53.984  1
172009  94.052  -76.804  53.969  1
172010  94.056  -76.806  53.951  1
172011  94.063  -76.806  53.936  1
172012  94.076  -76.804  53.925  1
172013  94.088  -76.802  53.917  1
172014  94.101  -76.801  53.909  1
172015  94.113  -76.799  53.902  1
172016  94.132  -76.795  53.895  1
172017  94.152  -76.791  53.886  1
172018  94.167  -76.788  53.874  1
172019  94.155  -76.792  53.860  1
172020  94.143  -76.795  53.841  1
172021  94.145  -76.796  53.819  1
172022  94.151  -76.798  53.797  1
172023  94.157  -76.799  53.775  1
172024  94.184  -76.791  53.757  1
172025  94.213  -76.782  53.744  1
172026  94.242  -76.773  53.730  1
172027  94.271  -76.763  53.716  1
172028  94.300  -76.754  53.700  1
172029  94.329  -76.745  53.682  1
172030  94.358  -76.736  53.660  1
172031  94.376  -76.733  53.633  1
172032  94.394  -76.730  53.602  1
172033  94.412  -76.727  53.573  1
172034  94.429  -76.724  53.546  1
172035  94.447  -76.721  53.521  1
172036  94.464  -76.718  53.501  1
172037  94.481  -76.715  53.480  1
172038  94.498  -76.712  53.460  1
172039  94.505  -76.712  53.441  1
172040  94.508  -76.712  53.420  1
172041  94.509  -76.714  53.397  1
172042  94.510  -76.718  53.374  1
172043  94.510  -76.721  53.348  1
172044  94.511  -76.724  53.318  1
172045  94.557  -76.718  53.287  1
172046  94.602  -76.712  53.256  1
172047  94.652  -76.696  53.224  1
172048  94.703  -76.676  53.192  1
172049  94.743  -76.665  53.159  1
172050  94.779  -76.655  53.125  1
172051  94.815  -76.646  53.085  1
172052  94.833  -76.638  53.042  1
172053  94.845  -76.632  52.999  1
172054  94.857  -76.626  52.958  1
172055  94.869  -76.620  52.922  1
172056  94.881  -76.614  52.888  1
172057  94.893  -76.608  52.852  1
172058  94.904  -76.602  52.816  1
172059  94.916  -76.596  52.780  1
172060  94.928  -76.589  52.744  1
172061  94.936  -76.583  52.707  1
172062  94.942  -76.577  52.667  1
172063  94.956  -76.578  52.626  1
172064  94.981  -76.588  52.582  1
172065  95.006  -76.598  52.533  1
172066  95.032  -76.608  52.484  1
172067  95.057  -76.617  52.433  1
172068  95.083  -76.627  52.381  1
172069  95.108  -76.636  52.334  1
172070  95.133  -76.646  52.290  1
172071  95.158  -76.655  52.248  1
172072  95.180  -76.671  52.205  1
172073  95.190  -76.684  52.162  1
172074  95.199  -76.697  52.117  1
172075  95.209  -76.711  52.074  1
172076  95.218  -76.724  52.032  1
172077  95.228  -76.738  51.988  1
172078  95.238  -76.751  51.940  1
172079  95.247  -76.765  51.887  1
172080  95.257  -76.778  51.833  1
172081  95.266  -76.792  51.783  1
172082  95.280  -76.805  51.733  1
172083  95.295  -76.818  51.685  1
172084  95.310  -76.831  51.640  1
172085  95.324  -76.843  51.595  1
172086  95.339  -76.856  51.549  1
172087  95.356  -76.861  51.502  1
172088  95.375  -76.862  51.454  1
172089  95.394  -76.864  51.406  1
172090  95.412  -76.865  51.358  1
172091  95.431  -76.867  51.311  1
172092  95.450  -76.868  51.263  1
172093  95.468  -76.870  51.215  1
172094  95.487  -76.871  51.169  1
172095  95.506  -76.877  51.122  1
172096  95.522  -76.895  51.076  1
172097  95.537  -76.914  51.030  1
172098  95.553  -76.932  50.984  1
172099  95.568  -76.951  50.940  1
172100  95.584  -76.969  50.898  1
172101  95.599  -76.988  50.857  1
172102  95.615  -77.007  50.817  1
172103  95.630  -77.025  50.777  1
172104  95.646  -77.044  50.738  1
172105  95.662  -77.063  50.699  1
172106  95.677  -77.072  50.660  1
172107  95.691  -77.078  50.620  1
172108  95.706  -77.083  50.580  1
172109  95.721  -77.088  50.541  1
172110  95.736  -77.094  50.501  1
172111  95.751  -77.098  50.461  1
172112  95.764  -77.108  50.422  1
172113  95.777  -77.118  50.384  1
172114  95.790  -77.128  50.344  1
172115  95.803  -77.138  50.303  1
172116  95.818  -77.140  50.261  1
172117  95.833  -77.138  50.219  1
172118  95.848  -77.136  50.174  1
172119  95.863  -77.134  50.129  1
172120  95.878  -77.132  50.084  1
172121  95.893  -77.131  50.036  1
172122  95.908  -77.128  49.983  1
172123  95.921  -77.127  49.922  1
172124  95.932  -77.138  49.848  1
172125  95.940  -77.149  49.774  1
172126  95.948  -77.160  49.705  1
172127  95.980  -77.174  49.640  1
172128  96.002  -77.183  49.581  1
172129  96.015  -77.195  49.527  1
172130  96.029  -77.212  49.476  1
172131  96.043  -77.229  49.429  1
172132  96.056  -77.245  49.387  1
172133  96.071  -77.262  49.347  1
172134  96.087  -77.274  49.311  1
172135  96.104  -77.284  49.279  1
172136  96.121  -77.294  49.247  1
172137  96.138  -77.304  49.216  1
172138  96.155  -77.315  49.187  1
172139  96.172  -77.325  49.159  1
172140  96.190  -77.335  49.136  1
172141  96.209  -77.340  49.114  1
172142  96.230  -77.342  49.092  1
172143  96.250  -77.344  49.071  1
172144  96.270  -77.346  49.050  1
172145  96.291  -77.348  49.029  1
172146  96.312  -77.351  49.006  1
172147  96.332  -77.353  48.989  1
172148  96.353  -77.352  48.972  1
172149  96.374  -77.350  48.955  1
172150  96.394  -77.349  48.938  1
172151  96.409  -77.366  48.924  1
172152  96.425  -77.382  48.909  1
172153  96.441  -77.398  48.894  1
172154  96.456  -77.414  48.879  1
172155  96.471  -77.430  48.866  1
172156  96.487  -77.447  48.853  1
172157  96.503  -77.463  48.840  1
172158  96.518  -77.479  48.825  1
172159  96.534  -77.495  48.811  1
172160  96.551  -77.510  48.798  1
172161  96.568  -77.525  48.785  1
172162  96.584  -77.540  48.775  1
172163  96.600  -77.555  48.767  1
172164  96.616  -77.573  48.759  1
172165  96.639  -77.582  48.749  1
172166  96.662  -77.591  48.735  1
172167  96.686  -77.600  48.721  1
172168  96.709  -77.610  48.707  1
172169  96.732  -77.619  48.692  1
172170  96.756  -77.628  48.677  1
172171  96.779  -77.638  48.661  1
172172  96.801  -77.639  48.644  1
172173  96.822  -77.634  48.628  1
172174  96.843  -77.630  48.613  1
172175  96.867  -77.634  48.598  1
172176  96.897  -77.652  48.580  1
172177  96.927  -77.671  48.564  1
172178  96.957  -77.689  48.547  1
172179  96.994  -77.703  48.530  1
172180  97.030  -77.718  48.515  1
172181  97.038  -77.699  48.500  1
172182  97.044  -77.676  48.484  1
172183  97.050  -77.654  48.466  1
172184  97.056  -77.631  48.447  1
172185  97.062  -77.609  48.427  1
172186  97.071  -77.598  48.407  1
172187  97.080  -77.586  48.385  1
172188  97.089  -77.575  48.361  1
172189  97.098  -77.564  48.337  1
172190  97.107  -77.552  48.313  1
172191  97.116  -77.539  48.289  1
172192  97.123  -77.524  48.265  1
172193  97.145  -77.515  48.242  1
172194  97.180  -77.516  48.220  1
172195  97.203  -77.524  48.196  1
172196  97.226  -77.533  48.174  1
172197  97.248  -77.540  48.152  1
172198  97.271  -77.548  48.131  1
172199  97.294  -77.557  48.109  1
172200  97.316  -77.564  48.087  1
172201  97.338  -77.573  48.065  1
172202  97.361  -77.581  48.041  1
172203  97.384  -77.589  48.016  1
172204  97.407  -77.598  47.991  1
172205  97.430  -77.608  47.965  1
172206  97.453  -77.617  47.940  1
172207  97.477  -77.627  47.915  1
172208  97.500  -77.636  47.890  1
172209  97.524  -77.646  47.864  1
172210  97.547  -77.656  47.838  1
172211  97.571  -77.666  47.812  1
172212  97.590  -77.674  47.786  1
172213  97.594  -77.668  47.759  1
172214  97.598  -77.663  47.733  1
172215  97.610  -77.659  47.706  1
172216  97.643  -77.668  47.680  1
172217  97.680  -77.680  47.652  1
172218  97.717  -77.692  47.624  1
172219  97.754  -77.704  47.595  1
172220  97.792  -77.716  47.566  1
172221  97.829  -77.728  47.537  1
172222  97.866  -77.740  47.508  1
172223  97.903  -77.752  47.478  1
172224  97.930  -77.752  47.450  1
172225  97.947  -77.742  47.422  1
172226  97.938  -77.729  47.395  1
172227  97.899  -77.713  47.369  1
172228  97.861  -77.697  47.343  1
172229  97.831  -77.676  47.315  1
172230  97.856  -77.621  47.286  1
172231  97.881  -77.567  47.258  1
172232  97.906  -77.512  47.229  1
172233  97.946  -77.506  47.200  1
172234  97.987  -77.503  47.172  1
172235  98.016  -77.530  47.143  1
172236  98.051  -77.559  47.117  1
172237  98.085  -77.588  47.091  1
172238  98.120  -77.617  47.065  1
172239  98.154  -77.646  47.041  1
172240  98.189  -77.676  47.015  1
172241  98.223  -77.705  46.988  1
172242  98.253  -77.714  46.963  1
172243  98.265  -77.718  46.935  1
172244  98.267  -77.722  46.907  1
172245  98.268  -77.727  46.878  1
172246  98.270  -77.731  46.850  1
172247  98.272  -77.736  46.824  1
172248  98.274  -77.741  46.798  1
172249  98.282  -77.746  46.772  1
172250  98.292  -77.751  46.750  1
172251  98.301  -77.756  46.726  1
172252  98.310  -77.761  46.703  1
172253  98.331  -77.766  46.680  1
172254  98.352  -77.770  46.658  1
172255  98.389  -77.765  46.636  1
172256  98.423  -77.761  46.615  1
172257  98.445  -77.763  46.594  1
172258  98.468  -77.766  46.572  1
172259  98.491  -77.768  46.549  1
172260  98.514  -77.769  46.527  1
172261  98.538  -77.768  46.504  1
172262  98.563  -77.768  46.481  1
172263  98.587  -77.766  46.459  1
172264  98.596  -77.783  46.438  1
172265  98.604  -77.799  46.416  1
172266  98.619  -77.811  46.396  1
172267  98.647  -77.795  46.376  1
172268  98.650  -77.797  46.354  1
172269  98.652  -77.799  46.332  1
172270  98.653  -77.800  46.312  1
172271  98.655  -77.802  46.291  1
172272  98.658  -77.802  46.269  1
172273  98.661  -77.802  46.249  1
172274  98.665  -77.802  46.229  1
172275  98.668  -77.803  46.208  1
172276  98.671  -77.803  46.188  1
172277  98.674  -77.804  46.168  1
172278  98.677  -77.804  46.149  1
172279  98.681  -77.804  46.131  1
172280  98.693  -77.808  46.112  1
172281  98.711  -77.816  46.093  1
172282  98.740  -77.824  46.074  1
172283  98.782  -77.832  46.057  1
172284  98.824  -77.840  46.040  1
172285  98.866  -77.848  46.022  1
172286  98.908  -77.855  46.005  1
172287  98.950  -77.864  45.989  1
172288  98.983  -77.872  45.972  1
172289  99.007  -77.881  45.955  1
172290  99.030  -77.890  45.939  1
172291  99.054  -77.899  45.925  1
172292  99.078  -77.908  45.911  1
172293  99.102  -77.917  45.897  1
172294  99.126  -77.926  45.882  1
172295  99.149  -77.935  45.868  1
172296  99.173  -77.944  45.855  1
172297  99.197  -77.953  45.843  1
172298  99.219  -77.962  45.833  1
172299  99.239  -77.972  45.824  1
172300  99.263  -77.981  45.815  1
172301  99.302  -77.986  45.804  1
172302  99.337  -77.992  45.793  1
172303  99.342  -78.006  45.782  1
172304  99.348  -78.019  45.771  1
172305  99.359  -78.028  45.762  1
172306  99.373  -78.035  45.754  1
172307  99.387  -78.043  45.747  1
172308  99.402  -78.050  45.740  1
172309  99.425  -78.055  45.732  1
172310  99.469  -78.058  45.722  1
172311  99.513  -78.061  45.711  1
172312  99.536  -78.077  45.700  1
172313  99.556  -78.091  45.688  1
172314  99.573  -78.103  45.675  1
172315  99.588  -78.118  45.661  1
172316  99.603  -78.131  45.648  1
172317  99.617  -78.146  45.634  1
172318  99.646  -78.161  45.620  1
172319  99.677  -78.177  45.605  1
172320  99.707  -78.192  45.591  1
172321  99.737  -78.208  45.575  1
172322  99.768  -78.223  45.560  1
172323  99.826  -78.252  45.546  1
172324  99.877  -78.279  45.530  1
172325  99.897  -78.292  45.514  1
172326  99.915  -78.305  45.498  1
172327  99.934  -78.319  45.481  1
172328  99.952  -78.332  45.464  1
172329  99.971  -78.345  45.448  1
172330  99.990  -78.359  45.432  1
172331  100.018  -78.367  45.415  1
172332  100.050  -78.373  45.400  1
172333  100.069  -78.382  45.385  1
172334  100.074  -78.395  45.371  1
172335  100.093  -78.402  45.356  1
172336  100.123  -78.407  45.341  1
172337  100.153  -78.412  45.325  1
172338  100.182  -78.416  45.310  1
172339  100.206  -78.420  45.295  1
172340  100.230  -78.423  45.279  1
172341  100.254  -78.426  45.264  1
172342  100.278  -78.429  45.249  1
172343  100.303  -78.432  45.233  1
172344  100.329  -78.435  45.218  1
172345  100.366  -78.445  45.202  1
172346  100.404  -78.454  45.187  1
172347  100.441  -78.463  45.171  1
172348  100.478  -78.473  45.156  1
172349  100.515  -78.482  45.141  1
172350  100.553  -78.491  45.128  1
172351  100.611  -78.498  45.114  1
172352  100.669  -78.506  45.099  1
172353  100.727  -78.514  45.084  1
172354  100.786  -78.521  45.068  1
172355  100.844  -78.529  45.052  1
172356  100.902  -78.536  45.035  1
172357  100.957  -78.543  45.019  1
172358  100.939  -78.561  45.004  1
172359  100.918  -78.578  44.988  1
172360  100.898  -78.595  44.972  1
172361  100.879  -78.588  44.956  1
172362  100.924  -78.593  44.941  1
172363  100.957  -78.594  44.926  1
172364  100.990  -78.594  44.913  1
172365  101.024  -78.595  44.898  1
172366  101.057  -78.595  44.883  1
172367  101.088  -78.604  44.869  1
172368  101.116  -78.588  44.852  1
172369  101.148  -78.579  44.837  1
172370  101.201  -78.593  44.821  1
172371  101.256  -78.608  44.805  1
172372  101.289  -78.622  44.790  1
172373  101.310  -78.636  44.774  1
172374  101.326  -78.655  44.758  1
172375  101.336  -78.681  44.742  1
172376  101.346  -78.707  44.727  1
172377  101.357  -78.733  44.712  1
172378  101.374  -78.756  44.698  1
172379  101.400  -78.778  44.683  1
172380  101.425  -78.800  44.668  1
172381  101.451  -78.821  44.653  1
172382  101.477  -78.843  44.639  1
172383  101.502  -78.865  44.623  1
172384  101.528  -78.886  44.609  1
172385  101.568  -78.906  44.595  1
172386  101.610  -78.925  44.581  1
172387  101.653  -78.945  44.568  1
172388  101.685  -78.959  44.555  1
172389  101.702  -78.965  44.542  1
172390  101.718  -78.970  44.529  1
172391  101.735  -78.976  44.517  1
172392  101.752  -78.981  44.504  1
172393  101.769  -78.987  44.491  1
172394  101.785  -78.993  44.479  1
172395  101.802  -78.998  44.467  1
172396  101.819  -79.004  44.456  1
172397  101.836  -79.009  44.444  1
172398  101.852  -79.015  44.432  1
172399  101.870  -79.021  44.420  1
172400  101.886  -79.026  44.408  1
172401  101.903  -79.032  44.396  1
172629  92.659  -77.148  54.112  1
172630  92.683  -77.159  54.126  1
172631  92.706  -77.170  54.138  1
172632  92.722  -77.182  54.150  1
172633  92.730  -77.194  54.160  1
172634  92.737  -77.207  54.168  1
172635  92.744  -77.219  54.177  1
172636  92.751  -77.232  54.187  1
172637  92.758  -77.244  54.194  1
172638  92.765  -77.257  54.200  1
172639  92.779  -77.258  54.205  1
172640  92.799  -77.250  54.210  1
172641  92.820  -77.241  54.213  1
172642  92.840  -77.232  54.217  1
172643  92.860  -77.223  54.222  1
172644  92.881  -77.215  54.226  1
172645  92.901  -77.206  54.230  1
172646  92.922  -77.197  54.234  1
172647  92.942  -77.188  54.238  1
172648  92.962  -77.179  54.242  1
172649  92.983  -77.171  54.245  1
172650  93.003  -77.162  54.249  1
172651  93.023  -77.153  54.253  1
172652  93.044  -77.144  54.257  1
172653  93.064  -77.135  54.262  1
172654  93.084  -77.126  54.266  1
172655  93.103  -77.116  54.271  1
172656  93.123  -77.106  54.277  1
172657  93.142  -77.095  54.283  1
172658  93.162  -77.085  54.290  1
172659  93.180  -77.072  54.299  1
172660  93.196  -77.061  54.303  1
172661  93.200  -77.054  54.304  1
172662  93.204  -77.048  54.301  1
172663  93.209  -77.042  54.291  1
172664  93.213  -77.036  54.283  1
172665  93.217  -77.030  54.276  1
172666  93.226  -77.020  54.272  1
172667  93.236  -77.010  54.271  1
172668  93.264  -77.003  54.271  1
172669  93.299  -76.999  54.271  1
172670  93.335  -76.994  54.270  1
172671  93.372  -76.989  54.270  1
172672  93.404  -76.982  54.268  1
172673  93.419  -76.975  54.266  1
172674  93.439  -76.969  54.264  1
172675  93.459  -76.963  54.262  1
172676  93.479  -76.957  54.261  1
172677  93.499  -76.952  54.257  1
172678  93.521  -76.951  54.251  1
172679  93.544  -76.951  54.247  1
172680  93.562  -76.947  54.246  1
172681  93.573  -76.937  54.249  1
172682  93.583  -76.927  54.249  1
172683  93.596  -76.922  54.247  1
172684  93.609  -76.917  54.243  1
172685  93.622  -76.912  54.239  1
172686  93.634  -76.906  54.232  1
172687  93.647  -76.901  54.224  1
172688  93.660  -76.897  54.216  1
172689  93.682  -76.897  54.209  1
172690  93.705  -76.898  54.201  1
172691  93.716  -76.886  54.192  1
172692  93.724  -76.870  54.183  1
172693  93.731  -76.853  54.173  1
172694  93.750  -76.850  54.161  1
172695  93.768  -76.847  54.148  1
172696  93.786  -76.843  54.133  1
172697  93.805  -76.840  54.117  1
172698  93.823  -76.837  54.102  1
172699  93.845  -76.837  54.088  1
172700  93.873  -76.845  54.078  1
172701  93.903  -76.853  54.069  1
172702  93.921  -76.845  54.062  1
172703  93.938  -76.834  54.055  1
172704  93.955  -76.824  54.045  1
172705  93.972  -76.814  54.036  1
172706  93.989  -76.805  54.029  1
172707  94.006  -76.801  54.021  1
172708  94.023  -76.797  54.012  1
172709  94.040  -76.794  54.002  1
172710  94.054  -76.791  53.991  1
172711  94.058  -76.793  53.975  1
172712  94.061  -76.796  53.962  1
172713  94.065  -76.797  53.952  1
172714  94.075  -76.796  53.943  1
172715  94.087  -76.795  53.936  1
172716  94.103  -76.793  53.929  1
172717  94.122  -76.789  53.921  1
172718  94.142  -76.784  53.910  1
172719  94.166  -76.779  53.898  1
172720  94.159  -76.781  53.884  1
172721  94.147  -76.785  53.867  1
172722  94.135  -76.789  53.846  1
172723  94.134  -76.790  53.825  1
172724  94.146  -76.789  53.806  1
172725  94.175  -76.780  53.790  1
172726  94.204  -76.771  53.776  1
172727  94.234  -76.761  53.763  1
172728  94.262  -76.752  53.751  1
172729  94.291  -76.743  53.733  1
172730  94.321  -76.734  53.714  1
172731  94.350  -76.724  53.689  1
172732  94.371  -76.718  53.659  1
172733  94.389  -76.715  53.626  1
172734  94.406  -76.712  53.593  1
172735  94.423  -76.710  53.563  1
172736  94.440  -76.707  53.535  1
172737  94.458  -76.704  53.511  1
172738  94.475  -76.701  53.488  1
172739  94.492  -76.698  53.466  1
172740  94.495  -76.698  53.446  1
172741  94.498  -76.699  53.426  1
172742  94.501  -76.699  53.405  1
172743  94.503  -76.699  53.384  1
172744  94.503  -76.703  53.358  1
172745  94.514  -76.705  53.330  1
172746  94.559  -76.698  53.299  1
172747  94.605  -76.692  53.267  1
172748  94.653  -76.679  53.234  1
172749  94.703  -76.661  53.202  1
172750  94.739  -76.651  53.170  1
172751  94.775  -76.642  53.138  1
172752  94.812  -76.632  53.099  1
172753  94.830  -76.625  53.058  1
172754  94.841  -76.619  53.015  1
172755  94.853  -76.613  52.977  1
172756  94.865  -76.607  52.943  1
172757  94.877  -76.601  52.911  1
172758  94.889  -76.595  52.878  1
172759  94.901  -76.589  52.841  1
172760  94.911  -76.583  52.804  1
172761  94.916  -76.576  52.768  1
172762  94.922  -76.570  52.729  1
172763  94.938  -76.572  52.690  1
172764  94.964  -76.582  52.650  1
172765  94.989  -76.592  52.607  1
172766  95.014  -76.602  52.559  1
172767  95.039  -76.611  52.511  1
172768  95.064  -76.621  52.460  1
172769  95.090  -76.630  52.406  1
172770  95.115  -76.640  52.355  1
172771  95.140  -76.649  52.306  1
172772  95.147  -76.651  52.260  1
172773  95.165  -76.655  52.214  1
172774  95.185  -76.666  52.168  1
172775  95.194  -76.680  52.122  1
172776  95.204  -76.693  52.076  1
172777  95.213  -76.706  52.033  1
172778  95.223  -76.720  51.988  1
172779  95.233  -76.734  51.941  1
172780  95.242  -76.746  51.891  1
172781  95.251  -76.760  51.841  1
172782  95.261  -76.774  51.793  1
172783  95.276  -76.787  51.746  1
172784  95.290  -76.799  51.700  1
172785  95.305  -76.812  51.656  1
172786  95.320  -76.825  51.613  1
172787  95.335  -76.838  51.568  1
172788  95.349  -76.851  51.522  1
172789  95.368  -76.853  51.475  1
172790  95.386  -76.855  51.428  1
172791  95.405  -76.856  51.381  1
172792  95.423  -76.857  51.333  1
172793  95.442  -76.859  51.285  1
172794  95.461  -76.860  51.236  1
172795  95.479  -76.862  51.189  1
172796  95.494  -76.865  51.141  1
172797  95.520  -76.883  51.095  1
172798  95.536  -76.901  51.049  1
172799  95.551  -76.920  51.003  1
172800  95.567  -76.938  50.960  1
172801  95.583  -76.957  50.918  1
172802  95.598  -76.976  50.877  1
172803  95.614  -76.994  50.837  1
172804  95.629  -77.013  50.796  1
172805  95.644  -77.031  50.756  1
172806  95.660  -77.050  50.717  1
172807  95.675  -77.059  50.679  1
172808  95.690  -77.064  50.639  1
172809  95.705  -77.069  50.599  1
172810  95.720  -77.074  50.561  1
172811  95.735  -77.079  50.520  1
172812  95.749  -77.085  50.481  1
172813  95.764  -77.090  50.442  1
172814  95.779  -77.095  50.405  1
172815  95.794  -77.100  50.365  1
172816  95.808  -77.107  50.324  1
172817  95.821  -77.116  50.281  1
172818  95.836  -77.114  50.237  1
172819  95.851  -77.113  50.191  1
172820  95.869  -77.113  50.144  1
172821  95.887  -77.114  50.098  1
172822  95.906  -77.116  50.051  1
172823  95.924  -77.117  49.997  1
172824  95.931  -77.117  49.936  1
172825  95.930  -77.119  49.862  1
172826  95.938  -77.129  49.787  1
172827  95.969  -77.144  49.717  1
172828  96.016  -77.160  49.652  1
172829  96.027  -77.166  49.592  1
172830  96.040  -77.173  49.538  1
172831  96.053  -77.190  49.487  1
172832  96.067  -77.207  49.441  1
172833  96.082  -77.223  49.397  1
172834  96.095  -77.240  49.358  1
172835  96.109  -77.257  49.322  1
172836  96.123  -77.274  49.289  1
172837  96.137  -77.291  49.258  1
172838  96.151  -77.307  49.227  1
172839  96.167  -77.319  49.198  1
172840  96.184  -77.329  49.170  1
172841  96.201  -77.339  49.146  1
172842  96.222  -77.342  49.123  1
172843  96.242  -77.345  49.101  1
172844  96.263  -77.345  49.080  1
172845  96.284  -77.344  49.059  1
172846  96.305  -77.342  49.039  1
172847  96.325  -77.340  49.018  1
172848  96.346  -77.338  49.000  1
172849  96.367  -77.337  48.984  1
172850  96.388  -77.335  48.968  1
172851  96.408  -77.333  48.953  1
172852  96.424  -77.348  48.938  1
172853  96.440  -77.364  48.923  1
172854  96.455  -77.381  48.908  1
172855  96.471  -77.397  48.893  1
172856  96.486  -77.413  48.879  1
172857  96.502  -77.429  48.866  1
172858  96.517  -77.445  48.852  1
172859  96.533  -77.462  48.838  1
172860  96.548  -77.478  48.823  1
172861  96.564  -77.494  48.808  1
172862  96.579  -77.511  48.796  1
172863  96.595  -77.526  48.784  1
172864  96.611  -77.542  48.775  1
172865  96.631  -77.552  48.766  1
172866  96.653  -77.564  48.753  1
172867  96.676  -77.574  48.741  1
172868  96.699  -77.584  48.728  1
172869  96.722  -77.593  48.716  1
172870  96.745  -77.603  48.700  1
172871  96.768  -77.612  48.685  1
172872  96.792  -77.621  48.670  1
172873  96.815  -77.631  48.654  1
172874  96.837  -77.631  48.638  1
172875  96.858  -77.627  48.622  1
172876  96.885  -77.639  48.605  1
172877  96.915  -77.657  48.589  1
172878  96.950  -77.672  48.572  1
172879  96.986  -77.687  48.555  1
172880  97.023  -77.702  48.538  1
172881  97.043  -77.696  48.522  1
172882  97.049  -77.674  48.507  1
172883  97.055  -77.652  48.492  1
172884  97.063  -77.636  48.476  1
172885  97.072  -77.624  48.457  1
172886  97.081  -77.613  48.437  1
172887  97.090  -77.602  48.416  1
172888  97.099  -77.590  48.393  1
172889  97.108  -77.579  48.371  1
172890  97.117  -77.567  48.348  1
172891  97.126  -77.555  48.324  1
172892  97.135  -77.542  48.302  1
172893  97.142  -77.526  48.277  1
172894  97.150  -77.511  48.252  1
172895  97.190  -77.510  48.229  1
172896  97.213  -77.517  48.208  1
172897  97.236  -77.526  48.185  1
172898  97.258  -77.534  48.163  1
172899  97.281  -77.542  48.141  1
172900  97.304  -77.550  48.119  1
172901  97.326  -77.558  48.098  1
172902  97.349  -77.567  48.076  1
172903  97.372  -77.574  48.051  1
172904  97.394  -77.583  48.026  1
172905  97.417  -77.591  48.001  1
172906  97.439  -77.599  47.976  1
172907  97.462  -77.607  47.950  1
172908  97.485  -77.615  47.925  1
172909  97.508  -77.625  47.899  1
172910  97.531  -77.635  47.872  1
172911  97.555  -77.644  47.847  1
172912  97.578  -77.654  47.820  1
172913  97.601  -77.664  47.794  1
172914  97.610  -77.662  47.767  1
172915  97.614  -77.657  47.741  1
172916  97.634  -77.656  47.715  1
172917  97.656  -77.657  47.688  1
172918  97.693  -77.669  47.660  1
172919  97.730  -77.680  47.631  1
172920  97.768  -77.692  47.603  1
172921  97.805  -77.705  47.574  1
172922  97.843  -77.717  47.545  1
172923  97.880  -77.729  47.516  1
172924  97.917  -77.741  47.486  1
172925  97.939  -77.736  47.458  1
172926  97.957  -77.727  47.431  1
172927  97.967  -77.716  47.404  1
172928  97.928  -77.700  47.377  1
172929  97.890  -77.684  47.350  1
172930  97.858  -77.664  47.322  1
172931  97.883  -77.609  47.293  1
172932  97.908  -77.555  47.264  1
172933  97.933  -77.501  47.235  1
172934  97.959  -77.450  47.206  1
172935  98.000  -77.447  47.178  1
172936  98.032  -77.469  47.150  1
172937  98.067  -77.498  47.124  1
172938  98.101  -77.527  47.098  1
172939  98.136  -77.557  47.071  1
172940  98.170  -77.586  47.047  1
172941  98.205  -77.615  47.020  1
172942  98.238  -77.645  46.994  1
172943  98.270  -77.682  46.968  1
172944  98.286  -77.705  46.940  1
172945  98.288  -77.711  46.912  1
172946  98.291  -77.715  46.884  1
172947  98.293  -77.720  46.856  1
172948  98.295  -77.725  46.829  1
172949  98.297  -77.730  46.802  1
172950  98.303  -77.734  46.776  1
172951  98.312  -77.740  46.753  1
172952  98.322  -77.745  46.730  1
172953  98.332  -77.750  46.707  1
172954  98.341  -77.755  46.684  1
172955  98.373  -77.752  46.660  1
172956  98.411  -77.746  46.639  1
172957  98.438  -77.746  46.618  1
172958  98.461  -77.749  46.597  1
172959  98.484  -77.750  46.576  1
172960  98.508  -77.749  46.554  1
172961  98.532  -77.749  46.531  1
172962  98.557  -77.748  46.509  1
172963  98.581  -77.746  46.486  1
172964  98.601  -77.751  46.464  1
172965  98.610  -77.767  46.443  1
172966  98.621  -77.782  46.421  1
172967  98.641  -77.787  46.401  1
172968  98.667  -77.775  46.380  1
172969  98.673  -77.783  46.359  1
172970  98.676  -77.786  46.337  1
172971  98.678  -77.787  46.317  1
172972  98.679  -77.789  46.296  1
172973  98.681  -77.790  46.274  1
172974  98.683  -77.792  46.253  1
172975  98.685  -77.793  46.233  1
172976  98.686  -77.795  46.212  1
172977  98.688  -77.796  46.191  1
172978  98.690  -77.798  46.171  1
172979  98.693  -77.798  46.152  1
172980  98.696  -77.798  46.133  1
172981  98.699  -77.799  46.114  1
172982  98.713  -77.804  46.095  1
172983  98.752  -77.812  46.076  1
172984  98.794  -77.820  46.057  1
172985  98.835  -77.827  46.040  1
172986  98.875  -77.835  46.023  1
172987  98.916  -77.843  46.006  1
172988  98.953  -77.850  45.990  1
172989  98.984  -77.855  45.973  1
172990  99.008  -77.864  45.956  1
172991  99.028  -77.876  45.940  1
172992  99.049  -77.888  45.926  1
172993  99.069  -77.899  45.912  1
172994  99.089  -77.912  45.898  1
172995  99.113  -77.921  45.884  1
172996  99.137  -77.930  45.870  1
172997  99.161  -77.938  45.858  1
172998  99.185  -77.947  45.846  1
172999  99.207  -77.956  45.837  1
173000  99.232  -77.965  45.828  1
173001  99.271  -77.971  45.818  1
173002  99.310  -77.975  45.807  1
173003  99.341  -77.983  45.795  1
173004  99.346  -77.996  45.784  1
173005  99.351  -78.010  45.774  1
173006  99.357  -78.025  45.766  1
173007  99.369  -78.033  45.758  1
173008  99.383  -78.040  45.751  1
173009  99.397  -78.047  45.744  1
173010  99.418  -78.053  45.736  1
173011  99.462  -78.056  45.726  1
173012  99.506  -78.059  45.716  1
173013  99.545  -78.065  45.704  1
173014  99.561  -78.075  45.691  1
173015  99.580  -78.089  45.679  1
173016  99.603  -78.106  45.666  1
173017  99.614  -78.119  45.653  1
173018  99.624  -78.131  45.640  1
173019  99.638  -78.144  45.626  1
173020  99.652  -78.159  45.612  1
173021  99.674  -78.173  45.597  1
173022  99.705  -78.189  45.582  1
173023  99.761  -78.217  45.566  1
173024  99.820  -78.247  45.550  1
173025  99.878  -78.275  45.535  1
173026  99.900  -78.291  45.519  1
173027  99.919  -78.304  45.503  1
173028  99.937  -78.317  45.487  1
173029  99.957  -78.330  45.470  1
173030  99.976  -78.343  45.453  1
173031  100.008  -78.349  45.437  1
173032  100.041  -78.356  45.421  1
173033  100.073  -78.362  45.405  1
173034  100.082  -78.373  45.391  1
173035  100.087  -78.385  45.377  1
173036  100.092  -78.396  45.362  1
173037  100.123  -78.401  45.347  1
173038  100.152  -78.406  45.332  1
173039  100.182  -78.411  45.317  1
173040  100.212  -78.416  45.302  1
173041  100.241  -78.420  45.287  1
173042  100.265  -78.423  45.271  1
173043  100.289  -78.426  45.256  1
173044  100.314  -78.429  45.239  1
173045  100.338  -78.432  45.224  1
173046  100.366  -78.438  45.209  1
173047  100.404  -78.447  45.192  1
173048  100.441  -78.456  45.177  1
173049  100.478  -78.466  45.162  1
173050  100.515  -78.475  45.149  1
173051  100.562  -78.483  45.135  1
173052  100.620  -78.491  45.120  1
173053  100.679  -78.498  45.105  1
173054  100.737  -78.506  45.090  1
173055  100.795  -78.514  45.074  1
173056  100.853  -78.520  45.058  1
173057  100.891  -78.528  45.042  1
173058  100.923  -78.535  45.026  1
173059  100.945  -78.545  45.009  1
173060  100.924  -78.563  44.993  1
173061  100.904  -78.579  44.977  1
173062  100.888  -78.542  44.962  1
173063  100.915  -78.524  44.948  1
173064  100.943  -78.523  44.933  1
173065  100.961  -78.523  44.919  1
173066  101.005  -78.549  44.905  1
173067  101.050  -78.576  44.889  1
173068  101.088  -78.586  44.874  1
173069  101.117  -78.570  44.858  1
173070  101.164  -78.568  44.842  1
173071  101.223  -78.584  44.827  1
173072  101.266  -78.599  44.811  1
173073  101.287  -78.613  44.795  1
173074  101.308  -78.627  44.779  1
173075  101.328  -78.642  44.763  1
173076  101.339  -78.668  44.747  1
173077  101.349  -78.694  44.733  1
173078  101.360  -78.719  44.718  1
173079  101.386  -78.741  44.703  1
173080  101.412  -78.762  44.688  1
173081  101.438  -78.784  44.673  1
173082  101.463  -78.806  44.659  1
173083  101.489  -78.827  44.645  1
173084  101.515  -78.849  44.629  1
173085  101.540  -78.871  44.614  1
173086  101.567  -78.893  44.600  1
173087  101.610  -78.912  44.586  1
173088  101.652  -78.931  44.572  1
173089  101.686  -78.946  44.559  1
173090  101.702  -78.951  44.546  1
173091  101.720  -78.957  44.533  1
173092  101.736  -78.962  44.521  1
173093  101.753  -78.968  44.508  1
173094  101.770  -78.974  44.496  1
173095  101.786  -78.980  44.484  1
173096  101.803  -78.985  44.472  1
173097  101.820  -78.990  44.460  1
173098  101.837  -78.996  44.448  1
173099  101.853  -79.002  44.436  1
173100  101.870  -79.008  44.424  1
173101  101.887  -79.013  44.412  1
173102  101.904  -79.018  44.400  1
173331  92.670  -77.130  54.104  1
173332  92.693  -77.141  54.117  1
173333  92.716  -77.152  54.128  1
173334  92.723  -77.165  54.137  1
173335  92.730  -77.177  54.146  1
173336  92.737  -77.190  54.155  1
173337  92.744  -77.203  54.164  1
173338  92.751  -77.215  54.172  1
173339  92.758  -77.228  54.178  1
173340  92.769  -77.235  54.183  1
173341  92.789  -77.226  54.188  1
173342  92.809  -77.217  54.192  1
173343  92.830  -77.208  54.197  1
173344  92.850  -77.200  54.203  1
173345  92.870  -77.191  54.206  1
173346  92.890  -77.182  54.211  1
173347  92.911  -77.173  54.216  1
173348  92.931  -77.165  54.221  1
173349  92.952  -77.156  54.224  1
173350  92.972  -77.147  54.229  1
173351  92.992  -77.138  54.234  1
173352  93.013  -77.129  54.238  1
173353  93.033  -77.121  54.243  1
173354  93.053  -77.112  54.247  1
173355  93.074  -77.103  54.251  1
173356  93.094  -77.094  54.256  1
173357  93.115  -77.086  54.262  1
173358  93.134  -77.075  54.268  1
173359  93.153  -77.066  54.275  1
173360  93.173  -77.055  54.286  1
173361  93.190  -77.042  54.293  1
173362  93.194  -77.036  54.295  1
173363  93.199  -77.030  54.290  1
173364  93.203  -77.024  54.282  1
173365  93.207  -77.018  54.276  1
173366  93.212  -77.011  54.272  1
173367  93.216  -77.005  54.271  1
173368  93.223  -76.997  54.271  1
173369  93.250  -76.990  54.273  1
173370  93.288  -76.985  54.274  1
173371  93.327  -76.979  54.274  1
173372  93.367  -76.973  54.274  1
173373  93.398  -76.966  54.273  1
173374  93.404  -76.956  54.271  1
173375  93.418  -76.948  54.269  1
173376  93.438  -76.942  54.268  1
173377  93.458  -76.937  54.267  1
173378  93.479  -76.931  54.263  1
173379  93.501  -76.931  54.258  1
173380  93.524  -76.932  54.255  1
173381  93.547  -76.932  54.254  1
173382  93.569  -76.932  54.257  1
173383  93.580  -76.922  54.258  1
173384  93.590  -76.911  54.258  1
173385  93.601  -76.900  54.256  1
173386  93.612  -76.892  54.251  1
173387  93.624  -76.887  54.246  1
173388  93.637  -76.881  54.240  1
173389  93.654  -76.878  54.233  1
173390  93.676  -76.879  54.225  1
173391  93.699  -76.880  54.217  1
173392  93.715  -76.874  54.207  1
173393  93.722  -76.857  54.200  1
173394  93.731  -76.843  54.190  1
173395  93.750  -76.840  54.178  1
173396  93.768  -76.837  54.165  1
173397  93.787  -76.834  54.150  1
173398  93.805  -76.831  54.134  1
173399  93.824  -76.827  54.117  1
173400  93.842  -76.824  54.101  1
173401  93.867  -76.828  54.089  1
173402  93.896  -76.836  54.078  1
173403  93.916  -76.830  54.069  1
173404  93.933  -76.819  54.061  1
173405  93.950  -76.809  54.051  1
173406  93.967  -76.799  54.042  1
173407  93.984  -76.796  54.036  1
173408  94.001  -76.792  54.031  1
173409  94.018  -76.788  54.025  1
173410  94.035  -76.784  54.018  1
173411  94.052  -76.781  54.011  1
173412  94.060  -76.781  53.998  1
173413  94.064  -76.783  53.987  1
173414  94.067  -76.785  53.978  1
173415  94.071  -76.787  53.969  1
173416  94.074  -76.789  53.962  1
173417  94.096  -76.784  53.956  1
173418  94.122  -76.777  53.948  1
173419  94.149  -76.771  53.935  1
173420  94.161  -76.767  53.922  1
173421  94.161  -76.768  53.908  1
173422  94.150  -76.772  53.892  1
173423  94.138  -76.777  53.873  1
173424  94.127  -76.781  53.854  1
173425  94.139  -76.777  53.836  1
173426  94.169  -76.768  53.819  1
173427  94.198  -76.759  53.805  1
173428  94.228  -76.749  53.792  1
173429  94.258  -76.740  53.780  1
173430  94.287  -76.730  53.763  1
173431  94.317  -76.721  53.742  1
173432  94.347  -76.712  53.716  1
173433  94.365  -76.705  53.685  1
173434  94.383  -76.701  53.650  1
173435  94.400  -76.698  53.616  1
173436  94.417  -76.695  53.583  1
173437  94.434  -76.692  53.552  1
173438  94.452  -76.689  53.524  1
173439  94.469  -76.686  53.497  1
173440  94.483  -76.683  53.472  1
173441  94.485  -76.684  53.450  1
173442  94.488  -76.684  53.429  1
173443  94.491  -76.685  53.409  1
173444  94.493  -76.685  53.389  1
173445  94.496  -76.686  53.365  1
173446  94.517  -76.684  53.337  1
173447  94.562  -76.678  53.306  1
173448  94.608  -76.672  53.274  1
173449  94.654  -76.662  53.240  1
173450  94.699  -76.647  53.209  1
173451  94.736  -76.638  53.179  1
173452  94.771  -76.628  53.148  1
173453  94.808  -76.619  53.112  1
173454  94.826  -76.611  53.073  1
173455  94.838  -76.605  53.033  1
173456  94.849  -76.599  52.996  1
173457  94.861  -76.593  52.964  1
173458  94.873  -76.587  52.933  1
173459  94.885  -76.581  52.904  1
173460  94.891  -76.575  52.866  1
173461  94.897  -76.569  52.829  1
173462  94.902  -76.563  52.792  1
173463  94.920  -76.566  52.752  1
173464  94.946  -76.576  52.713  1
173465  94.971  -76.586  52.673  1
173466  94.996  -76.596  52.631  1
173467  95.021  -76.605  52.585  1
173468  95.046  -76.614  52.538  1
173469  95.071  -76.624  52.487  1
173470  95.096  -76.633  52.433  1
173471  95.103  -76.635  52.379  1
173472  95.111  -76.636  52.327  1
173473  95.118  -76.638  52.276  1
173474  95.135  -76.642  52.227  1
173475  95.173  -76.649  52.179  1
173476  95.189  -76.661  52.130  1
173477  95.199  -76.675  52.083  1
173478  95.208  -76.689  52.037  1
173479  95.217  -76.702  51.991  1
173480  95.227  -76.715  51.945  1
173481  95.237  -76.729  51.897  1
173482  95.246  -76.743  51.851  1
173483  95.257  -76.755  51.804  1
173484  95.271  -76.768  51.759  1
173485  95.286  -76.781  51.715  1
173486  95.301  -76.794  51.673  1
173487  95.316  -76.807  51.631  1
173488  95.330  -76.820  51.588  1
173489  95.345  -76.833  51.544  1
173490  95.360  -76.843  51.498  1
173491  95.379  -76.845  51.451  1
173492  95.398  -76.846  51.404  1
173493  95.416  -76.848  51.355  1
173494  95.435  -76.850  51.306  1
173495  95.454  -76.851  51.258  1
173496  95.471  -76.853  51.209  1
173497  95.482  -76.855  51.161  1
173498  95.508  -76.872  51.114  1
173499  95.533  -76.889  51.068  1
173500  95.550  -76.908  51.024  1
173501  95.565  -76.926  50.981  1
173502  95.581  -76.945  50.939  1
173503  95.597  -76.963  50.898  1
173504  95.612  -76.982  50.857  1
173505  95.628  -77.001  50.817  1
173506  95.643  -77.019  50.776  1
173507  95.659  -77.038  50.737  1
173508  95.674  -77.045  50.699  1
173509  95.688  -77.050  50.660  1
173510  95.703  -77.055  50.620  1
173511  95.718  -77.060  50.581  1
173512  95.733  -77.066  50.541  1
173513  95.748  -77.071  50.501  1
173514  95.763  -77.076  50.463  1
173515  95.777  -77.081  50.426  1
173516  95.792  -77.087  50.386  1
173517  95.807  -77.092  50.344  1
173518  95.825  -77.100  50.301  1
173519  95.857  -77.107  50.255  1
173520  95.876  -77.109  50.208  1
173521  95.894  -77.110  50.160  1
173522  95.913  -77.112  50.113  1
173523  95.932  -77.113  50.063  1
173524  95.950  -77.115  50.008  1
173525  95.948  -77.113  49.946  1
173526  95.941  -77.110  49.871  1
173527  95.958  -77.113  49.797  1
173528  96.026  -77.135  49.727  1
173529  96.041  -77.142  49.663  1
173530  96.053  -77.148  49.603  1
173531  96.065  -77.154  49.549  1
173532  96.079  -77.169  49.499  1
173533  96.092  -77.185  49.451  1
173534  96.106  -77.202  49.408  1
173535  96.120  -77.219  49.370  1
173536  96.134  -77.235  49.334  1
173537  96.148  -77.252  49.301  1
173538  96.162  -77.269  49.270  1
173539  96.176  -77.285  49.239  1
173540  96.190  -77.302  49.209  1
173541  96.204  -77.319  49.182  1
173542  96.215  -77.334  49.158  1
173543  96.236  -77.334  49.135  1
173544  96.256  -77.332  49.113  1
173545  96.277  -77.330  49.092  1
173546  96.298  -77.329  49.071  1
173547  96.319  -77.327  49.051  1
173548  96.339  -77.326  49.031  1
173549  96.360  -77.323  49.013  1
173550  96.381  -77.322  48.998  1
173551  96.401  -77.320  48.983  1
173552  96.422  -77.318  48.969  1
173553  96.439  -77.331  48.953  1
173554  96.454  -77.347  48.938  1
173555  96.470  -77.363  48.923  1
173556  96.485  -77.379  48.908  1
173557  96.501  -77.395  48.894  1
173558  96.516  -77.412  48.880  1
173559  96.532  -77.428  48.866  1
173560  96.547  -77.445  48.851  1
173561  96.563  -77.461  48.835  1
173562  96.579  -77.476  48.820  1
173563  96.594  -77.493  48.806  1
173564  96.610  -77.508  48.794  1
173565  96.629  -77.518  48.783  1
173566  96.648  -77.528  48.773  1
173567  96.670  -77.539  48.760  1
173568  96.693  -77.550  48.748  1
173569  96.715  -77.561  48.736  1
173570  96.738  -77.572  48.724  1
173571  96.760  -77.583  48.709  1
173572  96.783  -77.594  48.695  1
173573  96.805  -77.605  48.680  1
173574  96.828  -77.614  48.664  1
173575  96.852  -77.624  48.649  1
173576  96.874  -77.625  48.632  1
173577  96.906  -77.642  48.614  1
173578  96.943  -77.656  48.598  1
173579  96.979  -77.671  48.580  1
173580  97.016  -77.686  48.563  1
173581  97.048  -77.695  48.546  1
173582  97.054  -77.674  48.529  1
173583  97.064  -77.662  48.512  1
173584  97.073  -77.651  48.497  1
173585  97.082  -77.639  48.483  1
173586  97.091  -77.628  48.465  1
173587  97.100  -77.617  48.445  1
173588  97.109  -77.605  48.423  1
173589  97.118  -77.593  48.401  1
173590  97.127  -77.582  48.378  1
173591  97.137  -77.570  48.356  1
173592  97.146  -77.559  48.333  1
173593  97.153  -77.544  48.310  1
173594  97.160  -77.529  48.286  1
173595  97.168  -77.514  48.261  1
173596  97.195  -77.507  48.238  1
173597  97.224  -77.511  48.217  1
173598  97.246  -77.520  48.195  1
173599  97.269  -77.527  48.172  1
173600  97.291  -77.536  48.150  1
173601  97.314  -77.544  48.128  1
173602  97.336  -77.551  48.107  1
173603  97.359  -77.560  48.086  1
173604  97.382  -77.568  48.062  1
173605  97.404  -77.576  48.037  1
173606  97.427  -77.584  48.012  1
173607  97.450  -77.592  47.987  1
173608  97.472  -77.600  47.961  1
173609  97.495  -77.608  47.936  1
173610  97.517  -77.617  47.909  1
173611  97.540  -77.624  47.881  1
173612  97.563  -77.633  47.855  1
173613  97.586  -77.642  47.829  1
173614  97.609  -77.652  47.802  1
173615  97.626  -77.657  47.775  1
173616  97.639  -77.654  47.749  1
173617  97.658  -77.653  47.722  1
173618  97.678  -77.652  47.695  1
173619  97.706  -77.658  47.666  1
173620  97.743  -77.669  47.638  1
173621  97.781  -77.681  47.610  1
173622  97.818  -77.693  47.581  1
173623  97.856  -77.705  47.552  1
173624  97.893  -77.718  47.523  1
173625  97.930  -77.730  47.494  1
173626  97.949  -77.721  47.466  1
173627  97.966  -77.711  47.439  1
173628  97.984  -77.702  47.413  1
173629  97.957  -77.686  47.386  1
173630  97.919  -77.671  47.357  1
173631  97.884  -77.652  47.329  1
173632  97.910  -77.598  47.300  1
173633  97.934  -77.543  47.270  1
173634  97.959  -77.489  47.241  1
173635  97.985  -77.434  47.212  1
173636  98.013  -77.391  47.184  1
173637  98.048  -77.408  47.157  1
173638  98.082  -77.438  47.131  1
173639  98.117  -77.467  47.105  1
173640  98.149  -77.501  47.079  1
173641  98.181  -77.538  47.053  1
173642  98.212  -77.574  47.026  1
173643  98.244  -77.611  46.999  1
173644  98.275  -77.646  46.972  1
173645  98.307  -77.683  46.945  1
173646  98.307  -77.697  46.917  1
173647  98.308  -77.702  46.889  1
173648  98.311  -77.708  46.861  1
173649  98.313  -77.712  46.834  1
173650  98.316  -77.718  46.807  1
173651  98.323  -77.722  46.781  1
173652  98.364  -77.733  46.757  1
173653  98.375  -77.739  46.734  1
173654  98.370  -77.743  46.711  1
173655  98.360  -77.742  46.689  1
173656  98.395  -77.734  46.665  1
173657  98.432  -77.728  46.643  1
173658  98.454  -77.731  46.622  1
173659  98.479  -77.730  46.601  1
173660  98.503  -77.730  46.580  1
173661  98.527  -77.729  46.559  1
173662  98.551  -77.728  46.537  1
173663  98.576  -77.727  46.514  1
173664  98.600  -77.726  46.491  1
173665  98.615  -77.735  46.469  1
173666  98.624  -77.752  46.448  1
173667  98.643  -77.758  46.427  1
173668  98.664  -77.765  46.407  1
173669  98.687  -77.756  46.386  1
173670  98.693  -77.763  46.365  1
173671  98.699  -77.771  46.344  1
173672  98.703  -77.774  46.323  1
173673  98.704  -77.776  46.302  1
173674  98.706  -77.777  46.281  1
173675  98.708  -77.779  46.260  1
173676  98.709  -77.780  46.238  1
173677  98.711  -77.782  46.217  1
173678  98.712  -77.783  46.195  1
173679  98.714  -77.785  46.175  1
173680  98.716  -77.787  46.156  1
173681  98.717  -77.788  46.136  1
173682  98.719  -77.790  46.117  1
173683  98.720  -77.792  46.098  1
173684  98.760  -77.799  46.079  1
173685  98.800  -77.807  46.058  1
173686  98.840  -77.815  46.041  1
173687  98.880  -77.822  46.024  1
173688  98.920  -77.830  46.007  1
173689  98.951  -77.834  45.991  1
173690  98.982  -77.839  45.974  1
173691  99.012  -77.843  45.958  1
173692  99.035  -77.854  45.941  1
173693  99.056  -77.865  45.927  1
173694  99.076  -77.877  45.913  1
173695  99.096  -77.889  45.899  1
173696  99.117  -77.901  45.886  1
173697  99.138  -77.913  45.872  1
173698  99.158  -77.924  45.861  1
173699  99.179  -77.937  45.850  1
173700  99.202  -77.949  45.841  1
173701  99.240  -77.955  45.831  1
173702  99.279  -77.960  45.821  1
173703  99.318  -77.965  45.809  1
173704  99.345  -77.974  45.798  1
173705  99.350  -77.987  45.787  1
173706  99.355  -78.001  45.778  1
173707  99.361  -78.015  45.770  1
173708  99.366  -78.029  45.763  1
173709  99.378  -78.037  45.757  1
173710  99.393  -78.044  45.749  1
173711  99.411  -78.050  45.740  1
173712  99.455  -78.053  45.730  1
173713  99.498  -78.056  45.720  1
173714  99.534  -78.059  45.708  1
173715  99.563  -78.062  45.696  1
173716  99.591  -78.084  45.684  1
173717  99.617  -78.106  45.672  1
173718  99.628  -78.118  45.658  1
173719  99.639  -78.130  45.646  1
173720  99.650  -78.142  45.632  1
173721  99.661  -78.154  45.618  1
173722  99.673  -78.166  45.603  1
173723  99.705  -78.178  45.588  1
173724  99.755  -78.212  45.572  1
173725  99.814  -78.241  45.556  1
173726  99.872  -78.270  45.541  1
173727  99.904  -78.288  45.525  1
173728  99.923  -78.302  45.509  1
173729  99.941  -78.315  45.493  1
173730  99.967  -78.326  45.476  1
173731  99.999  -78.332  45.459  1
173732  100.031  -78.338  45.443  1
173733  100.063  -78.344  45.428  1
173734  100.089  -78.351  45.412  1
173735  100.094  -78.363  45.397  1
173736  100.100  -78.376  45.383  1
173737  100.105  -78.387  45.368  1
173738  100.122  -78.395  45.354  1
173739  100.151  -78.401  45.339  1
173740  100.182  -78.405  45.324  1
173741  100.211  -78.410  45.309  1
173742  100.241  -78.415  45.293  1
173743  100.271  -78.420  45.278  1
173744  100.300  -78.425  45.262  1
173745  100.325  -78.428  45.245  1
173746  100.349  -78.431  45.230  1
173747  100.373  -78.434  45.215  1
173748  100.404  -78.440  45.198  1
173749  100.441  -78.449  45.183  1
173750  100.478  -78.459  45.169  1
173751  100.516  -78.468  45.155  1
173752  100.571  -78.476  45.141  1
173753  100.630  -78.483  45.126  1
173754  100.688  -78.491  45.111  1
173755  100.747  -78.498  45.095  1
173756  100.785  -78.505  45.079  1
173757  100.819  -78.513  45.064  1
173758  100.851  -78.520  45.048  1
173759  100.884  -78.528  45.031  1
173760  100.917  -78.535  45.014  1
173761  100.930  -78.547  44.998  1
173762  100.912  -78.542  44.983  1
173763  100.896  -78.496  44.968  1
173764  100.885  -78.470  44.954  1
173765  100.922  -78.490  44.940  1
173766  100.966  -78.517  44.925  1
173767  101.010  -78.544  44.910  1
173768  101.055  -78.570  44.894  1
173769  101.088  -78.567  44.879  1
173770  101.121  -78.551  44.864  1
173771  101.179  -78.557  44.848  1
173772  101.238  -78.573  44.832  1
173773  101.263  -78.589  44.816  1
173774  101.285  -78.604  44.799  1
173775  101.307  -78.619  44.783  1
173776  101.327  -78.633  44.768  1
173777  101.341  -78.655  44.753  1
173778  101.351  -78.680  44.739  1
173779  101.373  -78.703  44.723  1
173780  101.398  -78.725  44.708  1
173781  101.424  -78.747  44.694  1
173782  101.450  -78.768  44.678  1
173783  101.475  -78.790  44.664  1
173784  101.501  -78.812  44.650  1
173785  101.527  -78.833  44.635  1
173786  101.552  -78.855  44.620  1
173787  101.578  -78.877  44.605  1
173788  101.610  -78.898  44.590  1
173789  101.652  -78.917  44.577  1
173790  101.687  -78.933  44.563  1
173791  101.703  -78.938  44.550  1
173792  101.720  -78.943  44.537  1
173793  101.737  -78.949  44.524  1
173794  101.754  -78.955  44.512  1
173795  101.770  -78.961  44.500  1
173796  101.787  -78.966  44.488  1
173797  101.804  -78.972  44.476  1
173798  101.821  -78.977  44.464  1
173799  101.837  -78.983  44.451  1
173800  101.854  -78.989  44.439  1
173801  101.871  -78.994  44.427  1
173802  101.888  -79.000  44.415  1
173803  101.904  -79.006  44.404  1
174033  92.681  -77.112  54.094  1
174034  92.704  -77.123  54.105  1
174035  92.716  -77.135  54.114  1
174036  92.723  -77.147  54.122  1
174037  92.730  -77.160  54.131  1
174038  92.737  -77.172  54.140  1
174039  92.744  -77.185  54.148  1
174040  92.752  -77.198  54.154  1
174041  92.759  -77.210  54.159  1
174042  92.779  -77.202  54.165  1
174043  92.799  -77.194  54.170  1
174044  92.819  -77.185  54.175  1
174045  92.840  -77.176  54.181  1
174046  92.860  -77.167  54.186  1
174047  92.880  -77.159  54.191  1
174048  92.901  -77.150  54.196  1
174049  92.921  -77.141  54.202  1
174050  92.941  -77.132  54.206  1
174051  92.961  -77.123  54.211  1
174052  92.982  -77.115  54.216  1
174053  93.002  -77.106  54.221  1
174054  93.022  -77.097  54.226  1
174055  93.043  -77.088  54.231  1
174056  93.063  -77.079  54.237  1
174057  93.083  -77.071  54.242  1
174058  93.104  -77.062  54.247  1
174059  93.124  -77.053  54.254  1
174060  93.145  -77.044  54.262  1
174061  93.165  -77.035  54.272  1
174062  93.184  -77.024  54.279  1
174063  93.189  -77.018  54.282  1
174064  93.193  -77.011  54.277  1
174065  93.197  -77.005  54.272  1
174066  93.202  -76.999  54.269  1
174067  93.209  -76.993  54.269  1
174068  93.217  -76.987  54.271  1
174069  93.225  -76.981  54.272  1
174070  93.243  -76.975  54.274  1
174071  93.283  -76.969  54.277  1
174072  93.323  -76.963  54.277  1
174073  93.362  -76.958  54.276  1
174074  93.391  -76.950  54.275  1
174075  93.398  -76.940  54.274  1
174076  93.404  -76.929  54.273  1
174077  93.417  -76.922  54.273  1
174078  93.437  -76.915  54.272  1
174079  93.459  -76.912  54.268  1
174080  93.482  -76.912  54.264  1
174081  93.504  -76.912  54.262  1
174082  93.527  -76.913  54.263  1
174083  93.550  -76.913  54.264  1
174084  93.573  -76.913  54.267  1
174085  93.586  -76.906  54.268  1
174086  93.597  -76.895  54.268  1
174087  93.607  -76.884  54.264  1
174088  93.618  -76.874  54.260  1
174089  93.628  -76.863  54.254  1
174090  93.648  -76.861  54.247  1
174091  93.670  -76.862  54.239  1
174092  93.693  -76.862  54.232  1
174093  93.713  -76.861  54.223  1
174094  93.721  -76.845  54.215  1
174095  93.732  -76.833  54.204  1
174096  93.750  -76.830  54.192  1
174097  93.769  -76.826  54.179  1
174098  93.787  -76.823  54.164  1
174099  93.805  -76.820  54.149  1
174100  93.824  -76.817  54.132  1
174101  93.843  -76.814  54.116  1
174102  93.861  -76.810  54.104  1
174103  93.890  -76.818  54.093  1
174104  93.911  -76.815  54.082  1
174105  93.928  -76.804  54.072  1
174106  93.945  -76.794  54.060  1
174107  93.962  -76.790  54.051  1
174108  93.979  -76.787  54.044  1
174109  93.996  -76.783  54.040  1
174110  94.013  -76.779  54.036  1
174111  94.030  -76.775  54.032  1
174112  94.047  -76.771  54.029  1
174113  94.063  -76.768  54.019  1
174114  94.066  -76.771  54.011  1
174115  94.070  -76.773  54.003  1
174116  94.073  -76.774  53.995  1
174117  94.077  -76.777  53.989  1
174118  94.104  -76.770  53.983  1
174119  94.130  -76.763  53.975  1
174120  94.147  -76.759  53.961  1
174121  94.156  -76.755  53.947  1
174122  94.164  -76.753  53.933  1
174123  94.152  -76.758  53.918  1
174124  94.141  -76.762  53.900  1
174125  94.129  -76.767  53.883  1
174126  94.140  -76.764  53.866  1
174127  94.167  -76.755  53.848  1
174128  94.196  -76.746  53.833  1
174129  94.226  -76.737  53.820  1
174130  94.256  -76.727  53.806  1
174131  94.285  -76.718  53.790  1
174132  94.315  -76.708  53.769  1
174133  94.344  -76.699  53.742  1
174134  94.360  -76.693  53.710  1
174135  94.377  -76.687  53.674  1
174136  94.394  -76.683  53.639  1
174137  94.411  -76.680  53.606  1
174138  94.428  -76.677  53.573  1
174139  94.445  -76.674  53.542  1
174140  94.463  -76.671  53.512  1
174141  94.473  -76.670  53.483  1
174142  94.476  -76.670  53.457  1
174143  94.478  -76.671  53.434  1
174144  94.481  -76.671  53.412  1
174145  94.484  -76.671  53.391  1
174146  94.488  -76.670  53.367  1
174147  94.521  -76.665  53.340  1
174148  94.565  -76.658  53.310  1
174149  94.610  -76.652  53.280  1
174150  94.656  -76.646  53.246  1
174151  94.695  -76.634  53.214  1
174152  94.732  -76.624  53.183  1
174153  94.768  -76.615  53.153  1
174154  94.804  -76.605  53.118  1
174155  94.822  -76.599  53.081  1
174156  94.834  -76.592  53.043  1
174157  94.845  -76.586  53.010  1
174158  94.857  -76.580  52.979  1
174159  94.866  -76.574  52.950  1
174160  94.872  -76.567  52.922  1
174161  94.878  -76.561  52.888  1
174162  94.883  -76.555  52.854  1
174163  94.902  -76.560  52.819  1
174164  94.927  -76.570  52.781  1
174165  94.953  -76.580  52.741  1
174166  94.978  -76.589  52.700  1
174167  95.003  -76.599  52.656  1
174168  95.028  -76.608  52.610  1
174169  95.051  -76.617  52.563  1
174170  95.058  -76.619  52.514  1
174171  95.066  -76.621  52.462  1
174172  95.073  -76.622  52.406  1
174173  95.081  -76.624  52.352  1
174174  95.089  -76.625  52.298  1
174175  95.106  -76.629  52.246  1
174176  95.143  -76.636  52.195  1
174177  95.181  -76.644  52.146  1
174178  95.193  -76.657  52.097  1
174179  95.203  -76.671  52.050  1
174180  95.212  -76.684  52.002  1
174181  95.222  -76.697  51.955  1
174182  95.232  -76.711  51.908  1
174183  95.241  -76.724  51.862  1
174184  95.252  -76.737  51.816  1
174185  95.267  -76.750  51.772  1
174186  95.282  -76.763  51.730  1
174187  95.297  -76.776  51.691  1
174188  95.311  -76.789  51.651  1
174189  95.326  -76.802  51.610  1
174190  95.341  -76.815  51.566  1
174191  95.355  -76.828  51.522  1
174192  95.372  -76.836  51.475  1
174193  95.390  -76.837  51.427  1
174194  95.409  -76.838  51.378  1
174195  95.427  -76.840  51.328  1
174196  95.446  -76.841  51.279  1
174197  95.460  -76.843  51.230  1
174198  95.471  -76.846  51.181  1
174199  95.495  -76.862  51.134  1
174200  95.521  -76.878  51.089  1
174201  95.547  -76.896  51.045  1
174202  95.564  -76.914  51.003  1
174203  95.580  -76.932  50.962  1
174204  95.595  -76.951  50.920  1
174205  95.611  -76.970  50.879  1
174206  95.626  -76.988  50.839  1
174207  95.642  -77.007  50.799  1
174208  95.658  -77.025  50.759  1
174209  95.672  -77.031  50.721  1
174210  95.687  -77.036  50.682  1
174211  95.702  -77.041  50.642  1
174212  95.716  -77.047  50.603  1
174213  95.732  -77.052  50.563  1
174214  95.746  -77.057  50.523  1
174215  95.761  -77.063  50.483  1
174216  95.776  -77.068  50.446  1
174217  95.792  -77.075  50.406  1
174218  95.811  -77.083  50.364  1
174219  95.831  -77.091  50.320  1
174220  95.867  -77.099  50.274  1
174221  95.902  -77.106  50.224  1
174222  95.920  -77.108  50.174  1
174223  95.939  -77.110  50.126  1
174224  95.958  -77.111  50.074  1
174225  95.971  -77.112  50.016  1
174226  95.964  -77.109  49.952  1
174227  95.979  -77.109  49.879  1
174228  96.024  -77.113  49.805  1
174229  96.055  -77.119  49.737  1
174230  96.066  -77.125  49.674  1
174231  96.079  -77.131  49.615  1
174232  96.091  -77.137  49.561  1
174233  96.103  -77.147  49.511  1
174234  96.117  -77.163  49.463  1
174235  96.131  -77.180  49.420  1
174236  96.145  -77.197  49.382  1
174237  96.159  -77.213  49.347  1
174238  96.173  -77.230  49.313  1
174239  96.187  -77.247  49.282  1
174240  96.201  -77.264  49.252  1
174241  96.210  -77.282  49.222  1
174242  96.214  -77.303  49.194  1
174243  96.231  -77.311  49.170  1
174244  96.250  -77.316  49.147  1
174245  96.270  -77.317  49.125  1
174246  96.291  -77.316  49.105  1
174247  96.312  -77.313  49.085  1
174248  96.332  -77.312  49.065  1
174249  96.353  -77.310  49.046  1
174250  96.374  -77.308  49.029  1
174251  96.395  -77.307  49.014  1
174252  96.415  -77.305  49.000  1
174253  96.436  -77.303  48.987  1
174254  96.454  -77.313  48.970  1
174255  96.469  -77.329  48.954  1
174256  96.484  -77.346  48.938  1
174257  96.500  -77.362  48.924  1
174258  96.516  -77.378  48.910  1
174259  96.531  -77.395  48.895  1
174260  96.546  -77.410  48.880  1
174261  96.562  -77.427  48.865  1
174262  96.578  -77.443  48.848  1
174263  96.593  -77.460  48.832  1
174264  96.610  -77.473  48.818  1
174265  96.628  -77.484  48.805  1
174266  96.647  -77.494  48.793  1
174267  96.666  -77.504  48.781  1
174268  96.687  -77.515  48.769  1
174269  96.710  -77.526  48.757  1
174270  96.732  -77.537  48.745  1
174271  96.755  -77.548  48.733  1
174272  96.778  -77.559  48.719  1
174273  96.800  -77.570  48.705  1
174274  96.822  -77.581  48.691  1
174275  96.845  -77.592  48.675  1
174276  96.866  -77.607  48.659  1
174277  96.888  -77.614  48.642  1
174278  96.924  -77.629  48.624  1
174279  96.960  -77.643  48.606  1
174280  96.997  -77.658  48.588  1
174281  97.033  -77.673  48.570  1
174282  97.064  -77.689  48.553  1
174283  97.074  -77.677  48.535  1
174284  97.083  -77.666  48.517  1
174285  97.092  -77.655  48.501  1
174286  97.101  -77.643  48.488  1
174287  97.110  -77.632  48.470  1
174288  97.119  -77.620  48.451  1
174289  97.129  -77.608  48.429  1
174290  97.138  -77.597  48.408  1
174291  97.147  -77.586  48.385  1
174292  97.156  -77.574  48.362  1
174293  97.164  -77.561  48.340  1
174294  97.172  -77.546  48.317  1
174295  97.179  -77.531  48.293  1
174296  97.186  -77.516  48.268  1
174297  97.199  -77.504  48.245  1
174298  97.234  -77.505  48.224  1
174299  97.256  -77.513  48.202  1
174300  97.279  -77.521  48.180  1
174301  97.302  -77.530  48.157  1
174302  97.324  -77.537  48.137  1
174303  97.347  -77.545  48.116  1
174304  97.369  -77.554  48.096  1
174305  97.392  -77.561  48.073  1
174306  97.415  -77.570  48.050  1
174307  97.437  -77.578  48.025  1
174308  97.460  -77.586  47.999  1
174309  97.483  -77.594  47.973  1
174310  97.505  -77.602  47.947  1
174311  97.528  -77.610  47.919  1
174312  97.550  -77.618  47.891  1
174313  97.573  -77.627  47.864  1
174314  97.595  -77.634  47.838  1
174315  97.618  -77.642  47.811  1
174316  97.641  -77.651  47.783  1
174317  97.663  -77.650  47.756  1
174318  97.682  -77.649  47.728  1
174319  97.702  -77.649  47.701  1
174320  97.722  -77.648  47.672  1
174321  97.757  -77.658  47.643  1
174322  97.794  -77.670  47.615  1
174323  97.831  -77.682  47.588  1
174324  97.869  -77.694  47.558  1
174325  97.906  -77.706  47.530  1
174326  97.941  -77.716  47.502  1
174327  97.958  -77.706  47.474  1
174328  97.976  -77.696  47.447  1
174329  97.994  -77.686  47.421  1
174330  97.987  -77.674  47.393  1
174331  97.948  -77.658  47.365  1
174332  97.911  -77.641  47.335  1
174333  97.936  -77.586  47.305  1
174334  97.961  -77.532  47.276  1
174335  97.986  -77.477  47.247  1
174336  98.011  -77.423  47.219  1
174337  98.036  -77.368  47.192  1
174338  98.060  -77.357  47.164  1
174339  98.091  -77.393  47.139  1
174340  98.123  -77.429  47.112  1
174341  98.155  -77.466  47.086  1
174342  98.186  -77.502  47.059  1
174343  98.218  -77.539  47.033  1
174344  98.249  -77.575  47.005  1
174345  98.281  -77.611  46.978  1
174346  98.312  -77.648  46.950  1
174347  98.334  -77.677  46.922  1
174348  98.329  -77.687  46.894  1
174349  98.329  -77.695  46.866  1
174350  98.331  -77.699  46.840  1
174351  98.334  -77.705  46.813  1
174352  98.336  -77.709  46.787  1
174353  98.368  -77.717  46.763  1
174354  98.386  -77.728  46.739  1
174355  98.361  -77.732  46.716  1
174356  98.384  -77.725  46.693  1
174357  98.419  -77.717  46.671  1
174358  98.448  -77.711  46.649  1
174359  98.473  -77.711  46.627  1
174360  98.497  -77.710  46.605  1
174361  98.521  -77.709  46.585  1
174362  98.546  -77.708  46.564  1
174363  98.570  -77.708  46.542  1
174364  98.594  -77.706  46.519  1
174365  98.619  -77.705  46.496  1
174366  98.629  -77.720  46.475  1
174367  98.645  -77.730  46.455  1
174368  98.665  -77.736  46.434  1
174369  98.686  -77.741  46.414  1
174370  98.706  -77.736  46.393  1
174371  98.712  -77.744  46.372  1
174372  98.719  -77.752  46.351  1
174373  98.725  -77.758  46.330  1
174374  98.729  -77.763  46.309  1
174375  98.731  -77.765  46.289  1
174376  98.732  -77.766  46.267  1
174377  98.734  -77.768  46.245  1
174378  98.735  -77.769  46.223  1
174379  98.737  -77.771  46.201  1
174380  98.739  -77.772  46.181  1
174381  98.740  -77.773  46.161  1
174382  98.742  -77.774  46.140  1
174383  98.743  -77.777  46.120  1
174384  98.744  -77.780  46.101  1
174385  98.765  -77.786  46.081  1
174386  98.805  -77.793  46.060  1
174387  98.845  -77.801  46.042  1
174388  98.885  -77.808  46.025  1
174389  98.919  -77.815  46.009  1
174390  98.950  -77.819  45.992  1
174391  98.980  -77.824  45.976  1
174392  99.010  -77.828  45.960  1
174393  99.041  -77.833  45.944  1
174394  99.063  -77.843  45.930  1
174395  99.083  -77.855  45.916  1
174396  99.104  -77.867  45.902  1
174397  99.124  -77.879  45.888  1
174398  99.145  -77.890  45.875  1
174399  99.165  -77.902  45.863  1
174400  99.186  -77.915  45.853  1
174401  99.214  -77.930  45.843  1
174402  99.249  -77.944  45.833  1
174403  99.287  -77.949  45.823  1
174404  99.326  -77.955  45.812  1
174405  99.349  -77.965  45.802  1
174406  99.354  -77.978  45.792  1
174407  99.359  -77.992  45.784  1
174408  99.364  -78.006  45.776  1
174409  99.370  -78.019  45.769  1
174410  99.375  -78.034  45.762  1
174411  99.387  -78.041  45.754  1
174412  99.404  -78.048  45.745  1
174413  99.448  -78.051  45.735  1
174414  99.487  -78.054  45.725  1
174415  99.520  -78.056  45.713  1
174416  99.563  -78.062  45.701  1
174417  99.593  -78.084  45.690  1
174418  99.618  -78.105  45.677  1
174419  99.629  -78.117  45.664  1
174420  99.641  -78.129  45.652  1
174421  99.652  -78.141  45.638  1
174422  99.663  -78.153  45.624  1
174423  99.687  -78.150  45.610  1
174424  99.724  -78.162  45.595  1
174425  99.768  -78.198  45.579  1
174426  99.811  -78.234  45.564  1
174427  99.866  -78.265  45.548  1
174428  99.908  -78.287  45.531  1
174429  99.926  -78.300  45.515  1
174430  99.957  -78.307  45.498  1
174431  99.989  -78.313  45.483  1
174432  100.021  -78.320  45.467  1
174433  100.054  -78.326  45.451  1
174434  100.086  -78.332  45.436  1
174435  100.102  -78.342  45.421  1
174436  100.108  -78.354  45.405  1
174437  100.113  -78.366  45.390  1
174438  100.118  -78.378  45.376  1
174439  100.123  -78.389  45.361  1
174440  100.151  -78.395  45.346  1
174441  100.181  -78.400  45.331  1
174442  100.210  -78.404  45.315  1
174443  100.241  -78.410  45.299  1
174444  100.270  -78.414  45.283  1
174445  100.300  -78.420  45.267  1
174446  100.330  -78.424  45.251  1
174447  100.360  -78.429  45.235  1
174448  100.385  -78.432  45.220  1
174449  100.409  -78.435  45.205  1
174450  100.441  -78.442  45.190  1
174451  100.479  -78.451  45.176  1
174452  100.522  -78.460  45.162  1
174453  100.581  -78.468  45.148  1
174454  100.639  -78.475  45.132  1
174455  100.680  -78.482  45.116  1
174456  100.713  -78.490  45.100  1
174457  100.746  -78.498  45.084  1
174458  100.779  -78.505  45.069  1
174459  100.812  -78.513  45.052  1
174460  100.845  -78.520  45.036  1
174461  100.879  -78.528  45.019  1
174462  100.918  -78.535  45.004  1
174463  100.927  -78.525  44.989  1
174464  100.916  -78.502  44.974  1
174465  100.906  -78.479  44.959  1
174466  100.927  -78.484  44.944  1
174467  100.971  -78.511  44.929  1
174468  101.016  -78.539  44.914  1
174469  101.059  -78.564  44.899  1
174470  101.089  -78.548  44.883  1
174471  101.134  -78.531  44.867  1
174472  101.193  -78.545  44.852  1
174473  101.238  -78.561  44.836  1
174474  101.260  -78.577  44.820  1
174475  101.282  -78.593  44.804  1
174476  101.304  -78.609  44.788  1
174477  101.326  -78.624  44.772  1
174478  101.344  -78.642  44.758  1
174479  101.359  -78.666  44.743  1
174480  101.385  -78.688  44.728  1
174481  101.410  -78.709  44.713  1
174482  101.436  -78.731  44.698  1
174483  101.462  -78.753  44.683  1
174484  101.487  -78.774  44.668  1
174485  101.513  -78.796  44.654  1
174486  101.538  -78.818  44.639  1
174487  101.564  -78.839  44.624  1
174488  101.590  -78.861  44.609  1
174489  101.615  -78.883  44.594  1
174490  101.652  -78.903  44.581  1
174491  101.687  -78.919  44.567  1
174492  101.704  -78.925  44.554  1
174493  101.721  -78.930  44.540  1
174494  101.738  -78.937  44.527  1
174495  101.754  -78.942  44.515  1
174496  101.771  -78.947  44.503  1
174497  101.788  -78.953  44.491  1
174498  101.805  -78.959  44.479  1
174499  101.822  -78.965  44.467  1
174500  101.838  -78.970  44.455  1
174501  101.855  -78.975  44.443  1
174502  101.872  -78.981  44.430  1
174503  101.889  -78.987  44.418  1
174504  101.905  -78.993  44.407  1
174734  92.668  -77.083  54.069  1
174735  92.691  -77.094  54.080  1
174736  92.709  -77.106  54.089  1
174737  92.716  -77.118  54.097  1
174738  92.723  -77.131  54.105  1
174739  92.730  -77.143  54.115  1
174740  92.738  -77.156  54.123  1
174741  92.745  -77.168  54.129  1
174742  92.752  -77.181  54.135  1
174743  92.768  -77.179  54.140  1
174744  92.788  -77.170  54.146  1
174745  92.809  -77.161  54.152  1
174746  92.829  -77.152  54.157  1
174747  92.849  -77.144  54.164  1
174748  92.870  -77.135  54.170  1
174749  92.890  -77.126  54.175  1
174750  92.911  -77.117  54.181  1
174751  92.931  -77.109  54.186  1
174752  92.951  -77.100  54.191  1
174753  92.972  -77.091  54.197  1
174754  92.992  -77.082  54.203  1
174755  93.012  -77.073  54.209  1
174756  93.032  -77.065  54.215  1
174757  93.053  -77.056  54.221  1
174758  93.073  -77.047  54.226  1
174759  93.093  -77.038  54.232  1
174760  93.114  -77.030  54.239  1
174761  93.134  -77.021  54.247  1
174762  93.154  -77.012  54.256  1
174763  93.175  -77.003  54.263  1
174764  93.194  -77.000  54.267  1
174765  93.207  -76.994  54.264  1
174766  93.215  -76.989  54.263  1
174767  93.223  -76.983  54.264  1
174768  93.231  -76.977  54.267  1
174769  93.240  -76.972  54.270  1
174770  93.248  -76.965  54.272  1
174771  93.256  -76.959  54.274  1
174772  93.278  -76.953  54.278  1
174773  93.318  -76.948  54.276  1
174774  93.357  -76.942  54.275  1
174775  93.385  -76.934  54.274  1
174776  93.392  -76.924  54.272  1
174777  93.398  -76.913  54.273  1
174778  93.405  -76.903  54.274  1
174779  93.417  -76.894  54.275  1
174780  93.439  -76.893  54.273  1
174781  93.462  -76.893  54.271  1
174782  93.485  -76.893  54.270  1
174783  93.507  -76.893  54.271  1
174784  93.530  -76.894  54.271  1
174785  93.553  -76.894  54.275  1
174786  93.576  -76.894  54.278  1
174787  93.593  -76.890  54.278  1
174788  93.604  -76.879  54.276  1
174789  93.616  -76.867  54.272  1
174790  93.628  -76.854  54.266  1
174791  93.643  -76.845  54.259  1
174792  93.664  -76.844  54.252  1
174793  93.687  -76.845  54.245  1
174794  93.709  -76.846  54.238  1
174795  93.719  -76.832  54.229  1
174796  93.732  -76.822  54.218  1
174797  93.751  -76.819  54.206  1
174798  93.769  -76.816  54.193  1
174799  93.787  -76.813  54.179  1
174800  93.806  -76.809  54.163  1
174801  93.825  -76.806  54.147  1
174802  93.843  -76.803  54.131  1
174803  93.861  -76.800  54.119  1
174804  93.884  -76.801  54.108  1
174805  93.906  -76.799  54.098  1
174806  93.923  -76.788  54.087  1
174807  93.940  -76.784  54.075  1
174808  93.957  -76.781  54.064  1
174809  93.974  -76.777  54.056  1
174810  93.991  -76.774  54.050  1
174811  94.008  -76.770  54.046  1
174812  94.025  -76.766  54.044  1
174813  94.042  -76.762  54.044  1
174814  94.059  -76.759  54.037  1
174815  94.069  -76.758  54.032  1
174816  94.072  -76.760  54.027  1
174817  94.076  -76.762  54.021  1
174818  94.085  -76.762  54.014  1
174819  94.112  -76.755  54.007  1
174820  94.133  -76.749  54.000  1
174821  94.143  -76.746  53.987  1
174822  94.152  -76.743  53.973  1
174823  94.161  -76.741  53.959  1
174824  94.154  -76.743  53.944  1
174825  94.143  -76.748  53.928  1
174826  94.131  -76.752  53.911  1
174827  94.145  -76.749  53.894  1
174828  94.166  -76.743  53.877  1
174829  94.194  -76.734  53.861  1
174830  94.223  -76.724  53.846  1
174831  94.253  -76.715  53.831  1
174832  94.283  -76.706  53.814  1
174833  94.313  -76.696  53.793  1
174834  94.339  -76.688  53.766  1
174835  94.355  -76.681  53.734  1
174836  94.371  -76.674  53.699  1
174837  94.388  -76.668  53.664  1
174838  94.405  -76.665  53.630  1
174839  94.422  -76.662  53.596  1
174840  94.439  -76.659  53.563  1
174841  94.457  -76.657  53.530  1
174842  94.463  -76.656  53.497  1
174843  94.466  -76.656  53.468  1
174844  94.469  -76.656  53.441  1
174845  94.471  -76.657  53.416  1
174846  94.477  -76.655  53.393  1
174847  94.487  -76.650  53.368  1
174848  94.528  -76.644  53.341  1
174849  94.572  -76.638  53.312  1
174850  94.616  -76.632  53.283  1
174851  94.658  -76.627  53.250  1
174852  94.691  -76.621  53.218  1
174853  94.728  -76.611  53.185  1
174854  94.764  -76.602  53.155  1
174855  94.801  -76.592  53.122  1
174856  94.818  -76.586  53.088  1
174857  94.830  -76.579  53.053  1
174858  94.841  -76.573  53.024  1
174859  94.847  -76.567  52.995  1
174860  94.852  -76.561  52.966  1
174861  94.858  -76.555  52.938  1
174862  94.863  -76.549  52.907  1
174863  94.884  -76.554  52.875  1
174864  94.909  -76.564  52.842  1
174865  94.934  -76.574  52.806  1
174866  94.960  -76.583  52.767  1
174867  94.985  -76.592  52.726  1
174868  95.006  -76.601  52.683  1
174869  95.014  -76.602  52.635  1
174870  95.022  -76.604  52.588  1
174871  95.029  -76.605  52.539  1
174872  95.037  -76.608  52.489  1
174873  95.044  -76.609  52.435  1
174874  95.052  -76.611  52.380  1
174875  95.059  -76.612  52.326  1
174876  95.077  -76.616  52.273  1
174877  95.114  -76.624  52.220  1
174878  95.151  -76.631  52.168  1
174879  95.188  -76.639  52.117  1
174880  95.198  -76.652  52.069  1
174881  95.207  -76.666  52.021  1
174882  95.217  -76.680  51.972  1
174883  95.227  -76.693  51.924  1
174884  95.236  -76.706  51.878  1
174885  95.248  -76.719  51.833  1
174886  95.263  -76.732  51.789  1
174887  95.277  -76.745  51.747  1
174888  95.292  -76.758  51.708  1
174889  95.307  -76.771  51.669  1
174890  95.322  -76.784  51.629  1
174891  95.336  -76.796  51.586  1
174892  95.351  -76.809  51.540  1
174893  95.366  -76.822  51.492  1
174894  95.383  -76.828  51.444  1
174895  95.402  -76.829  51.395  1
174896  95.420  -76.831  51.346  1
174897  95.439  -76.832  51.297  1
174898  95.450  -76.834  51.251  1
174899  95.460  -76.837  51.204  1
174900  95.483  -76.851  51.157  1
174901  95.509  -76.868  51.111  1
174902  95.535  -76.884  51.068  1
174903  95.561  -76.902  51.026  1
174904  95.579  -76.920  50.985  1
174905  95.594  -76.939  50.944  1
174906  95.609  -76.957  50.903  1
174907  95.625  -76.976  50.863  1
174908  95.640  -76.994  50.823  1
174909  95.656  -77.012  50.782  1
174910  95.671  -77.017  50.743  1
174911  95.686  -77.022  50.704  1
174912  95.700  -77.028  50.665  1
174913  95.716  -77.033  50.625  1
174914  95.730  -77.038  50.585  1
174915  95.745  -77.044  50.545  1
174916  95.760  -77.049  50.504  1
174917  95.778  -77.057  50.465  1
174918  95.797  -77.066  50.425  1
174919  95.815  -77.074  50.383  1
174920  95.839  -77.082  50.339  1
174921  95.874  -77.090  50.291  1
174922  95.909  -77.097  50.240  1
174923  95.945  -77.105  50.188  1
174924  95.965  -77.107  50.137  1
174925  95.983  -77.109  50.082  1
174926  95.988  -77.108  50.021  1
174927  96.005  -77.108  49.955  1
174928  96.044  -77.110  49.884  1
174929  96.060  -77.110  49.813  1
174930  96.076  -77.108  49.747  1
174931  96.092  -77.108  49.686  1
174932  96.104  -77.114  49.627  1
174933  96.116  -77.119  49.574  1
174934  96.128  -77.125  49.523  1
174935  96.142  -77.142  49.475  1
174936  96.156  -77.159  49.433  1
174937  96.170  -77.175  49.395  1
174938  96.184  -77.192  49.360  1
174939  96.198  -77.209  49.327  1
174940  96.210  -77.226  49.296  1
174941  96.214  -77.247  49.265  1
174942  96.218  -77.267  49.236  1
174943  96.226  -77.283  49.207  1
174944  96.246  -77.288  49.183  1
174945  96.265  -77.293  49.160  1
174946  96.285  -77.298  49.139  1
174947  96.305  -77.301  49.119  1
174948  96.326  -77.298  49.100  1
174949  96.346  -77.297  49.082  1
174950  96.367  -77.295  49.065  1
174951  96.388  -77.294  49.050  1
174952  96.409  -77.291  49.035  1
174953  96.430  -77.290  49.019  1
174954  96.450  -77.288  49.005  1
174955  96.468  -77.296  48.987  1
174956  96.484  -77.312  48.970  1
174957  96.499  -77.329  48.954  1
174958  96.515  -77.345  48.941  1
174959  96.530  -77.361  48.926  1
174960  96.546  -77.377  48.911  1
174961  96.561  -77.393  48.896  1
174962  96.577  -77.410  48.880  1
174963  96.592  -77.426  48.864  1
174964  96.609  -77.439  48.847  1
174965  96.628  -77.450  48.832  1
174966  96.647  -77.460  48.818  1
174967  96.665  -77.470  48.805  1
174968  96.684  -77.480  48.792  1
174969  96.704  -77.491  48.779  1
174970  96.727  -77.502  48.767  1
174971  96.749  -77.513  48.754  1
174972  96.772  -77.524  48.742  1
174973  96.795  -77.535  48.729  1
174974  96.817  -77.546  48.715  1
174975  96.836  -77.563  48.701  1
174976  96.854  -77.583  48.686  1
174977  96.869  -77.588  48.669  1
174978  96.890  -77.590  48.652  1
174979  96.928  -77.604  48.634  1
174980  96.965  -77.618  48.615  1
174981  97.001  -77.633  48.596  1
174982  97.037  -77.647  48.577  1
174983  97.070  -77.667  48.559  1
174984  97.093  -77.681  48.539  1
174985  97.102  -77.670  48.522  1
174986  97.111  -77.658  48.505  1
174987  97.120  -77.646  48.488  1
174988  97.129  -77.635  48.472  1
174989  97.138  -77.624  48.454  1
174990  97.148  -77.612  48.433  1
174991  97.157  -77.601  48.412  1
174992  97.166  -77.589  48.390  1
174993  97.175  -77.577  48.369  1
174994  97.183  -77.564  48.348  1
174995  97.190  -77.548  48.324  1
174996  97.197  -77.533  48.300  1
174997  97.205  -77.518  48.277  1
174998  97.212  -77.503  48.254  1
174999  97.244  -77.498  48.232  1
175000  97.267  -77.507  48.210  1
175001  97.289  -77.515  48.188  1
175002  97.312  -77.523  48.166  1
175003  97.334  -77.531  48.145  1
175004  97.357  -77.539  48.125  1
175005  97.380  -77.547  48.105  1
175006  97.402  -77.555  48.082  1
175007  97.425  -77.564  48.059  1
175008  97.447  -77.571  48.035  1
175009  97.470  -77.580  48.010  1
175010  97.493  -77.588  47.984  1
175011  97.515  -77.595  47.958  1
175012  97.538  -77.604  47.930  1
175013  97.561  -77.612  47.902  1
175014  97.583  -77.620  47.875  1
175015  97.605  -77.629  47.847  1
175016  97.624  -77.641  47.818  1
175017  97.654  -77.645  47.790  1
175018  97.688  -77.648  47.763  1
175019  97.706  -77.646  47.735  1
175020  97.726  -77.645  47.707  1
175021  97.745  -77.644  47.679  1
175022  97.770  -77.647  47.650  1
175023  97.807  -77.658  47.621  1
175024  97.845  -77.671  47.594  1
175025  97.882  -77.683  47.565  1
175026  97.919  -77.695  47.537  1
175027  97.951  -77.701  47.509  1
175028  97.968  -77.691  47.482  1
175029  97.986  -77.680  47.456  1
175030  98.003  -77.671  47.428  1
175031  98.016  -77.661  47.400  1
175032  97.977  -77.645  47.372  1
175033  97.939  -77.629  47.342  1
175034  97.963  -77.574  47.311  1
175035  97.988  -77.520  47.281  1
175036  98.013  -77.465  47.252  1
175037  98.038  -77.411  47.226  1
175038  98.061  -77.373  47.199  1
175039  98.081  -77.373  47.170  1
175040  98.101  -77.373  47.145  1
175041  98.129  -77.394  47.119  1
175042  98.160  -77.430  47.092  1
175043  98.192  -77.467  47.065  1
175044  98.223  -77.503  47.039  1
175045  98.254  -77.539  47.012  1
175046  98.286  -77.576  46.984  1
175047  98.317  -77.612  46.955  1
175048  98.349  -77.649  46.927  1
175049  98.356  -77.667  46.899  1
175050  98.352  -77.677  46.872  1
175051  98.349  -77.687  46.845  1
175052  98.351  -77.692  46.819  1
175053  98.354  -77.696  46.794  1
175054  98.364  -77.700  46.769  1
175055  98.377  -77.708  46.745  1
175056  98.381  -77.712  46.722  1
175057  98.404  -77.710  46.699  1
175058  98.438  -77.702  46.677  1
175059  98.467  -77.696  46.654  1
175060  98.491  -77.692  46.632  1
175061  98.515  -77.689  46.611  1
175062  98.540  -77.689  46.591  1
175063  98.564  -77.688  46.570  1
175064  98.588  -77.687  46.548  1
175065  98.613  -77.686  46.524  1
175066  98.635  -77.688  46.501  1
175067  98.646  -77.702  46.481  1
175068  98.667  -77.707  46.463  1
175069  98.688  -77.713  46.443  1
175070  98.709  -77.718  46.422  1
175071  98.725  -77.717  46.400  1
175072  98.732  -77.724  46.380  1
175073  98.738  -77.732  46.358  1
175074  98.745  -77.740  46.339  1
175075  98.751  -77.746  46.318  1
175076  98.756  -77.752  46.296  1
175077  98.757  -77.753  46.275  1
175078  98.759  -77.755  46.254  1
175079  98.760  -77.756  46.231  1
175080  98.762  -77.757  46.209  1
175081  98.764  -77.758  46.188  1
175082  98.765  -77.760  46.168  1
175083  98.767  -77.762  46.147  1
175084  98.768  -77.765  46.127  1
175085  98.769  -77.769  46.106  1
175086  98.769  -77.772  46.085  1
175087  98.809  -77.780  46.065  1
175088  98.850  -77.787  46.047  1
175089  98.887  -77.794  46.029  1
175090  98.917  -77.799  46.012  1
175091  98.948  -77.803  45.995  1
175092  98.978  -77.808  45.979  1
175093  99.008  -77.812  45.963  1
175094  99.039  -77.817  45.947  1
175095  99.069  -77.822  45.932  1
175096  99.090  -77.833  45.918  1
175097  99.111  -77.845  45.904  1
175098  99.132  -77.856  45.891  1
175099  99.152  -77.868  45.878  1
175100  99.172  -77.881  45.866  1
175101  99.193  -77.892  45.855  1
175102  99.225  -77.910  45.846  1
175103  99.259  -77.928  45.836  1
175104  99.296  -77.940  45.826  1
175105  99.335  -77.945  45.816  1
175106  99.352  -77.956  45.807  1
175107  99.358  -77.969  45.798  1
175108  99.363  -77.983  45.790  1
175109  99.368  -77.996  45.782  1
175110  99.373  -78.010  45.774  1
175111  99.379  -78.025  45.767  1
175112  99.384  -78.038  45.759  1
175113  99.397  -78.046  45.751  1
175114  99.440  -78.050  45.741  1
175115  99.477  -78.053  45.731  1
175116  99.519  -78.059  45.720  1
175117  99.562  -78.066  45.707  1
175118  99.595  -78.084  45.695  1
175119  99.620  -78.103  45.683  1
175120  99.631  -78.116  45.670  1
175121  99.642  -78.128  45.658  1
175122  99.653  -78.140  45.645  1
175123  99.673  -78.141  45.631  1
175124  99.704  -78.128  45.616  1
175125  99.743  -78.146  45.603  1
175126  99.786  -78.181  45.587  1
175127  99.830  -78.217  45.571  1
175128  99.873  -78.253  45.556  1
175129  99.915  -78.283  45.540  1
175130  99.947  -78.290  45.524  1
175131  99.980  -78.296  45.507  1
175132  100.012  -78.302  45.491  1
175133  100.044  -78.309  45.474  1
175134  100.076  -78.315  45.459  1
175135  100.109  -78.321  45.443  1
175136  100.115  -78.333  45.429  1
175137  100.120  -78.344  45.413  1
175138  100.125  -78.357  45.398  1
175139  100.130  -78.368  45.383  1
175140  100.135  -78.380  45.368  1
175141  100.150  -78.389  45.353  1
175142  100.180  -78.394  45.338  1
175143  100.210  -78.399  45.322  1
175144  100.240  -78.404  45.305  1
175145  100.269  -78.409  45.289  1
175146  100.299  -78.413  45.273  1
175147  100.329  -78.419  45.257  1
175148  100.359  -78.423  45.241  1
175149  100.388  -78.429  45.226  1
175150  100.419  -78.433  45.212  1
175151  100.444  -78.437  45.197  1
175152  100.479  -78.445  45.183  1
175153  100.532  -78.453  45.168  1
175154  100.575  -78.460  45.154  1
175155  100.608  -78.467  45.138  1
175156  100.641  -78.475  45.122  1
175157  100.679  -78.482  45.105  1
175158  100.719  -78.489  45.089  1
175159  100.759  -78.495  45.073  1
175160  100.799  -78.502  45.057  1
175161  100.839  -78.508  45.040  1
175162  100.879  -78.515  45.024  1
175163  100.912  -78.521  45.009  1
175164  100.938  -78.526  44.994  1
175165  100.937  -78.511  44.980  1
175166  100.927  -78.488  44.965  1
175167  100.932  -78.479  44.950  1
175168  100.976  -78.506  44.935  1
175169  101.021  -78.532  44.920  1
175170  101.060  -78.545  44.904  1
175171  101.095  -78.529  44.888  1
175172  101.148  -78.518  44.872  1
175173  101.207  -78.534  44.856  1
175174  101.235  -78.550  44.841  1
175175  101.257  -78.566  44.825  1
175176  101.279  -78.582  44.809  1
175177  101.301  -78.598  44.792  1
175178  101.323  -78.614  44.777  1
175179  101.345  -78.630  44.763  1
175180  101.371  -78.651  44.748  1
175181  101.397  -78.672  44.733  1
175182  101.422  -78.694  44.718  1
175183  101.448  -78.715  44.702  1
175184  101.474  -78.737  44.687  1
175185  101.499  -78.759  44.673  1
175186  101.525  -78.780  44.658  1
175187  101.550  -78.802  44.642  1
175188  101.576  -78.824  44.627  1
175189  101.602  -78.846  44.613  1
175190  101.627  -78.868  44.599  1
175191  101.653  -78.890  44.585  1
175192  101.688  -78.906  44.571  1
175193  101.705  -78.912  44.558  1
175194  101.722  -78.918  44.544  1
175195  101.739  -78.923  44.531  1
175196  101.755  -78.929  44.517  1
175197  101.772  -78.934  44.505  1
175198  101.789  -78.940  44.493  1
175199  101.806  -78.946  44.481  1
175200  101.822  -78.951  44.469  1
175201  101.839  -78.957  44.457  1
175202  101.856  -78.962  44.445  1
175203  101.873  -78.968  44.432  1
175204  101.889  -78.974  44.420  1
175205  101.906  -78.979  44.409  1
175436  92.678  -77.065  54.054  1
175437  92.701  -77.076  54.062  1
175438  92.710  -77.088  54.070  1
175439  92.717  -77.101  54.078  1
175440  92.724  -77.113  54.087  1
175441  92.731  -77.126  54.095  1
175442  92.738  -77.138  54.102  1
175443  92.745  -77.151  54.108  1
175444  92.758  -77.155  54.114  1
175445  92.778  -77.146  54.120  1
175446  92.798  -77.138  54.126  1
175447  92.818  -77.128  54.133  1
175448  92.839  -77.120  54.140  1
175449  92.859  -77.111  54.147  1
175450  92.879  -77.103  54.153  1
175451  92.900  -77.094  54.158  1
175452  92.920  -77.085  54.164  1
175453  92.941  -77.076  54.170  1
175454  92.961  -77.067  54.176  1
175455  92.981  -77.059  54.183  1
175456  93.002  -77.050  54.191  1
175457  93.022  -77.041  54.198  1
175458  93.043  -77.032  54.204  1
175459  93.063  -77.023  54.210  1
175460  93.083  -77.015  54.217  1
175461  93.103  -77.006  54.224  1
175462  93.124  -76.997  54.231  1
175463  93.144  -76.988  54.239  1
175464  93.164  -76.980  54.245  1
175465  93.184  -76.975  54.250  1
175466  93.203  -76.972  54.250  1
175467  93.222  -76.969  54.252  1
175468  93.241  -76.965  54.256  1
175469  93.255  -76.961  54.261  1
175470  93.263  -76.956  54.265  1
175471  93.271  -76.950  54.268  1
175472  93.279  -76.943  54.271  1
175473  93.287  -76.938  54.274  1
175474  93.313  -76.932  54.272  1
175475  93.352  -76.926  54.271  1
175476  93.379  -76.918  54.270  1
175477  93.386  -76.908  54.267  1
175478  93.392  -76.897  54.268  1
175479  93.399  -76.887  54.271  1
175480  93.411  -76.879  54.274  1
175481  93.429  -76.875  54.274  1
175482  93.452  -76.875  54.274  1
175483  93.475  -76.875  54.276  1
175484  93.497  -76.875  54.278  1
175485  93.520  -76.875  54.279  1
175486  93.543  -76.876  54.283  1
175487  93.565  -76.876  54.286  1
175488  93.588  -76.876  54.288  1
175489  93.604  -76.870  54.285  1
175490  93.617  -76.857  54.281  1
175491  93.629  -76.844  54.276  1
175492  93.641  -76.831  54.269  1
175493  93.660  -76.829  54.263  1
175494  93.681  -76.828  54.257  1
175495  93.703  -76.828  54.250  1
175496  93.718  -76.820  54.242  1
175497  93.732  -76.812  54.232  1
175498  93.751  -76.809  54.220  1
175499  93.769  -76.806  54.207  1
175500  93.788  -76.802  54.192  1
175501  93.806  -76.799  54.177  1
175502  93.825  -76.796  54.161  1
175503  93.843  -76.793  54.146  1
175504  93.862  -76.790  54.134  1
175505  93.880  -76.787  54.123  1
175506  93.901  -76.784  54.114  1
175507  93.918  -76.779  54.103  1
175508  93.935  -76.775  54.090  1
175509  93.952  -76.771  54.078  1
175510  93.969  -76.768  54.068  1
175511  93.986  -76.764  54.061  1
175512  94.003  -76.761  54.057  1
175513  94.020  -76.757  54.056  1
175514  94.037  -76.753  54.056  1
175515  94.054  -76.749  54.053  1
175516  94.071  -76.746  54.050  1
175517  94.074  -76.748  54.048  1
175518  94.078  -76.750  54.044  1
175519  94.093  -76.748  54.038  1
175520  94.119  -76.740  54.032  1
175521  94.129  -76.738  54.024  1
175522  94.138  -76.735  54.012  1
175523  94.148  -76.732  53.998  1
175524  94.157  -76.729  53.984  1
175525  94.157  -76.730  53.969  1
175526  94.145  -76.734  53.954  1
175527  94.134  -76.739  53.939  1
175528  94.151  -76.734  53.922  1
175529  94.172  -76.727  53.905  1
175530  94.192  -76.721  53.888  1
175531  94.221  -76.712  53.870  1
175532  94.251  -76.703  53.853  1
175533  94.281  -76.693  53.836  1
175534  94.311  -76.684  53.814  1
175535  94.333  -76.676  53.788  1
175536  94.349  -76.670  53.756  1
175537  94.365  -76.663  53.724  1
175538  94.382  -76.656  53.691  1
175539  94.398  -76.651  53.657  1
175540  94.416  -76.648  53.621  1
175541  94.433  -76.645  53.586  1
175542  94.450  -76.642  53.550  1
175543  94.454  -76.642  53.515  1
175544  94.456  -76.643  53.483  1
175545  94.459  -76.643  53.452  1
175546  94.467  -76.640  53.424  1
175547  94.477  -76.634  53.397  1
175548  94.490  -76.630  53.369  1
175549  94.534  -76.624  53.341  1
175550  94.578  -76.618  53.311  1
175551  94.623  -76.611  53.283  1
175552  94.659  -76.611  53.251  1
175553  94.677  -76.606  53.219  1
175554  94.714  -76.599  53.187  1
175555  94.760  -76.589  53.154  1
175556  94.796  -76.579  53.123  1
175557  94.814  -76.572  53.093  1
175558  94.822  -76.566  53.065  1
175559  94.827  -76.560  53.040  1
175560  94.833  -76.553  53.012  1
175561  94.838  -76.547  52.983  1
175562  94.844  -76.541  52.953  1
175563  94.866  -76.548  52.922  1
175564  94.891  -76.558  52.892  1
175565  94.916  -76.567  52.861  1
175566  94.942  -76.577  52.829  1
175567  94.962  -76.585  52.792  1
175568  94.970  -76.586  52.752  1
175569  94.977  -76.588  52.709  1
175570  94.985  -76.589  52.662  1
175571  94.992  -76.591  52.614  1
175572  95.000  -76.592  52.564  1
175573  95.007  -76.594  52.514  1
175574  95.015  -76.596  52.462  1
175575  95.023  -76.598  52.409  1
175576  95.030  -76.599  52.355  1
175577  95.048  -76.603  52.300  1
175578  95.085  -76.611  52.246  1
175579  95.122  -76.618  52.193  1
175580  95.160  -76.626  52.141  1
175581  95.193  -76.634  52.090  1
175582  95.202  -76.648  52.041  1
175583  95.211  -76.661  51.992  1
175584  95.221  -76.675  51.943  1
175585  95.231  -76.688  51.896  1
175586  95.244  -76.702  51.851  1
175587  95.259  -76.715  51.807  1
175588  95.273  -76.727  51.764  1
175589  95.288  -76.740  51.724  1
175590  95.303  -76.753  51.684  1
175591  95.317  -76.766  51.645  1
175592  95.332  -76.779  51.601  1
175593  95.347  -76.792  51.555  1
175594  95.361  -76.805  51.507  1
175595  95.376  -76.818  51.459  1
175596  95.395  -76.819  51.412  1
175597  95.413  -76.821  51.365  1
175598  95.428  -76.823  51.319  1
175599  95.439  -76.825  51.274  1
175600  95.450  -76.828  51.228  1
175601  95.471  -76.840  51.182  1
175602  95.497  -76.857  51.135  1
175603  95.523  -76.874  51.092  1
175604  95.549  -76.891  51.050  1
175605  95.574  -76.908  51.009  1
175606  95.593  -76.926  50.968  1
175607  95.608  -76.945  50.928  1
175608  95.624  -76.963  50.888  1
175609  95.639  -76.982  50.848  1
175610  95.655  -76.998  50.808  1
175611  95.669  -77.003  50.769  1
175612  95.684  -77.009  50.729  1
175613  95.699  -77.014  50.689  1
175614  95.714  -77.019  50.650  1
175615  95.729  -77.025  50.610  1
175616  95.745  -77.031  50.569  1
175617  95.763  -77.040  50.527  1
175618  95.782  -77.048  50.486  1
175619  95.801  -77.057  50.444  1
175620  95.819  -77.066  50.401  1
175621  95.846  -77.073  50.356  1
175622  95.882  -77.081  50.306  1
175623  95.917  -77.088  50.253  1
175624  95.953  -77.096  50.200  1
175625  95.988  -77.103  50.147  1
175626  96.010  -77.106  50.090  1
175627  96.030  -77.106  50.026  1
175628  96.046  -77.106  49.959  1
175629  96.062  -77.104  49.890  1
175630  96.079  -77.103  49.821  1
175631  96.095  -77.102  49.757  1
175632  96.111  -77.101  49.696  1
175633  96.128  -77.100  49.639  1
175634  96.142  -77.103  49.586  1
175635  96.154  -77.109  49.536  1
175636  96.167  -77.120  49.488  1
175637  96.181  -77.137  49.446  1
175638  96.195  -77.153  49.409  1
175639  96.208  -77.170  49.374  1
175640  96.214  -77.191  49.341  1
175641  96.217  -77.211  49.310  1
175642  96.221  -77.232  49.279  1
175643  96.225  -77.252  49.250  1
175644  96.242  -77.260  49.221  1
175645  96.261  -77.265  49.198  1
175646  96.281  -77.269  49.175  1
175647  96.300  -77.275  49.153  1
175648  96.320  -77.279  49.134  1
175649  96.340  -77.284  49.115  1
175650  96.361  -77.282  49.098  1
175651  96.381  -77.280  49.081  1
175652  96.402  -77.279  49.068  1
175653  96.422  -77.276  49.053  1
175654  96.444  -77.275  49.038  1
175655  96.464  -77.273  49.023  1
175656  96.483  -77.279  49.006  1
175657  96.499  -77.294  48.989  1
175658  96.514  -77.311  48.973  1
175659  96.529  -77.327  48.959  1
175660  96.545  -77.344  48.944  1
175661  96.560  -77.360  48.929  1
175662  96.576  -77.376  48.913  1
175663  96.591  -77.392  48.896  1
175664  96.609  -77.405  48.879  1
175665  96.627  -77.415  48.863  1
175666  96.646  -77.426  48.847  1
175667  96.665  -77.436  48.832  1
175668  96.683  -77.446  48.818  1
175669  96.702  -77.457  48.805  1
175670  96.722  -77.467  48.792  1
175671  96.744  -77.478  48.779  1
175672  96.766  -77.489  48.766  1
175673  96.789  -77.500  48.753  1
175674  96.807  -77.520  48.740  1
175675  96.825  -77.541  48.727  1
175676  96.841  -77.557  48.712  1
175677  96.857  -77.562  48.696  1
175678  96.872  -77.567  48.678  1
175679  96.888  -77.572  48.660  1
175680  96.933  -77.578  48.642  1
175681  96.969  -77.593  48.622  1
175682  97.006  -77.608  48.602  1
175683  97.042  -77.622  48.583  1
175684  97.074  -77.643  48.564  1
175685  97.102  -77.668  48.545  1
175686  97.121  -77.673  48.527  1
175687  97.130  -77.661  48.509  1
175688  97.139  -77.650  48.491  1
175689  97.148  -77.639  48.475  1
175690  97.157  -77.627  48.457  1
175691  97.167  -77.616  48.438  1
175692  97.176  -77.604  48.418  1
175693  97.185  -77.592  48.397  1
175694  97.194  -77.581  48.375  1
175695  97.202  -77.567  48.354  1
175696  97.209  -77.551  48.330  1
175697  97.216  -77.536  48.307  1
175698  97.223  -77.521  48.284  1
175699  97.230  -77.506  48.262  1
175700  97.249  -77.495  48.241  1
175701  97.277  -77.501  48.219  1
175702  97.300  -77.508  48.197  1
175703  97.322  -77.517  48.175  1
175704  97.345  -77.525  48.155  1
175705  97.367  -77.533  48.134  1
175706  97.390  -77.541  48.113  1
175707  97.413  -77.549  48.091  1
175708  97.435  -77.557  48.069  1
175709  97.458  -77.565  48.045  1
175710  97.480  -77.573  48.020  1
175711  97.503  -77.581  47.994  1
175712  97.525  -77.589  47.968  1
175713  97.548  -77.598  47.940  1
175714  97.571  -77.606  47.912  1
175715  97.590  -77.618  47.884  1
175716  97.609  -77.630  47.855  1
175717  97.631  -77.638  47.826  1
175718  97.667  -77.640  47.798  1
175719  97.713  -77.647  47.770  1
175720  97.733  -77.644  47.742  1
175721  97.750  -77.642  47.714  1
175722  97.770  -77.641  47.686  1
175723  97.789  -77.640  47.658  1
175724  97.820  -77.647  47.629  1
175725  97.858  -77.659  47.600  1
175726  97.895  -77.671  47.572  1
175727  97.932  -77.683  47.544  1
175728  97.960  -77.686  47.516  1
175729  97.978  -77.675  47.489  1
175730  97.996  -77.665  47.463  1
175731  98.013  -77.655  47.436  1
175732  98.030  -77.645  47.407  1
175733  98.006  -77.631  47.378  1
175734  97.968  -77.615  47.348  1
175735  97.990  -77.563  47.317  1
175736  98.014  -77.508  47.286  1
175737  98.039  -77.454  47.258  1
175738  98.065  -77.399  47.231  1
175739  98.085  -77.397  47.204  1
175740  98.105  -77.396  47.175  1
175741  98.125  -77.396  47.149  1
175742  98.145  -77.395  47.123  1
175743  98.165  -77.395  47.097  1
175744  98.197  -77.432  47.071  1
175745  98.228  -77.467  47.044  1
175746  98.260  -77.504  47.017  1
175747  98.291  -77.540  46.989  1
175748  98.323  -77.577  46.961  1
175749  98.354  -77.613  46.934  1
175750  98.382  -77.646  46.907  1
175751  98.378  -77.657  46.880  1
175752  98.374  -77.667  46.852  1
175753  98.370  -77.678  46.826  1
175754  98.371  -77.684  46.801  1
175755  98.377  -77.688  46.777  1
175756  98.397  -77.688  46.752  1
175757  98.416  -77.688  46.729  1
175758  98.430  -77.690  46.706  1
175759  98.456  -77.686  46.684  1
175760  98.486  -77.680  46.660  1
175761  98.510  -77.677  46.638  1
175762  98.534  -77.673  46.617  1
175763  98.559  -77.670  46.597  1
175764  98.583  -77.667  46.576  1
175765  98.607  -77.666  46.554  1
175766  98.631  -77.665  46.531  1
175767  98.649  -77.672  46.509  1
175768  98.669  -77.678  46.489  1
175769  98.690  -77.684  46.470  1
175770  98.711  -77.689  46.450  1
175771  98.731  -77.696  46.430  1
175772  98.745  -77.697  46.409  1
175773  98.751  -77.705  46.388  1
175774  98.758  -77.712  46.366  1
175775  98.764  -77.720  46.347  1
175776  98.771  -77.727  46.328  1
175777  98.777  -77.735  46.306  1
175778  98.782  -77.740  46.285  1
175779  98.783  -77.741  46.263  1
175780  98.785  -77.743  46.241  1
175781  98.787  -77.744  46.219  1
175782  98.788  -77.746  46.197  1
175783  98.790  -77.748  46.176  1
175784  98.791  -77.751  46.154  1
175785  98.792  -77.754  46.134  1
175786  98.792  -77.758  46.112  1
175787  98.793  -77.761  46.091  1
175788  98.814  -77.766  46.071  1
175789  98.854  -77.774  46.052  1
175790  98.885  -77.779  46.034  1
175791  98.916  -77.783  46.016  1
175792  98.946  -77.788  45.999  1
175793  98.976  -77.793  45.982  1
175794  99.006  -77.797  45.966  1
175795  99.037  -77.802  45.950  1
175796  99.067  -77.806  45.936  1
175797  99.097  -77.811  45.921  1
175798  99.118  -77.823  45.908  1
175799  99.139  -77.834  45.894  1
175800  99.159  -77.846  45.882  1
175801  99.180  -77.858  45.870  1
175802  99.204  -77.871  45.859  1
175803  99.237  -77.890  45.849  1
175804  99.271  -77.909  45.839  1
175805  99.305  -77.927  45.829  1
175806  99.343  -77.934  45.820  1
175807  99.356  -77.946  45.812  1
175808  99.362  -77.960  45.803  1
175809  99.367  -77.974  45.795  1
175810  99.372  -77.987  45.787  1
175811  99.377  -78.001  45.780  1
175812  99.383  -78.015  45.772  1
175813  99.388  -78.029  45.764  1
175814  99.394  -78.043  45.756  1
175815  99.433  -78.050  45.747  1
175816  99.476  -78.056  45.736  1
175817  99.518  -78.062  45.725  1
175818  99.561  -78.069  45.713  1
175819  99.597  -78.083  45.701  1
175820  99.621  -78.103  45.689  1
175821  99.632  -78.115  45.677  1
175822  99.643  -78.127  45.665  1
175823  99.659  -78.132  45.652  1
175824  99.690  -78.119  45.638  1
175825  99.720  -78.106  45.624  1
175826  99.761  -78.129  45.610  1
175827  99.805  -78.165  45.595  1
175828  99.848  -78.201  45.580  1
175829  99.892  -78.237  45.564  1
175830  99.929  -78.252  45.549  1
175831  99.965  -78.267  45.532  1
175832  100.001  -78.282  45.515  1
175833  100.034  -78.291  45.499  1
175834  100.067  -78.297  45.482  1
175835  100.099  -78.304  45.466  1
175836  100.123  -78.311  45.451  1
175837  100.128  -78.323  45.436  1
175838  100.133  -78.335  45.421  1
175839  100.138  -78.347  45.406  1
175840  100.143  -78.359  45.391  1
175841  100.148  -78.370  45.376  1
175842  100.153  -78.382  45.361  1
175843  100.179  -78.388  45.345  1
175844  100.209  -78.393  45.329  1
175845  100.239  -78.398  45.313  1
175846  100.269  -78.403  45.297  1
175847  100.298  -78.408  45.281  1
175848  100.328  -78.413  45.265  1
175849  100.358  -78.418  45.250  1
175850  100.388  -78.423  45.234  1
175851  100.418  -78.428  45.219  1
175852  100.447  -78.432  45.204  1
175853  100.479  -78.436  45.190  1
175854  100.519  -78.442  45.175  1
175855  100.560  -78.449  45.161  1
175856  100.600  -78.456  45.144  1
175857  100.640  -78.462  45.128  1
175858  100.680  -78.469  45.112  1
175859  100.720  -78.476  45.096  1
175860  100.760  -78.482  45.079  1
175861  100.800  -78.489  45.063  1
175862  100.840  -78.495  45.047  1
175863  100.878  -78.501  45.030  1
175864  100.904  -78.507  45.015  1
175865  100.930  -78.513  45.000  1
175866  100.957  -78.518  44.986  1
175867  100.948  -78.497  44.971  1
175868  100.938  -78.473  44.956  1
175869  100.982  -78.500  44.941  1
175870  101.026  -78.527  44.925  1
175871  101.060  -78.526  44.910  1
175872  101.107  -78.509  44.894  1
175873  101.162  -78.507  44.877  1
175874  101.209  -78.523  44.861  1
175875  101.232  -78.539  44.846  1
175876  101.253  -78.554  44.830  1
175877  101.275  -78.570  44.814  1
175878  101.298  -78.586  44.798  1
175879  101.321  -78.602  44.782  1
175880  101.347  -78.620  44.767  1
175881  101.374  -78.641  44.753  1
175882  101.400  -78.662  44.738  1
175883  101.426  -78.683  44.722  1
175884  101.453  -78.705  44.705  1
175885  101.479  -78.726  44.691  1
175886  101.505  -78.747  44.677  1
175887  101.532  -78.768  44.662  1
175888  101.558  -78.789  44.647  1
175889  101.585  -78.811  44.632  1
175890  101.611  -78.832  44.616  1
175891  101.637  -78.853  44.602  1
175892  101.664  -78.874  44.588  1
175893  101.689  -78.893  44.574  1
175894  101.705  -78.899  44.561  1
175895  101.722  -78.905  44.547  1
175896  101.739  -78.910  44.534  1
175897  101.756  -78.916  44.520  1
175898  101.772  -78.921  44.507  1
175899  101.790  -78.927  44.496  1
175900  101.806  -78.933  44.483  1
175901  101.823  -78.939  44.471  1
175902  101.840  -78.944  44.459  1
175903  101.856  -78.949  44.447  1
175904  101.873  -78.955  44.434  1
175905  101.890  -78.961  44.422  1
175906  101.907  -78.967  44.411  1
175907  101.923  -78.972  44.400  1
176141  92.717  -77.084  54.059  1
176142  92.724  -77.097  54.067  1
176143  92.731  -77.109  54.074  1
176144  92.738  -77.122  54.081  1
176145  92.747  -77.132  54.087  1
176146  92.768  -77.122  54.093  1
176147  92.788  -77.114  54.100  1
176148  92.808  -77.105  54.108  1
176149  92.829  -77.096  54.115  1
176150  92.849  -77.088  54.122  1
176151  92.869  -77.078  54.129  1
176152  92.889  -77.070  54.135  1
176153  92.910  -77.061  54.141  1
176154  92.930  -77.053  54.148  1
176155  92.950  -77.044  54.156  1
176156  92.971  -77.035  54.163  1
176157  92.991  -77.026  54.171  1
176158  93.011  -77.017  54.179  1
176159  93.032  -77.009  54.186  1
176160  93.052  -77.000  54.193  1
176161  93.073  -76.991  54.200  1
176162  93.093  -76.982  54.208  1
176163  93.113  -76.974  54.215  1
176164  93.134  -76.965  54.222  1
176165  93.154  -76.956  54.227  1
176166  93.174  -76.952  54.231  1
176167  93.193  -76.949  54.235  1
176168  93.212  -76.945  54.241  1
176169  93.231  -76.942  54.247  1
176170  93.250  -76.939  54.252  1
176171  93.269  -76.936  54.258  1
176172  93.289  -76.932  54.262  1
176173  93.302  -76.928  54.265  1
176174  93.310  -76.922  54.266  1
176175  93.319  -76.916  54.265  1
176176  93.348  -76.910  54.264  1
176177  93.373  -76.902  54.262  1
176178  93.379  -76.892  54.260  1
176179  93.389  -76.883  54.261  1
176180  93.403  -76.875  54.264  1
176181  93.416  -76.867  54.268  1
176182  93.430  -76.859  54.271  1
176183  93.450  -76.858  54.274  1
176184  93.473  -76.858  54.278  1
176185  93.495  -76.858  54.282  1
176186  93.518  -76.858  54.284  1
176187  93.541  -76.858  54.287  1
176188  93.563  -76.859  54.291  1
176189  93.583  -76.856  54.292  1
176190  93.601  -76.852  54.290  1
176191  93.617  -76.847  54.287  1
176192  93.630  -76.834  54.283  1
176193  93.642  -76.821  54.278  1
176194  93.659  -76.815  54.273  1
176195  93.678  -76.812  54.267  1
176196  93.697  -76.811  54.259  1
176197  93.716  -76.807  54.251  1
176198  93.733  -76.802  54.242  1
176199  93.751  -76.799  54.230  1
176200  93.770  -76.796  54.217  1
176201  93.788  -76.793  54.203  1
176202  93.806  -76.789  54.188  1
176203  93.825  -76.786  54.173  1
176204  93.843  -76.782  54.159  1
176205  93.861  -76.777  54.148  1
176206  93.878  -76.772  54.137  1
176207  93.895  -76.770  54.127  1
176208  93.913  -76.768  54.117  1
176209  93.930  -76.766  54.105  1
176210  93.947  -76.762  54.093  1
176211  93.964  -76.759  54.081  1
176212  93.981  -76.755  54.074  1
176213  93.998  -76.751  54.069  1
176214  94.015  -76.748  54.066  1
176215  94.032  -76.744  54.067  1
176216  94.049  -76.740  54.067  1
176217  94.066  -76.737  54.067  1
176218  94.077  -76.735  54.066  1
176219  94.080  -76.737  54.064  1
176220  94.101  -76.733  54.061  1
176221  94.115  -76.729  54.055  1
176222  94.125  -76.726  54.048  1
176223  94.134  -76.723  54.036  1
176224  94.143  -76.721  54.022  1
176225  94.153  -76.718  54.008  1
176226  94.159  -76.715  53.994  1
176227  94.148  -76.720  53.980  1
176228  94.136  -76.724  53.965  1
176229  94.156  -76.719  53.949  1
176230  94.177  -76.713  53.932  1
176231  94.198  -76.707  53.913  1
176232  94.219  -76.700  53.894  1
176233  94.249  -76.691  53.875  1
176234  94.279  -76.681  53.857  1
176235  94.309  -76.672  53.836  1
176236  94.328  -76.665  53.810  1
176237  94.344  -76.658  53.779  1
176238  94.360  -76.651  53.748  1
176239  94.377  -76.644  53.716  1
176240  94.393  -76.637  53.682  1
176241  94.409  -76.633  53.646  1
176242  94.427  -76.630  53.610  1
176243  94.441  -76.628  53.573  1
176244  94.443  -76.628  53.535  1
176245  94.447  -76.628  53.502  1
176246  94.456  -76.624  53.469  1
176247  94.466  -76.619  53.438  1
176248  94.476  -76.614  53.408  1
176249  94.496  -76.609  53.378  1
176250  94.540  -76.603  53.347  1
176251  94.584  -76.597  53.316  1
176252  94.626  -76.592  53.284  1
176253  94.659  -76.594  53.252  1
176254  94.678  -76.589  53.220  1
176255  94.695  -76.585  53.189  1
176256  94.737  -76.576  53.159  1
176257  94.784  -76.566  53.130  1
176258  94.803  -76.558  53.102  1
176259  94.808  -76.552  53.076  1
176260  94.814  -76.546  53.055  1
176261  94.819  -76.540  53.029  1
176262  94.825  -76.533  53.001  1
176263  94.848  -76.542  52.971  1
176264  94.873  -76.552  52.938  1
176265  94.899  -76.561  52.908  1
176266  94.918  -76.568  52.879  1
176267  94.925  -76.570  52.850  1
176268  94.933  -76.571  52.815  1
176269  94.941  -76.574  52.777  1
176270  94.948  -76.575  52.735  1
176271  94.956  -76.577  52.688  1
176272  94.963  -76.578  52.639  1
176273  94.971  -76.580  52.590  1
176274  94.978  -76.581  52.539  1
176275  94.986  -76.583  52.488  1
176276  94.993  -76.585  52.436  1
176277  95.001  -76.586  52.383  1
176278  95.019  -76.590  52.327  1
176279  95.056  -76.598  52.274  1
176280  95.093  -76.605  52.220  1
176281  95.130  -76.613  52.167  1
176282  95.168  -76.621  52.115  1
176283  95.197  -76.630  52.064  1
176284  95.206  -76.643  52.014  1
176285  95.216  -76.657  51.964  1
176286  95.226  -76.671  51.916  1
176287  95.240  -76.683  51.871  1
176288  95.254  -76.696  51.826  1
176289  95.269  -76.709  51.781  1
176290  95.283  -76.722  51.739  1
176291  95.299  -76.735  51.697  1
176292  95.313  -76.748  51.655  1
176293  95.328  -76.761  51.611  1
176294  95.342  -76.774  51.566  1
176295  95.357  -76.787  51.521  1
176296  95.372  -76.799  51.474  1
176297  95.387  -76.810  51.429  1
176298  95.406  -76.812  51.385  1
176299  95.418  -76.814  51.342  1
176300  95.429  -76.816  51.298  1
176301  95.440  -76.818  51.254  1
176302  95.459  -76.829  51.208  1
176303  95.485  -76.846  51.161  1
176304  95.511  -76.863  51.116  1
176305  95.536  -76.881  51.074  1
176306  95.562  -76.897  51.033  1
176307  95.588  -76.915  50.992  1
176308  95.607  -76.933  50.953  1
176309  95.622  -76.951  50.915  1
176310  95.638  -76.970  50.876  1
176311  95.653  -76.984  50.835  1
176312  95.668  -76.990  50.796  1
176313  95.683  -76.995  50.755  1
176314  95.697  -77.000  50.714  1
176315  95.712  -77.006  50.675  1
176316  95.731  -77.014  50.635  1
176317  95.749  -77.022  50.593  1
176318  95.768  -77.031  50.550  1
176319  95.787  -77.040  50.506  1
176320  95.805  -77.048  50.463  1
176321  95.824  -77.056  50.419  1
176322  95.853  -77.065  50.372  1
176323  95.889  -77.072  50.319  1
176324  95.924  -77.079  50.265  1
176325  95.960  -77.087  50.211  1
176326  95.995  -77.094  50.156  1
176327  96.026  -77.100  50.096  1
176328  96.043  -77.104  50.031  1
176329  96.061  -77.101  49.964  1
176330  96.080  -77.099  49.896  1
176331  96.098  -77.097  49.829  1
176332  96.114  -77.096  49.766  1
176333  96.130  -77.095  49.707  1
176334  96.147  -77.094  49.650  1
176335  96.163  -77.093  49.598  1
176336  96.179  -77.091  49.548  1
176337  96.192  -77.098  49.501  1
176338  96.205  -77.115  49.459  1
176339  96.214  -77.135  49.422  1
176340  96.217  -77.155  49.389  1
176341  96.221  -77.175  49.355  1
176342  96.225  -77.196  49.324  1
176343  96.228  -77.217  49.294  1
176344  96.237  -77.232  49.264  1
176345  96.257  -77.237  49.236  1
176346  96.276  -77.241  49.213  1
176347  96.296  -77.247  49.191  1
176348  96.316  -77.252  49.169  1
176349  96.335  -77.257  49.150  1
176350  96.355  -77.262  49.131  1
176351  96.375  -77.266  49.113  1
176352  96.395  -77.265  49.097  1
176353  96.416  -77.263  49.084  1
176354  96.437  -77.261  49.071  1
176355  96.457  -77.260  49.057  1
176356  96.478  -77.258  49.042  1
176357  96.498  -77.261  49.025  1
176358  96.513  -77.278  49.009  1
176359  96.529  -77.294  48.992  1
176360  96.544  -77.310  48.978  1
176361  96.559  -77.326  48.963  1
176362  96.575  -77.342  48.947  1
176363  96.591  -77.359  48.930  1
176364  96.608  -77.371  48.913  1
176365  96.627  -77.381  48.896  1
176366  96.646  -77.392  48.879  1
176367  96.664  -77.401  48.863  1
176368  96.683  -77.412  48.848  1
176369  96.701  -77.422  48.833  1
176370  96.720  -77.432  48.818  1
176371  96.739  -77.443  48.805  1
176372  96.760  -77.455  48.791  1
176373  96.778  -77.476  48.778  1
176374  96.796  -77.498  48.765  1
176375  96.813  -77.519  48.751  1
176376  96.829  -77.531  48.737  1
176377  96.845  -77.536  48.722  1
176378  96.860  -77.541  48.706  1
176379  96.876  -77.546  48.687  1
176380  96.891  -77.551  48.668  1
176381  96.937  -77.553  48.649  1
176382  96.973  -77.567  48.629  1
176383  97.010  -77.582  48.609  1
176384  97.046  -77.597  48.590  1
176385  97.077  -77.618  48.571  1
176386  97.106  -77.643  48.551  1
176387  97.135  -77.668  48.532  1
176388  97.149  -77.665  48.514  1
176389  97.158  -77.654  48.495  1
176390  97.167  -77.642  48.478  1
176391  97.176  -77.630  48.461  1
176392  97.186  -77.619  48.444  1
176393  97.195  -77.608  48.424  1
176394  97.204  -77.596  48.403  1
176395  97.213  -77.584  48.382  1
176396  97.220  -77.569  48.359  1
176397  97.227  -77.554  48.336  1
176398  97.234  -77.539  48.313  1
176399  97.242  -77.523  48.291  1
176400  97.249  -77.508  48.270  1
176401  97.256  -77.493  48.249  1
176402  97.287  -77.494  48.228  1
176403  97.310  -77.502  48.206  1
176404  97.332  -77.511  48.186  1
176405  97.355  -77.518  48.165  1
176406  97.378  -77.526  48.143  1
176407  97.400  -77.535  48.122  1
176408  97.423  -77.542  48.100  1
176409  97.445  -77.551  48.077  1
176410  97.468  -77.559  48.054  1
176411  97.491  -77.567  48.029  1
176412  97.513  -77.575  48.003  1
176413  97.536  -77.583  47.976  1
176414  97.555  -77.595  47.949  1
176415  97.574  -77.608  47.920  1
176416  97.593  -77.620  47.892  1
176417  97.612  -77.633  47.863  1
176418  97.640  -77.631  47.835  1
176419  97.680  -77.635  47.807  1
176420  97.726  -77.642  47.778  1
176421  97.762  -77.645  47.750  1
176422  97.777  -77.640  47.722  1
176423  97.794  -77.637  47.694  1
176424  97.813  -77.636  47.666  1
176425  97.833  -77.636  47.637  1
176426  97.871  -77.648  47.608  1
176427  97.908  -77.660  47.579  1
176428  97.945  -77.672  47.550  1
176429  97.970  -77.670  47.523  1
176430  97.988  -77.660  47.497  1
176431  98.005  -77.650  47.470  1
176432  98.023  -77.640  47.442  1
176433  98.040  -77.630  47.413  1
176434  98.035  -77.618  47.383  1
176435  97.997  -77.602  47.353  1
176436  98.016  -77.551  47.323  1
176437  98.041  -77.497  47.294  1
176438  98.066  -77.442  47.265  1
176439  98.088  -77.420  47.236  1
176440  98.108  -77.420  47.208  1
176441  98.129  -77.420  47.180  1
176442  98.149  -77.419  47.154  1
176443  98.169  -77.419  47.128  1
176444  98.189  -77.418  47.102  1
176445  98.209  -77.418  47.076  1
176446  98.234  -77.432  47.049  1
176447  98.265  -77.469  47.023  1
176448  98.297  -77.505  46.996  1
176449  98.329  -77.541  46.968  1
176450  98.360  -77.577  46.941  1
176451  98.391  -77.614  46.914  1
176452  98.404  -77.636  46.887  1
176453  98.400  -77.647  46.860  1
176454  98.396  -77.658  46.833  1
176455  98.392  -77.668  46.808  1
176456  98.391  -77.676  46.785  1
176457  98.411  -77.675  46.761  1
176458  98.435  -77.672  46.737  1
176459  98.459  -77.669  46.714  1
176460  98.479  -77.668  46.691  1
176461  98.505  -77.664  46.668  1
176462  98.529  -77.661  46.646  1
176463  98.553  -77.658  46.625  1
176464  98.577  -77.655  46.603  1
176465  98.601  -77.651  46.582  1
176466  98.626  -77.648  46.561  1
176467  98.650  -77.645  46.538  1
176468  98.670  -77.650  46.517  1
176469  98.692  -77.655  46.496  1
176470  98.712  -77.661  46.477  1
176471  98.733  -77.667  46.457  1
176472  98.754  -77.672  46.438  1
176473  98.765  -77.678  46.418  1
176474  98.771  -77.686  46.397  1
176475  98.777  -77.692  46.375  1
176476  98.784  -77.700  46.355  1
176477  98.790  -77.708  46.336  1
176478  98.797  -77.715  46.316  1
176479  98.803  -77.723  46.295  1
176480  98.808  -77.728  46.273  1
176481  98.810  -77.730  46.251  1
176482  98.811  -77.731  46.230  1
176483  98.813  -77.733  46.208  1
176484  98.814  -77.736  46.185  1
176485  98.815  -77.740  46.163  1
176486  98.816  -77.743  46.141  1
176487  98.816  -77.746  46.120  1
176488  98.817  -77.749  46.098  1
176489  98.819  -77.753  46.077  1
176490  98.853  -77.758  46.057  1
176491  98.883  -77.763  46.039  1
176492  98.914  -77.768  46.020  1
176493  98.944  -77.772  46.003  1
176494  98.974  -77.777  45.985  1
176495  99.004  -77.781  45.969  1
176496  99.035  -77.787  45.954  1
176497  99.065  -77.791  45.939  1
176498  99.095  -77.796  45.925  1
176499  99.126  -77.800  45.911  1
176500  99.146  -77.812  45.897  1
176501  99.166  -77.824  45.885  1
176502  99.187  -77.836  45.874  1
176503  99.215  -77.852  45.863  1
176504  99.249  -77.870  45.853  1
176505  99.283  -77.889  45.844  1
176506  99.316  -77.907  45.835  1
176507  99.351  -77.924  45.826  1
176508  99.360  -77.937  45.817  1
176509  99.366  -77.952  45.808  1
176510  99.373  -77.968  45.800  1
176511  99.380  -77.984  45.792  1
176512  99.387  -78.000  45.785  1
176513  99.394  -78.015  45.777  1
176514  99.401  -78.031  45.769  1
176515  99.420  -78.042  45.761  1
176516  99.441  -78.052  45.751  1
176517  99.474  -78.059  45.741  1
176518  99.517  -78.066  45.730  1
176519  99.560  -78.073  45.718  1
176520  99.600  -78.082  45.706  1
176521  99.622  -78.102  45.695  1
176522  99.634  -78.114  45.683  1
176523  99.646  -78.124  45.671  1
176524  99.677  -78.110  45.658  1
176525  99.707  -78.097  45.645  1
176526  99.737  -78.084  45.631  1
176527  99.780  -78.112  45.617  1
176528  99.823  -78.149  45.602  1
176529  99.867  -78.184  45.588  1
176530  99.906  -78.206  45.572  1
176531  99.942  -78.221  45.556  1
176532  99.978  -78.235  45.539  1
176533  100.014  -78.250  45.522  1
176534  100.050  -78.266  45.506  1
176535  100.086  -78.280  45.490  1
176536  100.121  -78.292  45.475  1
176537  100.136  -78.302  45.460  1
176538  100.141  -78.313  45.445  1
176539  100.146  -78.326  45.429  1
176540  100.151  -78.338  45.414  1
176541  100.156  -78.349  45.400  1
176542  100.161  -78.361  45.384  1
176543  100.166  -78.373  45.369  1
176544  100.178  -78.382  45.353  1
176545  100.208  -78.388  45.336  1
176546  100.238  -78.392  45.320  1
176547  100.268  -78.398  45.304  1
176548  100.297  -78.402  45.287  1
176549  100.328  -78.407  45.272  1
176550  100.357  -78.412  45.256  1
176551  100.387  -78.417  45.241  1
176552  100.417  -78.422  45.226  1
176553  100.448  -78.423  45.211  1
176554  100.482  -78.424  45.196  1
176555  100.521  -78.429  45.182  1
176556  100.561  -78.436  45.167  1
176557  100.601  -78.442  45.151  1
176558  100.641  -78.449  45.135  1
176559  100.681  -78.456  45.119  1
176560  100.721  -78.462  45.102  1
176561  100.761  -78.469  45.086  1
176562  100.802  -78.476  45.069  1
176563  100.842  -78.482  45.053  1
176564  100.869  -78.488  45.037  1
176565  100.896  -78.493  45.021  1
176566  100.922  -78.499  45.006  1
176567  100.949  -78.504  44.992  1
176568  100.969  -78.506  44.977  1
176569  100.959  -78.482  44.962  1
176570  100.987  -78.495  44.947  1
176571  101.031  -78.522  44.930  1
176572  101.068  -78.507  44.915  1
176573  101.120  -78.489  44.900  1
176574  101.177  -78.495  44.883  1
176575  101.206  -78.511  44.867  1
176576  101.228  -78.527  44.851  1
176577  101.250  -78.543  44.835  1
176578  101.272  -78.559  44.819  1
176579  101.298  -78.576  44.804  1
176580  101.324  -78.593  44.788  1
176581  101.350  -78.610  44.772  1
176582  101.376  -78.630  44.757  1
176583  101.402  -78.652  44.742  1
176584  101.428  -78.674  44.726  1
176585  101.455  -78.695  44.711  1
176586  101.481  -78.717  44.696  1
176587  101.507  -78.738  44.681  1
176588  101.534  -78.759  44.666  1
176589  101.560  -78.780  44.651  1
176590  101.587  -78.802  44.636  1
176591  101.613  -78.823  44.620  1
176592  101.640  -78.844  44.605  1
176593  101.665  -78.868  44.591  1
176594  101.688  -78.902  44.578  1
176595  101.700  -78.898  44.564  1
176596  101.717  -78.904  44.550  1
176597  101.734  -78.909  44.537  1
176598  101.751  -78.915  44.523  1
176599  101.767  -78.921  44.510  1
176600  101.784  -78.926  44.498  1
176601  101.801  -78.932  44.486  1
176602  101.818  -78.937  44.473  1
176603  101.835  -78.943  44.461  1
176604  101.851  -78.949  44.449  1
176605  101.868  -78.954  44.437  1
176606  101.885  -78.960  44.425  1
176607  101.902  -78.965  44.413  1
176608  101.918  -78.971  44.402  1
176852  92.859  -77.055  54.103  1
176853  92.879  -77.047  54.111  1
176854  92.900  -77.038  54.118  1
176855  92.920  -77.028  54.126  1
176856  92.940  -77.020  54.134  1
176857  92.960  -77.011  54.143  1
176858  92.981  -77.003  54.152  1
176859  93.001  -76.994  54.160  1
176860  93.021  -76.985  54.168  1
176861  93.042  -76.976  54.176  1
176862  93.062  -76.967  54.184  1
176863  93.082  -76.959  54.192  1
176864  93.103  -76.950  54.199  1
176865  93.123  -76.941  54.206  1
176866  93.143  -76.932  54.211  1
176867  93.163  -76.928  54.217  1
176868  93.182  -76.925  54.221  1
176869  93.201  -76.922  54.226  1
176870  93.220  -76.918  54.232  1
176871  93.239  -76.915  54.237  1
176872  93.259  -76.912  54.242  1
176873  93.278  -76.909  54.246  1
176874  93.297  -76.906  54.250  1
176875  93.317  -76.902  54.252  1
176876  93.336  -76.899  54.252  1
176877  93.350  -76.894  54.251  1
176878  93.366  -76.886  54.250  1
176879  93.380  -76.878  54.248  1
176880  93.394  -76.871  54.249  1
176881  93.408  -76.863  54.252  1
176882  93.421  -76.856  54.258  1
176883  93.435  -76.848  54.264  1
176884  93.448  -76.840  54.270  1
176885  93.471  -76.840  54.276  1
176886  93.493  -76.840  54.282  1
176887  93.516  -76.840  54.286  1
176888  93.539  -76.840  54.289  1
176889  93.561  -76.840  54.292  1
176890  93.579  -76.837  54.292  1
176891  93.596  -76.832  54.291  1
176892  93.613  -76.828  54.289  1
176893  93.630  -76.824  54.287  1
176894  93.643  -76.812  54.284  1
176895  93.657  -76.801  54.280  1
176896  93.676  -76.799  54.274  1
176897  93.695  -76.796  54.267  1
176898  93.714  -76.793  54.258  1
176899  93.731  -76.788  54.249  1
176900  93.749  -76.784  54.238  1
176901  93.767  -76.779  54.226  1
176902  93.784  -76.774  54.212  1
176903  93.802  -76.769  54.198  1
176904  93.820  -76.765  54.183  1
176905  93.837  -76.760  54.170  1
176906  93.855  -76.755  54.159  1
176907  93.872  -76.750  54.148  1
176908  93.889  -76.748  54.139  1
176909  93.904  -76.749  54.130  1
176910  93.922  -76.748  54.118  1
176911  93.939  -76.746  54.105  1
176912  93.958  -76.744  54.095  1
176913  93.975  -76.743  54.086  1
176914  93.993  -76.741  54.081  1
176915  94.010  -76.738  54.078  1
176916  94.027  -76.734  54.078  1
176917  94.044  -76.731  54.078  1
176918  94.061  -76.727  54.079  1
176919  94.078  -76.724  54.082  1
176920  94.083  -76.725  54.082  1
176921  94.102  -76.720  54.080  1
176922  94.111  -76.717  54.076  1
176923  94.121  -76.715  54.071  1
176924  94.130  -76.712  54.058  1
176925  94.139  -76.708  54.044  1
176926  94.148  -76.705  54.031  1
176927  94.158  -76.703  54.017  1
176928  94.150  -76.706  54.003  1
176929  94.141  -76.710  53.989  1
176930  94.161  -76.704  53.975  1
176931  94.182  -76.698  53.956  1
176932  94.203  -76.692  53.938  1
176933  94.223  -76.686  53.920  1
176934  94.247  -76.678  53.900  1
176935  94.276  -76.669  53.880  1
176936  94.306  -76.660  53.858  1
176937  94.322  -76.653  53.833  1
176938  94.339  -76.646  53.801  1
176939  94.355  -76.640  53.771  1
176940  94.371  -76.633  53.740  1
176941  94.387  -76.626  53.707  1
176942  94.403  -76.619  53.672  1
176943  94.420  -76.615  53.635  1
176944  94.431  -76.614  53.597  1
176945  94.435  -76.613  53.558  1
176946  94.445  -76.608  53.523  1
176947  94.456  -76.603  53.489  1
176948  94.466  -76.599  53.456  1
176949  94.476  -76.594  53.423  1
176950  94.502  -76.588  53.392  1
176951  94.547  -76.583  53.358  1
176952  94.591  -76.577  53.324  1
176953  94.627  -76.576  53.290  1
176954  94.659  -76.577  53.257  1
176955  94.679  -76.574  53.225  1
176956  94.696  -76.568  53.195  1
176957  94.713  -76.563  53.168  1
176958  94.760  -76.553  53.140  1
176959  94.788  -76.546  53.114  1
176960  94.794  -76.539  53.089  1
176961  94.800  -76.533  53.069  1
176962  94.805  -76.527  53.045  1
176963  94.830  -76.536  53.018  1
176964  94.855  -76.546  52.988  1
176965  94.874  -76.552  52.954  1
176966  94.881  -76.554  52.924  1
176967  94.889  -76.555  52.896  1
176968  94.896  -76.557  52.868  1
176969  94.904  -76.558  52.835  1
176970  94.911  -76.560  52.799  1
176971  94.919  -76.562  52.758  1
176972  94.926  -76.564  52.711  1
176973  94.934  -76.565  52.663  1
176974  94.942  -76.567  52.614  1
176975  94.949  -76.568  52.564  1
176976  94.957  -76.570  52.513  1
176977  94.964  -76.572  52.461  1
176978  94.972  -76.574  52.408  1
176979  94.990  -76.577  52.353  1
176980  95.027  -76.585  52.299  1
176981  95.064  -76.592  52.246  1
176982  95.101  -76.600  52.193  1
176983  95.138  -76.608  52.141  1
176984  95.175  -76.615  52.089  1
176985  95.201  -76.625  52.039  1
176986  95.211  -76.639  51.988  1
176987  95.220  -76.652  51.939  1
176988  95.235  -76.665  51.892  1
176989  95.250  -76.678  51.846  1
176990  95.265  -76.691  51.800  1
176991  95.279  -76.704  51.756  1
176992  95.294  -76.717  51.712  1
176993  95.309  -76.730  51.668  1
176994  95.323  -76.743  51.623  1
176995  95.338  -76.755  51.578  1
176996  95.353  -76.768  51.534  1
176997  95.368  -76.781  51.490  1
176998  95.382  -76.794  51.447  1
176999  95.397  -76.802  51.405  1
177000  95.407  -76.805  51.364  1
177001  95.418  -76.807  51.321  1
177002  95.429  -76.809  51.277  1
177003  95.447  -76.818  51.231  1
177004  95.473  -76.836  51.185  1
177005  95.498  -76.853  51.140  1
177006  95.524  -76.870  51.098  1
177007  95.550  -76.887  51.058  1
177008  95.576  -76.903  51.019  1
177009  95.602  -76.921  50.980  1
177010  95.621  -76.939  50.943  1
177011  95.636  -76.957  50.905  1
177012  95.652  -76.971  50.866  1
177013  95.667  -76.976  50.824  1
177014  95.681  -76.981  50.782  1
177015  95.698  -76.988  50.740  1
177016  95.716  -76.997  50.700  1
177017  95.735  -77.006  50.658  1
177018  95.754  -77.014  50.615  1
177019  95.772  -77.022  50.570  1
177020  95.791  -77.031  50.524  1
177021  95.809  -77.040  50.479  1
177022  95.828  -77.048  50.434  1
177023  95.861  -77.056  50.386  1
177024  95.896  -77.063  50.332  1
177025  95.932  -77.071  50.277  1
177026  95.967  -77.078  50.221  1
177027  96.002  -77.081  50.164  1
177028  96.029  -77.081  50.102  1
177029  96.043  -77.096  50.037  1
177030  96.058  -77.108  49.969  1
177031  96.077  -77.105  49.902  1
177032  96.095  -77.103  49.837  1
177033  96.114  -77.100  49.776  1
177034  96.133  -77.098  49.718  1
177035  96.152  -77.095  49.662  1
177036  96.170  -77.093  49.610  1
177037  96.189  -77.091  49.561  1
177038  96.207  -77.088  49.514  1
177039  96.217  -77.099  49.473  1
177040  96.221  -77.119  49.436  1
177041  96.224  -77.140  49.403  1
177042  96.228  -77.160  49.369  1
177043  96.232  -77.182  49.339  1
177044  96.235  -77.202  49.309  1
177045  96.253  -77.209  49.279  1
177046  96.272  -77.213  49.252  1
177047  96.292  -77.219  49.229  1
177048  96.312  -77.224  49.207  1
177049  96.331  -77.229  49.186  1
177050  96.350  -77.234  49.166  1
177051  96.370  -77.238  49.147  1
177052  96.390  -77.244  49.130  1
177053  96.409  -77.248  49.113  1
177054  96.430  -77.248  49.101  1
177055  96.451  -77.247  49.088  1
177056  96.471  -77.244  49.075  1
177057  96.492  -77.243  49.062  1
177058  96.512  -77.244  49.046  1
177059  96.528  -77.260  49.028  1
177060  96.543  -77.276  49.011  1
177061  96.558  -77.292  48.997  1
177062  96.574  -77.309  48.982  1
177063  96.590  -77.325  48.965  1
177064  96.608  -77.337  48.948  1
177065  96.626  -77.347  48.930  1
177066  96.645  -77.357  48.913  1
177067  96.664  -77.367  48.896  1
177068  96.682  -77.378  48.880  1
177069  96.701  -77.388  48.863  1
177070  96.720  -77.398  48.847  1
177071  96.736  -77.410  48.833  1
177072  96.751  -77.429  48.819  1
177073  96.766  -77.454  48.804  1
177074  96.784  -77.476  48.790  1
177075  96.802  -77.497  48.776  1
177076  96.817  -77.505  48.760  1
177077  96.833  -77.510  48.746  1
177078  96.848  -77.515  48.731  1
177079  96.864  -77.520  48.714  1
177080  96.879  -77.526  48.694  1
177081  96.894  -77.530  48.674  1
177082  96.941  -77.528  48.655  1
177083  96.977  -77.542  48.636  1
177084  97.014  -77.557  48.618  1
177085  97.050  -77.571  48.599  1
177086  97.081  -77.594  48.579  1
177087  97.110  -77.619  48.558  1
177088  97.139  -77.644  48.539  1
177089  97.168  -77.668  48.519  1
177090  97.177  -77.657  48.500  1
177091  97.186  -77.645  48.482  1
177092  97.195  -77.634  48.466  1
177093  97.205  -77.623  48.448  1
177094  97.214  -77.611  48.429  1
177095  97.223  -77.600  48.408  1
177096  97.231  -77.586  48.386  1
177097  97.238  -77.571  48.364  1
177098  97.246  -77.556  48.341  1
177099  97.253  -77.541  48.319  1
177100  97.260  -77.526  48.297  1
177101  97.267  -77.511  48.276  1
177102  97.275  -77.495  48.256  1
177103  97.298  -77.488  48.236  1
177104  97.320  -77.496  48.216  1
177105  97.343  -77.504  48.196  1
177106  97.365  -77.512  48.174  1
177107  97.388  -77.520  48.154  1
177108  97.410  -77.528  48.133  1
177109  97.433  -77.536  48.111  1
177110  97.456  -77.545  48.088  1
177111  97.478  -77.552  48.064  1
177112  97.501  -77.561  48.039  1
177113  97.521  -77.572  48.013  1
177114  97.540  -77.585  47.987  1
177115  97.559  -77.597  47.959  1
177116  97.578  -77.609  47.930  1
177117  97.597  -77.622  47.902  1
177118  97.621  -77.625  47.873  1
177119  97.648  -77.624  47.845  1
177120  97.693  -77.630  47.816  1
177121  97.739  -77.636  47.787  1
177122  97.785  -77.642  47.759  1
177123  97.806  -77.641  47.730  1
177124  97.821  -77.636  47.702  1
177125  97.837  -77.633  47.673  1
177126  97.857  -77.632  47.644  1
177127  97.884  -77.636  47.615  1
177128  97.921  -77.649  47.586  1
177129  97.959  -77.661  47.558  1
177130  97.980  -77.655  47.530  1
177131  97.997  -77.645  47.503  1
177132  98.015  -77.635  47.475  1
177133  98.032  -77.625  47.447  1
177134  98.050  -77.615  47.418  1
177135  98.065  -77.605  47.389  1
177136  98.026  -77.589  47.359  1
177137  98.043  -77.539  47.330  1
177138  98.068  -77.485  47.301  1
177139  98.091  -77.444  47.272  1
177140  98.111  -77.444  47.242  1
177141  98.132  -77.443  47.213  1
177142  98.152  -77.443  47.185  1
177143  98.172  -77.442  47.159  1
177144  98.192  -77.442  47.133  1
177145  98.212  -77.442  47.106  1
177146  98.232  -77.441  47.080  1
177147  98.252  -77.441  47.053  1
177148  98.273  -77.440  47.027  1
177149  98.302  -77.470  47.001  1
177150  98.334  -77.506  46.974  1
177151  98.365  -77.542  46.948  1
177152  98.396  -77.579  46.921  1
177153  98.428  -77.614  46.894  1
177154  98.426  -77.627  46.867  1
177155  98.422  -77.638  46.841  1
177156  98.418  -77.649  46.816  1
177157  98.414  -77.659  46.793  1
177158  98.423  -77.661  46.771  1
177159  98.444  -77.661  46.747  1
177160  98.466  -77.659  46.723  1
177161  98.488  -77.658  46.700  1
177162  98.511  -77.656  46.677  1
177163  98.537  -77.650  46.655  1
177164  98.563  -77.645  46.634  1
177165  98.588  -77.639  46.611  1
177166  98.614  -77.633  46.589  1
177167  98.639  -77.630  46.567  1
177168  98.661  -77.636  46.546  1
177169  98.683  -77.640  46.524  1
177170  98.704  -77.645  46.503  1
177171  98.725  -77.651  46.483  1
177172  98.746  -77.655  46.463  1
177173  98.769  -77.658  46.444  1
177174  98.780  -77.661  46.425  1
177175  98.787  -77.667  46.404  1
177176  98.795  -77.674  46.383  1
177177  98.802  -77.681  46.363  1
177178  98.810  -77.688  46.343  1
177179  98.816  -77.696  46.324  1
177180  98.822  -77.703  46.303  1
177181  98.829  -77.711  46.282  1
177182  98.835  -77.717  46.260  1
177183  98.836  -77.718  46.238  1
177184  98.837  -77.721  46.216  1
177185  98.838  -77.725  46.194  1
177186  98.839  -77.728  46.171  1
177187  98.839  -77.732  46.149  1
177188  98.838  -77.736  46.127  1
177189  98.837  -77.740  46.106  1
177190  98.838  -77.743  46.085  1
177191  98.857  -77.749  46.066  1
177192  98.889  -77.756  46.046  1
177193  98.915  -77.756  46.027  1
177194  98.942  -77.757  46.008  1
177195  98.972  -77.761  45.990  1
177196  99.003  -77.766  45.973  1
177197  99.033  -77.771  45.957  1
177198  99.063  -77.775  45.942  1
177199  99.093  -77.780  45.928  1
177200  99.124  -77.784  45.915  1
177201  99.153  -77.790  45.901  1
177202  99.173  -77.802  45.888  1
177203  99.194  -77.814  45.877  1
177204  99.227  -77.832  45.867  1
177205  99.261  -77.850  45.857  1
177206  99.295  -77.868  45.848  1
177207  99.328  -77.893  45.839  1
177208  99.354  -77.918  45.831  1
177209  99.374  -77.941  45.820  1
177210  99.381  -77.957  45.812  1
177211  99.388  -77.973  45.804  1
177212  99.395  -77.989  45.796  1
177213  99.402  -78.005  45.789  1
177214  99.409  -78.021  45.781  1
177215  99.426  -78.032  45.772  1
177216  99.447  -78.042  45.764  1
177217  99.469  -78.051  45.755  1
177218  99.491  -78.061  45.745  1
177219  99.515  -78.069  45.734  1
177220  99.558  -78.076  45.722  1
177221  99.601  -78.083  45.711  1
177222  99.624  -78.100  45.700  1
177223  99.635  -78.112  45.689  1
177224  99.663  -78.102  45.677  1
177225  99.694  -78.088  45.665  1
177226  99.724  -78.075  45.651  1
177227  99.755  -78.062  45.636  1
177228  99.798  -78.097  45.622  1
177229  99.842  -78.132  45.607  1
177230  99.883  -78.159  45.592  1
177231  99.919  -78.174  45.576  1
177232  99.955  -78.189  45.561  1
177233  99.991  -78.204  45.544  1
177234  100.028  -78.219  45.528  1
177235  100.063  -78.234  45.512  1
177236  100.098  -78.254  45.498  1
177237  100.130  -78.279  45.483  1
177238  100.149  -78.287  45.468  1
177239  100.153  -78.304  45.452  1
177240  100.158  -78.316  45.437  1
177241  100.163  -78.328  45.421  1
177242  100.168  -78.340  45.406  1
177243  100.174  -78.351  45.391  1
177244  100.179  -78.363  45.375  1
177245  100.184  -78.375  45.359  1
177246  100.207  -78.382  45.342  1
177247  100.237  -78.387  45.326  1
177248  100.267  -78.391  45.310  1
177249  100.297  -78.397  45.293  1
177250  100.327  -78.401  45.278  1
177251  100.356  -78.407  45.263  1
177252  100.387  -78.409  45.248  1
177253  100.418  -78.410  45.233  1
177254  100.449  -78.410  45.218  1
177255  100.484  -78.413  45.203  1
177256  100.522  -78.416  45.188  1
177257  100.562  -78.423  45.173  1
177258  100.602  -78.429  45.158  1
177259  100.642  -78.435  45.142  1
177260  100.682  -78.442  45.125  1
177261  100.722  -78.449  45.108  1
177262  100.763  -78.455  45.092  1
177263  100.802  -78.462  45.075  1
177264  100.835  -78.468  45.058  1
177265  100.861  -78.474  45.042  1
177266  100.888  -78.479  45.027  1
177267  100.914  -78.485  45.012  1
177268  100.940  -78.491  44.998  1
177269  100.967  -78.496  44.983  1
177270  100.980  -78.492  44.968  1
177271  100.992  -78.489  44.952  1
177272  101.032  -78.504  44.937  1
177273  101.080  -78.487  44.922  1
177274  101.132  -78.469  44.906  1
177275  101.181  -78.483  44.889  1
177276  101.203  -78.499  44.874  1
177277  101.225  -78.515  44.858  1
177278  101.248  -78.532  44.842  1
177279  101.274  -78.549  44.826  1
177280  101.301  -78.566  44.810  1
177281  101.327  -78.583  44.794  1
177282  101.353  -78.600  44.777  1
177283  101.379  -78.619  44.761  1
177284  101.405  -78.642  44.746  1
177285  101.431  -78.664  44.731  1
177286  101.457  -78.686  44.716  1
177287  101.483  -78.708  44.701  1
177288  101.510  -78.729  44.685  1
177289  101.536  -78.750  44.670  1
177290  101.563  -78.771  44.655  1
177291  101.589  -78.793  44.640  1
177292  101.616  -78.814  44.624  1
177293  101.641  -78.839  44.609  1
177294  101.664  -78.872  44.596  1
177295  101.687  -78.905  44.582  1
177296  101.696  -78.899  44.568  1
177297  101.712  -78.902  44.554  1
177298  101.729  -78.908  44.541  1
177299  101.746  -78.914  44.527  1
177300  101.762  -78.919  44.514  1
177301  101.779  -78.925  44.501  1
177302  101.796  -78.930  44.489  1
177303  101.813  -78.937  44.477  1
177304  101.830  -78.942  44.464  1
177305  101.846  -78.947  44.452  1
177306  101.863  -78.953  44.440  1
177307  101.880  -78.959  44.428  1
177308  101.897  -78.965  44.416  1
177309  101.913  -78.970  44.405  1
177555  92.889  -77.014  54.094  1
177556  92.909  -77.005  54.103  1
177557  92.930  -76.997  54.112  1
177558  92.950  -76.987  54.122  1
177559  92.970  -76.979  54.132  1
177560  92.991  -76.970  54.141  1
177561  93.011  -76.961  54.151  1
177562  93.031  -76.953  54.158  1
177563  93.052  -76.943  54.167  1
177564  93.072  -76.935  54.175  1
177565  93.092  -76.926  54.183  1
177566  93.113  -76.918  54.190  1
177567  93.133  -76.909  54.196  1
177568  93.152  -76.904  54.202  1
177569  93.171  -76.901  54.208  1
177570  93.191  -76.898  54.213  1
177571  93.210  -76.895  54.218  1
177572  93.229  -76.891  54.223  1
177573  93.249  -76.888  54.227  1
177574  93.268  -76.885  54.230  1
177575  93.287  -76.881  54.233  1
177576  93.306  -76.878  54.235  1
177577  93.326  -76.875  54.236  1
177578  93.345  -76.871  54.236  1
177579  93.364  -76.868  54.235  1
177580  93.383  -76.865  54.234  1
177581  93.399  -76.859  54.235  1
177582  93.413  -76.852  54.238  1
177583  93.426  -76.844  54.244  1
177584  93.440  -76.837  54.252  1
177585  93.453  -76.829  54.260  1
177586  93.469  -76.823  54.267  1
177587  93.491  -76.823  54.275  1
177588  93.514  -76.823  54.280  1
177589  93.537  -76.823  54.284  1
177590  93.557  -76.821  54.288  1
177591  93.574  -76.817  54.288  1
177592  93.591  -76.813  54.288  1
177593  93.608  -76.809  54.287  1
177594  93.625  -76.804  54.287  1
177595  93.642  -76.800  54.285  1
177596  93.656  -76.789  54.282  1
177597  93.674  -76.785  54.277  1
177598  93.693  -76.782  54.271  1
177599  93.711  -76.774  54.262  1
177600  93.726  -76.767  54.253  1
177601  93.743  -76.762  54.243  1
177602  93.761  -76.757  54.232  1
177603  93.778  -76.752  54.220  1
177604  93.796  -76.747  54.207  1
177605  93.814  -76.743  54.192  1
177606  93.831  -76.738  54.178  1
177607  93.849  -76.734  54.167  1
177608  93.866  -76.728  54.158  1
177609  93.883  -76.727  54.149  1
177610  93.898  -76.727  54.140  1
177611  93.913  -76.728  54.129  1
177612  93.931  -76.727  54.118  1
177613  93.949  -76.725  54.107  1
177614  93.967  -76.724  54.099  1
177615  93.984  -76.722  54.092  1
177616  94.002  -76.721  54.089  1
177617  94.020  -76.719  54.089  1
177618  94.038  -76.718  54.088  1
177619  94.055  -76.716  54.090  1
177620  94.073  -76.715  54.093  1
177621  94.088  -76.712  54.095  1
177622  94.098  -76.708  54.094  1
177623  94.107  -76.705  54.092  1
177624  94.116  -76.702  54.089  1
177625  94.126  -76.700  54.077  1
177626  94.135  -76.697  54.065  1
177627  94.144  -76.694  54.053  1
177628  94.153  -76.691  54.039  1
177629  94.153  -76.692  54.026  1
177630  94.146  -76.695  54.013  1
177631  94.167  -76.689  54.000  1
177632  94.188  -76.683  53.981  1
177633  94.208  -76.677  53.963  1
177634  94.229  -76.671  53.944  1
177635  94.250  -76.665  53.925  1
177636  94.274  -76.657  53.905  1
177637  94.300  -76.648  53.883  1
177638  94.317  -76.641  53.857  1
177639  94.333  -76.634  53.827  1
177640  94.349  -76.627  53.796  1
177641  94.365  -76.621  53.765  1
177642  94.382  -76.614  53.732  1
177643  94.398  -76.608  53.697  1
177644  94.414  -76.601  53.661  1
177645  94.424  -76.598  53.624  1
177646  94.434  -76.593  53.586  1
177647  94.445  -76.588  53.548  1
177648  94.455  -76.583  53.512  1
177649  94.465  -76.578  53.476  1
177650  94.475  -76.574  53.443  1
177651  94.509  -76.567  53.410  1
177652  94.553  -76.561  53.374  1
177653  94.595  -76.558  53.337  1
177654  94.627  -76.559  53.302  1
177655  94.660  -76.561  53.269  1
177656  94.680  -76.557  53.237  1
177657  94.697  -76.552  53.206  1
177658  94.714  -76.546  53.180  1
177659  94.736  -76.541  53.154  1
177660  94.774  -76.532  53.129  1
177661  94.780  -76.526  53.104  1
177662  94.787  -76.520  53.083  1
177663  94.812  -76.530  53.058  1
177664  94.829  -76.536  53.032  1
177665  94.837  -76.537  53.003  1
177666  94.844  -76.539  52.970  1
177667  94.852  -76.541  52.940  1
177668  94.859  -76.542  52.913  1
177669  94.867  -76.544  52.885  1
177670  94.875  -76.546  52.854  1
177671  94.882  -76.547  52.819  1
177672  94.890  -76.549  52.778  1
177673  94.897  -76.551  52.734  1
177674  94.905  -76.552  52.687  1
177675  94.912  -76.554  52.639  1
177676  94.920  -76.555  52.590  1
177677  94.927  -76.557  52.538  1
177678  94.935  -76.558  52.486  1
177679  94.943  -76.561  52.432  1
177680  94.961  -76.564  52.377  1
177681  94.998  -76.572  52.324  1
177682  95.035  -76.580  52.271  1
177683  95.072  -76.587  52.218  1
177684  95.109  -76.595  52.166  1
177685  95.146  -76.602  52.115  1
177686  95.183  -76.610  52.063  1
177687  95.205  -76.621  52.012  1
177688  95.216  -76.634  51.962  1
177689  95.231  -76.647  51.913  1
177690  95.246  -76.660  51.866  1
177691  95.260  -76.673  51.819  1
177692  95.275  -76.686  51.773  1
177693  95.289  -76.699  51.727  1
177694  95.305  -76.712  51.681  1
177695  95.319  -76.724  51.635  1
177696  95.334  -76.739  51.591  1
177697  95.348  -76.753  51.548  1
177698  95.362  -76.767  51.504  1
177699  95.377  -76.781  51.462  1
177700  95.405  -76.793  51.421  1
177701  95.397  -76.796  51.381  1
177702  95.408  -76.798  51.339  1
177703  95.418  -76.800  51.296  1
177704  95.435  -76.808  51.251  1
177705  95.461  -76.825  51.207  1
177706  95.486  -76.842  51.163  1
177707  95.512  -76.859  51.123  1
177708  95.538  -76.876  51.084  1
177709  95.564  -76.893  51.046  1
177710  95.590  -76.910  51.009  1
177711  95.616  -76.927  50.972  1
177712  95.635  -76.945  50.934  1
177713  95.650  -76.957  50.893  1
177714  95.665  -76.962  50.850  1
177715  95.684  -76.972  50.807  1
177716  95.702  -76.980  50.765  1
177717  95.721  -76.988  50.723  1
177718  95.739  -76.997  50.680  1
177719  95.758  -77.005  50.635  1
177720  95.776  -77.014  50.589  1
177721  95.795  -77.022  50.543  1
177722  95.814  -77.031  50.498  1
177723  95.833  -77.039  50.450  1
177724  95.868  -77.047  50.400  1
177725  95.904  -77.054  50.346  1
177726  95.939  -77.062  50.290  1
177727  95.974  -77.066  50.233  1
177728  96.006  -77.061  50.174  1
177729  96.032  -77.063  50.110  1
177730  96.046  -77.078  50.043  1
177731  96.060  -77.093  49.976  1
177732  96.074  -77.107  49.909  1
177733  96.092  -77.110  49.845  1
177734  96.110  -77.106  49.785  1
177735  96.129  -77.104  49.728  1
177736  96.148  -77.102  49.673  1
177737  96.167  -77.099  49.622  1
177738  96.185  -77.097  49.574  1
177739  96.204  -77.094  49.530  1
177740  96.224  -77.084  49.488  1
177741  96.228  -77.104  49.452  1
177742  96.231  -77.125  49.418  1
177743  96.235  -77.146  49.385  1
177744  96.239  -77.166  49.355  1
177745  96.249  -77.181  49.325  1
177746  96.268  -77.185  49.296  1
177747  96.288  -77.191  49.269  1
177748  96.307  -77.196  49.245  1
177749  96.327  -77.201  49.224  1
177750  96.346  -77.206  49.203  1
177751  96.366  -77.210  49.183  1
177752  96.386  -77.216  49.165  1
177753  96.405  -77.221  49.148  1
177754  96.425  -77.226  49.131  1
177755  96.444  -77.231  49.119  1
177756  96.465  -77.232  49.107  1
177757  96.485  -77.229  49.095  1
177758  96.506  -77.228  49.081  1
177759  96.527  -77.226  49.065  1
177760  96.542  -77.243  49.049  1
177761  96.558  -77.259  49.032  1
177762  96.574  -77.276  49.017  1
177763  96.589  -77.291  49.002  1
177764  96.607  -77.303  48.985  1
177765  96.626  -77.313  48.968  1
177766  96.645  -77.323  48.950  1
177767  96.663  -77.333  48.931  1
177768  96.682  -77.344  48.913  1
177769  96.699  -77.355  48.896  1
177770  96.715  -77.369  48.879  1
177771  96.731  -77.382  48.863  1
177772  96.747  -77.395  48.847  1
177773  96.758  -77.424  48.832  1
177774  96.772  -77.454  48.816  1
177775  96.790  -77.474  48.801  1
177776  96.805  -77.479  48.786  1
177777  96.821  -77.484  48.770  1
177778  96.836  -77.489  48.754  1
177779  96.852  -77.495  48.738  1
177780  96.867  -77.500  48.721  1
177781  96.882  -77.504  48.701  1
177782  96.898  -77.510  48.681  1
177783  96.946  -77.502  48.662  1
177784  96.982  -77.517  48.644  1
177785  97.018  -77.532  48.626  1
177786  97.055  -77.546  48.607  1
177787  97.085  -77.570  48.587  1
177788  97.114  -77.594  48.566  1
177789  97.143  -77.619  48.546  1
177790  97.172  -77.644  48.526  1
177791  97.196  -77.661  48.507  1
177792  97.206  -77.649  48.488  1
177793  97.215  -77.638  48.470  1
177794  97.224  -77.627  48.452  1
177795  97.233  -77.614  48.433  1
177796  97.242  -77.603  48.411  1
177797  97.250  -77.589  48.390  1
177798  97.257  -77.573  48.369  1
177799  97.264  -77.558  48.348  1
177800  97.272  -77.543  48.327  1
177801  97.279  -77.528  48.306  1
177802  97.286  -77.513  48.285  1
177803  97.293  -77.498  48.265  1
177804  97.304  -77.484  48.246  1
177805  97.330  -77.489  48.226  1
177806  97.353  -77.498  48.205  1
177807  97.376  -77.506  48.184  1
177808  97.398  -77.514  48.163  1
177809  97.421  -77.522  48.142  1
177810  97.443  -77.530  48.121  1
177811  97.466  -77.538  48.097  1
177812  97.486  -77.549  48.073  1
177813  97.505  -77.561  48.048  1
177814  97.524  -77.574  48.022  1
177815  97.543  -77.586  47.996  1
177816  97.563  -77.599  47.969  1
177817  97.582  -77.611  47.941  1
177818  97.603  -77.620  47.912  1
177819  97.630  -77.618  47.883  1
177820  97.661  -77.618  47.854  1
177821  97.707  -77.624  47.824  1
177822  97.752  -77.631  47.795  1
177823  97.798  -77.637  47.766  1
177824  97.836  -77.641  47.737  1
177825  97.851  -77.637  47.708  1
177826  97.866  -77.633  47.678  1
177827  97.881  -77.629  47.649  1
177828  97.900  -77.628  47.621  1
177829  97.935  -77.637  47.592  1
177830  97.972  -77.649  47.564  1
177831  97.989  -77.639  47.536  1
177832  98.007  -77.630  47.507  1
177833  98.024  -77.620  47.480  1
177834  98.042  -77.610  47.451  1
177835  98.060  -77.600  47.422  1
177836  98.077  -77.590  47.394  1
177837  98.055  -77.576  47.365  1
177838  98.070  -77.528  47.336  1
177839  98.094  -77.473  47.308  1
177840  98.115  -77.467  47.279  1
177841  98.135  -77.467  47.249  1
177842  98.155  -77.467  47.219  1
177843  98.175  -77.466  47.189  1
177844  98.196  -77.466  47.163  1
177845  98.216  -77.465  47.136  1
177846  98.236  -77.465  47.109  1
177847  98.256  -77.464  47.083  1
177848  98.276  -77.464  47.057  1
177849  98.296  -77.464  47.032  1
177850  98.316  -77.463  47.006  1
177851  98.339  -77.470  46.980  1
177852  98.370  -77.507  46.954  1
177853  98.402  -77.543  46.927  1
177854  98.434  -77.580  46.900  1
177855  98.452  -77.607  46.875  1
177856  98.448  -77.617  46.849  1
177857  98.444  -77.628  46.824  1
177858  98.440  -77.638  46.801  1
177859  98.443  -77.639  46.780  1
177860  98.459  -77.638  46.757  1
177861  98.481  -77.637  46.733  1
177862  98.502  -77.636  46.710  1
177863  98.527  -77.632  46.687  1
177864  98.553  -77.627  46.665  1
177865  98.578  -77.620  46.643  1
177866  98.604  -77.615  46.621  1
177867  98.627  -77.619  46.598  1
177868  98.648  -77.624  46.576  1
177869  98.670  -77.630  46.553  1
177870  98.692  -77.635  46.531  1
177871  98.713  -77.640  46.510  1
177872  98.734  -77.645  46.490  1
177873  98.756  -77.650  46.470  1
177874  98.778  -77.644  46.451  1
177875  98.791  -77.645  46.431  1
177876  98.799  -77.652  46.411  1
177877  98.806  -77.658  46.390  1
177878  98.814  -77.665  46.370  1
177879  98.821  -77.672  46.351  1
177880  98.829  -77.680  46.331  1
177881  98.837  -77.686  46.311  1
177882  98.844  -77.693  46.290  1
177883  98.850  -77.699  46.268  1
177884  98.856  -77.708  46.246  1
177885  98.855  -77.712  46.225  1
177886  98.854  -77.716  46.203  1
177887  98.853  -77.720  46.180  1
177888  98.852  -77.724  46.158  1
177889  98.851  -77.727  46.136  1
177890  98.850  -77.731  46.114  1
177891  98.857  -77.735  46.092  1
177892  98.868  -77.738  46.073  1
177893  98.893  -77.746  46.053  1
177894  98.930  -77.758  46.033  1
177895  98.964  -77.767  46.012  1
177896  98.989  -77.766  45.994  1
177897  99.015  -77.765  45.977  1
177898  99.040  -77.765  45.960  1
177899  99.066  -77.765  45.945  1
177900  99.091  -77.765  45.931  1
177901  99.122  -77.769  45.918  1
177902  99.152  -77.774  45.905  1
177903  99.181  -77.780  45.892  1
177904  99.206  -77.793  45.881  1
177905  99.239  -77.812  45.871  1
177906  99.273  -77.840  45.860  1
177907  99.306  -77.868  45.851  1
177908  99.330  -77.893  45.842  1
177909  99.354  -77.917  45.833  1
177910  99.378  -77.940  45.823  1
177911  99.396  -77.962  45.815  1
177912  99.403  -77.978  45.807  1
177913  99.410  -77.994  45.799  1
177914  99.417  -78.010  45.790  1
177915  99.432  -78.022  45.783  1
177916  99.454  -78.032  45.775  1
177917  99.476  -78.041  45.766  1
177918  99.497  -78.050  45.756  1
177919  99.519  -78.060  45.746  1
177920  99.541  -78.069  45.735  1
177921  99.562  -78.079  45.724  1
177922  99.600  -78.086  45.713  1
177923  99.625  -78.100  45.702  1
177924  99.650  -78.094  45.691  1
177925  99.681  -78.080  45.679  1
177926  99.711  -78.066  45.667  1
177927  99.742  -78.053  45.654  1
177928  99.773  -78.044  45.640  1
177929  99.817  -78.080  45.625  1
177930  99.859  -78.112  45.610  1
177931  99.896  -78.128  45.595  1
177932  99.932  -78.142  45.580  1
177933  99.968  -78.157  45.565  1
177934  100.004  -78.172  45.550  1
177935  100.037  -78.195  45.534  1
177936  100.069  -78.225  45.519  1
177937  100.101  -78.255  45.504  1
177938  100.134  -78.265  45.490  1
177939  100.163  -78.265  45.475  1
177940  100.168  -78.282  45.459  1
177941  100.172  -78.298  45.444  1
177942  100.177  -78.314  45.428  1
177943  100.182  -78.330  45.412  1
177944  100.187  -78.342  45.397  1
177945  100.192  -78.354  45.380  1
177946  100.197  -78.366  45.364  1
177947  100.206  -78.376  45.347  1
177948  100.236  -78.381  45.331  1
177949  100.266  -78.386  45.315  1
177950  100.296  -78.391  45.300  1
177951  100.326  -78.395  45.285  1
177952  100.357  -78.396  45.269  1
177953  100.388  -78.397  45.254  1
177954  100.419  -78.398  45.239  1
177955  100.451  -78.399  45.225  1
177956  100.486  -78.401  45.210  1
177957  100.524  -78.404  45.194  1
177958  100.563  -78.410  45.178  1
177959  100.603  -78.416  45.162  1
177960  100.643  -78.423  45.146  1
177961  100.684  -78.429  45.130  1
177962  100.723  -78.435  45.113  1
177963  100.764  -78.442  45.096  1
177964  100.801  -78.448  45.079  1
177965  100.827  -78.454  45.063  1
177966  100.853  -78.460  45.047  1
177967  100.880  -78.466  45.032  1
177968  100.906  -78.471  45.018  1
177969  100.932  -78.477  45.004  1
177970  100.959  -78.482  44.989  1
177971  100.985  -78.489  44.974  1
177972  100.997  -78.483  44.958  1
177973  101.041  -78.485  44.944  1
177974  101.093  -78.467  44.928  1
177975  101.146  -78.456  44.912  1
177976  101.178  -78.472  44.896  1
177977  101.199  -78.488  44.880  1
177978  101.225  -78.505  44.864  1
177979  101.251  -78.522  44.848  1
177980  101.277  -78.539  44.832  1
177981  101.304  -78.556  44.816  1
177982  101.330  -78.573  44.800  1
177983  101.356  -78.591  44.783  1
177984  101.382  -78.608  44.766  1
177985  101.408  -78.630  44.751  1
177986  101.433  -78.654  44.736  1
177987  101.460  -78.677  44.720  1
177988  101.485  -78.698  44.705  1
177989  101.512  -78.720  44.690  1
177990  101.538  -78.741  44.675  1
177991  101.565  -78.762  44.660  1
177992  101.591  -78.783  44.644  1
177993  101.616  -78.810  44.629  1
177994  101.639  -78.843  44.614  1
177995  101.662  -78.876  44.600  1
177996  101.685  -78.908  44.586  1
177997  101.697  -78.909  44.572  1
177998  101.707  -78.902  44.558  1
177999  101.724  -78.907  44.544  1
178000  101.741  -78.913  44.530  1
178001  101.757  -78.918  44.517  1
178002  101.774  -78.924  44.505  1
178003  101.791  -78.930  44.493  1
178004  101.808  -78.935  44.480  1
178005  101.825  -78.941  44.467  1
178006  101.841  -78.946  44.455  1
178007  101.858  -78.952  44.443  1
178008  101.875  -78.958  44.431  1
178009  101.892  -78.963  44.419  1
178010  101.908  -78.969  44.408  1
178258  92.919  -76.972  54.090  1
178259  92.939  -76.964  54.102  1
178260  92.960  -76.955  54.112  1
178261  92.980  -76.947  54.123  1
178262  93.000  -76.937  54.131  1
178263  93.021  -76.929  54.140  1
178264  93.041  -76.920  54.150  1
178265  93.062  -76.911  54.159  1
178266  93.082  -76.903  54.168  1
178267  93.102  -76.893  54.175  1
178268  93.123  -76.885  54.181  1
178269  93.142  -76.881  54.188  1
178270  93.161  -76.878  54.195  1
178271  93.181  -76.875  54.200  1
178272  93.200  -76.871  54.204  1
178273  93.219  -76.868  54.208  1
178274  93.238  -76.865  54.212  1
178275  93.257  -76.861  54.214  1
178276  93.276  -76.858  54.217  1
178277  93.296  -76.855  54.218  1
178278  93.315  -76.851  54.220  1
178279  93.334  -76.848  54.221  1
178280  93.354  -76.845  54.220  1
178281  93.373  -76.842  54.221  1
178282  93.393  -76.839  54.222  1
178283  93.412  -76.836  54.225  1
178284  93.431  -76.833  54.231  1
178285  93.445  -76.825  54.238  1
178286  93.459  -76.818  54.247  1
178287  93.472  -76.810  54.255  1
178288  93.489  -76.806  54.263  1
178289  93.512  -76.806  54.270  1
178290  93.535  -76.806  54.276  1
178291  93.552  -76.802  54.279  1
178292  93.569  -76.797  54.280  1
178293  93.586  -76.793  54.280  1
178294  93.604  -76.789  54.281  1
178295  93.621  -76.785  54.282  1
178296  93.638  -76.781  54.281  1
178297  93.655  -76.776  54.279  1
178298  93.672  -76.771  54.275  1
178299  93.690  -76.763  54.268  1
178300  93.708  -76.755  54.260  1
178301  93.725  -76.747  54.252  1
178302  93.739  -76.740  54.243  1
178303  93.755  -76.735  54.235  1
178304  93.772  -76.730  54.225  1
178305  93.790  -76.725  54.212  1
178306  93.807  -76.721  54.197  1
178307  93.825  -76.716  54.183  1
178308  93.842  -76.712  54.172  1
178309  93.860  -76.706  54.163  1
178310  93.876  -76.705  54.156  1
178311  93.892  -76.706  54.148  1
178312  93.907  -76.707  54.139  1
178313  93.922  -76.708  54.129  1
178314  93.940  -76.706  54.120  1
178315  93.958  -76.705  54.111  1
178316  93.976  -76.703  54.104  1
178317  93.993  -76.702  54.099  1
178318  94.011  -76.700  54.098  1
178319  94.029  -76.699  54.098  1
178320  94.047  -76.697  54.099  1
178321  94.064  -76.696  54.102  1
178322  94.080  -76.695  54.105  1
178323  94.092  -76.695  54.106  1
178324  94.103  -76.693  54.105  1
178325  94.112  -76.691  54.104  1
178326  94.121  -76.688  54.095  1
178327  94.131  -76.685  54.085  1
178328  94.140  -76.683  54.074  1
178329  94.149  -76.680  54.061  1
178330  94.155  -76.678  54.049  1
178331  94.151  -76.680  54.037  1
178332  94.173  -76.674  54.024  1
178333  94.193  -76.668  54.006  1
178334  94.214  -76.661  53.988  1
178335  94.235  -76.655  53.969  1
178336  94.255  -76.649  53.950  1
178337  94.276  -76.643  53.931  1
178338  94.295  -76.636  53.909  1
178339  94.312  -76.630  53.884  1
178340  94.327  -76.622  53.855  1
178341  94.343  -76.615  53.824  1
178342  94.359  -76.608  53.792  1
178343  94.374  -76.601  53.759  1
178344  94.391  -76.594  53.725  1
178345  94.408  -76.586  53.690  1
178346  94.424  -76.577  53.654  1
178347  94.434  -76.573  53.615  1
178348  94.444  -76.567  53.576  1
178349  94.454  -76.563  53.538  1
178350  94.464  -76.558  53.501  1
178351  94.474  -76.553  53.466  1
178352  94.516  -76.547  53.431  1
178353  94.560  -76.541  53.393  1
178354  94.596  -76.541  53.354  1
178355  94.628  -76.542  53.317  1
178356  94.660  -76.544  53.283  1
178357  94.681  -76.540  53.251  1
178358  94.698  -76.535  53.221  1
178359  94.715  -76.530  53.197  1
178360  94.732  -76.525  53.172  1
178361  94.758  -76.518  53.148  1
178362  94.769  -76.514  53.121  1
178363  94.784  -76.520  53.095  1
178364  94.792  -76.521  53.068  1
178365  94.800  -76.523  53.041  1
178366  94.807  -76.524  53.014  1
178367  94.815  -76.526  52.984  1
178368  94.822  -76.528  52.956  1
178369  94.830  -76.530  52.931  1
178370  94.837  -76.531  52.904  1
178371  94.845  -76.533  52.873  1
178372  94.853  -76.534  52.838  1
178373  94.860  -76.536  52.799  1
178374  94.868  -76.538  52.756  1
178375  94.876  -76.539  52.710  1
178376  94.883  -76.541  52.662  1
178377  94.891  -76.542  52.611  1
178378  94.898  -76.544  52.560  1
178379  94.906  -76.546  52.508  1
178380  94.913  -76.548  52.455  1
178381  94.931  -76.552  52.400  1
178382  94.969  -76.559  52.346  1
178383  95.005  -76.567  52.294  1
178384  95.043  -76.574  52.243  1
178385  95.080  -76.582  52.191  1
178386  95.117  -76.589  52.140  1
178387  95.154  -76.597  52.088  1
178388  95.191  -76.605  52.036  1
178389  95.212  -76.616  51.985  1
178390  95.227  -76.629  51.936  1
178391  95.241  -76.643  51.887  1
178392  95.256  -76.658  51.839  1
178393  95.270  -76.671  51.791  1
178394  95.284  -76.686  51.742  1
178395  95.299  -76.700  51.694  1
178396  95.314  -76.715  51.649  1
178397  95.328  -76.728  51.605  1
178398  95.343  -76.743  51.561  1
178399  95.357  -76.757  51.517  1
178400  95.372  -76.771  51.476  1
178401  95.411  -76.781  51.435  1
178402  95.410  -76.787  51.394  1
178403  95.397  -76.789  51.354  1
178404  95.408  -76.791  51.312  1
178405  95.422  -76.797  51.269  1
178406  95.448  -76.815  51.226  1
178407  95.474  -76.831  51.184  1
178408  95.500  -76.848  51.147  1
178409  95.526  -76.865  51.110  1
178410  95.552  -76.882  51.072  1
178411  95.578  -76.900  51.037  1
178412  95.603  -76.916  50.999  1
178413  95.629  -76.934  50.960  1
178414  95.651  -76.946  50.919  1
178415  95.670  -76.954  50.875  1
178416  95.688  -76.962  50.832  1
178417  95.706  -76.971  50.789  1
178418  95.725  -76.980  50.745  1
178419  95.744  -76.988  50.701  1
178420  95.762  -76.997  50.655  1
178421  95.781  -77.005  50.607  1
178422  95.800  -77.013  50.563  1
178423  95.818  -77.022  50.516  1
178424  95.840  -77.031  50.467  1
178425  95.876  -77.038  50.415  1
178426  95.911  -77.045  50.360  1
178427  95.946  -77.052  50.303  1
178428  95.978  -77.047  50.244  1
178429  96.010  -77.041  50.183  1
178430  96.035  -77.044  50.117  1
178431  96.049  -77.059  50.050  1
178432  96.063  -77.074  49.983  1
178433  96.077  -77.089  49.917  1
178434  96.091  -77.104  49.854  1
178435  96.107  -77.113  49.795  1
178436  96.125  -77.110  49.739  1
178437  96.144  -77.108  49.686  1
178438  96.163  -77.106  49.636  1
178439  96.182  -77.103  49.589  1
178440  96.200  -77.100  49.545  1
178441  96.221  -77.088  49.504  1
178442  96.235  -77.089  49.468  1
178443  96.239  -77.110  49.434  1
178444  96.242  -77.131  49.401  1
178445  96.246  -77.151  49.371  1
178446  96.264  -77.158  49.342  1
178447  96.284  -77.163  49.313  1
178448  96.303  -77.168  49.287  1
178449  96.323  -77.172  49.263  1
178450  96.342  -77.178  49.241  1
178451  96.362  -77.182  49.221  1
178452  96.381  -77.188  49.202  1
178453  96.401  -77.193  49.184  1
178454  96.420  -77.197  49.167  1
178455  96.440  -77.203  49.151  1
178456  96.460  -77.207  49.138  1
178457  96.479  -77.213  49.126  1
178458  96.500  -77.215  49.114  1
178459  96.520  -77.213  49.100  1
178460  96.541  -77.211  49.085  1
178461  96.557  -77.226  49.069  1
178462  96.573  -77.241  49.053  1
178463  96.588  -77.258  49.038  1
178464  96.606  -77.269  49.022  1
178465  96.625  -77.279  49.005  1
178466  96.644  -77.289  48.988  1
178467  96.662  -77.300  48.970  1
178468  96.678  -77.313  48.951  1
178469  96.694  -77.326  48.932  1
178470  96.710  -77.340  48.913  1
178471  96.726  -77.353  48.896  1
178472  96.742  -77.367  48.880  1
178473  96.757  -77.379  48.863  1
178474  96.766  -77.420  48.846  1
178475  96.778  -77.448  48.829  1
178476  96.793  -77.453  48.813  1
178477  96.809  -77.458  48.797  1
178478  96.824  -77.464  48.780  1
178479  96.839  -77.469  48.763  1
178480  96.855  -77.473  48.745  1
178481  96.870  -77.479  48.727  1
178482  96.886  -77.484  48.708  1
178483  96.901  -77.489  48.688  1
178484  96.944  -77.483  48.669  1
178485  96.986  -77.492  48.652  1
178486  97.023  -77.506  48.633  1
178487  97.059  -77.520  48.615  1
178488  97.089  -77.545  48.596  1
178489  97.117  -77.570  48.574  1
178490  97.147  -77.595  48.554  1
178491  97.175  -77.620  48.534  1
178492  97.205  -77.644  48.514  1
178493  97.225  -77.653  48.493  1
178494  97.234  -77.642  48.474  1
178495  97.243  -77.630  48.455  1
178496  97.252  -77.618  48.435  1
178497  97.261  -77.606  48.415  1
178498  97.268  -77.591  48.395  1
178499  97.276  -77.576  48.375  1
178500  97.283  -77.561  48.356  1
178501  97.290  -77.545  48.336  1
178502  97.297  -77.530  48.315  1
178503  97.305  -77.515  48.295  1
178504  97.312  -77.500  48.274  1
178505  97.319  -77.485  48.255  1
178506  97.341  -77.483  48.235  1
178507  97.363  -77.492  48.215  1
178508  97.386  -77.499  48.193  1
178509  97.408  -77.508  48.172  1
178510  97.431  -77.516  48.151  1
178511  97.452  -77.526  48.129  1
178512  97.470  -77.539  48.106  1
178513  97.490  -77.551  48.082  1
178514  97.509  -77.564  48.057  1
178515  97.528  -77.576  48.031  1
178516  97.547  -77.588  48.005  1
178517  97.566  -77.601  47.978  1
178518  97.585  -77.613  47.950  1
178519  97.611  -77.613  47.921  1
178520  97.639  -77.611  47.892  1
178521  97.674  -77.613  47.862  1
178522  97.720  -77.619  47.832  1
178523  97.765  -77.626  47.802  1
178524  97.811  -77.632  47.772  1
178525  97.856  -77.639  47.743  1
178526  97.880  -77.637  47.712  1
178527  97.895  -77.633  47.682  1
178528  97.910  -77.629  47.653  1
178529  97.925  -77.625  47.624  1
178530  97.948  -77.626  47.595  1
178531  97.982  -77.634  47.567  1
178532  97.999  -77.624  47.539  1
178533  98.017  -77.614  47.511  1
178534  98.034  -77.605  47.482  1
178535  98.052  -77.595  47.454  1
178536  98.069  -77.585  47.426  1
178537  98.087  -77.575  47.398  1
178538  98.084  -77.563  47.370  1
178539  98.096  -77.516  47.342  1
178540  98.119  -77.491  47.314  1
178541  98.139  -77.491  47.285  1
178542  98.159  -77.490  47.256  1
178543  98.179  -77.489  47.227  1
178544  98.199  -77.489  47.198  1
178545  98.219  -77.489  47.170  1
178546  98.239  -77.489  47.143  1
178547  98.260  -77.488  47.116  1
178548  98.280  -77.488  47.089  1
178549  98.300  -77.487  47.063  1
178550  98.320  -77.487  47.038  1
178551  98.340  -77.486  47.013  1
178552  98.360  -77.486  46.987  1
178553  98.380  -77.486  46.960  1
178554  98.408  -77.508  46.934  1
178555  98.439  -77.544  46.908  1
178556  98.471  -77.580  46.883  1
178557  98.475  -77.597  46.859  1
178558  98.471  -77.608  46.835  1
178559  98.468  -77.614  46.812  1
178560  98.471  -77.615  46.790  1
178561  98.473  -77.615  46.767  1
178562  98.495  -77.614  46.744  1
178563  98.517  -77.614  46.721  1
178564  98.543  -77.608  46.698  1
178565  98.568  -77.602  46.676  1
178566  98.592  -77.603  46.653  1
178567  98.614  -77.608  46.631  1
178568  98.636  -77.614  46.608  1
178569  98.657  -77.619  46.585  1
178570  98.679  -77.624  46.561  1
178571  98.701  -77.630  46.539  1
178572  98.722  -77.635  46.517  1
178573  98.744  -77.639  46.497  1
178574  98.766  -77.639  46.477  1
178575  98.786  -77.632  46.457  1
178576  98.800  -77.632  46.438  1
178577  98.810  -77.636  46.418  1
178578  98.818  -77.642  46.398  1
178579  98.826  -77.650  46.378  1
178580  98.833  -77.657  46.358  1
178581  98.841  -77.664  46.339  1
178582  98.848  -77.671  46.319  1
178583  98.844  -77.673  46.298  1
178584  98.841  -77.677  46.276  1
178585  98.864  -77.697  46.254  1
178586  98.868  -77.704  46.233  1
178587  98.867  -77.708  46.211  1
178588  98.866  -77.711  46.189  1
178589  98.865  -77.715  46.167  1
178590  98.864  -77.719  46.144  1
178591  98.866  -77.723  46.121  1
178592  98.876  -77.726  46.098  1
178593  98.887  -77.729  46.077  1
178594  98.898  -77.732  46.057  1
178595  98.929  -77.743  46.037  1
178596  98.966  -77.755  46.017  1
178597  99.004  -77.768  45.998  1
178598  99.038  -77.777  45.981  1
178599  99.063  -77.776  45.964  1
178600  99.089  -77.775  45.949  1
178601  99.115  -77.775  45.934  1
178602  99.140  -77.774  45.921  1
178603  99.165  -77.774  45.909  1
178604  99.191  -77.773  45.898  1
178605  99.217  -77.787  45.886  1
178606  99.251  -77.815  45.874  1
178607  99.283  -77.843  45.863  1
178608  99.306  -77.867  45.853  1
178609  99.330  -77.891  45.844  1
178610  99.354  -77.915  45.834  1
178611  99.377  -77.939  45.825  1
178612  99.401  -77.963  45.817  1
178613  99.418  -77.984  45.809  1
178614  99.425  -78.000  45.801  1
178615  99.439  -78.012  45.792  1
178616  99.461  -78.022  45.784  1
178617  99.482  -78.031  45.776  1
178618  99.504  -78.040  45.767  1
178619  99.525  -78.050  45.758  1
178620  99.547  -78.059  45.747  1
178621  99.568  -78.069  45.736  1
178622  99.590  -78.078  45.725  1
178623  99.612  -78.087  45.714  1
178624  99.637  -78.085  45.703  1
178625  99.667  -78.072  45.693  1
178626  99.698  -78.058  45.681  1
178627  99.728  -78.045  45.669  1
178628  99.759  -78.031  45.656  1
178629  99.791  -78.028  45.642  1
178630  99.835  -78.063  45.628  1
178631  99.872  -78.081  45.613  1
178632  99.909  -78.096  45.599  1
178633  99.945  -78.111  45.585  1
178634  99.978  -78.137  45.569  1
178635  100.009  -78.166  45.555  1
178636  100.041  -78.197  45.541  1
178637  100.073  -78.226  45.526  1
178638  100.105  -78.243  45.510  1
178639  100.138  -78.251  45.495  1
178640  100.177  -78.243  45.480  1
178641  100.182  -78.260  45.465  1
178642  100.186  -78.276  45.450  1
178643  100.191  -78.293  45.434  1
178644  100.196  -78.309  45.417  1
178645  100.200  -78.326  45.401  1
178646  100.205  -78.342  45.385  1
178647  100.210  -78.356  45.368  1
178648  100.215  -78.368  45.352  1
178649  100.235  -78.376  45.336  1
178650  100.265  -78.380  45.321  1
178651  100.296  -78.382  45.305  1
178652  100.327  -78.383  45.290  1
178653  100.358  -78.384  45.275  1
178654  100.389  -78.385  45.260  1
178655  100.420  -78.386  45.244  1
178656  100.452  -78.387  45.229  1
178657  100.489  -78.390  45.214  1
178658  100.527  -78.393  45.198  1
178659  100.564  -78.396  45.182  1
178660  100.604  -78.403  45.166  1
178661  100.644  -78.410  45.150  1
178662  100.685  -78.416  45.133  1
178663  100.725  -78.423  45.116  1
178664  100.765  -78.429  45.099  1
178665  100.793  -78.435  45.083  1
178666  100.819  -78.441  45.067  1
178667  100.845  -78.446  45.051  1
178668  100.872  -78.451  45.037  1
178669  100.898  -78.457  45.023  1
178670  100.924  -78.463  45.009  1
178671  100.951  -78.469  44.994  1
178672  100.977  -78.474  44.979  1
178673  101.005  -78.480  44.964  1
178674  101.054  -78.465  44.950  1
178675  101.106  -78.447  44.934  1
178676  101.152  -78.445  44.917  1
178677  101.175  -78.461  44.901  1
178678  101.201  -78.478  44.886  1
178679  101.228  -78.495  44.870  1
178680  101.254  -78.512  44.854  1
178681  101.280  -78.529  44.837  1
178682  101.306  -78.547  44.820  1
178683  101.332  -78.564  44.804  1
178684  101.358  -78.581  44.788  1
178685  101.385  -78.598  44.770  1
178686  101.411  -78.620  44.755  1
178687  101.437  -78.642  44.739  1
178688  101.462  -78.665  44.724  1
178689  101.488  -78.688  44.709  1
178690  101.514  -78.711  44.694  1
178691  101.541  -78.732  44.679  1
178692  101.567  -78.753  44.664  1
178693  101.592  -78.780  44.648  1
178694  101.615  -78.813  44.633  1
178695  101.637  -78.846  44.618  1
178696  101.661  -78.879  44.604  1
178697  101.683  -78.912  44.590  1
178698  101.698  -78.921  44.576  1
178699  101.705  -78.906  44.561  1
178700  101.719  -78.906  44.547  1
178701  101.736  -78.912  44.533  1
178702  101.752  -78.917  44.521  1
178703  101.769  -78.923  44.509  1
178704  101.786  -78.928  44.496  1
178705  101.802  -78.934  44.482  1
178706  101.820  -78.940  44.469  1
178707  101.836  -78.946  44.457  1
178708  101.853  -78.951  44.445  1
178709  101.870  -78.956  44.433  1
178710  101.887  -78.962  44.422  1
178711  101.903  -78.968  44.410  1
178961  92.949  -76.931  54.092  1
178962  92.970  -76.923  54.103  1
178963  92.990  -76.914  54.112  1
178964  93.010  -76.905  54.122  1
178965  93.030  -76.897  54.132  1
178966  93.051  -76.887  54.143  1
178967  93.071  -76.879  54.151  1
178968  93.092  -76.870  54.160  1
178969  93.112  -76.862  54.168  1
178970  93.132  -76.857  54.174  1
178971  93.151  -76.854  54.181  1
178972  93.170  -76.850  54.187  1
178973  93.189  -76.847  54.192  1
178974  93.208  -76.844  54.196  1
178975  93.227  -76.840  54.200  1
178976  93.247  -76.837  54.202  1
178977  93.266  -76.834  54.204  1
178978  93.285  -76.831  54.206  1
178979  93.304  -76.828  54.208  1
178980  93.324  -76.824  54.209  1
178981  93.343  -76.821  54.210  1
178982  93.363  -76.818  54.211  1
178983  93.382  -76.815  54.212  1
178984  93.402  -76.812  54.215  1
178985  93.421  -76.809  54.219  1
178986  93.440  -76.806  54.224  1
178987  93.460  -76.803  54.232  1
178988  93.477  -76.799  54.240  1
178989  93.491  -76.791  54.248  1
178990  93.509  -76.787  54.257  1
178991  93.531  -76.787  54.264  1
178992  93.548  -76.782  54.268  1
178993  93.565  -76.778  54.269  1
178994  93.582  -76.774  54.271  1
178995  93.599  -76.769  54.273  1
178996  93.617  -76.765  54.275  1
178997  93.634  -76.760  54.275  1
178998  93.651  -76.755  54.273  1
178999  93.669  -76.751  54.270  1
179000  93.687  -76.743  54.263  1
179001  93.705  -76.736  54.256  1
179002  93.723  -76.727  54.248  1
179003  93.736  -76.721  54.241  1
179004  93.751  -76.714  54.234  1
179005  93.766  -76.708  54.226  1
179006  93.783  -76.703  54.215  1
179007  93.801  -76.699  54.200  1
179008  93.819  -76.694  54.185  1
179009  93.836  -76.690  54.174  1
179010  93.854  -76.684  54.165  1
179011  93.870  -76.683  54.159  1
179012  93.886  -76.684  54.153  1
179013  93.901  -76.686  54.146  1
179014  93.916  -76.687  54.137  1
179015  93.932  -76.687  54.129  1
179016  93.949  -76.685  54.122  1
179017  93.967  -76.683  54.116  1
179018  93.985  -76.682  54.110  1
179019  94.003  -76.680  54.108  1
179020  94.020  -76.679  54.106  1
179021  94.038  -76.677  54.106  1
179022  94.056  -76.676  54.108  1
179023  94.070  -76.677  54.112  1
179024  94.085  -76.677  54.115  1
179025  94.097  -76.677  54.117  1
179026  94.107  -76.676  54.117  1
179027  94.116  -76.675  54.111  1
179028  94.126  -76.674  54.103  1
179029  94.136  -76.671  54.094  1
179030  94.145  -76.668  54.082  1
179031  94.154  -76.665  54.071  1
179032  94.157  -76.665  54.060  1
179033  94.178  -76.658  54.048  1
179034  94.198  -76.652  54.031  1
179035  94.219  -76.646  54.012  1
179036  94.238  -76.640  53.994  1
179037  94.256  -76.633  53.977  1
179038  94.272  -76.627  53.958  1
179039  94.287  -76.621  53.937  1
179040  94.302  -76.615  53.912  1
179041  94.318  -76.608  53.883  1
179042  94.334  -76.601  53.853  1
179043  94.350  -76.594  53.821  1
179044  94.365  -76.586  53.788  1
179045  94.382  -76.579  53.754  1
179046  94.402  -76.568  53.721  1
179047  94.421  -76.558  53.686  1
179048  94.433  -76.552  53.646  1
179049  94.443  -76.547  53.606  1
179050  94.454  -76.542  53.567  1
179051  94.464  -76.538  53.528  1
179052  94.478  -76.533  53.490  1
179053  94.522  -76.527  53.452  1
179054  94.563  -76.523  53.413  1
179055  94.596  -76.524  53.372  1
179056  94.628  -76.526  53.333  1
179057  94.660  -76.527  53.298  1
179058  94.681  -76.524  53.266  1
179059  94.698  -76.518  53.238  1
179060  94.715  -76.514  53.213  1
179061  94.733  -76.508  53.189  1
179062  94.750  -76.504  53.164  1
179063  94.752  -76.505  53.138  1
179064  94.755  -76.507  53.110  1
179065  94.763  -76.508  53.082  1
179066  94.770  -76.510  53.054  1
179067  94.778  -76.511  53.026  1
179068  94.785  -76.513  52.999  1
179069  94.793  -76.515  52.972  1
179070  94.801  -76.517  52.948  1
179071  94.808  -76.518  52.921  1
179072  94.816  -76.520  52.891  1
179073  94.823  -76.521  52.857  1
179074  94.831  -76.523  52.820  1
179075  94.838  -76.524  52.777  1
179076  94.846  -76.527  52.731  1
179077  94.853  -76.528  52.682  1
179078  94.861  -76.530  52.631  1
179079  94.868  -76.531  52.579  1
179080  94.876  -76.533  52.528  1
179081  94.884  -76.534  52.476  1
179082  94.902  -76.538  52.423  1
179083  94.939  -76.546  52.369  1
179084  94.977  -76.554  52.315  1
179085  95.014  -76.561  52.264  1
179086  95.051  -76.569  52.211  1
179087  95.088  -76.577  52.160  1
179088  95.125  -76.584  52.109  1
179089  95.166  -76.593  52.056  1
179090  95.207  -76.605  52.006  1
179091  95.221  -76.618  51.955  1
179092  95.236  -76.633  51.905  1
179093  95.250  -76.647  51.856  1
179094  95.265  -76.661  51.807  1
179095  95.279  -76.675  51.759  1
179096  95.294  -76.690  51.711  1
179097  95.308  -76.704  51.665  1
179098  95.323  -76.718  51.619  1
179099  95.337  -76.733  51.574  1
179100  95.352  -76.746  51.531  1
179101  95.373  -76.760  51.489  1
179102  95.414  -76.770  51.447  1
179103  95.433  -76.777  51.406  1
179104  95.416  -76.780  51.367  1
179105  95.398  -76.782  51.327  1
179106  95.410  -76.787  51.285  1
179107  95.436  -76.804  51.244  1
179108  95.462  -76.821  51.205  1
179109  95.488  -76.837  51.169  1
179110  95.514  -76.855  51.133  1
179111  95.540  -76.872  51.097  1
179112  95.566  -76.890  51.061  1
179113  95.593  -76.907  51.023  1
179114  95.619  -76.925  50.984  1
179115  95.645  -76.940  50.944  1
179116  95.670  -76.947  50.901  1
179117  95.692  -76.954  50.857  1
179118  95.711  -76.962  50.812  1
179119  95.730  -76.971  50.767  1
179120  95.748  -76.979  50.722  1
179121  95.766  -76.987  50.674  1
179122  95.785  -76.997  50.627  1
179123  95.804  -77.005  50.583  1
179124  95.822  -77.013  50.535  1
179125  95.847  -77.022  50.484  1
179126  95.883  -77.029  50.429  1
179127  95.918  -77.037  50.373  1
179128  95.950  -77.031  50.314  1
179129  95.982  -77.027  50.254  1
179130  96.014  -77.022  50.193  1
179131  96.038  -77.025  50.126  1
179132  96.052  -77.041  50.059  1
179133  96.066  -77.056  49.991  1
179134  96.080  -77.071  49.927  1
179135  96.094  -77.085  49.866  1
179136  96.108  -77.100  49.807  1
179137  96.122  -77.116  49.752  1
179138  96.141  -77.114  49.701  1
179139  96.159  -77.112  49.652  1
179140  96.178  -77.110  49.605  1
179141  96.197  -77.107  49.560  1
179142  96.218  -77.094  49.520  1
179143  96.239  -77.081  49.485  1
179144  96.246  -77.095  49.451  1
179145  96.249  -77.116  49.418  1
179146  96.260  -77.130  49.389  1
179147  96.279  -77.135  49.359  1
179148  96.299  -77.140  49.330  1
179149  96.318  -77.144  49.305  1
179150  96.338  -77.150  49.282  1
179151  96.358  -77.154  49.261  1
179152  96.377  -77.160  49.240  1
179153  96.397  -77.165  49.221  1
179154  96.416  -77.169  49.204  1
179155  96.436  -77.175  49.188  1
179156  96.456  -77.179  49.171  1
179157  96.475  -77.185  49.158  1
179158  96.495  -77.189  49.146  1
179159  96.514  -77.194  49.133  1
179160  96.534  -77.197  49.120  1
179161  96.555  -77.196  49.106  1
179162  96.572  -77.208  49.091  1
179163  96.587  -77.224  49.075  1
179164  96.606  -77.235  49.059  1
179165  96.624  -77.244  49.042  1
179166  96.641  -77.257  49.026  1
179167  96.657  -77.270  49.009  1
179168  96.673  -77.284  48.991  1
179169  96.689  -77.298  48.972  1
179170  96.704  -77.310  48.952  1
179171  96.721  -77.324  48.932  1
179172  96.736  -77.338  48.914  1
179173  96.752  -77.351  48.897  1
179174  96.766  -77.373  48.879  1
179175  96.836  -77.404  48.860  1
179176  96.802  -77.422  48.842  1
179177  96.797  -77.432  48.825  1
179178  96.812  -77.438  48.808  1
179179  96.827  -77.442  48.789  1
179180  96.843  -77.448  48.770  1
179181  96.858  -77.453  48.752  1
179182  96.874  -77.458  48.733  1
179183  96.889  -77.463  48.714  1
179184  96.904  -77.468  48.694  1
179185  96.939  -77.465  48.675  1
179186  96.991  -77.467  48.658  1
179187  97.027  -77.481  48.640  1
179188  97.063  -77.495  48.622  1
179189  97.092  -77.520  48.604  1
179190  97.121  -77.545  48.583  1
179191  97.150  -77.570  48.563  1
179192  97.179  -77.595  48.542  1
179193  97.209  -77.620  48.521  1
179194  97.237  -77.645  48.500  1
179195  97.253  -77.645  48.479  1
179196  97.262  -77.633  48.460  1
179197  97.272  -77.622  48.439  1
179198  97.280  -77.608  48.419  1
179199  97.287  -77.593  48.399  1
179200  97.294  -77.578  48.380  1
179201  97.301  -77.563  48.362  1
179202  97.309  -77.548  48.344  1
179203  97.316  -77.533  48.324  1
179204  97.323  -77.517  48.304  1
179205  97.330  -77.502  48.283  1
179206  97.337  -77.487  48.264  1
179207  97.351  -77.477  48.245  1
179208  97.374  -77.485  48.225  1
179209  97.396  -77.493  48.203  1
179210  97.417  -77.503  48.181  1
179211  97.436  -77.516  48.160  1
179212  97.455  -77.528  48.138  1
179213  97.474  -77.540  48.115  1
179214  97.494  -77.553  48.090  1
179215  97.513  -77.565  48.064  1
179216  97.531  -77.577  48.038  1
179217  97.550  -77.590  48.012  1
179218  97.570  -77.602  47.984  1
179219  97.593  -77.607  47.956  1
179220  97.620  -77.605  47.926  1
179221  97.648  -77.604  47.896  1
179222  97.687  -77.608  47.866  1
179223  97.733  -77.614  47.836  1
179224  97.779  -77.620  47.806  1
179225  97.824  -77.627  47.775  1
179226  97.870  -77.633  47.745  1
179227  97.910  -77.637  47.714  1
179228  97.924  -77.633  47.684  1
179229  97.939  -77.630  47.655  1
179230  97.954  -77.625  47.626  1
179231  97.969  -77.621  47.597  1
179232  97.991  -77.619  47.569  1
179233  98.009  -77.609  47.540  1
179234  98.026  -77.599  47.512  1
179235  98.044  -77.589  47.484  1
179236  98.061  -77.580  47.456  1
179237  98.079  -77.570  47.429  1
179238  98.096  -77.559  47.401  1
179239  98.113  -77.549  47.374  1
179240  98.122  -77.514  47.346  1
179241  98.142  -77.514  47.319  1
179242  98.162  -77.514  47.290  1
179243  98.182  -77.514  47.262  1
179244  98.203  -77.513  47.234  1
179245  98.223  -77.513  47.205  1
179246  98.243  -77.512  47.177  1
179247  98.263  -77.511  47.150  1
179248  98.283  -77.511  47.123  1
179249  98.303  -77.511  47.095  1
179250  98.323  -77.511  47.069  1
179251  98.344  -77.510  47.044  1
179252  98.364  -77.510  47.019  1
179253  98.384  -77.509  46.993  1
179254  98.404  -77.509  46.967  1
179255  98.424  -77.508  46.942  1
179256  98.444  -77.508  46.916  1
179257  98.476  -77.545  46.891  1
179258  98.501  -77.577  46.868  1
179259  98.497  -77.587  46.846  1
179260  98.497  -77.592  46.824  1
179261  98.499  -77.592  46.800  1
179262  98.501  -77.592  46.777  1
179263  98.509  -77.592  46.754  1
179264  98.532  -77.589  46.732  1
179265  98.557  -77.586  46.709  1
179266  98.579  -77.592  46.686  1
179267  98.601  -77.598  46.663  1
179268  98.623  -77.603  46.640  1
179269  98.645  -77.608  46.617  1
179270  98.667  -77.614  46.594  1
179271  98.689  -77.619  46.569  1
179272  98.710  -77.624  46.546  1
179273  98.732  -77.630  46.525  1
179274  98.753  -77.634  46.505  1
179275  98.777  -77.624  46.484  1
179276  98.795  -77.619  46.464  1
179277  98.808  -77.620  46.444  1
179278  98.822  -77.620  46.425  1
179279  98.830  -77.627  46.405  1
179280  98.837  -77.634  46.385  1
179281  98.845  -77.641  46.365  1
179282  98.844  -77.645  46.345  1
179283  98.838  -77.647  46.325  1
179284  98.831  -77.649  46.304  1
179285  98.842  -77.661  46.283  1
179286  98.865  -77.680  46.260  1
179287  98.881  -77.696  46.239  1
179288  98.880  -77.699  46.217  1
179289  98.879  -77.703  46.195  1
179290  98.878  -77.707  46.173  1
179291  98.878  -77.711  46.150  1
179292  98.885  -77.714  46.127  1
179293  98.896  -77.718  46.104  1
179294  98.906  -77.721  46.083  1
179295  98.917  -77.724  46.063  1
179296  98.928  -77.727  46.043  1
179297  98.964  -77.739  46.023  1
179298  99.002  -77.752  46.004  1
179299  99.040  -77.764  45.986  1
179300  99.077  -77.777  45.969  1
179301  99.112  -77.787  45.954  1
179302  99.138  -77.786  45.939  1
179303  99.163  -77.785  45.925  1
179304  99.189  -77.785  45.913  1
179305  99.206  -77.778  45.901  1
179306  99.228  -77.790  45.889  1
179307  99.259  -77.817  45.877  1
179308  99.283  -77.841  45.866  1
179309  99.306  -77.865  45.855  1
179310  99.330  -77.889  45.845  1
179311  99.354  -77.913  45.836  1
179312  99.377  -77.937  45.827  1
179313  99.401  -77.961  45.819  1
179314  99.425  -77.985  45.811  1
179315  99.445  -78.003  45.802  1
179316  99.467  -78.012  45.793  1
179317  99.487  -78.020  45.785  1
179318  99.508  -78.028  45.777  1
179319  99.529  -78.037  45.769  1
179320  99.550  -78.045  45.759  1
179321  99.571  -78.053  45.748  1
179322  99.592  -78.062  45.737  1
179323  99.613  -78.071  45.726  1
179324  99.635  -78.077  45.715  1
179325  99.661  -78.063  45.705  1
179326  99.688  -78.050  45.694  1
179327  99.715  -78.036  45.682  1
179328  99.745  -78.023  45.671  1
179329  99.776  -78.009  45.658  1
179330  99.810  -78.011  45.645  1
179331  99.849  -78.034  45.631  1
179332  99.886  -78.050  45.618  1
179333  99.918  -78.078  45.604  1
179334  99.949  -78.108  45.590  1
179335  99.981  -78.138  45.575  1
179336  100.012  -78.168  45.561  1
179337  100.044  -78.197  45.546  1
179338  100.076  -78.220  45.531  1
179339  100.109  -78.229  45.516  1
179340  100.142  -78.238  45.501  1
179341  100.179  -78.237  45.486  1
179342  100.196  -78.238  45.470  1
179343  100.200  -78.254  45.455  1
179344  100.205  -78.271  45.438  1
179345  100.209  -78.287  45.421  1
179346  100.214  -78.304  45.404  1
179347  100.219  -78.320  45.389  1
179348  100.223  -78.337  45.373  1
179349  100.228  -78.353  45.357  1
179350  100.235  -78.368  45.342  1
179351  100.266  -78.369  45.327  1
179352  100.297  -78.370  45.311  1
179353  100.328  -78.371  45.295  1
179354  100.359  -78.372  45.280  1
179355  100.390  -78.373  45.265  1
179356  100.421  -78.374  45.249  1
179357  100.453  -78.375  45.233  1
179358  100.491  -78.379  45.217  1
179359  100.528  -78.382  45.201  1
179360  100.566  -78.385  45.186  1
179361  100.606  -78.389  45.169  1
179362  100.645  -78.396  45.152  1
179363  100.686  -78.403  45.135  1
179364  100.726  -78.409  45.117  1
179365  100.758  -78.415  45.101  1
179366  100.785  -78.421  45.086  1
179367  100.811  -78.426  45.071  1
179368  100.837  -78.432  45.056  1
179369  100.864  -78.438  45.041  1
179370  100.890  -78.444  45.027  1
179371  100.916  -78.449  45.013  1
179372  100.954  -78.456  44.998  1
179373  100.993  -78.462  44.984  1
179374  101.025  -78.469  44.969  1
179375  101.071  -78.450  44.953  1
179376  101.119  -78.428  44.938  1
179377  101.151  -78.434  44.922  1
179378  101.178  -78.451  44.906  1
179379  101.204  -78.468  44.891  1
179380  101.230  -78.485  44.874  1
179381  101.256  -78.503  44.857  1
179382  101.282  -78.520  44.841  1
179383  101.309  -78.537  44.825  1
179384  101.335  -78.554  44.808  1
179385  101.361  -78.571  44.791  1
179386  101.388  -78.589  44.775  1
179387  101.413  -78.609  44.758  1
179388  101.440  -78.632  44.743  1
179389  101.465  -78.655  44.727  1
179390  101.491  -78.677  44.712  1
179391  101.517  -78.700  44.697  1
179392  101.543  -78.723  44.682  1
179393  101.567  -78.751  44.667  1
179394  101.590  -78.783  44.652  1
179395  101.613  -78.817  44.637  1
179396  101.636  -78.849  44.622  1
179397  101.659  -78.883  44.608  1
179398  101.682  -78.915  44.593  1
179399  101.699  -78.931  44.579  1
179400  101.706  -78.918  44.565  1
179401  101.714  -78.905  44.552  1
179402  101.731  -78.911  44.536  1
179403  101.747  -78.916  44.524  1
179404  101.764  -78.921  44.512  1
179405  101.781  -78.927  44.499  1
179406  101.798  -78.933  44.486  1
179407  101.815  -78.939  44.473  1
179408  101.831  -78.944  44.461  1
179409  101.848  -78.949  44.448  1
179410  101.865  -78.955  44.436  1
179411  101.882  -78.961  44.425  1
179412  101.898  -78.967  44.412  1
179663  92.959  -76.899  54.082  1
179664  92.980  -76.890  54.093  1
179665  93.000  -76.881  54.104  1
179666  93.020  -76.873  54.115  1
179667  93.041  -76.864  54.126  1
179668  93.061  -76.855  54.135  1
179669  93.081  -76.846  54.145  1
179670  93.101  -76.837  54.154  1
179671  93.121  -76.834  54.161  1
179672  93.140  -76.830  54.168  1
179673  93.159  -76.827  54.175  1
179674  93.179  -76.824  54.181  1
179675  93.198  -76.820  54.184  1
179676  93.217  -76.817  54.188  1
179677  93.236  -76.814  54.191  1
179678  93.256  -76.810  54.193  1
179679  93.275  -76.807  54.196  1
179680  93.294  -76.804  54.198  1
179681  93.313  -76.801  54.199  1
179682  93.333  -76.798  54.201  1
179683  93.352  -76.795  54.202  1
179684  93.372  -76.792  54.203  1
179685  93.391  -76.789  54.205  1
179686  93.411  -76.786  54.209  1
179687  93.430  -76.783  54.212  1
179688  93.449  -76.780  54.218  1
179689  93.469  -76.777  54.225  1
179690  93.489  -76.774  54.232  1
179691  93.508  -76.771  54.241  1
179692  93.526  -76.766  54.249  1
179693  93.544  -76.762  54.254  1
179694  93.561  -76.757  54.257  1
179695  93.579  -76.752  54.260  1
179696  93.596  -76.748  54.262  1
179697  93.614  -76.743  54.265  1
179698  93.631  -76.739  54.264  1
179699  93.649  -76.734  54.264  1
179700  93.666  -76.729  54.261  1
179701  93.684  -76.724  54.256  1
179702  93.702  -76.716  54.249  1
179703  93.721  -76.708  54.242  1
179704  93.735  -76.701  54.236  1
179705  93.749  -76.694  54.232  1
179706  93.763  -76.688  54.225  1
179707  93.777  -76.682  54.216  1
179708  93.795  -76.677  54.202  1
179709  93.813  -76.672  54.187  1
179710  93.830  -76.668  54.176  1
179711  93.848  -76.662  54.167  1
179712  93.864  -76.661  54.161  1
179713  93.879  -76.663  54.158  1
179714  93.895  -76.664  54.152  1
179715  93.910  -76.665  54.144  1
179716  93.925  -76.666  54.138  1
179717  93.941  -76.666  54.132  1
179718  93.959  -76.665  54.127  1
179719  93.977  -76.663  54.122  1
179720  93.994  -76.661  54.118  1
179721  94.012  -76.660  54.115  1
179722  94.030  -76.658  54.113  1
179723  94.046  -76.658  54.114  1
179724  94.060  -76.658  54.119  1
179725  94.075  -76.659  54.124  1
179726  94.089  -76.660  54.128  1
179727  94.101  -76.659  54.130  1
179728  94.111  -76.658  54.126  1
179729  94.120  -76.657  54.119  1
179730  94.130  -76.656  54.112  1
179731  94.140  -76.655  54.102  1
179732  94.150  -76.653  54.092  1
179733  94.163  -76.649  54.081  1
179734  94.181  -76.643  54.071  1
179735  94.198  -76.636  54.053  1
179736  94.215  -76.630  54.035  1
179737  94.232  -76.624  54.017  1
179738  94.250  -76.618  54.000  1
179739  94.264  -76.611  53.982  1
179740  94.279  -76.606  53.963  1
179741  94.293  -76.600  53.940  1
179742  94.309  -76.593  53.913  1
179743  94.325  -76.586  53.883  1
179744  94.341  -76.579  53.853  1
179745  94.356  -76.572  53.821  1
179746  94.376  -76.562  53.787  1
179747  94.396  -76.552  53.754  1
179748  94.416  -76.541  53.719  1
179749  94.433  -76.532  53.679  1
179750  94.443  -76.527  53.637  1
179751  94.453  -76.522  53.596  1
179752  94.463  -76.517  53.556  1
179753  94.484  -76.512  53.515  1
179754  94.529  -76.506  53.475  1
179755  94.564  -76.505  53.434  1
179756  94.596  -76.507  53.391  1
179757  94.628  -76.508  53.352  1
179758  94.661  -76.510  53.316  1
179759  94.682  -76.507  53.284  1
179760  94.699  -76.502  53.255  1
179761  94.716  -76.497  53.230  1
179762  94.734  -76.492  53.205  1
179763  94.752  -76.489  53.180  1
179764  94.758  -76.489  53.154  1
179765  94.754  -76.491  53.126  1
179766  94.749  -76.494  53.098  1
179767  94.745  -76.496  53.069  1
179768  94.749  -76.499  53.040  1
179769  94.756  -76.500  53.013  1
179770  94.764  -76.502  52.988  1
179771  94.771  -76.504  52.963  1
179772  94.779  -76.505  52.938  1
179773  94.786  -76.507  52.908  1
179774  94.794  -76.508  52.875  1
179775  94.802  -76.510  52.838  1
179776  94.809  -76.511  52.795  1
179777  94.817  -76.514  52.749  1
179778  94.824  -76.515  52.700  1
179779  94.832  -76.517  52.648  1
179780  94.839  -76.518  52.597  1
179781  94.847  -76.520  52.547  1
179782  94.854  -76.521  52.497  1
179783  94.873  -76.525  52.445  1
179784  94.910  -76.533  52.391  1
179785  94.948  -76.541  52.337  1
179786  94.984  -76.549  52.283  1
179787  95.022  -76.556  52.231  1
179788  95.059  -76.564  52.180  1
179789  95.102  -76.574  52.128  1
179790  95.153  -76.586  52.075  1
179791  95.195  -76.596  52.024  1
179792  95.216  -76.608  51.973  1
179793  95.230  -76.623  51.921  1
179794  95.245  -76.636  51.872  1
179795  95.259  -76.651  51.823  1
179796  95.274  -76.665  51.775  1
179797  95.288  -76.680  51.727  1
179798  95.303  -76.693  51.680  1
179799  95.317  -76.708  51.634  1
179800  95.332  -76.722  51.589  1
179801  95.346  -76.737  51.545  1
179802  95.377  -76.748  51.502  1
179803  95.418  -76.758  51.460  1
179804  95.457  -76.768  51.418  1
179805  95.439  -76.770  51.379  1
179806  95.421  -76.773  51.339  1
179807  95.404  -76.777  51.300  1
179808  95.425  -76.794  51.260  1
179809  95.451  -76.812  51.224  1
179810  95.478  -76.829  51.188  1
179811  95.504  -76.846  51.153  1
179812  95.530  -76.864  51.118  1
179813  95.556  -76.882  51.082  1
179814  95.583  -76.900  51.045  1
179815  95.609  -76.917  51.006  1
179816  95.635  -76.934  50.967  1
179817  95.661  -76.941  50.925  1
179818  95.686  -76.948  50.880  1
179819  95.711  -76.955  50.835  1
179820  95.734  -76.962  50.789  1
179821  95.752  -76.971  50.742  1
179822  95.771  -76.979  50.694  1
179823  95.790  -76.987  50.647  1
179824  95.808  -76.996  50.602  1
179825  95.827  -77.005  50.551  1
179826  95.855  -77.012  50.498  1
179827  95.890  -77.020  50.443  1
179828  95.923  -77.017  50.385  1
179829  95.955  -77.012  50.325  1
179830  95.986  -77.006  50.264  1
179831  96.018  -77.001  50.203  1
179832  96.040  -77.007  50.136  1
179833  96.054  -77.022  50.070  1
179834  96.069  -77.037  50.004  1
179835  96.083  -77.052  49.941  1
179836  96.097  -77.067  49.880  1
179837  96.111  -77.082  49.822  1
179838  96.125  -77.097  49.768  1
179839  96.139  -77.112  49.716  1
179840  96.156  -77.118  49.668  1
179841  96.174  -77.116  49.622  1
179842  96.193  -77.113  49.577  1
179843  96.214  -77.100  49.538  1
179844  96.235  -77.087  49.503  1
179845  96.253  -77.080  49.470  1
179846  96.256  -77.101  49.436  1
179847  96.275  -77.106  49.406  1
179848  96.295  -77.112  49.377  1
179849  96.314  -77.116  49.350  1
179850  96.334  -77.122  49.324  1
179851  96.354  -77.127  49.302  1
179852  96.373  -77.132  49.281  1
179853  96.393  -77.137  49.260  1
179854  96.412  -77.141  49.243  1
179855  96.432  -77.147  49.225  1
179856  96.451  -77.151  49.208  1
179857  96.471  -77.157  49.192  1
179858  96.490  -77.162  49.179  1
179859  96.510  -77.166  49.166  1
179860  96.530  -77.172  49.153  1
179861  96.549  -77.176  49.141  1
179862  96.569  -77.181  49.128  1
179863  96.587  -77.190  49.113  1
179864  96.604  -77.201  49.096  1
179865  96.620  -77.215  49.080  1
179866  96.636  -77.229  49.064  1
179867  96.652  -77.241  49.048  1
179868  96.668  -77.255  49.030  1
179869  96.683  -77.269  49.012  1
179870  96.699  -77.282  48.993  1
179871  96.715  -77.295  48.972  1
179872  96.731  -77.309  48.951  1
179873  96.746  -77.322  48.933  1
179874  96.762  -77.335  48.914  1
179875  96.879  -77.351  48.895  1
179876  96.892  -77.370  48.876  1
179877  96.858  -77.388  48.857  1
179878  96.824  -77.405  48.838  1
179879  96.815  -77.417  48.820  1
179880  96.831  -77.422  48.800  1
179881  96.847  -77.427  48.781  1
179882  96.862  -77.432  48.761  1
179883  96.877  -77.437  48.740  1
179884  96.892  -77.442  48.721  1
179885  96.908  -77.448  48.702  1
179886  96.935  -77.448  48.683  1
179887  96.995  -77.441  48.664  1
179888  97.031  -77.455  48.646  1
179889  97.067  -77.471  48.628  1
179890  97.096  -77.496  48.609  1
179891  97.125  -77.520  48.590  1
179892  97.154  -77.545  48.570  1
179893  97.183  -77.570  48.550  1
179894  97.212  -77.595  48.529  1
179895  97.241  -77.620  48.507  1
179896  97.270  -77.645  48.486  1
179897  97.282  -77.637  48.466  1
179898  97.291  -77.626  48.446  1
179899  97.298  -77.611  48.425  1
179900  97.305  -77.596  48.405  1
179901  97.313  -77.581  48.386  1
179902  97.320  -77.566  48.368  1
179903  97.327  -77.551  48.351  1
179904  97.334  -77.536  48.332  1
179905  97.342  -77.520  48.313  1
179906  97.349  -77.505  48.292  1
179907  97.356  -77.490  48.274  1
179908  97.363  -77.475  48.255  1
179909  97.382  -77.480  48.235  1
179910  97.401  -77.492  48.213  1
179911  97.421  -77.505  48.191  1
179912  97.440  -77.517  48.169  1
179913  97.459  -77.530  48.146  1
179914  97.478  -77.542  48.122  1
179915  97.497  -77.555  48.097  1
179916  97.516  -77.567  48.071  1
179917  97.535  -77.580  48.046  1
179918  97.555  -77.592  48.019  1
179919  97.575  -77.602  47.991  1
179920  97.602  -77.600  47.961  1
179921  97.629  -77.598  47.931  1
179922  97.657  -77.596  47.901  1
179923  97.701  -77.602  47.870  1
179924  97.746  -77.608  47.839  1
179925  97.792  -77.615  47.809  1
179926  97.837  -77.621  47.778  1
179927  97.883  -77.628  47.747  1
179928  97.928  -77.634  47.716  1
179929  97.954  -77.633  47.686  1
179930  97.969  -77.630  47.657  1
179931  97.984  -77.625  47.628  1
179932  98.000  -77.621  47.599  1
179933  98.020  -77.614  47.570  1
179934  98.035  -77.602  47.542  1
179935  98.051  -77.592  47.514  1
179936  98.067  -77.580  47.486  1
179937  98.082  -77.570  47.459  1
179938  98.098  -77.559  47.432  1
179939  98.113  -77.548  47.405  1
179940  98.126  -77.536  47.377  1
179941  98.146  -77.533  47.350  1
179942  98.166  -77.534  47.323  1
179943  98.186  -77.536  47.295  1
179944  98.206  -77.536  47.267  1
179945  98.226  -77.536  47.240  1
179946  98.246  -77.536  47.212  1
179947  98.266  -77.536  47.185  1
179948  98.286  -77.535  47.158  1
179949  98.306  -77.535  47.131  1
179950  98.326  -77.534  47.102  1
179951  98.347  -77.534  47.076  1
179952  98.367  -77.533  47.050  1
179953  98.387  -77.533  47.025  1
179954  98.407  -77.533  47.000  1
179955  98.427  -77.532  46.975  1
179956  98.447  -77.532  46.950  1
179957  98.467  -77.531  46.925  1
179958  98.488  -77.531  46.901  1
179959  98.513  -77.545  46.877  1
179960  98.523  -77.567  46.855  1
179961  98.524  -77.568  46.835  1
179962  98.527  -77.569  46.812  1
179963  98.529  -77.569  46.788  1
179964  98.530  -77.572  46.764  1
179965  98.545  -77.576  46.742  1
179966  98.566  -77.581  46.719  1
179967  98.588  -77.586  46.696  1
179968  98.610  -77.592  46.673  1
179969  98.632  -77.597  46.649  1
179970  98.654  -77.602  46.626  1
179971  98.676  -77.608  46.602  1
179972  98.698  -77.614  46.578  1
179973  98.720  -77.619  46.554  1
179974  98.741  -77.624  46.533  1
179975  98.764  -77.620  46.512  1
179976  98.788  -77.608  46.493  1
179977  98.803  -77.607  46.473  1
179978  98.817  -77.607  46.453  1
179979  98.831  -77.607  46.432  1
179980  98.841  -77.611  46.411  1
179981  98.845  -77.617  46.391  1
179982  98.838  -77.619  46.371  1
179983  98.831  -77.620  46.351  1
179984  98.825  -77.622  46.331  1
179985  98.819  -77.625  46.310  1
179986  98.843  -77.645  46.289  1
179987  98.867  -77.664  46.267  1
179988  98.890  -77.684  46.246  1
179989  98.894  -77.691  46.224  1
179990  98.893  -77.695  46.202  1
179991  98.892  -77.699  46.180  1
179992  98.894  -77.702  46.157  1
179993  98.904  -77.705  46.134  1
179994  98.915  -77.708  46.111  1
179995  98.925  -77.711  46.090  1
179996  98.936  -77.714  46.069  1
179997  98.947  -77.718  46.049  1
179998  98.962  -77.723  46.029  1
179999  99.000  -77.735  46.010  1
180000  99.038  -77.748  45.991  1
180001  99.075  -77.761  45.974  1
180002  99.113  -77.773  45.958  1
180003  99.150  -77.786  45.943  1
180004  99.187  -77.796  45.929  1
180005  99.211  -77.796  45.916  1
180006  99.216  -77.780  45.903  1
180007  99.235  -77.791  45.890  1
180008  99.259  -77.815  45.879  1
180009  99.282  -77.838  45.868  1
180010  99.304  -77.861  45.857  1
180011  99.327  -77.884  45.847  1
180012  99.350  -77.906  45.837  1
180013  99.373  -77.930  45.828  1
180014  99.396  -77.953  45.819  1
180015  99.427  -77.973  45.811  1
180016  99.466  -77.993  45.804  1
180017  99.489  -78.003  45.795  1
180018  99.510  -78.011  45.787  1
180019  99.531  -78.019  45.779  1
180020  99.552  -78.028  45.770  1
180021  99.573  -78.037  45.760  1
180022  99.593  -78.045  45.749  1
180023  99.615  -78.053  45.738  1
180024  99.636  -78.062  45.727  1
180025  99.660  -78.056  45.716  1
180026  99.687  -78.042  45.705  1
180027  99.714  -78.028  45.695  1
180028  99.740  -78.015  45.684  1
180029  99.767  -78.001  45.672  1
180030  99.793  -77.987  45.661  1
180031  99.826  -77.989  45.648  1
180032  99.857  -78.019  45.635  1
180033  99.889  -78.049  45.622  1
180034  99.921  -78.079  45.609  1
180035  99.952  -78.109  45.595  1
180036  99.984  -78.139  45.580  1
180037  100.015  -78.169  45.566  1
180038  100.047  -78.198  45.551  1
180039  100.080  -78.206  45.536  1
180040  100.113  -78.215  45.521  1
180041  100.146  -78.224  45.506  1
180042  100.179  -78.232  45.490  1
180043  100.210  -78.216  45.474  1
180044  100.214  -78.232  45.459  1
180045  100.219  -78.249  45.443  1
180046  100.223  -78.266  45.426  1
180047  100.228  -78.282  45.409  1
180048  100.233  -78.298  45.394  1
180049  100.238  -78.315  45.379  1
180050  100.242  -78.331  45.363  1
180051  100.249  -78.348  45.348  1
180052  100.267  -78.357  45.332  1
180053  100.298  -78.358  45.317  1
180054  100.329  -78.359  45.300  1
180055  100.360  -78.360  45.285  1
180056  100.392  -78.361  45.269  1
180057  100.422  -78.362  45.253  1
180058  100.456  -78.363  45.236  1
180059  100.493  -78.366  45.221  1
180060  100.531  -78.370  45.205  1
180061  100.569  -78.373  45.188  1
180062  100.607  -78.376  45.172  1
180063  100.647  -78.383  45.155  1
180064  100.687  -78.389  45.138  1
180065  100.724  -78.396  45.121  1
180066  100.750  -78.401  45.106  1
180067  100.777  -78.407  45.091  1
180068  100.803  -78.413  45.076  1
180069  100.829  -78.418  45.062  1
180070  100.862  -78.425  45.047  1
180071  100.902  -78.431  45.033  1
180072  100.941  -78.438  45.018  1
180073  100.980  -78.445  45.003  1
180074  101.018  -78.451  44.988  1
180075  101.045  -78.458  44.973  1
180076  101.092  -78.438  44.957  1
180077  101.137  -78.418  44.942  1
180078  101.152  -78.426  44.926  1
180079  101.179  -78.442  44.910  1
180080  101.207  -78.459  44.894  1
180081  101.233  -78.476  44.877  1
180082  101.259  -78.493  44.860  1
180083  101.285  -78.510  44.844  1
180084  101.312  -78.527  44.828  1
180085  101.338  -78.545  44.811  1
180086  101.364  -78.561  44.794  1
180087  101.390  -78.579  44.778  1
180088  101.416  -78.598  44.761  1
180089  101.442  -78.620  44.745  1
180090  101.468  -78.643  44.731  1
180091  101.494  -78.666  44.716  1
180092  101.519  -78.689  44.700  1
180093  101.544  -78.714  44.685  1
180094  101.567  -78.745  44.670  1
180095  101.590  -78.779  44.655  1
180096  101.613  -78.811  44.639  1
180097  101.636  -78.844  44.624  1
180098  101.659  -78.877  44.610  1
180099  101.682  -78.910  44.596  1
180100  101.694  -78.915  44.581  1
180101  101.705  -78.918  44.568  1
180102  101.714  -78.915  44.555  1
180103  101.726  -78.909  44.539  1
180104  101.742  -78.915  44.526  1
180105  101.759  -78.921  44.514  1
180106  101.776  -78.926  44.501  1
180107  101.793  -78.932  44.488  1
180108  101.810  -78.937  44.476  1
180109  101.826  -78.943  44.463  1
180110  101.843  -78.949  44.451  1
180111  101.859  -78.954  44.439  1
180112  101.877  -78.960  44.427  1
180113  101.893  -78.965  44.414  1
180114  101.911  -78.971  44.403  1
180365  92.969  -76.867  54.072  1
180366  92.990  -76.858  54.085  1
180367  93.010  -76.849  54.097  1
180368  93.030  -76.840  54.109  1
180369  93.051  -76.831  54.120  1
180370  93.071  -76.823  54.130  1
180371  93.091  -76.814  54.139  1
180372  93.111  -76.809  54.147  1
180373  93.130  -76.806  54.154  1
180374  93.149  -76.803  54.162  1
180375  93.168  -76.799  54.169  1
180376  93.188  -76.796  54.173  1
180377  93.207  -76.793  54.177  1
180378  93.226  -76.790  54.181  1
180379  93.245  -76.787  54.184  1
180380  93.264  -76.784  54.187  1
180381  93.284  -76.781  54.189  1
180382  93.303  -76.777  54.190  1
180383  93.322  -76.774  54.191  1
180384  93.342  -76.771  54.194  1
180385  93.361  -76.768  54.195  1
180386  93.381  -76.765  54.197  1
180387  93.400  -76.762  54.200  1
180388  93.420  -76.759  54.202  1
180389  93.439  -76.756  54.206  1
180390  93.459  -76.753  54.211  1
180391  93.478  -76.750  54.217  1
180392  93.499  -76.747  54.225  1
180393  93.518  -76.749  54.232  1
180394  93.539  -76.743  54.239  1
180395  93.559  -76.736  54.244  1
180396  93.576  -76.731  54.247  1
180397  93.594  -76.726  54.250  1
180398  93.612  -76.721  54.251  1
180399  93.629  -76.717  54.252  1
180400  93.646  -76.712  54.251  1
180401  93.664  -76.708  54.250  1
180402  93.682  -76.703  54.245  1
180403  93.700  -76.696  54.240  1
180404  93.718  -76.689  54.235  1
180405  93.733  -76.681  54.230  1
180406  93.747  -76.675  54.226  1
180407  93.761  -76.668  54.221  1
180408  93.774  -76.661  54.213  1
180409  93.789  -76.655  54.200  1
180410  93.806  -76.650  54.189  1
180411  93.824  -76.646  54.180  1
180412  93.842  -76.640  54.172  1
180413  93.858  -76.640  54.166  1
180414  93.873  -76.641  54.163  1
180415  93.888  -76.643  54.159  1
180416  93.903  -76.643  54.152  1
180417  93.919  -76.645  54.146  1
180418  93.934  -76.646  54.141  1
180419  93.950  -76.646  54.137  1
180420  93.968  -76.644  54.133  1
180421  93.986  -76.643  54.129  1
180422  94.003  -76.641  54.124  1
180423  94.021  -76.640  54.122  1
180424  94.036  -76.640  54.121  1
180425  94.050  -76.640  54.126  1
180426  94.065  -76.641  54.132  1
180427  94.079  -76.642  54.138  1
180428  94.094  -76.643  54.142  1
180429  94.105  -76.642  54.139  1
180430  94.115  -76.640  54.134  1
180431  94.124  -76.640  54.129  1
180432  94.134  -76.638  54.120  1
180433  94.144  -76.637  54.111  1
180434  94.157  -76.633  54.101  1
180435  94.175  -76.627  54.092  1
180436  94.192  -76.621  54.074  1
180437  94.209  -76.614  54.057  1
180438  94.226  -76.608  54.040  1
180439  94.242  -76.602  54.022  1
180440  94.256  -76.596  54.005  1
180441  94.271  -76.590  53.987  1
180442  94.285  -76.584  53.967  1
180443  94.300  -76.579  53.941  1
180444  94.316  -76.572  53.912  1
180445  94.332  -76.564  53.883  1
180446  94.350  -76.555  53.851  1
180447  94.370  -76.545  53.818  1
180448  94.390  -76.534  53.785  1
180449  94.410  -76.524  53.749  1
180450  94.429  -76.513  53.709  1
180451  94.442  -76.507  53.667  1
180452  94.452  -76.502  53.626  1
180453  94.463  -76.497  53.584  1
180454  94.491  -76.492  53.542  1
180455  94.532  -76.487  53.500  1
180456  94.564  -76.489  53.457  1
180457  94.597  -76.490  53.414  1
180458  94.629  -76.492  53.372  1
180459  94.661  -76.493  53.335  1
180460  94.683  -76.490  53.301  1
180461  94.700  -76.486  53.271  1
180462  94.717  -76.480  53.245  1
180463  94.735  -76.477  53.219  1
180464  94.754  -76.473  53.193  1
180465  94.765  -76.472  53.168  1
180466  94.760  -76.475  53.142  1
180467  94.756  -76.478  53.114  1
180468  94.751  -76.480  53.086  1
180469  94.747  -76.483  53.056  1
180470  94.742  -76.486  53.028  1
180471  94.738  -76.489  53.001  1
180472  94.742  -76.490  52.975  1
180473  94.750  -76.492  52.949  1
180474  94.757  -76.494  52.921  1
180475  94.765  -76.495  52.888  1
180476  94.772  -76.497  52.852  1
180477  94.780  -76.499  52.809  1
180478  94.787  -76.500  52.763  1
180479  94.795  -76.502  52.714  1
180480  94.803  -76.504  52.663  1
180481  94.810  -76.505  52.613  1
180482  94.818  -76.507  52.565  1
180483  94.825  -76.508  52.517  1
180484  94.844  -76.512  52.466  1
180485  94.881  -76.520  52.413  1
180486  94.918  -76.528  52.358  1
180487  94.955  -76.536  52.303  1
180488  94.992  -76.543  52.249  1
180489  95.038  -76.554  52.198  1
180490  95.089  -76.567  52.147  1
180491  95.139  -76.580  52.094  1
180492  95.179  -76.588  52.041  1
180493  95.210  -76.598  51.989  1
180494  95.225  -76.612  51.937  1
180495  95.239  -76.627  51.887  1
180496  95.254  -76.641  51.838  1
180497  95.268  -76.655  51.790  1
180498  95.283  -76.669  51.742  1
180499  95.298  -76.683  51.695  1
180500  95.312  -76.698  51.649  1
180501  95.326  -76.712  51.604  1
180502  95.341  -76.726  51.559  1
180503  95.380  -76.737  51.516  1
180504  95.422  -76.746  51.473  1
180505  95.464  -76.756  51.431  1
180506  95.462  -76.761  51.391  1
180507  95.445  -76.764  51.352  1
180508  95.427  -76.767  51.313  1
180509  95.435  -76.785  51.276  1
180510  95.442  -76.803  51.241  1
180511  95.468  -76.821  51.206  1
180512  95.494  -76.839  51.172  1
180513  95.520  -76.856  51.137  1
180514  95.547  -76.874  51.102  1
180515  95.573  -76.891  51.065  1
180516  95.599  -76.909  51.028  1
180517  95.626  -76.926  50.989  1
180518  95.651  -76.937  50.947  1
180519  95.676  -76.943  50.903  1
180520  95.701  -76.950  50.857  1
180521  95.727  -76.956  50.810  1
180522  95.752  -76.963  50.762  1
180523  95.775  -76.970  50.714  1
180524  95.794  -76.979  50.666  1
180525  95.812  -76.987  50.619  1
180526  95.831  -76.996  50.568  1
180527  95.862  -77.003  50.513  1
180528  95.895  -77.002  50.457  1
180529  95.927  -76.997  50.399  1
180530  95.959  -76.992  50.338  1
180531  95.990  -76.987  50.277  1
180532  96.023  -76.981  50.216  1
180533  96.043  -76.989  50.150  1
180534  96.057  -77.003  50.084  1
180535  96.072  -77.019  50.019  1
180536  96.086  -77.034  49.956  1
180537  96.100  -77.049  49.895  1
180538  96.114  -77.063  49.838  1
180539  96.128  -77.078  49.784  1
180540  96.142  -77.094  49.733  1
180541  96.156  -77.109  49.684  1
180542  96.171  -77.122  49.639  1
180543  96.189  -77.119  49.595  1
180544  96.210  -77.106  49.556  1
180545  96.232  -77.093  49.520  1
180546  96.253  -77.079  49.487  1
180547  96.271  -77.078  49.455  1
180548  96.291  -77.084  49.425  1
180549  96.310  -77.088  49.397  1
180550  96.328  -77.095  49.370  1
180551  96.345  -77.102  49.344  1
180552  96.362  -77.109  49.322  1
180553  96.379  -77.116  49.302  1
180554  96.396  -77.122  49.282  1
180555  96.413  -77.129  49.265  1
180556  96.430  -77.136  49.248  1
180557  96.447  -77.143  49.231  1
180558  96.464  -77.150  49.214  1
180559  96.481  -77.157  49.201  1
180560  96.498  -77.163  49.188  1
180561  96.515  -77.170  49.175  1
180562  96.539  -77.172  49.163  1
180563  96.570  -77.172  49.151  1
180564  96.594  -77.175  49.136  1
180565  96.609  -77.188  49.118  1
180566  96.625  -77.201  49.102  1
180567  96.641  -77.214  49.085  1
180568  96.656  -77.228  49.069  1
180569  96.672  -77.241  49.051  1
180570  96.687  -77.255  49.032  1
180571  96.702  -77.268  49.012  1
180572  96.718  -77.282  48.992  1
180573  96.734  -77.295  48.971  1
180574  96.749  -77.309  48.951  1
180575  96.778  -77.322  48.932  1
180576  96.912  -77.333  48.912  1
180577  96.927  -77.338  48.892  1
180578  96.914  -77.353  48.873  1
180579  96.880  -77.371  48.853  1
180580  96.846  -77.389  48.832  1
180581  96.834  -77.401  48.812  1
180582  96.850  -77.406  48.792  1
180583  96.865  -77.411  48.771  1
180584  96.881  -77.417  48.750  1
180585  96.896  -77.421  48.730  1
180586  96.911  -77.426  48.710  1
180587  96.930  -77.430  48.691  1
180588  96.999  -77.416  48.671  1
180589  97.035  -77.430  48.652  1
180590  97.071  -77.447  48.634  1
180591  97.100  -77.471  48.615  1
180592  97.129  -77.496  48.596  1
180593  97.158  -77.521  48.578  1
180594  97.187  -77.545  48.558  1
180595  97.216  -77.570  48.536  1
180596  97.245  -77.595  48.515  1
180597  97.274  -77.620  48.494  1
180598  97.300  -77.640  48.473  1
180599  97.309  -77.629  48.453  1
180600  97.317  -77.614  48.433  1
180601  97.324  -77.599  48.413  1
180602  97.331  -77.583  48.393  1
180603  97.338  -77.568  48.375  1
180604  97.346  -77.553  48.358  1
180605  97.352  -77.536  48.340  1
180606  97.357  -77.518  48.322  1
180607  97.362  -77.500  48.302  1
180608  97.367  -77.482  48.283  1
180609  97.373  -77.467  48.264  1
180610  97.386  -77.483  48.245  1
180611  97.405  -77.495  48.223  1
180612  97.425  -77.507  48.202  1
180613  97.443  -77.519  48.179  1
180614  97.462  -77.532  48.155  1
180615  97.481  -77.544  48.129  1
180616  97.501  -77.556  48.104  1
180617  97.520  -77.569  48.078  1
180618  97.539  -77.581  48.052  1
180619  97.558  -77.593  48.025  1
180620  97.584  -77.595  47.997  1
180621  97.611  -77.592  47.966  1
180622  97.638  -77.591  47.936  1
180623  97.668  -77.590  47.905  1
180624  97.714  -77.597  47.873  1
180625  97.759  -77.603  47.842  1
180626  97.805  -77.610  47.811  1
180627  97.850  -77.616  47.780  1
180628  97.896  -77.623  47.749  1
180629  97.941  -77.629  47.718  1
180630  97.983  -77.634  47.687  1
180631  97.998  -77.630  47.657  1
180632  98.014  -77.625  47.627  1
180633  98.035  -77.618  47.600  1
180634  98.056  -77.611  47.572  1
180635  98.073  -77.602  47.545  1
180636  98.087  -77.590  47.517  1
180637  98.096  -77.577  47.489  1
180638  98.105  -77.564  47.462  1
180639  98.113  -77.551  47.435  1
180640  98.123  -77.537  47.409  1
180641  98.132  -77.522  47.381  1
180642  98.152  -77.514  47.353  1
180643  98.189  -77.522  47.325  1
180644  98.209  -77.523  47.297  1
180645  98.229  -77.524  47.271  1
180646  98.249  -77.526  47.244  1
180647  98.270  -77.527  47.218  1
180648  98.290  -77.529  47.192  1
180649  98.310  -77.530  47.165  1
180650  98.330  -77.531  47.138  1
180651  98.350  -77.533  47.111  1
180652  98.370  -77.534  47.083  1
180653  98.390  -77.536  47.057  1
180654  98.411  -77.537  47.032  1
180655  98.431  -77.539  47.009  1
180656  98.451  -77.540  46.983  1
180657  98.471  -77.541  46.959  1
180658  98.491  -77.542  46.934  1
180659  98.511  -77.544  46.910  1
180660  98.531  -77.545  46.887  1
180661  98.547  -77.550  46.865  1
180662  98.547  -77.558  46.844  1
180663  98.546  -77.564  46.821  1
180664  98.546  -77.571  46.798  1
180665  98.548  -77.578  46.775  1
180666  98.567  -77.581  46.752  1
180667  98.586  -77.584  46.728  1
180668  98.605  -77.587  46.705  1
180669  98.624  -77.590  46.682  1
180670  98.643  -77.594  46.659  1
180671  98.663  -77.597  46.634  1
180672  98.685  -77.602  46.610  1
180673  98.707  -77.608  46.586  1
180674  98.729  -77.613  46.562  1
180675  98.750  -77.618  46.540  1
180676  98.775  -77.605  46.519  1
180677  98.797  -77.594  46.500  1
180678  98.811  -77.594  46.480  1
180679  98.826  -77.594  46.460  1
180680  98.840  -77.595  46.438  1
180681  98.852  -77.598  46.417  1
180682  98.848  -77.601  46.396  1
180683  98.841  -77.602  46.376  1
180684  98.834  -77.604  46.357  1
180685  98.827  -77.605  46.337  1
180686  98.831  -77.611  46.316  1
180687  98.844  -77.629  46.295  1
180688  98.868  -77.649  46.273  1
180689  98.892  -77.668  46.252  1
180690  98.907  -77.683  46.231  1
180691  98.907  -77.686  46.209  1
180692  98.906  -77.690  46.187  1
180693  98.913  -77.693  46.164  1
180694  98.923  -77.696  46.141  1
180695  98.934  -77.699  46.119  1
180696  98.944  -77.703  46.097  1
180697  98.955  -77.706  46.077  1
180698  98.966  -77.709  46.057  1
180699  98.977  -77.712  46.037  1
180700  98.998  -77.719  46.017  1
180701  99.036  -77.732  45.997  1
180702  99.074  -77.744  45.979  1
180703  99.111  -77.757  45.963  1
180704  99.149  -77.769  45.947  1
180705  99.185  -77.787  45.932  1
180706  99.197  -77.787  45.918  1
180707  99.211  -77.766  45.905  1
180708  99.228  -77.780  45.892  1
180709  99.251  -77.803  45.880  1
180710  99.274  -77.827  45.869  1
180711  99.297  -77.849  45.858  1
180712  99.320  -77.872  45.849  1
180713  99.343  -77.895  45.839  1
180714  99.365  -77.918  45.830  1
180715  99.401  -77.938  45.821  1
180716  99.439  -77.958  45.813  1
180717  99.478  -77.978  45.805  1
180718  99.511  -77.994  45.797  1
180719  99.532  -78.003  45.788  1
180720  99.553  -78.011  45.779  1
180721  99.574  -78.019  45.770  1
180722  99.595  -78.028  45.760  1
180723  99.616  -78.036  45.750  1
180724  99.637  -78.044  45.739  1
180725  99.659  -78.048  45.728  1
180726  99.686  -78.034  45.717  1
180727  99.713  -78.021  45.706  1
180728  99.739  -78.007  45.696  1
180729  99.766  -77.993  45.686  1
180730  99.793  -77.980  45.674  1
180731  99.813  -77.983  45.663  1
180732  99.831  -77.993  45.651  1
180733  99.861  -78.020  45.638  1
180734  99.892  -78.050  45.626  1
180735  99.924  -78.080  45.613  1
180736  99.956  -78.110  45.599  1
180737  99.987  -78.140  45.585  1
180738  100.019  -78.170  45.570  1
180739  100.051  -78.184  45.556  1
180740  100.084  -78.193  45.541  1
180741  100.117  -78.201  45.525  1
180742  100.150  -78.210  45.509  1
180743  100.183  -78.219  45.493  1
180744  100.223  -78.194  45.477  1
180745  100.228  -78.211  45.461  1
180746  100.233  -78.227  45.445  1
180747  100.238  -78.244  45.430  1
180748  100.242  -78.260  45.415  1
180749  100.247  -78.276  45.399  1
180750  100.252  -78.293  45.383  1
180751  100.257  -78.310  45.367  1
180752  100.264  -78.326  45.353  1
180753  100.272  -78.342  45.337  1
180754  100.299  -78.346  45.321  1
180755  100.330  -78.347  45.306  1
180756  100.361  -78.348  45.289  1
180757  100.393  -78.349  45.273  1
180758  100.423  -78.350  45.256  1
180759  100.458  -78.352  45.240  1
180760  100.496  -78.355  45.224  1
180761  100.534  -78.358  45.208  1
180762  100.571  -78.362  45.191  1
180763  100.609  -78.365  45.175  1
180764  100.648  -78.369  45.158  1
180765  100.688  -78.376  45.142  1
180766  100.716  -78.382  45.126  1
180767  100.742  -78.388  45.110  1
180768  100.771  -78.394  45.096  1
180769  100.811  -78.400  45.081  1
180770  100.850  -78.407  45.067  1
180771  100.889  -78.413  45.053  1
180772  100.928  -78.420  45.038  1
180773  100.968  -78.427  45.023  1
180774  101.007  -78.433  45.008  1
180775  101.038  -78.440  44.993  1
180776  101.065  -78.447  44.978  1
180777  101.112  -78.426  44.962  1
180778  101.146  -78.417  44.947  1
180779  101.162  -78.425  44.930  1
180780  101.177  -78.433  44.914  1
180781  101.204  -78.449  44.898  1
180782  101.234  -78.466  44.881  1
180783  101.262  -78.483  44.864  1
180784  101.288  -78.501  44.848  1
180785  101.314  -78.517  44.831  1
180786  101.340  -78.535  44.814  1
180787  101.367  -78.552  44.797  1
180788  101.393  -78.569  44.781  1
180789  101.419  -78.587  44.764  1
180790  101.445  -78.610  44.749  1
180791  101.471  -78.633  44.733  1
180792  101.496  -78.655  44.718  1
180793  101.521  -78.680  44.703  1
180794  101.544  -78.707  44.688  1
180795  101.567  -78.739  44.673  1
180796  101.590  -78.772  44.658  1
180797  101.613  -78.805  44.642  1
180798  101.636  -78.837  44.627  1
180799  101.659  -78.870  44.612  1
180800  101.676  -78.887  44.598  1
180801  101.687  -78.890  44.584  1
180802  101.697  -78.893  44.570  1
180803  101.708  -78.896  44.557  1
180804  101.729  -78.912  44.541  1
180805  101.747  -78.918  44.528  1
180806  101.766  -78.924  44.516  1
180807  101.784  -78.930  44.502  1
180808  101.802  -78.937  44.490  1
180809  101.821  -78.943  44.478  1
180810  101.839  -78.949  44.465  1
180811  101.857  -78.955  44.452  1
180812  101.875  -78.962  44.440  1
180813  101.894  -78.968  44.428  1
180814  101.912  -78.974  44.416  1
180815  101.930  -78.980  44.404  1
181067  92.979  -76.834  54.065  1
181068  92.999  -76.825  54.078  1
181069  93.020  -76.817  54.091  1
181070  93.040  -76.808  54.103  1
181071  93.060  -76.799  54.114  1
181072  93.081  -76.790  54.124  1
181073  93.100  -76.786  54.134  1
181074  93.119  -76.783  54.141  1
181075  93.139  -76.779  54.149  1
181076  93.158  -76.776  54.155  1
181077  93.177  -76.773  54.162  1
181078  93.196  -76.770  54.167  1
181079  93.215  -76.766  54.171  1
181080  93.234  -76.763  54.174  1
181081  93.254  -76.760  54.178  1
181082  93.273  -76.756  54.180  1
181083  93.292  -76.753  54.182  1
181084  93.312  -76.750  54.183  1
181085  93.332  -76.747  54.185  1
181086  93.351  -76.744  54.187  1
181087  93.370  -76.741  54.188  1
181088  93.390  -76.738  54.191  1
181089  93.409  -76.735  54.193  1
181090  93.429  -76.732  54.195  1
181091  93.448  -76.730  54.198  1
181092  93.468  -76.727  54.203  1
181093  93.492  -76.723  54.210  1
181094  93.510  -76.725  54.216  1
181095  93.529  -76.728  54.223  1
181096  93.549  -76.724  54.229  1
181097  93.570  -76.715  54.233  1
181098  93.591  -76.705  54.236  1
181099  93.609  -76.700  54.236  1
181100  93.627  -76.696  54.237  1
181101  93.644  -76.690  54.238  1
181102  93.661  -76.686  54.237  1
181103  93.679  -76.681  54.233  1
181104  93.697  -76.677  54.230  1
181105  93.715  -76.669  54.226  1
181106  93.731  -76.661  54.223  1
181107  93.745  -76.655  54.219  1
181108  93.759  -76.649  54.215  1
181109  93.773  -76.642  54.209  1
181110  93.786  -76.635  54.201  1
181111  93.800  -76.628  54.193  1
181112  93.818  -76.624  54.187  1
181113  93.836  -76.619  54.183  1
181114  93.852  -76.618  54.178  1
181115  93.867  -76.620  54.175  1
181116  93.882  -76.621  54.170  1
181117  93.897  -76.622  54.163  1
181118  93.912  -76.623  54.155  1
181119  93.927  -76.624  54.149  1
181120  93.943  -76.625  54.144  1
181121  93.960  -76.624  54.140  1
181122  93.977  -76.623  54.138  1
181123  93.995  -76.621  54.134  1
181124  94.011  -76.621  54.131  1
181125  94.026  -76.621  54.129  1
181126  94.040  -76.622  54.131  1
181127  94.055  -76.623  54.135  1
181128  94.069  -76.624  54.141  1
181129  94.084  -76.624  54.147  1
181130  94.098  -76.625  54.147  1
181131  94.109  -76.624  54.145  1
181132  94.119  -76.623  54.142  1
181133  94.128  -76.621  54.135  1
181134  94.138  -76.621  54.128  1
181135  94.152  -76.617  54.119  1
181136  94.169  -76.611  54.110  1
181137  94.186  -76.604  54.094  1
181138  94.203  -76.598  54.078  1
181139  94.219  -76.592  54.061  1
181140  94.233  -76.586  54.045  1
181141  94.248  -76.580  54.028  1
181142  94.262  -76.574  54.010  1
181143  94.277  -76.569  53.992  1
181144  94.291  -76.563  53.967  1
181145  94.307  -76.557  53.940  1
181146  94.325  -76.549  53.910  1
181147  94.344  -76.538  53.879  1
181148  94.364  -76.527  53.846  1
181149  94.384  -76.517  53.813  1
181150  94.404  -76.506  53.777  1
181151  94.424  -76.495  53.738  1
181152  94.441  -76.486  53.696  1
181153  94.452  -76.482  53.653  1
181154  94.462  -76.477  53.611  1
181155  94.497  -76.471  53.568  1
181156  94.533  -76.470  53.525  1
181157  94.565  -76.472  53.482  1
181158  94.597  -76.473  53.437  1
181159  94.629  -76.475  53.393  1
181160  94.662  -76.477  53.354  1
181161  94.684  -76.474  53.318  1
181162  94.701  -76.469  53.286  1
181163  94.718  -76.464  53.259  1
181164  94.737  -76.461  53.232  1
181165  94.756  -76.458  53.206  1
181166  94.771  -76.456  53.181  1
181167  94.767  -76.459  53.156  1
181168  94.762  -76.461  53.129  1
181169  94.758  -76.464  53.102  1
181170  94.753  -76.467  53.072  1
181171  94.749  -76.470  53.042  1
181172  94.744  -76.473  53.013  1
181173  94.739  -76.475  52.985  1
181174  94.735  -76.478  52.959  1
181175  94.730  -76.480  52.931  1
181176  94.736  -76.483  52.899  1
181177  94.743  -76.484  52.864  1
181178  94.751  -76.486  52.822  1
181179  94.758  -76.487  52.777  1
181180  94.766  -76.489  52.728  1
181181  94.773  -76.491  52.677  1
181182  94.781  -76.492  52.627  1
181183  94.788  -76.494  52.578  1
181184  94.796  -76.495  52.530  1
181185  94.815  -76.499  52.480  1
181186  94.852  -76.507  52.428  1
181187  94.889  -76.514  52.377  1
181188  94.926  -76.523  52.325  1
181189  94.973  -76.534  52.270  1
181190  95.024  -76.547  52.216  1
181191  95.075  -76.560  52.164  1
181192  95.124  -76.572  52.110  1
181193  95.164  -76.580  52.057  1
181194  95.203  -76.588  52.004  1
181195  95.219  -76.602  51.952  1
181196  95.234  -76.616  51.901  1
181197  95.248  -76.630  51.853  1
181198  95.263  -76.645  51.805  1
181199  95.277  -76.659  51.758  1
181200  95.292  -76.673  51.710  1
181201  95.306  -76.687  51.663  1
181202  95.321  -76.702  51.618  1
181203  95.342  -76.715  51.573  1
181204  95.384  -76.724  51.529  1
181205  95.425  -76.734  51.487  1
181206  95.467  -76.744  51.446  1
181207  95.486  -76.752  51.406  1
181208  95.468  -76.754  51.367  1
181209  95.451  -76.758  51.329  1
181210  95.458  -76.776  51.292  1
181211  95.465  -76.794  51.258  1
181212  95.472  -76.812  51.224  1
181213  95.484  -76.831  51.190  1
181214  95.511  -76.848  51.156  1
181215  95.537  -76.865  51.122  1
181216  95.563  -76.883  51.086  1
181217  95.590  -76.900  51.049  1
181218  95.616  -76.918  51.010  1
181219  95.641  -76.932  50.968  1
181220  95.667  -76.938  50.924  1
181221  95.692  -76.945  50.877  1
181222  95.717  -76.952  50.830  1
181223  95.742  -76.959  50.782  1
181224  95.767  -76.965  50.734  1
181225  95.793  -76.972  50.685  1
181226  95.817  -76.978  50.637  1
181227  95.835  -76.987  50.585  1
181228  95.868  -76.987  50.531  1
181229  95.899  -76.982  50.474  1
181230  95.931  -76.977  50.415  1
181231  95.963  -76.972  50.355  1
181232  95.995  -76.967  50.294  1
181233  96.027  -76.962  50.233  1
181234  96.046  -76.970  50.169  1
181235  96.060  -76.985  50.103  1
181236  96.075  -77.000  50.037  1
181237  96.089  -77.015  49.972  1
181238  96.103  -77.030  49.911  1
181239  96.117  -77.045  49.854  1
181240  96.131  -77.060  49.801  1
181241  96.145  -77.075  49.751  1
181242  96.159  -77.091  49.702  1
181243  96.172  -77.106  49.656  1
181244  96.187  -77.119  49.613  1
181245  96.190  -77.122  49.573  1
181246  96.203  -77.113  49.537  1
181247  96.217  -77.104  49.504  1
181248  96.230  -77.096  49.473  1
181249  96.247  -77.103  49.445  1
181250  96.264  -77.110  49.418  1
181251  96.281  -77.116  49.391  1
181252  96.298  -77.122  49.366  1
181253  96.315  -77.129  49.344  1
181254  96.332  -77.136  49.324  1
181255  96.349  -77.143  49.305  1
181256  96.366  -77.150  49.288  1
181257  96.383  -77.157  49.271  1
181258  96.400  -77.163  49.254  1
181259  96.417  -77.170  49.238  1
181260  96.447  -77.170  49.225  1
181261  96.477  -77.169  49.212  1
181262  96.508  -77.169  49.200  1
181263  96.538  -77.168  49.187  1
181264  96.569  -77.168  49.173  1
181265  96.590  -77.172  49.157  1
181266  96.611  -77.176  49.139  1
181267  96.628  -77.188  49.123  1
181268  96.643  -77.201  49.105  1
181269  96.659  -77.214  49.087  1
181270  96.674  -77.228  49.070  1
181271  96.690  -77.241  49.051  1
181272  96.705  -77.254  49.031  1
181273  96.721  -77.268  49.010  1
181274  96.736  -77.282  48.989  1
181275  96.752  -77.295  48.970  1
181276  96.854  -77.309  48.950  1
181277  96.895  -77.314  48.930  1
181278  96.909  -77.319  48.909  1
181279  96.924  -77.325  48.890  1
181280  96.937  -77.336  48.869  1
181281  96.902  -77.354  48.847  1
181282  96.868  -77.373  48.825  1
181283  96.853  -77.385  48.804  1
181284  96.869  -77.391  48.783  1
181285  96.884  -77.395  48.762  1
181286  96.899  -77.401  48.741  1
181287  96.914  -77.406  48.720  1
181288  96.930  -77.410  48.700  1
181289  97.002  -77.392  48.680  1
181290  97.040  -77.405  48.660  1
181291  97.075  -77.422  48.640  1
181292  97.103  -77.447  48.622  1
181293  97.133  -77.472  48.603  1
181294  97.162  -77.496  48.584  1
181295  97.190  -77.521  48.564  1
181296  97.220  -77.546  48.544  1
181297  97.248  -77.570  48.523  1
181298  97.278  -77.595  48.502  1
181299  97.307  -77.620  48.481  1
181300  97.326  -77.629  48.462  1
181301  97.331  -77.611  48.442  1
181302  97.336  -77.592  48.422  1
181303  97.342  -77.575  48.402  1
181304  97.347  -77.557  48.383  1
181305  97.352  -77.539  48.365  1
181306  97.358  -77.521  48.348  1
181307  97.363  -77.503  48.331  1
181308  97.368  -77.485  48.312  1
181309  97.373  -77.467  48.293  1
181310  97.382  -77.465  48.274  1
181311  97.395  -77.483  48.254  1
181312  97.409  -77.496  48.233  1
181313  97.428  -77.508  48.211  1
181314  97.447  -77.521  48.188  1
181315  97.466  -77.533  48.164  1
181316  97.485  -77.545  48.138  1
181317  97.504  -77.558  48.112  1
181318  97.523  -77.570  48.085  1
181319  97.542  -77.583  48.057  1
181320  97.565  -77.589  48.030  1
181321  97.592  -77.587  48.001  1
181322  97.619  -77.586  47.970  1
181323  97.647  -77.583  47.940  1
181324  97.681  -77.585  47.909  1
181325  97.727  -77.592  47.877  1
181326  97.773  -77.598  47.844  1
181327  97.818  -77.605  47.814  1
181328  97.864  -77.611  47.782  1
181329  97.909  -77.617  47.750  1
181330  97.955  -77.624  47.720  1
181331  98.000  -77.630  47.689  1
181332  98.028  -77.630  47.659  1
181333  98.047  -77.624  47.630  1
181334  98.061  -77.620  47.602  1
181335  98.075  -77.605  47.575  1
181336  98.084  -77.592  47.547  1
181337  98.093  -77.579  47.519  1
181338  98.102  -77.566  47.491  1
181339  98.111  -77.552  47.464  1
181340  98.120  -77.539  47.437  1
181341  98.130  -77.523  47.411  1
181342  98.139  -77.508  47.383  1
181343  98.148  -77.493  47.355  1
181344  98.192  -77.501  47.328  1
181345  98.233  -77.511  47.300  1
181346  98.253  -77.512  47.273  1
181347  98.273  -77.513  47.247  1
181348  98.293  -77.514  47.221  1
181349  98.313  -77.516  47.197  1
181350  98.334  -77.517  47.171  1
181351  98.354  -77.519  47.145  1
181352  98.374  -77.520  47.118  1
181353  98.394  -77.521  47.091  1
181354  98.414  -77.523  47.065  1
181355  98.434  -77.524  47.040  1
181356  98.454  -77.526  47.016  1
181357  98.475  -77.527  46.991  1
181358  98.495  -77.529  46.967  1
181359  98.515  -77.530  46.943  1
181360  98.535  -77.531  46.919  1
181361  98.549  -77.526  46.896  1
181362  98.555  -77.545  46.874  1
181363  98.562  -77.564  46.852  1
181364  98.561  -77.571  46.830  1
181365  98.560  -77.578  46.807  1
181366  98.570  -77.583  46.784  1
181367  98.589  -77.586  46.761  1
181368  98.608  -77.589  46.737  1
181369  98.627  -77.592  46.714  1
181370  98.646  -77.595  46.691  1
181371  98.665  -77.599  46.668  1
181372  98.685  -77.602  46.642  1
181373  98.704  -77.605  46.618  1
181374  98.723  -77.608  46.594  1
181375  98.744  -77.605  46.570  1
181376  98.762  -77.602  46.548  1
181377  98.786  -77.589  46.527  1
181378  98.806  -77.581  46.506  1
181379  98.820  -77.582  46.485  1
181380  98.836  -77.583  46.464  1
181381  98.851  -77.584  46.442  1
181382  98.862  -77.588  46.422  1
181383  98.870  -77.595  46.402  1
181384  98.870  -77.599  46.382  1
181385  98.863  -77.600  46.362  1
181386  98.856  -77.602  46.343  1
181387  98.868  -77.610  46.323  1
181388  98.885  -77.619  46.301  1
181389  98.871  -77.633  46.278  1
181390  98.893  -77.652  46.257  1
181391  98.917  -77.671  46.237  1
181392  98.920  -77.678  46.216  1
181393  98.921  -77.682  46.195  1
181394  98.932  -77.685  46.173  1
181395  98.942  -77.688  46.150  1
181396  98.953  -77.691  46.127  1
181397  98.964  -77.694  46.106  1
181398  98.975  -77.697  46.085  1
181399  98.985  -77.700  46.064  1
181400  98.996  -77.703  46.043  1
181401  99.006  -77.706  46.022  1
181402  99.034  -77.716  46.002  1
181403  99.072  -77.728  45.983  1
181404  99.109  -77.743  45.966  1
181405  99.142  -77.772  45.950  1
181406  99.167  -77.790  45.934  1
181407  99.187  -77.768  45.920  1
181408  99.199  -77.748  45.907  1
181409  99.221  -77.769  45.893  1
181410  99.243  -77.793  45.881  1
181411  99.267  -77.815  45.870  1
181412  99.289  -77.838  45.860  1
181413  99.312  -77.861  45.850  1
181414  99.336  -77.884  45.841  1
181415  99.374  -77.903  45.831  1
181416  99.413  -77.923  45.823  1
181417  99.451  -77.943  45.814  1
181418  99.490  -77.962  45.806  1
181419  99.528  -77.981  45.798  1
181420  99.555  -77.993  45.789  1
181421  99.576  -78.002  45.780  1
181422  99.596  -78.010  45.770  1
181423  99.618  -78.018  45.760  1
181424  99.639  -78.028  45.750  1
181425  99.659  -78.036  45.740  1
181426  99.685  -78.027  45.729  1
181427  99.712  -78.013  45.718  1
181428  99.738  -78.000  45.707  1
181429  99.765  -77.986  45.697  1
181430  99.790  -77.977  45.687  1
181431  99.807  -77.987  45.676  1
181432  99.825  -77.996  45.665  1
181433  99.843  -78.006  45.654  1
181434  99.864  -78.022  45.641  1
181435  99.896  -78.051  45.629  1
181436  99.927  -78.081  45.617  1
181437  99.959  -78.111  45.603  1
181438  99.990  -78.141  45.589  1
181439  100.022  -78.163  45.574  1
181440  100.055  -78.171  45.559  1
181441  100.088  -78.179  45.542  1
181442  100.121  -78.188  45.527  1
181443  100.154  -78.197  45.511  1
181444  100.187  -78.205  45.495  1
181445  100.238  -78.172  45.479  1
181446  100.242  -78.189  45.463  1
181447  100.247  -78.206  45.448  1
181448  100.252  -78.222  45.433  1
181449  100.256  -78.238  45.418  1
181450  100.261  -78.255  45.403  1
181451  100.266  -78.271  45.388  1
181452  100.272  -78.288  45.373  1
181453  100.279  -78.305  45.357  1
181454  100.285  -78.322  45.342  1
181455  100.302  -78.333  45.326  1
181456  100.331  -78.335  45.310  1
181457  100.362  -78.336  45.293  1
181458  100.394  -78.337  45.276  1
181459  100.425  -78.338  45.260  1
181460  100.460  -78.341  45.244  1
181461  100.498  -78.344  45.228  1
181462  100.536  -78.347  45.211  1
181463  100.573  -78.350  45.194  1
181464  100.612  -78.354  45.177  1
181465  100.649  -78.357  45.162  1
181466  100.682  -78.363  45.146  1
181467  100.719  -78.369  45.131  1
181468  100.759  -78.376  45.115  1
181469  100.798  -78.382  45.101  1
181470  100.837  -78.389  45.087  1
181471  100.876  -78.395  45.072  1
181472  100.916  -78.402  45.058  1
181473  100.956  -78.409  45.042  1
181474  100.995  -78.416  45.027  1
181475  101.030  -78.423  45.013  1
181476  101.057  -78.429  44.997  1
181477  101.085  -78.436  44.981  1
181478  101.132  -78.414  44.965  1
181479  101.155  -78.416  44.950  1
181480  101.170  -78.424  44.934  1
181481  101.186  -78.432  44.918  1
181482  101.201  -78.440  44.901  1
181483  101.229  -78.457  44.884  1
181484  101.259  -78.473  44.867  1
181485  101.288  -78.491  44.851  1
181486  101.317  -78.508  44.834  1
181487  101.343  -78.525  44.817  1
181488  101.370  -78.542  44.801  1
181489  101.396  -78.559  44.784  1
181490  101.422  -78.576  44.769  1
181491  101.448  -78.598  44.752  1
181492  101.474  -78.621  44.736  1
181493  101.498  -78.645  44.721  1
181494  101.522  -78.673  44.706  1
181495  101.544  -78.700  44.691  1
181496  101.567  -78.732  44.676  1
181497  101.591  -78.765  44.660  1
181498  101.613  -78.798  44.645  1
181499  101.636  -78.830  44.630  1
181500  101.658  -78.859  44.615  1
181501  101.669  -78.862  44.600  1
181502  101.680  -78.865  44.586  1
181503  101.690  -78.868  44.572  1
181504  101.714  -78.882  44.559  1
181505  101.753  -78.908  44.543  1
181506  101.766  -78.926  44.531  1
181507  101.784  -78.932  44.518  1
181508  101.802  -78.938  44.504  1
181509  101.821  -78.945  44.492  1
181510  101.839  -78.951  44.479  1
181511  101.857  -78.957  44.466  1
181512  101.876  -78.963  44.453  1
181513  101.894  -78.969  44.441  1
181514  101.912  -78.976  44.429  1
181515  101.930  -78.982  44.418  1
181516  101.949  -78.988  44.406  1
181769  92.989  -76.802  54.059  1
181770  93.009  -76.793  54.073  1
181771  93.029  -76.784  54.086  1
181772  93.050  -76.775  54.097  1
181773  93.070  -76.767  54.108  1
181774  93.090  -76.762  54.120  1
181775  93.109  -76.759  54.128  1
181776  93.128  -76.755  54.136  1
181777  93.147  -76.752  54.144  1
181778  93.166  -76.749  54.151  1
181779  93.186  -76.746  54.156  1
181780  93.205  -76.743  54.161  1
181781  93.224  -76.740  54.165  1
181782  93.243  -76.736  54.169  1
181783  93.263  -76.733  54.172  1
181784  93.282  -76.730  54.174  1
181785  93.301  -76.727  54.176  1
181786  93.321  -76.724  54.178  1
181787  93.341  -76.721  54.179  1
181788  93.360  -76.718  54.181  1
181789  93.379  -76.715  54.183  1
181790  93.399  -76.712  54.185  1
181791  93.418  -76.708  54.186  1
181792  93.438  -76.705  54.188  1
181793  93.458  -76.702  54.192  1
181794  93.484  -76.699  54.196  1
181795  93.502  -76.702  54.201  1
181796  93.521  -76.705  54.206  1
181797  93.539  -76.708  54.212  1
181798  93.559  -76.705  54.216  1
181799  93.580  -76.696  54.218  1
181800  93.601  -76.686  54.218  1
181801  93.622  -76.676  54.220  1
181802  93.641  -76.669  54.221  1
181803  93.659  -76.665  54.222  1
181804  93.677  -76.660  54.221  1
181805  93.694  -76.655  54.219  1
181806  93.712  -76.650  54.217  1
181807  93.729  -76.642  54.214  1
181808  93.744  -76.636  54.210  1
181809  93.757  -76.629  54.208  1
181810  93.771  -76.622  54.205  1
181811  93.785  -76.615  54.202  1
181812  93.798  -76.608  54.198  1
181813  93.812  -76.602  54.196  1
181814  93.830  -76.597  54.195  1
181815  93.845  -76.597  54.192  1
181816  93.860  -76.598  54.189  1
181817  93.876  -76.599  54.184  1
181818  93.891  -76.600  54.176  1
181819  93.906  -76.601  54.167  1
181820  93.921  -76.602  54.159  1
181821  93.936  -76.603  54.153  1
181822  93.952  -76.605  54.149  1
181823  93.969  -76.604  54.148  1
181824  93.986  -76.602  54.144  1
181825  94.001  -76.603  54.140  1
181826  94.016  -76.603  54.137  1
181827  94.030  -76.604  54.137  1
181828  94.045  -76.605  54.139  1
181829  94.059  -76.605  54.144  1
181830  94.074  -76.606  54.150  1
181831  94.088  -76.607  54.152  1
181832  94.103  -76.608  54.152  1
181833  94.113  -76.606  54.151  1
181834  94.123  -76.605  54.148  1
181835  94.134  -76.603  54.143  1
181836  94.147  -76.599  54.136  1
181837  94.163  -76.594  54.126  1
181838  94.180  -76.588  54.112  1
181839  94.196  -76.582  54.095  1
181840  94.210  -76.576  54.079  1
181841  94.225  -76.571  54.062  1
181842  94.240  -76.564  54.046  1
181843  94.254  -76.559  54.030  1
181844  94.269  -76.553  54.013  1
181845  94.285  -76.547  53.988  1
181846  94.302  -76.541  53.960  1
181847  94.321  -76.533  53.931  1
181848  94.338  -76.520  53.900  1
181849  94.358  -76.510  53.868  1
181850  94.378  -76.499  53.835  1
181851  94.398  -76.489  53.800  1
181852  94.418  -76.479  53.762  1
181853  94.438  -76.468  53.721  1
181854  94.451  -76.461  53.679  1
181855  94.461  -76.456  53.636  1
181856  94.500  -76.452  53.594  1
181857  94.533  -76.454  53.552  1
181858  94.565  -76.455  53.507  1
181859  94.597  -76.457  53.461  1
181860  94.629  -76.458  53.415  1
181861  94.662  -76.460  53.373  1
181862  94.685  -76.458  53.334  1
181863  94.702  -76.452  53.301  1
181864  94.720  -76.449  53.273  1
181865  94.739  -76.446  53.245  1
181866  94.758  -76.443  53.218  1
181867  94.776  -76.440  53.193  1
181868  94.773  -76.442  53.169  1
181869  94.768  -76.445  53.143  1
181870  94.764  -76.448  53.116  1
181871  94.759  -76.451  53.086  1
181872  94.755  -76.454  53.055  1
181873  94.750  -76.456  53.025  1
181874  94.746  -76.459  52.996  1
181875  94.741  -76.462  52.970  1
181876  94.737  -76.464  52.942  1
181877  94.732  -76.467  52.911  1
181878  94.728  -76.470  52.877  1
181879  94.723  -76.473  52.835  1
181880  94.729  -76.474  52.790  1
181881  94.737  -76.476  52.742  1
181882  94.744  -76.478  52.691  1
181883  94.752  -76.480  52.641  1
181884  94.759  -76.481  52.592  1
181885  94.767  -76.483  52.543  1
181886  94.785  -76.486  52.493  1
181887  94.823  -76.494  52.444  1
181888  94.860  -76.502  52.395  1
181889  94.909  -76.514  52.345  1
181890  94.960  -76.527  52.291  1
181891  95.011  -76.540  52.236  1
181892  95.062  -76.553  52.182  1
181893  95.109  -76.564  52.127  1
181894  95.148  -76.572  52.073  1
181895  95.187  -76.580  52.021  1
181896  95.214  -76.592  51.969  1
181897  95.229  -76.606  51.917  1
181898  95.243  -76.620  51.868  1
181899  95.257  -76.634  51.820  1
181900  95.272  -76.649  51.773  1
181901  95.286  -76.663  51.725  1
181902  95.301  -76.677  51.679  1
181903  95.315  -76.691  51.633  1
181904  95.345  -76.703  51.588  1
181905  95.387  -76.713  51.545  1
181906  95.429  -76.723  51.502  1
181907  95.471  -76.733  51.461  1
181908  95.509  -76.742  51.421  1
181909  95.491  -76.745  51.382  1
181910  95.474  -76.749  51.345  1
181911  95.482  -76.767  51.309  1
181912  95.489  -76.785  51.275  1
181913  95.496  -76.803  51.241  1
181914  95.503  -76.821  51.208  1
181915  95.510  -76.840  51.174  1
181916  95.527  -76.857  51.140  1
181917  95.553  -76.875  51.104  1
181918  95.580  -76.893  51.067  1
181919  95.606  -76.910  51.027  1
181920  95.632  -76.927  50.987  1
181921  95.657  -76.934  50.943  1
181922  95.682  -76.940  50.896  1
181923  95.707  -76.947  50.849  1
181924  95.733  -76.953  50.801  1
181925  95.758  -76.960  50.753  1
181926  95.783  -76.967  50.704  1
181927  95.808  -76.974  50.657  1
181928  95.838  -76.972  50.606  1
181929  95.870  -76.966  50.552  1
181930  95.902  -76.962  50.495  1
181931  95.934  -76.956  50.436  1
181932  95.965  -76.951  50.375  1
181933  95.997  -76.946  50.314  1
181934  96.027  -76.943  50.253  1
181935  96.044  -76.953  50.188  1
181936  96.058  -76.969  50.123  1
181937  96.072  -76.984  50.057  1
181938  96.085  -76.999  49.992  1
181939  96.099  -77.014  49.930  1
181940  96.112  -77.029  49.872  1
181941  96.126  -77.044  49.818  1
181942  96.139  -77.059  49.769  1
181943  96.153  -77.075  49.721  1
181944  96.170  -77.088  49.675  1
181945  96.184  -77.100  49.632  1
181946  96.174  -77.118  49.593  1
181947  96.164  -77.137  49.558  1
181948  96.172  -77.134  49.525  1
181949  96.185  -77.125  49.494  1
181950  96.200  -77.123  49.466  1
181951  96.218  -77.130  49.439  1
181952  96.235  -77.137  49.413  1
181953  96.251  -77.144  49.388  1
181954  96.268  -77.150  49.366  1
181955  96.286  -77.157  49.346  1
181956  96.303  -77.164  49.328  1
181957  96.324  -77.169  49.310  1
181958  96.355  -77.168  49.293  1
181959  96.385  -77.167  49.277  1
181960  96.415  -77.166  49.262  1
181961  96.446  -77.166  49.250  1
181962  96.476  -77.166  49.237  1
181963  96.507  -77.165  49.224  1
181964  96.537  -77.164  49.211  1
181965  96.567  -77.163  49.197  1
181966  96.587  -77.169  49.181  1
181967  96.608  -77.173  49.163  1
181968  96.628  -77.178  49.145  1
181969  96.646  -77.187  49.127  1
181970  96.661  -77.201  49.108  1
181971  96.677  -77.214  49.088  1
181972  96.692  -77.228  49.068  1
181973  96.708  -77.241  49.048  1
181974  96.724  -77.254  49.027  1
181975  96.739  -77.268  49.007  1
181976  96.754  -77.282  48.988  1
181977  96.863  -77.291  48.968  1
181978  96.877  -77.296  48.947  1
181979  96.891  -77.301  48.928  1
181980  96.906  -77.305  48.907  1
181981  96.920  -77.312  48.885  1
181982  96.935  -77.323  48.863  1
181983  96.925  -77.338  48.840  1
181984  96.890  -77.356  48.818  1
181985  96.872  -77.370  48.796  1
181986  96.887  -77.375  48.774  1
181987  96.903  -77.380  48.752  1
181988  96.918  -77.385  48.731  1
181989  96.934  -77.390  48.710  1
181990  96.997  -77.375  48.690  1
181991  97.044  -77.379  48.670  1
181992  97.078  -77.398  48.649  1
181993  97.107  -77.423  48.629  1
181994  97.136  -77.447  48.610  1
181995  97.165  -77.472  48.590  1
181996  97.194  -77.497  48.571  1
181997  97.223  -77.521  48.552  1
181998  97.252  -77.546  48.530  1
181999  97.281  -77.570  48.509  1
182000  97.305  -77.589  48.488  1
182001  97.330  -77.609  48.469  1
182002  97.337  -77.595  48.449  1
182003  97.343  -77.578  48.429  1
182004  97.348  -77.560  48.410  1
182005  97.353  -77.542  48.391  1
182006  97.358  -77.524  48.373  1
182007  97.363  -77.506  48.356  1
182008  97.369  -77.488  48.339  1
182009  97.374  -77.470  48.320  1
182010  97.379  -77.452  48.301  1
182011  97.391  -77.464  48.281  1
182012  97.404  -77.483  48.262  1
182013  97.417  -77.500  48.242  1
182014  97.432  -77.511  48.219  1
182015  97.451  -77.523  48.196  1
182016  97.470  -77.535  48.171  1
182017  97.489  -77.547  48.145  1
182018  97.508  -77.560  48.119  1
182019  97.527  -77.572  48.091  1
182020  97.546  -77.583  48.062  1
182021  97.574  -77.582  48.034  1
182022  97.601  -77.580  48.005  1
182023  97.629  -77.578  47.974  1
182024  97.656  -77.577  47.943  1
182025  97.695  -77.580  47.911  1
182026  97.740  -77.586  47.879  1
182027  97.786  -77.592  47.847  1
182028  97.831  -77.599  47.816  1
182029  97.877  -77.605  47.784  1
182030  97.922  -77.612  47.752  1
182031  97.968  -77.618  47.722  1
182032  98.009  -77.622  47.692  1
182033  98.041  -77.625  47.662  1
182034  98.055  -77.636  47.633  1
182035  98.069  -77.619  47.604  1
182036  98.081  -77.594  47.576  1
182037  98.090  -77.580  47.548  1
182038  98.099  -77.567  47.520  1
182039  98.108  -77.555  47.493  1
182040  98.118  -77.539  47.466  1
182041  98.127  -77.524  47.439  1
182042  98.136  -77.509  47.412  1
182043  98.146  -77.494  47.384  1
182044  98.155  -77.479  47.357  1
182045  98.183  -77.476  47.330  1
182046  98.233  -77.489  47.302  1
182047  98.277  -77.499  47.275  1
182048  98.297  -77.501  47.249  1
182049  98.317  -77.501  47.224  1
182050  98.337  -77.503  47.200  1
182051  98.357  -77.504  47.176  1
182052  98.377  -77.506  47.151  1
182053  98.397  -77.508  47.125  1
182054  98.418  -77.509  47.099  1
182055  98.438  -77.510  47.074  1
182056  98.458  -77.511  47.049  1
182057  98.478  -77.513  47.022  1
182058  98.498  -77.514  46.999  1
182059  98.518  -77.516  46.975  1
182060  98.538  -77.517  46.950  1
182061  98.558  -77.518  46.927  1
182062  98.556  -77.519  46.903  1
182063  98.563  -77.539  46.882  1
182064  98.569  -77.558  46.861  1
182065  98.575  -77.578  46.838  1
182066  98.575  -77.585  46.816  1
182067  98.592  -77.589  46.793  1
182068  98.611  -77.592  46.770  1
182069  98.630  -77.595  46.745  1
182070  98.649  -77.598  46.722  1
182071  98.670  -77.593  46.698  1
182072  98.692  -77.587  46.674  1
182073  98.713  -77.580  46.649  1
182074  98.734  -77.574  46.625  1
182075  98.756  -77.568  46.601  1
182076  98.777  -77.561  46.576  1
182077  98.797  -77.558  46.554  1
182078  98.805  -77.564  46.532  1
182079  98.816  -77.570  46.511  1
182080  98.832  -77.571  46.490  1
182081  98.847  -77.572  46.469  1
182082  98.862  -77.573  46.448  1
182083  98.873  -77.578  46.428  1
182084  98.880  -77.585  46.407  1
182085  98.888  -77.591  46.388  1
182086  98.892  -77.597  46.368  1
182087  98.887  -77.599  46.348  1
182088  98.905  -77.608  46.327  1
182089  98.922  -77.618  46.306  1
182090  98.939  -77.627  46.284  1
182091  98.931  -77.640  46.263  1
182092  98.918  -77.655  46.243  1
182093  98.933  -77.670  46.223  1
182094  98.940  -77.673  46.201  1
182095  98.951  -77.676  46.180  1
182096  98.961  -77.679  46.157  1
182097  98.973  -77.682  46.134  1
182098  98.983  -77.685  46.113  1
182099  98.994  -77.689  46.091  1
182100  99.004  -77.692  46.069  1
182101  99.015  -77.695  46.048  1
182102  99.025  -77.698  46.026  1
182103  99.037  -77.701  46.006  1
182104  99.066  -77.727  45.987  1
182105  99.100  -77.757  45.969  1
182106  99.133  -77.787  45.952  1
182107  99.161  -77.769  45.937  1
182108  99.188  -77.745  45.922  1
182109  99.191  -77.735  45.909  1
182110  99.213  -77.758  45.894  1
182111  99.236  -77.781  45.882  1
182112  99.259  -77.804  45.871  1
182113  99.282  -77.827  45.862  1
182114  99.309  -77.849  45.852  1
182115  99.347  -77.868  45.843  1
182116  99.386  -77.888  45.833  1
182117  99.424  -77.907  45.825  1
182118  99.463  -77.927  45.816  1
182119  99.501  -77.946  45.807  1
182120  99.540  -77.966  45.798  1
182121  99.577  -77.984  45.788  1
182122  99.598  -77.993  45.778  1
182123  99.619  -78.002  45.769  1
182124  99.640  -78.010  45.759  1
182125  99.661  -78.018  45.748  1
182126  99.684  -78.018  45.738  1
182127  99.711  -78.005  45.728  1
182128  99.737  -77.992  45.717  1
182129  99.764  -77.978  45.707  1
182130  99.784  -77.981  45.697  1
182131  99.802  -77.990  45.687  1
182132  99.820  -78.000  45.675  1
182133  99.837  -78.010  45.665  1
182134  99.855  -78.020  45.654  1
182135  99.872  -78.030  45.642  1
182136  99.899  -78.053  45.630  1
182137  99.930  -78.082  45.617  1
182138  99.962  -78.112  45.604  1
182139  99.993  -78.140  45.590  1
182140  100.027  -78.149  45.576  1
182141  100.059  -78.157  45.560  1
182142  100.092  -78.166  45.543  1
182143  100.125  -78.174  45.528  1
182144  100.158  -78.183  45.512  1
182145  100.191  -78.191  45.496  1
182146  100.241  -78.166  45.480  1
182147  100.256  -78.167  45.464  1
182148  100.261  -78.184  45.450  1
182149  100.265  -78.200  45.436  1
182150  100.270  -78.216  45.421  1
182151  100.275  -78.233  45.407  1
182152  100.281  -78.250  45.392  1
182153  100.288  -78.267  45.377  1
182154  100.294  -78.284  45.362  1
182155  100.301  -78.300  45.346  1
182156  100.310  -78.316  45.329  1
182157  100.333  -78.323  45.313  1
182158  100.363  -78.324  45.298  1
182159  100.395  -78.326  45.281  1
182160  100.426  -78.326  45.263  1
182161  100.463  -78.329  45.247  1
182162  100.500  -78.332  45.230  1
182163  100.538  -78.335  45.215  1
182164  100.576  -78.338  45.199  1
182165  100.614  -78.341  45.182  1
182166  100.655  -78.343  45.167  1
182167  100.702  -78.351  45.151  1
182168  100.746  -78.358  45.136  1
182169  100.786  -78.364  45.121  1
182170  100.825  -78.371  45.106  1
182171  100.864  -78.378  45.091  1
182172  100.904  -78.385  45.077  1
182173  100.943  -78.391  45.063  1
182174  100.982  -78.398  45.048  1
182175  101.022  -78.404  45.033  1
182176  101.050  -78.411  45.018  1
182177  101.077  -78.418  45.001  1
182178  101.104  -78.425  44.985  1
182179  101.148  -78.407  44.969  1
182180  101.164  -78.415  44.954  1
182181  101.179  -78.423  44.938  1
182182  101.194  -78.431  44.921  1
182183  101.210  -78.439  44.904  1
182184  101.226  -78.448  44.888  1
182185  101.254  -78.464  44.871  1
182186  101.284  -78.481  44.854  1
182187  101.314  -78.498  44.837  1
182188  101.343  -78.515  44.821  1
182189  101.372  -78.532  44.805  1
182190  101.398  -78.550  44.789  1
182191  101.425  -78.567  44.773  1
182192  101.451  -78.588  44.756  1
182193  101.476  -78.611  44.740  1
182194  101.499  -78.639  44.725  1
182195  101.522  -78.666  44.709  1
182196  101.545  -78.692  44.694  1
182197  101.567  -78.725  44.679  1
182198  101.591  -78.758  44.664  1
182199  101.614  -78.791  44.647  1
182200  101.636  -78.824  44.633  1
182201  101.650  -78.834  44.618  1
182202  101.662  -78.837  44.604  1
182203  101.672  -78.840  44.590  1
182204  101.698  -78.855  44.576  1
182205  101.737  -78.880  44.563  1
182206  101.775  -78.905  44.547  1
182207  101.785  -78.934  44.534  1
182208  101.803  -78.940  44.520  1
182209  101.821  -78.946  44.507  1
182210  101.840  -78.952  44.494  1
182211  101.858  -78.959  44.481  1
182212  101.876  -78.965  44.468  1
182213  101.895  -78.971  44.455  1
182214  101.913  -78.977  44.443  1
182215  101.931  -78.984  44.431  1
182216  101.949  -78.990  44.420  1
182217  101.968  -78.996  44.408  1
182471  92.999  -76.769  54.056  1
182472  93.019  -76.761  54.069  1
182473  93.040  -76.752  54.082  1
182474  93.060  -76.743  54.094  1
182475  93.079  -76.739  54.105  1
182476  93.098  -76.735  54.114  1
182477  93.118  -76.732  54.124  1
182478  93.137  -76.729  54.133  1
182479  93.156  -76.725  54.140  1
182480  93.176  -76.722  54.146  1
182481  93.195  -76.719  54.151  1
182482  93.214  -76.715  54.156  1
182483  93.233  -76.712  54.160  1
182484  93.252  -76.709  54.164  1
182485  93.272  -76.706  54.166  1
182486  93.291  -76.703  54.169  1
182487  93.310  -76.700  54.171  1
182488  93.330  -76.697  54.172  1
182489  93.350  -76.694  54.174  1
182490  93.369  -76.691  54.176  1
182491  93.389  -76.688  54.177  1
182492  93.408  -76.685  54.178  1
182493  93.427  -76.682  54.179  1
182494  93.447  -76.679  54.181  1
182495  93.476  -76.676  54.184  1
182496  93.494  -76.679  54.187  1
182497  93.512  -76.681  54.192  1
182498  93.531  -76.684  54.196  1
182499  93.549  -76.687  54.198  1
182500  93.569  -76.687  54.200  1
182501  93.590  -76.677  54.200  1
182502  93.611  -76.667  54.202  1
182503  93.632  -76.657  54.204  1
182504  93.653  -76.647  54.207  1
182505  93.674  -76.638  54.208  1
182506  93.692  -76.633  54.208  1
182507  93.709  -76.629  54.208  1
182508  93.727  -76.623  54.206  1
182509  93.742  -76.616  54.205  1
182510  93.755  -76.609  54.204  1
182511  93.769  -76.602  54.203  1
182512  93.783  -76.596  54.203  1
182513  93.797  -76.589  54.204  1
182514  93.811  -76.582  54.206  1
182515  93.824  -76.575  54.207  1
182516  93.839  -76.575  54.206  1
182517  93.854  -76.577  54.204  1
182518  93.869  -76.577  54.199  1
182519  93.885  -76.578  54.191  1
182520  93.900  -76.580  54.180  1
182521  93.915  -76.580  54.172  1
182522  93.930  -76.582  54.165  1
182523  93.945  -76.583  54.160  1
182524  93.961  -76.584  54.158  1
182525  93.977  -76.584  54.154  1
182526  93.991  -76.585  54.149  1
182527  94.006  -76.585  54.145  1
182528  94.020  -76.586  54.143  1
182529  94.035  -76.586  54.144  1
182530  94.049  -76.587  54.148  1
182531  94.064  -76.588  54.153  1
182532  94.078  -76.589  54.157  1
182533  94.092  -76.589  54.159  1
182534  94.107  -76.589  54.159  1
182535  94.117  -76.589  54.159  1
182536  94.129  -76.586  54.156  1
182537  94.143  -76.582  54.150  1
182538  94.156  -76.578  54.141  1
182539  94.173  -76.571  54.127  1
182540  94.188  -76.566  54.111  1
182541  94.203  -76.560  54.094  1
182542  94.219  -76.554  54.078  1
182543  94.235  -76.547  54.062  1
182544  94.252  -76.541  54.046  1
182545  94.268  -76.534  54.030  1
182546  94.284  -76.528  54.004  1
182547  94.303  -76.526  53.976  1
182548  94.323  -76.524  53.946  1
182549  94.340  -76.511  53.914  1
182550  94.357  -76.498  53.882  1
182551  94.374  -76.485  53.850  1
182552  94.392  -76.472  53.816  1
182553  94.412  -76.461  53.779  1
182554  94.432  -76.451  53.740  1
182555  94.451  -76.441  53.700  1
182556  94.466  -76.436  53.657  1
182557  94.501  -76.436  53.615  1
182558  94.533  -76.437  53.574  1
182559  94.565  -76.439  53.530  1
182560  94.598  -76.440  53.483  1
182561  94.630  -76.442  53.436  1
182562  94.662  -76.443  53.393  1
182563  94.685  -76.441  53.353  1
182564  94.703  -76.437  53.319  1
182565  94.722  -76.434  53.288  1
182566  94.741  -76.431  53.259  1
182567  94.759  -76.428  53.231  1
182568  94.778  -76.426  53.206  1
182569  94.779  -76.426  53.180  1
182570  94.775  -76.430  53.154  1
182571  94.770  -76.432  53.127  1
182572  94.766  -76.435  53.099  1
182573  94.761  -76.437  53.068  1
182574  94.757  -76.440  53.038  1
182575  94.752  -76.443  53.010  1
182576  94.748  -76.445  52.984  1
182577  94.743  -76.448  52.956  1
182578  94.739  -76.451  52.926  1
182579  94.734  -76.454  52.893  1
182580  94.730  -76.457  52.851  1
182581  94.724  -76.459  52.806  1
182582  94.720  -76.462  52.757  1
182583  94.715  -76.464  52.706  1
182584  94.722  -76.467  52.655  1
182585  94.730  -76.468  52.606  1
182586  94.738  -76.470  52.558  1
182587  94.757  -76.473  52.509  1
182588  94.794  -76.481  52.460  1
182589  94.845  -76.494  52.411  1
182590  94.896  -76.507  52.363  1
182591  94.947  -76.520  52.311  1
182592  94.997  -76.533  52.258  1
182593  95.048  -76.546  52.203  1
182594  95.093  -76.556  52.147  1
182595  95.132  -76.564  52.091  1
182596  95.172  -76.573  52.038  1
182597  95.208  -76.581  51.987  1
182598  95.223  -76.596  51.934  1
182599  95.238  -76.610  51.885  1
182600  95.252  -76.624  51.836  1
182601  95.266  -76.638  51.787  1
182602  95.281  -76.652  51.741  1
182603  95.296  -76.667  51.695  1
182604  95.310  -76.681  51.649  1
182605  95.349  -76.691  51.604  1
182606  95.391  -76.701  51.561  1
182607  95.432  -76.711  51.518  1
182608  95.474  -76.721  51.477  1
182609  95.516  -76.731  51.437  1
182610  95.515  -76.736  51.398  1
182611  95.498  -76.739  51.361  1
182612  95.505  -76.757  51.326  1
182613  95.512  -76.775  51.292  1
182614  95.520  -76.793  51.259  1
182615  95.527  -76.812  51.226  1
182616  95.534  -76.830  51.192  1
182617  95.541  -76.849  51.158  1
182618  95.548  -76.867  51.122  1
182619  95.569  -76.884  51.083  1
182620  95.596  -76.902  51.043  1
182621  95.622  -76.919  51.004  1
182622  95.648  -76.929  50.960  1
182623  95.673  -76.935  50.914  1
182624  95.698  -76.942  50.868  1
182625  95.723  -76.949  50.819  1
182626  95.748  -76.956  50.771  1
182627  95.778  -76.954  50.723  1
182628  95.808  -76.953  50.676  1
182629  95.838  -76.950  50.626  1
182630  95.871  -76.945  50.572  1
182631  95.902  -76.940  50.516  1
182632  95.934  -76.934  50.458  1
182633  95.966  -76.929  50.397  1
182634  95.995  -76.927  50.335  1
182635  96.020  -76.928  50.273  1
182636  96.039  -76.937  50.209  1
182637  96.052  -76.953  50.143  1
182638  96.066  -76.968  50.077  1
182639  96.080  -76.983  50.011  1
182640  96.093  -76.998  49.949  1
182641  96.107  -77.013  49.891  1
182642  96.120  -77.028  49.837  1
182643  96.134  -77.044  49.788  1
182644  96.151  -77.056  49.740  1
182645  96.176  -77.066  49.694  1
182646  96.182  -77.079  49.652  1
182647  96.172  -77.098  49.614  1
182648  96.162  -77.116  49.579  1
182649  96.152  -77.135  49.547  1
182650  96.142  -77.153  49.516  1
182651  96.154  -77.145  49.488  1
182652  96.171  -77.151  49.462  1
182653  96.188  -77.158  49.436  1
182654  96.205  -77.165  49.410  1
182655  96.231  -77.166  49.389  1
182656  96.262  -77.166  49.370  1
182657  96.292  -77.165  49.351  1
182658  96.323  -77.164  49.334  1
182659  96.353  -77.164  49.318  1
182660  96.384  -77.163  49.302  1
182661  96.414  -77.163  49.287  1
182662  96.444  -77.162  49.275  1
182663  96.475  -77.161  49.262  1
182664  96.505  -77.160  49.249  1
182665  96.536  -77.160  49.235  1
182666  96.564  -77.160  49.221  1
182667  96.584  -77.165  49.204  1
182668  96.605  -77.170  49.186  1
182669  96.625  -77.175  49.168  1
182670  96.646  -77.179  49.149  1
182671  96.664  -77.187  49.129  1
182672  96.680  -77.201  49.109  1
182673  96.695  -77.214  49.088  1
182674  96.711  -77.228  49.066  1
182675  96.726  -77.241  49.045  1
182676  96.742  -77.254  49.024  1
182677  96.819  -77.268  49.005  1
182678  96.846  -77.273  48.985  1
182679  96.860  -77.278  48.964  1
182680  96.874  -77.282  48.945  1
182681  96.888  -77.287  48.924  1
182682  96.902  -77.291  48.901  1
182683  96.917  -77.299  48.879  1
182684  96.932  -77.310  48.855  1
182685  96.946  -77.321  48.832  1
182686  96.912  -77.339  48.809  1
182687  96.891  -77.354  48.786  1
182688  96.906  -77.359  48.764  1
182689  96.922  -77.364  48.742  1
182690  96.937  -77.370  48.721  1
182691  96.993  -77.357  48.701  1
182692  97.048  -77.354  48.680  1
182693  97.082  -77.373  48.659  1
182694  97.111  -77.398  48.637  1
182695  97.140  -77.423  48.617  1
182696  97.169  -77.448  48.597  1
182697  97.198  -77.472  48.578  1
182698  97.227  -77.497  48.559  1
182699  97.253  -77.518  48.538  1
182700  97.277  -77.537  48.516  1
182701  97.302  -77.557  48.496  1
182702  97.326  -77.576  48.476  1
182703  97.343  -77.581  48.456  1
182704  97.349  -77.563  48.437  1
182705  97.354  -77.545  48.417  1
182706  97.359  -77.527  48.398  1
182707  97.364  -77.509  48.381  1
182708  97.369  -77.491  48.364  1
182709  97.374  -77.473  48.347  1
182710  97.380  -77.455  48.328  1
182711  97.387  -77.445  48.307  1
182712  97.400  -77.464  48.287  1
182713  97.413  -77.482  48.268  1
182714  97.426  -77.499  48.248  1
182715  97.440  -77.514  48.227  1
182716  97.455  -77.524  48.203  1
182717  97.473  -77.536  48.177  1
182718  97.493  -77.549  48.152  1
182719  97.512  -77.561  48.125  1
182720  97.531  -77.573  48.097  1
182721  97.556  -77.577  48.068  1
182722  97.583  -77.574  48.039  1
182723  97.610  -77.573  48.009  1
182724  97.638  -77.571  47.977  1
182725  97.665  -77.569  47.945  1
182726  97.708  -77.574  47.913  1
182727  97.753  -77.581  47.881  1
182728  97.799  -77.587  47.850  1
182729  97.844  -77.594  47.817  1
182730  97.890  -77.600  47.786  1
182731  97.935  -77.606  47.755  1
182732  97.972  -77.608  47.725  1
182733  98.009  -77.609  47.694  1
182734  98.046  -77.611  47.664  1
182735  98.063  -77.620  47.635  1
182736  98.077  -77.599  47.605  1
182737  98.087  -77.583  47.576  1
182738  98.096  -77.570  47.548  1
182739  98.105  -77.556  47.520  1
182740  98.114  -77.541  47.494  1
182741  98.124  -77.526  47.467  1
182742  98.134  -77.511  47.440  1
182743  98.143  -77.495  47.413  1
182744  98.152  -77.480  47.387  1
182745  98.161  -77.465  47.359  1
182746  98.174  -77.451  47.331  1
182747  98.223  -77.464  47.304  1
182748  98.273  -77.476  47.278  1
182749  98.320  -77.488  47.252  1
182750  98.341  -77.489  47.227  1
182751  98.361  -77.490  47.203  1
182752  98.381  -77.492  47.179  1
182753  98.401  -77.493  47.155  1
182754  98.421  -77.495  47.132  1
182755  98.441  -77.496  47.107  1
182756  98.461  -77.498  47.082  1
182757  98.482  -77.499  47.057  1
182758  98.502  -77.500  47.032  1
182759  98.522  -77.501  47.007  1
182760  98.542  -77.503  46.983  1
182761  98.562  -77.504  46.959  1
182762  98.557  -77.494  46.934  1
182763  98.564  -77.514  46.912  1
182764  98.570  -77.533  46.890  1
182765  98.577  -77.553  46.869  1
182766  98.583  -77.573  46.846  1
182767  98.593  -77.586  46.824  1
182768  98.613  -77.581  46.801  1
182769  98.632  -77.577  46.778  1
182770  98.651  -77.573  46.753  1
182771  98.670  -77.569  46.729  1
182772  98.690  -77.564  46.706  1
182773  98.709  -77.561  46.681  1
182774  98.728  -77.556  46.657  1
182775  98.748  -77.551  46.632  1
182776  98.767  -77.548  46.607  1
182777  98.787  -77.543  46.583  1
182778  98.805  -77.541  46.559  1
182779  98.820  -77.548  46.537  1
182780  98.834  -77.554  46.516  1
182781  98.843  -77.561  46.495  1
182782  98.858  -77.561  46.474  1
182783  98.874  -77.563  46.454  1
182784  98.883  -77.568  46.433  1
182785  98.890  -77.575  46.413  1
182786  98.899  -77.581  46.394  1
182787  98.906  -77.588  46.374  1
182788  98.920  -77.595  46.354  1
182789  98.939  -77.606  46.332  1
182790  98.958  -77.617  46.311  1
182791  98.976  -77.626  46.290  1
182792  98.994  -77.636  46.269  1
182793  98.990  -77.648  46.249  1
182794  98.977  -77.645  46.228  1
182795  98.982  -77.645  46.206  1
182796  98.991  -77.647  46.185  1
182797  98.998  -77.651  46.163  1
182798  99.006  -77.655  46.141  1
182799  99.014  -77.658  46.120  1
182800  99.022  -77.663  46.096  1
182801  99.029  -77.667  46.074  1
182802  99.038  -77.671  46.052  1
182803  99.045  -77.674  46.030  1
182804  99.053  -77.678  46.010  1
182805  99.072  -77.696  45.991  1
182806  99.104  -77.729  45.973  1
182807  99.135  -77.758  45.955  1
182808  99.166  -77.746  45.939  1
182809  99.175  -77.727  45.925  1
182810  99.183  -77.724  45.910  1
182811  99.206  -77.747  45.896  1
182812  99.228  -77.770  45.884  1
182813  99.252  -77.793  45.873  1
182814  99.282  -77.814  45.863  1
182815  99.321  -77.834  45.854  1
182816  99.359  -77.852  45.844  1
182817  99.398  -77.872  45.834  1
182818  99.436  -77.892  45.826  1
182819  99.475  -77.912  45.816  1
182820  99.513  -77.931  45.807  1
182821  99.552  -77.950  45.797  1
182822  99.590  -77.970  45.787  1
182823  99.621  -77.984  45.777  1
182824  99.642  -77.993  45.767  1
182825  99.662  -78.001  45.757  1
182826  99.684  -78.009  45.746  1
182827  99.710  -77.997  45.736  1
182828  99.736  -77.984  45.726  1
182829  99.762  -77.975  45.716  1
182830  99.779  -77.984  45.706  1
182831  99.796  -77.994  45.696  1
182832  99.814  -78.004  45.685  1
182833  99.832  -78.014  45.674  1
182834  99.849  -78.024  45.664  1
182835  99.867  -78.034  45.653  1
182836  99.885  -78.044  45.642  1
182837  99.902  -78.054  45.630  1
182838  99.933  -78.084  45.617  1
182839  99.965  -78.113  45.603  1
182840  99.997  -78.126  45.589  1
182841  100.031  -78.135  45.575  1
182842  100.063  -78.144  45.559  1
182843  100.096  -78.152  45.543  1
182844  100.129  -78.160  45.528  1
182845  100.162  -78.169  45.512  1
182846  100.195  -78.178  45.496  1
182847  100.238  -78.166  45.480  1
182848  100.270  -78.146  45.464  1
182849  100.275  -78.162  45.450  1
182850  100.279  -78.178  45.436  1
182851  100.284  -78.195  45.423  1
182852  100.290  -78.212  45.409  1
182853  100.296  -78.228  45.395  1
182854  100.303  -78.245  45.380  1
182855  100.310  -78.263  45.364  1
182856  100.316  -78.279  45.349  1
182857  100.323  -78.296  45.333  1
182858  100.340  -78.307  45.317  1
182859  100.364  -78.313  45.301  1
182860  100.396  -78.313  45.284  1
182861  100.427  -78.314  45.267  1
182862  100.465  -78.317  45.251  1
182863  100.502  -78.321  45.234  1
182864  100.541  -78.324  45.218  1
182865  100.580  -78.326  45.202  1
182866  100.622  -78.326  45.186  1
182867  100.667  -78.329  45.171  1
182868  100.714  -78.337  45.156  1
182869  100.761  -78.345  45.141  1
182870  100.808  -78.353  45.126  1
182871  100.852  -78.360  45.111  1
182872  100.891  -78.366  45.096  1
182873  100.930  -78.373  45.082  1
182874  100.970  -78.380  45.068  1
182875  101.009  -78.387  45.053  1
182876  101.042  -78.394  45.038  1
182877  101.069  -78.401  45.022  1
182878  101.097  -78.407  45.005  1
182879  101.124  -78.413  44.989  1
182880  101.156  -78.405  44.973  1
182881  101.172  -78.413  44.956  1
182882  101.188  -78.422  44.941  1
182883  101.203  -78.430  44.924  1
182884  101.218  -78.438  44.908  1
182885  101.234  -78.446  44.891  1
182886  101.250  -78.454  44.874  1
182887  101.279  -78.472  44.857  1
182888  101.309  -78.489  44.841  1
182889  101.338  -78.506  44.826  1
182890  101.368  -78.523  44.810  1
182891  101.398  -78.540  44.794  1
182892  101.427  -78.557  44.777  1
182893  101.453  -78.577  44.761  1
182894  101.476  -78.604  44.745  1
182895  101.499  -78.632  44.729  1
182896  101.522  -78.658  44.713  1
182897  101.545  -78.686  44.698  1
182898  101.568  -78.718  44.683  1
182899  101.591  -78.752  44.667  1
182900  101.614  -78.784  44.651  1
182901  101.632  -78.806  44.637  1
182902  101.643  -78.809  44.623  1
182903  101.654  -78.812  44.608  1
182904  101.681  -78.828  44.594  1
182905  101.720  -78.853  44.580  1
182906  101.759  -78.879  44.566  1
182907  101.798  -78.904  44.551  1
182908  101.804  -78.943  44.537  1
182909  101.822  -78.949  44.523  1
182910  101.840  -78.955  44.510  1
182911  101.858  -78.961  44.496  1
182912  101.877  -78.967  44.483  1
182913  101.895  -78.974  44.471  1
182914  101.913  -78.980  44.458  1
182915  101.932  -78.986  44.446  1
182916  101.950  -78.992  44.434  1
182917  101.968  -78.998  44.421  1
182918  101.986  -79.005  44.408  1
183173  93.009  -76.737  54.052  1
183174  93.029  -76.728  54.066  1
183175  93.049  -76.719  54.079  1
183176  93.069  -76.715  54.091  1
183177  93.088  -76.712  54.101  1
183178  93.107  -76.708  54.111  1
183179  93.127  -76.705  54.121  1
183180  93.146  -76.702  54.129  1
183181  93.165  -76.699  54.136  1
183182  93.184  -76.695  54.142  1
183183  93.203  -76.692  54.148  1
183184  93.222  -76.689  54.152  1
183185  93.242  -76.685  54.155  1
183186  93.261  -76.682  54.158  1
183187  93.281  -76.679  54.161  1
183188  93.300  -76.677  54.163  1
183189  93.320  -76.674  54.165  1
183190  93.339  -76.671  54.167  1
183191  93.359  -76.668  54.168  1
183192  93.378  -76.665  54.169  1
183193  93.398  -76.661  54.170  1
183194  93.417  -76.658  54.171  1
183195  93.439  -76.655  54.171  1
183196  93.468  -76.652  54.173  1
183197  93.486  -76.655  54.175  1
183198  93.504  -76.658  54.179  1
183199  93.523  -76.661  54.180  1
183200  93.541  -76.664  54.182  1
183201  93.560  -76.667  54.182  1
183202  93.578  -76.668  54.183  1
183203  93.600  -76.658  54.185  1
183204  93.621  -76.648  54.188  1
183205  93.642  -76.638  54.192  1
183206  93.663  -76.628  54.195  1
183207  93.685  -76.618  54.196  1
183208  93.706  -76.609  54.198  1
183209  93.724  -76.602  54.199  1
183210  93.740  -76.596  54.199  1
183211  93.754  -76.589  54.200  1
183212  93.766  -76.582  54.202  1
183213  93.776  -76.575  54.204  1
183214  93.786  -76.567  54.207  1
183215  93.796  -76.560  54.210  1
183216  93.813  -76.561  54.212  1
183217  93.832  -76.567  54.214  1
183218  93.847  -76.567  54.214  1
183219  93.863  -76.568  54.211  1
183220  93.878  -76.568  54.205  1
183221  93.893  -76.569  54.196  1
183222  93.908  -76.570  54.188  1
183223  93.924  -76.571  54.180  1
183224  93.939  -76.571  54.174  1
183225  93.955  -76.569  54.170  1
183226  93.964  -76.566  54.165  1
183227  93.978  -76.567  54.160  1
183228  93.993  -76.567  54.154  1
183229  94.008  -76.568  54.151  1
183230  94.023  -76.568  54.150  1
183231  94.038  -76.569  54.152  1
183232  94.053  -76.570  54.158  1
183233  94.068  -76.571  54.161  1
183234  94.082  -76.571  54.164  1
183235  94.097  -76.572  54.167  1
183236  94.111  -76.572  54.166  1
183237  94.125  -76.568  54.165  1
183238  94.139  -76.564  54.162  1
183239  94.153  -76.560  54.154  1
183240  94.169  -76.554  54.139  1
183241  94.185  -76.548  54.123  1
183242  94.201  -76.542  54.107  1
183243  94.218  -76.535  54.093  1
183244  94.234  -76.529  54.077  1
183245  94.250  -76.522  54.061  1
183246  94.267  -76.516  54.043  1
183247  94.284  -76.511  54.016  1
183248  94.305  -76.510  53.988  1
183249  94.324  -76.508  53.958  1
183250  94.343  -76.504  53.926  1
183251  94.360  -76.490  53.892  1
183252  94.377  -76.477  53.861  1
183253  94.394  -76.463  53.828  1
183254  94.411  -76.449  53.792  1
183255  94.428  -76.436  53.756  1
183256  94.446  -76.423  53.716  1
183257  94.469  -76.417  53.675  1
183258  94.501  -76.419  53.633  1
183259  94.534  -76.420  53.593  1
183260  94.566  -76.422  53.549  1
183261  94.598  -76.423  53.501  1
183262  94.630  -76.425  53.455  1
183263  94.663  -76.426  53.412  1
183264  94.687  -76.425  53.373  1
183265  94.705  -76.422  53.337  1
183266  94.723  -76.420  53.304  1
183267  94.740  -76.419  53.273  1
183268  94.757  -76.417  53.243  1
183269  94.774  -76.416  53.216  1
183270  94.778  -76.417  53.189  1
183271  94.774  -76.419  53.162  1
183272  94.770  -76.421  53.134  1
183273  94.766  -76.423  53.107  1
183274  94.762  -76.425  53.079  1
183275  94.759  -76.427  53.050  1
183276  94.755  -76.430  53.023  1
183277  94.751  -76.432  52.998  1
183278  94.747  -76.434  52.971  1
183279  94.743  -76.436  52.943  1
183280  94.739  -76.439  52.911  1
183281  94.735  -76.441  52.869  1
183282  94.731  -76.443  52.823  1
183283  94.726  -76.445  52.774  1
183284  94.722  -76.448  52.723  1
183285  94.717  -76.451  52.671  1
183286  94.713  -76.454  52.621  1
183287  94.708  -76.457  52.572  1
183288  94.730  -76.461  52.522  1
183289  94.780  -76.474  52.473  1
183290  94.831  -76.487  52.423  1
183291  94.882  -76.500  52.374  1
183292  94.933  -76.513  52.324  1
183293  94.984  -76.526  52.272  1
183294  95.035  -76.539  52.219  1
183295  95.078  -76.549  52.165  1
183296  95.117  -76.557  52.110  1
183297  95.156  -76.565  52.057  1
183298  95.195  -76.573  52.004  1
183299  95.217  -76.586  51.952  1
183300  95.232  -76.599  51.902  1
183301  95.247  -76.614  51.853  1
183302  95.261  -76.628  51.805  1
183303  95.275  -76.643  51.758  1
183304  95.290  -76.656  51.712  1
183305  95.311  -76.670  51.666  1
183306  95.353  -76.680  51.620  1
183307  95.394  -76.690  51.577  1
183308  95.436  -76.699  51.534  1
183309  95.478  -76.709  51.492  1
183310  95.520  -76.719  51.452  1
183311  95.538  -76.726  51.413  1
183312  95.522  -76.730  51.376  1
183313  95.529  -76.748  51.341  1
183314  95.536  -76.766  51.308  1
183315  95.543  -76.784  51.276  1
183316  95.550  -76.802  51.243  1
183317  95.557  -76.821  51.210  1
183318  95.564  -76.839  51.175  1
183319  95.571  -76.857  51.139  1
183320  95.579  -76.875  51.101  1
183321  95.586  -76.893  51.061  1
183322  95.612  -76.911  51.021  1
183323  95.638  -76.924  50.977  1
183324  95.663  -76.931  50.931  1
183325  95.688  -76.937  50.885  1
183326  95.718  -76.937  50.835  1
183327  95.748  -76.935  50.786  1
183328  95.778  -76.934  50.740  1
183329  95.808  -76.932  50.693  1
183330  95.839  -76.928  50.644  1
183331  95.871  -76.923  50.591  1
183332  95.903  -76.918  50.536  1
183333  95.935  -76.913  50.480  1
183334  95.963  -76.911  50.420  1
183335  95.988  -76.912  50.357  1
183336  96.014  -76.914  50.293  1
183337  96.033  -76.922  50.229  1
183338  96.047  -76.937  50.164  1
183339  96.060  -76.952  50.099  1
183340  96.074  -76.967  50.032  1
183341  96.088  -76.982  49.970  1
183342  96.101  -76.997  49.912  1
183343  96.115  -77.012  49.859  1
183344  96.132  -77.025  49.808  1
183345  96.158  -77.034  49.760  1
183346  96.183  -77.043  49.714  1
183347  96.179  -77.059  49.673  1
183348  96.169  -77.078  49.635  1
183349  96.159  -77.097  49.600  1
183350  96.149  -77.115  49.568  1
183351  96.139  -77.134  49.538  1
183352  96.129  -77.152  49.511  1
183353  96.139  -77.162  49.485  1
183354  96.170  -77.161  49.459  1
183355  96.200  -77.161  49.434  1
183356  96.231  -77.160  49.413  1
183357  96.261  -77.160  49.394  1
183358  96.292  -77.160  49.376  1
183359  96.322  -77.159  49.359  1
183360  96.352  -77.159  49.344  1
183361  96.382  -77.158  49.328  1
183362  96.413  -77.158  49.312  1
183363  96.443  -77.157  49.299  1
183364  96.473  -77.157  49.287  1
183365  96.504  -77.157  49.274  1
183366  96.534  -77.156  49.261  1
183367  96.560  -77.157  49.246  1
183368  96.581  -77.162  49.228  1
183369  96.601  -77.166  49.209  1
183370  96.622  -77.171  49.191  1
183371  96.643  -77.176  49.171  1
183372  96.663  -77.181  49.151  1
183373  96.682  -77.187  49.131  1
183374  96.698  -77.201  49.109  1
183375  96.714  -77.214  49.086  1
183376  96.729  -77.228  49.063  1
183377  96.744  -77.241  49.042  1
183378  96.814  -77.251  49.021  1
183379  96.828  -77.255  49.001  1
183380  96.842  -77.260  48.981  1
183381  96.857  -77.264  48.961  1
183382  96.871  -77.269  48.940  1
183383  96.885  -77.273  48.917  1
183384  96.899  -77.278  48.893  1
183385  96.913  -77.286  48.869  1
183386  96.928  -77.298  48.846  1
183387  96.943  -77.308  48.822  1
183388  96.935  -77.323  48.799  1
183389  96.909  -77.338  48.776  1
183390  96.925  -77.343  48.754  1
183391  96.940  -77.348  48.733  1
183392  96.988  -77.340  48.711  1
183393  97.053  -77.329  48.690  1
183394  97.086  -77.348  48.668  1
183395  97.115  -77.373  48.646  1
183396  97.144  -77.398  48.625  1
183397  97.173  -77.423  48.605  1
183398  97.200  -77.446  48.586  1
183399  97.225  -77.465  48.566  1
183400  97.249  -77.485  48.546  1
183401  97.274  -77.504  48.524  1
183402  97.298  -77.523  48.503  1
183403  97.322  -77.542  48.482  1
183404  97.347  -77.562  48.464  1
183405  97.354  -77.548  48.444  1
183406  97.360  -77.530  48.425  1
183407  97.365  -77.512  48.406  1
183408  97.370  -77.494  48.388  1
183409  97.375  -77.476  48.371  1
183410  97.380  -77.458  48.354  1
183411  97.385  -77.440  48.335  1
183412  97.396  -77.445  48.314  1
183413  97.409  -77.463  48.294  1
183414  97.422  -77.480  48.274  1
183415  97.435  -77.498  48.254  1
183416  97.448  -77.517  48.233  1
183417  97.463  -77.529  48.211  1
183418  97.477  -77.539  48.187  1
183419  97.496  -77.551  48.160  1
183420  97.515  -77.563  48.133  1
183421  97.537  -77.570  48.105  1
183422  97.565  -77.569  48.075  1
183423  97.592  -77.567  48.045  1
183424  97.619  -77.565  48.013  1
183425  97.646  -77.564  47.981  1
183426  97.675  -77.563  47.950  1
183427  97.721  -77.569  47.918  1
183428  97.766  -77.576  47.886  1
183429  97.812  -77.582  47.855  1
183430  97.857  -77.589  47.823  1
183431  97.898  -77.592  47.791  1
183432  97.935  -77.593  47.759  1
183433  97.972  -77.595  47.728  1
183434  98.009  -77.596  47.697  1
183435  98.046  -77.598  47.666  1
183436  98.072  -77.603  47.636  1
183437  98.084  -77.584  47.608  1
183438  98.093  -77.571  47.579  1
183439  98.103  -77.557  47.550  1
183440  98.112  -77.542  47.522  1
183441  98.122  -77.526  47.495  1
183442  98.131  -77.511  47.467  1
183443  98.140  -77.496  47.440  1
183444  98.150  -77.481  47.413  1
183445  98.159  -77.466  47.387  1
183446  98.168  -77.451  47.360  1
183447  98.177  -77.436  47.332  1
183448  98.214  -77.439  47.305  1
183449  98.264  -77.451  47.279  1
183450  98.313  -77.464  47.254  1
183451  98.363  -77.476  47.229  1
183452  98.384  -77.478  47.205  1
183453  98.405  -77.479  47.182  1
183454  98.425  -77.480  47.160  1
183455  98.445  -77.482  47.137  1
183456  98.465  -77.483  47.113  1
183457  98.485  -77.485  47.089  1
183458  98.505  -77.486  47.065  1
183459  98.525  -77.488  47.040  1
183460  98.546  -77.489  47.015  1
183461  98.566  -77.490  46.991  1
183462  98.558  -77.469  46.967  1
183463  98.565  -77.489  46.943  1
183464  98.571  -77.508  46.920  1
183465  98.578  -77.528  46.899  1
183466  98.584  -77.548  46.877  1
183467  98.598  -77.564  46.853  1
183468  98.610  -77.567  46.831  1
183469  98.622  -77.564  46.808  1
183470  98.641  -77.559  46.784  1
183471  98.660  -77.555  46.760  1
183472  98.679  -77.551  46.736  1
183473  98.699  -77.547  46.712  1
183474  98.718  -77.542  46.688  1
183475  98.737  -77.539  46.664  1
183476  98.757  -77.534  46.639  1
183477  98.776  -77.530  46.614  1
183478  98.795  -77.526  46.590  1
183479  98.813  -77.524  46.566  1
183480  98.828  -77.531  46.543  1
183481  98.843  -77.537  46.521  1
183482  98.857  -77.544  46.501  1
183483  98.870  -77.550  46.480  1
183484  98.885  -77.552  46.459  1
183485  98.893  -77.558  46.438  1
183486  98.897  -77.565  46.419  1
183487  98.896  -77.572  46.400  1
183488  98.895  -77.578  46.380  1
183489  98.940  -77.586  46.358  1
183490  98.959  -77.597  46.338  1
183491  98.979  -77.608  46.316  1
183492  98.998  -77.618  46.294  1
183493  99.018  -77.628  46.274  1
183494  99.026  -77.639  46.254  1
183495  98.999  -77.642  46.233  1
183496  98.987  -77.643  46.212  1
183497  98.997  -77.643  46.189  1
183498  99.007  -77.643  46.166  1
183499  99.016  -77.643  46.144  1
183500  99.026  -77.643  46.123  1
183501  99.037  -77.643  46.100  1
183502  99.046  -77.644  46.077  1
183503  99.054  -77.648  46.055  1
183504  99.062  -77.652  46.034  1
183505  99.069  -77.656  46.014  1
183506  99.077  -77.661  45.995  1
183507  99.110  -77.692  45.977  1
183508  99.141  -77.718  45.958  1
183509  99.164  -77.724  45.942  1
183510  99.164  -77.708  45.927  1
183511  99.175  -77.712  45.912  1
183512  99.198  -77.736  45.898  1
183513  99.221  -77.758  45.886  1
183514  99.256  -77.779  45.875  1
183515  99.294  -77.798  45.864  1
183516  99.333  -77.818  45.855  1
183517  99.371  -77.837  45.845  1
183518  99.410  -77.857  45.836  1
183519  99.448  -77.876  45.826  1
183520  99.487  -77.896  45.817  1
183521  99.525  -77.915  45.807  1
183522  99.563  -77.935  45.796  1
183523  99.602  -77.954  45.786  1
183524  99.640  -77.974  45.776  1
183525  99.664  -77.984  45.765  1
183526  99.685  -77.993  45.754  1
183527  99.709  -77.990  45.744  1
183528  99.735  -77.976  45.733  1
183529  99.756  -77.978  45.724  1
183530  99.774  -77.988  45.714  1
183531  99.791  -77.998  45.705  1
183532  99.808  -78.008  45.694  1
183533  99.826  -78.018  45.682  1
183534  99.844  -78.028  45.672  1
183535  99.861  -78.038  45.662  1
183536  99.879  -78.048  45.652  1
183537  99.897  -78.058  45.641  1
183538  99.914  -78.068  45.628  1
183539  99.936  -78.084  45.615  1
183540  99.969  -78.104  45.601  1
183541  100.001  -78.112  45.586  1
183542  100.034  -78.122  45.572  1
183543  100.067  -78.130  45.557  1
183544  100.100  -78.138  45.543  1
183545  100.133  -78.147  45.527  1
183546  100.166  -78.156  45.512  1
183547  100.199  -78.164  45.496  1
183548  100.234  -78.166  45.480  1
183549  100.284  -78.124  45.465  1
183550  100.289  -78.141  45.451  1
183551  100.293  -78.156  45.437  1
183552  100.298  -78.173  45.424  1
183553  100.305  -78.190  45.410  1
183554  100.312  -78.207  45.396  1
183555  100.318  -78.224  45.381  1
183556  100.325  -78.241  45.365  1
183557  100.332  -78.258  45.350  1
183558  100.338  -78.275  45.335  1
183559  100.348  -78.290  45.319  1
183560  100.370  -78.297  45.304  1
183561  100.397  -78.301  45.287  1
183562  100.429  -78.303  45.270  1
183563  100.467  -78.306  45.254  1
183564  100.506  -78.309  45.237  1
183565  100.548  -78.309  45.221  1
183566  100.590  -78.309  45.205  1
183567  100.632  -78.309  45.188  1
183568  100.678  -78.316  45.174  1
183569  100.725  -78.324  45.160  1
183570  100.772  -78.332  45.145  1
183571  100.819  -78.339  45.130  1
183572  100.865  -78.347  45.116  1
183573  100.913  -78.355  45.102  1
183574  100.957  -78.363  45.087  1
183575  100.997  -78.369  45.071  1
183576  101.034  -78.376  45.056  1
183577  101.061  -78.382  45.041  1
183578  101.089  -78.389  45.026  1
183579  101.116  -78.396  45.009  1
183580  101.145  -78.401  44.992  1
183581  101.165  -78.404  44.976  1
183582  101.181  -78.413  44.959  1
183583  101.196  -78.420  44.943  1
183584  101.212  -78.429  44.927  1
183585  101.228  -78.437  44.910  1
183586  101.243  -78.445  44.895  1
183587  101.258  -78.453  44.878  1
183588  101.274  -78.462  44.862  1
183589  101.304  -78.479  44.845  1
183590  101.334  -78.496  44.830  1
183591  101.363  -78.514  44.814  1
183592  101.393  -78.530  44.798  1
183593  101.423  -78.548  44.782  1
183594  101.453  -78.571  44.766  1
183595  101.476  -78.598  44.750  1
183596  101.499  -78.624  44.734  1
183597  101.522  -78.651  44.717  1
183598  101.545  -78.679  44.702  1
183599  101.568  -78.711  44.686  1
183600  101.591  -78.744  44.671  1
183601  101.614  -78.777  44.656  1
183602  101.625  -78.781  44.641  1
183603  101.636  -78.784  44.627  1
183604  101.665  -78.801  44.613  1
183605  101.703  -78.827  44.598  1
183606  101.742  -78.852  44.583  1
183607  101.781  -78.877  44.568  1
183608  101.820  -78.902  44.554  1
183609  101.822  -78.950  44.540  1
183610  101.840  -78.957  44.526  1
183611  101.859  -78.963  44.512  1
183612  101.877  -78.969  44.499  1
183613  101.895  -78.975  44.486  1
183614  101.914  -78.981  44.473  1
183615  101.932  -78.988  44.460  1
183616  101.950  -78.994  44.448  1
183617  101.968  -79.000  44.436  1
183618  101.987  -79.006  44.423  1
183619  102.005  -79.012  44.410  1
183875  93.018  -76.705  54.049  1
183876  93.039  -76.696  54.063  1
183877  93.058  -76.691  54.076  1
183878  93.077  -76.688  54.087  1
183879  93.097  -76.684  54.098  1
183880  93.116  -76.681  54.108  1
183881  93.135  -76.678  54.117  1
183882  93.154  -76.674  54.125  1
183883  93.174  -76.671  54.132  1
183884  93.193  -76.668  54.138  1
183885  93.212  -76.665  54.143  1
183886  93.231  -76.661  54.147  1
183887  93.251  -76.658  54.150  1
183888  93.270  -76.655  54.153  1
183889  93.290  -76.652  54.155  1
183890  93.309  -76.649  54.157  1
183891  93.329  -76.646  54.159  1
183892  93.348  -76.643  54.161  1
183893  93.368  -76.640  54.161  1
183894  93.387  -76.638  54.161  1
183895  93.407  -76.635  54.162  1
183896  93.432  -76.631  54.162  1
183897  93.460  -76.629  54.163  1
183898  93.478  -76.632  54.165  1
183899  93.496  -76.635  54.167  1
183900  93.515  -76.637  54.167  1
183901  93.533  -76.640  54.168  1
183902  93.552  -76.643  54.168  1
183903  93.570  -76.646  54.168  1
183904  93.588  -76.649  54.170  1
183905  93.610  -76.639  54.174  1
183906  93.631  -76.629  54.177  1
183907  93.652  -76.619  54.181  1
183908  93.673  -76.609  54.184  1
183909  93.694  -76.599  54.187  1
183910  93.715  -76.590  54.191  1
183911  93.734  -76.580  54.193  1
183912  93.737  -76.567  54.196  1
183913  93.747  -76.560  54.200  1
183914  93.757  -76.552  54.203  1
183915  93.767  -76.545  54.208  1
183916  93.777  -76.537  54.212  1
183917  93.803  -76.550  54.216  1
183918  93.825  -76.558  54.219  1
183919  93.840  -76.559  54.221  1
183920  93.856  -76.560  54.221  1
183921  93.871  -76.561  54.217  1
183922  93.886  -76.561  54.211  1
183923  93.901  -76.561  54.203  1
183924  93.917  -76.562  54.195  1
183925  93.933  -76.557  54.188  1
183926  93.948  -76.552  54.182  1
183927  93.952  -76.549  54.176  1
183928  93.963  -76.549  54.170  1
183929  93.978  -76.549  54.163  1
183930  93.993  -76.550  54.159  1
183931  94.008  -76.551  54.157  1
183932  94.023  -76.552  54.157  1
183933  94.038  -76.552  54.162  1
183934  94.053  -76.552  54.165  1
183935  94.066  -76.555  54.168  1
183936  94.078  -76.558  54.171  1
183937  94.105  -76.553  54.171  1
183938  94.124  -76.549  54.170  1
183939  94.138  -76.545  54.167  1
183940  94.152  -76.541  54.160  1
183941  94.168  -76.536  54.148  1
183942  94.184  -76.529  54.133  1
183943  94.200  -76.523  54.118  1
183944  94.216  -76.516  54.103  1
183945  94.232  -76.510  54.088  1
183946  94.249  -76.503  54.071  1
183947  94.266  -76.498  54.052  1
183948  94.285  -76.496  54.025  1
183949  94.305  -76.495  53.996  1
183950  94.325  -76.493  53.965  1
183951  94.345  -76.491  53.932  1
183952  94.362  -76.482  53.900  1
183953  94.380  -76.468  53.868  1
183954  94.397  -76.455  53.836  1
183955  94.414  -76.441  53.801  1
183956  94.430  -76.427  53.765  1
183957  94.448  -76.414  53.727  1
183958  94.470  -76.410  53.687  1
183959  94.496  -76.411  53.647  1
183960  94.524  -76.413  53.605  1
183961  94.556  -76.414  53.562  1
183962  94.588  -76.417  53.516  1
183963  94.620  -76.418  53.472  1
183964  94.652  -76.420  53.431  1
183965  94.680  -76.420  53.392  1
183966  94.697  -76.419  53.357  1
183967  94.714  -76.417  53.321  1
183968  94.731  -76.416  53.287  1
183969  94.748  -76.414  53.254  1
183970  94.764  -76.412  53.225  1
183971  94.769  -76.412  53.196  1
183972  94.766  -76.414  53.167  1
183973  94.762  -76.417  53.139  1
183974  94.758  -76.419  53.114  1
183975  94.754  -76.421  53.087  1
183976  94.750  -76.423  53.061  1
183977  94.746  -76.426  53.035  1
183978  94.742  -76.428  53.011  1
183979  94.738  -76.430  52.986  1
183980  94.734  -76.433  52.960  1
183981  94.730  -76.435  52.930  1
183982  94.726  -76.437  52.889  1
183983  94.722  -76.439  52.843  1
183984  94.718  -76.442  52.793  1
183985  94.714  -76.443  52.742  1
183986  94.710  -76.445  52.689  1
183987  94.706  -76.448  52.638  1
183988  94.709  -76.451  52.588  1
183989  94.718  -76.455  52.537  1
183990  94.767  -76.467  52.487  1
183991  94.818  -76.480  52.438  1
183992  94.869  -76.493  52.388  1
183993  94.920  -76.506  52.337  1
183994  94.971  -76.519  52.286  1
183995  95.022  -76.532  52.234  1
183996  95.062  -76.541  52.181  1
183997  95.102  -76.549  52.128  1
183998  95.140  -76.557  52.076  1
183999  95.180  -76.565  52.024  1
184000  95.212  -76.575  51.972  1
184001  95.227  -76.589  51.922  1
184002  95.241  -76.603  51.874  1
184003  95.256  -76.618  51.825  1
184004  95.270  -76.632  51.777  1
184005  95.284  -76.646  51.730  1
184006  95.315  -76.658  51.684  1
184007  95.356  -76.668  51.638  1
184008  95.398  -76.677  51.594  1
184009  95.440  -76.687  51.551  1
184010  95.481  -76.698  51.509  1
184011  95.523  -76.708  51.469  1
184012  95.561  -76.717  51.430  1
184013  95.545  -76.721  51.393  1
184014  95.552  -76.739  51.357  1
184015  95.559  -76.757  51.324  1
184016  95.566  -76.775  51.291  1
184017  95.573  -76.793  51.259  1
184018  95.581  -76.812  51.226  1
184019  95.588  -76.830  51.191  1
184020  95.595  -76.848  51.154  1
184021  95.602  -76.866  51.116  1
184022  95.609  -76.884  51.076  1
184023  95.616  -76.903  51.035  1
184024  95.629  -76.919  50.992  1
184025  95.658  -76.918  50.946  1
184026  95.688  -76.917  50.897  1
184027  95.718  -76.915  50.849  1
184028  95.748  -76.915  50.802  1
184029  95.778  -76.913  50.757  1
184030  95.808  -76.912  50.711  1
184031  95.839  -76.907  50.662  1
184032  95.872  -76.902  50.610  1
184033  95.903  -76.897  50.556  1
184034  95.931  -76.896  50.500  1
184035  95.956  -76.897  50.440  1
184036  95.982  -76.898  50.377  1
184037  96.007  -76.899  50.315  1
184038  96.028  -76.906  50.252  1
184039  96.042  -76.921  50.187  1
184040  96.055  -76.936  50.121  1
184041  96.068  -76.951  50.056  1
184042  96.082  -76.966  49.994  1
184043  96.096  -76.981  49.935  1
184044  96.114  -76.994  49.881  1
184045  96.139  -77.003  49.830  1
184046  96.164  -77.012  49.782  1
184047  96.187  -77.021  49.737  1
184048  96.177  -77.040  49.695  1
184049  96.167  -77.058  49.657  1
184050  96.157  -77.077  49.623  1
184051  96.147  -77.095  49.591  1
184052  96.136  -77.113  49.561  1
184053  96.136  -77.129  49.535  1
184054  96.165  -77.125  49.509  1
184055  96.182  -77.136  49.483  1
184056  96.203  -77.144  49.459  1
184057  96.233  -77.144  49.438  1
184058  96.264  -77.143  49.420  1
184059  96.294  -77.142  49.402  1
184060  96.324  -77.142  49.386  1
184061  96.355  -77.141  49.371  1
184062  96.385  -77.141  49.355  1
184063  96.415  -77.141  49.339  1
184064  96.446  -77.140  49.326  1
184065  96.476  -77.140  49.313  1
184066  96.507  -77.139  49.300  1
184067  96.537  -77.139  49.286  1
184068  96.558  -77.148  49.270  1
184069  96.579  -77.155  49.251  1
184070  96.599  -77.162  49.231  1
184071  96.619  -77.168  49.213  1
184072  96.640  -77.172  49.193  1
184073  96.660  -77.177  49.174  1
184074  96.680  -77.182  49.153  1
184075  96.700  -77.187  49.130  1
184076  96.716  -77.201  49.106  1
184077  96.732  -77.214  49.082  1
184078  96.782  -77.227  49.060  1
184079  96.796  -77.232  49.039  1
184080  96.810  -77.237  49.018  1
184081  96.824  -77.241  48.996  1
184082  96.839  -77.246  48.976  1
184083  96.853  -77.251  48.954  1
184084  96.867  -77.255  48.931  1
184085  96.882  -77.260  48.907  1
184086  96.896  -77.264  48.883  1
184087  96.910  -77.273  48.859  1
184088  96.925  -77.285  48.835  1
184089  96.939  -77.295  48.811  1
184090  96.954  -77.307  48.788  1
184091  96.928  -77.323  48.766  1
184092  96.944  -77.328  48.744  1
184093  96.983  -77.323  48.721  1
184094  97.057  -77.304  48.699  1
184095  97.089  -77.324  48.677  1
184096  97.118  -77.349  48.655  1
184097  97.148  -77.373  48.633  1
184098  97.172  -77.393  48.613  1
184099  97.196  -77.413  48.593  1
184100  97.221  -77.432  48.572  1
184101  97.246  -77.451  48.553  1
184102  97.270  -77.470  48.532  1
184103  97.295  -77.490  48.511  1
184104  97.319  -77.510  48.490  1
184105  97.344  -77.529  48.471  1
184106  97.360  -77.533  48.451  1
184107  97.365  -77.515  48.432  1
184108  97.371  -77.498  48.413  1
184109  97.376  -77.479  48.395  1
184110  97.381  -77.461  48.377  1
184111  97.386  -77.444  48.360  1
184112  97.391  -77.426  48.342  1
184113  97.404  -77.444  48.321  1
184114  97.418  -77.462  48.301  1
184115  97.431  -77.479  48.280  1
184116  97.444  -77.498  48.260  1
184117  97.457  -77.515  48.239  1
184118  97.470  -77.533  48.217  1
184119  97.486  -77.542  48.193  1
184120  97.500  -77.552  48.167  1
184121  97.519  -77.565  48.140  1
184122  97.546  -77.564  48.112  1
184123  97.573  -77.561  48.082  1
184124  97.600  -77.560  48.051  1
184125  97.628  -77.558  48.019  1
184126  97.655  -77.556  47.986  1
184127  97.688  -77.558  47.955  1
184128  97.734  -77.564  47.923  1
184129  97.780  -77.570  47.891  1
184130  97.824  -77.577  47.860  1
184131  97.861  -77.577  47.829  1
184132  97.898  -77.579  47.797  1
184133  97.935  -77.580  47.764  1
184134  97.972  -77.582  47.732  1
184135  98.009  -77.583  47.701  1
184136  98.046  -77.584  47.670  1
184137  98.080  -77.587  47.639  1
184138  98.091  -77.573  47.610  1
184139  98.100  -77.558  47.582  1
184140  98.109  -77.543  47.554  1
184141  98.119  -77.528  47.526  1
184142  98.128  -77.513  47.497  1
184143  98.138  -77.498  47.468  1
184144  98.147  -77.483  47.441  1
184145  98.156  -77.467  47.414  1
184146  98.165  -77.452  47.388  1
184147  98.175  -77.437  47.360  1
184148  98.184  -77.422  47.333  1
184149  98.205  -77.414  47.307  1
184150  98.254  -77.426  47.281  1
184151  98.304  -77.439  47.255  1
184152  98.354  -77.451  47.231  1
184153  98.404  -77.464  47.207  1
184154  98.428  -77.467  47.186  1
184155  98.448  -77.468  47.164  1
184156  98.468  -77.469  47.141  1
184157  98.488  -77.470  47.118  1
184158  98.508  -77.472  47.094  1
184159  98.528  -77.473  47.070  1
184160  98.549  -77.475  47.047  1
184161  98.569  -77.476  47.023  1
184162  98.563  -77.452  46.999  1
184163  98.566  -77.463  46.975  1
184164  98.572  -77.483  46.952  1
184165  98.579  -77.502  46.929  1
184166  98.589  -77.520  46.906  1
184167  98.602  -77.536  46.883  1
184168  98.616  -77.553  46.859  1
184169  98.627  -77.549  46.837  1
184170  98.639  -77.545  46.813  1
184171  98.650  -77.542  46.790  1
184172  98.669  -77.537  46.765  1
184173  98.688  -77.533  46.741  1
184174  98.708  -77.529  46.718  1
184175  98.727  -77.525  46.694  1
184176  98.746  -77.520  46.669  1
184177  98.766  -77.517  46.645  1
184178  98.785  -77.512  46.620  1
184179  98.804  -77.508  46.595  1
184180  98.822  -77.508  46.572  1
184181  98.837  -77.514  46.549  1
184182  98.851  -77.520  46.527  1
184183  98.866  -77.527  46.507  1
184184  98.880  -77.533  46.486  1
184185  98.889  -77.542  46.465  1
184186  98.886  -77.548  46.444  1
184187  98.885  -77.555  46.424  1
184188  98.883  -77.562  46.404  1
184189  98.940  -77.567  46.384  1
184190  98.959  -77.577  46.363  1
184191  98.979  -77.588  46.341  1
184192  98.999  -77.599  46.320  1
184193  99.018  -77.608  46.298  1
184194  99.032  -77.617  46.278  1
184195  99.030  -77.630  46.257  1
184196  99.021  -77.641  46.236  1
184197  98.992  -77.641  46.215  1
184198  99.001  -77.642  46.192  1
184199  99.011  -77.642  46.169  1
184200  99.021  -77.642  46.147  1
184201  99.031  -77.642  46.125  1
184202  99.041  -77.642  46.102  1
184203  99.051  -77.642  46.080  1
184204  99.061  -77.642  46.058  1
184205  99.071  -77.642  46.037  1
184206  99.081  -77.642  46.017  1
184207  99.091  -77.642  45.998  1
184208  99.104  -77.652  45.980  1
184209  99.127  -77.677  45.962  1
184210  99.150  -77.702  45.945  1
184211  99.152  -77.690  45.929  1
184212  99.167  -77.702  45.914  1
184213  99.191  -77.724  45.900  1
184214  99.229  -77.743  45.888  1
184215  99.268  -77.763  45.877  1
184216  99.306  -77.783  45.865  1
184217  99.345  -77.802  45.855  1
184218  99.383  -77.822  45.846  1
184219  99.421  -77.841  45.837  1
184220  99.460  -77.861  45.827  1
184221  99.498  -77.881  45.817  1
184222  99.537  -77.900  45.806  1
184223  99.575  -77.919  45.795  1
184224  99.614  -77.939  45.785  1
184225  99.652  -77.959  45.774  1
184226  99.687  -77.975  45.762  1
184227  99.708  -77.982  45.751  1
184228  99.733  -77.972  45.741  1
184229  99.751  -77.982  45.731  1
184230  99.768  -77.992  45.721  1
184231  99.786  -78.002  45.712  1
184232  99.803  -78.012  45.703  1
184233  99.821  -78.022  45.692  1
184234  99.838  -78.032  45.681  1
184235  99.856  -78.042  45.669  1
184236  99.873  -78.052  45.660  1
184237  99.891  -78.059  45.650  1
184238  99.907  -78.062  45.639  1
184239  99.925  -78.070  45.625  1
184240  99.946  -78.081  45.612  1
184241  99.977  -78.086  45.599  1
184242  100.005  -78.099  45.585  1
184243  100.039  -78.108  45.570  1
184244  100.071  -78.116  45.556  1
184245  100.104  -78.125  45.541  1
184246  100.137  -78.133  45.527  1
184247  100.170  -78.142  45.511  1
184248  100.203  -78.150  45.496  1
184249  100.235  -78.159  45.480  1
184250  100.298  -78.102  45.466  1
184251  100.302  -78.119  45.452  1
184252  100.308  -78.134  45.438  1
184253  100.314  -78.152  45.425  1
184254  100.320  -78.169  45.412  1
184255  100.327  -78.185  45.397  1
184256  100.334  -78.203  45.382  1
184257  100.340  -78.219  45.366  1
184258  100.347  -78.237  45.351  1
184259  100.353  -78.253  45.335  1
184260  100.360  -78.270  45.320  1
184261  100.378  -78.281  45.304  1
184262  100.400  -78.288  45.288  1
184263  100.432  -78.291  45.272  1
184264  100.473  -78.291  45.256  1
184265  100.515  -78.292  45.240  1
184266  100.557  -78.292  45.223  1
184267  100.599  -78.292  45.208  1
184268  100.642  -78.295  45.192  1
184269  100.690  -78.303  45.177  1
184270  100.737  -78.310  45.162  1
184271  100.783  -78.319  45.148  1
184272  100.830  -78.326  45.134  1
184273  100.877  -78.334  45.119  1
184274  100.924  -78.341  45.105  1
184275  100.971  -78.349  45.090  1
184276  101.018  -78.357  45.075  1
184277  101.051  -78.363  45.059  1
184278  101.078  -78.370  45.044  1
184279  101.105  -78.377  45.028  1
184280  101.132  -78.384  45.011  1
184281  101.158  -78.391  44.995  1
184282  101.174  -78.402  44.978  1
184283  101.190  -78.411  44.962  1
184284  101.205  -78.420  44.946  1
184285  101.220  -78.428  44.930  1
184286  101.236  -78.435  44.914  1
184287  101.252  -78.444  44.898  1
184288  101.267  -78.452  44.882  1
184289  101.282  -78.460  44.866  1
184290  101.299  -78.470  44.850  1
184291  101.329  -78.486  44.834  1
184292  101.358  -78.504  44.818  1
184293  101.388  -78.521  44.802  1
184294  101.418  -78.544  44.786  1
184295  101.448  -78.567  44.771  1
184296  101.476  -78.590  44.755  1
184297  101.499  -78.617  44.738  1
184298  101.522  -78.645  44.722  1
184299  101.545  -78.672  44.706  1
184300  101.568  -78.705  44.690  1
184301  101.591  -78.737  44.674  1
184302  101.607  -78.753  44.658  1
184303  101.618  -78.756  44.644  1
184304  101.648  -78.774  44.630  1
184305  101.687  -78.799  44.615  1
184306  101.726  -78.825  44.601  1
184307  101.764  -78.850  44.586  1
184308  101.803  -78.875  44.571  1
184309  101.842  -78.901  44.557  1
184310  101.841  -78.959  44.543  1
184311  101.859  -78.965  44.529  1
184312  101.878  -78.971  44.515  1
184313  101.896  -78.977  44.502  1
184314  101.914  -78.984  44.488  1
184315  101.933  -78.990  44.475  1
184316  101.951  -78.996  44.462  1
184317  101.969  -79.002  44.449  1
184318  101.987  -79.009  44.437  1
184319  102.006  -79.015  44.425  1
184320  102.024  -79.021  44.412  1
184582  93.125  -76.654  54.104  1
184583  93.144  -76.651  54.113  1
184584  93.163  -76.648  54.120  1
184585  93.183  -76.644  54.127  1
184586  93.202  -76.641  54.133  1
184587  93.221  -76.638  54.138  1
184588  93.240  -76.635  54.141  1
184589  93.260  -76.632  54.144  1
184590  93.279  -76.629  54.147  1
184591  93.299  -76.626  54.149  1
184592  93.319  -76.623  54.151  1
184593  93.338  -76.620  54.153  1
184594  93.357  -76.617  54.153  1
184595  93.377  -76.614  54.153  1
184596  93.396  -76.611  54.153  1
184597  93.425  -76.607  54.154  1
184598  93.451  -76.605  54.155  1
184599  93.470  -76.608  54.156  1
184600  93.488  -76.611  54.157  1
184601  93.507  -76.614  54.157  1
184602  93.525  -76.617  54.157  1
184603  93.543  -76.620  54.157  1
184604  93.562  -76.623  54.158  1
184605  93.580  -76.626  54.159  1
184606  93.599  -76.629  54.162  1
184607  93.620  -76.620  54.165  1
184608  93.641  -76.610  54.167  1
184609  93.662  -76.600  54.171  1
184610  93.683  -76.590  54.175  1
184611  93.704  -76.580  54.180  1
184612  93.725  -76.571  54.185  1
184613  93.735  -76.560  54.192  1
184614  93.728  -76.537  54.199  1
184615  93.738  -76.530  54.203  1
184616  93.748  -76.522  54.207  1
184617  93.767  -76.526  54.212  1
184618  93.794  -76.539  54.217  1
184619  93.818  -76.550  54.222  1
184620  93.834  -76.551  54.226  1
184621  93.849  -76.552  54.228  1
184622  93.864  -76.552  54.227  1
184623  93.879  -76.553  54.223  1
184624  93.895  -76.550  54.217  1
184625  93.911  -76.546  54.209  1
184626  93.927  -76.540  54.202  1
184627  93.938  -76.536  54.195  1
184628  93.942  -76.533  54.188  1
184629  93.948  -76.531  54.180  1
184630  93.963  -76.532  54.173  1
184631  93.978  -76.533  54.168  1
184632  93.993  -76.533  54.164  1
184633  94.007  -76.534  54.162  1
184634  94.019  -76.537  54.166  1
184635  94.031  -76.540  54.168  1
184636  94.043  -76.543  54.169  1
184637  94.068  -76.540  54.172  1
184638  94.096  -76.535  54.173  1
184639  94.123  -76.530  54.172  1
184640  94.137  -76.526  54.170  1
184641  94.151  -76.522  54.165  1
184642  94.167  -76.517  54.155  1
184643  94.183  -76.511  54.142  1
184644  94.199  -76.504  54.127  1
184645  94.215  -76.498  54.113  1
184646  94.231  -76.491  54.097  1
184647  94.248  -76.485  54.079  1
184648  94.267  -76.482  54.060  1
184649  94.286  -76.480  54.033  1
184650  94.306  -76.479  54.003  1
184651  94.326  -76.477  53.972  1
184652  94.346  -76.476  53.941  1
184653  94.365  -76.473  53.908  1
184654  94.382  -76.460  53.876  1
184655  94.399  -76.446  53.843  1
184656  94.416  -76.433  53.807  1
184657  94.433  -76.419  53.771  1
184658  94.450  -76.406  53.734  1
184659  94.475  -76.405  53.694  1
184660  94.501  -76.408  53.653  1
184661  94.528  -76.409  53.611  1
184662  94.554  -76.411  53.568  1
184663  94.580  -76.412  53.525  1
184664  94.606  -76.414  53.485  1
184665  94.638  -76.416  53.447  1
184666  94.670  -76.417  53.411  1
184667  94.688  -76.416  53.374  1
184668  94.704  -76.414  53.337  1
184669  94.721  -76.412  53.301  1
184670  94.738  -76.410  53.266  1
184671  94.754  -76.408  53.235  1
184672  94.761  -76.408  53.205  1
184673  94.757  -76.410  53.176  1
184674  94.753  -76.412  53.147  1
184675  94.749  -76.414  53.121  1
184676  94.745  -76.417  53.095  1
184677  94.741  -76.419  53.069  1
184678  94.737  -76.421  53.045  1
184679  94.733  -76.423  53.024  1
184680  94.729  -76.426  53.002  1
184681  94.725  -76.428  52.978  1
184682  94.721  -76.430  52.950  1
184683  94.717  -76.433  52.911  1
184684  94.713  -76.435  52.866  1
184685  94.709  -76.437  52.817  1
184686  94.705  -76.439  52.765  1
184687  94.701  -76.442  52.711  1
184688  94.709  -76.445  52.658  1
184689  94.718  -76.449  52.606  1
184690  94.728  -76.453  52.554  1
184691  94.754  -76.461  52.505  1
184692  94.805  -76.473  52.456  1
184693  94.856  -76.486  52.405  1
184694  94.907  -76.499  52.352  1
184695  94.958  -76.512  52.299  1
184696  95.007  -76.525  52.247  1
184697  95.047  -76.533  52.196  1
184698  95.086  -76.541  52.145  1
184699  95.125  -76.549  52.095  1
184700  95.164  -76.558  52.044  1
184701  95.203  -76.565  51.992  1
184702  95.221  -76.579  51.944  1
184703  95.236  -76.593  51.896  1
184704  95.250  -76.608  51.845  1
184705  95.264  -76.621  51.797  1
184706  95.279  -76.636  51.750  1
184707  95.318  -76.646  51.703  1
184708  95.360  -76.656  51.658  1
184709  95.402  -76.666  51.612  1
184710  95.444  -76.676  51.569  1
184711  95.485  -76.686  51.527  1
184712  95.527  -76.696  51.486  1
184713  95.569  -76.705  51.446  1
184714  95.568  -76.712  51.409  1
184715  95.576  -76.730  51.373  1
184716  95.583  -76.748  51.340  1
184717  95.590  -76.766  51.307  1
184718  95.597  -76.784  51.274  1
184719  95.604  -76.802  51.241  1
184720  95.611  -76.821  51.205  1
184721  95.618  -76.839  51.167  1
184722  95.620  -76.856  51.129  1
184723  95.617  -76.871  51.088  1
184724  95.613  -76.887  51.047  1
184725  95.631  -76.894  51.004  1
184726  95.659  -76.897  50.958  1
184727  95.688  -76.897  50.909  1
184728  95.718  -76.895  50.862  1
184729  95.748  -76.893  50.817  1
184730  95.778  -76.892  50.774  1
184731  95.808  -76.890  50.728  1
184732  95.840  -76.885  50.680  1
184733  95.872  -76.880  50.628  1
184734  95.899  -76.880  50.575  1
184735  95.924  -76.881  50.518  1
184736  95.950  -76.882  50.458  1
184737  95.975  -76.884  50.396  1
184738  96.001  -76.884  50.336  1
184739  96.023  -76.890  50.275  1
184740  96.036  -76.905  50.211  1
184741  96.050  -76.920  50.145  1
184742  96.063  -76.935  50.081  1
184743  96.077  -76.950  50.018  1
184744  96.095  -76.962  49.959  1
184745  96.120  -76.972  49.904  1
184746  96.146  -76.980  49.853  1
184747  96.171  -76.989  49.805  1
184748  96.184  -77.001  49.760  1
184749  96.174  -77.019  49.719  1
184750  96.164  -77.038  49.681  1
184751  96.154  -77.056  49.647  1
184752  96.144  -77.075  49.615  1
184753  96.142  -77.091  49.585  1
184754  96.151  -77.105  49.559  1
184755  96.161  -77.119  49.533  1
184756  96.214  -77.094  49.508  1
184757  96.228  -77.108  49.484  1
184758  96.242  -77.122  49.464  1
184759  96.266  -77.125  49.446  1
184760  96.297  -77.125  49.429  1
184761  96.327  -77.125  49.413  1
184762  96.358  -77.125  49.398  1
184763  96.388  -77.124  49.382  1
184764  96.418  -77.123  49.366  1
184765  96.449  -77.123  49.353  1
184766  96.479  -77.122  49.340  1
184767  96.510  -77.122  49.327  1
184768  96.540  -77.115  49.312  1
184769  96.558  -77.131  49.295  1
184770  96.577  -77.144  49.275  1
184771  96.597  -77.151  49.255  1
184772  96.617  -77.158  49.235  1
184773  96.637  -77.165  49.216  1
184774  96.657  -77.172  49.196  1
184775  96.677  -77.178  49.175  1
184776  96.697  -77.184  49.151  1
184777  96.718  -77.188  49.126  1
184778  96.734  -77.201  49.102  1
184779  96.764  -77.209  49.079  1
184780  96.779  -77.213  49.057  1
184781  96.793  -77.218  49.035  1
184782  96.807  -77.222  49.013  1
184783  96.821  -77.227  48.991  1
184784  96.835  -77.232  48.969  1
184785  96.850  -77.237  48.945  1
184786  96.864  -77.241  48.921  1
184787  96.878  -77.246  48.897  1
184788  96.892  -77.251  48.872  1
184789  96.907  -77.260  48.848  1
184790  96.922  -77.272  48.823  1
184791  96.936  -77.282  48.800  1
184792  96.951  -77.294  48.777  1
184793  96.947  -77.307  48.756  1
184794  96.979  -77.305  48.733  1
184795  97.054  -77.285  48.710  1
184796  97.093  -77.299  48.687  1
184797  97.120  -77.321  48.665  1
184798  97.144  -77.341  48.643  1
184799  97.169  -77.360  48.621  1
184800  97.193  -77.379  48.600  1
184801  97.218  -77.398  48.579  1
184802  97.242  -77.418  48.560  1
184803  97.266  -77.438  48.539  1
184804  97.291  -77.457  48.519  1
184805  97.315  -77.476  48.498  1
184806  97.340  -77.495  48.478  1
184807  97.364  -77.515  48.458  1
184808  97.371  -77.501  48.439  1
184809  97.377  -77.483  48.420  1
184810  97.382  -77.464  48.402  1
184811  97.387  -77.447  48.384  1
184812  97.392  -77.429  48.366  1
184813  97.400  -77.425  48.348  1
184814  97.414  -77.443  48.328  1
184815  97.427  -77.461  48.307  1
184816  97.440  -77.479  48.287  1
184817  97.453  -77.497  48.266  1
184818  97.466  -77.514  48.245  1
184819  97.479  -77.533  48.223  1
184820  97.494  -77.547  48.199  1
184821  97.508  -77.557  48.173  1
184822  97.525  -77.552  48.146  1
184823  97.555  -77.556  48.116  1
184824  97.582  -77.555  48.086  1
184825  97.609  -77.553  48.056  1
184826  97.637  -77.551  48.024  1
184827  97.664  -77.549  47.991  1
184828  97.702  -77.552  47.959  1
184829  97.747  -77.558  47.928  1
184830  97.787  -77.562  47.897  1
184831  97.824  -77.563  47.866  1
184832  97.861  -77.564  47.835  1
184833  97.898  -77.566  47.802  1
184834  97.935  -77.567  47.770  1
184835  97.972  -77.569  47.737  1
184836  98.009  -77.570  47.706  1
184837  98.046  -77.567  47.674  1
184838  98.083  -77.564  47.643  1
184839  98.097  -77.559  47.614  1
184840  98.107  -77.544  47.585  1
184841  98.116  -77.529  47.558  1
184842  98.126  -77.514  47.530  1
184843  98.135  -77.498  47.501  1
184844  98.144  -77.483  47.473  1
184845  98.154  -77.468  47.445  1
184846  98.163  -77.453  47.417  1
184847  98.172  -77.438  47.389  1
184848  98.181  -77.423  47.362  1
184849  98.191  -77.407  47.335  1
184850  98.201  -77.392  47.308  1
184851  98.245  -77.401  47.282  1
184852  98.295  -77.414  47.257  1
184853  98.345  -77.426  47.232  1
184854  98.394  -77.439  47.209  1
184855  98.444  -77.451  47.187  1
184856  98.472  -77.455  47.165  1
184857  98.492  -77.457  47.143  1
184858  98.512  -77.457  47.120  1
184859  98.532  -77.459  47.098  1
184860  98.552  -77.461  47.075  1
184861  98.572  -77.462  47.053  1
184862  98.572  -77.443  47.029  1
184863  98.567  -77.438  47.005  1
184864  98.573  -77.457  46.982  1
184865  98.581  -77.476  46.958  1
184866  98.594  -77.493  46.934  1
184867  98.607  -77.510  46.911  1
184868  98.621  -77.526  46.888  1
184869  98.633  -77.536  46.865  1
184870  98.645  -77.532  46.841  1
184871  98.656  -77.527  46.818  1
184872  98.668  -77.523  46.794  1
184873  98.679  -77.520  46.769  1
184874  98.697  -77.516  46.746  1
184875  98.717  -77.511  46.723  1
184876  98.736  -77.507  46.700  1
184877  98.755  -77.503  46.675  1
184878  98.775  -77.498  46.651  1
184879  98.794  -77.495  46.626  1
184880  98.813  -77.490  46.601  1
184881  98.831  -77.491  46.578  1
184882  98.845  -77.498  46.556  1
184883  98.860  -77.504  46.534  1
184884  98.874  -77.511  46.513  1
184885  98.887  -77.517  46.491  1
184886  98.880  -77.529  46.471  1
184887  98.874  -77.539  46.450  1
184888  98.873  -77.545  46.429  1
184889  98.896  -77.551  46.409  1
184890  98.960  -77.558  46.388  1
184891  98.980  -77.568  46.367  1
184892  98.999  -77.578  46.345  1
184893  99.019  -77.587  46.323  1
184894  99.038  -77.595  46.301  1
184895  99.037  -77.608  46.281  1
184896  99.035  -77.622  46.260  1
184897  99.034  -77.635  46.238  1
184898  99.010  -77.639  46.216  1
184899  99.006  -77.639  46.195  1
184900  99.016  -77.639  46.172  1
184901  99.026  -77.640  46.149  1
184902  99.036  -77.640  46.127  1
184903  99.046  -77.640  46.105  1
184904  99.056  -77.640  46.083  1
184905  99.066  -77.640  46.061  1
184906  99.076  -77.640  46.041  1
184907  99.086  -77.640  46.020  1
184908  99.095  -77.643  46.001  1
184909  99.104  -77.647  45.983  1
184910  99.113  -77.652  45.965  1
184911  99.125  -77.660  45.948  1
184912  99.140  -77.672  45.932  1
184913  99.164  -77.689  45.916  1
184914  99.202  -77.708  45.902  1
184915  99.241  -77.728  45.889  1
184916  99.279  -77.748  45.878  1
184917  99.318  -77.768  45.867  1
184918  99.356  -77.787  45.857  1
184919  99.395  -77.806  45.847  1
184920  99.433  -77.826  45.837  1
184921  99.472  -77.846  45.828  1
184922  99.510  -77.865  45.817  1
184923  99.549  -77.884  45.806  1
184924  99.587  -77.904  45.794  1
184925  99.626  -77.924  45.783  1
184926  99.664  -77.943  45.772  1
184927  99.703  -77.962  45.760  1
184928  99.726  -77.971  45.749  1
184929  99.743  -77.975  45.738  1
184930  99.759  -77.979  45.729  1
184931  99.775  -77.984  45.719  1
184932  99.792  -77.987  45.709  1
184933  99.808  -77.991  45.700  1
184934  99.824  -77.996  45.690  1
184935  99.841  -78.000  45.679  1
184936  99.860  -78.009  45.667  1
184937  99.881  -78.021  45.658  1
184938  99.902  -78.033  45.648  1
184939  99.923  -78.044  45.636  1
184940  99.943  -78.056  45.623  1
184941  99.970  -78.064  45.610  1
184942  100.000  -78.069  45.597  1
184943  100.030  -78.075  45.583  1
184944  100.060  -78.080  45.568  1
184945  100.075  -78.103  45.554  1
184946  100.108  -78.111  45.540  1
184947  100.141  -78.119  45.526  1
184948  100.174  -78.128  45.511  1
184949  100.207  -78.137  45.496  1
184950  100.240  -78.145  45.481  1
184951  100.301  -78.094  45.467  1
184952  100.317  -78.097  45.453  1
184953  100.322  -78.113  45.439  1
184954  100.329  -78.130  45.426  1
184955  100.336  -78.147  45.413  1
184956  100.342  -78.164  45.398  1
184957  100.349  -78.181  45.382  1
184958  100.355  -78.198  45.367  1
184959  100.362  -78.215  45.352  1
184960  100.368  -78.232  45.337  1
184961  100.375  -78.249  45.322  1
184962  100.385  -78.263  45.306  1
184963  100.409  -78.271  45.290  1
184964  100.440  -78.275  45.274  1
184965  100.482  -78.275  45.258  1
184966  100.524  -78.275  45.242  1
184967  100.566  -78.275  45.226  1
184968  100.608  -78.275  45.211  1
184969  100.654  -78.282  45.196  1
184970  100.701  -78.290  45.180  1
184971  100.748  -78.297  45.165  1
184972  100.794  -78.305  45.151  1
184973  100.841  -78.313  45.136  1
184974  100.888  -78.320  45.122  1
184975  100.935  -78.329  45.107  1
184976  100.979  -78.335  45.093  1
184977  101.016  -78.341  45.078  1
184978  101.055  -78.348  45.062  1
184979  101.085  -78.355  45.046  1
184980  101.112  -78.361  45.030  1
184981  101.139  -78.368  45.013  1
184982  101.165  -78.376  44.997  1
184983  101.181  -78.386  44.981  1
184984  101.196  -78.397  44.965  1
184985  101.212  -78.407  44.950  1
184986  101.228  -78.418  44.934  1
184987  101.244  -78.429  44.918  1
184988  101.260  -78.440  44.902  1
184989  101.276  -78.451  44.885  1
184990  101.291  -78.459  44.869  1
184991  101.307  -78.467  44.854  1
184992  101.324  -78.477  44.838  1
184993  101.354  -78.494  44.822  1
184994  101.384  -78.517  44.806  1
184995  101.414  -78.539  44.789  1
184996  101.444  -78.563  44.773  1
184997  101.473  -78.586  44.758  1
184998  101.499  -78.611  44.741  1
184999  101.523  -78.637  44.725  1
185000  101.545  -78.665  44.710  1
185001  101.568  -78.698  44.694  1
185002  101.589  -78.725  44.678  1
185003  101.600  -78.728  44.661  1
185004  101.631  -78.747  44.647  1
185005  101.670  -78.773  44.632  1
185006  101.709  -78.798  44.618  1
185007  101.748  -78.823  44.604  1
185008  101.786  -78.849  44.589  1
185009  101.825  -78.874  44.574  1
185010  101.864  -78.899  44.560  1
185011  101.859  -78.967  44.545  1
185012  101.878  -78.973  44.531  1
185013  101.896  -78.979  44.517  1
185014  101.914  -78.986  44.503  1
185015  101.933  -78.992  44.490  1
185016  101.951  -78.998  44.476  1
185017  101.969  -79.004  44.463  1
185018  101.988  -79.010  44.451  1
185019  102.006  -79.016  44.438  1
185020  102.024  -79.023  44.426  1
185021  102.042  -79.029  44.414  1
185291  93.269  -76.605  54.138  1
185292  93.288  -76.602  54.141  1
185293  93.308  -76.599  54.142  1
185294  93.328  -76.596  54.144  1
185295  93.347  -76.593  54.145  1
185296  93.366  -76.590  54.145  1
185297  93.387  -76.587  54.146  1
185298  93.418  -76.583  54.146  1
185299  93.443  -76.582  54.147  1
185300  93.462  -76.585  54.147  1
185301  93.480  -76.588  54.148  1
185302  93.499  -76.590  54.148  1
185303  93.517  -76.593  54.147  1
185304  93.535  -76.596  54.148  1
185305  93.554  -76.599  54.148  1
185306  93.572  -76.602  54.149  1
185307  93.590  -76.605  54.151  1
185308  93.609  -76.608  54.154  1
185309  93.629  -76.600  54.156  1
185310  93.650  -76.591  54.159  1
185311  93.672  -76.581  54.163  1
185312  93.693  -76.571  54.168  1
185313  93.714  -76.561  54.175  1
185314  93.735  -76.552  54.184  1
185315  93.737  -76.539  54.194  1
185316  93.719  -76.507  54.199  1
185317  93.730  -76.501  54.205  1
185318  93.757  -76.514  54.211  1
185319  93.784  -76.528  54.217  1
185320  93.811  -76.542  54.222  1
185321  93.827  -76.542  54.229  1
185322  93.842  -76.543  54.233  1
185323  93.857  -76.543  54.233  1
185324  93.873  -76.539  54.232  1
185325  93.890  -76.533  54.228  1
185326  93.906  -76.529  54.222  1
185327  93.922  -76.524  54.213  1
185328  93.929  -76.520  54.207  1
185329  93.932  -76.517  54.200  1
185330  93.936  -76.514  54.192  1
185331  93.948  -76.514  54.184  1
185332  93.960  -76.517  54.176  1
185333  93.972  -76.520  54.171  1
185334  93.984  -76.523  54.167  1
185335  93.996  -76.527  54.168  1
185336  94.008  -76.530  54.168  1
185337  94.031  -76.527  54.167  1
185338  94.059  -76.522  54.168  1
185339  94.087  -76.517  54.170  1
185340  94.116  -76.511  54.171  1
185341  94.136  -76.507  54.170  1
185342  94.150  -76.503  54.167  1
185343  94.165  -76.498  54.159  1
185344  94.181  -76.492  54.148  1
185345  94.198  -76.485  54.135  1
185346  94.214  -76.479  54.121  1
185347  94.230  -76.472  54.104  1
185348  94.248  -76.468  54.085  1
185349  94.268  -76.467  54.066  1
185350  94.287  -76.465  54.039  1
185351  94.307  -76.463  54.010  1
185352  94.327  -76.461  53.979  1
185353  94.347  -76.460  53.950  1
185354  94.366  -76.458  53.917  1
185355  94.385  -76.451  53.883  1
185356  94.402  -76.438  53.849  1
185357  94.419  -76.425  53.813  1
185358  94.436  -76.411  53.776  1
185359  94.454  -76.400  53.738  1
185360  94.480  -76.401  53.700  1
185361  94.506  -76.403  53.659  1
185362  94.533  -76.404  53.618  1
185363  94.559  -76.407  53.577  1
185364  94.585  -76.408  53.534  1
185365  94.611  -76.410  53.497  1
185366  94.638  -76.412  53.462  1
185367  94.662  -76.412  53.426  1
185368  94.678  -76.412  53.390  1
185369  94.694  -76.411  53.352  1
185370  94.711  -76.408  53.315  1
185371  94.727  -76.406  53.279  1
185372  94.744  -76.404  53.246  1
185373  94.752  -76.404  53.215  1
185374  94.748  -76.406  53.185  1
185375  94.744  -76.408  53.156  1
185376  94.740  -76.411  53.130  1
185377  94.736  -76.413  53.104  1
185378  94.732  -76.415  53.079  1
185379  94.728  -76.417  53.056  1
185380  94.724  -76.420  53.036  1
185381  94.720  -76.422  53.015  1
185382  94.716  -76.424  52.991  1
185383  94.712  -76.426  52.964  1
185384  94.708  -76.428  52.928  1
185385  94.704  -76.430  52.885  1
185386  94.700  -76.433  52.837  1
185387  94.700  -76.436  52.785  1
185388  94.709  -76.439  52.731  1
185389  94.718  -76.443  52.678  1
185390  94.728  -76.447  52.626  1
185391  94.737  -76.451  52.574  1
185392  94.746  -76.455  52.523  1
185393  94.791  -76.467  52.472  1
185394  94.842  -76.480  52.421  1
185395  94.893  -76.492  52.368  1
185396  94.944  -76.505  52.315  1
185397  94.992  -76.517  52.261  1
185398  95.031  -76.525  52.209  1
185399  95.070  -76.533  52.159  1
185400  95.110  -76.542  52.109  1
185401  95.148  -76.549  52.060  1
185402  95.188  -76.558  52.011  1
185403  95.215  -76.569  51.965  1
185404  95.230  -76.583  51.918  1
185405  95.245  -76.597  51.869  1
185406  95.259  -76.611  51.821  1
185407  95.280  -76.624  51.772  1
185408  95.322  -76.634  51.724  1
185409  95.364  -76.644  51.679  1
185410  95.405  -76.654  51.633  1
185411  95.447  -76.664  51.589  1
185412  95.489  -76.674  51.546  1
185413  95.531  -76.684  51.504  1
185414  95.572  -76.694  51.463  1
185415  95.592  -76.702  51.425  1
185416  95.599  -76.720  51.389  1
185417  95.606  -76.738  51.355  1
185418  95.613  -76.756  51.321  1
185419  95.618  -76.774  51.288  1
185420  95.614  -76.790  51.254  1
185421  95.610  -76.806  51.218  1
185422  95.607  -76.822  51.179  1
185423  95.603  -76.838  51.139  1
185424  95.599  -76.853  51.098  1
185425  95.607  -76.865  51.057  1
185426  95.635  -76.867  51.013  1
185427  95.663  -76.870  50.967  1
185428  95.690  -76.872  50.920  1
185429  95.718  -76.875  50.876  1
185430  95.748  -76.873  50.833  1
185431  95.778  -76.871  50.789  1
185432  95.809  -76.868  50.745  1
185433  95.840  -76.864  50.697  1
185434  95.867  -76.864  50.646  1
185435  95.892  -76.865  50.593  1
185436  95.918  -76.866  50.534  1
185437  95.943  -76.868  50.474  1
185438  95.969  -76.868  50.415  1
185439  95.994  -76.870  50.358  1
185440  96.017  -76.874  50.298  1
185441  96.031  -76.889  50.236  1
185442  96.044  -76.904  50.171  1
185443  96.058  -76.919  50.105  1
185444  96.077  -76.931  50.041  1
185445  96.102  -76.940  49.982  1
185446  96.127  -76.949  49.927  1
185447  96.152  -76.958  49.876  1
185448  96.177  -76.966  49.829  1
185449  96.182  -76.981  49.785  1
185450  96.172  -77.000  49.745  1
185451  96.162  -77.018  49.707  1
185452  96.152  -77.037  49.672  1
185453  96.147  -77.053  49.640  1
185454  96.157  -77.067  49.610  1
185455  96.166  -77.081  49.583  1
185456  96.176  -77.094  49.557  1
185457  96.245  -77.052  49.533  1
185458  96.259  -77.066  49.511  1
185459  96.273  -77.079  49.491  1
185460  96.288  -77.093  49.473  1
185461  96.302  -77.106  49.456  1
185462  96.330  -77.108  49.441  1
185463  96.361  -77.107  49.426  1
185464  96.391  -77.106  49.410  1
185465  96.421  -77.106  49.394  1
185466  96.452  -77.106  49.382  1
185467  96.482  -77.106  49.368  1
185468  96.512  -77.105  49.354  1
185469  96.542  -77.089  49.340  1
185470  96.559  -77.113  49.321  1
185471  96.575  -77.135  49.300  1
185472  96.595  -77.141  49.279  1
185473  96.615  -77.147  49.258  1
185474  96.636  -77.154  49.238  1
185475  96.656  -77.161  49.217  1
185476  96.676  -77.168  49.196  1
185477  96.695  -77.175  49.173  1
185478  96.716  -77.182  49.147  1
185479  96.736  -77.188  49.122  1
185480  96.747  -77.191  49.098  1
185481  96.761  -77.195  49.076  1
185482  96.775  -77.200  49.053  1
185483  96.789  -77.204  49.031  1
185484  96.804  -77.209  49.007  1
185485  96.818  -77.213  48.984  1
185486  96.832  -77.218  48.960  1
185487  96.847  -77.222  48.937  1
185488  96.861  -77.227  48.912  1
185489  96.875  -77.232  48.886  1
185490  96.889  -77.237  48.861  1
185491  96.904  -77.248  48.837  1
185492  96.918  -77.258  48.812  1
185493  96.933  -77.269  48.790  1
185494  96.947  -77.281  48.768  1
185495  96.984  -77.279  48.745  1
185496  97.061  -77.260  48.721  1
185497  97.093  -77.270  48.697  1
185498  97.116  -77.288  48.675  1
185499  97.141  -77.307  48.653  1
185500  97.165  -77.327  48.630  1
185501  97.189  -77.346  48.608  1
185502  97.214  -77.366  48.587  1
185503  97.238  -77.385  48.566  1
185504  97.263  -77.404  48.546  1
185505  97.288  -77.423  48.526  1
185506  97.312  -77.443  48.506  1
185507  97.336  -77.462  48.486  1
185508  97.361  -77.482  48.467  1
185509  97.377  -77.486  48.447  1
185510  97.382  -77.467  48.428  1
185511  97.388  -77.450  48.409  1
185512  97.393  -77.432  48.391  1
185513  97.398  -77.414  48.373  1
185514  97.409  -77.424  48.353  1
185515  97.423  -77.442  48.333  1
185516  97.436  -77.460  48.313  1
185517  97.449  -77.478  48.293  1
185518  97.462  -77.496  48.271  1
185519  97.475  -77.514  48.249  1
185520  97.489  -77.532  48.227  1
185521  97.502  -77.549  48.203  1
185522  97.493  -77.517  48.177  1
185523  97.523  -77.523  48.149  1
185524  97.555  -77.529  48.120  1
185525  97.585  -77.535  48.090  1
185526  97.616  -77.541  48.059  1
185527  97.646  -77.544  48.028  1
185528  97.673  -77.542  47.995  1
185529  97.714  -77.546  47.964  1
185530  97.750  -77.548  47.933  1
185531  97.787  -77.548  47.902  1
185532  97.824  -77.546  47.871  1
185533  97.862  -77.542  47.839  1
185534  97.898  -77.539  47.806  1
185535  97.936  -77.536  47.773  1
185536  97.973  -77.532  47.740  1
185537  98.010  -77.528  47.708  1
185538  98.047  -77.525  47.676  1
185539  98.084  -77.521  47.646  1
185540  98.101  -77.517  47.618  1
185541  98.111  -77.513  47.590  1
185542  98.122  -77.508  47.562  1
185543  98.132  -77.500  47.535  1
185544  98.142  -77.485  47.506  1
185545  98.151  -77.470  47.478  1
185546  98.160  -77.454  47.449  1
185547  98.169  -77.439  47.421  1
185548  98.179  -77.424  47.394  1
185549  98.189  -77.409  47.367  1
185550  98.198  -77.394  47.340  1
185551  98.207  -77.379  47.313  1
185552  98.236  -77.377  47.286  1
185553  98.286  -77.389  47.260  1
185554  98.336  -77.401  47.235  1
185555  98.385  -77.414  47.212  1
185556  98.435  -77.426  47.190  1
185557  98.484  -77.439  47.167  1
185558  98.515  -77.444  47.145  1
185559  98.535  -77.445  47.123  1
185560  98.556  -77.447  47.100  1
185561  98.576  -77.448  47.079  1
185562  98.581  -77.435  47.057  1
185563  98.568  -77.413  47.034  1
185564  98.574  -77.432  47.011  1
185565  98.585  -77.450  46.988  1
185566  98.599  -77.466  46.964  1
185567  98.612  -77.483  46.940  1
185568  98.626  -77.498  46.916  1
185569  98.639  -77.515  46.893  1
185570  98.651  -77.517  46.870  1
185571  98.662  -77.514  46.846  1
185572  98.674  -77.510  46.822  1
185573  98.686  -77.506  46.798  1
185574  98.697  -77.501  46.773  1
185575  98.708  -77.498  46.750  1
185576  98.725  -77.494  46.727  1
185577  98.745  -77.489  46.704  1
185578  98.764  -77.486  46.680  1
185579  98.784  -77.481  46.656  1
185580  98.803  -77.476  46.632  1
185581  98.822  -77.473  46.607  1
185582  98.839  -77.474  46.584  1
185583  98.854  -77.481  46.562  1
185584  98.868  -77.487  46.540  1
185585  98.883  -77.494  46.519  1
185586  98.878  -77.504  46.498  1
185587  98.871  -77.516  46.477  1
185588  98.864  -77.527  46.456  1
185589  98.861  -77.536  46.434  1
185590  98.960  -77.539  46.413  1
185591  98.980  -77.549  46.391  1
185592  98.999  -77.558  46.369  1
185593  99.019  -77.566  46.348  1
185594  99.039  -77.574  46.326  1
185595  99.043  -77.586  46.304  1
185596  99.042  -77.600  46.283  1
185597  99.040  -77.613  46.262  1
185598  99.039  -77.627  46.241  1
185599  99.032  -77.638  46.219  1
185600  99.011  -77.638  46.197  1
185601  99.021  -77.638  46.174  1
185602  99.031  -77.638  46.152  1
185603  99.041  -77.638  46.130  1
185604  99.051  -77.638  46.107  1
185605  99.061  -77.639  46.086  1
185606  99.071  -77.639  46.065  1
185607  99.080  -77.639  46.043  1
185608  99.090  -77.641  46.023  1
185609  99.099  -77.645  46.005  1
185610  99.108  -77.649  45.986  1
185611  99.117  -77.653  45.969  1
185612  99.126  -77.658  45.951  1
185613  99.148  -77.658  45.935  1
185614  99.182  -77.670  45.919  1
185615  99.215  -77.686  45.905  1
185616  99.249  -77.703  45.892  1
185617  99.283  -77.720  45.880  1
185618  99.317  -77.736  45.869  1
185619  99.351  -77.752  45.858  1
185620  99.385  -77.769  45.848  1
185621  99.421  -77.787  45.838  1
185622  99.458  -77.805  45.828  1
185623  99.496  -77.823  45.818  1
185624  99.533  -77.841  45.806  1
185625  99.570  -77.859  45.794  1
185626  99.607  -77.877  45.782  1
185627  99.644  -77.896  45.770  1
185628  99.682  -77.914  45.758  1
185629  99.726  -77.924  45.746  1
185630  99.742  -77.928  45.736  1
185631  99.758  -77.932  45.726  1
185632  99.775  -77.937  45.716  1
185633  99.796  -77.949  45.706  1
185634  99.817  -77.960  45.697  1
185635  99.837  -77.972  45.687  1
185636  99.858  -77.984  45.676  1
185637  99.879  -77.996  45.666  1
185638  99.900  -78.007  45.655  1
185639  99.921  -78.019  45.645  1
185640  99.941  -78.031  45.633  1
185641  99.963  -78.042  45.621  1
185642  99.993  -78.047  45.608  1
185643  100.023  -78.053  45.595  1
185644  100.053  -78.058  45.581  1
185645  100.083  -78.062  45.567  1
185646  100.114  -78.068  45.554  1
185647  100.144  -78.073  45.540  1
185648  100.174  -78.078  45.525  1
185649  100.178  -78.115  45.511  1
185650  100.211  -78.123  45.497  1
185651  100.244  -78.131  45.482  1
185652  100.299  -78.094  45.468  1
185653  100.331  -78.075  45.454  1
185654  100.338  -78.092  45.440  1
185655  100.344  -78.109  45.426  1
185656  100.351  -78.126  45.413  1
185657  100.357  -78.143  45.398  1
185658  100.364  -78.159  45.383  1
185659  100.370  -78.177  45.368  1
185660  100.374  -78.199  45.353  1
185661  100.378  -78.220  45.338  1
185662  100.387  -78.235  45.323  1
185663  100.396  -78.248  45.308  1
185664  100.420  -78.253  45.292  1
185665  100.450  -78.258  45.276  1
185666  100.491  -78.259  45.260  1
185667  100.533  -78.259  45.244  1
185668  100.575  -78.259  45.229  1
185669  100.618  -78.261  45.214  1
185670  100.665  -78.269  45.199  1
185671  100.712  -78.276  45.184  1
185672  100.759  -78.284  45.168  1
185673  100.806  -78.292  45.153  1
185674  100.853  -78.300  45.139  1
185675  100.900  -78.307  45.124  1
185676  100.939  -78.314  45.109  1
185677  100.977  -78.320  45.094  1
185678  101.015  -78.326  45.080  1
185679  101.053  -78.333  45.064  1
185680  101.091  -78.339  45.048  1
185681  101.119  -78.346  45.032  1
185682  101.145  -78.353  45.016  1
185683  101.172  -78.360  45.000  1
185684  101.187  -78.370  44.984  1
185685  101.203  -78.381  44.969  1
185686  101.219  -78.392  44.953  1
185687  101.235  -78.403  44.936  1
185688  101.251  -78.413  44.921  1
185689  101.267  -78.424  44.906  1
185690  101.282  -78.435  44.889  1
185691  101.298  -78.446  44.873  1
185692  101.314  -78.457  44.857  1
185693  101.328  -78.471  44.841  1
185694  101.351  -78.491  44.825  1
185695  101.379  -78.513  44.809  1
185696  101.409  -78.535  44.793  1
185697  101.439  -78.558  44.776  1
185698  101.469  -78.581  44.761  1
185699  101.498  -78.604  44.744  1
185700  101.523  -78.630  44.728  1
185701  101.546  -78.658  44.713  1
185702  101.568  -78.691  44.697  1
185703  101.582  -78.700  44.681  1
185704  101.615  -78.720  44.665  1
185705  101.653  -78.745  44.650  1
185706  101.692  -78.771  44.635  1
185707  101.731  -78.796  44.620  1
185708  101.770  -78.821  44.604  1
185709  101.809  -78.847  44.590  1
185710  101.847  -78.872  44.576  1
185711  101.886  -78.898  44.560  1
185712  101.878  -78.975  44.546  1
185713  101.897  -78.981  44.532  1
185714  101.915  -78.987  44.518  1
185715  101.933  -78.993  44.504  1
185716  101.952  -78.999  44.491  1
185717  101.970  -79.006  44.477  1
185718  101.988  -79.012  44.465  1
185719  102.007  -79.018  44.452  1
185720  102.025  -79.024  44.439  1
185721  102.043  -79.031  44.427  1
185722  102.061  -79.037  44.415  1
185723  102.080  -79.043  44.402  1
185994  93.297  -76.576  54.133  1
185995  93.317  -76.573  54.135  1
185996  93.337  -76.570  54.137  1
185997  93.356  -76.567  54.137  1
185998  93.380  -76.563  54.137  1
185999  93.411  -76.559  54.137  1
186000  93.435  -76.558  54.138  1
186001  93.454  -76.561  54.138  1
186002  93.472  -76.564  54.139  1
186003  93.490  -76.567  54.139  1
186004  93.509  -76.570  54.138  1
186005  93.527  -76.573  54.138  1
186006  93.546  -76.576  54.139  1
186007  93.564  -76.579  54.140  1
186008  93.582  -76.582  54.142  1
186009  93.601  -76.585  54.145  1
186010  93.619  -76.587  54.146  1
186011  93.639  -76.581  54.148  1
186012  93.660  -76.572  54.151  1
186013  93.682  -76.562  54.156  1
186014  93.703  -76.552  54.165  1
186015  93.724  -76.542  54.175  1
186016  93.744  -76.536  54.185  1
186017  93.738  -76.517  54.193  1
186018  93.721  -76.490  54.201  1
186019  93.748  -76.504  54.208  1
186020  93.775  -76.517  54.215  1
186021  93.802  -76.531  54.222  1
186022  93.820  -76.534  54.229  1
186023  93.835  -76.532  54.235  1
186024  93.851  -76.527  54.237  1
186025  93.867  -76.521  54.237  1
186026  93.884  -76.517  54.236  1
186027  93.900  -76.511  54.232  1
186028  93.915  -76.507  54.225  1
186029  93.919  -76.504  54.218  1
186030  93.923  -76.501  54.211  1
186031  93.931  -76.497  54.202  1
186032  93.937  -76.499  54.193  1
186033  93.938  -76.505  54.185  1
186034  93.949  -76.509  54.178  1
186035  93.961  -76.512  54.172  1
186036  93.973  -76.515  54.171  1
186037  93.995  -76.514  54.168  1
186038  94.023  -76.508  54.166  1
186039  94.051  -76.503  54.166  1
186040  94.079  -76.498  54.166  1
186041  94.108  -76.493  54.167  1
186042  94.135  -76.488  54.167  1
186043  94.149  -76.483  54.168  1
186044  94.164  -76.480  54.161  1
186045  94.180  -76.473  54.152  1
186046  94.196  -76.467  54.140  1
186047  94.213  -76.460  54.127  1
186048  94.229  -76.454  54.110  1
186049  94.249  -76.452  54.091  1
186050  94.269  -76.451  54.071  1
186051  94.288  -76.449  54.046  1
186052  94.308  -76.448  54.018  1
186053  94.328  -76.446  53.989  1
186054  94.347  -76.445  53.960  1
186055  94.367  -76.443  53.927  1
186056  94.387  -76.441  53.892  1
186057  94.405  -76.430  53.856  1
186058  94.421  -76.417  53.819  1
186059  94.438  -76.403  53.780  1
186060  94.459  -76.395  53.742  1
186061  94.485  -76.397  53.703  1
186062  94.511  -76.399  53.665  1
186063  94.538  -76.401  53.626  1
186064  94.564  -76.402  53.586  1
186065  94.590  -76.404  53.545  1
186066  94.615  -76.404  53.509  1
186067  94.635  -76.402  53.474  1
186068  94.655  -76.401  53.439  1
186069  94.668  -76.408  53.405  1
186070  94.684  -76.407  53.368  1
186071  94.700  -76.404  53.330  1
186072  94.717  -76.402  53.292  1
186073  94.734  -76.400  53.257  1
186074  94.743  -76.399  53.225  1
186075  94.739  -76.401  53.195  1
186076  94.735  -76.404  53.167  1
186077  94.731  -76.406  53.141  1
186078  94.728  -76.408  53.114  1
186079  94.723  -76.411  53.089  1
186080  94.719  -76.413  53.066  1
186081  94.715  -76.415  53.046  1
186082  94.711  -76.417  53.025  1
186083  94.707  -76.420  53.002  1
186084  94.703  -76.422  52.976  1
186085  94.700  -76.424  52.940  1
186086  94.696  -76.426  52.898  1
186087  94.701  -76.430  52.851  1
186088  94.710  -76.433  52.800  1
186089  94.719  -76.437  52.747  1
186090  94.728  -76.442  52.695  1
186091  94.737  -76.445  52.643  1
186092  94.746  -76.449  52.590  1
186093  94.755  -76.453  52.539  1
186094  94.778  -76.460  52.487  1
186095  94.829  -76.473  52.436  1
186096  94.880  -76.486  52.384  1
186097  94.931  -76.499  52.331  1
186098  94.976  -76.509  52.278  1
186099  95.016  -76.517  52.226  1
186100  95.055  -76.526  52.176  1
186101  95.094  -76.533  52.127  1
186102  95.133  -76.542  52.077  1
186103  95.172  -76.550  52.029  1
186104  95.210  -76.558  51.983  1
186105  95.225  -76.573  51.936  1
186106  95.239  -76.586  51.888  1
186107  95.254  -76.601  51.841  1
186108  95.283  -76.613  51.793  1
186109  95.325  -76.623  51.745  1
186110  95.367  -76.633  51.701  1
186111  95.409  -76.643  51.655  1
186112  95.451  -76.652  51.609  1
186113  95.492  -76.662  51.565  1
186114  95.534  -76.672  51.521  1
186115  95.576  -76.682  51.480  1
186116  95.615  -76.693  51.441  1
186117  95.611  -76.708  51.404  1
186118  95.608  -76.724  51.369  1
186119  95.604  -76.740  51.334  1
186120  95.600  -76.756  51.299  1
186121  95.597  -76.772  51.264  1
186122  95.593  -76.788  51.226  1
186123  95.590  -76.804  51.186  1
186124  95.586  -76.820  51.145  1
186125  95.584  -76.835  51.104  1
186126  95.611  -76.837  51.063  1
186127  95.639  -76.840  51.021  1
186128  95.667  -76.843  50.976  1
186129  95.694  -76.846  50.931  1
186130  95.722  -76.848  50.889  1
186131  95.749  -76.850  50.848  1
186132  95.778  -76.850  50.806  1
186133  95.809  -76.847  50.762  1
186134  95.835  -76.848  50.714  1
186135  95.861  -76.850  50.662  1
186136  95.886  -76.850  50.607  1
186137  95.911  -76.852  50.549  1
186138  95.937  -76.853  50.491  1
186139  95.962  -76.854  50.436  1
186140  95.987  -76.856  50.384  1
186141  96.012  -76.858  50.325  1
186142  96.025  -76.873  50.263  1
186143  96.039  -76.888  50.197  1
186144  96.058  -76.900  50.132  1
186145  96.084  -76.909  50.068  1
186146  96.109  -76.918  50.008  1
186147  96.134  -76.926  49.954  1
186148  96.159  -76.935  49.903  1
186149  96.184  -76.943  49.857  1
186150  96.179  -76.961  49.814  1
186151  96.169  -76.979  49.772  1
186152  96.159  -76.998  49.733  1
186153  96.152  -77.016  49.698  1
186154  96.162  -77.029  49.666  1
186155  96.171  -77.043  49.637  1
186156  96.181  -77.056  49.610  1
186157  96.190  -77.069  49.584  1
186158  96.242  -77.044  49.560  1
186159  96.291  -77.024  49.538  1
186160  96.305  -77.038  49.519  1
186161  96.319  -77.051  49.503  1
186162  96.333  -77.065  49.487  1
186163  96.347  -77.078  49.471  1
186164  96.363  -77.090  49.455  1
186165  96.393  -77.090  49.440  1
186166  96.424  -77.089  49.426  1
186167  96.454  -77.089  49.412  1
186168  96.484  -77.088  49.398  1
186169  96.515  -77.081  49.383  1
186170  96.543  -77.068  49.368  1
186171  96.559  -77.094  49.347  1
186172  96.575  -77.119  49.325  1
186173  96.594  -77.131  49.304  1
186174  96.614  -77.138  49.282  1
186175  96.634  -77.144  49.261  1
186176  96.654  -77.150  49.240  1
186177  96.674  -77.157  49.218  1
186178  96.694  -77.164  49.194  1
186179  96.714  -77.169  49.168  1
186180  96.734  -77.174  49.142  1
186181  96.750  -77.179  49.118  1
186182  96.760  -77.182  49.094  1
186183  96.770  -77.185  49.071  1
186184  96.780  -77.188  49.048  1
186185  96.790  -77.192  49.024  1
186186  96.800  -77.195  49.000  1
186187  96.814  -77.200  48.976  1
186188  96.829  -77.204  48.953  1
186189  96.843  -77.209  48.928  1
186190  96.857  -77.213  48.902  1
186191  96.872  -77.218  48.876  1
186192  96.886  -77.223  48.851  1
186193  96.900  -77.235  48.826  1
186194  96.915  -77.245  48.802  1
186195  96.950  -77.245  48.779  1
186196  97.013  -77.241  48.756  1
186197  97.064  -77.250  48.732  1
186198  97.110  -77.266  48.709  1
186199  97.127  -77.274  48.685  1
186200  97.144  -77.282  48.662  1
186201  97.162  -77.294  48.640  1
186202  97.186  -77.313  48.618  1
186203  97.211  -77.332  48.597  1
186204  97.235  -77.351  48.576  1
186205  97.259  -77.371  48.556  1
186206  97.284  -77.390  48.536  1
186207  97.308  -77.410  48.515  1
186208  97.333  -77.429  48.495  1
186209  97.357  -77.448  48.476  1
186210  97.382  -77.468  48.456  1
186211  97.388  -77.453  48.436  1
186212  97.393  -77.435  48.417  1
186213  97.399  -77.417  48.398  1
186214  97.405  -77.405  48.379  1
186215  97.419  -77.423  48.359  1
186216  97.432  -77.442  48.339  1
186217  97.445  -77.459  48.319  1
186218  97.458  -77.477  48.299  1
186219  97.471  -77.495  48.276  1
186220  97.485  -77.513  48.255  1
186221  97.498  -77.531  48.232  1
186222  97.502  -77.511  48.208  1
186223  97.519  -77.512  48.180  1
186224  97.546  -77.514  48.152  1
186225  97.574  -77.517  48.123  1
186226  97.602  -77.518  48.093  1
186227  97.629  -77.520  48.062  1
186228  97.657  -77.523  48.031  1
186229  97.684  -77.525  47.999  1
186230  97.715  -77.514  47.968  1
186231  97.751  -77.511  47.937  1
186232  97.788  -77.507  47.906  1
186233  97.825  -77.504  47.874  1
186234  97.863  -77.500  47.841  1
186235  97.900  -77.496  47.809  1
186236  97.937  -77.493  47.776  1
186237  97.974  -77.489  47.743  1
186238  98.011  -77.486  47.711  1
186239  98.048  -77.483  47.679  1
186240  98.085  -77.479  47.649  1
186241  98.104  -77.474  47.622  1
186242  98.114  -77.470  47.594  1
186243  98.126  -77.466  47.567  1
186244  98.136  -77.462  47.539  1
186245  98.147  -77.457  47.511  1
186246  98.157  -77.453  47.482  1
186247  98.167  -77.440  47.454  1
186248  98.176  -77.425  47.427  1
186249  98.185  -77.410  47.400  1
186250  98.195  -77.395  47.372  1
186251  98.205  -77.379  47.345  1
186252  98.214  -77.364  47.319  1
186253  98.227  -77.352  47.291  1
186254  98.277  -77.364  47.265  1
186255  98.326  -77.376  47.239  1
186256  98.376  -77.389  47.214  1
186257  98.426  -77.401  47.192  1
186258  98.475  -77.414  47.169  1
186259  98.524  -77.426  47.147  1
186260  98.559  -77.432  47.125  1
186261  98.579  -77.434  47.103  1
186262  98.589  -77.426  47.081  1
186263  98.569  -77.387  47.061  1
186264  98.577  -77.406  47.038  1
186265  98.590  -77.423  47.015  1
186266  98.603  -77.439  46.992  1
186267  98.617  -77.455  46.970  1
186268  98.630  -77.472  46.946  1
186269  98.643  -77.488  46.922  1
186270  98.657  -77.504  46.899  1
186271  98.668  -77.500  46.875  1
186272  98.679  -77.495  46.852  1
186273  98.691  -77.492  46.828  1
186274  98.703  -77.488  46.803  1
186275  98.714  -77.484  46.778  1
186276  98.726  -77.479  46.755  1
186277  98.737  -77.476  46.732  1
186278  98.754  -77.472  46.709  1
186279  98.773  -77.467  46.686  1
186280  98.792  -77.464  46.662  1
186281  98.812  -77.459  46.639  1
186282  98.831  -77.455  46.616  1
186283  98.847  -77.457  46.593  1
186284  98.862  -77.464  46.571  1
186285  98.877  -77.470  46.548  1
186286  98.876  -77.481  46.525  1
186287  98.869  -77.492  46.503  1
186288  98.862  -77.503  46.482  1
186289  98.855  -77.514  46.461  1
186290  98.901  -77.523  46.440  1
186291  98.980  -77.529  46.418  1
186292  99.000  -77.537  46.396  1
186293  99.020  -77.545  46.373  1
186294  99.040  -77.554  46.351  1
186295  99.049  -77.564  46.329  1
186296  99.048  -77.577  46.308  1
186297  99.047  -77.591  46.286  1
186298  99.045  -77.604  46.265  1
186299  99.044  -77.617  46.243  1
186300  99.042  -77.631  46.221  1
186301  99.021  -77.636  46.198  1
186302  99.026  -77.636  46.176  1
186303  99.035  -77.636  46.154  1
186304  99.046  -77.636  46.132  1
186305  99.056  -77.636  46.110  1
186306  99.066  -77.636  46.089  1
186307  99.075  -77.636  46.067  1
186308  99.085  -77.639  46.046  1
186309  99.094  -77.642  46.026  1
186310  99.103  -77.647  46.008  1
186311  99.112  -77.651  45.990  1
186312  99.127  -77.654  45.972  1
186313  99.157  -77.653  45.954  1
186314  99.187  -77.652  45.938  1
186315  99.217  -77.653  45.922  1
186316  99.252  -77.670  45.907  1
186317  99.285  -77.686  45.894  1
186318  99.319  -77.702  45.882  1
186319  99.353  -77.719  45.870  1
186320  99.387  -77.736  45.860  1
186321  99.421  -77.752  45.849  1
186322  99.455  -77.768  45.838  1
186323  99.489  -77.785  45.829  1
186324  99.523  -77.801  45.818  1
186325  99.557  -77.818  45.807  1
186326  99.591  -77.834  45.794  1
186327  99.625  -77.851  45.783  1
186328  99.659  -77.867  45.770  1
186329  99.693  -77.884  45.757  1
186330  99.731  -77.888  45.745  1
186331  99.752  -77.899  45.735  1
186332  99.773  -77.912  45.725  1
186333  99.793  -77.923  45.714  1
186334  99.815  -77.935  45.704  1
186335  99.835  -77.946  45.694  1
186336  99.856  -77.959  45.684  1
186337  99.877  -77.970  45.674  1
186338  99.898  -77.982  45.664  1
186339  99.918  -77.993  45.653  1
186340  99.939  -78.006  45.642  1
186341  99.960  -78.017  45.630  1
186342  99.986  -78.025  45.618  1
186343  100.016  -78.031  45.607  1
186344  100.046  -78.036  45.594  1
186345  100.076  -78.040  45.581  1
186346  100.107  -78.046  45.567  1
186347  100.137  -78.051  45.554  1
186348  100.168  -78.056  45.540  1
186349  100.198  -78.062  45.525  1
186350  100.228  -78.066  45.511  1
186351  100.258  -78.072  45.497  1
186352  100.288  -78.077  45.483  1
186353  100.299  -78.093  45.469  1
186354  100.323  -78.087  45.455  1
186355  100.326  -78.109  45.441  1
186356  100.334  -78.125  45.427  1
186357  100.344  -78.139  45.413  1
186358  100.353  -78.153  45.398  1
186359  100.362  -78.167  45.384  1
186360  100.372  -78.181  45.369  1
186361  100.382  -78.195  45.354  1
186362  100.391  -78.210  45.339  1
186363  100.400  -78.223  45.324  1
186364  100.410  -78.238  45.310  1
186365  100.432  -78.235  45.294  1
186366  100.459  -78.241  45.278  1
186367  100.500  -78.242  45.261  1
186368  100.542  -78.242  45.247  1
186369  100.584  -78.242  45.232  1
186370  100.630  -78.247  45.217  1
186371  100.677  -78.255  45.201  1
186372  100.723  -78.263  45.187  1
186373  100.770  -78.271  45.171  1
186374  100.817  -78.279  45.156  1
186375  100.861  -78.286  45.142  1
186376  100.899  -78.292  45.126  1
186377  100.937  -78.298  45.112  1
186378  100.975  -78.305  45.097  1
186379  101.013  -78.311  45.082  1
186380  101.051  -78.317  45.067  1
186381  101.090  -78.324  45.051  1
186382  101.125  -78.330  45.035  1
186383  101.152  -78.337  45.019  1
186384  101.178  -78.344  45.003  1
186385  101.194  -78.354  44.988  1
186386  101.210  -78.366  44.972  1
186387  101.226  -78.376  44.956  1
186388  101.242  -78.387  44.940  1
186389  101.257  -78.398  44.924  1
186390  101.273  -78.409  44.909  1
186391  101.289  -78.420  44.893  1
186392  101.302  -78.437  44.877  1
186393  101.315  -78.454  44.861  1
186394  101.331  -78.472  44.844  1
186395  101.357  -78.492  44.828  1
186396  101.383  -78.514  44.812  1
186397  101.409  -78.534  44.796  1
186398  101.435  -78.554  44.780  1
186399  101.464  -78.577  44.763  1
186400  101.494  -78.600  44.747  1
186401  101.523  -78.623  44.731  1
186402  101.546  -78.651  44.716  1
186403  101.564  -78.671  44.700  1
186404  101.598  -78.693  44.684  1
186405  101.637  -78.718  44.669  1
186406  101.676  -78.744  44.653  1
186407  101.714  -78.769  44.638  1
186408  101.753  -78.795  44.622  1
186409  101.792  -78.820  44.607  1
186410  101.830  -78.845  44.592  1
186411  101.869  -78.871  44.577  1
186412  101.908  -78.896  44.562  1
186413  101.947  -78.921  44.547  1
186414  101.915  -78.990  44.533  1
186415  101.934  -78.996  44.519  1
186416  101.952  -79.002  44.505  1
186417  101.970  -79.008  44.492  1
186418  101.988  -79.014  44.479  1
186419  102.007  -79.021  44.466  1
186420  102.025  -79.027  44.453  1
186421  102.043  -79.033  44.440  1
186422  102.061  -79.039  44.428  1
186423  102.080  -79.045  44.416  1
186424  102.098  -79.052  44.403  1
186696  93.306  -76.549  54.126  1
186697  93.326  -76.546  54.128  1
186698  93.346  -76.543  54.128  1
186699  93.373  -76.539  54.129  1
186700  93.404  -76.535  54.129  1
186701  93.427  -76.535  54.130  1
186702  93.446  -76.538  54.130  1
186703  93.464  -76.541  54.131  1
186704  93.482  -76.544  54.131  1
186705  93.501  -76.546  54.131  1
186706  93.519  -76.549  54.130  1
186707  93.538  -76.552  54.132  1
186708  93.556  -76.555  54.133  1
186709  93.574  -76.558  54.135  1
186710  93.592  -76.561  54.137  1
186711  93.611  -76.564  54.138  1
186712  93.629  -76.567  54.140  1
186713  93.649  -76.562  54.143  1
186714  93.671  -76.552  54.147  1
186715  93.692  -76.543  54.154  1
186716  93.713  -76.533  54.163  1
186717  93.734  -76.524  54.173  1
186718  93.751  -76.520  54.183  1
186719  93.740  -76.496  54.192  1
186720  93.752  -76.498  54.202  1
186721  93.775  -76.510  54.212  1
186722  93.798  -76.523  54.220  1
186723  93.814  -76.520  54.228  1
186724  93.830  -76.514  54.234  1
186725  93.846  -76.510  54.238  1
186726  93.862  -76.505  54.240  1
186727  93.878  -76.500  54.241  1
186728  93.895  -76.495  54.239  1
186729  93.906  -76.491  54.235  1
186730  93.909  -76.488  54.228  1
186731  93.919  -76.483  54.220  1
186732  93.931  -76.478  54.210  1
186733  93.938  -76.479  54.202  1
186734  93.939  -76.486  54.193  1
186735  93.940  -76.493  54.185  1
186736  93.941  -76.500  54.178  1
186737  93.958  -76.501  54.174  1
186738  93.986  -76.495  54.170  1
186739  94.014  -76.490  54.167  1
186740  94.043  -76.485  54.165  1
186741  94.071  -76.480  54.165  1
186742  94.099  -76.474  54.166  1
186743  94.127  -76.469  54.167  1
186744  94.148  -76.464  54.168  1
186745  94.163  -76.461  54.164  1
186746  94.179  -76.455  54.156  1
186747  94.195  -76.448  54.145  1
186748  94.211  -76.442  54.132  1
186749  94.230  -76.439  54.115  1
186750  94.250  -76.437  54.097  1
186751  94.270  -76.435  54.079  1
186752  94.289  -76.433  54.054  1
186753  94.309  -76.432  54.027  1
186754  94.329  -76.430  54.000  1
186755  94.348  -76.429  53.969  1
186756  94.368  -76.427  53.937  1
186757  94.388  -76.426  53.903  1
186758  94.407  -76.422  53.867  1
186759  94.424  -76.408  53.828  1
186760  94.441  -76.395  53.788  1
186761  94.464  -76.392  53.749  1
186762  94.490  -76.393  53.709  1
186763  94.517  -76.395  53.671  1
186764  94.543  -76.397  53.635  1
186765  94.568  -76.398  53.598  1
186766  94.589  -76.395  53.560  1
186767  94.609  -76.393  53.523  1
186768  94.630  -76.391  53.487  1
186769  94.647  -76.392  53.452  1
186770  94.660  -76.398  53.418  1
186771  94.674  -76.402  53.382  1
186772  94.690  -76.401  53.345  1
186773  94.707  -76.398  53.307  1
186774  94.723  -76.396  53.272  1
186775  94.735  -76.395  53.239  1
186776  94.731  -76.398  53.208  1
186777  94.726  -76.400  53.180  1
186778  94.722  -76.402  53.153  1
186779  94.718  -76.404  53.126  1
186780  94.714  -76.407  53.099  1
186781  94.710  -76.409  53.075  1
186782  94.707  -76.411  53.054  1
186783  94.703  -76.413  53.032  1
186784  94.699  -76.415  53.009  1
186785  94.695  -76.417  52.983  1
186786  94.692  -76.420  52.947  1
186787  94.701  -76.424  52.905  1
186788  94.710  -76.428  52.859  1
186789  94.719  -76.432  52.810  1
186790  94.729  -76.436  52.759  1
186791  94.738  -76.439  52.707  1
186792  94.747  -76.443  52.657  1
186793  94.756  -76.447  52.604  1
186794  94.765  -76.451  52.552  1
186795  94.774  -76.455  52.501  1
186796  94.816  -76.466  52.450  1
186797  94.866  -76.479  52.399  1
186798  94.917  -76.492  52.348  1
186799  94.961  -76.502  52.297  1
186800  95.000  -76.510  52.246  1
186801  95.039  -76.517  52.196  1
186802  95.078  -76.526  52.146  1
186803  95.118  -76.534  52.096  1
186804  95.157  -76.542  52.048  1
186805  95.196  -76.550  52.000  1
186806  95.219  -76.562  51.953  1
186807  95.234  -76.577  51.906  1
186808  95.248  -76.591  51.859  1
186809  95.287  -76.601  51.812  1
186810  95.329  -76.611  51.767  1
186811  95.371  -76.621  51.723  1
186812  95.412  -76.630  51.677  1
186813  95.454  -76.641  51.630  1
186814  95.496  -76.651  51.584  1
186815  95.533  -76.661  51.539  1
186816  95.552  -76.671  51.497  1
186817  95.570  -76.681  51.456  1
186818  95.589  -76.692  51.418  1
186819  95.590  -76.706  51.382  1
186820  95.587  -76.722  51.346  1
186821  95.583  -76.738  51.310  1
186822  95.580  -76.754  51.272  1
186823  95.576  -76.770  51.233  1
186824  95.572  -76.786  51.192  1
186825  95.568  -76.802  51.151  1
186826  95.588  -76.808  51.110  1
186827  95.615  -76.811  51.070  1
186828  95.642  -76.813  51.028  1
186829  95.670  -76.816  50.985  1
186830  95.698  -76.818  50.943  1
186831  95.726  -76.821  50.902  1
186832  95.753  -76.824  50.862  1
186833  95.782  -76.827  50.821  1
186834  95.801  -76.826  50.777  1
186835  95.828  -76.832  50.728  1
186836  95.854  -76.835  50.677  1
186837  95.879  -76.836  50.622  1
186838  95.905  -76.837  50.565  1
186839  95.930  -76.838  50.511  1
186840  95.956  -76.840  50.459  1
186841  95.981  -76.840  50.409  1
186842  96.006  -76.842  50.351  1
186843  96.020  -76.857  50.289  1
186844  96.040  -76.869  50.224  1
186845  96.065  -76.878  50.158  1
186846  96.090  -76.887  50.095  1
186847  96.115  -76.895  50.036  1
186848  96.141  -76.904  49.981  1
186849  96.166  -76.912  49.931  1
186850  96.187  -76.922  49.885  1
186851  96.177  -76.941  49.842  1
186852  96.167  -76.959  49.801  1
186853  96.157  -76.978  49.761  1
186854  96.167  -76.991  49.726  1
186855  96.176  -77.005  49.695  1
186856  96.186  -77.019  49.666  1
186857  96.195  -77.031  49.638  1
186858  96.205  -77.045  49.612  1
186859  96.233  -77.041  49.589  1
186860  96.322  -76.982  49.567  1
186861  96.336  -76.996  49.549  1
186862  96.350  -77.009  49.533  1
186863  96.365  -77.022  49.518  1
186864  96.379  -77.036  49.501  1
186865  96.393  -77.050  49.486  1
186866  96.407  -77.063  49.471  1
186867  96.427  -77.072  49.457  1
186868  96.457  -77.072  49.443  1
186869  96.487  -77.071  49.428  1
186870  96.518  -77.056  49.413  1
186871  96.544  -77.050  49.395  1
186872  96.559  -77.075  49.373  1
186873  96.575  -77.101  49.351  1
186874  96.592  -77.120  49.328  1
186875  96.612  -77.127  49.307  1
186876  96.632  -77.134  49.286  1
186877  96.652  -77.141  49.264  1
186878  96.672  -77.147  49.240  1
186879  96.692  -77.152  49.215  1
186880  96.713  -77.157  49.189  1
186881  96.733  -77.161  49.163  1
186882  96.753  -77.166  49.137  1
186883  96.764  -77.169  49.113  1
186884  96.774  -77.172  49.089  1
186885  96.784  -77.176  49.065  1
186886  96.794  -77.179  49.041  1
186887  96.804  -77.183  49.017  1
186888  96.813  -77.186  48.993  1
186889  96.823  -77.190  48.969  1
186890  96.833  -77.193  48.944  1
186891  96.843  -77.196  48.918  1
186892  96.854  -77.200  48.892  1
186893  96.868  -77.204  48.867  1
186894  96.883  -77.210  48.841  1
186895  96.915  -77.213  48.816  1
186896  96.966  -77.222  48.792  1
186897  97.017  -77.231  48.768  1
186898  97.067  -77.241  48.744  1
186899  97.114  -77.257  48.720  1
186900  97.145  -77.269  48.696  1
186901  97.161  -77.279  48.673  1
186902  97.178  -77.287  48.650  1
186903  97.194  -77.295  48.628  1
186904  97.211  -77.304  48.607  1
186905  97.231  -77.319  48.587  1
186906  97.256  -77.338  48.566  1
186907  97.280  -77.357  48.546  1
186908  97.305  -77.376  48.525  1
186909  97.329  -77.396  48.505  1
186910  97.354  -77.415  48.485  1
186911  97.378  -77.435  48.465  1
186912  97.394  -77.438  48.445  1
186913  97.399  -77.420  48.425  1
186914  97.404  -77.402  48.406  1
186915  97.415  -77.404  48.386  1
186916  97.428  -77.423  48.366  1
186917  97.441  -77.440  48.346  1
186918  97.454  -77.458  48.325  1
186919  97.467  -77.476  48.304  1
186920  97.479  -77.491  48.282  1
186921  97.490  -77.480  48.260  1
186922  97.511  -77.489  48.238  1
186923  97.507  -77.489  48.213  1
186924  97.534  -77.487  48.184  1
186925  97.561  -77.487  48.155  1
186926  97.589  -77.489  48.126  1
186927  97.616  -77.491  48.095  1
186928  97.644  -77.493  48.065  1
186929  97.671  -77.495  48.034  1
186930  97.699  -77.497  48.003  1
186931  97.729  -77.489  47.972  1
186932  97.759  -77.477  47.941  1
186933  97.790  -77.465  47.909  1
186934  97.826  -77.461  47.876  1
186935  97.864  -77.457  47.843  1
186936  97.901  -77.454  47.811  1
186937  97.938  -77.451  47.778  1
186938  97.975  -77.447  47.745  1
186939  98.012  -77.443  47.713  1
186940  98.050  -77.440  47.682  1
186941  98.086  -77.436  47.653  1
186942  98.107  -77.432  47.627  1
186943  98.118  -77.428  47.600  1
186944  98.129  -77.423  47.571  1
186945  98.139  -77.420  47.543  1
186946  98.150  -77.415  47.515  1
186947  98.161  -77.410  47.487  1
186948  98.171  -77.407  47.459  1
186949  98.182  -77.402  47.432  1
186950  98.193  -77.396  47.404  1
186951  98.202  -77.381  47.377  1
186952  98.211  -77.366  47.350  1
186953  98.221  -77.351  47.323  1
186954  98.230  -77.335  47.296  1
186955  98.268  -77.339  47.269  1
186956  98.317  -77.352  47.243  1
186957  98.367  -77.364  47.217  1
186958  98.416  -77.376  47.194  1
186959  98.466  -77.389  47.172  1
186960  98.515  -77.401  47.149  1
186961  98.565  -77.413  47.126  1
186962  98.598  -77.417  47.104  1
186963  98.577  -77.377  47.083  1
186964  98.582  -77.379  47.062  1
186965  98.595  -77.395  47.040  1
186966  98.608  -77.412  47.018  1
186967  98.622  -77.428  46.996  1
186968  98.635  -77.445  46.973  1
186969  98.648  -77.461  46.950  1
186970  98.661  -77.477  46.927  1
186971  98.674  -77.486  46.904  1
186972  98.686  -77.482  46.881  1
186973  98.697  -77.478  46.857  1
186974  98.709  -77.473  46.833  1
186975  98.720  -77.470  46.810  1
186976  98.732  -77.466  46.785  1
186977  98.743  -77.462  46.762  1
186978  98.755  -77.457  46.739  1
186979  98.767  -77.454  46.717  1
186980  98.782  -77.450  46.694  1
186981  98.801  -77.445  46.671  1
186982  98.821  -77.442  46.648  1
186983  98.840  -77.437  46.625  1
186984  98.856  -77.441  46.602  1
186985  98.870  -77.448  46.579  1
186986  98.874  -77.457  46.556  1
186987  98.867  -77.468  46.531  1
186988  98.860  -77.479  46.509  1
186989  98.878  -77.489  46.488  1
186990  98.958  -77.495  46.467  1
186991  98.979  -77.504  46.446  1
186992  99.000  -77.516  46.424  1
186993  99.020  -77.524  46.401  1
186994  99.040  -77.533  46.377  1
186995  99.056  -77.542  46.355  1
186996  99.054  -77.555  46.333  1
186997  99.053  -77.569  46.311  1
186998  99.051  -77.582  46.289  1
186999  99.050  -77.595  46.267  1
187000  99.049  -77.608  46.245  1
187001  99.047  -77.622  46.223  1
187002  99.043  -77.634  46.200  1
187003  99.030  -77.635  46.177  1
187004  99.041  -77.635  46.155  1
187005  99.051  -77.635  46.134  1
187006  99.060  -77.635  46.113  1
187007  99.070  -77.635  46.091  1
187008  99.080  -77.636  46.070  1
187009  99.089  -77.640  46.049  1
187010  99.098  -77.644  46.029  1
187011  99.107  -77.649  46.011  1
187012  99.135  -77.649  45.992  1
187013  99.165  -77.648  45.974  1
187014  99.196  -77.647  45.957  1
187015  99.225  -77.646  45.941  1
187016  99.256  -77.645  45.924  1
187017  99.287  -77.652  45.909  1
187018  99.322  -77.669  45.896  1
187019  99.355  -77.686  45.884  1
187020  99.389  -77.702  45.872  1
187021  99.423  -77.718  45.861  1
187022  99.457  -77.735  45.850  1
187023  99.491  -77.752  45.839  1
187024  99.525  -77.768  45.830  1
187025  99.559  -77.784  45.818  1
187026  99.593  -77.801  45.806  1
187027  99.627  -77.817  45.794  1
187028  99.661  -77.834  45.781  1
187029  99.695  -77.850  45.769  1
187030  99.736  -77.855  45.756  1
187031  99.749  -77.868  45.743  1
187032  99.771  -77.886  45.732  1
187033  99.791  -77.897  45.722  1
187034  99.812  -77.909  45.711  1
187035  99.833  -77.921  45.700  1
187036  99.854  -77.933  45.690  1
187037  99.874  -77.944  45.680  1
187038  99.896  -77.956  45.670  1
187039  99.916  -77.968  45.661  1
187040  99.937  -77.980  45.649  1
187041  99.958  -77.992  45.639  1
187042  99.979  -78.003  45.628  1
187043  100.009  -78.009  45.616  1
187044  100.039  -78.014  45.605  1
187045  100.069  -78.018  45.593  1
187046  100.100  -78.024  45.580  1
187047  100.130  -78.029  45.567  1
187048  100.160  -78.034  45.554  1
187049  100.190  -78.040  45.540  1
187050  100.221  -78.044  45.527  1
187051  100.251  -78.050  45.512  1
187052  100.281  -78.055  45.498  1
187053  100.302  -78.069  45.484  1
187054  100.317  -78.079  45.471  1
187055  100.329  -78.087  45.457  1
187056  100.338  -78.100  45.442  1
187057  100.348  -78.115  45.428  1
187058  100.357  -78.128  45.414  1
187059  100.366  -78.142  45.398  1
187060  100.376  -78.156  45.384  1
187061  100.385  -78.170  45.370  1
187062  100.395  -78.184  45.355  1
187063  100.404  -78.198  45.339  1
187064  100.414  -78.213  45.325  1
187065  100.423  -78.226  45.310  1
187066  100.445  -78.219  45.295  1
187067  100.471  -78.224  45.279  1
187068  100.509  -78.225  45.264  1
187069  100.551  -78.225  45.249  1
187070  100.594  -78.226  45.234  1
187071  100.641  -78.235  45.219  1
187072  100.688  -78.242  45.204  1
187073  100.735  -78.250  45.188  1
187074  100.782  -78.257  45.173  1
187075  100.822  -78.264  45.159  1
187076  100.860  -78.270  45.144  1
187077  100.898  -78.277  45.128  1
187078  100.936  -78.283  45.114  1
187079  100.974  -78.289  45.099  1
187080  101.012  -78.296  45.084  1
187081  101.050  -78.302  45.069  1
187082  101.088  -78.308  45.054  1
187083  101.126  -78.315  45.038  1
187084  101.159  -78.321  45.022  1
187085  101.185  -78.329  45.006  1
187086  101.201  -78.339  44.991  1
187087  101.217  -78.350  44.976  1
187088  101.233  -78.360  44.960  1
187089  101.248  -78.371  44.944  1
187090  101.262  -78.386  44.928  1
187091  101.275  -78.404  44.912  1
187092  101.289  -78.420  44.897  1
187093  101.302  -78.437  44.881  1
187094  101.315  -78.454  44.864  1
187095  101.337  -78.473  44.848  1
187096  101.363  -78.495  44.832  1
187097  101.389  -78.515  44.815  1
187098  101.415  -78.535  44.799  1
187099  101.441  -78.556  44.782  1
187100  101.467  -78.576  44.766  1
187101  101.493  -78.598  44.750  1
187102  101.519  -78.618  44.734  1
187103  101.546  -78.643  44.719  1
187104  101.582  -78.666  44.703  1
187105  101.620  -78.692  44.687  1
187106  101.659  -78.717  44.671  1
187107  101.697  -78.742  44.656  1
187108  101.736  -78.767  44.640  1
187109  101.775  -78.793  44.624  1
187110  101.814  -78.818  44.609  1
187111  101.852  -78.843  44.593  1
187112  101.891  -78.869  44.578  1
187113  101.930  -78.894  44.563  1
187114  101.969  -78.920  44.548  1
187115  101.934  -78.997  44.534  1
187116  101.952  -79.004  44.521  1
187117  101.971  -79.010  44.506  1
187118  101.989  -79.016  44.494  1
187119  102.007  -79.022  44.481  1
187120  102.026  -79.028  44.468  1
187121  102.044  -79.035  44.455  1
187122  102.062  -79.041  44.442  1
187123  102.081  -79.047  44.430  1
187124  102.099  -79.053  44.416  1
187125  102.117  -79.059  44.403  1
187398  93.315  -76.522  54.117  1
187399  93.335  -76.519  54.118  1
187400  93.366  -76.515  54.120  1
187401  93.397  -76.511  54.121  1
187402  93.419  -76.511  54.122  1
187403  93.437  -76.514  54.123  1
187404  93.456  -76.517  54.124  1
187405  93.474  -76.520  54.123  1
187406  93.493  -76.524  54.123  1
187407  93.511  -76.526  54.123  1
187408  93.530  -76.529  54.124  1
187409  93.548  -76.532  54.126  1
187410  93.566  -76.535  54.127  1
187411  93.584  -76.538  54.130  1
187412  93.603  -76.541  54.131  1
187413  93.621  -76.543  54.133  1
187414  93.639  -76.546  54.135  1
187415  93.659  -76.543  54.139  1
187416  93.680  -76.533  54.146  1
187417  93.701  -76.524  54.153  1
187418  93.722  -76.514  54.162  1
187419  93.744  -76.505  54.171  1
187420  93.758  -76.505  54.181  1
187421  93.759  -76.493  54.191  1
187422  93.782  -76.506  54.203  1
187423  93.797  -76.503  54.212  1
187424  93.812  -76.499  54.221  1
187425  93.827  -76.495  54.229  1
187426  93.841  -76.492  54.235  1
187427  93.856  -76.488  54.239  1
187428  93.872  -76.483  54.242  1
187429  93.889  -76.478  54.243  1
187430  93.896  -76.475  54.242  1
187431  93.908  -76.469  54.237  1
187432  93.920  -76.464  54.228  1
187433  93.932  -76.458  54.217  1
187434  93.939  -76.459  54.209  1
187435  93.940  -76.467  54.201  1
187436  93.941  -76.473  54.194  1
187437  93.950  -76.479  54.187  1
187438  93.966  -76.480  54.181  1
187439  93.984  -76.477  54.176  1
187440  94.006  -76.472  54.171  1
187441  94.034  -76.467  54.167  1
187442  94.062  -76.461  54.167  1
187443  94.090  -76.456  54.168  1
187444  94.119  -76.451  54.170  1
187445  94.147  -76.445  54.170  1
187446  94.161  -76.442  54.168  1
187447  94.178  -76.436  54.161  1
187448  94.194  -76.429  54.150  1
187449  94.211  -76.424  54.137  1
187450  94.231  -76.423  54.122  1
187451  94.251  -76.421  54.105  1
187452  94.271  -76.420  54.088  1
187453  94.290  -76.418  54.063  1
187454  94.310  -76.417  54.037  1
187455  94.330  -76.415  54.009  1
187456  94.349  -76.413  53.979  1
187457  94.369  -76.411  53.946  1
187458  94.389  -76.410  53.913  1
187459  94.409  -76.408  53.879  1
187460  94.427  -76.400  53.839  1
187461  94.443  -76.386  53.799  1
187462  94.469  -76.387  53.759  1
187463  94.495  -76.389  53.718  1
187464  94.522  -76.391  53.680  1
187465  94.542  -76.389  53.645  1
187466  94.563  -76.386  53.611  1
187467  94.583  -76.383  53.575  1
187468  94.604  -76.381  53.538  1
187469  94.624  -76.379  53.502  1
187470  94.639  -76.383  53.467  1
187471  94.652  -76.389  53.434  1
187472  94.665  -76.396  53.400  1
187473  94.680  -76.396  53.364  1
187474  94.696  -76.395  53.326  1
187475  94.713  -76.392  53.289  1
187476  94.725  -76.391  53.255  1
187477  94.721  -76.393  53.224  1
187478  94.717  -76.395  53.195  1
187479  94.713  -76.398  53.167  1
187480  94.710  -76.400  53.138  1
187481  94.706  -76.402  53.110  1
187482  94.702  -76.404  53.083  1
187483  94.698  -76.407  53.059  1
187484  94.694  -76.409  53.036  1
187485  94.690  -76.411  53.012  1
187486  94.692  -76.414  52.983  1
187487  94.701  -76.418  52.948  1
187488  94.710  -76.422  52.908  1
187489  94.720  -76.426  52.863  1
187490  94.729  -76.430  52.816  1
187491  94.738  -76.433  52.767  1
187492  94.747  -76.437  52.718  1
187493  94.756  -76.442  52.669  1
187494  94.765  -76.445  52.618  1
187495  94.774  -76.449  52.568  1
187496  94.783  -76.453  52.518  1
187497  94.803  -76.459  52.470  1
187498  94.853  -76.472  52.419  1
187499  94.904  -76.485  52.369  1
187500  94.946  -76.494  52.321  1
187501  94.984  -76.502  52.270  1
187502  95.024  -76.510  52.219  1
187503  95.063  -76.518  52.168  1
187504  95.102  -76.526  52.116  1
187505  95.141  -76.534  52.066  1
187506  95.180  -76.542  52.018  1
187507  95.214  -76.552  51.970  1
187508  95.228  -76.566  51.921  1
187509  95.249  -76.580  51.874  1
187510  95.291  -76.589  51.828  1
187511  95.333  -76.599  51.784  1
187512  95.375  -76.609  51.743  1
187513  95.416  -76.619  51.698  1
187514  95.450  -76.629  51.652  1
187515  95.469  -76.640  51.605  1
187516  95.487  -76.650  51.558  1
187517  95.506  -76.660  51.514  1
187518  95.525  -76.671  51.471  1
187519  95.543  -76.680  51.431  1
187520  95.562  -76.691  51.393  1
187521  95.569  -76.704  51.356  1
187522  95.566  -76.720  51.319  1
187523  95.562  -76.736  51.281  1
187524  95.558  -76.752  51.240  1
187525  95.555  -76.768  51.200  1
187526  95.564  -76.778  51.158  1
187527  95.591  -76.781  51.117  1
187528  95.619  -76.784  51.076  1
187529  95.647  -76.786  51.036  1
187530  95.674  -76.789  50.995  1
187531  95.702  -76.792  50.953  1
187532  95.732  -76.795  50.913  1
187533  95.762  -76.798  50.873  1
187534  95.788  -76.802  50.832  1
187535  95.811  -76.806  50.788  1
187536  95.817  -76.794  50.741  1
187537  95.840  -76.797  50.690  1
187538  95.867  -76.803  50.635  1
187539  95.894  -76.809  50.583  1
187540  95.921  -76.816  50.532  1
187541  95.948  -76.822  50.483  1
187542  95.974  -76.826  50.434  1
187543  96.000  -76.828  50.377  1
187544  96.021  -76.837  50.316  1
187545  96.046  -76.846  50.251  1
187546  96.072  -76.855  50.185  1
187547  96.097  -76.864  50.123  1
187548  96.122  -76.872  50.064  1
187549  96.147  -76.881  50.009  1
187550  96.172  -76.890  49.960  1
187551  96.184  -76.903  49.914  1
187552  96.174  -76.921  49.871  1
187553  96.164  -76.940  49.829  1
187554  96.172  -76.953  49.790  1
187555  96.181  -76.967  49.755  1
187556  96.191  -76.981  49.724  1
187557  96.200  -76.994  49.695  1
187558  96.210  -77.007  49.668  1
187559  96.220  -77.021  49.642  1
187560  96.230  -77.034  49.618  1
187561  96.329  -76.964  49.597  1
187562  96.368  -76.953  49.579  1
187563  96.382  -76.967  49.563  1
187564  96.396  -76.981  49.547  1
187565  96.410  -76.994  49.531  1
187566  96.424  -77.008  49.517  1
187567  96.438  -77.022  49.503  1
187568  96.452  -77.035  49.488  1
187569  96.466  -77.049  49.475  1
187570  96.489  -77.049  49.460  1
187571  96.516  -77.032  49.443  1
187572  96.513  -77.059  49.422  1
187573  96.550  -77.065  49.400  1
187574  96.575  -77.083  49.376  1
187575  96.591  -77.109  49.353  1
187576  96.610  -77.117  49.332  1
187577  96.630  -77.124  49.311  1
187578  96.651  -77.129  49.288  1
187579  96.671  -77.134  49.264  1
187580  96.691  -77.138  49.237  1
187581  96.711  -77.144  49.211  1
187582  96.731  -77.148  49.184  1
187583  96.751  -77.153  49.157  1
187584  96.767  -77.157  49.133  1
187585  96.777  -77.160  49.107  1
187586  96.787  -77.164  49.082  1
187587  96.797  -77.167  49.058  1
187588  96.807  -77.170  49.033  1
187589  96.817  -77.174  49.009  1
187590  96.827  -77.177  48.985  1
187591  96.836  -77.181  48.960  1
187592  96.847  -77.184  48.934  1
187593  96.858  -77.188  48.908  1
187594  96.870  -77.192  48.883  1
187595  96.882  -77.196  48.857  1
187596  96.919  -77.203  48.832  1
187597  96.969  -77.213  48.807  1
187598  97.020  -77.222  48.782  1
187599  97.070  -77.232  48.757  1
187600  97.116  -77.249  48.732  1
187601  97.163  -77.265  48.708  1
187602  97.179  -77.274  48.685  1
187603  97.195  -77.282  48.662  1
187604  97.212  -77.291  48.640  1
187605  97.229  -77.300  48.618  1
187606  97.245  -77.308  48.598  1
187607  97.261  -77.317  48.576  1
187608  97.278  -77.326  48.555  1
187609  97.301  -77.343  48.535  1
187610  97.325  -77.363  48.515  1
187611  97.350  -77.382  48.495  1
187612  97.375  -77.401  48.476  1
187613  97.399  -77.421  48.456  1
187614  97.405  -77.405  48.435  1
187615  97.410  -77.387  48.415  1
187616  97.424  -77.404  48.395  1
187617  97.437  -77.422  48.374  1
187618  97.450  -77.439  48.353  1
187619  97.460  -77.450  48.332  1
187620  97.477  -77.449  48.310  1
187621  97.499  -77.457  48.288  1
187622  97.520  -77.466  48.266  1
187623  97.526  -77.470  48.242  1
187624  97.522  -77.464  48.217  1
187625  97.548  -77.462  48.189  1
187626  97.576  -77.461  48.160  1
187627  97.603  -77.462  48.130  1
187628  97.631  -77.464  48.099  1
187629  97.658  -77.466  48.069  1
187630  97.685  -77.468  48.038  1
187631  97.713  -77.470  48.007  1
187632  97.743  -77.463  47.976  1
187633  97.774  -77.451  47.944  1
187634  97.804  -77.439  47.912  1
187635  97.835  -77.427  47.880  1
187636  97.865  -77.416  47.847  1
187637  97.902  -77.411  47.814  1
187638  97.939  -77.408  47.782  1
187639  97.977  -77.404  47.750  1
187640  98.013  -77.401  47.718  1
187641  98.051  -77.398  47.687  1
187642  98.088  -77.394  47.658  1
187643  98.111  -77.390  47.630  1
187644  98.122  -77.385  47.602  1
187645  98.132  -77.381  47.574  1
187646  98.143  -77.377  47.546  1
187647  98.153  -77.373  47.519  1
187648  98.164  -77.369  47.491  1
187649  98.175  -77.364  47.464  1
187650  98.185  -77.360  47.437  1
187651  98.196  -77.356  47.409  1
187652  98.207  -77.351  47.382  1
187653  98.217  -77.347  47.355  1
187654  98.227  -77.336  47.327  1
187655  98.236  -77.321  47.300  1
187656  98.258  -77.315  47.273  1
187657  98.308  -77.327  47.246  1
187658  98.358  -77.339  47.220  1
187659  98.407  -77.351  47.197  1
187660  98.457  -77.363  47.173  1
187661  98.511  -77.375  47.150  1
187662  98.564  -77.387  47.128  1
187663  98.572  -77.369  47.106  1
187664  98.569  -77.351  47.085  1
187665  98.598  -77.368  47.064  1
187666  98.613  -77.385  47.043  1
187667  98.627  -77.401  47.021  1
187668  98.640  -77.417  47.000  1
187669  98.653  -77.434  46.977  1
187670  98.666  -77.450  46.954  1
187671  98.679  -77.467  46.932  1
187672  98.692  -77.468  46.910  1
187673  98.703  -77.464  46.887  1
187674  98.715  -77.460  46.863  1
187675  98.726  -77.456  46.840  1
187676  98.738  -77.452  46.816  1
187677  98.749  -77.448  46.793  1
187678  98.761  -77.444  46.770  1
187679  98.772  -77.440  46.748  1
187680  98.784  -77.436  46.726  1
187681  98.795  -77.432  46.703  1
187682  98.810  -77.428  46.680  1
187683  98.830  -77.423  46.657  1
187684  98.849  -77.420  46.633  1
187685  98.864  -77.425  46.610  1
187686  98.871  -77.432  46.587  1
187687  98.865  -77.444  46.563  1
187688  98.866  -77.455  46.539  1
187689  98.934  -77.461  46.516  1
187690  98.954  -77.467  46.494  1
187691  98.974  -77.472  46.472  1
187692  98.997  -77.487  46.451  1
187693  99.020  -77.504  46.429  1
187694  99.041  -77.512  46.406  1
187695  99.060  -77.520  46.382  1
187696  99.060  -77.533  46.359  1
187697  99.059  -77.546  46.336  1
187698  99.058  -77.560  46.314  1
187699  99.056  -77.573  46.292  1
187700  99.055  -77.586  46.270  1
187701  99.053  -77.600  46.248  1
187702  99.052  -77.613  46.226  1
187703  99.051  -77.627  46.203  1
187704  99.035  -77.633  46.180  1
187705  99.046  -77.633  46.157  1
187706  99.055  -77.633  46.136  1
187707  99.065  -77.633  46.114  1
187708  99.075  -77.633  46.093  1
187709  99.084  -77.638  46.073  1
187710  99.093  -77.642  46.052  1
187711  99.114  -77.643  46.032  1
187712  99.144  -77.642  46.013  1
187713  99.174  -77.642  45.995  1
187714  99.204  -77.642  45.977  1
187715  99.234  -77.641  45.960  1
187716  99.264  -77.640  45.943  1
187717  99.294  -77.639  45.927  1
187718  99.324  -77.639  45.911  1
187719  99.357  -77.652  45.898  1
187720  99.392  -77.668  45.885  1
187721  99.425  -77.685  45.873  1
187722  99.460  -77.702  45.862  1
187723  99.493  -77.718  45.850  1
187724  99.527  -77.734  45.840  1
187725  99.561  -77.751  45.829  1
187726  99.595  -77.768  45.817  1
187727  99.629  -77.783  45.805  1
187728  99.663  -77.800  45.793  1
187729  99.697  -77.817  45.779  1
187730  99.739  -77.825  45.767  1
187731  99.756  -77.836  45.754  1
187732  99.769  -77.848  45.741  1
187733  99.788  -77.867  45.730  1
187734  99.810  -77.884  45.718  1
187735  99.831  -77.896  45.707  1
187736  99.852  -77.907  45.696  1
187737  99.872  -77.919  45.686  1
187738  99.893  -77.931  45.676  1
187739  99.914  -77.943  45.666  1
187740  99.935  -77.954  45.656  1
187741  99.956  -77.966  45.646  1
187742  99.977  -77.978  45.636  1
187743  100.002  -77.987  45.625  1
187744  100.032  -77.992  45.614  1
187745  100.062  -77.996  45.602  1
187746  100.092  -78.002  45.591  1
187747  100.123  -78.007  45.579  1
187748  100.153  -78.012  45.567  1
187749  100.183  -78.018  45.554  1
187750  100.213  -78.022  45.541  1
187751  100.244  -78.028  45.527  1
187752  100.268  -78.038  45.512  1
187753  100.288  -78.052  45.498  1
187754  100.309  -78.065  45.484  1
187755  100.325  -78.078  45.471  1
187756  100.337  -78.084  45.457  1
187757  100.350  -78.092  45.442  1
187758  100.361  -78.103  45.428  1
187759  100.370  -78.118  45.414  1
187760  100.380  -78.131  45.399  1
187761  100.390  -78.145  45.384  1
187762  100.399  -78.159  45.369  1
187763  100.408  -78.173  45.354  1
187764  100.418  -78.188  45.339  1
187765  100.427  -78.201  45.325  1
187766  100.436  -78.216  45.310  1
187767  100.458  -78.208  45.295  1
187768  100.483  -78.206  45.281  1
187769  100.519  -78.209  45.266  1
187770  100.561  -78.209  45.251  1
187771  100.606  -78.213  45.235  1
187772  100.652  -78.221  45.220  1
187773  100.699  -78.228  45.206  1
187774  100.744  -78.236  45.190  1
187775  100.782  -78.242  45.175  1
187776  100.820  -78.249  45.160  1
187777  100.858  -78.255  45.146  1
187778  100.896  -78.261  45.131  1
187779  100.934  -78.268  45.116  1
187780  100.972  -78.274  45.100  1
187781  101.010  -78.280  45.086  1
187782  101.048  -78.287  45.072  1
187783  101.086  -78.293  45.057  1
187784  101.124  -78.299  45.042  1
187785  101.162  -78.306  45.025  1
187786  101.192  -78.313  45.010  1
187787  101.208  -78.323  44.995  1
187788  101.223  -78.335  44.980  1
187789  101.236  -78.353  44.963  1
187790  101.249  -78.369  44.947  1
187791  101.262  -78.386  44.932  1
187792  101.276  -78.404  44.916  1
187793  101.289  -78.420  44.900  1
187794  101.302  -78.437  44.884  1
187795  101.317  -78.455  44.867  1
187796  101.343  -78.476  44.851  1
187797  101.369  -78.496  44.834  1
187798  101.395  -78.517  44.818  1
187799  101.421  -78.537  44.801  1
187800  101.447  -78.558  44.785  1
187801  101.473  -78.579  44.769  1
187802  101.490  -78.589  44.753  1
187803  101.525  -78.610  44.738  1
187804  101.555  -78.633  44.722  1
187805  101.593  -78.660  44.706  1
187806  101.636  -78.687  44.690  1
187807  101.679  -78.714  44.673  1
187808  101.720  -78.740  44.658  1
187809  101.758  -78.766  44.642  1
187810  101.797  -78.791  44.627  1
187811  101.836  -78.817  44.611  1
187812  101.875  -78.842  44.594  1
187813  101.913  -78.868  44.578  1
187814  101.952  -78.893  44.563  1
187815  101.991  -78.918  44.549  1
187816  101.953  -79.006  44.535  1
187817  101.971  -79.012  44.522  1
187818  101.989  -79.018  44.508  1
187819  102.007  -79.024  44.495  1
187820  102.026  -79.031  44.482  1
187821  102.044  -79.037  44.469  1
187822  102.062  -79.043  44.456  1
187823  102.081  -79.049  44.444  1
187824  102.100  -79.054  44.431  1
187825  102.119  -79.056  44.417  1
187826  102.138  -79.057  44.405  1
188100  93.328  -76.495  54.109  1
188101  93.359  -76.491  54.111  1
188102  93.390  -76.487  54.112  1
188103  93.411  -76.488  54.114  1
188104  93.429  -76.491  54.115  1
188105  93.448  -76.494  54.116  1
188106  93.466  -76.497  54.116  1
188107  93.485  -76.500  54.115  1
188108  93.503  -76.502  54.116  1
188109  93.521  -76.505  54.117  1
188110  93.540  -76.508  54.118  1
188111  93.558  -76.511  54.121  1
188112  93.576  -76.514  54.123  1
188113  93.594  -76.517  54.125  1
188114  93.613  -76.520  54.126  1
188115  93.631  -76.523  54.129  1
188116  93.649  -76.526  54.132  1
188117  93.669  -76.524  54.138  1
188118  93.690  -76.514  54.145  1
188119  93.711  -76.505  54.153  1
188120  93.732  -76.495  54.160  1
188121  93.751  -76.489  54.170  1
188122  93.766  -76.490  54.181  1
188123  93.780  -76.487  54.193  1
188124  93.795  -76.483  54.203  1
188125  93.809  -76.480  54.214  1
188126  93.824  -76.477  54.224  1
188127  93.839  -76.473  54.231  1
188128  93.854  -76.469  54.236  1
188129  93.868  -76.465  54.241  1
188130  93.883  -76.461  54.244  1
188131  93.896  -76.455  54.244  1
188132  93.909  -76.450  54.241  1
188133  93.921  -76.445  54.234  1
188134  93.933  -76.439  54.223  1
188135  93.940  -76.439  54.215  1
188136  93.941  -76.447  54.208  1
188137  93.952  -76.451  54.201  1
188138  93.966  -76.456  54.195  1
188139  93.980  -76.460  54.190  1
188140  93.998  -76.455  54.185  1
188141  94.016  -76.451  54.178  1
188142  94.035  -76.447  54.175  1
188143  94.054  -76.442  54.175  1
188144  94.082  -76.438  54.177  1
188145  94.111  -76.433  54.179  1
188146  94.139  -76.427  54.181  1
188147  94.161  -76.423  54.177  1
188148  94.176  -76.417  54.170  1
188149  94.193  -76.411  54.159  1
188150  94.212  -76.409  54.146  1
188151  94.232  -76.408  54.130  1
188152  94.252  -76.405  54.114  1
188153  94.271  -76.404  54.098  1
188154  94.291  -76.402  54.074  1
188155  94.311  -76.401  54.047  1
188156  94.331  -76.399  54.019  1
188157  94.350  -76.398  53.988  1
188158  94.370  -76.396  53.956  1
188159  94.390  -76.395  53.923  1
188160  94.409  -76.393  53.890  1
188161  94.429  -76.391  53.852  1
188162  94.448  -76.382  53.813  1
188163  94.474  -76.383  53.772  1
188164  94.496  -76.381  53.730  1
188165  94.516  -76.379  53.692  1
188166  94.537  -76.376  53.657  1
188167  94.557  -76.374  53.624  1
188168  94.577  -76.372  53.590  1
188169  94.598  -76.370  53.555  1
188170  94.618  -76.367  53.519  1
188171  94.631  -76.373  53.484  1
188172  94.644  -76.379  53.452  1
188173  94.657  -76.387  53.420  1
188174  94.670  -76.392  53.385  1
188175  94.686  -76.390  53.347  1
188176  94.703  -76.389  53.308  1
188177  94.717  -76.387  53.273  1
188178  94.713  -76.389  53.241  1
188179  94.709  -76.392  53.211  1
188180  94.705  -76.394  53.182  1
188181  94.701  -76.395  53.152  1
188182  94.697  -76.398  53.122  1
188183  94.693  -76.400  53.092  1
188184  94.689  -76.402  53.066  1
188185  94.685  -76.404  53.040  1
188186  94.693  -76.408  53.015  1
188187  94.702  -76.412  52.985  1
188188  94.711  -76.416  52.949  1
188189  94.720  -76.420  52.910  1
188190  94.729  -76.424  52.867  1
188191  94.738  -76.428  52.821  1
188192  94.747  -76.432  52.775  1
188193  94.757  -76.436  52.729  1
188194  94.766  -76.439  52.682  1
188195  94.775  -76.443  52.633  1
188196  94.784  -76.447  52.584  1
188197  94.793  -76.451  52.537  1
188198  94.802  -76.455  52.490  1
188199  94.840  -76.465  52.441  1
188200  94.891  -76.478  52.392  1
188201  94.930  -76.486  52.344  1
188202  94.969  -76.494  52.292  1
188203  95.008  -76.502  52.240  1
188204  95.047  -76.510  52.187  1
188205  95.087  -76.518  52.133  1
188206  95.126  -76.527  52.082  1
188207  95.165  -76.535  52.033  1
188208  95.204  -76.542  51.985  1
188209  95.223  -76.556  51.936  1
188210  95.253  -76.567  51.890  1
188211  95.295  -76.577  51.843  1
188212  95.336  -76.587  51.799  1
188213  95.367  -76.598  51.758  1
188214  95.386  -76.608  51.715  1
188215  95.404  -76.618  51.670  1
188216  95.422  -76.629  51.624  1
188217  95.441  -76.639  51.576  1
188218  95.460  -76.649  51.530  1
188219  95.478  -76.660  51.486  1
188220  95.497  -76.670  51.444  1
188221  95.516  -76.680  51.405  1
188222  95.534  -76.690  51.367  1
188223  95.548  -76.702  51.328  1
188224  95.545  -76.718  51.290  1
188225  95.541  -76.734  51.249  1
188226  95.540  -76.749  51.209  1
188227  95.567  -76.752  51.168  1
188228  95.595  -76.754  51.127  1
188229  95.623  -76.756  51.087  1
188230  95.652  -76.759  51.047  1
188231  95.682  -76.763  51.006  1
188232  95.711  -76.766  50.965  1
188233  95.741  -76.769  50.923  1
188234  95.770  -76.772  50.881  1
188235  95.794  -76.777  50.840  1
188236  95.816  -76.781  50.797  1
188237  95.834  -76.782  50.750  1
188238  95.837  -76.767  50.702  1
188239  95.852  -76.762  50.652  1
188240  95.879  -76.768  50.603  1
188241  95.906  -76.774  50.555  1
188242  95.933  -76.781  50.506  1
188243  95.967  -76.793  50.457  1
188244  96.001  -76.807  50.403  1
188245  96.025  -76.815  50.343  1
188246  96.053  -76.824  50.280  1
188247  96.078  -76.833  50.215  1
188248  96.103  -76.841  50.153  1
188249  96.128  -76.850  50.095  1
188250  96.154  -76.859  50.040  1
188251  96.179  -76.868  49.990  1
188252  96.182  -76.882  49.945  1
188253  96.172  -76.901  49.902  1
188254  96.177  -76.915  49.860  1
188255  96.186  -76.929  49.821  1
188256  96.196  -76.942  49.786  1
188257  96.206  -76.956  49.755  1
188258  96.216  -76.969  49.726  1
188259  96.225  -76.983  49.700  1
188260  96.235  -76.996  49.674  1
188261  96.244  -77.009  49.650  1
188262  96.320  -76.962  49.628  1
188263  96.399  -76.912  49.610  1
188264  96.413  -76.925  49.593  1
188265  96.428  -76.939  49.578  1
188266  96.442  -76.953  49.563  1
188267  96.456  -76.966  49.549  1
188268  96.470  -76.980  49.535  1
188269  96.464  -76.979  49.520  1
188270  96.474  -77.021  49.507  1
188271  96.515  -77.029  49.490  1
188272  96.494  -77.035  49.471  1
188273  96.477  -77.074  49.450  1
188274  96.511  -77.082  49.427  1
188275  96.549  -77.088  49.403  1
188276  96.587  -77.094  49.380  1
188277  96.609  -77.106  49.359  1
188278  96.629  -77.111  49.337  1
188279  96.649  -77.116  49.314  1
188280  96.669  -77.121  49.289  1
188281  96.689  -77.125  49.262  1
188282  96.710  -77.130  49.234  1
188283  96.730  -77.135  49.206  1
188284  96.750  -77.140  49.178  1
188285  96.770  -77.144  49.153  1
188286  96.781  -77.148  49.127  1
188287  96.791  -77.151  49.101  1
188288  96.803  -77.156  49.076  1
188289  96.815  -77.160  49.051  1
188290  96.826  -77.163  49.026  1
188291  96.838  -77.168  49.001  1
188292  96.851  -77.172  48.977  1
188293  96.863  -77.175  48.951  1
188294  96.875  -77.180  48.925  1
188295  96.886  -77.184  48.900  1
188296  96.898  -77.188  48.874  1
188297  96.922  -77.194  48.849  1
188298  96.973  -77.203  48.823  1
188299  97.023  -77.212  48.797  1
188300  97.073  -77.224  48.771  1
188301  97.119  -77.241  48.747  1
188302  97.166  -77.257  48.723  1
188303  97.197  -77.269  48.700  1
188304  97.214  -77.278  48.676  1
188305  97.230  -77.287  48.653  1
188306  97.246  -77.295  48.631  1
188307  97.263  -77.304  48.609  1
188308  97.279  -77.313  48.587  1
188309  97.296  -77.321  48.566  1
188310  97.312  -77.330  48.546  1
188311  97.329  -77.338  48.526  1
188312  97.347  -77.349  48.506  1
188313  97.371  -77.368  48.486  1
188314  97.395  -77.388  48.466  1
188315  97.412  -77.390  48.445  1
188316  97.419  -77.385  48.425  1
188317  97.433  -77.403  48.404  1
188318  97.443  -77.410  48.383  1
188319  97.464  -77.419  48.362  1
188320  97.486  -77.426  48.340  1
188321  97.508  -77.435  48.317  1
188322  97.529  -77.443  48.295  1
188323  97.548  -77.451  48.273  1
188324  97.511  -77.442  48.248  1
188325  97.536  -77.439  48.222  1
188326  97.564  -77.438  48.195  1
188327  97.590  -77.436  48.165  1
188328  97.617  -77.435  48.135  1
188329  97.645  -77.436  48.104  1
188330  97.672  -77.439  48.073  1
188331  97.700  -77.441  48.043  1
188332  97.728  -77.442  48.012  1
188333  97.757  -77.437  47.980  1
188334  97.788  -77.425  47.948  1
188335  97.818  -77.414  47.917  1
188336  97.849  -77.401  47.885  1
188337  97.879  -77.390  47.853  1
188338  97.910  -77.378  47.820  1
188339  97.941  -77.367  47.787  1
188340  97.978  -77.362  47.754  1
188341  98.015  -77.358  47.723  1
188342  98.052  -77.355  47.692  1
188343  98.089  -77.351  47.663  1
188344  98.114  -77.348  47.635  1
188345  98.125  -77.343  47.606  1
188346  98.135  -77.339  47.578  1
188347  98.146  -77.335  47.551  1
188348  98.157  -77.330  47.524  1
188349  98.167  -77.326  47.497  1
188350  98.178  -77.322  47.469  1
188351  98.189  -77.317  47.442  1
188352  98.199  -77.313  47.414  1
188353  98.210  -77.309  47.387  1
188354  98.221  -77.304  47.360  1
188355  98.231  -77.301  47.332  1
188356  98.242  -77.296  47.305  1
188357  98.252  -77.292  47.277  1
188358  98.302  -77.301  47.249  1
188359  98.355  -77.313  47.223  1
188360  98.408  -77.325  47.199  1
188361  98.461  -77.336  47.175  1
188362  98.514  -77.348  47.152  1
188363  98.567  -77.360  47.130  1
188364  98.546  -77.323  47.108  1
188365  98.575  -77.340  47.087  1
188366  98.604  -77.357  47.067  1
188367  98.631  -77.374  47.046  1
188368  98.645  -77.390  47.025  1
188369  98.658  -77.407  47.003  1
188370  98.671  -77.423  46.981  1
188371  98.685  -77.439  46.958  1
188372  98.698  -77.454  46.937  1
188373  98.709  -77.450  46.915  1
188374  98.721  -77.446  46.893  1
188375  98.732  -77.442  46.871  1
188376  98.743  -77.438  46.848  1
188377  98.755  -77.434  46.824  1
188378  98.767  -77.430  46.801  1
188379  98.778  -77.426  46.778  1
188380  98.790  -77.422  46.756  1
188381  98.801  -77.418  46.735  1
188382  98.813  -77.414  46.712  1
188383  98.825  -77.410  46.689  1
188384  98.839  -77.406  46.665  1
188385  98.858  -77.401  46.642  1
188386  98.869  -77.409  46.618  1
188387  98.863  -77.420  46.595  1
188388  98.910  -77.426  46.571  1
188389  98.930  -77.432  46.547  1
188390  98.950  -77.438  46.524  1
188391  98.970  -77.443  46.501  1
188392  98.990  -77.449  46.479  1
188393  99.016  -77.470  46.458  1
188394  99.041  -77.491  46.436  1
188395  99.061  -77.499  46.413  1
188396  99.067  -77.511  46.389  1
188397  99.065  -77.524  46.364  1
188398  99.064  -77.538  46.341  1
188399  99.062  -77.551  46.318  1
188400  99.061  -77.564  46.296  1
188401  99.060  -77.577  46.273  1
188402  99.058  -77.591  46.251  1
188403  99.057  -77.605  46.229  1
188404  99.055  -77.617  46.205  1
188405  99.054  -77.631  46.182  1
188406  99.050  -77.631  46.160  1
188407  99.060  -77.631  46.139  1
188408  99.070  -77.631  46.117  1
188409  99.079  -77.635  46.096  1
188410  99.092  -77.639  46.075  1
188411  99.122  -77.638  46.055  1
188412  99.152  -77.637  46.034  1
188413  99.183  -77.636  46.015  1
188414  99.212  -77.636  45.997  1
188415  99.242  -77.635  45.979  1
188416  99.273  -77.635  45.962  1
188417  99.302  -77.634  45.945  1
188418  99.333  -77.633  45.929  1
188419  99.363  -77.633  45.913  1
188420  99.394  -77.635  45.899  1
188421  99.427  -77.652  45.887  1
188422  99.462  -77.668  45.875  1
188423  99.495  -77.684  45.863  1
188424  99.529  -77.701  45.851  1
188425  99.563  -77.718  45.839  1
188426  99.597  -77.734  45.828  1
188427  99.631  -77.750  45.816  1
188428  99.665  -77.767  45.804  1
188429  99.699  -77.783  45.792  1
188430  99.734  -77.799  45.778  1
188431  99.762  -77.805  45.765  1
188432  99.775  -77.817  45.752  1
188433  99.789  -77.829  45.740  1
188434  99.803  -77.843  45.727  1
188435  99.828  -77.868  45.715  1
188436  99.850  -77.882  45.703  1
188437  99.870  -77.893  45.692  1
188438  99.891  -77.906  45.681  1
188439  99.912  -77.917  45.671  1
188440  99.933  -77.929  45.661  1
188441  99.954  -77.940  45.652  1
188442  99.974  -77.953  45.643  1
188443  99.995  -77.964  45.633  1
188444  100.025  -77.970  45.622  1
188445  100.055  -77.975  45.612  1
188446  100.085  -77.980  45.600  1
188447  100.116  -77.985  45.589  1
188448  100.146  -77.990  45.578  1
188449  100.176  -77.996  45.566  1
188450  100.206  -78.000  45.553  1
188451  100.234  -78.008  45.539  1
188452  100.255  -78.022  45.525  1
188453  100.275  -78.035  45.512  1
188454  100.296  -78.049  45.497  1
188455  100.316  -78.063  45.484  1
188456  100.333  -78.075  45.471  1
188457  100.345  -78.082  45.456  1
188458  100.358  -78.090  45.442  1
188459  100.371  -78.097  45.428  1
188460  100.384  -78.106  45.413  1
188461  100.394  -78.121  45.398  1
188462  100.403  -78.134  45.383  1
188463  100.412  -78.148  45.368  1
188464  100.422  -78.163  45.353  1
188465  100.431  -78.176  45.339  1
188466  100.440  -78.191  45.324  1
188467  100.450  -78.204  45.310  1
188468  100.472  -78.197  45.296  1
188469  100.495  -78.188  45.282  1
188470  100.528  -78.192  45.267  1
188471  100.570  -78.192  45.252  1
188472  100.617  -78.200  45.236  1
188473  100.664  -78.208  45.221  1
188474  100.704  -78.214  45.206  1
188475  100.743  -78.221  45.190  1
188476  100.780  -78.227  45.175  1
188477  100.819  -78.233  45.161  1
188478  100.856  -78.240  45.146  1
188479  100.894  -78.246  45.131  1
188480  100.932  -78.252  45.116  1
188481  100.970  -78.259  45.101  1
188482  101.008  -78.265  45.087  1
188483  101.046  -78.271  45.073  1
188484  101.085  -78.278  45.059  1
188485  101.122  -78.284  45.044  1
188486  101.163  -78.291  45.028  1
188487  101.199  -78.300  45.013  1
188488  101.210  -78.319  44.998  1
188489  101.223  -78.335  44.982  1
188490  101.236  -78.353  44.966  1
188491  101.249  -78.369  44.951  1
188492  101.262  -78.386  44.935  1
188493  101.276  -78.404  44.918  1
188494  101.289  -78.420  44.903  1
188495  101.302  -78.438  44.887  1
188496  101.323  -78.457  44.870  1
188497  101.349  -78.477  44.854  1
188498  101.375  -78.498  44.837  1
188499  101.401  -78.518  44.820  1
188500  101.427  -78.539  44.804  1
188501  101.435  -78.534  44.788  1
188502  101.471  -78.555  44.772  1
188503  101.506  -78.576  44.757  1
188504  101.541  -78.598  44.742  1
188505  101.568  -78.623  44.725  1
188506  101.595  -78.648  44.709  1
188507  101.634  -78.676  44.693  1
188508  101.677  -78.702  44.676  1
188509  101.720  -78.730  44.660  1
188510  101.763  -78.757  44.644  1
188511  101.806  -78.784  44.627  1
188512  101.849  -78.811  44.611  1
188513  101.892  -78.838  44.596  1
188514  101.935  -78.865  44.580  1
188515  101.974  -78.891  44.566  1
188516  102.013  -78.916  44.552  1
188517  101.971  -79.014  44.537  1
188518  101.990  -79.020  44.523  1
188519  102.008  -79.026  44.510  1
188520  102.028  -79.028  44.496  1
188521  102.047  -79.030  44.483  1
188522  102.066  -79.031  44.470  1
188523  102.086  -79.033  44.457  1
188524  102.105  -79.035  44.445  1
188525  102.125  -79.037  44.432  1
188526  102.144  -79.038  44.419  1
188527  102.164  -79.040  44.407  1
188802  93.352  -76.467  54.100  1
188803  93.382  -76.463  54.102  1
188804  93.403  -76.464  54.104  1
188805  93.421  -76.467  54.106  1
188806  93.440  -76.470  54.107  1
188807  93.458  -76.473  54.108  1
188808  93.477  -76.477  54.108  1
188809  93.495  -76.479  54.109  1
188810  93.513  -76.482  54.110  1
188811  93.532  -76.485  54.112  1
188812  93.550  -76.488  54.114  1
188813  93.568  -76.491  54.117  1
188814  93.586  -76.494  54.119  1
188815  93.605  -76.497  54.120  1
188816  93.623  -76.499  54.123  1
188817  93.641  -76.502  54.127  1
188818  93.660  -76.505  54.132  1
188819  93.679  -76.505  54.138  1
188820  93.700  -76.495  54.146  1
188821  93.721  -76.486  54.152  1
188822  93.743  -76.476  54.161  1
188823  93.759  -76.474  54.171  1
188824  93.773  -76.473  54.182  1
188825  93.788  -76.470  54.195  1
188826  93.802  -76.466  54.207  1
188827  93.817  -76.462  54.218  1
188828  93.832  -76.459  54.226  1
188829  93.846  -76.455  54.232  1
188830  93.861  -76.451  54.238  1
188831  93.877  -76.440  54.242  1
188832  93.892  -76.434  54.244  1
188833  93.907  -76.430  54.242  1
188834  93.922  -76.425  54.237  1
188835  93.934  -76.420  54.228  1
188836  93.942  -76.420  54.220  1
188837  93.953  -76.425  54.213  1
188838  93.967  -76.429  54.207  1
188839  93.981  -76.433  54.201  1
188840  93.995  -76.437  54.198  1
188841  94.012  -76.435  54.194  1
188842  94.031  -76.430  54.187  1
188843  94.049  -76.426  54.183  1
188844  94.068  -76.422  54.183  1
188845  94.086  -76.418  54.185  1
188846  94.104  -76.414  54.189  1
188847  94.130  -76.408  54.191  1
188848  94.158  -76.404  54.187  1
188849  94.175  -76.398  54.179  1
188850  94.194  -76.395  54.170  1
188851  94.213  -76.393  54.156  1
188852  94.233  -76.392  54.141  1
188853  94.253  -76.390  54.125  1
188854  94.272  -76.389  54.108  1
188855  94.292  -76.387  54.083  1
188856  94.312  -76.385  54.056  1
188857  94.332  -76.383  54.027  1
188858  94.351  -76.382  53.996  1
188859  94.371  -76.380  53.964  1
188860  94.391  -76.379  53.933  1
188861  94.410  -76.377  53.902  1
188862  94.430  -76.376  53.866  1
188863  94.449  -76.374  53.827  1
188864  94.470  -76.372  53.786  1
188865  94.490  -76.370  53.745  1
188866  94.510  -76.367  53.708  1
188867  94.531  -76.364  53.673  1
188868  94.551  -76.362  53.639  1
188869  94.571  -76.360  53.605  1
188870  94.592  -76.357  53.570  1
188871  94.611  -76.357  53.536  1
188872  94.624  -76.364  53.503  1
188873  94.636  -76.370  53.472  1
188874  94.649  -76.377  53.441  1
188875  94.662  -76.384  53.407  1
188876  94.676  -76.386  53.368  1
188877  94.693  -76.385  53.329  1
188878  94.708  -76.383  53.292  1
188879  94.704  -76.385  53.258  1
188880  94.700  -76.387  53.227  1
188881  94.696  -76.389  53.198  1
188882  94.692  -76.392  53.167  1
188883  94.688  -76.394  53.136  1
188884  94.684  -76.396  53.105  1
188885  94.684  -76.398  53.075  1
188886  94.693  -76.402  53.047  1
188887  94.702  -76.407  53.019  1
188888  94.711  -76.411  52.989  1
188889  94.720  -76.414  52.953  1
188890  94.730  -76.418  52.912  1
188891  94.739  -76.422  52.870  1
188892  94.748  -76.426  52.826  1
188893  94.757  -76.430  52.782  1
188894  94.766  -76.433  52.738  1
188895  94.775  -76.437  52.694  1
188896  94.784  -76.441  52.648  1
188897  94.793  -76.445  52.602  1
188898  94.803  -76.449  52.556  1
188899  94.812  -76.453  52.510  1
188900  94.827  -76.458  52.463  1
188901  94.875  -76.470  52.415  1
188902  94.914  -76.478  52.366  1
188903  94.954  -76.486  52.313  1
188904  94.993  -76.494  52.260  1
188905  95.032  -76.502  52.205  1
188906  95.071  -76.511  52.149  1
188907  95.110  -76.519  52.097  1
188908  95.149  -76.527  52.048  1
188909  95.188  -76.535  51.999  1
188910  95.217  -76.546  51.951  1
188911  95.256  -76.556  51.904  1
188912  95.283  -76.566  51.857  1
188913  95.302  -76.577  51.812  1
188914  95.321  -76.587  51.772  1
188915  95.339  -76.597  51.730  1
188916  95.358  -76.608  51.687  1
188917  95.377  -76.618  51.642  1
188918  95.395  -76.628  51.594  1
188919  95.414  -76.639  51.547  1
188920  95.432  -76.649  51.502  1
188921  95.451  -76.659  51.459  1
188922  95.470  -76.670  51.418  1
188923  95.488  -76.680  51.378  1
188924  95.507  -76.690  51.339  1
188925  95.525  -76.700  51.300  1
188926  95.524  -76.716  51.260  1
188927  95.544  -76.722  51.220  1
188928  95.572  -76.724  51.180  1
188929  95.602  -76.727  51.139  1
188930  95.632  -76.730  51.100  1
188931  95.662  -76.734  51.060  1
188932  95.691  -76.737  51.019  1
188933  95.721  -76.740  50.977  1
188934  95.751  -76.743  50.934  1
188935  95.776  -76.747  50.892  1
188936  95.799  -76.752  50.850  1
188937  95.821  -76.756  50.808  1
188938  95.844  -76.762  50.764  1
188939  95.855  -76.754  50.718  1
188940  95.858  -76.739  50.673  1
188941  95.864  -76.727  50.627  1
188942  95.899  -76.740  50.579  1
188943  95.943  -76.761  50.531  1
188944  95.983  -76.780  50.481  1
188945  96.003  -76.785  50.428  1
188946  96.023  -76.790  50.370  1
188947  96.051  -76.799  50.308  1
188948  96.084  -76.810  50.245  1
188949  96.110  -76.818  50.183  1
188950  96.135  -76.828  50.125  1
188951  96.160  -76.836  50.070  1
188952  96.185  -76.845  50.020  1
188953  96.179  -76.862  49.976  1
188954  96.182  -76.878  49.933  1
188955  96.192  -76.891  49.892  1
188956  96.201  -76.904  49.853  1
188957  96.211  -76.918  49.819  1
188958  96.221  -76.931  49.787  1
188959  96.230  -76.945  49.758  1
188960  96.240  -76.958  49.732  1
188961  96.249  -76.972  49.707  1
188962  96.259  -76.985  49.683  1
188963  96.310  -76.959  49.662  1
188964  96.416  -76.884  49.643  1
188965  96.445  -76.884  49.626  1
188966  96.459  -76.897  49.611  1
188967  96.473  -76.910  49.596  1
188968  96.453  -76.901  49.582  1
188969  96.438  -76.914  49.568  1
188970  96.461  -76.970  49.554  1
188971  96.484  -77.026  49.539  1
188972  96.519  -77.028  49.521  1
188973  96.491  -77.060  49.500  1
188974  96.495  -77.049  49.478  1
188975  96.514  -77.034  49.454  1
188976  96.548  -77.045  49.430  1
188977  96.583  -77.056  49.407  1
188978  96.617  -77.076  49.386  1
188979  96.641  -77.088  49.364  1
188980  96.661  -77.092  49.340  1
188981  96.681  -77.097  49.314  1
188982  96.701  -77.102  49.286  1
188983  96.721  -77.106  49.256  1
188984  96.741  -77.111  49.227  1
188985  96.761  -77.116  49.200  1
188986  96.782  -77.121  49.174  1
188987  96.795  -77.132  49.147  1
188988  96.807  -77.143  49.120  1
188989  96.819  -77.147  49.094  1
188990  96.831  -77.151  49.068  1
188991  96.843  -77.156  49.043  1
188992  96.855  -77.160  49.018  1
188993  96.867  -77.164  48.994  1
188994  96.879  -77.168  48.968  1
188995  96.891  -77.172  48.943  1
188996  96.903  -77.176  48.917  1
188997  96.915  -77.180  48.892  1
188998  96.927  -77.184  48.866  1
188999  96.976  -77.193  48.839  1
189000  97.027  -77.202  48.813  1
189001  97.075  -77.216  48.787  1
189002  97.122  -77.232  48.762  1
189003  97.168  -77.248  48.738  1
189004  97.215  -77.265  48.714  1
189005  97.231  -77.273  48.690  1
189006  97.248  -77.282  48.667  1
189007  97.264  -77.291  48.644  1
189008  97.281  -77.300  48.622  1
189009  97.297  -77.308  48.599  1
189010  97.314  -77.316  48.578  1
189011  97.330  -77.326  48.557  1
189012  97.347  -77.334  48.538  1
189013  97.363  -77.342  48.518  1
189014  97.379  -77.351  48.498  1
189015  97.396  -77.360  48.477  1
189016  97.417  -77.374  48.456  1
189017  97.430  -77.379  48.435  1
189018  97.452  -77.388  48.415  1
189019  97.473  -77.396  48.392  1
189020  97.495  -77.404  48.371  1
189021  97.517  -77.412  48.348  1
189022  97.538  -77.420  48.325  1
189023  97.560  -77.429  48.303  1
189024  97.532  -77.423  48.280  1
189025  97.524  -77.417  48.255  1
189026  97.551  -77.415  48.229  1
189027  97.578  -77.413  48.200  1
189028  97.605  -77.410  48.170  1
189029  97.632  -77.409  48.140  1
189030  97.659  -77.409  48.109  1
189031  97.687  -77.411  48.078  1
189032  97.715  -77.414  48.047  1
189033  97.742  -77.415  48.016  1
189034  97.771  -77.411  47.985  1
189035  97.802  -77.399  47.954  1
189036  97.832  -77.388  47.922  1
189037  97.863  -77.376  47.891  1
189038  97.893  -77.364  47.860  1
189039  97.924  -77.352  47.826  1
189040  97.955  -77.340  47.793  1
189041  97.986  -77.329  47.759  1
189042  98.016  -77.316  47.728  1
189043  98.053  -77.313  47.697  1
189044  98.090  -77.309  47.668  1
189045  98.118  -77.305  47.640  1
189046  98.128  -77.301  47.612  1
189047  98.139  -77.297  47.585  1
189048  98.149  -77.292  47.557  1
189049  98.160  -77.288  47.531  1
189050  98.171  -77.284  47.503  1
189051  98.181  -77.279  47.475  1
189052  98.192  -77.275  47.448  1
189053  98.204  -77.271  47.421  1
189054  98.217  -77.266  47.393  1
189055  98.230  -77.263  47.366  1
189056  98.244  -77.258  47.339  1
189057  98.257  -77.254  47.311  1
189058  98.273  -77.273  47.283  1
189059  98.308  -77.276  47.255  1
189060  98.358  -77.286  47.228  1
189061  98.411  -77.298  47.204  1
189062  98.464  -77.309  47.180  1
189063  98.517  -77.321  47.157  1
189064  98.538  -77.311  47.134  1
189065  98.552  -77.312  47.112  1
189066  98.581  -77.329  47.092  1
189067  98.610  -77.346  47.072  1
189068  98.639  -77.363  47.050  1
189069  98.663  -77.379  47.029  1
189070  98.676  -77.396  47.008  1
189071  98.689  -77.412  46.987  1
189072  98.703  -77.429  46.964  1
189073  98.715  -77.436  46.942  1
189074  98.726  -77.432  46.920  1
189075  98.738  -77.428  46.899  1
189076  98.749  -77.424  46.876  1
189077  98.761  -77.420  46.854  1
189078  98.773  -77.416  46.832  1
189079  98.784  -77.412  46.808  1
189080  98.796  -77.408  46.786  1
189081  98.807  -77.404  46.765  1
189082  98.819  -77.400  46.744  1
189083  98.830  -77.396  46.720  1
189084  98.842  -77.392  46.697  1
189085  98.853  -77.388  46.673  1
189086  98.867  -77.385  46.649  1
189087  98.886  -77.392  46.626  1
189088  98.906  -77.398  46.603  1
189089  98.926  -77.403  46.579  1
189090  98.946  -77.409  46.554  1
189091  98.966  -77.414  46.531  1
189092  98.986  -77.420  46.507  1
189093  99.007  -77.428  46.484  1
189094  99.034  -77.454  46.464  1
189095  99.061  -77.479  46.442  1
189096  99.073  -77.489  46.419  1
189097  99.071  -77.502  46.395  1
189098  99.070  -77.516  46.370  1
189099  99.069  -77.529  46.345  1
189100  99.067  -77.542  46.322  1
189101  99.066  -77.555  46.301  1
189102  99.064  -77.569  46.278  1
189103  99.063  -77.582  46.255  1
189104  99.062  -77.595  46.232  1
189105  99.060  -77.609  46.208  1
189106  99.059  -77.622  46.185  1
189107  99.055  -77.630  46.164  1
189108  99.065  -77.630  46.143  1
189109  99.074  -77.633  46.120  1
189110  99.100  -77.633  46.099  1
189111  99.131  -77.633  46.078  1
189112  99.161  -77.632  46.058  1
189113  99.191  -77.631  46.037  1
189114  99.221  -77.630  46.018  1
189115  99.251  -77.630  45.999  1
189116  99.281  -77.629  45.982  1
189117  99.311  -77.629  45.965  1
189118  99.341  -77.628  45.948  1
189119  99.371  -77.627  45.931  1
189120  99.401  -77.627  45.915  1
189121  99.431  -77.626  45.901  1
189122  99.464  -77.635  45.889  1
189123  99.497  -77.651  45.876  1
189124  99.532  -77.667  45.864  1
189125  99.565  -77.684  45.852  1
189126  99.600  -77.700  45.840  1
189127  99.633  -77.717  45.828  1
189128  99.667  -77.733  45.816  1
189129  99.701  -77.750  45.803  1
189130  99.735  -77.766  45.790  1
189131  99.768  -77.774  45.777  1
189132  99.781  -77.786  45.764  1
189133  99.795  -77.798  45.751  1
189134  99.808  -77.810  45.737  1
189135  99.822  -77.822  45.724  1
189136  99.844  -77.845  45.712  1
189137  99.868  -77.868  45.700  1
189138  99.889  -77.880  45.689  1
189139  99.910  -77.892  45.677  1
189140  99.931  -77.903  45.667  1
189141  99.951  -77.915  45.658  1
189142  99.972  -77.927  45.648  1
189143  99.993  -77.939  45.639  1
189144  100.017  -77.948  45.630  1
189145  100.048  -77.953  45.620  1
189146  100.078  -77.958  45.609  1
189147  100.109  -77.963  45.599  1
189148  100.139  -77.968  45.587  1
189149  100.169  -77.974  45.576  1
189150  100.199  -77.978  45.563  1
189151  100.221  -77.991  45.550  1
189152  100.242  -78.005  45.537  1
189153  100.262  -78.018  45.523  1
189154  100.282  -78.033  45.511  1
189155  100.303  -78.047  45.496  1
189156  100.323  -78.060  45.483  1
189157  100.342  -78.073  45.469  1
189158  100.353  -78.081  45.456  1
189159  100.366  -78.088  45.442  1
189160  100.379  -78.096  45.427  1
189161  100.393  -78.103  45.412  1
189162  100.406  -78.110  45.397  1
189163  100.416  -78.124  45.382  1
189164  100.426  -78.138  45.367  1
189165  100.435  -78.151  45.352  1
189166  100.444  -78.166  45.337  1
189167  100.454  -78.179  45.323  1
189168  100.464  -78.194  45.309  1
189169  100.485  -78.187  45.294  1
189170  100.508  -78.177  45.280  1
189171  100.537  -78.175  45.266  1
189172  100.581  -78.179  45.250  1
189173  100.627  -78.187  45.235  1
189174  100.665  -78.193  45.221  1
189175  100.703  -78.199  45.206  1
189176  100.741  -78.205  45.190  1
189177  100.779  -78.212  45.175  1
189178  100.817  -78.218  45.160  1
189179  100.855  -78.224  45.145  1
189180  100.894  -78.232  45.131  1
189181  100.935  -78.239  45.116  1
189182  100.976  -78.247  45.102  1
189183  101.016  -78.254  45.088  1
189184  101.057  -78.262  45.074  1
189185  101.098  -78.269  45.060  1
189186  101.139  -78.277  45.045  1
189187  101.179  -78.285  45.030  1
189188  101.208  -78.297  45.015  1
189189  101.220  -78.315  45.000  1
189190  101.230  -78.333  44.985  1
189191  101.239  -78.351  44.969  1
189192  101.249  -78.369  44.953  1
189193  101.263  -78.387  44.937  1
189194  101.276  -78.404  44.921  1
189195  101.289  -78.420  44.906  1
189196  101.303  -78.438  44.890  1
189197  101.329  -78.458  44.873  1
189198  101.355  -78.479  44.857  1
189199  101.346  -78.458  44.840  1
189200  101.381  -78.479  44.823  1
189201  101.416  -78.501  44.807  1
189202  101.452  -78.522  44.791  1
189203  101.487  -78.543  44.775  1
189204  101.523  -78.564  44.759  1
189205  101.554  -78.587  44.743  1
189206  101.581  -78.613  44.726  1
189207  101.608  -78.639  44.710  1
189208  101.634  -78.664  44.694  1
189209  101.675  -78.691  44.677  1
189210  101.718  -78.718  44.661  1
189211  101.761  -78.745  44.645  1
189212  101.804  -78.772  44.628  1
189213  101.847  -78.799  44.612  1
189214  101.890  -78.827  44.597  1
189215  101.933  -78.854  44.582  1
189216  101.976  -78.880  44.568  1
189217  101.956  -78.981  44.554  1
189218  101.994  -79.006  44.539  1
189219  102.013  -79.008  44.525  1
189220  102.033  -79.009  44.511  1
189221  102.052  -79.011  44.498  1
189222  102.072  -79.012  44.485  1
189223  102.092  -79.014  44.472  1
189224  102.111  -79.016  44.459  1
189225  102.130  -79.018  44.447  1
189226  102.150  -79.019  44.433  1
189227  102.169  -79.021  44.421  1
189228  102.189  -79.022  44.408  1
189229  102.208  -79.024  44.394  1
189505  93.395  -76.441  54.094  1
189506  93.413  -76.444  54.096  1
189507  93.432  -76.447  54.098  1
189508  93.450  -76.450  54.099  1
189509  93.468  -76.453  54.100  1
189510  93.487  -76.456  54.101  1
189511  93.505  -76.458  54.103  1
189512  93.523  -76.461  54.106  1
189513  93.542  -76.464  54.108  1
189514  93.560  -76.467  54.111  1
189515  93.578  -76.470  54.113  1
189516  93.596  -76.473  54.115  1
189517  93.615  -76.476  54.118  1
189518  93.633  -76.479  54.121  1
189519  93.652  -76.482  54.126  1
189520  93.670  -76.485  54.132  1
189521  93.689  -76.486  54.140  1
189522  93.710  -76.477  54.145  1
189523  93.731  -76.467  54.153  1
189524  93.751  -76.458  54.163  1
189525  93.766  -76.459  54.175  1
189526  93.780  -76.456  54.188  1
189527  93.795  -76.452  54.201  1
189528  93.810  -76.448  54.212  1
189529  93.825  -76.445  54.219  1
189530  93.839  -76.441  54.226  1
189531  93.854  -76.436  54.231  1
189532  93.870  -76.420  54.236  1
189533  93.886  -76.413  54.238  1
189534  93.901  -76.408  54.239  1
189535  93.916  -76.404  54.236  1
189536  93.931  -76.399  54.229  1
189537  93.948  -76.400  54.222  1
189538  93.965  -76.403  54.216  1
189539  93.982  -76.406  54.210  1
189540  93.996  -76.410  54.205  1
189541  94.011  -76.414  54.204  1
189542  94.027  -76.414  54.201  1
189543  94.045  -76.410  54.197  1
189544  94.064  -76.405  54.192  1
189545  94.082  -76.401  54.191  1
189546  94.100  -76.397  54.193  1
189547  94.119  -76.393  54.197  1
189548  94.137  -76.389  54.200  1
189549  94.155  -76.384  54.196  1
189550  94.175  -76.381  54.189  1
189551  94.195  -76.379  54.180  1
189552  94.214  -76.377  54.167  1
189553  94.234  -76.376  54.152  1
189554  94.254  -76.374  54.136  1
189555  94.273  -76.373  54.118  1
189556  94.293  -76.371  54.092  1
189557  94.313  -76.370  54.064  1
189558  94.333  -76.368  54.035  1
189559  94.352  -76.366  54.004  1
189560  94.372  -76.364  53.973  1
189561  94.392  -76.363  53.943  1
189562  94.412  -76.361  53.913  1
189563  94.431  -76.360  53.878  1
189564  94.449  -76.358  53.840  1
189565  94.468  -76.357  53.800  1
189566  94.486  -76.356  53.761  1
189567  94.505  -76.355  53.724  1
189568  94.525  -76.353  53.689  1
189569  94.545  -76.351  53.656  1
189570  94.566  -76.348  53.622  1
189571  94.586  -76.345  53.589  1
189572  94.603  -76.348  53.556  1
189573  94.616  -76.354  53.525  1
189574  94.628  -76.361  53.494  1
189575  94.641  -76.368  53.462  1
189576  94.653  -76.375  53.427  1
189577  94.666  -76.382  53.389  1
189578  94.682  -76.380  53.349  1
189579  94.699  -76.379  53.313  1
189580  94.695  -76.380  53.278  1
189581  94.691  -76.383  53.246  1
189582  94.687  -76.385  53.216  1
189583  94.683  -76.387  53.184  1
189584  94.679  -76.389  53.151  1
189585  94.684  -76.393  53.120  1
189586  94.693  -76.397  53.088  1
189587  94.702  -76.401  53.057  1
189588  94.712  -76.404  53.027  1
189589  94.721  -76.408  52.997  1
189590  94.730  -76.412  52.960  1
189591  94.739  -76.416  52.921  1
189592  94.748  -76.420  52.880  1
189593  94.757  -76.423  52.837  1
189594  94.766  -76.428  52.794  1
189595  94.775  -76.432  52.752  1
189596  94.784  -76.436  52.711  1
189597  94.793  -76.439  52.665  1
189598  94.803  -76.443  52.619  1
189599  94.812  -76.447  52.572  1
189600  94.821  -76.451  52.525  1
189601  94.830  -76.455  52.479  1
189602  94.859  -76.462  52.432  1
189603  94.899  -76.470  52.383  1
189604  94.938  -76.478  52.330  1
189605  94.977  -76.486  52.276  1
189606  95.016  -76.495  52.221  1
189607  95.057  -76.503  52.164  1
189608  95.099  -76.511  52.111  1
189609  95.140  -76.519  52.060  1
189610  95.181  -76.527  52.011  1
189611  95.216  -76.533  51.964  1
189612  95.237  -76.539  51.915  1
189613  95.256  -76.550  51.868  1
189614  95.275  -76.560  51.825  1
189615  95.294  -76.571  51.786  1
189616  95.313  -76.580  51.746  1
189617  95.332  -76.591  51.703  1
189618  95.351  -76.601  51.659  1
189619  95.371  -76.611  51.612  1
189620  95.390  -76.621  51.565  1
189621  95.408  -76.631  51.519  1
189622  95.427  -76.642  51.474  1
189623  95.447  -76.652  51.432  1
189624  95.466  -76.662  51.392  1
189625  95.485  -76.672  51.353  1
189626  95.503  -76.683  51.313  1
189627  95.523  -76.693  51.274  1
189628  95.552  -76.696  51.235  1
189629  95.582  -76.699  51.195  1
189630  95.612  -76.702  51.155  1
189631  95.641  -76.705  51.115  1
189632  95.671  -76.708  51.075  1
189633  95.701  -76.712  51.034  1
189634  95.731  -76.715  50.992  1
189635  95.758  -76.718  50.949  1
189636  95.781  -76.722  50.906  1
189637  95.804  -76.727  50.864  1
189638  95.827  -76.732  50.822  1
189639  95.849  -76.737  50.780  1
189640  95.872  -76.741  50.738  1
189641  95.875  -76.726  50.697  1
189642  95.878  -76.712  50.653  1
189643  95.918  -76.729  50.606  1
189644  95.962  -76.749  50.556  1
189645  95.986  -76.758  50.506  1
189646  96.006  -76.763  50.453  1
189647  96.026  -76.768  50.396  1
189648  96.045  -76.774  50.337  1
189649  96.077  -76.784  50.275  1
189650  96.110  -76.795  50.214  1
189651  96.142  -76.805  50.155  1
189652  96.167  -76.814  50.101  1
189653  96.187  -76.824  50.051  1
189654  96.187  -76.840  50.006  1
189655  96.197  -76.853  49.964  1
189656  96.206  -76.866  49.924  1
189657  96.216  -76.880  49.886  1
189658  96.226  -76.893  49.852  1
189659  96.235  -76.907  49.821  1
189660  96.245  -76.920  49.792  1
189661  96.254  -76.934  49.766  1
189662  96.264  -76.947  49.741  1
189663  96.273  -76.961  49.718  1
189664  96.301  -76.958  49.696  1
189665  96.406  -76.882  49.679  1
189666  96.476  -76.841  49.662  1
189667  96.443  -76.823  49.646  1
189668  96.401  -76.807  49.631  1
189669  96.425  -76.863  49.616  1
189670  96.448  -76.919  49.603  1
189671  96.472  -76.975  49.589  1
189672  96.495  -77.032  49.572  1
189673  96.506  -77.046  49.552  1
189674  96.505  -77.046  49.530  1
189675  96.515  -77.019  49.506  1
189676  96.525  -76.991  49.482  1
189677  96.553  -76.992  49.458  1
189678  96.588  -77.003  49.435  1
189679  96.622  -77.027  49.414  1
189680  96.655  -77.056  49.391  1
189681  96.678  -77.064  49.366  1
189682  96.698  -77.069  49.338  1
189683  96.718  -77.074  49.308  1
189684  96.738  -77.078  49.278  1
189685  96.758  -77.084  49.250  1
189686  96.779  -77.088  49.222  1
189687  96.797  -77.094  49.194  1
189688  96.810  -77.106  49.167  1
189689  96.822  -77.117  49.139  1
189690  96.834  -77.128  49.111  1
189691  96.847  -77.139  49.085  1
189692  96.859  -77.147  49.060  1
189693  96.871  -77.152  49.036  1
189694  96.883  -77.156  49.011  1
189695  96.895  -77.160  48.985  1
189696  96.907  -77.164  48.960  1
189697  96.919  -77.168  48.935  1
189698  96.931  -77.172  48.910  1
189699  96.943  -77.176  48.883  1
189700  96.979  -77.183  48.855  1
189701  97.030  -77.192  48.829  1
189702  97.078  -77.207  48.802  1
189703  97.124  -77.224  48.777  1
189704  97.171  -77.240  48.753  1
189705  97.218  -77.257  48.728  1
189706  97.249  -77.269  48.705  1
189707  97.265  -77.278  48.681  1
189708  97.282  -77.286  48.657  1
189709  97.299  -77.295  48.635  1
189710  97.315  -77.304  48.613  1
189711  97.331  -77.312  48.591  1
189712  97.348  -77.321  48.571  1
189713  97.365  -77.329  48.551  1
189714  97.381  -77.338  48.531  1
189715  97.397  -77.347  48.511  1
189716  97.414  -77.355  48.490  1
189717  97.425  -77.351  48.469  1
189718  97.461  -77.365  48.447  1
189719  97.483  -77.373  48.426  1
189720  97.504  -77.382  48.403  1
189721  97.526  -77.390  48.380  1
189722  97.547  -77.398  48.357  1
189723  97.569  -77.406  48.334  1
189724  97.554  -77.404  48.311  1
189725  97.516  -77.395  48.288  1
189726  97.539  -77.392  48.262  1
189727  97.566  -77.390  48.234  1
189728  97.593  -77.388  48.205  1
189729  97.620  -77.386  48.175  1
189730  97.647  -77.384  48.145  1
189731  97.674  -77.382  48.115  1
189732  97.701  -77.384  48.084  1
189733  97.729  -77.386  48.052  1
189734  97.756  -77.388  48.021  1
189735  97.785  -77.385  47.991  1
189736  97.816  -77.373  47.959  1
189737  97.846  -77.361  47.927  1
189738  97.877  -77.350  47.895  1
189739  97.908  -77.338  47.863  1
189740  97.938  -77.326  47.830  1
189741  97.969  -77.314  47.798  1
189742  98.000  -77.303  47.765  1
189743  98.030  -77.291  47.734  1
189744  98.061  -77.279  47.704  1
189745  98.092  -77.267  47.674  1
189746  98.121  -77.263  47.646  1
189747  98.132  -77.258  47.617  1
189748  98.143  -77.254  47.589  1
189749  98.156  -77.250  47.562  1
189750  98.169  -77.246  47.534  1
189751  98.182  -77.241  47.507  1
189752  98.196  -77.237  47.481  1
189753  98.209  -77.233  47.454  1
189754  98.222  -77.229  47.426  1
189755  98.235  -77.225  47.399  1
189756  98.248  -77.220  47.371  1
189757  98.262  -77.216  47.344  1
189758  98.277  -77.235  47.316  1
189759  98.295  -77.254  47.288  1
189760  98.331  -77.257  47.260  1
189761  98.366  -77.261  47.234  1
189762  98.414  -77.270  47.210  1
189763  98.467  -77.282  47.187  1
189764  98.520  -77.294  47.163  1
189765  98.529  -77.284  47.139  1
189766  98.558  -77.301  47.117  1
189767  98.587  -77.318  47.096  1
189768  98.616  -77.335  47.076  1
189769  98.645  -77.351  47.055  1
189770  98.674  -77.368  47.034  1
189771  98.694  -77.385  47.014  1
189772  98.707  -77.401  46.992  1
189773  98.721  -77.418  46.970  1
189774  98.732  -77.418  46.948  1
189775  98.744  -77.414  46.927  1
189776  98.756  -77.410  46.905  1
189777  98.767  -77.406  46.883  1
189778  98.779  -77.402  46.861  1
189779  98.790  -77.398  46.839  1
189780  98.802  -77.394  46.816  1
189781  98.813  -77.390  46.795  1
189782  98.825  -77.386  46.774  1
189783  98.836  -77.382  46.752  1
189784  98.847  -77.382  46.728  1
189785  98.858  -77.382  46.704  1
189786  98.869  -77.382  46.680  1
189787  98.880  -77.382  46.656  1
189788  98.902  -77.373  46.634  1
189789  98.922  -77.374  46.611  1
189790  98.942  -77.380  46.586  1
189791  98.962  -77.385  46.561  1
189792  98.982  -77.392  46.536  1
189793  99.002  -77.398  46.512  1
189794  99.025  -77.411  46.490  1
189795  99.053  -77.437  46.468  1
189796  99.077  -77.463  46.446  1
189797  99.080  -77.480  46.424  1
189798  99.078  -77.493  46.401  1
189799  99.077  -77.507  46.376  1
189800  99.075  -77.520  46.351  1
189801  99.073  -77.533  46.327  1
189802  99.071  -77.547  46.305  1
189803  99.069  -77.560  46.282  1
189804  99.068  -77.573  46.259  1
189805  99.066  -77.586  46.237  1
189806  99.065  -77.600  46.214  1
189807  99.063  -77.613  46.190  1
189808  99.062  -77.627  46.168  1
189809  99.079  -77.628  46.147  1
189810  99.109  -77.627  46.125  1
189811  99.139  -77.627  46.103  1
189812  99.169  -77.627  46.082  1
189813  99.199  -77.626  46.061  1
189814  99.229  -77.625  46.040  1
189815  99.260  -77.624  46.020  1
189816  99.289  -77.624  46.002  1
189817  99.320  -77.623  45.984  1
189818  99.350  -77.622  45.966  1
189819  99.379  -77.622  45.949  1
189820  99.410  -77.621  45.933  1
189821  99.440  -77.620  45.918  1
189822  99.470  -77.620  45.904  1
189823  99.500  -77.619  45.890  1
189824  99.534  -77.634  45.877  1
189825  99.567  -77.651  45.865  1
189826  99.602  -77.667  45.853  1
189827  99.635  -77.683  45.841  1
189828  99.669  -77.700  45.828  1
189829  99.703  -77.716  45.815  1
189830  99.737  -77.733  45.803  1
189831  99.774  -77.743  45.790  1
189832  99.788  -77.755  45.776  1
189833  99.801  -77.767  45.762  1
189834  99.815  -77.779  45.749  1
189835  99.828  -77.791  45.736  1
189836  99.842  -77.803  45.722  1
189837  99.859  -77.821  45.709  1
189838  99.885  -77.846  45.698  1
189839  99.908  -77.866  45.686  1
189840  99.928  -77.878  45.674  1
189841  99.949  -77.890  45.664  1
189842  99.970  -77.902  45.655  1
189843  99.991  -77.913  45.645  1
189844  100.012  -77.925  45.636  1
189845  100.041  -77.931  45.627  1
189846  100.071  -77.936  45.618  1
189847  100.102  -77.941  45.608  1
189848  100.132  -77.946  45.597  1
189849  100.162  -77.952  45.585  1
189850  100.188  -77.961  45.574  1
189851  100.208  -77.975  45.561  1
189852  100.228  -77.988  45.548  1
189853  100.249  -78.003  45.535  1
189854  100.269  -78.016  45.522  1
189855  100.289  -78.030  45.508  1
189856  100.310  -78.044  45.495  1
189857  100.331  -78.058  45.481  1
189858  100.350  -78.072  45.468  1
189859  100.361  -78.078  45.454  1
189860  100.374  -78.086  45.440  1
189861  100.388  -78.094  45.426  1
189862  100.401  -78.101  45.411  1
189863  100.414  -78.109  45.395  1
189864  100.428  -78.116  45.380  1
189865  100.439  -78.127  45.365  1
189866  100.449  -78.141  45.351  1
189867  100.458  -78.154  45.336  1
189868  100.468  -78.169  45.322  1
189869  100.477  -78.182  45.308  1
189870  100.498  -78.175  45.293  1
189871  100.522  -78.166  45.279  1
189872  100.546  -78.159  45.264  1
189873  100.587  -78.165  45.249  1
189874  100.626  -78.172  45.234  1
189875  100.666  -78.179  45.220  1
189876  100.707  -78.187  45.206  1
189877  100.748  -78.194  45.190  1
189878  100.788  -78.202  45.175  1
189879  100.829  -78.210  45.159  1
189880  100.870  -78.217  45.144  1
189881  100.911  -78.225  45.130  1
189882  100.952  -78.232  45.115  1
189883  100.992  -78.240  45.101  1
189884  101.033  -78.247  45.087  1
189885  101.073  -78.255  45.074  1
189886  101.114  -78.263  45.060  1
189887  101.155  -78.270  45.045  1
189888  101.196  -78.278  45.031  1
189889  101.218  -78.292  45.016  1
189890  101.230  -78.310  45.001  1
189891  101.241  -78.329  44.986  1
189892  101.250  -78.347  44.970  1
189893  101.260  -78.366  44.955  1
189894  101.269  -78.384  44.939  1
189895  101.279  -78.402  44.923  1
189896  101.289  -78.420  44.908  1
189897  101.281  -78.409  44.892  1
189898  101.292  -78.404  44.875  1
189899  101.327  -78.425  44.859  1
189900  101.362  -78.446  44.843  1
189901  101.398  -78.467  44.826  1
189902  101.433  -78.488  44.810  1
189903  101.468  -78.509  44.793  1
189904  101.503  -78.530  44.777  1
189905  101.539  -78.551  44.761  1
189906  101.566  -78.576  44.744  1
189907  101.594  -78.602  44.727  1
189908  101.620  -78.628  44.711  1
189909  101.647  -78.654  44.694  1
189910  101.674  -78.680  44.678  1
189911  101.716  -78.706  44.662  1
189912  101.759  -78.733  44.645  1
189913  101.802  -78.761  44.629  1
189914  101.845  -78.788  44.614  1
189915  101.888  -78.814  44.599  1
189916  101.889  -78.891  44.584  1
189917  101.932  -78.923  44.569  1
189918  101.975  -78.955  44.556  1
189919  102.018  -78.987  44.541  1
189920  102.039  -78.990  44.527  1
189921  102.058  -78.992  44.513  1
189922  102.078  -78.993  44.500  1
189923  102.097  -78.995  44.486  1
189924  102.117  -78.996  44.473  1
189925  102.136  -78.999  44.460  1
189926  102.156  -79.000  44.447  1
189927  102.175  -79.002  44.435  1
189928  102.194  -79.003  44.422  1
189929  102.214  -79.005  44.408  1
189930  102.233  -79.006  44.395  1
190209  93.442  -76.426  54.091  1
190210  93.460  -76.430  54.093  1
190211  93.479  -76.433  54.093  1
190212  93.497  -76.435  54.096  1
190213  93.515  -76.438  54.099  1
190214  93.534  -76.441  54.102  1
190215  93.552  -76.444  54.106  1
190216  93.570  -76.447  54.108  1
190217  93.588  -76.450  54.110  1
190218  93.607  -76.453  54.113  1
190219  93.625  -76.455  54.116  1
190220  93.644  -76.458  54.120  1
190221  93.662  -76.461  54.126  1
190222  93.680  -76.464  54.134  1
190223  93.699  -76.467  54.139  1
190224  93.720  -76.458  54.146  1
190225  93.741  -76.448  54.155  1
190226  93.759  -76.443  54.168  1
190227  93.773  -76.442  54.182  1
190228  93.788  -76.438  54.195  1
190229  93.802  -76.435  54.207  1
190230  93.818  -76.431  54.213  1
190231  93.832  -76.427  54.220  1
190232  93.848  -76.415  54.225  1
190233  93.864  -76.399  54.229  1
190234  93.880  -76.391  54.231  1
190235  93.895  -76.386  54.233  1
190236  93.910  -76.382  54.233  1
190237  93.925  -76.378  54.227  1
190238  93.944  -76.384  54.219  1
190239  93.962  -76.389  54.213  1
190240  93.979  -76.391  54.208  1
190241  93.995  -76.394  54.206  1
190242  94.012  -76.397  54.207  1
190243  94.030  -76.397  54.205  1
190244  94.047  -76.393  54.200  1
190245  94.065  -76.389  54.196  1
190246  94.082  -76.385  54.195  1
190247  94.101  -76.381  54.197  1
190248  94.118  -76.377  54.201  1
190249  94.136  -76.373  54.204  1
190250  94.154  -76.370  54.201  1
190251  94.175  -76.367  54.195  1
190252  94.196  -76.364  54.188  1
190253  94.215  -76.361  54.175  1
190254  94.235  -76.360  54.161  1
190255  94.255  -76.358  54.145  1
190256  94.275  -76.357  54.127  1
190257  94.294  -76.355  54.100  1
190258  94.314  -76.354  54.072  1
190259  94.334  -76.352  54.042  1
190260  94.353  -76.350  54.012  1
190261  94.373  -76.348  53.982  1
190262  94.393  -76.347  53.953  1
190263  94.413  -76.345  53.924  1
190264  94.431  -76.344  53.890  1
190265  94.449  -76.342  53.853  1
190266  94.468  -76.341  53.814  1
190267  94.486  -76.340  53.776  1
190268  94.505  -76.339  53.741  1
190269  94.523  -76.338  53.707  1
190270  94.542  -76.337  53.675  1
190271  94.560  -76.336  53.642  1
190272  94.580  -76.334  53.609  1
190273  94.595  -76.338  53.578  1
190274  94.608  -76.345  53.547  1
190275  94.620  -76.351  53.515  1
190276  94.633  -76.359  53.482  1
190277  94.645  -76.366  53.447  1
190278  94.659  -76.373  53.409  1
190279  94.672  -76.376  53.370  1
190280  94.689  -76.374  53.333  1
190281  94.686  -76.376  53.299  1
190282  94.682  -76.379  53.265  1
190283  94.679  -76.381  53.234  1
190284  94.676  -76.383  53.201  1
190285  94.685  -76.387  53.167  1
190286  94.694  -76.391  53.135  1
190287  94.703  -76.395  53.102  1
190288  94.712  -76.398  53.069  1
190289  94.721  -76.402  53.037  1
190290  94.730  -76.407  53.005  1
190291  94.740  -76.411  52.968  1
190292  94.749  -76.414  52.930  1
190293  94.758  -76.418  52.890  1
190294  94.767  -76.422  52.848  1
190295  94.776  -76.426  52.807  1
190296  94.785  -76.430  52.766  1
190297  94.794  -76.433  52.725  1
190298  94.804  -76.437  52.679  1
190299  94.815  -76.440  52.632  1
190300  94.827  -76.444  52.585  1
190301  94.838  -76.447  52.537  1
190302  94.849  -76.450  52.492  1
190303  94.868  -76.455  52.444  1
190304  94.910  -76.463  52.395  1
190305  94.951  -76.471  52.343  1
190306  94.992  -76.480  52.289  1
190307  95.034  -76.488  52.233  1
190308  95.074  -76.495  52.177  1
190309  95.116  -76.504  52.122  1
190310  95.152  -76.511  52.071  1
190311  95.177  -76.518  52.021  1
190312  95.214  -76.519  51.973  1
190313  95.243  -76.521  51.925  1
190314  95.266  -76.526  51.879  1
190315  95.288  -76.532  51.836  1
190316  95.308  -76.542  51.796  1
190317  95.327  -76.552  51.756  1
190318  95.346  -76.562  51.716  1
190319  95.365  -76.572  51.675  1
190320  95.384  -76.583  51.631  1
190321  95.403  -76.592  51.584  1
190322  95.422  -76.603  51.537  1
190323  95.441  -76.613  51.491  1
190324  95.460  -76.624  51.448  1
190325  95.479  -76.633  51.408  1
190326  95.498  -76.644  51.369  1
190327  95.517  -76.654  51.330  1
190328  95.536  -76.665  51.291  1
190329  95.561  -76.670  51.252  1
190330  95.591  -76.673  51.213  1
190331  95.621  -76.676  51.174  1
190332  95.651  -76.680  51.135  1
190333  95.680  -76.683  51.095  1
190334  95.710  -76.686  51.054  1
190335  95.740  -76.689  51.011  1
190336  95.764  -76.693  50.969  1
190337  95.787  -76.698  50.926  1
190338  95.809  -76.702  50.884  1
190339  95.832  -76.707  50.844  1
190340  95.855  -76.712  50.803  1
190341  95.878  -76.716  50.763  1
190342  95.893  -76.713  50.723  1
190343  95.896  -76.699  50.678  1
190344  95.938  -76.718  50.631  1
190345  95.969  -76.730  50.582  1
190346  95.988  -76.736  50.532  1
190347  96.008  -76.741  50.479  1
190348  96.028  -76.747  50.424  1
190349  96.048  -76.752  50.366  1
190350  96.070  -76.759  50.307  1
190351  96.103  -76.769  50.245  1
190352  96.136  -76.780  50.185  1
190353  96.169  -76.790  50.130  1
190354  96.192  -76.802  50.081  1
190355  96.202  -76.815  50.036  1
190356  96.212  -76.828  49.995  1
190357  96.221  -76.842  49.955  1
190358  96.231  -76.856  49.918  1
190359  96.240  -76.869  49.885  1
190360  96.250  -76.882  49.854  1
190361  96.259  -76.896  49.825  1
190362  96.269  -76.909  49.800  1
190363  96.278  -76.923  49.776  1
190364  96.289  -76.936  49.754  1
190365  96.298  -76.950  49.733  1
190366  96.345  -76.856  49.715  1
190367  96.369  -76.746  49.698  1
190368  96.392  -76.758  49.682  1
190369  96.412  -76.813  49.668  1
190370  96.436  -76.869  49.654  1
190371  96.459  -76.925  49.640  1
190372  96.482  -76.981  49.624  1
190373  96.506  -77.038  49.605  1
190374  96.514  -77.043  49.584  1
190375  96.525  -77.016  49.561  1
190376  96.535  -76.988  49.537  1
190377  96.545  -76.961  49.511  1
190378  96.558  -76.940  49.487  1
190379  96.593  -76.950  49.463  1
190380  96.627  -76.978  49.441  1
190381  96.660  -77.006  49.416  1
190382  96.693  -77.034  49.390  1
190383  96.715  -77.041  49.362  1
190384  96.735  -77.046  49.331  1
190385  96.755  -77.051  49.301  1
190386  96.775  -77.056  49.272  1
190387  96.795  -77.060  49.242  1
190388  96.812  -77.068  49.214  1
190389  96.825  -77.079  49.187  1
190390  96.837  -77.091  49.159  1
190391  96.850  -77.102  49.131  1
190392  96.862  -77.113  49.104  1
190393  96.874  -77.124  49.079  1
190394  96.887  -77.135  49.054  1
190395  96.899  -77.147  49.029  1
190396  96.911  -77.152  49.003  1
190397  96.924  -77.156  48.978  1
190398  96.935  -77.160  48.952  1
190399  96.947  -77.164  48.926  1
190400  96.959  -77.168  48.899  1
190401  96.983  -77.173  48.872  1
190402  97.034  -77.183  48.845  1
190403  97.080  -77.199  48.818  1
190404  97.127  -77.216  48.793  1
190405  97.174  -77.232  48.768  1
190406  97.221  -77.248  48.744  1
190407  97.267  -77.265  48.720  1
190408  97.284  -77.273  48.696  1
190409  97.300  -77.282  48.673  1
190410  97.316  -77.291  48.650  1
190411  97.333  -77.299  48.628  1
190412  97.350  -77.308  48.607  1
190413  97.366  -77.316  48.587  1
190414  97.382  -77.325  48.567  1
190415  97.399  -77.334  48.547  1
190416  97.413  -77.335  48.525  1
190417  97.423  -77.331  48.504  1
190418  97.434  -77.327  48.483  1
190419  97.492  -77.351  48.461  1
190420  97.513  -77.359  48.438  1
190421  97.535  -77.367  48.414  1
190422  97.557  -77.376  48.390  1
190423  97.578  -77.383  48.366  1
190424  97.575  -77.385  48.341  1
190425  97.538  -77.376  48.318  1
190426  97.527  -77.369  48.293  1
190427  97.554  -77.367  48.266  1
190428  97.581  -77.365  48.238  1
190429  97.607  -77.363  48.210  1
190430  97.635  -77.361  48.180  1
190431  97.662  -77.360  48.150  1
190432  97.688  -77.357  48.120  1
190433  97.716  -77.357  48.089  1
190434  97.743  -77.359  48.058  1
190435  97.771  -77.360  48.028  1
190436  97.799  -77.359  47.997  1
190437  97.830  -77.348  47.965  1
190438  97.860  -77.335  47.932  1
190439  97.891  -77.324  47.900  1
190440  97.922  -77.312  47.867  1
190441  97.952  -77.301  47.835  1
190442  97.983  -77.288  47.803  1
190443  98.014  -77.277  47.771  1
190444  98.044  -77.265  47.740  1
190445  98.075  -77.253  47.710  1
190446  98.104  -77.240  47.681  1
190447  98.129  -77.226  47.652  1
190448  98.148  -77.216  47.623  1
190449  98.161  -77.212  47.595  1
190450  98.174  -77.208  47.567  1
190451  98.187  -77.204  47.539  1
190452  98.201  -77.200  47.512  1
190453  98.214  -77.195  47.485  1
190454  98.227  -77.191  47.459  1
190455  98.240  -77.187  47.432  1
190456  98.253  -77.182  47.404  1
190457  98.267  -77.179  47.377  1
190458  98.282  -77.197  47.349  1
190459  98.297  -77.219  47.321  1
190460  98.317  -77.235  47.293  1
190461  98.353  -77.239  47.265  1
190462  98.389  -77.243  47.240  1
190463  98.425  -77.247  47.216  1
190464  98.471  -77.255  47.194  1
190465  98.507  -77.256  47.171  1
190466  98.535  -77.273  47.146  1
190467  98.564  -77.289  47.123  1
190468  98.593  -77.307  47.101  1
190469  98.622  -77.323  47.080  1
190470  98.651  -77.340  47.060  1
190471  98.680  -77.357  47.040  1
190472  98.709  -77.374  47.019  1
190473  98.725  -77.391  46.997  1
190474  98.738  -77.404  46.976  1
190475  98.750  -77.400  46.956  1
190476  98.762  -77.396  46.935  1
190477  98.773  -77.392  46.913  1
190478  98.784  -77.388  46.890  1
190479  98.796  -77.384  46.868  1
190480  98.807  -77.381  46.846  1
190481  98.818  -77.381  46.824  1
190482  98.829  -77.382  46.803  1
190483  98.840  -77.382  46.782  1
190484  98.851  -77.382  46.760  1
190485  98.862  -77.382  46.735  1
190486  98.872  -77.382  46.710  1
190487  98.883  -77.383  46.686  1
190488  98.895  -77.382  46.661  1
190489  98.916  -77.374  46.639  1
190490  98.937  -77.366  46.615  1
190491  98.958  -77.357  46.591  1
190492  98.979  -77.363  46.566  1
190493  98.999  -77.369  46.542  1
190494  99.018  -77.374  46.519  1
190495  99.044  -77.394  46.495  1
190496  99.066  -77.420  46.473  1
190497  99.080  -77.446  46.451  1
190498  99.094  -77.472  46.428  1
190499  99.092  -77.485  46.405  1
190500  99.090  -77.498  46.380  1
190501  99.088  -77.511  46.356  1
190502  99.087  -77.525  46.332  1
190503  99.085  -77.538  46.310  1
190504  99.083  -77.551  46.287  1
190505  99.081  -77.565  46.264  1
190506  99.079  -77.578  46.241  1
190507  99.078  -77.592  46.218  1
190508  99.076  -77.605  46.195  1
190509  99.076  -77.617  46.173  1
190510  99.099  -77.614  46.151  1
190511  99.139  -77.617  46.128  1
190512  99.178  -77.620  46.107  1
190513  99.208  -77.620  46.085  1
190514  99.238  -77.620  46.064  1
190515  99.268  -77.619  46.043  1
190516  99.298  -77.618  46.023  1
190517  99.328  -77.617  46.005  1
190518  99.358  -77.617  45.986  1
190519  99.388  -77.616  45.969  1
190520  99.418  -77.616  45.951  1
190521  99.448  -77.615  45.935  1
190522  99.478  -77.614  45.921  1
190523  99.508  -77.614  45.906  1
190524  99.539  -77.613  45.892  1
190525  99.569  -77.617  45.879  1
190526  99.604  -77.633  45.866  1
190527  99.637  -77.650  45.854  1
190528  99.672  -77.667  45.842  1
190529  99.705  -77.683  45.829  1
190530  99.739  -77.699  45.815  1
190531  99.776  -77.713  45.802  1
190532  99.794  -77.724  45.789  1
190533  99.807  -77.736  45.775  1
190534  99.821  -77.748  45.761  1
190535  99.834  -77.760  45.748  1
190536  99.848  -77.772  45.735  1
190537  99.861  -77.784  45.722  1
190538  99.875  -77.796  45.708  1
190539  99.900  -77.823  45.695  1
190540  99.925  -77.849  45.684  1
190541  99.947  -77.865  45.673  1
190542  99.968  -77.876  45.663  1
190543  99.989  -77.888  45.653  1
190544  100.009  -77.899  45.644  1
190545  100.034  -77.909  45.635  1
190546  100.064  -77.914  45.625  1
190547  100.094  -77.919  45.616  1
190548  100.125  -77.924  45.607  1
190549  100.154  -77.931  45.596  1
190550  100.174  -77.944  45.584  1
190551  100.195  -77.958  45.572  1
190552  100.215  -77.972  45.559  1
190553  100.235  -77.986  45.547  1
190554  100.256  -78.000  45.534  1
190555  100.276  -78.013  45.521  1
190556  100.297  -78.028  45.507  1
190557  100.317  -78.041  45.494  1
190558  100.338  -78.055  45.480  1
190559  100.358  -78.069  45.466  1
190560  100.369  -78.076  45.453  1
190561  100.383  -78.084  45.438  1
190562  100.396  -78.091  45.424  1
190563  100.409  -78.099  45.410  1
190564  100.423  -78.106  45.394  1
190565  100.436  -78.114  45.378  1
190566  100.449  -78.122  45.363  1
190567  100.462  -78.130  45.350  1
190568  100.472  -78.144  45.335  1
190569  100.481  -78.157  45.321  1
190570  100.490  -78.172  45.307  1
190571  100.512  -78.165  45.291  1
190572  100.535  -78.155  45.277  1
190573  100.567  -78.147  45.263  1
190574  100.602  -78.155  45.248  1
190575  100.642  -78.165  45.234  1
190576  100.683  -78.172  45.220  1
190577  100.723  -78.180  45.206  1
190578  100.764  -78.188  45.191  1
190579  100.805  -78.195  45.175  1
190580  100.845  -78.203  45.160  1
190581  100.886  -78.210  45.145  1
190582  100.927  -78.218  45.130  1
190583  100.968  -78.225  45.115  1
190584  101.008  -78.233  45.101  1
190585  101.049  -78.241  45.087  1
190586  101.090  -78.249  45.074  1
190587  101.131  -78.257  45.060  1
190588  101.172  -78.264  45.046  1
190589  101.212  -78.272  45.032  1
190590  101.228  -78.288  45.016  1
190591  101.239  -78.307  45.002  1
190592  101.251  -78.325  44.987  1
190593  101.261  -78.343  44.971  1
190594  101.271  -78.361  44.956  1
190595  101.280  -78.379  44.940  1
190596  101.290  -78.398  44.925  1
190597  101.255  -78.366  44.910  1
190598  101.273  -78.369  44.894  1
190599  101.308  -78.391  44.878  1
190600  101.343  -78.412  44.861  1
190601  101.379  -78.433  44.845  1
190602  101.414  -78.454  44.828  1
190603  101.450  -78.476  44.811  1
190604  101.485  -78.497  44.795  1
190605  101.520  -78.518  44.777  1
190606  101.552  -78.541  44.761  1
190607  101.579  -78.567  44.745  1
190608  101.606  -78.592  44.728  1
190609  101.633  -78.617  44.712  1
190610  101.660  -78.643  44.696  1
190611  101.687  -78.669  44.679  1
190612  101.714  -78.695  44.663  1
190613  101.757  -78.722  44.647  1
190614  101.800  -78.749  44.631  1
190615  101.821  -78.802  44.616  1
190616  101.864  -78.833  44.601  1
190617  101.907  -78.865  44.586  1
190618  101.950  -78.897  44.571  1
190619  101.993  -78.929  44.557  1
190620  102.036  -78.961  44.543  1
190621  102.064  -78.973  44.529  1
190622  102.084  -78.974  44.515  1
190623  102.103  -78.976  44.501  1
190624  102.122  -78.977  44.487  1
190625  102.142  -78.979  44.474  1
190626  102.161  -78.981  44.461  1
190627  102.181  -78.983  44.448  1
190628  102.200  -78.984  44.436  1
190629  102.220  -78.986  44.422  1
190630  102.239  -78.987  44.408  1
190631  102.258  -78.989  44.395  1
190632  102.278  -78.990  44.382  1
190913  93.489  -76.412  54.088  1
190914  93.507  -76.414  54.091  1
190915  93.525  -76.417  54.095  1
190916  93.544  -76.420  54.099  1
190917  93.562  -76.423  54.102  1
190918  93.580  -76.426  54.104  1
190919  93.599  -76.430  54.108  1
190920  93.617  -76.432  54.111  1
190921  93.635  -76.435  54.116  1
190922  93.654  -76.438  54.122  1
190923  93.672  -76.441  54.129  1
190924  93.691  -76.444  54.134  1
190925  93.709  -76.447  54.140  1
190926  93.730  -76.439  54.149  1
190927  93.751  -76.429  54.161  1
190928  93.766  -76.428  54.176  1
190929  93.781  -76.424  54.190  1
190930  93.795  -76.420  54.202  1
190931  93.810  -76.417  54.209  1
190932  93.825  -76.410  54.214  1
190933  93.841  -76.395  54.219  1
190934  93.858  -76.379  54.222  1
190935  93.873  -76.370  54.224  1
190936  93.888  -76.365  54.227  1
190937  93.903  -76.361  54.228  1
190938  93.921  -76.362  54.222  1
190939  93.939  -76.367  54.215  1
190940  93.959  -76.373  54.209  1
190941  93.976  -76.376  54.205  1
190942  93.992  -76.379  54.206  1
190943  94.009  -76.382  54.209  1
190944  94.027  -76.382  54.208  1
190945  94.044  -76.378  54.203  1
190946  94.062  -76.373  54.199  1
190947  94.079  -76.370  54.198  1
190948  94.098  -76.366  54.199  1
190949  94.115  -76.362  54.202  1
190950  94.134  -76.359  54.204  1
190951  94.153  -76.358  54.202  1
190952  94.174  -76.357  54.197  1
190953  94.196  -76.348  54.191  1
190954  94.216  -76.346  54.179  1
190955  94.237  -76.344  54.166  1
190956  94.256  -76.342  54.151  1
190957  94.276  -76.341  54.133  1
190958  94.295  -76.339  54.106  1
190959  94.315  -76.338  54.078  1
190960  94.335  -76.336  54.048  1
190961  94.355  -76.335  54.019  1
190962  94.374  -76.332  53.990  1
190963  94.394  -76.331  53.961  1
190964  94.413  -76.329  53.932  1
190965  94.431  -76.328  53.898  1
190966  94.449  -76.326  53.861  1
190967  94.468  -76.325  53.825  1
190968  94.486  -76.324  53.789  1
190969  94.505  -76.323  53.755  1
190970  94.523  -76.322  53.723  1
190971  94.542  -76.321  53.691  1
190972  94.560  -76.320  53.658  1
190973  94.576  -76.320  53.627  1
190974  94.589  -76.326  53.596  1
190975  94.600  -76.334  53.565  1
190976  94.613  -76.342  53.532  1
190977  94.625  -76.349  53.499  1
190978  94.638  -76.356  53.464  1
190979  94.650  -76.363  53.426  1
190980  94.663  -76.370  53.388  1
190981  94.678  -76.370  53.351  1
190982  94.678  -76.372  53.316  1
190983  94.674  -76.374  53.283  1
190984  94.676  -76.377  53.250  1
190985  94.685  -76.381  53.217  1
190986  94.694  -76.385  53.184  1
190987  94.703  -76.389  53.150  1
190988  94.712  -76.393  53.117  1
190989  94.721  -76.397  53.083  1
190990  94.731  -76.401  53.049  1
190991  94.740  -76.404  53.016  1
190992  94.749  -76.408  52.978  1
190993  94.760  -76.411  52.939  1
190994  94.772  -76.415  52.900  1
190995  94.783  -76.418  52.860  1
190996  94.794  -76.421  52.820  1
190997  94.806  -76.425  52.780  1
190998  94.817  -76.428  52.738  1
190999  94.829  -76.431  52.691  1
191000  94.840  -76.435  52.643  1
191001  94.851  -76.438  52.594  1
191002  94.863  -76.441  52.547  1
191003  94.875  -76.445  52.501  1
191004  94.886  -76.448  52.453  1
191005  94.927  -76.456  52.404  1
191006  94.968  -76.464  52.352  1
191007  95.010  -76.472  52.298  1
191008  95.051  -76.480  52.243  1
191009  95.092  -76.489  52.187  1
191010  95.117  -76.495  52.133  1
191011  95.142  -76.502  52.081  1
191012  95.167  -76.508  52.031  1
191013  95.210  -76.506  51.982  1
191014  95.247  -76.505  51.935  1
191015  95.270  -76.511  51.890  1
191016  95.293  -76.515  51.847  1
191017  95.316  -76.520  51.806  1
191018  95.339  -76.524  51.767  1
191019  95.359  -76.534  51.729  1
191020  95.378  -76.544  51.690  1
191021  95.397  -76.554  51.648  1
191022  95.416  -76.564  51.602  1
191023  95.435  -76.574  51.555  1
191024  95.454  -76.585  51.508  1
191025  95.473  -76.595  51.465  1
191026  95.492  -76.605  51.425  1
191027  95.512  -76.615  51.386  1
191028  95.531  -76.626  51.347  1
191029  95.549  -76.636  51.309  1
191030  95.571  -76.644  51.271  1
191031  95.601  -76.647  51.233  1
191032  95.630  -76.650  51.195  1
191033  95.660  -76.654  51.156  1
191034  95.690  -76.657  51.116  1
191035  95.720  -76.660  51.075  1
191036  95.746  -76.664  51.033  1
191037  95.769  -76.668  50.991  1
191038  95.792  -76.673  50.948  1
191039  95.815  -76.677  50.905  1
191040  95.837  -76.682  50.866  1
191041  95.860  -76.687  50.826  1
191042  95.883  -76.692  50.787  1
191043  95.906  -76.696  50.747  1
191044  95.913  -76.686  50.703  1
191045  95.952  -76.703  50.657  1
191046  95.971  -76.708  50.608  1
191047  95.991  -76.714  50.559  1
191048  96.011  -76.719  50.506  1
191049  96.031  -76.725  50.451  1
191050  96.050  -76.730  50.395  1
191051  96.071  -76.736  50.336  1
191052  96.095  -76.743  50.275  1
191053  96.131  -76.753  50.215  1
191054  96.168  -76.762  50.160  1
191055  96.196  -76.771  50.111  1
191056  96.216  -76.777  50.067  1
191057  96.234  -76.786  50.026  1
191058  96.243  -76.799  49.987  1
191059  96.253  -76.813  49.951  1
191060  96.262  -76.827  49.918  1
191061  96.272  -76.840  49.888  1
191062  96.281  -76.855  49.860  1
191063  96.291  -76.868  49.835  1
191064  96.300  -76.882  49.812  1
191065  96.310  -76.896  49.790  1
191066  96.327  -76.903  49.770  1
191067  96.390  -76.875  49.753  1
191068  96.453  -76.843  49.736  1
191069  96.489  -76.790  49.721  1
191070  96.505  -76.844  49.706  1
191071  96.520  -76.897  49.692  1
191072  96.510  -76.934  49.677  1
191073  96.499  -76.970  49.660  1
191074  96.493  -77.008  49.639  1
191075  96.522  -77.008  49.616  1
191076  96.538  -76.983  49.591  1
191077  96.553  -76.958  49.566  1
191078  96.565  -76.931  49.540  1
191079  96.575  -76.904  49.516  1
191080  96.598  -76.901  49.492  1
191081  96.631  -76.929  49.468  1
191082  96.665  -76.958  49.442  1
191083  96.698  -76.986  49.414  1
191084  96.732  -77.013  49.385  1
191085  96.752  -77.019  49.354  1
191086  96.772  -77.023  49.323  1
191087  96.792  -77.028  49.293  1
191088  96.812  -77.033  49.263  1
191089  96.827  -77.041  49.234  1
191090  96.840  -77.053  49.206  1
191091  96.852  -77.064  49.178  1
191092  96.865  -77.075  49.150  1
191093  96.877  -77.087  49.123  1
191094  96.889  -77.097  49.097  1
191095  96.902  -77.109  49.072  1
191096  96.914  -77.120  49.048  1
191097  96.927  -77.132  49.022  1
191098  96.939  -77.143  48.996  1
191099  96.952  -77.152  48.970  1
191100  96.964  -77.156  48.944  1
191101  96.975  -77.160  48.917  1
191102  96.987  -77.164  48.890  1
191103  97.036  -77.175  48.862  1
191104  97.083  -77.191  48.835  1
191105  97.130  -77.207  48.809  1
191106  97.176  -77.223  48.784  1
191107  97.223  -77.240  48.759  1
191108  97.270  -77.257  48.735  1
191109  97.301  -77.269  48.712  1
191110  97.318  -77.278  48.689  1
191111  97.334  -77.286  48.666  1
191112  97.351  -77.294  48.645  1
191113  97.367  -77.304  48.624  1
191114  97.384  -77.312  48.603  1
191115  97.400  -77.320  48.583  1
191116  97.411  -77.316  48.561  1
191117  97.422  -77.311  48.539  1
191118  97.433  -77.307  48.518  1
191119  97.444  -77.302  48.496  1
191120  97.491  -77.320  48.473  1
191121  97.544  -77.345  48.449  1
191122  97.566  -77.353  48.425  1
191123  97.588  -77.361  48.400  1
191124  97.596  -77.365  48.374  1
191125  97.559  -77.356  48.349  1
191126  97.522  -77.347  48.325  1
191127  97.541  -77.345  48.298  1
191128  97.568  -77.342  48.270  1
191129  97.595  -77.341  48.242  1
191130  97.623  -77.338  48.214  1
191131  97.649  -77.336  48.185  1
191132  97.676  -77.335  48.155  1
191133  97.703  -77.332  48.125  1
191134  97.730  -77.331  48.095  1
191135  97.757  -77.332  48.065  1
191136  97.785  -77.333  48.034  1
191137  97.813  -77.333  48.003  1
191138  97.844  -77.322  47.971  1
191139  97.874  -77.310  47.938  1
191140  97.905  -77.298  47.906  1
191141  97.936  -77.286  47.873  1
191142  97.966  -77.274  47.841  1
191143  97.997  -77.263  47.809  1
191144  98.028  -77.251  47.777  1
191145  98.059  -77.239  47.746  1
191146  98.084  -77.224  47.716  1
191147  98.108  -77.210  47.687  1
191148  98.134  -77.195  47.659  1
191149  98.159  -77.181  47.630  1
191150  98.179  -77.170  47.601  1
191151  98.193  -77.166  47.572  1
191152  98.206  -77.162  47.544  1
191153  98.219  -77.157  47.516  1
191154  98.232  -77.153  47.490  1
191155  98.245  -77.149  47.463  1
191156  98.258  -77.144  47.438  1
191157  98.272  -77.141  47.409  1
191158  98.287  -77.160  47.380  1
191159  98.302  -77.182  47.353  1
191160  98.318  -77.203  47.326  1
191161  98.340  -77.216  47.298  1
191162  98.375  -77.220  47.272  1
191163  98.412  -77.224  47.246  1
191164  98.447  -77.228  47.224  1
191165  98.483  -77.232  47.201  1
191166  98.513  -77.244  47.178  1
191167  98.541  -77.261  47.155  1
191168  98.570  -77.279  47.130  1
191169  98.599  -77.295  47.108  1
191170  98.628  -77.312  47.087  1
191171  98.657  -77.329  47.067  1
191172  98.686  -77.346  47.046  1
191173  98.715  -77.363  47.026  1
191174  98.743  -77.380  47.004  1
191175  98.756  -77.386  46.983  1
191176  98.767  -77.382  46.962  1
191177  98.778  -77.381  46.941  1
191178  98.789  -77.381  46.920  1
191179  98.800  -77.382  46.897  1
191180  98.811  -77.382  46.876  1
191181  98.822  -77.382  46.854  1
191182  98.833  -77.382  46.832  1
191183  98.844  -77.382  46.810  1
191184  98.854  -77.382  46.787  1
191185  98.865  -77.383  46.764  1
191186  98.876  -77.383  46.739  1
191187  98.887  -77.383  46.715  1
191188  98.898  -77.384  46.690  1
191189  98.909  -77.383  46.665  1
191190  98.930  -77.375  46.643  1
191191  98.951  -77.367  46.620  1
191192  98.973  -77.358  46.596  1
191193  98.994  -77.350  46.571  1
191194  99.015  -77.345  46.548  1
191195  99.035  -77.351  46.524  1
191196  99.056  -77.377  46.500  1
191197  99.070  -77.403  46.478  1
191198  99.083  -77.429  46.455  1
191199  99.097  -77.455  46.432  1
191200  99.106  -77.476  46.409  1
191201  99.104  -77.490  46.385  1
191202  99.102  -77.503  46.361  1
191203  99.100  -77.517  46.338  1
191204  99.098  -77.530  46.315  1
191205  99.097  -77.543  46.292  1
191206  99.095  -77.556  46.269  1
191207  99.093  -77.570  46.246  1
191208  99.091  -77.583  46.223  1
191209  99.089  -77.596  46.200  1
191210  99.099  -77.602  46.177  1
191211  99.121  -77.599  46.154  1
191212  99.144  -77.596  46.132  1
191213  99.184  -77.600  46.110  1
191214  99.223  -77.604  46.089  1
191215  99.264  -77.608  46.067  1
191216  99.303  -77.611  46.045  1
191217  99.337  -77.612  46.027  1
191218  99.366  -77.611  46.008  1
191219  99.397  -77.611  45.989  1
191220  99.427  -77.610  45.972  1
191221  99.456  -77.609  45.954  1
191222  99.487  -77.609  45.938  1
191223  99.517  -77.608  45.923  1
191224  99.547  -77.608  45.908  1
191225  99.577  -77.607  45.894  1
191226  99.607  -77.606  45.881  1
191227  99.639  -77.617  45.868  1
191228  99.674  -77.633  45.856  1
191229  99.707  -77.649  45.843  1
191230  99.742  -77.666  45.829  1
191231  99.775  -77.683  45.816  1
191232  99.800  -77.692  45.803  1
191233  99.814  -77.704  45.789  1
191234  99.827  -77.716  45.775  1
191235  99.841  -77.728  45.761  1
191236  99.854  -77.740  45.747  1
191237  99.867  -77.752  45.734  1
191238  99.881  -77.765  45.720  1
191239  99.894  -77.777  45.707  1
191240  99.916  -77.799  45.694  1
191241  99.941  -77.824  45.682  1
191242  99.966  -77.850  45.672  1
191243  99.987  -77.862  45.662  1
191244  100.007  -77.874  45.653  1
191245  100.028  -77.886  45.643  1
191246  100.057  -77.892  45.634  1
191247  100.087  -77.897  45.625  1
191248  100.117  -77.902  45.615  1
191249  100.140  -77.914  45.605  1
191250  100.161  -77.928  45.595  1
191251  100.181  -77.942  45.583  1
191252  100.202  -77.956  45.571  1
191253  100.222  -77.969  45.559  1
191254  100.243  -77.983  45.547  1
191255  100.263  -77.997  45.534  1
191256  100.283  -78.011  45.521  1
191257  100.304  -78.025  45.508  1
191258  100.324  -78.038  45.494  1
191259  100.345  -78.053  45.480  1
191260  100.365  -78.066  45.466  1
191261  100.378  -78.074  45.451  1
191262  100.391  -78.081  45.437  1
191263  100.404  -78.089  45.423  1
191264  100.418  -78.097  45.409  1
191265  100.431  -78.104  45.394  1
191266  100.444  -78.112  45.378  1
191267  100.458  -78.119  45.362  1
191268  100.471  -78.127  45.349  1
191269  100.484  -78.134  45.334  1
191270  100.494  -78.147  45.320  1
191271  100.504  -78.161  45.305  1
191272  100.525  -78.154  45.290  1
191273  100.556  -78.146  45.276  1
191274  100.593  -78.139  45.262  1
191275  100.622  -78.138  45.247  1
191276  100.661  -78.151  45.233  1
191277  100.700  -78.163  45.219  1
191278  100.740  -78.173  45.206  1
191279  100.780  -78.181  45.192  1
191280  100.821  -78.188  45.176  1
191281  100.862  -78.196  45.161  1
191282  100.903  -78.204  45.146  1
191283  100.944  -78.212  45.131  1
191284  100.984  -78.219  45.116  1
191285  101.025  -78.227  45.102  1
191286  101.065  -78.235  45.088  1
191287  101.106  -78.242  45.074  1
191288  101.147  -78.250  45.060  1
191289  101.188  -78.257  45.047  1
191290  101.226  -78.266  45.033  1
191291  101.237  -78.284  45.017  1
191292  101.249  -78.302  45.003  1
191293  101.260  -78.320  44.988  1
191294  101.272  -78.338  44.972  1
191295  101.282  -78.357  44.957  1
191296  101.291  -78.375  44.942  1
191297  101.301  -78.394  44.926  1
191298  101.283  -78.366  44.911  1
191299  101.296  -78.365  44.896  1
191300  101.325  -78.379  44.880  1
191301  101.360  -78.400  44.863  1
191302  101.395  -78.421  44.847  1
191303  101.430  -78.442  44.830  1
191304  101.466  -78.463  44.813  1
191305  101.501  -78.484  44.796  1
191306  101.537  -78.505  44.779  1
191307  101.565  -78.530  44.762  1
191308  101.592  -78.556  44.746  1
191309  101.619  -78.582  44.729  1
191310  101.645  -78.608  44.713  1
191311  101.673  -78.633  44.697  1
191312  101.699  -78.658  44.680  1
191313  101.727  -78.684  44.664  1
191314  101.755  -78.710  44.648  1
191315  101.796  -78.744  44.632  1
191316  101.839  -78.776  44.617  1
191317  101.883  -78.808  44.602  1
191318  101.925  -78.839  44.588  1
191319  101.969  -78.871  44.573  1
191320  102.012  -78.903  44.558  1
191321  102.055  -78.935  44.544  1
191322  102.089  -78.955  44.530  1
191323  102.109  -78.957  44.516  1
191324  102.128  -78.959  44.502  1
191325  102.147  -78.960  44.488  1
191326  102.167  -78.962  44.475  1
191327  102.186  -78.964  44.463  1
191328  102.206  -78.965  44.449  1
191329  102.226  -78.967  44.436  1
191330  102.245  -78.968  44.423  1
191331  102.264  -78.970  44.408  1
191332  102.283  -78.971  44.396  1
191333  102.303  -78.973  44.382  1
191615  93.499  -76.391  54.084  1
191616  93.517  -76.394  54.089  1
191617  93.536  -76.397  54.093  1
191618  93.554  -76.400  54.096  1
191619  93.572  -76.403  54.098  1
191620  93.591  -76.406  54.102  1
191621  93.609  -76.408  54.106  1
191622  93.627  -76.411  54.111  1
191623  93.646  -76.414  54.117  1
191624  93.664  -76.417  54.123  1
191625  93.683  -76.420  54.129  1
191626  93.701  -76.423  54.135  1
191627  93.719  -76.426  54.143  1
191628  93.740  -76.420  54.155  1
191629  93.759  -76.412  54.170  1
191630  93.774  -76.411  54.185  1
191631  93.788  -76.407  54.197  1
191632  93.803  -76.403  54.204  1
191633  93.819  -76.389  54.209  1
191634  93.835  -76.373  54.214  1
191635  93.851  -76.358  54.218  1
191636  93.867  -76.348  54.219  1
191637  93.882  -76.343  54.220  1
191638  93.897  -76.339  54.219  1
191639  93.916  -76.345  54.213  1
191640  93.935  -76.351  54.208  1
191641  93.955  -76.357  54.203  1
191642  93.972  -76.361  54.202  1
191643  93.989  -76.364  54.207  1
191644  94.006  -76.367  54.209  1
191645  94.024  -76.367  54.209  1
191646  94.041  -76.363  54.206  1
191647  94.059  -76.358  54.201  1
191648  94.076  -76.354  54.199  1
191649  94.095  -76.351  54.199  1
191650  94.113  -76.348  54.201  1
191651  94.133  -76.348  54.203  1
191652  94.153  -76.346  54.200  1
191653  94.173  -76.345  54.196  1
191654  94.195  -76.338  54.191  1
191655  94.218  -76.330  54.182  1
191656  94.238  -76.328  54.170  1
191657  94.257  -76.326  54.155  1
191658  94.277  -76.325  54.137  1
191659  94.296  -76.323  54.111  1
191660  94.316  -76.322  54.083  1
191661  94.336  -76.320  54.054  1
191662  94.356  -76.319  54.025  1
191663  94.376  -76.317  53.997  1
191664  94.395  -76.315  53.968  1
191665  94.413  -76.314  53.939  1
191666  94.431  -76.311  53.904  1
191667  94.449  -76.310  53.869  1
191668  94.468  -76.309  53.835  1
191669  94.486  -76.308  53.801  1
191670  94.505  -76.307  53.768  1
191671  94.523  -76.306  53.736  1
191672  94.542  -76.305  53.705  1
191673  94.557  -76.304  53.672  1
191674  94.570  -76.304  53.642  1
191675  94.582  -76.308  53.611  1
191676  94.595  -76.317  53.581  1
191677  94.607  -76.326  53.549  1
191678  94.619  -76.336  53.516  1
191679  94.631  -76.345  53.481  1
191680  94.642  -76.354  53.444  1
191681  94.655  -76.361  53.406  1
191682  94.668  -76.367  53.369  1
191683  94.669  -76.368  53.334  1
191684  94.676  -76.372  53.300  1
191685  94.685  -76.376  53.267  1
191686  94.694  -76.379  53.234  1
191687  94.705  -76.383  53.200  1
191688  94.716  -76.386  53.166  1
191689  94.728  -76.389  53.133  1
191690  94.740  -76.392  53.099  1
191691  94.751  -76.396  53.065  1
191692  94.762  -76.399  53.030  1
191693  94.774  -76.402  52.991  1
191694  94.785  -76.406  52.952  1
191695  94.796  -76.409  52.912  1
191696  94.808  -76.412  52.872  1
191697  94.819  -76.416  52.831  1
191698  94.831  -76.419  52.790  1
191699  94.842  -76.422  52.746  1
191700  94.853  -76.426  52.699  1
191701  94.865  -76.429  52.652  1
191702  94.877  -76.432  52.603  1
191703  94.888  -76.436  52.556  1
191704  94.899  -76.439  52.509  1
191705  94.911  -76.442  52.461  1
191706  94.945  -76.449  52.412  1
191707  94.985  -76.457  52.360  1
191708  95.027  -76.465  52.306  1
191709  95.057  -76.472  52.252  1
191710  95.082  -76.479  52.196  1
191711  95.107  -76.485  52.143  1
191712  95.131  -76.492  52.091  1
191713  95.158  -76.498  52.041  1
191714  95.207  -76.492  51.993  1
191715  95.251  -76.490  51.948  1
191716  95.274  -76.495  51.903  1
191717  95.297  -76.499  51.861  1
191718  95.320  -76.504  51.820  1
191719  95.343  -76.508  51.781  1
191720  95.367  -76.514  51.743  1
191721  95.390  -76.518  51.704  1
191722  95.410  -76.526  51.664  1
191723  95.429  -76.536  51.618  1
191724  95.449  -76.546  51.571  1
191725  95.468  -76.556  51.524  1
191726  95.487  -76.567  51.482  1
191727  95.506  -76.577  51.442  1
191728  95.525  -76.587  51.403  1
191729  95.544  -76.597  51.365  1
191730  95.563  -76.608  51.329  1
191731  95.582  -76.618  51.292  1
191732  95.610  -76.621  51.255  1
191733  95.640  -76.625  51.217  1
191734  95.670  -76.628  51.179  1
191735  95.699  -76.631  51.140  1
191736  95.729  -76.634  51.099  1
191737  95.752  -76.639  51.056  1
191738  95.774  -76.643  51.014  1
191739  95.797  -76.648  50.971  1
191740  95.820  -76.652  50.927  1
191741  95.843  -76.658  50.888  1
191742  95.866  -76.662  50.849  1
191743  95.888  -76.667  50.810  1
191744  95.911  -76.671  50.771  1
191745  95.933  -76.674  50.728  1
191746  95.954  -76.681  50.682  1
191747  95.974  -76.687  50.634  1
191748  95.995  -76.692  50.585  1
191749  96.016  -76.696  50.532  1
191750  96.036  -76.702  50.477  1
191751  96.057  -76.707  50.422  1
191752  96.078  -76.712  50.363  1
191753  96.098  -76.716  50.303  1
191754  96.132  -76.724  50.245  1
191755  96.169  -76.734  50.191  1
191756  96.195  -76.743  50.143  1
191757  96.215  -76.749  50.099  1
191758  96.235  -76.756  50.058  1
191759  96.254  -76.763  50.020  1
191760  96.274  -76.771  49.984  1
191761  96.285  -76.783  49.953  1
191762  96.294  -76.797  49.924  1
191763  96.304  -76.811  49.896  1
191764  96.313  -76.824  49.872  1
191765  96.323  -76.838  49.849  1
191766  96.332  -76.852  49.828  1
191767  96.368  -76.846  49.808  1
191768  96.431  -76.816  49.791  1
191769  96.495  -76.787  49.775  1
191770  96.488  -76.775  49.761  1
191771  96.477  -76.794  49.745  1
191772  96.465  -76.830  49.730  1
191773  96.453  -76.865  49.715  1
191774  96.441  -76.900  49.697  1
191775  96.475  -76.953  49.673  1
191776  96.513  -76.965  49.648  1
191777  96.528  -76.940  49.621  1
191778  96.544  -76.915  49.595  1
191779  96.559  -76.890  49.569  1
191780  96.575  -76.865  49.544  1
191781  96.609  -76.859  49.519  1
191782  96.637  -76.881  49.494  1
191783  96.670  -76.909  49.467  1
191784  96.703  -76.937  49.438  1
191785  96.737  -76.965  49.407  1
191786  96.768  -76.990  49.376  1
191787  96.789  -76.995  49.345  1
191788  96.809  -77.000  49.314  1
191789  96.829  -77.005  49.284  1
191790  96.842  -77.016  49.254  1
191791  96.855  -77.026  49.225  1
191792  96.867  -77.038  49.197  1
191793  96.880  -77.049  49.169  1
191794  96.892  -77.060  49.142  1
191795  96.904  -77.072  49.116  1
191796  96.917  -77.083  49.090  1
191797  96.930  -77.094  49.066  1
191798  96.942  -77.105  49.041  1
191799  96.954  -77.116  49.015  1
191800  96.967  -77.128  48.988  1
191801  96.979  -77.139  48.962  1
191802  96.992  -77.150  48.936  1
191803  97.004  -77.156  48.908  1
191804  97.039  -77.166  48.880  1
191805  97.086  -77.182  48.853  1
191806  97.133  -77.199  48.826  1
191807  97.179  -77.215  48.800  1
191808  97.226  -77.232  48.775  1
191809  97.273  -77.248  48.751  1
191810  97.319  -77.264  48.728  1
191811  97.335  -77.273  48.706  1
191812  97.352  -77.282  48.684  1
191813  97.369  -77.290  48.662  1
191814  97.385  -77.299  48.640  1
191815  97.398  -77.300  48.618  1
191816  97.409  -77.296  48.596  1
191817  97.420  -77.291  48.575  1
191818  97.431  -77.287  48.553  1
191819  97.442  -77.282  48.531  1
191820  97.453  -77.278  48.507  1
191821  97.487  -77.287  48.484  1
191822  97.575  -77.330  48.460  1
191823  97.597  -77.338  48.436  1
191824  97.617  -77.346  48.409  1
191825  97.580  -77.337  48.383  1
191826  97.543  -77.328  48.356  1
191827  97.529  -77.322  48.330  1
191828  97.556  -77.320  48.302  1
191829  97.583  -77.317  48.274  1
191830  97.610  -77.316  48.246  1
191831  97.637  -77.313  48.217  1
191832  97.664  -77.312  48.189  1
191833  97.691  -77.310  48.159  1
191834  97.718  -77.308  48.129  1
191835  97.745  -77.306  48.101  1
191836  97.772  -77.304  48.071  1
191837  97.800  -77.306  48.041  1
191838  97.827  -77.307  48.009  1
191839  97.858  -77.295  47.977  1
191840  97.888  -77.284  47.945  1
191841  97.919  -77.272  47.913  1
191842  97.950  -77.260  47.881  1
191843  97.981  -77.248  47.849  1
191844  98.011  -77.237  47.817  1
191845  98.038  -77.223  47.785  1
191846  98.063  -77.208  47.753  1
191847  98.088  -77.194  47.722  1
191848  98.113  -77.179  47.693  1
191849  98.139  -77.165  47.666  1
191850  98.164  -77.150  47.636  1
191851  98.189  -77.135  47.607  1
191852  98.211  -77.124  47.578  1
191853  98.224  -77.119  47.550  1
191854  98.237  -77.116  47.522  1
191855  98.250  -77.111  47.495  1
191856  98.263  -77.106  47.469  1
191857  98.277  -77.103  47.441  1
191858  98.292  -77.123  47.413  1
191859  98.307  -77.144  47.385  1
191860  98.323  -77.165  47.357  1
191861  98.339  -77.186  47.331  1
191862  98.362  -77.198  47.304  1
191863  98.398  -77.202  47.278  1
191864  98.434  -77.206  47.252  1
191865  98.469  -77.210  47.231  1
191866  98.489  -77.219  47.208  1
191867  98.513  -77.230  47.186  1
191868  98.546  -77.243  47.163  1
191869  98.577  -77.257  47.138  1
191870  98.605  -77.275  47.115  1
191871  98.635  -77.292  47.094  1
191872  98.663  -77.310  47.073  1
191873  98.692  -77.328  47.052  1
191874  98.721  -77.345  47.032  1
191875  98.750  -77.363  47.011  1
191876  98.769  -77.377  46.989  1
191877  98.782  -77.382  46.968  1
191878  98.793  -77.382  46.947  1
191879  98.804  -77.382  46.926  1
191880  98.814  -77.382  46.904  1
191881  98.826  -77.382  46.883  1
191882  98.836  -77.382  46.861  1
191883  98.847  -77.383  46.838  1
191884  98.858  -77.383  46.815  1
191885  98.869  -77.383  46.791  1
191886  98.879  -77.384  46.767  1
191887  98.890  -77.384  46.744  1
191888  98.901  -77.384  46.719  1
191889  98.912  -77.385  46.694  1
191890  98.924  -77.385  46.669  1
191891  98.945  -77.376  46.647  1
191892  98.966  -77.367  46.624  1
191893  98.987  -77.359  46.600  1
191894  99.008  -77.351  46.576  1
191895  99.029  -77.342  46.553  1
191896  99.046  -77.339  46.529  1
191897  99.059  -77.360  46.505  1
191898  99.073  -77.386  46.483  1
191899  99.087  -77.413  46.459  1
191900  99.101  -77.439  46.436  1
191901  99.115  -77.464  46.412  1
191902  99.118  -77.481  46.390  1
191903  99.116  -77.495  46.367  1
191904  99.114  -77.508  46.344  1
191905  99.113  -77.521  46.322  1
191906  99.111  -77.535  46.298  1
191907  99.109  -77.548  46.275  1
191908  99.107  -77.561  46.252  1
191909  99.105  -77.574  46.228  1
191910  99.103  -77.588  46.204  1
191911  99.122  -77.587  46.181  1
191912  99.144  -77.584  46.158  1
191913  99.166  -77.582  46.135  1
191914  99.189  -77.579  46.113  1
191915  99.229  -77.583  46.092  1
191916  99.269  -77.586  46.070  1
191917  99.308  -77.590  46.049  1
191918  99.348  -77.594  46.029  1
191919  99.388  -77.598  46.010  1
191920  99.428  -77.602  45.991  1
191921  99.465  -77.604  45.974  1
191922  99.495  -77.603  45.957  1
191923  99.525  -77.602  45.940  1
191924  99.555  -77.602  45.925  1
191925  99.585  -77.602  45.910  1
191926  99.615  -77.601  45.896  1
191927  99.645  -77.600  45.883  1
191928  99.676  -77.599  45.869  1
191929  99.709  -77.616  45.856  1
191930  99.744  -77.633  45.843  1
191931  99.777  -77.649  45.830  1
191932  99.806  -77.661  45.816  1
191933  99.820  -77.673  45.803  1
191934  99.833  -77.685  45.789  1
191935  99.847  -77.697  45.775  1
191936  99.860  -77.709  45.760  1
191937  99.873  -77.721  45.747  1
191938  99.887  -77.733  45.733  1
191939  99.901  -77.746  45.719  1
191940  99.914  -77.758  45.706  1
191941  99.931  -77.774  45.694  1
191942  99.957  -77.801  45.682  1
191943  99.981  -77.827  45.671  1
191944  100.005  -77.849  45.662  1
191945  100.026  -77.860  45.653  1
191946  100.050  -77.870  45.643  1
191947  100.080  -77.875  45.634  1
191948  100.107  -77.884  45.624  1
191949  100.127  -77.897  45.615  1
191950  100.147  -77.911  45.605  1
191951  100.168  -77.925  45.595  1
191952  100.189  -77.939  45.583  1
191953  100.209  -77.953  45.572  1
191954  100.229  -77.967  45.560  1
191955  100.250  -77.981  45.547  1
191956  100.270  -77.994  45.534  1
191957  100.290  -78.008  45.521  1
191958  100.311  -78.022  45.509  1
191959  100.332  -78.036  45.495  1
191960  100.352  -78.050  45.480  1
191961  100.372  -78.063  45.466  1
191962  100.386  -78.072  45.450  1
191963  100.399  -78.080  45.436  1
191964  100.412  -78.087  45.422  1
191965  100.426  -78.094  45.407  1
191966  100.439  -78.102  45.392  1
191967  100.453  -78.109  45.376  1
191968  100.466  -78.117  45.362  1
191969  100.479  -78.125  45.347  1
191970  100.492  -78.132  45.333  1
191971  100.505  -78.140  45.319  1
191972  100.517  -78.150  45.304  1
191973  100.546  -78.144  45.289  1
191974  100.582  -78.138  45.275  1
191975  100.619  -78.131  45.261  1
191976  100.651  -78.128  45.247  1
191977  100.681  -78.134  45.233  1
191978  100.719  -78.147  45.219  1
191979  100.759  -78.159  45.205  1
191980  100.797  -78.172  45.192  1
191981  100.838  -78.182  45.177  1
191982  100.879  -78.190  45.162  1
191983  100.919  -78.197  45.146  1
191984  100.960  -78.205  45.132  1
191985  101.000  -78.213  45.117  1
191986  101.041  -78.220  45.104  1
191987  101.082  -78.228  45.090  1
191988  101.123  -78.235  45.075  1
191989  101.164  -78.243  45.061  1
191990  101.204  -78.250  45.047  1
191991  101.235  -78.262  45.033  1
191992  101.246  -78.280  45.019  1
191993  101.258  -78.298  45.004  1
191994  101.270  -78.316  44.989  1
191995  101.281  -78.334  44.973  1
191996  101.293  -78.352  44.958  1
191997  101.303  -78.370  44.944  1
191998  101.298  -78.366  44.928  1
191999  101.312  -78.366  44.913  1
192000  101.325  -78.364  44.898  1
192001  101.341  -78.366  44.882  1
192002  101.376  -78.387  44.865  1
192003  101.412  -78.408  44.849  1
192004  101.447  -78.429  44.831  1
192005  101.482  -78.451  44.814  1
192006  101.518  -78.472  44.797  1
192007  101.550  -78.495  44.779  1
192008  101.578  -78.520  44.763  1
192009  101.604  -78.545  44.747  1
192010  101.631  -78.571  44.730  1
192011  101.658  -78.597  44.713  1
192012  101.685  -78.623  44.697  1
192013  101.712  -78.648  44.681  1
192014  101.740  -78.671  44.665  1
192015  101.770  -78.692  44.649  1
192016  101.815  -78.717  44.633  1
192017  101.858  -78.749  44.618  1
192018  101.901  -78.781  44.604  1
192019  101.944  -78.813  44.590  1
192020  101.987  -78.845  44.575  1
192021  102.030  -78.877  44.560  1
192022  102.074  -78.908  44.546  1
192023  102.114  -78.938  44.532  1
192024  102.134  -78.940  44.518  1
192025  102.153  -78.941  44.504  1
192026  102.173  -78.943  44.490  1
192027  102.192  -78.945  44.477  1
192028  102.211  -78.946  44.464  1
192029  102.231  -78.948  44.450  1
192030  102.250  -78.949  44.436  1
192031  102.270  -78.951  44.422  1
192032  102.290  -78.952  44.409  1
192033  102.309  -78.954  44.396  1
192034  102.328  -78.955  44.382  1
192035  102.348  -78.958  44.368  1
192317  93.509  -76.370  54.082  1
192318  93.528  -76.373  54.086  1
192319  93.546  -76.376  54.089  1
192320  93.564  -76.379  54.092  1
192321  93.582  -76.383  54.096  1
192322  93.601  -76.386  54.100  1
192323  93.619  -76.388  54.105  1
192324  93.638  -76.391  54.112  1
192325  93.656  -76.394  54.118  1
192326  93.675  -76.397  54.124  1
192327  93.693  -76.400  54.130  1
192328  93.711  -76.403  54.138  1
192329  93.729  -76.405  54.149  1
192330  93.750  -76.400  54.163  1
192331  93.766  -76.396  54.178  1
192332  93.781  -76.392  54.193  1
192333  93.796  -76.385  54.198  1
192334  93.813  -76.369  54.203  1
192335  93.829  -76.353  54.206  1
192336  93.845  -76.337  54.210  1
192337  93.861  -76.326  54.211  1
192338  93.875  -76.321  54.212  1
192339  93.893  -76.323  54.211  1
192340  93.912  -76.329  54.206  1
192341  93.931  -76.335  54.203  1
192342  93.950  -76.340  54.202  1
192343  93.969  -76.346  54.202  1
192344  93.986  -76.350  54.207  1
192345  94.003  -76.352  54.212  1
192346  94.020  -76.351  54.214  1
192347  94.038  -76.348  54.211  1
192348  94.056  -76.344  54.207  1
192349  94.073  -76.339  54.204  1
192350  94.092  -76.338  54.203  1
192351  94.113  -76.336  54.203  1
192352  94.132  -76.336  54.204  1
192353  94.152  -76.335  54.201  1
192354  94.172  -76.333  54.196  1
192355  94.194  -76.327  54.192  1
192356  94.217  -76.319  54.183  1
192357  94.239  -76.312  54.171  1
192358  94.258  -76.310  54.156  1
192359  94.278  -76.309  54.139  1
192360  94.298  -76.307  54.115  1
192361  94.318  -76.306  54.088  1
192362  94.337  -76.304  54.060  1
192363  94.357  -76.303  54.032  1
192364  94.377  -76.301  54.004  1
192365  94.395  -76.299  53.974  1
192366  94.413  -76.298  53.944  1
192367  94.431  -76.295  53.909  1
192368  94.449  -76.295  53.876  1
192369  94.468  -76.293  53.844  1
192370  94.486  -76.292  53.812  1
192371  94.505  -76.292  53.780  1
192372  94.523  -76.290  53.748  1
192373  94.537  -76.290  53.717  1
192374  94.551  -76.289  53.684  1
192375  94.564  -76.289  53.653  1
192376  94.577  -76.292  53.624  1
192377  94.589  -76.301  53.594  1
192378  94.601  -76.309  53.564  1
192379  94.613  -76.318  53.532  1
192380  94.625  -76.327  53.497  1
192381  94.637  -76.336  53.461  1
192382  94.649  -76.345  53.423  1
192383  94.661  -76.354  53.387  1
192384  94.675  -76.361  53.351  1
192385  94.687  -76.365  53.317  1
192386  94.700  -76.368  53.284  1
192387  94.712  -76.372  53.251  1
192388  94.725  -76.376  53.217  1
192389  94.738  -76.379  53.183  1
192390  94.750  -76.383  53.150  1
192391  94.763  -76.386  53.116  1
192392  94.775  -76.390  53.081  1
192393  94.787  -76.393  53.046  1
192394  94.799  -76.397  53.006  1
192395  94.810  -76.400  52.966  1
192396  94.821  -76.403  52.924  1
192397  94.833  -76.407  52.883  1
192398  94.844  -76.410  52.841  1
192399  94.855  -76.413  52.798  1
192400  94.867  -76.417  52.753  1
192401  94.879  -76.420  52.707  1
192402  94.890  -76.423  52.662  1
192403  94.901  -76.426  52.616  1
192404  94.913  -76.430  52.570  1
192405  94.924  -76.433  52.524  1
192406  94.935  -76.436  52.476  1
192407  94.962  -76.442  52.427  1
192408  94.997  -76.449  52.374  1
192409  95.022  -76.456  52.320  1
192410  95.047  -76.462  52.265  1
192411  95.072  -76.469  52.209  1
192412  95.097  -76.475  52.156  1
192413  95.121  -76.482  52.105  1
192414  95.154  -76.484  52.055  1
192415  95.203  -76.480  52.008  1
192416  95.253  -76.475  51.963  1
192417  95.278  -76.479  51.920  1
192418  95.301  -76.483  51.877  1
192419  95.324  -76.489  51.835  1
192420  95.347  -76.493  51.795  1
192421  95.371  -76.498  51.756  1
192422  95.394  -76.502  51.717  1
192423  95.417  -76.507  51.676  1
192424  95.440  -76.511  51.632  1
192425  95.462  -76.517  51.586  1
192426  95.481  -76.528  51.539  1
192427  95.500  -76.538  51.497  1
192428  95.519  -76.549  51.459  1
192429  95.538  -76.558  51.422  1
192430  95.557  -76.569  51.386  1
192431  95.577  -76.579  51.351  1
192432  95.595  -76.589  51.317  1
192433  95.619  -76.596  51.282  1
192434  95.649  -76.599  51.246  1
192435  95.679  -76.602  51.208  1
192436  95.708  -76.605  51.168  1
192437  95.734  -76.609  51.126  1
192438  95.757  -76.614  51.083  1
192439  95.779  -76.618  51.039  1
192440  95.803  -76.624  50.996  1
192441  95.825  -76.628  50.952  1
192442  95.848  -76.633  50.911  1
192443  95.871  -76.637  50.871  1
192444  95.894  -76.642  50.831  1
192445  95.918  -76.649  50.792  1
192446  95.942  -76.653  50.748  1
192447  95.963  -76.657  50.703  1
192448  95.983  -76.662  50.656  1
192449  96.004  -76.667  50.608  1
192450  96.025  -76.672  50.556  1
192451  96.045  -76.677  50.503  1
192452  96.066  -76.683  50.448  1
192453  96.087  -76.687  50.390  1
192454  96.107  -76.691  50.331  1
192455  96.133  -76.696  50.274  1
192456  96.170  -76.706  50.222  1
192457  96.195  -76.714  50.175  1
192458  96.215  -76.721  50.132  1
192459  96.234  -76.728  50.092  1
192460  96.254  -76.735  50.054  1
192461  96.273  -76.742  50.020  1
192462  96.293  -76.749  49.989  1
192463  96.313  -76.756  49.960  1
192464  96.326  -76.767  49.932  1
192465  96.336  -76.781  49.909  1
192466  96.345  -76.794  49.887  1
192467  96.355  -76.809  49.867  1
192468  96.408  -76.787  49.847  1
192469  96.448  -76.764  49.831  1
192470  96.439  -76.753  49.816  1
192471  96.429  -76.742  49.800  1
192472  96.419  -76.731  49.785  1
192473  96.408  -76.760  49.770  1
192474  96.396  -76.796  49.753  1
192475  96.392  -76.834  49.732  1
192476  96.458  -76.897  49.707  1
192477  96.504  -76.923  49.679  1
192478  96.519  -76.899  49.650  1
192479  96.534  -76.874  49.624  1
192480  96.550  -76.849  49.598  1
192481  96.587  -76.842  49.572  1
192482  96.625  -76.837  49.545  1
192483  96.656  -76.847  49.519  1
192484  96.683  -76.868  49.490  1
192485  96.710  -76.890  49.460  1
192486  96.742  -76.916  49.429  1
192487  96.775  -76.944  49.397  1
192488  96.806  -76.968  49.365  1
192489  96.826  -76.972  49.334  1
192490  96.845  -76.978  49.303  1
192491  96.858  -76.989  49.272  1
192492  96.870  -77.000  49.243  1
192493  96.882  -77.011  49.215  1
192494  96.895  -77.022  49.186  1
192495  96.907  -77.034  49.160  1
192496  96.920  -77.045  49.134  1
192497  96.932  -77.056  49.108  1
192498  96.945  -77.068  49.084  1
192499  96.957  -77.078  49.059  1
192500  96.969  -77.090  49.034  1
192501  96.982  -77.101  49.007  1
192502  96.995  -77.111  48.981  1
192503  97.008  -77.120  48.954  1
192504  97.022  -77.129  48.926  1
192505  97.053  -77.147  48.898  1
192506  97.093  -77.169  48.871  1
192507  97.135  -77.191  48.844  1
192508  97.182  -77.207  48.818  1
192509  97.228  -77.223  48.793  1
192510  97.275  -77.240  48.768  1
192511  97.322  -77.256  48.744  1
192512  97.354  -77.269  48.721  1
192513  97.370  -77.277  48.699  1
192514  97.386  -77.285  48.677  1
192515  97.397  -77.280  48.655  1
192516  97.408  -77.276  48.634  1
192517  97.419  -77.271  48.610  1
192518  97.430  -77.267  48.588  1
192519  97.441  -77.263  48.566  1
192520  97.451  -77.258  48.542  1
192521  97.462  -77.254  48.519  1
192522  97.483  -77.255  48.495  1
192523  97.581  -77.303  48.470  1
192524  97.628  -77.324  48.445  1
192525  97.602  -77.318  48.419  1
192526  97.565  -77.309  48.392  1
192527  97.528  -77.300  48.364  1
192528  97.544  -77.297  48.336  1
192529  97.571  -77.294  48.308  1
192530  97.598  -77.293  48.280  1
192531  97.625  -77.291  48.251  1
192532  97.652  -77.289  48.221  1
192533  97.679  -77.287  48.192  1
192534  97.706  -77.285  48.164  1
192535  97.733  -77.283  48.135  1
192536  97.760  -77.281  48.107  1
192537  97.787  -77.279  48.077  1
192538  97.814  -77.279  48.046  1
192539  97.842  -77.281  48.016  1
192540  97.872  -77.269  47.985  1
192541  97.902  -77.258  47.954  1
192542  97.933  -77.246  47.922  1
192543  97.964  -77.235  47.889  1
192544  97.993  -77.222  47.857  1
192545  98.018  -77.207  47.825  1
192546  98.043  -77.192  47.793  1
192547  98.068  -77.178  47.760  1
192548  98.093  -77.163  47.730  1
192549  98.119  -77.149  47.701  1
192550  98.143  -77.134  47.673  1
192551  98.168  -77.119  47.644  1
192552  98.194  -77.105  47.614  1
192553  98.219  -77.091  47.585  1
192554  98.242  -77.078  47.557  1
192555  98.255  -77.073  47.529  1
192556  98.268  -77.069  47.502  1
192557  98.281  -77.065  47.474  1
192558  98.297  -77.085  47.446  1
192559  98.312  -77.106  47.418  1
192560  98.328  -77.128  47.390  1
192561  98.343  -77.149  47.362  1
192562  98.359  -77.169  47.335  1
192563  98.384  -77.180  47.309  1
192564  98.421  -77.184  47.283  1
192565  98.456  -77.188  47.259  1
192566  98.473  -77.197  47.238  1
192567  98.489  -77.207  47.216  1
192568  98.511  -77.219  47.193  1
192569  98.544  -77.232  47.170  1
192570  98.577  -77.244  47.146  1
192571  98.609  -77.257  47.123  1
192572  98.641  -77.271  47.101  1
192573  98.670  -77.288  47.080  1
192574  98.699  -77.306  47.058  1
192575  98.727  -77.323  47.038  1
192576  98.756  -77.341  47.017  1
192577  98.773  -77.354  46.995  1
192578  98.790  -77.368  46.973  1
192579  98.807  -77.382  46.952  1
192580  98.818  -77.382  46.932  1
192581  98.829  -77.383  46.910  1
192582  98.840  -77.383  46.888  1
192583  98.851  -77.383  46.865  1
192584  98.861  -77.384  46.843  1
192585  98.872  -77.384  46.819  1
192586  98.883  -77.384  46.795  1
192587  98.894  -77.385  46.771  1
192588  98.905  -77.385  46.748  1
192589  98.916  -77.385  46.724  1
192590  98.927  -77.385  46.699  1
192591  98.938  -77.385  46.675  1
192592  98.959  -77.377  46.652  1
192593  98.980  -77.368  46.629  1
192594  99.001  -77.360  46.605  1
192595  99.022  -77.351  46.580  1
192596  99.042  -77.345  46.557  1
192597  99.053  -77.350  46.534  1
192598  99.064  -77.354  46.511  1
192599  99.076  -77.370  46.489  1
192600  99.090  -77.396  46.465  1
192601  99.104  -77.422  46.442  1
192602  99.118  -77.448  46.418  1
192603  99.132  -77.473  46.395  1
192604  99.130  -77.486  46.372  1
192605  99.128  -77.499  46.349  1
192606  99.126  -77.513  46.326  1
192607  99.124  -77.526  46.303  1
192608  99.123  -77.539  46.280  1
192609  99.121  -77.553  46.256  1
192610  99.119  -77.566  46.233  1
192611  99.122  -77.576  46.208  1
192612  99.144  -77.573  46.185  1
192613  99.166  -77.570  46.162  1
192614  99.189  -77.567  46.139  1
192615  99.211  -77.564  46.117  1
192616  99.234  -77.561  46.095  1
192617  99.274  -77.565  46.073  1
192618  99.313  -77.569  46.051  1
192619  99.353  -77.573  46.032  1
192620  99.394  -77.577  46.012  1
192621  99.433  -77.580  45.994  1
192622  99.473  -77.584  45.977  1
192623  99.513  -77.588  45.960  1
192624  99.553  -77.592  45.943  1
192625  99.592  -77.595  45.927  1
192626  99.624  -77.595  45.912  1
192627  99.654  -77.595  45.898  1
192628  99.684  -77.594  45.883  1
192629  99.714  -77.593  45.871  1
192630  99.746  -77.599  45.857  1
192631  99.779  -77.615  45.844  1
192632  99.812  -77.630  45.831  1
192633  99.826  -77.642  45.817  1
192634  99.840  -77.654  45.803  1
192635  99.853  -77.666  45.789  1
192636  99.866  -77.678  45.775  1
192637  99.880  -77.690  45.760  1
192638  99.894  -77.702  45.747  1
192639  99.907  -77.714  45.733  1
192640  99.920  -77.727  45.718  1
192641  99.934  -77.739  45.707  1
192642  99.947  -77.751  45.695  1
192643  99.972  -77.777  45.683  1
192644  99.997  -77.802  45.671  1
192645  100.022  -77.829  45.663  1
192646  100.045  -77.846  45.653  1
192647  100.073  -77.853  45.643  1
192648  100.093  -77.867  45.633  1
192649  100.114  -77.881  45.623  1
192650  100.134  -77.895  45.614  1
192651  100.155  -77.909  45.605  1
192652  100.175  -77.922  45.594  1
192653  100.196  -77.936  45.584  1
192654  100.216  -77.950  45.572  1
192655  100.237  -77.964  45.560  1
192656  100.257  -77.978  45.547  1
192657  100.277  -77.991  45.533  1
192658  100.298  -78.006  45.520  1
192659  100.318  -78.019  45.508  1
192660  100.339  -78.033  45.494  1
192661  100.359  -78.047  45.480  1
192662  100.379  -78.061  45.465  1
192663  100.394  -78.070  45.450  1
192664  100.407  -78.078  45.435  1
192665  100.421  -78.085  45.420  1
192666  100.434  -78.093  45.405  1
192667  100.447  -78.100  45.390  1
192668  100.461  -78.107  45.375  1
192669  100.474  -78.115  45.360  1
192670  100.487  -78.122  45.346  1
192671  100.504  -78.125  45.331  1
192672  100.522  -78.128  45.317  1
192673  100.542  -78.134  45.303  1
192674  100.571  -78.136  45.288  1
192675  100.608  -78.129  45.274  1
192676  100.645  -78.122  45.260  1
192677  100.680  -78.117  45.247  1
192678  100.703  -78.119  45.233  1
192679  100.739  -78.130  45.219  1
192680  100.778  -78.143  45.205  1
192681  100.818  -78.155  45.191  1
192682  100.856  -78.168  45.177  1
192683  100.896  -78.180  45.163  1
192684  100.935  -78.191  45.148  1
192685  100.976  -78.198  45.134  1
192686  101.017  -78.206  45.118  1
192687  101.058  -78.213  45.104  1
192688  101.098  -78.221  45.090  1
192689  101.139  -78.228  45.075  1
192690  101.180  -78.237  45.062  1
192691  101.220  -78.244  45.048  1
192692  101.244  -78.258  45.034  1
192693  101.256  -78.275  45.020  1
192694  101.267  -78.294  45.005  1
192695  101.279  -78.312  44.990  1
192696  101.291  -78.330  44.974  1
192697  101.302  -78.348  44.959  1
192698  101.314  -78.366  44.945  1
192699  101.326  -78.366  44.930  1
192700  101.339  -78.365  44.914  1
192701  101.353  -78.363  44.899  1
192702  101.366  -78.362  44.883  1
192703  101.393  -78.375  44.867  1
192704  101.428  -78.396  44.851  1
192705  101.464  -78.417  44.832  1
192706  101.499  -78.438  44.815  1
192707  101.534  -78.460  44.798  1
192708  101.563  -78.484  44.780  1
192709  101.590  -78.510  44.764  1
192710  101.617  -78.535  44.747  1
192711  101.644  -78.561  44.730  1
192712  101.671  -78.586  44.713  1
192713  101.698  -78.612  44.698  1
192714  101.728  -78.633  44.682  1
192715  101.757  -78.653  44.666  1
192716  101.787  -78.673  44.650  1
192717  101.832  -78.696  44.635  1
192718  101.877  -78.724  44.620  1
192719  101.919  -78.755  44.605  1
192720  101.963  -78.787  44.590  1
192721  102.006  -78.819  44.576  1
192722  102.049  -78.851  44.562  1
192723  102.092  -78.883  44.548  1
192724  102.135  -78.915  44.533  1
192725  102.159  -78.922  44.519  1
192726  102.178  -78.924  44.505  1
192727  102.198  -78.926  44.491  1
192728  102.218  -78.927  44.478  1
192729  102.237  -78.929  44.464  1
192730  102.256  -78.930  44.451  1
192731  102.275  -78.932  44.436  1
192732  102.295  -78.933  44.422  1
192733  102.315  -78.935  44.409  1
192734  102.334  -78.937  44.395  1
192735  102.353  -78.938  44.382  1
192736  102.373  -78.940  44.368  1
193019  93.519  -76.350  54.077  1
193020  93.538  -76.353  54.081  1
193021  93.556  -76.356  54.085  1
193022  93.574  -76.359  54.089  1
193023  93.593  -76.362  54.094  1
193024  93.611  -76.364  54.099  1
193025  93.630  -76.367  54.106  1
193026  93.648  -76.370  54.113  1
193027  93.666  -76.373  54.119  1
193028  93.685  -76.376  54.125  1
193029  93.703  -76.379  54.133  1
193030  93.721  -76.383  54.143  1
193031  93.740  -76.385  54.156  1
193032  93.759  -76.382  54.171  1
193033  93.774  -76.379  54.188  1
193034  93.790  -76.364  54.193  1
193035  93.806  -76.348  54.196  1
193036  93.822  -76.332  54.198  1
193037  93.839  -76.317  54.201  1
193038  93.854  -76.304  54.203  1
193039  93.869  -76.300  54.204  1
193040  93.889  -76.306  54.204  1
193041  93.908  -76.312  54.202  1
193042  93.927  -76.318  54.202  1
193043  93.945  -76.323  54.202  1
193044  93.965  -76.329  54.205  1
193045  93.983  -76.335  54.210  1
193046  94.000  -76.338  54.216  1
193047  94.017  -76.336  54.219  1
193048  94.035  -76.332  54.216  1
193049  94.053  -76.329  54.212  1
193050  94.072  -76.326  54.210  1
193051  94.092  -76.326  54.209  1
193052  94.112  -76.325  54.208  1
193053  94.131  -76.323  54.209  1
193054  94.151  -76.323  54.206  1
193055  94.171  -76.322  54.201  1
193056  94.193  -76.317  54.195  1
193057  94.215  -76.308  54.187  1
193058  94.239  -76.299  54.175  1
193059  94.259  -76.295  54.159  1
193060  94.279  -76.293  54.142  1
193061  94.299  -76.292  54.119  1
193062  94.319  -76.290  54.093  1
193063  94.338  -76.289  54.066  1
193064  94.358  -76.287  54.038  1
193065  94.377  -76.285  54.009  1
193066  94.395  -76.283  53.980  1
193067  94.413  -76.282  53.949  1
193068  94.431  -76.279  53.916  1
193069  94.449  -76.279  53.883  1
193070  94.468  -76.277  53.852  1
193071  94.486  -76.276  53.822  1
193072  94.504  -76.276  53.790  1
193073  94.518  -76.275  53.758  1
193074  94.531  -76.275  53.727  1
193075  94.545  -76.274  53.694  1
193076  94.558  -76.274  53.663  1
193077  94.571  -76.274  53.634  1
193078  94.583  -76.283  53.606  1
193079  94.596  -76.292  53.576  1
193080  94.607  -76.301  53.546  1
193081  94.619  -76.310  53.513  1
193082  94.631  -76.320  53.477  1
193083  94.643  -76.329  53.440  1
193084  94.663  -76.340  53.403  1
193085  94.675  -76.345  53.368  1
193086  94.686  -76.351  53.334  1
193087  94.698  -76.355  53.301  1
193088  94.711  -76.359  53.268  1
193089  94.723  -76.362  53.235  1
193090  94.736  -76.366  53.201  1
193091  94.748  -76.370  53.168  1
193092  94.761  -76.373  53.134  1
193093  94.773  -76.376  53.100  1
193094  94.786  -76.380  53.063  1
193095  94.799  -76.384  53.023  1
193096  94.811  -76.388  52.981  1
193097  94.824  -76.391  52.938  1
193098  94.836  -76.395  52.893  1
193099  94.849  -76.398  52.849  1
193100  94.861  -76.402  52.804  1
193101  94.874  -76.405  52.760  1
193102  94.887  -76.409  52.716  1
193103  94.899  -76.413  52.673  1
193104  94.912  -76.417  52.631  1
193105  94.924  -76.420  52.586  1
193106  94.936  -76.423  52.541  1
193107  94.949  -76.427  52.494  1
193108  94.963  -76.433  52.445  1
193109  94.987  -76.439  52.391  1
193110  95.012  -76.446  52.337  1
193111  95.037  -76.452  52.282  1
193112  95.061  -76.459  52.226  1
193113  95.086  -76.465  52.172  1
193114  95.111  -76.472  52.120  1
193115  95.151  -76.471  52.070  1
193116  95.200  -76.467  52.024  1
193117  95.250  -76.462  51.980  1
193118  95.282  -76.463  51.937  1
193119  95.306  -76.468  51.895  1
193120  95.328  -76.473  51.851  1
193121  95.351  -76.477  51.808  1
193122  95.375  -76.482  51.766  1
193123  95.398  -76.486  51.726  1
193124  95.421  -76.491  51.684  1
193125  95.444  -76.496  51.642  1
193126  95.467  -76.501  51.598  1
193127  95.490  -76.505  51.554  1
193128  95.513  -76.510  51.513  1
193129  95.533  -76.520  51.475  1
193130  95.551  -76.530  51.440  1
193131  95.570  -76.540  51.406  1
193132  95.590  -76.551  51.374  1
193133  95.609  -76.561  51.342  1
193134  95.629  -76.571  51.310  1
193135  95.659  -76.574  51.275  1
193136  95.688  -76.577  51.238  1
193137  95.716  -76.580  51.197  1
193138  95.739  -76.584  51.154  1
193139  95.762  -76.589  51.109  1
193140  95.785  -76.594  51.065  1
193141  95.808  -76.599  51.021  1
193142  95.831  -76.603  50.977  1
193143  95.854  -76.608  50.935  1
193144  95.878  -76.614  50.893  1
193145  95.902  -76.621  50.852  1
193146  95.926  -76.627  50.811  1
193147  95.950  -76.630  50.767  1
193148  95.972  -76.632  50.721  1
193149  95.992  -76.637  50.674  1
193150  96.013  -76.643  50.627  1
193151  96.034  -76.648  50.577  1
193152  96.054  -76.652  50.525  1
193153  96.075  -76.658  50.471  1
193154  96.096  -76.661  50.415  1
193155  96.116  -76.665  50.358  1
193156  96.136  -76.669  50.303  1
193157  96.171  -76.678  50.254  1
193158  96.194  -76.686  50.207  1
193159  96.214  -76.693  50.164  1
193160  96.234  -76.699  50.124  1
193161  96.253  -76.706  50.087  1
193162  96.273  -76.714  50.054  1
193163  96.293  -76.721  50.024  1
193164  96.312  -76.727  49.996  1
193165  96.332  -76.734  49.970  1
193166  96.352  -76.742  49.946  1
193167  96.368  -76.751  49.925  1
193168  96.385  -76.759  49.905  1
193169  96.399  -76.742  49.886  1
193170  96.389  -76.730  49.871  1
193171  96.380  -76.720  49.856  1
193172  96.370  -76.709  49.840  1
193173  96.361  -76.698  49.825  1
193174  96.351  -76.690  49.809  1
193175  96.339  -76.726  49.790  1
193176  96.375  -76.778  49.767  1
193177  96.441  -76.841  49.739  1
193178  96.494  -76.881  49.709  1
193179  96.509  -76.856  49.680  1
193180  96.526  -76.833  49.652  1
193181  96.565  -76.827  49.625  1
193182  96.602  -76.821  49.598  1
193183  96.641  -76.815  49.571  1
193184  96.677  -76.814  49.543  1
193185  96.703  -76.835  49.513  1
193186  96.730  -76.856  49.482  1
193187  96.756  -76.878  49.450  1
193188  96.783  -76.899  49.418  1
193189  96.813  -76.924  49.385  1
193190  96.842  -76.944  49.352  1
193191  96.860  -76.951  49.321  1
193192  96.873  -76.962  49.291  1
193193  96.885  -76.974  49.261  1
193194  96.897  -76.985  49.232  1
193195  96.910  -76.997  49.203  1
193196  96.923  -77.007  49.177  1
193197  96.936  -77.016  49.151  1
193198  96.949  -77.025  49.125  1
193199  96.962  -77.035  49.102  1
193200  96.975  -77.044  49.077  1
193201  96.989  -77.053  49.052  1
193202  97.002  -77.063  49.027  1
193203  97.015  -77.072  48.999  1
193204  97.029  -77.081  48.972  1
193205  97.062  -77.106  48.944  1
193206  97.085  -77.117  48.916  1
193207  97.123  -77.137  48.889  1
193208  97.164  -77.159  48.862  1
193209  97.205  -77.181  48.835  1
193210  97.245  -77.202  48.811  1
193211  97.286  -77.224  48.786  1
193212  97.326  -77.246  48.761  1
193213  97.371  -77.264  48.737  1
193214  97.384  -77.265  48.715  1
193215  97.395  -77.260  48.692  1
193216  97.406  -77.256  48.670  1
193217  97.417  -77.251  48.648  1
193218  97.428  -77.247  48.624  1
193219  97.439  -77.243  48.601  1
193220  97.450  -77.238  48.578  1
193221  97.461  -77.234  48.553  1
193222  97.472  -77.229  48.529  1
193223  97.483  -77.225  48.505  1
193224  97.577  -77.270  48.480  1
193225  97.623  -77.299  48.454  1
193226  97.586  -77.290  48.427  1
193227  97.549  -77.281  48.400  1
193228  97.532  -77.274  48.372  1
193229  97.559  -77.272  48.343  1
193230  97.586  -77.270  48.314  1
193231  97.612  -77.268  48.285  1
193232  97.640  -77.266  48.256  1
193233  97.667  -77.264  48.226  1
193234  97.693  -77.262  48.197  1
193235  97.721  -77.260  48.168  1
193236  97.747  -77.258  48.140  1
193237  97.775  -77.257  48.112  1
193238  97.801  -77.254  48.082  1
193239  97.828  -77.253  48.053  1
193240  97.856  -77.254  48.024  1
193241  97.886  -77.244  47.994  1
193242  97.917  -77.232  47.963  1
193243  97.947  -77.220  47.931  1
193244  97.973  -77.206  47.897  1
193245  97.998  -77.191  47.866  1
193246  98.023  -77.176  47.834  1
193247  98.048  -77.162  47.801  1
193248  98.073  -77.147  47.769  1
193249  98.098  -77.133  47.738  1
193250  98.123  -77.118  47.709  1
193251  98.148  -77.103  47.681  1
193252  98.173  -77.089  47.652  1
193253  98.199  -77.075  47.622  1
193254  98.224  -77.059  47.593  1
193255  98.248  -77.045  47.565  1
193256  98.273  -77.031  47.537  1
193257  98.286  -77.027  47.509  1
193258  98.302  -77.048  47.480  1
193259  98.317  -77.069  47.452  1
193260  98.333  -77.091  47.423  1
193261  98.348  -77.111  47.395  1
193262  98.364  -77.132  47.368  1
193263  98.379  -77.153  47.340  1
193264  98.407  -77.161  47.314  1
193265  98.442  -77.166  47.289  1
193266  98.458  -77.175  47.267  1
193267  98.473  -77.186  47.244  1
193268  98.489  -77.196  47.222  1
193269  98.510  -77.207  47.200  1
193270  98.543  -77.219  47.176  1
193271  98.575  -77.232  47.153  1
193272  98.608  -77.245  47.130  1
193273  98.641  -77.257  47.107  1
193274  98.673  -77.270  47.087  1
193275  98.705  -77.285  47.066  1
193276  98.734  -77.302  47.045  1
193277  98.760  -77.319  47.024  1
193278  98.776  -77.332  47.002  1
193279  98.793  -77.345  46.980  1
193280  98.810  -77.359  46.959  1
193281  98.828  -77.373  46.937  1
193282  98.843  -77.384  46.915  1
193283  98.854  -77.384  46.892  1
193284  98.865  -77.385  46.869  1
193285  98.876  -77.385  46.846  1
193286  98.887  -77.385  46.823  1
193287  98.898  -77.385  46.800  1
193288  98.909  -77.385  46.777  1
193289  98.919  -77.385  46.753  1
193290  98.930  -77.386  46.729  1
193291  98.941  -77.386  46.704  1
193292  98.952  -77.386  46.679  1
193293  98.973  -77.378  46.656  1
193294  98.994  -77.370  46.633  1
193295  99.015  -77.361  46.609  1
193296  99.037  -77.352  46.586  1
193297  99.049  -77.355  46.562  1
193298  99.060  -77.360  46.539  1
193299  99.071  -77.364  46.517  1
193300  99.082  -77.368  46.494  1
193301  99.094  -77.379  46.471  1
193302  99.108  -77.405  46.447  1
193303  99.122  -77.431  46.424  1
193304  99.136  -77.457  46.400  1
193305  99.143  -77.478  46.376  1
193306  99.142  -77.491  46.353  1
193307  99.140  -77.504  46.330  1
193308  99.138  -77.517  46.308  1
193309  99.136  -77.531  46.284  1
193310  99.134  -77.544  46.261  1
193311  99.133  -77.558  46.237  1
193312  99.145  -77.561  46.212  1
193313  99.167  -77.558  46.189  1
193314  99.189  -77.555  46.166  1
193315  99.211  -77.552  46.143  1
193316  99.233  -77.549  46.121  1
193317  99.255  -77.546  46.098  1
193318  99.279  -77.544  46.076  1
193319  99.319  -77.548  46.054  1
193320  99.359  -77.551  46.034  1
193321  99.399  -77.555  46.016  1
193322  99.438  -77.559  45.998  1
193323  99.478  -77.563  45.980  1
193324  99.518  -77.567  45.963  1
193325  99.558  -77.570  45.945  1
193326  99.598  -77.574  45.928  1
193327  99.638  -77.578  45.913  1
193328  99.678  -77.582  45.899  1
193329  99.717  -77.586  45.885  1
193330  99.753  -77.587  45.872  1
193331  99.783  -77.586  45.858  1
193332  99.816  -77.599  45.843  1
193333  99.832  -77.611  45.830  1
193334  99.846  -77.623  45.816  1
193335  99.859  -77.635  45.802  1
193336  99.873  -77.647  45.788  1
193337  99.886  -77.659  45.774  1
193338  99.900  -77.671  45.759  1
193339  99.913  -77.683  45.745  1
193340  99.926  -77.696  45.732  1
193341  99.940  -77.708  45.719  1
193342  99.954  -77.720  45.707  1
193343  99.967  -77.732  45.695  1
193344  99.988  -77.752  45.683  1
193345  100.012  -77.779  45.672  1
193346  100.037  -77.805  45.663  1
193347  100.063  -77.830  45.653  1
193348  100.085  -77.845  45.643  1
193349  100.104  -77.860  45.633  1
193350  100.124  -77.875  45.623  1
193351  100.143  -77.890  45.614  1
193352  100.162  -77.906  45.604  1
193353  100.182  -77.920  45.594  1
193354  100.203  -77.934  45.584  1
193355  100.223  -77.947  45.572  1
193356  100.244  -77.961  45.559  1
193357  100.264  -77.975  45.545  1
193358  100.284  -77.989  45.532  1
193359  100.305  -78.003  45.519  1
193360  100.325  -78.016  45.506  1
193361  100.346  -78.031  45.492  1
193362  100.366  -78.044  45.478  1
193363  100.387  -78.058  45.464  1
193364  100.402  -78.068  45.448  1
193365  100.416  -78.075  45.434  1
193366  100.429  -78.083  45.419  1
193367  100.444  -78.087  45.403  1
193368  100.462  -78.090  45.388  1
193369  100.480  -78.091  45.373  1
193370  100.498  -78.094  45.357  1
193371  100.516  -78.095  45.342  1
193372  100.534  -78.097  45.328  1
193373  100.554  -78.103  45.315  1
193374  100.577  -78.113  45.301  1
193375  100.601  -78.124  45.287  1
193376  100.634  -78.121  45.272  1
193377  100.671  -78.114  45.258  1
193378  100.707  -78.107  45.245  1
193379  100.733  -78.109  45.231  1
193380  100.759  -78.113  45.218  1
193381  100.798  -78.126  45.204  1
193382  100.837  -78.138  45.191  1
193383  100.876  -78.151  45.177  1
193384  100.915  -78.163  45.163  1
193385  100.955  -78.176  45.149  1
193386  100.993  -78.188  45.134  1
193387  101.033  -78.200  45.119  1
193388  101.074  -78.207  45.104  1
193389  101.115  -78.215  45.089  1
193390  101.156  -78.222  45.076  1
193391  101.196  -78.230  45.061  1
193392  101.237  -78.238  45.047  1
193393  101.254  -78.253  45.033  1
193394  101.265  -78.272  45.019  1
193395  101.277  -78.290  45.005  1
193396  101.288  -78.308  44.990  1
193397  101.301  -78.326  44.975  1
193398  101.317  -78.338  44.960  1
193399  101.334  -78.350  44.945  1
193400  101.351  -78.361  44.930  1
193401  101.368  -78.364  44.914  1
193402  101.381  -78.363  44.898  1
193403  101.394  -78.361  44.884  1
193404  101.409  -78.363  44.868  1
193405  101.445  -78.384  44.852  1
193406  101.480  -78.404  44.833  1
193407  101.515  -78.426  44.816  1
193408  101.549  -78.448  44.799  1
193409  101.575  -78.473  44.782  1
193410  101.603  -78.499  44.765  1
193411  101.629  -78.525  44.748  1
193412  101.656  -78.551  44.731  1
193413  101.685  -78.573  44.715  1
193414  101.714  -78.593  44.699  1
193415  101.744  -78.614  44.683  1
193416  101.773  -78.634  44.668  1
193417  101.804  -78.655  44.651  1
193418  101.849  -78.678  44.636  1
193419  101.894  -78.701  44.621  1
193420  101.938  -78.730  44.605  1
193421  101.981  -78.761  44.591  1
193422  102.024  -78.793  44.576  1
193423  102.067  -78.825  44.562  1
193424  102.110  -78.857  44.549  1
193425  102.153  -78.889  44.534  1
193426  102.184  -78.905  44.520  1
193427  102.203  -78.906  44.507  1
193428  102.223  -78.908  44.493  1
193429  102.243  -78.910  44.478  1
193430  102.262  -78.912  44.464  1
193431  102.281  -78.913  44.451  1
193432  102.301  -78.915  44.436  1
193433  102.320  -78.916  44.422  1
193434  102.340  -78.918  44.409  1
193435  102.359  -78.919  44.395  1
193436  102.379  -78.921  44.381  1
193437  102.398  -78.923  44.367  1
193720  93.511  -76.326  54.069  1
193721  93.530  -76.329  54.073  1
193722  93.548  -76.332  54.078  1
193723  93.566  -76.336  54.083  1
193724  93.585  -76.339  54.088  1
193725  93.603  -76.342  54.093  1
193726  93.621  -76.344  54.100  1
193727  93.640  -76.347  54.108  1
193728  93.658  -76.350  54.114  1
193729  93.677  -76.353  54.120  1
193730  93.695  -76.356  54.128  1
193731  93.713  -76.359  54.137  1
193732  93.731  -76.361  54.149  1
193733  93.750  -76.364  54.164  1
193734  93.767  -76.360  54.180  1
193735  93.783  -76.344  54.185  1
193736  93.800  -76.328  54.189  1
193737  93.816  -76.312  54.192  1
193738  93.832  -76.296  54.196  1
193739  93.848  -76.282  54.198  1
193740  93.865  -76.283  54.201  1
193741  93.884  -76.289  54.203  1
193742  93.903  -76.295  54.203  1
193743  93.922  -76.301  54.204  1
193744  93.941  -76.307  54.207  1
193745  93.960  -76.313  54.210  1
193746  93.979  -76.319  54.217  1
193747  93.997  -76.323  54.222  1
193748  94.014  -76.321  54.225  1
193749  94.032  -76.317  54.222  1
193750  94.052  -76.316  54.218  1
193751  94.071  -76.315  54.217  1
193752  94.091  -76.314  54.216  1
193753  94.111  -76.313  54.216  1
193754  94.131  -76.312  54.217  1
193755  94.150  -76.310  54.215  1
193756  94.170  -76.310  54.209  1
193757  94.191  -76.306  54.202  1
193758  94.214  -76.297  54.193  1
193759  94.237  -76.289  54.180  1
193760  94.260  -76.280  54.164  1
193761  94.280  -76.277  54.147  1
193762  94.300  -76.276  54.124  1
193763  94.320  -76.274  54.098  1
193764  94.339  -76.273  54.072  1
193765  94.358  -76.271  54.043  1
193766  94.376  -76.269  54.014  1
193767  94.394  -76.267  53.984  1
193768  94.413  -76.265  53.954  1
193769  94.431  -76.263  53.922  1
193770  94.449  -76.263  53.890  1
193771  94.468  -76.261  53.859  1
193772  94.485  -76.260  53.829  1
193773  94.498  -76.260  53.797  1
193774  94.512  -76.260  53.766  1
193775  94.526  -76.260  53.736  1
193776  94.539  -76.259  53.703  1
193777  94.552  -76.259  53.672  1
193778  94.566  -76.259  53.644  1
193779  94.578  -76.267  53.617  1
193780  94.590  -76.276  53.589  1
193781  94.602  -76.284  53.561  1
193782  94.614  -76.293  53.530  1
193783  94.626  -76.302  53.494  1
193784  94.643  -76.313  53.457  1
193785  94.665  -76.325  53.420  1
193786  94.676  -76.330  53.384  1
193787  94.687  -76.335  53.350  1
193788  94.698  -76.340  53.318  1
193789  94.709  -76.345  53.286  1
193790  94.721  -76.349  53.252  1
193791  94.734  -76.353  53.219  1
193792  94.747  -76.356  53.185  1
193793  94.759  -76.360  53.150  1
193794  94.772  -76.364  53.114  1
193795  94.784  -76.367  53.077  1
193796  94.797  -76.370  53.036  1
193797  94.809  -76.374  52.992  1
193798  94.822  -76.378  52.947  1
193799  94.834  -76.382  52.903  1
193800  94.847  -76.385  52.858  1
193801  94.859  -76.389  52.814  1
193802  94.872  -76.392  52.772  1
193803  94.885  -76.396  52.729  1
193804  94.897  -76.399  52.687  1
193805  94.910  -76.403  52.646  1
193806  94.922  -76.407  52.601  1
193807  94.935  -76.411  52.556  1
193808  94.948  -76.414  52.509  1
193809  94.953  -76.423  52.461  1
193810  94.977  -76.430  52.408  1
193811  95.001  -76.436  52.356  1
193812  95.027  -76.442  52.302  1
193813  95.051  -76.448  52.246  1
193814  95.076  -76.455  52.189  1
193815  95.101  -76.461  52.136  1
193816  95.147  -76.458  52.087  1
193817  95.197  -76.454  52.041  1
193818  95.246  -76.448  51.998  1
193819  95.286  -76.448  51.955  1
193820  95.310  -76.452  51.912  1
193821  95.332  -76.457  51.864  1
193822  95.355  -76.461  51.818  1
193823  95.379  -76.466  51.773  1
193824  95.402  -76.471  51.731  1
193825  95.425  -76.476  51.689  1
193826  95.448  -76.480  51.647  1
193827  95.471  -76.485  51.606  1
193828  95.494  -76.489  51.566  1
193829  95.517  -76.494  51.529  1
193830  95.540  -76.499  51.493  1
193831  95.563  -76.504  51.458  1
193832  95.584  -76.512  51.426  1
193833  95.603  -76.522  51.396  1
193834  95.622  -76.532  51.367  1
193835  95.641  -76.542  51.338  1
193836  95.668  -76.548  51.305  1
193837  95.697  -76.551  51.268  1
193838  95.722  -76.555  51.227  1
193839  95.745  -76.560  51.183  1
193840  95.767  -76.564  51.136  1
193841  95.791  -76.569  51.091  1
193842  95.814  -76.575  51.046  1
193843  95.838  -76.581  51.002  1
193844  95.863  -76.587  50.958  1
193845  95.887  -76.593  50.915  1
193846  95.911  -76.599  50.872  1
193847  95.935  -76.605  50.829  1
193848  95.959  -76.608  50.785  1
193849  95.981  -76.608  50.738  1
193850  96.002  -76.613  50.690  1
193851  96.023  -76.618  50.645  1
193852  96.043  -76.623  50.596  1
193853  96.063  -76.628  50.545  1
193854  96.084  -76.633  50.492  1
193855  96.104  -76.636  50.438  1
193856  96.125  -76.640  50.384  1
193857  96.145  -76.643  50.332  1
193858  96.172  -76.649  50.284  1
193859  96.194  -76.657  50.239  1
193860  96.214  -76.664  50.197  1
193861  96.233  -76.671  50.157  1
193862  96.253  -76.678  50.120  1
193863  96.272  -76.685  50.087  1
193864  96.292  -76.692  50.058  1
193865  96.312  -76.699  50.032  1
193866  96.332  -76.707  50.007  1
193867  96.352  -76.715  49.984  1
193868  96.372  -76.723  49.963  1
193869  96.391  -76.729  49.943  1
193870  96.374  -76.716  49.924  1
193871  96.357  -76.704  49.910  1
193872  96.340  -76.691  49.895  1
193873  96.323  -76.678  49.879  1
193874  96.306  -76.666  49.864  1
193875  96.292  -76.654  49.847  1
193876  96.292  -76.660  49.826  1
193877  96.358  -76.723  49.800  1
193878  96.424  -76.786  49.771  1
193879  96.484  -76.839  49.740  1
193880  96.504  -76.817  49.709  1
193881  96.541  -76.812  49.680  1
193882  96.580  -76.806  49.652  1
193883  96.618  -76.799  49.624  1
193884  96.656  -76.794  49.595  1
193885  96.694  -76.788  49.566  1
193886  96.724  -76.802  49.535  1
193887  96.750  -76.824  49.503  1
193888  96.777  -76.845  49.471  1
193889  96.803  -76.866  49.437  1
193890  96.830  -76.887  49.403  1
193891  96.857  -76.909  49.371  1
193892  96.876  -76.922  49.340  1
193893  96.889  -76.931  49.309  1
193894  96.903  -76.940  49.279  1
193895  96.916  -76.950  49.249  1
193896  96.930  -76.959  49.221  1
193897  96.943  -76.968  49.193  1
193898  96.956  -76.977  49.167  1
193899  96.969  -76.986  49.143  1
193900  96.982  -76.996  49.120  1
193901  96.996  -77.005  49.095  1
193902  97.009  -77.014  49.071  1
193903  97.022  -77.023  49.046  1
193904  97.037  -77.033  49.019  1
193905  97.069  -77.058  48.991  1
193906  97.101  -77.084  48.963  1
193907  97.124  -77.094  48.934  1
193908  97.153  -77.103  48.907  1
193909  97.193  -77.125  48.879  1
193910  97.234  -77.147  48.853  1
193911  97.275  -77.169  48.829  1
193912  97.315  -77.191  48.804  1
193913  97.356  -77.213  48.778  1
193914  97.389  -77.248  48.754  1
193915  97.408  -77.259  48.731  1
193916  97.417  -77.252  48.707  1
193917  97.426  -77.245  48.685  1
193918  97.435  -77.238  48.662  1
193919  97.444  -77.232  48.638  1
193920  97.454  -77.226  48.613  1
193921  97.463  -77.219  48.589  1
193922  97.472  -77.212  48.565  1
193923  97.481  -77.205  48.540  1
193924  97.492  -77.201  48.515  1
193925  97.532  -77.224  48.489  1
193926  97.568  -77.251  48.462  1
193927  97.570  -77.262  48.435  1
193928  97.533  -77.253  48.407  1
193929  97.546  -77.249  48.379  1
193930  97.573  -77.248  48.350  1
193931  97.600  -77.245  48.321  1
193932  97.628  -77.243  48.291  1
193933  97.654  -77.241  48.262  1
193934  97.681  -77.239  48.232  1
193935  97.708  -77.238  48.203  1
193936  97.735  -77.235  48.175  1
193937  97.762  -77.234  48.146  1
193938  97.789  -77.232  48.118  1
193939  97.816  -77.229  48.089  1
193940  97.843  -77.228  48.061  1
193941  97.870  -77.226  48.032  1
193942  97.900  -77.218  48.002  1
193943  97.928  -77.204  47.972  1
193944  97.953  -77.190  47.940  1
193945  97.978  -77.175  47.906  1
193946  98.003  -77.160  47.875  1
193947  98.028  -77.146  47.843  1
193948  98.053  -77.132  47.811  1
193949  98.078  -77.117  47.779  1
193950  98.103  -77.102  47.748  1
193951  98.129  -77.089  47.718  1
193952  98.154  -77.076  47.688  1
193953  98.179  -77.064  47.660  1
193954  98.205  -77.051  47.630  1
193955  98.230  -77.039  47.601  1
193956  98.256  -77.026  47.572  1
193957  98.282  -77.014  47.544  1
193958  98.306  -77.010  47.515  1
193959  98.314  -77.041  47.486  1
193960  98.334  -77.058  47.458  1
193961  98.353  -77.074  47.429  1
193962  98.369  -77.095  47.401  1
193963  98.384  -77.116  47.374  1
193964  98.400  -77.137  47.347  1
193965  98.427  -77.144  47.321  1
193966  98.442  -77.154  47.297  1
193967  98.458  -77.164  47.274  1
193968  98.474  -77.174  47.252  1
193969  98.489  -77.185  47.229  1
193970  98.508  -77.195  47.207  1
193971  98.541  -77.208  47.184  1
193972  98.574  -77.221  47.161  1
193973  98.606  -77.233  47.138  1
193974  98.639  -77.246  47.115  1
193975  98.672  -77.259  47.094  1
193976  98.705  -77.271  47.074  1
193977  98.737  -77.284  47.053  1
193978  98.763  -77.296  47.032  1
193979  98.780  -77.310  47.010  1
193980  98.797  -77.323  46.988  1
193981  98.814  -77.337  46.967  1
193982  98.831  -77.351  46.944  1
193983  98.848  -77.364  46.922  1
193984  98.865  -77.378  46.898  1
193985  98.879  -77.385  46.875  1
193986  98.890  -77.385  46.851  1
193987  98.901  -77.385  46.829  1
193988  98.912  -77.386  46.806  1
193989  98.923  -77.386  46.782  1
193990  98.934  -77.386  46.758  1
193991  98.944  -77.387  46.734  1
193992  98.955  -77.387  46.708  1
193993  98.967  -77.387  46.683  1
193994  98.988  -77.379  46.660  1
193995  99.009  -77.370  46.636  1
193996  99.030  -77.362  46.613  1
193997  99.045  -77.360  46.591  1
193998  99.056  -77.365  46.568  1
193999  99.067  -77.370  46.544  1
194000  99.078  -77.374  46.521  1
194001  99.089  -77.378  46.498  1
194002  99.100  -77.382  46.475  1
194003  99.111  -77.389  46.452  1
194004  99.125  -77.414  46.428  1
194005  99.139  -77.440  46.404  1
194006  99.153  -77.466  46.381  1
194007  99.155  -77.483  46.358  1
194008  99.153  -77.496  46.335  1
194009  99.152  -77.509  46.312  1
194010  99.150  -77.523  46.289  1
194011  99.148  -77.536  46.265  1
194012  99.146  -77.549  46.241  1
194013  99.167  -77.547  46.216  1
194014  99.189  -77.544  46.193  1
194015  99.211  -77.541  46.169  1
194016  99.233  -77.538  46.146  1
194017  99.256  -77.535  46.123  1
194018  99.278  -77.532  46.101  1
194019  99.300  -77.529  46.080  1
194020  99.324  -77.526  46.057  1
194021  99.364  -77.530  46.037  1
194022  99.404  -77.534  46.019  1
194023  99.443  -77.538  46.001  1
194024  99.484  -77.542  45.983  1
194025  99.523  -77.545  45.965  1
194026  99.563  -77.549  45.947  1
194027  99.603  -77.553  45.929  1
194028  99.643  -77.557  45.914  1
194029  99.683  -77.561  45.900  1
194030  99.723  -77.564  45.886  1
194031  99.763  -77.568  45.872  1
194032  99.802  -77.572  45.858  1
194033  99.839  -77.580  45.844  1
194034  99.852  -77.592  45.829  1
194035  99.865  -77.604  45.816  1
194036  99.879  -77.616  45.802  1
194037  99.893  -77.628  45.787  1
194038  99.906  -77.640  45.773  1
194039  99.919  -77.652  45.758  1
194040  99.933  -77.664  45.745  1
194041  99.946  -77.677  45.732  1
194042  99.960  -77.689  45.719  1
194043  99.973  -77.701  45.707  1
194044  99.987  -77.713  45.696  1
194045  100.003  -77.729  45.684  1
194046  100.028  -77.755  45.673  1
194047  100.053  -77.780  45.663  1
194048  100.077  -77.805  45.652  1
194049  100.107  -77.820  45.642  1
194050  100.129  -77.834  45.633  1
194051  100.149  -77.849  45.624  1
194052  100.168  -77.865  45.614  1
194053  100.188  -77.880  45.604  1
194054  100.207  -77.895  45.594  1
194055  100.226  -77.910  45.583  1
194056  100.246  -77.926  45.571  1
194057  100.265  -77.941  45.557  1
194058  100.284  -77.956  45.544  1
194059  100.303  -77.971  45.531  1
194060  100.323  -77.987  45.517  1
194061  100.342  -78.002  45.504  1
194062  100.362  -78.017  45.490  1
194063  100.381  -78.032  45.475  1
194064  100.401  -78.047  45.461  1
194065  100.421  -78.053  45.446  1
194066  100.438  -78.056  45.431  1
194067  100.457  -78.057  45.416  1
194068  100.474  -78.059  45.400  1
194069  100.492  -78.061  45.385  1
194070  100.510  -78.062  45.370  1
194071  100.528  -78.065  45.355  1
194072  100.546  -78.066  45.340  1
194073  100.566  -78.072  45.326  1
194074  100.590  -78.083  45.312  1
194075  100.613  -78.094  45.298  1
194076  100.635  -78.104  45.284  1
194077  100.660  -78.112  45.270  1
194078  100.696  -78.106  45.256  1
194079  100.733  -78.099  45.243  1
194080  100.762  -78.098  45.229  1
194081  100.785  -78.101  45.216  1
194082  100.818  -78.109  45.203  1
194083  100.857  -78.122  45.190  1
194084  100.896  -78.134  45.176  1
194085  100.935  -78.147  45.162  1
194086  100.974  -78.159  45.148  1
194087  101.013  -78.172  45.134  1
194088  101.052  -78.184  45.119  1
194089  101.092  -78.197  45.104  1
194090  101.131  -78.208  45.090  1
194091  101.172  -78.216  45.076  1
194092  101.212  -78.223  45.061  1
194093  101.252  -78.232  45.047  1
194094  101.263  -78.250  45.033  1
194095  101.275  -78.268  45.018  1
194096  101.287  -78.285  45.005  1
194097  101.305  -78.296  44.990  1
194098  101.321  -78.308  44.975  1
194099  101.338  -78.320  44.960  1
194100  101.355  -78.332  44.945  1
194101  101.372  -78.344  44.929  1
194102  101.389  -78.356  44.914  1
194103  101.409  -78.362  44.899  1
194104  101.422  -78.361  44.884  1
194105  101.435  -78.360  44.868  1
194106  101.461  -78.371  44.852  1
194107  101.496  -78.392  44.834  1
194108  101.532  -78.413  44.817  1
194109  101.561  -78.438  44.800  1
194110  101.588  -78.463  44.783  1
194111  101.615  -78.489  44.766  1
194112  101.643  -78.513  44.749  1
194113  101.672  -78.533  44.732  1
194114  101.702  -78.554  44.716  1
194115  101.731  -78.574  44.699  1
194116  101.761  -78.595  44.684  1
194117  101.790  -78.615  44.669  1
194118  101.820  -78.636  44.652  1
194119  101.866  -78.659  44.637  1
194120  101.911  -78.682  44.621  1
194121  101.956  -78.705  44.606  1
194122  101.999  -78.736  44.591  1
194123  102.043  -78.767  44.577  1
194124  102.086  -78.799  44.563  1
194125  102.129  -78.831  44.549  1
194126  102.172  -78.863  44.535  1
194127  102.209  -78.887  44.521  1
194128  102.229  -78.889  44.506  1
194129  102.248  -78.891  44.492  1
194130  102.268  -78.893  44.478  1
194131  102.287  -78.894  44.464  1
194132  102.307  -78.896  44.451  1
194133  102.326  -78.897  44.436  1
194134  102.345  -78.899  44.422  1
194135  102.365  -78.900  44.408  1
194136  102.384  -78.902  44.394  1
194137  102.404  -78.904  44.380  1
194138  102.423  -78.905  44.366  1
194139  102.443  -78.907  44.352  1
194422  93.521  -76.306  54.065  1
194423  93.540  -76.309  54.070  1
194424  93.558  -76.312  54.075  1
194425  93.577  -76.315  54.081  1
194426  93.595  -76.318  54.087  1
194427  93.613  -76.320  54.094  1
194428  93.632  -76.323  54.102  1
194429  93.650  -76.326  54.109  1
194430  93.669  -76.329  54.115  1
194431  93.687  -76.332  54.123  1
194432  93.705  -76.336  54.131  1
194433  93.723  -76.338  54.143  1
194434  93.742  -76.341  54.156  1
194435  93.755  -76.353  54.172  1
194436  93.766  -76.336  54.178  1
194437  93.785  -76.316  54.183  1
194438  93.805  -76.296  54.188  1
194439  93.825  -76.276  54.194  1
194440  93.842  -76.261  54.198  1
194441  93.861  -76.267  54.202  1
194442  93.880  -76.273  54.206  1
194443  93.899  -76.279  54.206  1
194444  93.918  -76.285  54.207  1
194445  93.937  -76.291  54.210  1
194446  93.956  -76.296  54.214  1
194447  93.975  -76.302  54.221  1
194448  93.994  -76.308  54.226  1
194449  94.011  -76.306  54.229  1
194450  94.031  -76.305  54.225  1
194451  94.051  -76.304  54.223  1
194452  94.070  -76.303  54.222  1
194453  94.090  -76.302  54.222  1
194454  94.110  -76.301  54.224  1
194455  94.130  -76.300  54.225  1
194456  94.150  -76.299  54.224  1
194457  94.170  -76.298  54.220  1
194458  94.190  -76.295  54.212  1
194459  94.213  -76.286  54.200  1
194460  94.236  -76.278  54.187  1
194461  94.259  -76.270  54.173  1
194462  94.281  -76.261  54.154  1
194463  94.301  -76.260  54.131  1
194464  94.321  -76.258  54.105  1
194465  94.340  -76.257  54.078  1
194466  94.358  -76.254  54.050  1
194467  94.376  -76.253  54.019  1
194468  94.394  -76.251  53.988  1
194469  94.412  -76.249  53.959  1
194470  94.431  -76.248  53.927  1
194471  94.449  -76.247  53.896  1
194472  94.466  -76.246  53.865  1
194473  94.479  -76.245  53.834  1
194474  94.493  -76.245  53.803  1
194475  94.506  -76.245  53.773  1
194476  94.520  -76.245  53.742  1
194477  94.533  -76.245  53.710  1
194478  94.546  -76.244  53.681  1
194479  94.560  -76.244  53.654  1
194480  94.572  -76.249  53.628  1
194481  94.584  -76.258  53.602  1
194482  94.596  -76.267  53.575  1
194483  94.608  -76.276  53.545  1
194484  94.624  -76.286  53.509  1
194485  94.645  -76.298  53.473  1
194486  94.665  -76.309  53.436  1
194487  94.676  -76.314  53.399  1
194488  94.687  -76.320  53.365  1
194489  94.698  -76.325  53.334  1
194490  94.709  -76.329  53.302  1
194491  94.720  -76.335  53.269  1
194492  94.732  -76.339  53.235  1
194493  94.745  -76.343  53.200  1
194494  94.757  -76.347  53.165  1
194495  94.770  -76.350  53.128  1
194496  94.782  -76.354  53.089  1
194497  94.795  -76.357  53.047  1
194498  94.808  -76.361  53.002  1
194499  94.820  -76.364  52.957  1
194500  94.833  -76.368  52.912  1
194501  94.845  -76.372  52.868  1
194502  94.858  -76.376  52.825  1
194503  94.871  -76.379  52.785  1
194504  94.883  -76.383  52.743  1
194505  94.895  -76.386  52.701  1
194506  94.908  -76.390  52.659  1
194507  94.920  -76.393  52.615  1
194508  94.933  -76.397  52.570  1
194509  94.946  -76.401  52.523  1
194510  94.952  -76.409  52.476  1
194511  94.967  -76.420  52.426  1
194512  94.991  -76.426  52.374  1
194513  95.016  -76.433  52.321  1
194514  95.041  -76.439  52.265  1
194515  95.065  -76.445  52.208  1
194516  95.095  -76.450  52.154  1
194517  95.144  -76.445  52.104  1
194518  95.193  -76.440  52.058  1
194519  95.243  -76.436  52.016  1
194520  95.290  -76.432  51.973  1
194521  95.314  -76.436  51.928  1
194522  95.336  -76.441  51.879  1
194523  95.359  -76.445  51.831  1
194524  95.383  -76.451  51.785  1
194525  95.406  -76.455  51.742  1
194526  95.429  -76.460  51.699  1
194527  95.452  -76.464  51.659  1
194528  95.475  -76.469  51.619  1
194529  95.498  -76.474  51.581  1
194530  95.521  -76.479  51.546  1
194531  95.544  -76.483  51.511  1
194532  95.567  -76.488  51.477  1
194533  95.591  -76.492  51.445  1
194534  95.614  -76.497  51.416  1
194535  95.635  -76.504  51.388  1
194536  95.655  -76.514  51.360  1
194537  95.677  -76.522  51.330  1
194538  95.704  -76.525  51.294  1
194539  95.727  -76.530  51.253  1
194540  95.751  -76.536  51.209  1
194541  95.775  -76.542  51.161  1
194542  95.799  -76.548  51.114  1
194543  95.823  -76.554  51.068  1
194544  95.847  -76.560  51.023  1
194545  95.872  -76.566  50.978  1
194546  95.896  -76.572  50.935  1
194547  95.919  -76.578  50.892  1
194548  95.944  -76.584  50.848  1
194549  95.967  -76.585  50.803  1
194550  95.990  -76.584  50.756  1
194551  96.011  -76.588  50.709  1
194552  96.032  -76.593  50.663  1
194553  96.052  -76.599  50.615  1
194554  96.073  -76.603  50.565  1
194555  96.093  -76.607  50.514  1
194556  96.113  -76.611  50.462  1
194557  96.133  -76.614  50.411  1
194558  96.154  -76.618  50.362  1
194559  96.174  -76.622  50.315  1
194560  96.194  -76.630  50.270  1
194561  96.214  -76.638  50.228  1
194562  96.234  -76.646  50.189  1
194563  96.254  -76.654  50.153  1
194564  96.274  -76.661  50.121  1
194565  96.294  -76.670  50.092  1
194566  96.314  -76.677  50.065  1
194567  96.334  -76.686  50.041  1
194568  96.354  -76.694  50.019  1
194569  96.373  -76.701  49.998  1
194570  96.392  -76.705  49.979  1
194571  96.395  -76.702  49.962  1
194572  96.378  -76.689  49.947  1
194573  96.361  -76.677  49.933  1
194574  96.343  -76.664  49.917  1
194575  96.326  -76.651  49.901  1
194576  96.316  -76.641  49.881  1
194577  96.330  -76.654  49.858  1
194578  96.383  -76.705  49.831  1
194579  96.436  -76.756  49.801  1
194580  96.487  -76.803  49.770  1
194581  96.524  -76.797  49.739  1
194582  96.561  -76.791  49.708  1
194583  96.599  -76.785  49.679  1
194584  96.637  -76.779  49.649  1
194585  96.674  -76.773  49.618  1
194586  96.712  -76.768  49.588  1
194587  96.744  -76.771  49.557  1
194588  96.770  -76.793  49.524  1
194589  96.797  -76.815  49.491  1
194590  96.824  -76.837  49.457  1
194591  96.851  -76.859  49.423  1
194592  96.878  -76.882  49.389  1
194593  96.895  -76.884  49.357  1
194594  96.910  -76.892  49.326  1
194595  96.923  -76.901  49.296  1
194596  96.936  -76.910  49.265  1
194597  96.950  -76.919  49.237  1
194598  96.963  -76.928  49.209  1
194599  96.976  -76.937  49.184  1
194600  96.990  -76.947  49.160  1
194601  97.003  -76.956  49.137  1
194602  97.016  -76.965  49.113  1
194603  97.029  -76.975  49.089  1
194604  97.044  -76.985  49.065  1
194605  97.077  -77.010  49.038  1
194606  97.109  -77.035  49.010  1
194607  97.141  -77.061  48.982  1
194608  97.164  -77.071  48.953  1
194609  97.183  -77.071  48.926  1
194610  97.223  -77.093  48.899  1
194611  97.264  -77.115  48.872  1
194612  97.305  -77.137  48.846  1
194613  97.345  -77.159  48.821  1
194614  97.377  -77.196  48.796  1
194615  97.409  -77.232  48.772  1
194616  97.436  -77.260  48.748  1
194617  97.445  -77.254  48.725  1
194618  97.454  -77.247  48.701  1
194619  97.464  -77.240  48.677  1
194620  97.473  -77.233  48.651  1
194621  97.482  -77.226  48.626  1
194622  97.491  -77.219  48.601  1
194623  97.500  -77.213  48.576  1
194624  97.507  -77.203  48.550  1
194625  97.507  -77.185  48.524  1
194626  97.511  -77.192  48.498  1
194627  97.515  -77.204  48.471  1
194628  97.537  -77.225  48.443  1
194629  97.534  -77.226  48.415  1
194630  97.561  -77.224  48.387  1
194631  97.588  -77.222  48.358  1
194632  97.615  -77.220  48.328  1
194633  97.642  -77.219  48.299  1
194634  97.669  -77.216  48.269  1
194635  97.696  -77.215  48.240  1
194636  97.723  -77.213  48.211  1
194637  97.750  -77.211  48.183  1
194638  97.777  -77.210  48.154  1
194639  97.804  -77.209  48.126  1
194640  97.830  -77.208  48.098  1
194641  97.858  -77.207  48.070  1
194642  97.885  -77.204  48.043  1
194643  97.910  -77.200  48.012  1
194644  97.935  -77.187  47.982  1
194645  97.961  -77.175  47.951  1
194646  97.987  -77.162  47.918  1
194647  98.012  -77.150  47.887  1
194648  98.037  -77.137  47.855  1
194649  98.063  -77.125  47.823  1
194650  98.088  -77.112  47.791  1
194651  98.114  -77.100  47.760  1
194652  98.140  -77.087  47.728  1
194653  98.165  -77.075  47.698  1
194654  98.191  -77.062  47.669  1
194655  98.216  -77.050  47.640  1
194656  98.242  -77.037  47.610  1
194657  98.267  -77.025  47.581  1
194658  98.293  -77.015  47.552  1
194659  98.317  -77.015  47.522  1
194660  98.342  -77.015  47.492  1
194661  98.353  -77.038  47.463  1
194662  98.357  -77.076  47.435  1
194663  98.366  -77.106  47.408  1
194664  98.385  -77.122  47.381  1
194665  98.416  -77.124  47.354  1
194666  98.432  -77.130  47.329  1
194667  98.442  -77.143  47.305  1
194668  98.458  -77.153  47.282  1
194669  98.474  -77.163  47.259  1
194670  98.489  -77.173  47.237  1
194671  98.507  -77.184  47.215  1
194672  98.539  -77.196  47.192  1
194673  98.572  -77.209  47.169  1
194674  98.605  -77.222  47.146  1
194675  98.638  -77.235  47.124  1
194676  98.670  -77.247  47.102  1
194677  98.703  -77.260  47.081  1
194678  98.744  -77.269  47.060  1
194679  98.774  -77.281  47.039  1
194680  98.788  -77.292  47.018  1
194681  98.803  -77.303  46.997  1
194682  98.817  -77.314  46.975  1
194683  98.835  -77.328  46.952  1
194684  98.852  -77.341  46.929  1
194685  98.869  -77.355  46.906  1
194686  98.886  -77.369  46.882  1
194687  98.903  -77.382  46.859  1
194688  98.916  -77.386  46.836  1
194689  98.926  -77.387  46.812  1
194690  98.937  -77.387  46.788  1
194691  98.948  -77.388  46.763  1
194692  98.959  -77.388  46.738  1
194693  98.970  -77.388  46.713  1
194694  98.981  -77.388  46.687  1
194695  99.002  -77.379  46.664  1
194696  99.023  -77.371  46.641  1
194697  99.042  -77.367  46.618  1
194698  99.053  -77.370  46.596  1
194699  99.063  -77.375  46.572  1
194700  99.074  -77.379  46.547  1
194701  99.085  -77.384  46.523  1
194702  99.096  -77.389  46.501  1
194703  99.107  -77.392  46.478  1
194704  99.118  -77.397  46.455  1
194705  99.129  -77.401  46.431  1
194706  99.142  -77.423  46.407  1
194707  99.156  -77.449  46.385  1
194708  99.169  -77.474  46.361  1
194709  99.167  -77.487  46.338  1
194710  99.165  -77.501  46.315  1
194711  99.163  -77.514  46.291  1
194712  99.162  -77.527  46.267  1
194713  99.167  -77.536  46.243  1
194714  99.190  -77.533  46.218  1
194715  99.212  -77.530  46.195  1
194716  99.234  -77.526  46.171  1
194717  99.256  -77.523  46.148  1
194718  99.278  -77.520  46.125  1
194719  99.300  -77.517  46.103  1
194720  99.323  -77.514  46.082  1
194721  99.345  -77.511  46.060  1
194722  99.369  -77.509  46.040  1
194723  99.409  -77.513  46.021  1
194724  99.449  -77.517  46.003  1
194725  99.489  -77.520  45.985  1
194726  99.528  -77.524  45.966  1
194727  99.568  -77.528  45.948  1
194728  99.608  -77.532  45.931  1
194729  99.648  -77.536  45.916  1
194730  99.688  -77.539  45.901  1
194731  99.728  -77.543  45.886  1
194732  99.768  -77.547  45.872  1
194733  99.809  -77.553  45.858  1
194734  99.854  -77.566  45.844  1
194735  99.874  -77.577  45.829  1
194736  99.887  -77.589  45.815  1
194737  99.901  -77.600  45.801  1
194738  99.914  -77.611  45.787  1
194739  99.927  -77.624  45.773  1
194740  99.940  -77.635  45.759  1
194741  99.953  -77.646  45.746  1
194742  99.966  -77.658  45.733  1
194743  99.979  -77.670  45.719  1
194744  99.993  -77.682  45.708  1
194745  100.006  -77.694  45.697  1
194746  100.019  -77.706  45.685  1
194747  100.044  -77.730  45.674  1
194748  100.068  -77.755  45.664  1
194749  100.092  -77.779  45.653  1
194750  100.121  -77.796  45.643  1
194751  100.151  -77.810  45.633  1
194752  100.174  -77.824  45.624  1
194753  100.193  -77.840  45.614  1
194754  100.213  -77.855  45.603  1
194755  100.232  -77.870  45.593  1
194756  100.252  -77.885  45.582  1
194757  100.271  -77.900  45.569  1
194758  100.290  -77.915  45.556  1
194759  100.310  -77.931  45.543  1
194760  100.329  -77.946  45.528  1
194761  100.348  -77.961  45.515  1
194762  100.367  -77.976  45.501  1
194763  100.387  -77.991  45.486  1
194764  100.409  -78.010  45.472  1
194765  100.434  -78.032  45.457  1
194766  100.451  -78.025  45.443  1
194767  100.469  -78.027  45.428  1
194768  100.486  -78.028  45.412  1
194769  100.504  -78.031  45.397  1
194770  100.522  -78.032  45.382  1
194771  100.540  -78.034  45.367  1
194772  100.558  -78.036  45.353  1
194773  100.578  -78.041  45.338  1
194774  100.601  -78.052  45.323  1
194775  100.624  -78.062  45.309  1
194776  100.647  -78.073  45.295  1
194777  100.671  -78.084  45.282  1
194778  100.694  -78.094  45.268  1
194779  100.722  -78.097  45.255  1
194780  100.759  -78.091  45.241  1
194781  100.791  -78.087  45.227  1
194782  100.815  -78.090  45.213  1
194783  100.838  -78.093  45.201  1
194784  100.876  -78.105  45.188  1
194785  100.916  -78.118  45.175  1
194786  100.955  -78.130  45.161  1
194787  100.994  -78.143  45.148  1
194788  101.033  -78.155  45.133  1
194789  101.072  -78.168  45.118  1
194790  101.111  -78.181  45.103  1
194791  101.150  -78.193  45.089  1
194792  101.189  -78.206  45.075  1
194793  101.229  -78.216  45.060  1
194794  101.261  -78.227  45.045  1
194795  101.275  -78.243  45.031  1
194796  101.292  -78.255  45.017  1
194797  101.309  -78.266  45.004  1
194798  101.326  -78.279  44.989  1
194799  101.342  -78.291  44.974  1
194800  101.359  -78.302  44.960  1
194801  101.376  -78.314  44.944  1
194802  101.393  -78.326  44.929  1
194803  101.410  -78.338  44.913  1
194804  101.426  -78.350  44.898  1
194805  101.444  -78.362  44.883  1
194806  101.463  -78.359  44.867  1
194807  101.478  -78.359  44.851  1
194808  101.513  -78.380  44.835  1
194809  101.547  -78.401  44.817  1
194810  101.574  -78.427  44.800  1
194811  101.601  -78.453  44.784  1
194812  101.630  -78.474  44.767  1
194813  101.659  -78.495  44.751  1
194814  101.689  -78.515  44.734  1
194815  101.718  -78.535  44.717  1
194816  101.748  -78.556  44.700  1
194817  101.777  -78.576  44.684  1
194818  101.807  -78.597  44.668  1
194819  101.837  -78.617  44.652  1
194820  101.882  -78.640  44.637  1
194821  101.927  -78.664  44.622  1
194822  101.973  -78.686  44.607  1
194823  102.018  -78.710  44.592  1
194824  102.061  -78.742  44.577  1
194825  102.104  -78.774  44.562  1
194826  102.147  -78.805  44.549  1
194827  102.190  -78.837  44.535  1
194828  102.234  -78.869  44.521  1
194829  102.254  -78.872  44.507  1
194830  102.273  -78.874  44.492  1
194831  102.293  -78.875  44.478  1
194832  102.312  -78.877  44.464  1
194833  102.332  -78.878  44.450  1
194834  102.351  -78.880  44.436  1
194835  102.371  -78.881  44.422  1
194836  102.390  -78.883  44.407  1
194837  102.409  -78.884  44.393  1
194838  102.429  -78.886  44.379  1
194839  102.449  -78.888  44.366  1
194840  102.468  -78.890  44.352  1
195123  93.513  -76.282  54.056  1
195124  93.532  -76.285  54.061  1
195125  93.550  -76.289  54.067  1
195126  93.568  -76.292  54.073  1
195127  93.587  -76.295  54.080  1
195128  93.605  -76.297  54.088  1
195129  93.624  -76.300  54.096  1
195130  93.642  -76.303  54.103  1
195131  93.660  -76.306  54.110  1
195132  93.679  -76.309  54.118  1
195133  93.697  -76.312  54.125  1
195134  93.715  -76.315  54.136  1
195135  93.733  -76.318  54.149  1
195136  93.747  -76.332  54.163  1
195137  93.755  -76.329  54.171  1
195138  93.763  -76.312  54.178  1
195139  93.782  -76.292  54.185  1
195140  93.802  -76.273  54.192  1
195141  93.830  -76.259  54.198  1
195142  93.865  -76.254  54.204  1
195143  93.884  -76.260  54.209  1
195144  93.902  -76.266  54.209  1
195145  93.920  -76.271  54.210  1
195146  93.938  -76.277  54.212  1
195147  93.957  -76.282  54.217  1
195148  93.975  -76.288  54.224  1
195149  93.993  -76.293  54.230  1
195150  94.004  -76.289  54.233  1
195151  94.023  -76.287  54.230  1
195152  94.042  -76.285  54.229  1
195153  94.061  -76.284  54.229  1
195154  94.079  -76.282  54.229  1
195155  94.099  -76.280  54.231  1
195156  94.117  -76.279  54.233  1
195157  94.137  -76.277  54.232  1
195158  94.166  -76.277  54.228  1
195159  94.193  -76.276  54.220  1
195160  94.214  -76.270  54.210  1
195161  94.236  -76.265  54.196  1
195162  94.258  -76.259  54.181  1
195163  94.280  -76.251  54.163  1
195164  94.302  -76.244  54.139  1
195165  94.322  -76.242  54.112  1
195166  94.340  -76.241  54.083  1
195167  94.358  -76.238  54.054  1
195168  94.376  -76.237  54.023  1
195169  94.394  -76.235  53.992  1
195170  94.412  -76.233  53.961  1
195171  94.431  -76.232  53.930  1
195172  94.447  -76.231  53.899  1
195173  94.460  -76.231  53.869  1
195174  94.473  -76.230  53.838  1
195175  94.487  -76.230  53.807  1
195176  94.500  -76.229  53.777  1
195177  94.513  -76.229  53.748  1
195178  94.527  -76.229  53.718  1
195179  94.540  -76.229  53.691  1
195180  94.554  -76.229  53.666  1
195181  94.566  -76.232  53.641  1
195182  94.578  -76.242  53.614  1
195183  94.591  -76.250  53.586  1
195184  94.604  -76.260  53.557  1
195185  94.625  -76.271  53.523  1
195186  94.646  -76.283  53.486  1
195187  94.666  -76.294  53.450  1
195188  94.677  -76.298  53.414  1
195189  94.688  -76.304  53.379  1
195190  94.699  -76.309  53.348  1
195191  94.710  -76.314  53.317  1
195192  94.721  -76.319  53.284  1
195193  94.732  -76.324  53.249  1
195194  94.744  -76.329  53.214  1
195195  94.756  -76.333  53.177  1
195196  94.768  -76.337  53.139  1
195197  94.780  -76.341  53.098  1
195198  94.793  -76.344  53.056  1
195199  94.806  -76.348  53.012  1
195200  94.818  -76.351  52.965  1
195201  94.831  -76.355  52.922  1
195202  94.843  -76.358  52.879  1
195203  94.856  -76.362  52.838  1
195204  94.868  -76.366  52.799  1
195205  94.881  -76.370  52.758  1
195206  94.894  -76.373  52.714  1
195207  94.906  -76.376  52.671  1
195208  94.919  -76.380  52.627  1
195209  94.931  -76.384  52.582  1
195210  94.944  -76.387  52.537  1
195211  94.951  -76.395  52.492  1
195212  94.956  -76.410  52.443  1
195213  94.981  -76.416  52.391  1
195214  95.006  -76.423  52.338  1
195215  95.031  -76.429  52.283  1
195216  95.055  -76.436  52.226  1
195217  95.091  -76.436  52.172  1
195218  95.140  -76.432  52.121  1
195219  95.190  -76.427  52.076  1
195220  95.240  -76.423  52.033  1
195221  95.289  -76.418  51.990  1
195222  95.318  -76.420  51.943  1
195223  95.341  -76.425  51.894  1
195224  95.364  -76.430  51.845  1
195225  95.387  -76.435  51.798  1
195226  95.410  -76.439  51.755  1
195227  95.433  -76.444  51.713  1
195228  95.456  -76.448  51.673  1
195229  95.479  -76.454  51.636  1
195230  95.502  -76.458  51.599  1
195231  95.525  -76.463  51.565  1
195232  95.548  -76.467  51.530  1
195233  95.571  -76.472  51.497  1
195234  95.595  -76.477  51.464  1
195235  95.618  -76.482  51.435  1
195236  95.641  -76.486  51.407  1
195237  95.664  -76.491  51.380  1
195238  95.687  -76.495  51.351  1
195239  95.711  -76.502  51.316  1
195240  95.735  -76.508  51.276  1
195241  95.759  -76.514  51.231  1
195242  95.783  -76.520  51.182  1
195243  95.808  -76.527  51.134  1
195244  95.832  -76.533  51.087  1
195245  95.856  -76.539  51.041  1
195246  95.880  -76.545  50.997  1
195247  95.904  -76.551  50.953  1
195248  95.928  -76.557  50.910  1
195249  95.953  -76.563  50.866  1
195250  95.975  -76.562  50.821  1
195251  95.999  -76.561  50.775  1
195252  96.020  -76.564  50.729  1
195253  96.041  -76.569  50.682  1
195254  96.061  -76.574  50.635  1
195255  96.082  -76.578  50.587  1
195256  96.102  -76.582  50.538  1
195257  96.122  -76.585  50.489  1
195258  96.142  -76.589  50.441  1
195259  96.155  -76.597  50.392  1
195260  96.172  -76.603  50.345  1
195261  96.194  -76.609  50.301  1
195262  96.216  -76.616  50.260  1
195263  96.236  -76.624  50.222  1
195264  96.256  -76.632  50.185  1
195265  96.276  -76.640  50.154  1
195266  96.296  -76.649  50.125  1
195267  96.316  -76.656  50.099  1
195268  96.336  -76.665  50.075  1
195269  96.356  -76.672  50.054  1
195270  96.374  -76.677  50.034  1
195271  96.393  -76.680  50.016  1
195272  96.411  -76.685  49.999  1
195273  96.398  -76.674  49.985  1
195274  96.381  -76.661  49.970  1
195275  96.364  -76.649  49.954  1
195276  96.361  -76.641  49.935  1
195277  96.369  -76.637  49.914  1
195278  96.379  -76.658  49.889  1
195279  96.432  -76.708  49.860  1
195280  96.483  -76.757  49.829  1
195281  96.528  -76.787  49.797  1
195282  96.566  -76.781  49.765  1
195283  96.603  -76.775  49.732  1
195284  96.641  -76.769  49.702  1
195285  96.678  -76.763  49.671  1
195286  96.710  -76.744  49.640  1
195287  96.737  -76.740  49.609  1
195288  96.764  -76.744  49.577  1
195289  96.792  -76.766  49.544  1
195290  96.818  -76.789  49.510  1
195291  96.845  -76.811  49.476  1
195292  96.872  -76.834  49.441  1
195293  96.895  -76.847  49.407  1
195294  96.912  -76.850  49.374  1
195295  96.930  -76.853  49.343  1
195296  96.943  -76.862  49.312  1
195297  96.957  -76.871  49.282  1
195298  96.970  -76.880  49.253  1
195299  96.983  -76.889  49.226  1
195300  96.997  -76.898  49.200  1
195301  97.010  -76.907  49.176  1
195302  97.023  -76.916  49.154  1
195303  97.036  -76.926  49.131  1
195304  97.052  -76.937  49.108  1
195305  97.084  -76.962  49.083  1
195306  97.116  -76.987  49.056  1
195307  97.149  -77.012  49.029  1
195308  97.181  -77.038  49.001  1
195309  97.204  -77.048  48.972  1
195310  97.218  -77.044  48.945  1
195311  97.253  -77.060  48.918  1
195312  97.294  -77.081  48.891  1
195313  97.333  -77.106  48.865  1
195314  97.365  -77.143  48.839  1
195315  97.397  -77.180  48.814  1
195316  97.429  -77.217  48.789  1
195317  97.461  -77.254  48.765  1
195318  97.474  -77.255  48.741  1
195319  97.483  -77.248  48.717  1
195320  97.492  -77.241  48.692  1
195321  97.501  -77.235  48.665  1
195322  97.510  -77.228  48.639  1
195323  97.519  -77.220  48.613  1
195324  97.519  -77.202  48.588  1
195325  97.519  -77.184  48.562  1
195326  97.520  -77.166  48.535  1
195327  97.524  -77.175  48.508  1
195328  97.528  -77.188  48.481  1
195329  97.533  -77.201  48.452  1
195330  97.550  -77.207  48.424  1
195331  97.575  -77.209  48.396  1
195332  97.602  -77.208  48.366  1
195333  97.629  -77.207  48.337  1
195334  97.656  -77.206  48.308  1
195335  97.682  -77.204  48.278  1
195336  97.710  -77.204  48.248  1
195337  97.736  -77.202  48.220  1
195338  97.764  -77.201  48.191  1
195339  97.790  -77.200  48.163  1
195340  97.817  -77.199  48.136  1
195341  97.844  -77.197  48.108  1
195342  97.873  -77.192  48.081  1
195343  97.903  -77.182  48.053  1
195344  97.925  -77.185  48.023  1
195345  97.947  -77.185  47.992  1
195346  97.972  -77.173  47.961  1
195347  97.998  -77.160  47.931  1
195348  98.023  -77.148  47.899  1
195349  98.049  -77.135  47.868  1
195350  98.074  -77.123  47.836  1
195351  98.100  -77.110  47.805  1
195352  98.125  -77.098  47.772  1
195353  98.151  -77.085  47.740  1
195354  98.176  -77.073  47.709  1
195355  98.202  -77.060  47.679  1
195356  98.227  -77.048  47.650  1
195357  98.253  -77.035  47.620  1
195358  98.279  -77.023  47.589  1
195359  98.303  -77.019  47.559  1
195360  98.327  -77.019  47.529  1
195361  98.352  -77.019  47.499  1
195362  98.377  -77.019  47.468  1
195363  98.393  -77.034  47.442  1
195364  98.397  -77.071  47.415  1
195365  98.401  -77.109  47.388  1
195366  98.438  -77.101  47.361  1
195367  98.450  -77.109  47.337  1
195368  98.442  -77.131  47.314  1
195369  98.458  -77.141  47.291  1
195370  98.474  -77.151  47.267  1
195371  98.489  -77.162  47.245  1
195372  98.505  -77.172  47.223  1
195373  98.538  -77.185  47.200  1
195374  98.571  -77.197  47.176  1
195375  98.603  -77.210  47.154  1
195376  98.637  -77.222  47.132  1
195377  98.669  -77.235  47.109  1
195378  98.708  -77.246  47.088  1
195379  98.758  -77.253  47.067  1
195380  98.786  -77.264  47.046  1
195381  98.799  -77.278  47.025  1
195382  98.814  -77.289  47.004  1
195383  98.829  -77.300  46.982  1
195384  98.843  -77.311  46.959  1
195385  98.858  -77.322  46.937  1
195386  98.872  -77.333  46.913  1
195387  98.889  -77.346  46.889  1
195388  98.907  -77.360  46.865  1
195389  98.923  -77.373  46.842  1
195390  98.940  -77.387  46.818  1
195391  98.952  -77.388  46.793  1
195392  98.962  -77.389  46.767  1
195393  98.974  -77.389  46.742  1
195394  98.984  -77.389  46.716  1
195395  98.995  -77.389  46.692  1
195396  99.016  -77.381  46.668  1
195397  99.038  -77.372  46.645  1
195398  99.049  -77.376  46.622  1
195399  99.060  -77.381  46.599  1
195400  99.070  -77.385  46.575  1
195401  99.081  -77.389  46.550  1
195402  99.092  -77.394  46.526  1
195403  99.103  -77.398  46.503  1
195404  99.114  -77.403  46.480  1
195405  99.125  -77.407  46.457  1
195406  99.136  -77.411  46.433  1
195407  99.147  -77.416  46.410  1
195408  99.160  -77.432  46.387  1
195409  99.174  -77.458  46.364  1
195410  99.181  -77.479  46.341  1
195411  99.179  -77.492  46.317  1
195412  99.178  -77.505  46.293  1
195413  99.175  -77.519  46.269  1
195414  99.190  -77.521  46.245  1
195415  99.212  -77.518  46.219  1
195416  99.234  -77.515  46.196  1
195417  99.257  -77.512  46.173  1
195418  99.279  -77.509  46.150  1
195419  99.301  -77.506  46.126  1
195420  99.323  -77.503  46.104  1
195421  99.345  -77.500  46.083  1
195422  99.367  -77.497  46.063  1
195423  99.390  -77.494  46.043  1
195424  99.414  -77.492  46.024  1
195425  99.454  -77.495  46.004  1
195426  99.494  -77.499  45.985  1
195427  99.534  -77.503  45.967  1
195428  99.574  -77.507  45.949  1
195429  99.614  -77.511  45.933  1
195430  99.653  -77.514  45.918  1
195431  99.693  -77.518  45.903  1
195432  99.733  -77.522  45.888  1
195433  99.773  -77.526  45.873  1
195434  99.817  -77.538  45.859  1
195435  99.862  -77.550  45.844  1
195436  99.896  -77.563  45.830  1
195437  99.909  -77.574  45.816  1
195438  99.922  -77.586  45.801  1
195439  99.935  -77.597  45.787  1
195440  99.948  -77.608  45.774  1
195441  99.962  -77.620  45.759  1
195442  99.975  -77.631  45.747  1
195443  99.988  -77.642  45.734  1
195444  100.001  -77.655  45.721  1
195445  100.014  -77.666  45.710  1
195446  100.027  -77.677  45.698  1
195447  100.040  -77.689  45.687  1
195448  100.059  -77.705  45.676  1
195449  100.083  -77.729  45.665  1
195450  100.108  -77.753  45.654  1
195451  100.135  -77.773  45.643  1
195452  100.165  -77.787  45.633  1
195453  100.196  -77.799  45.623  1
195454  100.218  -77.815  45.613  1
195455  100.238  -77.830  45.602  1
195456  100.257  -77.845  45.591  1
195457  100.277  -77.860  45.580  1
195458  100.296  -77.875  45.568  1
195459  100.316  -77.890  45.554  1
195460  100.335  -77.906  45.540  1
195461  100.354  -77.921  45.526  1
195462  100.373  -77.936  45.512  1
195463  100.393  -77.951  45.497  1
195464  100.417  -77.973  45.482  1
195465  100.442  -77.995  45.467  1
195466  100.465  -78.007  45.453  1
195467  100.481  -77.996  45.439  1
195468  100.498  -77.998  45.424  1
195469  100.516  -78.000  45.409  1
195470  100.534  -78.002  45.394  1
195471  100.552  -78.003  45.380  1
195472  100.570  -78.006  45.365  1
195473  100.590  -78.011  45.351  1
195474  100.613  -78.022  45.336  1
195475  100.636  -78.032  45.321  1
195476  100.659  -78.043  45.306  1
195477  100.683  -78.053  45.293  1
195478  100.705  -78.064  45.280  1
195479  100.728  -78.074  45.265  1
195480  100.752  -78.084  45.252  1
195481  100.785  -78.082  45.238  1
195482  100.820  -78.077  45.225  1
195483  100.844  -78.079  45.212  1
195484  100.867  -78.082  45.200  1
195485  100.897  -78.088  45.187  1
195486  100.935  -78.101  45.174  1
195487  100.975  -78.113  45.161  1
195488  101.013  -78.126  45.147  1
195489  101.053  -78.138  45.133  1
195490  101.092  -78.151  45.117  1
195491  101.131  -78.164  45.103  1
195492  101.170  -78.176  45.088  1
195493  101.209  -78.189  45.074  1
195494  101.247  -78.203  45.059  1
195495  101.279  -78.218  45.044  1
195496  101.296  -78.228  45.030  1
195497  101.313  -78.240  45.016  1
195498  101.330  -78.250  45.002  1
195499  101.346  -78.261  44.988  1
195500  101.363  -78.272  44.973  1
195501  101.380  -78.285  44.959  1
195502  101.397  -78.297  44.943  1
195503  101.414  -78.308  44.927  1
195504  101.431  -78.320  44.911  1
195505  101.448  -78.332  44.896  1
195506  101.465  -78.344  44.881  1
195507  101.481  -78.356  44.865  1
195508  101.504  -78.357  44.849  1
195509  101.529  -78.367  44.833  1
195510  101.559  -78.391  44.816  1
195511  101.588  -78.414  44.800  1
195512  101.617  -78.435  44.783  1
195513  101.647  -78.455  44.766  1
195514  101.676  -78.476  44.750  1
195515  101.706  -78.496  44.733  1
195516  101.735  -78.517  44.717  1
195517  101.765  -78.537  44.700  1
195518  101.794  -78.557  44.684  1
195519  101.824  -78.578  44.669  1
195520  101.853  -78.598  44.654  1
195521  101.899  -78.622  44.638  1
195522  101.944  -78.645  44.623  1
195523  101.989  -78.668  44.608  1
195524  102.035  -78.691  44.592  1
195525  102.080  -78.716  44.577  1
195526  102.123  -78.748  44.563  1
195527  102.166  -78.780  44.549  1
195528  102.209  -78.811  44.535  1
195529  102.252  -78.843  44.521  1
195530  102.279  -78.855  44.507  1
195531  102.299  -78.856  44.492  1
195532  102.318  -78.858  44.478  1
195533  102.337  -78.859  44.463  1
195534  102.357  -78.861  44.448  1
195535  102.376  -78.862  44.435  1
195536  102.396  -78.864  44.421  1
195537  102.415  -78.865  44.407  1
195538  102.435  -78.867  44.392  1
195539  102.454  -78.869  44.378  1
195540  102.473  -78.871  44.364  1
195541  102.493  -78.872  44.349  1
195542  102.513  -78.874  44.335  1
195825  93.524  -76.262  54.053  1
195826  93.542  -76.265  54.059  1
195827  93.560  -76.268  54.066  1
195828  93.579  -76.271  54.073  1
195829  93.597  -76.274  54.082  1
195830  93.616  -76.276  54.091  1
195831  93.634  -76.279  54.098  1
195832  93.652  -76.282  54.105  1
195833  93.671  -76.285  54.113  1
195834  93.689  -76.289  54.121  1
195835  93.707  -76.292  54.132  1
195836  93.725  -76.295  54.144  1
195837  93.739  -76.307  54.157  1
195838  93.745  -76.323  54.165  1
195839  93.754  -76.305  54.173  1
195840  93.763  -76.289  54.181  1
195841  93.779  -76.270  54.189  1
195842  93.815  -76.260  54.196  1
195843  93.854  -76.254  54.203  1
195844  93.890  -76.249  54.207  1
195845  93.908  -76.254  54.209  1
195846  93.926  -76.260  54.210  1
195847  93.945  -76.266  54.213  1
195848  93.963  -76.271  54.219  1
195849  93.981  -76.276  54.226  1
195850  93.985  -76.270  54.232  1
195851  93.989  -76.264  54.237  1
195852  94.005  -76.262  54.237  1
195853  94.024  -76.260  54.237  1
195854  94.043  -76.258  54.236  1
195855  94.062  -76.257  54.236  1
195856  94.083  -76.255  54.239  1
195857  94.112  -76.256  54.242  1
195858  94.141  -76.256  54.241  1
195859  94.170  -76.256  54.236  1
195860  94.196  -76.254  54.229  1
195861  94.217  -76.249  54.219  1
195862  94.239  -76.244  54.206  1
195863  94.261  -76.238  54.189  1
195864  94.282  -76.233  54.171  1
195865  94.303  -76.228  54.146  1
195866  94.322  -76.226  54.117  1
195867  94.340  -76.223  54.087  1
195868  94.358  -76.222  54.056  1
195869  94.377  -76.220  54.025  1
195870  94.395  -76.218  53.994  1
195871  94.413  -76.216  53.963  1
195872  94.429  -76.215  53.932  1
195873  94.441  -76.216  53.900  1
195874  94.454  -76.216  53.870  1
195875  94.468  -76.215  53.839  1
195876  94.481  -76.215  53.809  1
195877  94.494  -76.215  53.780  1
195878  94.507  -76.214  53.753  1
195879  94.521  -76.214  53.724  1
195880  94.535  -76.213  53.699  1
195881  94.548  -76.213  53.675  1
195882  94.561  -76.215  53.651  1
195883  94.573  -76.224  53.625  1
195884  94.585  -76.233  53.597  1
195885  94.606  -76.245  53.566  1
195886  94.627  -76.257  53.533  1
195887  94.648  -76.268  53.496  1
195888  94.666  -76.278  53.460  1
195889  94.677  -76.283  53.424  1
195890  94.688  -76.288  53.390  1
195891  94.699  -76.293  53.359  1
195892  94.710  -76.298  53.327  1
195893  94.721  -76.304  53.294  1
195894  94.733  -76.308  53.257  1
195895  94.744  -76.314  53.220  1
195896  94.755  -76.319  53.183  1
195897  94.766  -76.323  53.145  1
195898  94.779  -76.327  53.104  1
195899  94.791  -76.331  53.061  1
195900  94.804  -76.335  53.017  1
195901  94.817  -76.338  52.974  1
195902  94.829  -76.342  52.933  1
195903  94.841  -76.345  52.893  1
195904  94.854  -76.349  52.853  1
195905  94.866  -76.352  52.813  1
195906  94.879  -76.356  52.772  1
195907  94.892  -76.360  52.729  1
195908  94.904  -76.364  52.685  1
195909  94.917  -76.367  52.640  1
195910  94.929  -76.370  52.596  1
195911  94.942  -76.374  52.551  1
195912  94.950  -76.381  52.506  1
195913  94.946  -76.399  52.457  1
195914  94.971  -76.406  52.405  1
195915  94.995  -76.412  52.352  1
195916  95.020  -76.419  52.297  1
195917  95.045  -76.425  52.242  1
195918  95.088  -76.423  52.189  1
195919  95.137  -76.419  52.138  1
195920  95.187  -76.414  52.092  1
195921  95.236  -76.410  52.050  1
195922  95.285  -76.404  52.005  1
195923  95.322  -76.405  51.959  1
195924  95.345  -76.410  51.909  1
195925  95.368  -76.414  51.860  1
195926  95.391  -76.419  51.813  1
195927  95.414  -76.423  51.769  1
195928  95.437  -76.428  51.729  1
195929  95.460  -76.433  51.691  1
195930  95.483  -76.438  51.654  1
195931  95.507  -76.442  51.619  1
195932  95.529  -76.447  51.586  1
195933  95.552  -76.451  51.552  1
195934  95.576  -76.457  51.517  1
195935  95.599  -76.461  51.482  1
195936  95.622  -76.466  51.452  1
195937  95.645  -76.470  51.424  1
195938  95.668  -76.475  51.397  1
195939  95.693  -76.477  51.369  1
195940  95.720  -76.493  51.333  1
195941  95.744  -76.492  51.293  1
195942  95.768  -76.493  51.249  1
195943  95.792  -76.499  51.201  1
195944  95.816  -76.505  51.152  1
195945  95.840  -76.511  51.104  1
195946  95.865  -76.517  51.057  1
195947  95.889  -76.524  51.013  1
195948  95.913  -76.530  50.970  1
195949  95.937  -76.536  50.927  1
195950  95.961  -76.541  50.884  1
195951  95.984  -76.540  50.840  1
195952  96.007  -76.539  50.795  1
195953  96.029  -76.539  50.749  1
195954  96.050  -76.544  50.702  1
195955  96.071  -76.549  50.656  1
195956  96.091  -76.552  50.609  1
195957  96.110  -76.557  50.562  1
195958  96.122  -76.564  50.517  1
195959  96.135  -76.571  50.470  1
195960  96.148  -76.579  50.423  1
195961  96.171  -76.585  50.376  1
195962  96.193  -76.591  50.332  1
195963  96.215  -76.597  50.291  1
195964  96.238  -76.603  50.253  1
195965  96.258  -76.611  50.218  1
195966  96.278  -76.619  50.186  1
195967  96.298  -76.627  50.158  1
195968  96.318  -76.635  50.133  1
195969  96.337  -76.643  50.110  1
195970  96.357  -76.649  50.088  1
195971  96.375  -76.653  50.069  1
195972  96.394  -76.657  50.052  1
195973  96.412  -76.661  50.036  1
195974  96.419  -76.659  50.022  1
195975  96.402  -76.647  50.006  1
195976  96.404  -76.641  49.988  1
195977  96.413  -76.636  49.967  1
195978  96.422  -76.633  49.944  1
195979  96.432  -76.660  49.917  1
195980  96.480  -76.711  49.887  1
195981  96.525  -76.742  49.855  1
195982  96.570  -76.771  49.823  1
195983  96.607  -76.765  49.789  1
195984  96.645  -76.759  49.755  1
195985  96.676  -76.730  49.723  1
195986  96.703  -76.723  49.691  1
195987  96.731  -76.719  49.660  1
195988  96.758  -76.715  49.629  1
195989  96.786  -76.718  49.597  1
195990  96.812  -76.740  49.563  1
195991  96.839  -76.762  49.528  1
195992  96.866  -76.784  49.494  1
195993  96.893  -76.807  49.458  1
195994  96.912  -76.813  49.424  1
195995  96.930  -76.815  49.391  1
195996  96.947  -76.818  49.359  1
195997  96.964  -76.822  49.328  1
195998  96.977  -76.831  49.297  1
195999  96.990  -76.840  49.269  1
196000  97.004  -76.850  49.241  1
196001  97.017  -76.859  49.216  1
196002  97.030  -76.868  49.192  1
196003  97.043  -76.877  49.170  1
196004  97.060  -76.889  49.149  1
196005  97.092  -76.914  49.126  1
196006  97.124  -76.939  49.101  1
196007  97.156  -76.965  49.075  1
196008  97.188  -76.990  49.048  1
196009  97.203  -77.011  49.020  1
196010  97.223  -77.024  48.991  1
196011  97.258  -77.021  48.964  1
196012  97.283  -77.027  48.936  1
196013  97.321  -77.053  48.910  1
196014  97.353  -77.091  48.885  1
196015  97.385  -77.128  48.858  1
196016  97.417  -77.165  48.832  1
196017  97.449  -77.202  48.806  1
196018  97.480  -77.239  48.782  1
196019  97.502  -77.256  48.758  1
196020  97.511  -77.250  48.733  1
196021  97.520  -77.243  48.707  1
196022  97.530  -77.236  48.680  1
196023  97.531  -77.219  48.653  1
196024  97.532  -77.201  48.627  1
196025  97.532  -77.183  48.601  1
196026  97.532  -77.165  48.574  1
196027  97.533  -77.147  48.547  1
196028  97.537  -77.159  48.520  1
196029  97.542  -77.172  48.492  1
196030  97.548  -77.183  48.462  1
196031  97.571  -77.188  48.434  1
196032  97.593  -77.193  48.406  1
196033  97.615  -77.197  48.377  1
196034  97.642  -77.197  48.347  1
196035  97.669  -77.195  48.318  1
196036  97.696  -77.194  48.288  1
196037  97.723  -77.193  48.259  1
196038  97.749  -77.192  48.229  1
196039  97.777  -77.191  48.201  1
196040  97.803  -77.190  48.174  1
196041  97.830  -77.188  48.147  1
196042  97.860  -77.180  48.120  1
196043  97.891  -77.170  48.092  1
196044  97.921  -77.160  48.063  1
196045  97.942  -77.164  48.032  1
196046  97.962  -77.169  48.001  1
196047  97.984  -77.171  47.971  1
196048  98.009  -77.159  47.942  1
196049  98.034  -77.146  47.911  1
196050  98.060  -77.134  47.879  1
196051  98.085  -77.121  47.847  1
196052  98.111  -77.109  47.814  1
196053  98.137  -77.096  47.782  1
196054  98.162  -77.084  47.750  1
196055  98.187  -77.071  47.718  1
196056  98.213  -77.059  47.688  1
196057  98.239  -77.046  47.659  1
196058  98.264  -77.034  47.628  1
196059  98.290  -77.024  47.598  1
196060  98.314  -77.023  47.568  1
196061  98.339  -77.023  47.538  1
196062  98.363  -77.023  47.508  1
196063  98.387  -77.023  47.478  1
196064  98.412  -77.023  47.450  1
196065  98.433  -77.028  47.423  1
196066  98.437  -77.066  47.396  1
196067  98.459  -77.078  47.370  1
196068  98.468  -77.088  47.346  1
196069  98.460  -77.111  47.323  1
196070  98.458  -77.130  47.300  1
196071  98.474  -77.140  47.277  1
196072  98.489  -77.150  47.255  1
196073  98.505  -77.160  47.233  1
196074  98.537  -77.173  47.210  1
196075  98.570  -77.185  47.186  1
196076  98.602  -77.198  47.164  1
196077  98.635  -77.211  47.141  1
196078  98.671  -77.222  47.118  1
196079  98.721  -77.229  47.096  1
196080  98.771  -77.237  47.074  1
196081  98.797  -77.248  47.053  1
196082  98.811  -77.262  47.031  1
196083  98.826  -77.275  47.010  1
196084  98.840  -77.285  46.988  1
196085  98.855  -77.297  46.966  1
196086  98.869  -77.307  46.944  1
196087  98.884  -77.319  46.920  1
196088  98.899  -77.329  46.896  1
196089  98.913  -77.341  46.872  1
196090  98.928  -77.351  46.848  1
196091  98.944  -77.364  46.823  1
196092  98.961  -77.378  46.797  1
196093  98.977  -77.389  46.771  1
196094  98.988  -77.389  46.745  1
196095  98.999  -77.389  46.720  1
196096  99.009  -77.390  46.695  1
196097  99.030  -77.382  46.672  1
196098  99.045  -77.382  46.649  1
196099  99.056  -77.386  46.626  1
196100  99.067  -77.391  46.602  1
196101  99.078  -77.395  46.578  1
196102  99.088  -77.399  46.553  1
196103  99.099  -77.404  46.529  1
196104  99.111  -77.408  46.505  1
196105  99.122  -77.413  46.483  1
196106  99.132  -77.417  46.459  1
196107  99.143  -77.421  46.435  1
196108  99.154  -77.426  46.411  1
196109  99.165  -77.430  46.388  1
196110  99.177  -77.442  46.365  1
196111  99.191  -77.467  46.343  1
196112  99.193  -77.484  46.319  1
196113  99.191  -77.497  46.294  1
196114  99.191  -77.510  46.270  1
196115  99.213  -77.507  46.246  1
196116  99.235  -77.504  46.219  1
196117  99.257  -77.501  46.197  1
196118  99.279  -77.498  46.173  1
196119  99.301  -77.495  46.150  1
196120  99.324  -77.492  46.127  1
196121  99.346  -77.489  46.106  1
196122  99.368  -77.486  46.085  1
196123  99.390  -77.483  46.064  1
196124  99.412  -77.479  46.046  1
196125  99.434  -77.476  46.026  1
196126  99.459  -77.474  46.007  1
196127  99.499  -77.478  45.988  1
196128  99.539  -77.482  45.969  1
196129  99.579  -77.486  45.951  1
196130  99.619  -77.489  45.935  1
196131  99.658  -77.493  45.919  1
196132  99.698  -77.497  45.904  1
196133  99.738  -77.501  45.889  1
196134  99.781  -77.510  45.874  1
196135  99.826  -77.522  45.859  1
196136  99.870  -77.535  45.844  1
196137  99.915  -77.548  45.830  1
196138  99.931  -77.559  45.816  1
196139  99.944  -77.570  45.801  1
196140  99.957  -77.582  45.788  1
196141  99.970  -77.594  45.775  1
196142  99.983  -77.605  45.761  1
196143  99.996  -77.617  45.749  1
196144  100.009  -77.628  45.736  1
196145  100.022  -77.639  45.723  1
196146  100.036  -77.651  45.711  1
196147  100.049  -77.662  45.700  1
196148  100.063  -77.674  45.688  1
196149  100.078  -77.685  45.677  1
196150  100.098  -77.703  45.666  1
196151  100.123  -77.727  45.654  1
196152  100.148  -77.749  45.643  1
196153  100.179  -77.763  45.632  1
196154  100.210  -77.776  45.621  1
196155  100.240  -77.790  45.611  1
196156  100.263  -77.804  45.601  1
196157  100.283  -77.819  45.590  1
196158  100.302  -77.834  45.578  1
196159  100.321  -77.849  45.565  1
196160  100.341  -77.865  45.551  1
196161  100.360  -77.880  45.537  1
196162  100.379  -77.895  45.523  1
196163  100.401  -77.913  45.509  1
196164  100.426  -77.935  45.493  1
196165  100.451  -77.957  45.477  1
196166  100.475  -77.979  45.463  1
196167  100.495  -77.980  45.449  1
196168  100.510  -77.968  45.435  1
196169  100.528  -77.969  45.420  1
196170  100.546  -77.971  45.405  1
196171  100.564  -77.973  45.391  1
196172  100.582  -77.975  45.377  1
196173  100.602  -77.981  45.362  1
196174  100.625  -77.990  45.347  1
196175  100.648  -78.001  45.333  1
196176  100.671  -78.012  45.318  1
196177  100.694  -78.022  45.303  1
196178  100.717  -78.033  45.290  1
196179  100.741  -78.044  45.277  1
196180  100.764  -78.054  45.263  1
196181  100.787  -78.065  45.249  1
196182  100.811  -78.074  45.236  1
196183  100.847  -78.067  45.224  1
196184  100.873  -78.069  45.211  1
196185  100.896  -78.072  45.198  1
196186  100.920  -78.074  45.186  1
196187  100.955  -78.084  45.174  1
196188  100.994  -78.097  45.160  1
196189  101.034  -78.109  45.146  1
196190  101.072  -78.122  45.132  1
196191  101.112  -78.134  45.116  1
196192  101.150  -78.147  45.102  1
196193  101.190  -78.159  45.087  1
196194  101.227  -78.176  45.072  1
196195  101.263  -78.193  45.057  1
196196  101.299  -78.210  45.043  1
196197  101.316  -78.220  45.029  1
196198  101.333  -78.231  45.014  1
196199  101.350  -78.242  45.000  1
196200  101.367  -78.253  44.985  1
196201  101.384  -78.263  44.971  1
196202  101.401  -78.275  44.956  1
196203  101.418  -78.285  44.941  1
196204  101.434  -78.297  44.925  1
196205  101.452  -78.307  44.909  1
196206  101.468  -78.318  44.894  1
196207  101.485  -78.329  44.879  1
196208  101.502  -78.340  44.863  1
196209  101.519  -78.351  44.847  1
196210  101.543  -78.357  44.832  1
196211  101.575  -78.375  44.815  1
196212  101.605  -78.395  44.798  1
196213  101.634  -78.416  44.781  1
196214  101.664  -78.436  44.765  1
196215  101.693  -78.457  44.749  1
196216  101.723  -78.477  44.733  1
196217  101.752  -78.498  44.717  1
196218  101.781  -78.519  44.700  1
196219  101.811  -78.539  44.684  1
196220  101.840  -78.560  44.669  1
196221  101.870  -78.580  44.655  1
196222  101.915  -78.603  44.640  1
196223  101.961  -78.626  44.624  1
196224  102.006  -78.649  44.609  1
196225  102.051  -78.672  44.592  1
196226  102.097  -78.695  44.578  1
196227  102.141  -78.721  44.563  1
196228  102.184  -78.753  44.549  1
196229  102.228  -78.786  44.535  1
196230  102.270  -78.818  44.520  1
196231  102.304  -78.837  44.505  1
196232  102.324  -78.839  44.490  1
196233  102.343  -78.840  44.475  1
196234  102.363  -78.842  44.461  1
196235  102.382  -78.843  44.447  1
196236  102.401  -78.845  44.433  1
196237  102.421  -78.846  44.419  1
196238  102.441  -78.848  44.405  1
196239  102.460  -78.850  44.390  1
196240  102.479  -78.852  44.377  1
196241  102.499  -78.853  44.362  1
196242  102.518  -78.855  44.348  1
196243  102.538  -78.856  44.333  1
196527  93.534  -76.242  54.051  1
196528  93.552  -76.245  54.058  1
196529  93.571  -76.248  54.066  1
196530  93.589  -76.251  54.075  1
196531  93.608  -76.253  54.085  1
196532  93.626  -76.256  54.093  1
196533  93.644  -76.259  54.100  1
196534  93.662  -76.262  54.108  1
196535  93.681  -76.265  54.117  1
196536  93.699  -76.268  54.128  1
196537  93.717  -76.271  54.139  1
196538  93.731  -76.283  54.152  1
196539  93.735  -76.316  54.160  1
196540  93.745  -76.299  54.168  1
196541  93.754  -76.282  54.177  1
196542  93.768  -76.267  54.185  1
196543  93.801  -76.261  54.193  1
196544  93.839  -76.254  54.200  1
196545  93.879  -76.248  54.206  1
196546  93.914  -76.244  54.209  1
196547  93.933  -76.249  54.212  1
196548  93.951  -76.254  54.217  1
196549  93.969  -76.260  54.223  1
196550  93.973  -76.254  54.230  1
196551  93.978  -76.248  54.238  1
196552  93.982  -76.242  54.245  1
196553  93.988  -76.236  54.247  1
196554  94.006  -76.235  54.247  1
196555  94.029  -76.234  54.246  1
196556  94.058  -76.234  54.246  1
196557  94.087  -76.235  54.248  1
196558  94.116  -76.235  54.249  1
196559  94.145  -76.235  54.249  1
196560  94.174  -76.235  54.246  1
196561  94.199  -76.232  54.238  1
196562  94.221  -76.227  54.226  1
196563  94.243  -76.222  54.212  1
196564  94.264  -76.216  54.196  1
196565  94.285  -76.211  54.176  1
196566  94.305  -76.208  54.150  1
196567  94.323  -76.205  54.120  1
196568  94.341  -76.204  54.088  1
196569  94.359  -76.201  54.057  1
196570  94.377  -76.200  54.025  1
196571  94.395  -76.198  53.993  1
196572  94.413  -76.196  53.964  1
196573  94.430  -76.195  53.932  1
196574  94.442  -76.195  53.900  1
196575  94.454  -76.196  53.869  1
196576  94.465  -76.198  53.839  1
196577  94.477  -76.198  53.810  1
196578  94.488  -76.199  53.782  1
196579  94.502  -76.199  53.756  1
196580  94.515  -76.199  53.729  1
196581  94.529  -76.198  53.705  1
196582  94.542  -76.198  53.682  1
196583  94.555  -76.198  53.660  1
196584  94.567  -76.207  53.635  1
196585  94.586  -76.218  53.606  1
196586  94.607  -76.229  53.574  1
196587  94.628  -76.242  53.540  1
196588  94.649  -76.253  53.503  1
196589  94.667  -76.262  53.468  1
196590  94.678  -76.267  53.433  1
196591  94.689  -76.273  53.400  1
196592  94.700  -76.278  53.369  1
196593  94.711  -76.282  53.336  1
196594  94.722  -76.288  53.302  1
196595  94.733  -76.293  53.264  1
196596  94.745  -76.298  53.226  1
196597  94.756  -76.303  53.188  1
196598  94.767  -76.308  53.149  1
196599  94.778  -76.314  53.109  1
196600  94.789  -76.317  53.067  1
196601  94.802  -76.321  53.024  1
196602  94.815  -76.325  52.983  1
196603  94.827  -76.329  52.944  1
196604  94.840  -76.332  52.904  1
196605  94.852  -76.336  52.865  1
196606  94.865  -76.339  52.825  1
196607  94.878  -76.343  52.783  1
196608  94.890  -76.346  52.739  1
196609  94.903  -76.350  52.695  1
196610  94.915  -76.354  52.649  1
196611  94.927  -76.357  52.604  1
196612  94.940  -76.361  52.560  1
196613  94.950  -76.367  52.516  1
196614  94.936  -76.389  52.467  1
196615  94.961  -76.396  52.416  1
196616  94.985  -76.402  52.363  1
196617  95.010  -76.409  52.309  1
196618  95.035  -76.415  52.257  1
196619  95.085  -76.411  52.206  1
196620  95.134  -76.406  52.155  1
196621  95.183  -76.401  52.108  1
196622  95.233  -76.396  52.065  1
196623  95.282  -76.392  52.021  1
196624  95.326  -76.389  51.975  1
196625  95.349  -76.394  51.926  1
196626  95.372  -76.398  51.877  1
196627  95.395  -76.403  51.831  1
196628  95.418  -76.408  51.788  1
196629  95.441  -76.413  51.747  1
196630  95.464  -76.417  51.708  1
196631  95.487  -76.422  51.672  1
196632  95.511  -76.426  51.640  1
196633  95.533  -76.431  51.608  1
196634  95.556  -76.436  51.573  1
196635  95.580  -76.441  51.538  1
196636  95.603  -76.445  51.502  1
196637  95.626  -76.450  51.471  1
196638  95.649  -76.455  51.440  1
196639  95.674  -76.458  51.410  1
196640  95.699  -76.459  51.380  1
196641  95.730  -76.492  51.344  1
196642  95.754  -76.490  51.305  1
196643  95.777  -76.489  51.260  1
196644  95.801  -76.488  51.214  1
196645  95.825  -76.487  51.167  1
196646  95.849  -76.490  51.120  1
196647  95.873  -76.496  51.072  1
196648  95.897  -76.502  51.030  1
196649  95.921  -76.508  50.988  1
196650  95.946  -76.514  50.945  1
196651  95.969  -76.518  50.901  1
196652  95.992  -76.517  50.856  1
196653  96.015  -76.517  50.811  1
196654  96.038  -76.516  50.766  1
196655  96.059  -76.520  50.721  1
196656  96.078  -76.524  50.674  1
196657  96.090  -76.532  50.629  1
196658  96.103  -76.539  50.584  1
196659  96.116  -76.546  50.542  1
196660  96.128  -76.554  50.497  1
196661  96.147  -76.561  50.452  1
196662  96.169  -76.567  50.405  1
196663  96.191  -76.573  50.361  1
196664  96.214  -76.579  50.321  1
196665  96.236  -76.585  50.284  1
196666  96.258  -76.591  50.249  1
196667  96.279  -76.597  50.218  1
196668  96.300  -76.605  50.191  1
196669  96.320  -76.613  50.166  1
196670  96.339  -76.621  50.143  1
196671  96.358  -76.625  50.122  1
196672  96.376  -76.629  50.103  1
196673  96.395  -76.633  50.087  1
196674  96.413  -76.636  50.072  1
196675  96.431  -76.640  50.057  1
196676  96.443  -76.647  50.040  1
196677  96.451  -76.653  50.018  1
196678  96.459  -76.658  49.995  1
196679  96.467  -76.664  49.970  1
196680  96.476  -76.669  49.944  1
196681  96.520  -76.691  49.913  1
196682  96.566  -76.726  49.881  1
196683  96.611  -76.755  49.847  1
196684  96.641  -76.723  49.813  1
196685  96.669  -76.705  49.778  1
196686  96.697  -76.702  49.744  1
196687  96.724  -76.698  49.711  1
196688  96.752  -76.694  49.679  1
196689  96.780  -76.690  49.647  1
196690  96.807  -76.691  49.615  1
196691  96.833  -76.714  49.581  1
196692  96.860  -76.736  49.546  1
196693  96.887  -76.758  49.511  1
196694  96.911  -76.776  49.475  1
196695  96.929  -76.778  49.440  1
196696  96.947  -76.781  49.407  1
196697  96.965  -76.783  49.374  1
196698  96.982  -76.785  49.342  1
196699  96.997  -76.792  49.312  1
196700  97.011  -76.801  49.284  1
196701  97.024  -76.810  49.257  1
196702  97.037  -76.819  49.231  1
196703  97.050  -76.828  49.208  1
196704  97.067  -76.841  49.185  1
196705  97.099  -76.866  49.164  1
196706  97.132  -76.891  49.143  1
196707  97.164  -76.916  49.119  1
196708  97.174  -76.937  49.093  1
196709  97.176  -76.956  49.066  1
196710  97.179  -76.975  49.039  1
196711  97.181  -76.994  49.010  1
196712  97.235  -76.994  48.982  1
196713  97.310  -77.001  48.954  1
196714  97.344  -77.038  48.928  1
196715  97.373  -77.075  48.901  1
196716  97.404  -77.113  48.875  1
196717  97.437  -77.150  48.848  1
196718  97.468  -77.187  48.823  1
196719  97.501  -77.224  48.797  1
196720  97.530  -77.257  48.773  1
196721  97.540  -77.251  48.748  1
196722  97.543  -77.237  48.722  1
196723  97.544  -77.219  48.695  1
196724  97.544  -77.201  48.668  1
196725  97.544  -77.182  48.641  1
196726  97.545  -77.164  48.614  1
196727  97.545  -77.147  48.586  1
196728  97.546  -77.130  48.559  1
196729  97.550  -77.142  48.532  1
196730  97.555  -77.155  48.503  1
196731  97.570  -77.163  48.473  1
196732  97.591  -77.168  48.445  1
196733  97.613  -77.173  48.417  1
196734  97.636  -77.179  48.387  1
196735  97.658  -77.184  48.358  1
196736  97.682  -77.185  48.329  1
196737  97.709  -77.184  48.300  1
196738  97.736  -77.183  48.270  1
196739  97.763  -77.182  48.241  1
196740  97.790  -77.181  48.213  1
196741  97.817  -77.178  48.185  1
196742  97.848  -77.168  48.158  1
196743  97.878  -77.158  48.130  1
196744  97.909  -77.148  48.101  1
196745  97.939  -77.138  48.072  1
196746  97.959  -77.144  48.041  1
196747  97.980  -77.149  48.011  1
196748  97.999  -77.154  47.981  1
196749  98.020  -77.157  47.951  1
196750  98.045  -77.144  47.920  1
196751  98.071  -77.132  47.887  1
196752  98.097  -77.119  47.855  1
196753  98.122  -77.106  47.822  1
196754  98.148  -77.094  47.790  1
196755  98.173  -77.081  47.759  1
196756  98.199  -77.069  47.727  1
196757  98.224  -77.056  47.697  1
196758  98.250  -77.044  47.667  1
196759  98.276  -77.031  47.637  1
196760  98.300  -77.028  47.606  1
196761  98.324  -77.028  47.576  1
196762  98.349  -77.028  47.546  1
196763  98.373  -77.028  47.517  1
196764  98.398  -77.028  47.488  1
196765  98.423  -77.028  47.459  1
196766  98.447  -77.027  47.432  1
196767  98.472  -77.027  47.406  1
196768  98.482  -77.055  47.381  1
196769  98.487  -77.067  47.356  1
196770  98.478  -77.090  47.333  1
196771  98.469  -77.113  47.310  1
196772  98.474  -77.128  47.288  1
196773  98.489  -77.138  47.265  1
196774  98.505  -77.149  47.242  1
196775  98.535  -77.161  47.220  1
196776  98.568  -77.174  47.196  1
196777  98.601  -77.187  47.174  1
196778  98.635  -77.199  47.151  1
196779  98.685  -77.206  47.128  1
196780  98.735  -77.213  47.103  1
196781  98.785  -77.220  47.082  1
196782  98.809  -77.232  47.061  1
196783  98.823  -77.246  47.038  1
196784  98.837  -77.260  47.015  1
196785  98.851  -77.272  46.993  1
196786  98.866  -77.282  46.971  1
196787  98.880  -77.294  46.950  1
196788  98.895  -77.304  46.927  1
196789  98.910  -77.316  46.903  1
196790  98.924  -77.326  46.878  1
196791  98.939  -77.337  46.853  1
196792  98.953  -77.348  46.828  1
196793  98.968  -77.359  46.802  1
196794  98.983  -77.370  46.775  1
196795  98.999  -77.382  46.749  1
196796  99.013  -77.391  46.723  1
196797  99.024  -77.391  46.698  1
196798  99.041  -77.387  46.675  1
196799  99.052  -77.392  46.652  1
196800  99.063  -77.396  46.628  1
196801  99.074  -77.401  46.603  1
196802  99.085  -77.405  46.579  1
196803  99.096  -77.410  46.554  1
196804  99.106  -77.414  46.530  1
196805  99.118  -77.418  46.506  1
196806  99.129  -77.423  46.483  1
196807  99.140  -77.427  46.459  1
196808  99.150  -77.432  46.435  1
196809  99.161  -77.436  46.412  1
196810  99.172  -77.440  46.388  1
196811  99.184  -77.445  46.365  1
196812  99.195  -77.451  46.342  1
196813  99.207  -77.476  46.318  1
196814  99.205  -77.489  46.293  1
196815  99.213  -77.495  46.268  1
196816  99.235  -77.492  46.244  1
196817  99.258  -77.489  46.219  1
196818  99.280  -77.486  46.196  1
196819  99.302  -77.483  46.173  1
196820  99.324  -77.480  46.150  1
196821  99.346  -77.477  46.128  1
196822  99.368  -77.474  46.106  1
196823  99.391  -77.471  46.085  1
196824  99.413  -77.468  46.065  1
196825  99.435  -77.465  46.046  1
196826  99.457  -77.462  46.027  1
196827  99.479  -77.459  46.008  1
196828  99.504  -77.457  45.990  1
196829  99.544  -77.461  45.970  1
196830  99.584  -77.464  45.953  1
196831  99.624  -77.468  45.936  1
196832  99.663  -77.472  45.920  1
196833  99.704  -77.476  45.904  1
196834  99.745  -77.482  45.889  1
196835  99.789  -77.494  45.875  1
196836  99.834  -77.507  45.859  1
196837  99.879  -77.520  45.844  1
196838  99.924  -77.533  45.830  1
196839  99.952  -77.545  45.817  1
196840  99.966  -77.556  45.802  1
196841  99.979  -77.567  45.789  1
196842  99.992  -77.579  45.776  1
196843  100.005  -77.590  45.763  1
196844  100.018  -77.602  45.751  1
196845  100.031  -77.613  45.738  1
196846  100.044  -77.625  45.725  1
196847  100.057  -77.636  45.713  1
196848  100.071  -77.648  45.700  1
196849  100.086  -77.659  45.688  1
196850  100.101  -77.671  45.677  1
196851  100.116  -77.682  45.665  1
196852  100.138  -77.702  45.654  1
196853  100.162  -77.726  45.642  1
196854  100.193  -77.740  45.631  1
196855  100.223  -77.752  45.620  1
196856  100.254  -77.766  45.609  1
196857  100.285  -77.780  45.597  1
196858  100.308  -77.794  45.586  1
196859  100.327  -77.809  45.574  1
196860  100.347  -77.824  45.561  1
196861  100.366  -77.840  45.548  1
196862  100.385  -77.855  45.534  1
196863  100.410  -77.876  45.520  1
196864  100.434  -77.898  45.505  1
196865  100.459  -77.920  45.490  1
196866  100.484  -77.942  45.474  1
196867  100.508  -77.964  45.459  1
196868  100.525  -77.953  45.445  1
196869  100.540  -77.939  45.431  1
196870  100.558  -77.940  45.415  1
196871  100.576  -77.943  45.401  1
196872  100.594  -77.944  45.387  1
196873  100.614  -77.949  45.373  1
196874  100.637  -77.960  45.358  1
196875  100.660  -77.971  45.344  1
196876  100.683  -77.981  45.329  1
196877  100.706  -77.992  45.314  1
196878  100.729  -78.003  45.301  1
196879  100.753  -78.013  45.287  1
196880  100.776  -78.024  45.273  1
196881  100.798  -78.034  45.260  1
196882  100.822  -78.044  45.248  1
196883  100.845  -78.055  45.235  1
196884  100.873  -78.059  45.222  1
196885  100.902  -78.058  45.209  1
196886  100.925  -78.061  45.197  1
196887  100.949  -78.063  45.184  1
196888  100.975  -78.068  45.172  1
196889  101.014  -78.080  45.158  1
196890  101.053  -78.093  45.144  1
196891  101.092  -78.105  45.129  1
196892  101.131  -78.118  45.114  1
196893  101.169  -78.133  45.100  1
196894  101.205  -78.149  45.085  1
196895  101.242  -78.166  45.070  1
196896  101.278  -78.182  45.056  1
196897  101.315  -78.199  45.042  1
196898  101.336  -78.211  45.028  1
196899  101.353  -78.222  45.013  1
196900  101.371  -78.233  44.998  1
196901  101.387  -78.244  44.984  1
196902  101.404  -78.255  44.969  1
196903  101.421  -78.266  44.954  1
196904  101.438  -78.277  44.939  1
196905  101.455  -78.288  44.923  1
196906  101.472  -78.298  44.907  1
196907  101.489  -78.310  44.891  1
196908  101.505  -78.320  44.876  1
196909  101.523  -78.332  44.861  1
196910  101.540  -78.342  44.845  1
196911  101.564  -78.356  44.830  1
196912  101.589  -78.369  44.813  1
196913  101.621  -78.377  44.797  1
196914  101.650  -78.398  44.780  1
196915  101.680  -78.418  44.766  1
196916  101.709  -78.438  44.749  1
196917  101.739  -78.459  44.732  1
196918  101.768  -78.479  44.717  1
196919  101.798  -78.500  44.700  1
196920  101.827  -78.520  44.685  1
196921  101.857  -78.541  44.670  1
196922  101.887  -78.561  44.656  1
196923  101.932  -78.585  44.639  1
196924  101.977  -78.608  44.623  1
196925  102.023  -78.630  44.608  1
196926  102.068  -78.654  44.592  1
196927  102.114  -78.677  44.577  1
196928  102.159  -78.700  44.562  1
196929  102.203  -78.727  44.548  1
196930  102.246  -78.759  44.533  1
196931  102.289  -78.791  44.518  1
196932  102.329  -78.820  44.504  1
196933  102.349  -78.821  44.489  1
196934  102.368  -78.823  44.474  1
196935  102.388  -78.824  44.460  1
196936  102.407  -78.826  44.446  1
196937  102.427  -78.827  44.431  1
196938  102.446  -78.829  44.417  1
196939  102.466  -78.830  44.403  1
196940  102.485  -78.833  44.388  1
196941  102.504  -78.834  44.375  1
196942  102.524  -78.836  44.360  1
196943  102.543  -78.837  44.346  1
196944  102.563  -78.839  44.331  1
197228  93.526  -76.218  54.042  1
197229  93.544  -76.221  54.050  1
197230  93.563  -76.224  54.058  1
197231  93.581  -76.227  54.067  1
197232  93.599  -76.229  54.079  1
197233  93.618  -76.232  54.087  1
197234  93.636  -76.235  54.095  1
197235  93.654  -76.238  54.104  1
197236  93.673  -76.242  54.114  1
197237  93.691  -76.245  54.124  1
197238  93.709  -76.248  54.134  1
197239  93.724  -76.260  54.147  1
197240  93.727  -76.293  54.156  1
197241  93.735  -76.292  54.165  1
197242  93.744  -76.275  54.174  1
197243  93.770  -76.266  54.183  1
197244  93.803  -76.260  54.191  1
197245  93.836  -76.254  54.198  1
197246  93.869  -76.248  54.206  1
197247  93.904  -76.242  54.211  1
197248  93.939  -76.238  54.216  1
197249  93.958  -76.244  54.222  1
197250  93.962  -76.238  54.229  1
197251  93.966  -76.232  54.237  1
197252  93.970  -76.226  54.246  1
197253  93.973  -76.220  54.254  1
197254  93.977  -76.213  54.258  1
197255  94.004  -76.213  54.257  1
197256  94.033  -76.213  54.257  1
197257  94.062  -76.213  54.256  1
197258  94.091  -76.213  54.257  1
197259  94.120  -76.213  54.259  1
197260  94.149  -76.213  54.258  1
197261  94.178  -76.214  54.252  1
197262  94.203  -76.211  54.244  1
197263  94.224  -76.206  54.232  1
197264  94.246  -76.201  54.217  1
197265  94.267  -76.195  54.200  1
197266  94.287  -76.191  54.178  1
197267  94.305  -76.188  54.152  1
197268  94.323  -76.186  54.121  1
197269  94.341  -76.183  54.090  1
197270  94.359  -76.182  54.057  1
197271  94.378  -76.179  54.025  1
197272  94.396  -76.178  53.995  1
197273  94.414  -76.176  53.965  1
197274  94.432  -76.174  53.932  1
197275  94.443  -76.175  53.898  1
197276  94.455  -76.176  53.866  1
197277  94.467  -76.177  53.836  1
197278  94.478  -76.178  53.808  1
197279  94.490  -76.179  53.782  1
197280  94.501  -76.180  53.757  1
197281  94.513  -76.181  53.732  1
197282  94.525  -76.182  53.708  1
197283  94.536  -76.183  53.685  1
197284  94.549  -76.183  53.664  1
197285  94.566  -76.191  53.639  1
197286  94.588  -76.203  53.611  1
197287  94.609  -76.215  53.580  1
197288  94.630  -76.226  53.545  1
197289  94.651  -76.238  53.509  1
197290  94.667  -76.247  53.474  1
197291  94.678  -76.251  53.440  1
197292  94.689  -76.257  53.408  1
197293  94.700  -76.262  53.376  1
197294  94.711  -76.267  53.343  1
197295  94.722  -76.272  53.307  1
197296  94.734  -76.277  53.270  1
197297  94.745  -76.282  53.232  1
197298  94.756  -76.287  53.192  1
197299  94.767  -76.292  53.151  1
197300  94.778  -76.298  53.113  1
197301  94.789  -76.303  53.073  1
197302  94.801  -76.307  53.033  1
197303  94.813  -76.311  52.993  1
197304  94.825  -76.315  52.954  1
197305  94.838  -76.319  52.914  1
197306  94.850  -76.323  52.874  1
197307  94.863  -76.326  52.834  1
197308  94.876  -76.329  52.791  1
197309  94.888  -76.333  52.746  1
197310  94.901  -76.337  52.701  1
197311  94.913  -76.340  52.655  1
197312  94.926  -76.344  52.610  1
197313  94.938  -76.348  52.566  1
197314  94.949  -76.353  52.523  1
197315  94.935  -76.376  52.475  1
197316  94.950  -76.386  52.425  1
197317  94.975  -76.392  52.374  1
197318  94.999  -76.399  52.321  1
197319  95.032  -76.402  52.272  1
197320  95.081  -76.398  52.222  1
197321  95.130  -76.392  52.172  1
197322  95.180  -76.388  52.124  1
197323  95.230  -76.383  52.080  1
197324  95.279  -76.379  52.036  1
197325  95.328  -76.374  51.991  1
197326  95.353  -76.378  51.943  1
197327  95.376  -76.383  51.896  1
197328  95.399  -76.388  51.851  1
197329  95.422  -76.392  51.807  1
197330  95.445  -76.397  51.766  1
197331  95.468  -76.401  51.726  1
197332  95.491  -76.406  51.690  1
197333  95.515  -76.411  51.659  1
197334  95.538  -76.416  51.627  1
197335  95.560  -76.420  51.593  1
197336  95.584  -76.425  51.558  1
197337  95.607  -76.430  51.523  1
197338  95.630  -76.434  51.490  1
197339  95.654  -76.438  51.458  1
197340  95.680  -76.439  51.426  1
197341  95.705  -76.441  51.394  1
197342  95.739  -76.490  51.358  1
197343  95.763  -76.489  51.318  1
197344  95.787  -76.488  51.273  1
197345  95.811  -76.486  51.227  1
197346  95.835  -76.486  51.181  1
197347  95.859  -76.484  51.135  1
197348  95.882  -76.483  51.087  1
197349  95.906  -76.482  51.046  1
197350  95.930  -76.487  51.004  1
197351  95.954  -76.493  50.961  1
197352  95.978  -76.495  50.917  1
197353  96.001  -76.495  50.872  1
197354  96.024  -76.494  50.826  1
197355  96.045  -76.495  50.781  1
197356  96.061  -76.499  50.737  1
197357  96.075  -76.507  50.692  1
197358  96.088  -76.514  50.648  1
197359  96.101  -76.522  50.606  1
197360  96.114  -76.530  50.566  1
197361  96.129  -76.534  50.523  1
197362  96.147  -76.538  50.479  1
197363  96.168  -76.545  50.434  1
197364  96.190  -76.552  50.391  1
197365  96.212  -76.559  50.351  1
197366  96.234  -76.566  50.314  1
197367  96.256  -76.572  50.280  1
197368  96.278  -76.578  50.249  1
197369  96.301  -76.584  50.222  1
197370  96.322  -76.592  50.198  1
197371  96.340  -76.597  50.175  1
197372  96.359  -76.601  50.154  1
197373  96.374  -76.603  50.136  1
197374  96.389  -76.605  50.119  1
197375  96.404  -76.608  50.103  1
197376  96.432  -76.623  50.086  1
197377  96.451  -76.636  50.066  1
197378  96.459  -76.641  50.043  1
197379  96.467  -76.647  50.019  1
197380  96.476  -76.652  49.994  1
197381  96.501  -76.660  49.967  1
197382  96.549  -76.671  49.937  1
197383  96.597  -76.683  49.904  1
197384  96.636  -76.689  49.870  1
197385  96.663  -76.684  49.835  1
197386  96.690  -76.680  49.800  1
197387  96.718  -76.677  49.765  1
197388  96.745  -76.673  49.731  1
197389  96.773  -76.668  49.698  1
197390  96.800  -76.665  49.665  1
197391  96.827  -76.665  49.632  1
197392  96.855  -76.687  49.599  1
197393  96.881  -76.709  49.564  1
197394  96.908  -76.732  49.528  1
197395  96.929  -76.741  49.492  1
197396  96.947  -76.743  49.456  1
197397  96.964  -76.746  49.422  1
197398  96.982  -76.749  49.389  1
197399  97.000  -76.751  49.358  1
197400  97.017  -76.753  49.327  1
197401  97.031  -76.762  49.299  1
197402  97.044  -76.771  49.272  1
197403  97.058  -76.780  49.247  1
197404  97.075  -76.793  49.224  1
197405  97.107  -76.818  49.202  1
197406  97.139  -76.843  49.181  1
197407  97.145  -76.863  49.160  1
197408  97.148  -76.882  49.138  1
197409  97.150  -76.901  49.112  1
197410  97.153  -76.920  49.084  1
197411  97.155  -76.940  49.057  1
197412  97.165  -76.960  49.029  1
197413  97.219  -76.982  49.001  1
197414  97.308  -76.995  48.973  1
197415  97.386  -77.013  48.946  1
197416  97.415  -77.051  48.919  1
197417  97.444  -77.090  48.892  1
197418  97.473  -77.128  48.866  1
197419  97.502  -77.166  48.839  1
197420  97.531  -77.204  48.814  1
197421  97.549  -77.240  48.788  1
197422  97.556  -77.236  48.763  1
197423  97.557  -77.218  48.737  1
197424  97.557  -77.201  48.710  1
197425  97.557  -77.182  48.682  1
197426  97.558  -77.164  48.654  1
197427  97.558  -77.146  48.627  1
197428  97.558  -77.128  48.599  1
197429  97.559  -77.113  48.572  1
197430  97.564  -77.126  48.544  1
197431  97.568  -77.138  48.514  1
197432  97.590  -77.144  48.485  1
197433  97.612  -77.149  48.456  1
197434  97.634  -77.153  48.427  1
197435  97.656  -77.159  48.398  1
197436  97.678  -77.164  48.369  1
197437  97.700  -77.169  48.341  1
197438  97.722  -77.174  48.312  1
197439  97.749  -77.172  48.283  1
197440  97.776  -77.172  48.254  1
197441  97.805  -77.166  48.225  1
197442  97.836  -77.156  48.196  1
197443  97.866  -77.146  48.169  1
197444  97.896  -77.136  48.140  1
197445  97.927  -77.126  48.111  1
197446  97.956  -77.117  48.081  1
197447  97.977  -77.122  48.051  1
197448  97.997  -77.128  48.021  1
197449  98.016  -77.133  47.990  1
197450  98.036  -77.138  47.959  1
197451  98.057  -77.143  47.928  1
197452  98.082  -77.130  47.895  1
197453  98.108  -77.118  47.863  1
197454  98.134  -77.105  47.829  1
197455  98.159  -77.093  47.798  1
197456  98.184  -77.080  47.766  1
197457  98.210  -77.068  47.735  1
197458  98.235  -77.055  47.705  1
197459  98.261  -77.043  47.675  1
197460  98.287  -77.032  47.644  1
197461  98.311  -77.032  47.614  1
197462  98.336  -77.032  47.584  1
197463  98.360  -77.032  47.554  1
197464  98.384  -77.031  47.525  1
197465  98.409  -77.031  47.497  1
197466  98.433  -77.031  47.469  1
197467  98.457  -77.031  47.443  1
197468  98.482  -77.031  47.417  1
197469  98.507  -77.031  47.392  1
197470  98.505  -77.047  47.367  1
197471  98.497  -77.069  47.343  1
197472  98.488  -77.091  47.321  1
197473  98.480  -77.114  47.298  1
197474  98.489  -77.127  47.275  1
197475  98.505  -77.138  47.253  1
197476  98.534  -77.150  47.230  1
197477  98.567  -77.162  47.207  1
197478  98.599  -77.175  47.183  1
197479  98.648  -77.182  47.159  1
197480  98.698  -77.189  47.135  1
197481  98.748  -77.197  47.112  1
197482  98.798  -77.204  47.089  1
197483  98.820  -77.216  47.066  1
197484  98.835  -77.229  47.042  1
197485  98.849  -77.243  47.020  1
197486  98.862  -77.257  46.998  1
197487  98.877  -77.268  46.977  1
197488  98.891  -77.279  46.956  1
197489  98.906  -77.290  46.932  1
197490  98.921  -77.301  46.907  1
197491  98.935  -77.312  46.882  1
197492  98.950  -77.323  46.857  1
197493  98.964  -77.334  46.831  1
197494  98.979  -77.345  46.805  1
197495  98.994  -77.356  46.779  1
197496  99.008  -77.367  46.753  1
197497  99.023  -77.378  46.727  1
197498  99.038  -77.389  46.701  1
197499  99.049  -77.395  46.678  1
197500  99.060  -77.400  46.653  1
197501  99.070  -77.405  46.628  1
197502  99.081  -77.410  46.603  1
197503  99.092  -77.415  46.579  1
197504  99.103  -77.420  46.553  1
197505  99.114  -77.423  46.529  1
197506  99.125  -77.428  46.506  1
197507  99.136  -77.432  46.483  1
197508  99.147  -77.437  46.459  1
197509  99.157  -77.442  46.435  1
197510  99.168  -77.446  46.412  1
197511  99.180  -77.450  46.387  1
197512  99.191  -77.454  46.365  1
197513  99.201  -77.459  46.341  1
197514  99.212  -77.464  46.316  1
197515  99.218  -77.480  46.291  1
197516  99.236  -77.480  46.266  1
197517  99.258  -77.477  46.242  1
197518  99.280  -77.474  46.218  1
197519  99.302  -77.471  46.195  1
197520  99.325  -77.468  46.172  1
197521  99.347  -77.465  46.150  1
197522  99.369  -77.462  46.128  1
197523  99.391  -77.460  46.106  1
197524  99.413  -77.457  46.085  1
197525  99.435  -77.454  46.065  1
197526  99.457  -77.451  46.046  1
197527  99.479  -77.448  46.027  1
197528  99.501  -77.445  46.008  1
197529  99.523  -77.442  45.990  1
197530  99.549  -77.440  45.971  1
197531  99.589  -77.444  45.953  1
197532  99.629  -77.447  45.936  1
197533  99.669  -77.451  45.919  1
197534  99.709  -77.454  45.904  1
197535  99.753  -77.466  45.890  1
197536  99.798  -77.479  45.875  1
197537  99.843  -77.492  45.859  1
197538  99.888  -77.504  45.845  1
197539  99.932  -77.517  45.831  1
197540  99.974  -77.530  45.817  1
197541  99.987  -77.541  45.803  1
197542  100.000  -77.552  45.790  1
197543  100.013  -77.564  45.777  1
197544  100.027  -77.576  45.764  1
197545  100.040  -77.587  45.751  1
197546  100.053  -77.599  45.738  1
197547  100.066  -77.610  45.726  1
197548  100.079  -77.621  45.714  1
197549  100.093  -77.633  45.700  1
197550  100.109  -77.644  45.688  1
197551  100.124  -77.655  45.676  1
197552  100.139  -77.667  45.664  1
197553  100.154  -77.678  45.652  1
197554  100.177  -77.700  45.640  1
197555  100.207  -77.716  45.628  1
197556  100.237  -77.730  45.617  1
197557  100.268  -77.743  45.605  1
197558  100.298  -77.756  45.594  1
197559  100.329  -77.769  45.582  1
197560  100.352  -77.783  45.570  1
197561  100.372  -77.799  45.557  1
197562  100.393  -77.817  45.544  1
197563  100.418  -77.839  45.530  1
197564  100.442  -77.861  45.516  1
197565  100.467  -77.883  45.501  1
197566  100.492  -77.905  45.486  1
197567  100.516  -77.926  45.471  1
197568  100.541  -77.944  45.455  1
197569  100.555  -77.925  45.440  1
197570  100.570  -77.910  45.426  1
197571  100.588  -77.912  45.411  1
197572  100.606  -77.914  45.397  1
197573  100.626  -77.919  45.382  1
197574  100.649  -77.930  45.368  1
197575  100.672  -77.940  45.354  1
197576  100.695  -77.950  45.339  1
197577  100.718  -77.961  45.325  1
197578  100.742  -77.971  45.311  1
197579  100.764  -77.982  45.298  1
197580  100.787  -77.993  45.285  1
197581  100.811  -78.003  45.271  1
197582  100.834  -78.014  45.258  1
197583  100.857  -78.025  45.246  1
197584  100.880  -78.035  45.234  1
197585  100.903  -78.046  45.222  1
197586  100.931  -78.047  45.209  1
197587  100.955  -78.050  45.196  1
197588  100.978  -78.053  45.184  1
197589  101.001  -78.055  45.171  1
197590  101.034  -78.063  45.157  1
197591  101.073  -78.076  45.143  1
197592  101.112  -78.089  45.128  1
197593  101.148  -78.106  45.113  1
197594  101.185  -78.122  45.099  1
197595  101.221  -78.139  45.084  1
197596  101.257  -78.156  45.069  1
197597  101.294  -78.172  45.055  1
197598  101.330  -78.189  45.041  1
197599  101.357  -78.203  45.027  1
197600  101.374  -78.213  45.012  1
197601  101.391  -78.225  44.997  1
197602  101.408  -78.235  44.982  1
197603  101.424  -78.247  44.967  1
197604  101.442  -78.257  44.952  1
197605  101.458  -78.268  44.936  1
197606  101.475  -78.279  44.920  1
197607  101.492  -78.290  44.905  1
197608  101.509  -78.300  44.889  1
197609  101.526  -78.312  44.873  1
197610  101.543  -78.322  44.858  1
197611  101.567  -78.336  44.842  1
197612  101.592  -78.349  44.825  1
197613  101.616  -78.362  44.811  1
197614  101.640  -78.376  44.795  1
197615  101.665  -78.388  44.779  1
197616  101.697  -78.399  44.764  1
197617  101.726  -78.420  44.747  1
197618  101.756  -78.440  44.731  1
197619  101.785  -78.460  44.716  1
197620  101.815  -78.481  44.699  1
197621  101.844  -78.501  44.685  1
197622  101.874  -78.522  44.670  1
197623  101.903  -78.543  44.655  1
197624  101.949  -78.566  44.639  1
197625  101.994  -78.589  44.623  1
197626  102.040  -78.612  44.607  1
197627  102.085  -78.635  44.592  1
197628  102.130  -78.658  44.576  1
197629  102.176  -78.681  44.561  1
197630  102.221  -78.704  44.546  1
197631  102.265  -78.733  44.531  1
197632  102.308  -78.765  44.517  1
197633  102.351  -78.797  44.503  1
197634  102.374  -78.804  44.488  1
197635  102.393  -78.805  44.473  1
197636  102.413  -78.807  44.459  1
197637  102.433  -78.808  44.444  1
197638  102.452  -78.810  44.429  1
197639  102.471  -78.811  44.415  1
197640  102.491  -78.813  44.401  1
197641  102.510  -78.815  44.387  1
197642  102.530  -78.817  44.372  1
197643  102.549  -78.818  44.357  1
197644  102.569  -78.820  44.342  1
197645  102.588  -78.821  44.328  1
197930  93.536  -76.198  54.041  1
197931  93.555  -76.201  54.051  1
197932  93.573  -76.204  54.061  1
197933  93.591  -76.207  54.072  1
197934  93.610  -76.209  54.082  1
197935  93.628  -76.212  54.090  1
197936  93.646  -76.215  54.099  1
197937  93.664  -76.218  54.109  1
197938  93.683  -76.222  54.120  1
197939  93.701  -76.225  54.132  1
197940  93.716  -76.235  54.143  1
197941  93.720  -76.269  54.153  1
197942  93.725  -76.286  54.164  1
197943  93.739  -76.271  54.175  1
197944  93.772  -76.265  54.184  1
197945  93.805  -76.259  54.191  1
197946  93.838  -76.253  54.199  1
197947  93.871  -76.248  54.210  1
197948  93.904  -76.240  54.217  1
197949  93.936  -76.227  54.223  1
197950  93.946  -76.220  54.230  1
197951  93.949  -76.213  54.238  1
197952  93.952  -76.207  54.246  1
197953  93.955  -76.201  54.256  1
197954  93.957  -76.195  54.265  1
197955  93.978  -76.189  54.269  1
197956  94.007  -76.190  54.269  1
197957  94.037  -76.191  54.268  1
197958  94.066  -76.191  54.267  1
197959  94.096  -76.192  54.268  1
197960  94.124  -76.192  54.269  1
197961  94.153  -76.193  54.267  1
197962  94.183  -76.193  54.259  1
197963  94.206  -76.189  54.250  1
197964  94.228  -76.184  54.237  1
197965  94.250  -76.179  54.222  1
197966  94.270  -76.174  54.203  1
197967  94.288  -76.172  54.180  1
197968  94.306  -76.169  54.153  1
197969  94.324  -76.166  54.123  1
197970  94.342  -76.163  54.091  1
197971  94.360  -76.161  54.059  1
197972  94.378  -76.160  54.028  1
197973  94.396  -76.157  53.997  1
197974  94.414  -76.156  53.967  1
197975  94.432  -76.154  53.932  1
197976  94.445  -76.154  53.897  1
197977  94.457  -76.155  53.863  1
197978  94.468  -76.157  53.833  1
197979  94.480  -76.157  53.805  1
197980  94.491  -76.158  53.780  1
197981  94.503  -76.160  53.756  1
197982  94.514  -76.160  53.731  1
197983  94.526  -76.161  53.708  1
197984  94.538  -76.163  53.685  1
197985  94.551  -76.167  53.664  1
197986  94.568  -76.176  53.640  1
197987  94.589  -76.188  53.614  1
197988  94.610  -76.200  53.583  1
197989  94.631  -76.211  53.549  1
197990  94.652  -76.223  53.513  1
197991  94.668  -76.231  53.479  1
197992  94.679  -76.236  53.445  1
197993  94.690  -76.241  53.414  1
197994  94.701  -76.246  53.383  1
197995  94.712  -76.251  53.349  1
197996  94.723  -76.257  53.313  1
197997  94.735  -76.261  53.275  1
197998  94.746  -76.267  53.236  1
197999  94.757  -76.272  53.197  1
198000  94.768  -76.277  53.158  1
198001  94.779  -76.282  53.121  1
198002  94.790  -76.287  53.083  1
198003  94.801  -76.292  53.043  1
198004  94.812  -76.298  53.003  1
198005  94.824  -76.302  52.962  1
198006  94.836  -76.305  52.921  1
198007  94.849  -76.309  52.881  1
198008  94.861  -76.313  52.840  1
198009  94.874  -76.317  52.796  1
198010  94.886  -76.320  52.751  1
198011  94.899  -76.323  52.705  1
198012  94.911  -76.327  52.658  1
198013  94.924  -76.331  52.614  1
198014  94.936  -76.335  52.571  1
198015  94.948  -76.339  52.528  1
198016  94.934  -76.361  52.480  1
198017  94.940  -76.376  52.433  1
198018  94.965  -76.383  52.384  1
198019  94.989  -76.389  52.333  1
198020  95.028  -76.389  52.285  1
198021  95.077  -76.384  52.237  1
198022  95.127  -76.379  52.188  1
198023  95.177  -76.375  52.142  1
198024  95.226  -76.370  52.096  1
198025  95.275  -76.365  52.051  1
198026  95.325  -76.361  52.007  1
198027  95.357  -76.362  51.961  1
198028  95.380  -76.367  51.916  1
198029  95.403  -76.372  51.871  1
198030  95.426  -76.376  51.827  1
198031  95.449  -76.381  51.785  1
198032  95.472  -76.386  51.745  1
198033  95.495  -76.391  51.707  1
198034  95.519  -76.395  51.674  1
198035  95.542  -76.400  51.644  1
198036  95.564  -76.404  51.612  1
198037  95.588  -76.409  51.578  1
198038  95.611  -76.414  51.545  1
198039  95.635  -76.417  51.511  1
198040  95.660  -76.419  51.477  1
198041  95.686  -76.421  51.445  1
198042  95.711  -76.423  51.411  1
198043  95.746  -76.474  51.374  1
198044  95.773  -76.488  51.333  1
198045  95.797  -76.486  51.287  1
198046  95.820  -76.486  51.241  1
198047  95.844  -76.484  51.194  1
198048  95.868  -76.482  51.148  1
198049  95.892  -76.480  51.102  1
198050  95.915  -76.477  51.061  1
198051  95.939  -76.475  51.020  1
198052  95.963  -76.473  50.977  1
198053  95.984  -76.475  50.932  1
198054  96.006  -76.475  50.886  1
198055  96.028  -76.476  50.841  1
198056  96.049  -76.477  50.796  1
198057  96.063  -76.483  50.753  1
198058  96.076  -76.491  50.710  1
198059  96.089  -76.499  50.668  1
198060  96.102  -76.505  50.628  1
198061  96.118  -76.510  50.590  1
198062  96.137  -76.510  50.548  1
198063  96.151  -76.513  50.505  1
198064  96.170  -76.518  50.461  1
198065  96.191  -76.526  50.419  1
198066  96.214  -76.533  50.381  1
198067  96.235  -76.539  50.344  1
198068  96.257  -76.547  50.309  1
198069  96.279  -76.554  50.278  1
198070  96.301  -76.561  50.252  1
198071  96.320  -76.567  50.229  1
198072  96.333  -76.568  50.206  1
198073  96.348  -76.571  50.185  1
198074  96.363  -76.573  50.166  1
198075  96.379  -76.575  50.148  1
198076  96.395  -76.578  50.131  1
198077  96.436  -76.608  50.111  1
198078  96.459  -76.624  50.089  1
198079  96.467  -76.630  50.066  1
198080  96.476  -76.635  50.041  1
198081  96.484  -76.640  50.016  1
198082  96.528  -76.652  49.989  1
198083  96.576  -76.663  49.960  1
198084  96.615  -76.667  49.927  1
198085  96.649  -76.665  49.892  1
198086  96.684  -76.659  49.857  1
198087  96.712  -76.655  49.821  1
198088  96.739  -76.652  49.785  1
198089  96.766  -76.648  49.751  1
198090  96.794  -76.643  49.717  1
198091  96.821  -76.640  49.684  1
198092  96.849  -76.638  49.650  1
198093  96.875  -76.661  49.616  1
198094  96.902  -76.683  49.580  1
198095  96.929  -76.704  49.544  1
198096  96.946  -76.706  49.507  1
198097  96.964  -76.708  49.471  1
198098  96.981  -76.712  49.437  1
198099  96.999  -76.714  49.404  1
198100  97.017  -76.716  49.373  1
198101  97.034  -76.718  49.342  1
198102  97.051  -76.722  49.313  1
198103  97.064  -76.731  49.286  1
198104  97.082  -76.745  49.262  1
198105  97.114  -76.770  49.240  1
198106  97.116  -76.789  49.218  1
198107  97.119  -76.808  49.199  1
198108  97.125  -76.828  49.178  1
198109  97.137  -76.849  49.156  1
198110  97.149  -76.870  49.130  1
198111  97.161  -76.891  49.102  1
198112  97.173  -76.912  49.075  1
198113  97.185  -76.934  49.047  1
198114  97.219  -76.956  49.019  1
198115  97.288  -76.964  48.991  1
198116  97.394  -77.003  48.964  1
198117  97.457  -77.027  48.938  1
198118  97.486  -77.066  48.910  1
198119  97.508  -77.102  48.883  1
198120  97.521  -77.135  48.856  1
198121  97.534  -77.169  48.830  1
198122  97.547  -77.193  48.805  1
198123  97.560  -77.200  48.779  1
198124  97.569  -77.200  48.752  1
198125  97.570  -77.182  48.723  1
198126  97.570  -77.163  48.696  1
198127  97.570  -77.145  48.668  1
198128  97.571  -77.127  48.640  1
198129  97.571  -77.109  48.612  1
198130  97.572  -77.097  48.586  1
198131  97.577  -77.110  48.557  1
198132  97.589  -77.119  48.526  1
198133  97.611  -77.124  48.497  1
198134  97.633  -77.129  48.467  1
198135  97.655  -77.134  48.438  1
198136  97.677  -77.139  48.409  1
198137  97.699  -77.144  48.381  1
198138  97.721  -77.149  48.353  1
198139  97.743  -77.154  48.325  1
198140  97.765  -77.160  48.296  1
198141  97.793  -77.154  48.267  1
198142  97.823  -77.144  48.238  1
198143  97.854  -77.134  48.209  1
198144  97.884  -77.124  48.179  1
198145  97.915  -77.114  48.150  1
198146  97.945  -77.104  48.120  1
198147  97.973  -77.097  48.090  1
198148  97.994  -77.102  48.060  1
198149  98.014  -77.107  48.029  1
198150  98.033  -77.113  47.999  1
198151  98.054  -77.118  47.968  1
198152  98.074  -77.123  47.936  1
198153  98.094  -77.128  47.904  1
198154  98.119  -77.116  47.871  1
198155  98.145  -77.103  47.838  1
198156  98.170  -77.091  47.806  1
198157  98.196  -77.078  47.774  1
198158  98.221  -77.066  47.744  1
198159  98.247  -77.053  47.713  1
198160  98.272  -77.041  47.682  1
198161  98.297  -77.036  47.652  1
198162  98.321  -77.036  47.621  1
198163  98.346  -77.036  47.593  1
198164  98.370  -77.036  47.564  1
198165  98.395  -77.036  47.535  1
198166  98.420  -77.036  47.508  1
198167  98.444  -77.036  47.481  1
198168  98.468  -77.035  47.454  1
198169  98.492  -77.029  47.429  1
198170  98.516  -77.024  47.403  1
198171  98.520  -77.033  47.378  1
198172  98.514  -77.050  47.354  1
198173  98.506  -77.071  47.331  1
198174  98.498  -77.094  47.308  1
198175  98.490  -77.116  47.286  1
198176  98.505  -77.126  47.263  1
198177  98.532  -77.138  47.240  1
198178  98.565  -77.150  47.217  1
198179  98.612  -77.159  47.193  1
198180  98.662  -77.166  47.169  1
198181  98.712  -77.173  47.145  1
198182  98.762  -77.180  47.121  1
198183  98.812  -77.187  47.097  1
198184  98.833  -77.200  47.073  1
198185  98.846  -77.213  47.048  1
198186  98.860  -77.227  47.026  1
198187  98.874  -77.241  47.004  1
198188  98.888  -77.254  46.982  1
198189  98.903  -77.265  46.961  1
198190  98.917  -77.276  46.936  1
198191  98.932  -77.287  46.911  1
198192  98.946  -77.298  46.886  1
198193  98.961  -77.309  46.861  1
198194  98.976  -77.320  46.835  1
198195  98.990  -77.331  46.808  1
198196  99.005  -77.341  46.783  1
198197  99.019  -77.353  46.757  1
198198  99.034  -77.363  46.730  1
198199  99.049  -77.373  46.704  1
198200  99.061  -77.378  46.679  1
198201  99.073  -77.383  46.653  1
198202  99.084  -77.389  46.627  1
198203  99.094  -77.395  46.602  1
198204  99.105  -77.401  46.578  1
198205  99.116  -77.406  46.552  1
198206  99.126  -77.412  46.528  1
198207  99.137  -77.417  46.504  1
198208  99.147  -77.423  46.482  1
198209  99.158  -77.429  46.458  1
198210  99.169  -77.435  46.434  1
198211  99.180  -77.440  46.410  1
198212  99.190  -77.446  46.386  1
198213  99.201  -77.451  46.363  1
198214  99.211  -77.457  46.339  1
198215  99.222  -77.463  46.314  1
198216  99.238  -77.468  46.289  1
198217  99.264  -77.468  46.264  1
198218  99.283  -77.464  46.240  1
198219  99.303  -77.460  46.216  1
198220  99.325  -77.457  46.193  1
198221  99.347  -77.454  46.171  1
198222  99.369  -77.451  46.149  1
198223  99.391  -77.448  46.126  1
198224  99.413  -77.445  46.105  1
198225  99.435  -77.442  46.084  1
198226  99.457  -77.439  46.064  1
198227  99.480  -77.436  46.045  1
198228  99.502  -77.433  46.025  1
198229  99.524  -77.430  46.006  1
198230  99.546  -77.427  45.988  1
198231  99.568  -77.424  45.970  1
198232  99.594  -77.423  45.952  1
198233  99.634  -77.426  45.935  1
198234  99.674  -77.430  45.918  1
198235  99.716  -77.438  45.903  1
198236  99.761  -77.451  45.889  1
198237  99.806  -77.464  45.874  1
198238  99.851  -77.476  45.859  1
198239  99.896  -77.489  45.845  1
198240  99.941  -77.501  45.831  1
198241  99.986  -77.514  45.817  1
198242  100.009  -77.526  45.803  1
198243  100.022  -77.538  45.790  1
198244  100.035  -77.549  45.777  1
198245  100.049  -77.561  45.763  1
198246  100.062  -77.572  45.751  1
198247  100.075  -77.583  45.738  1
198248  100.088  -77.595  45.726  1
198249  100.101  -77.607  45.713  1
198250  100.116  -77.618  45.699  1
198251  100.132  -77.630  45.687  1
198252  100.147  -77.641  45.675  1
198253  100.162  -77.652  45.663  1
198254  100.177  -77.664  45.651  1
198255  100.193  -77.675  45.638  1
198256  100.220  -77.692  45.626  1
198257  100.251  -77.706  45.613  1
198258  100.282  -77.719  45.601  1
198259  100.312  -77.733  45.590  1
198260  100.343  -77.746  45.578  1
198261  100.374  -77.759  45.566  1
198262  100.402  -77.780  45.553  1
198263  100.426  -77.801  45.540  1
198264  100.451  -77.823  45.527  1
198265  100.476  -77.845  45.513  1
198266  100.500  -77.867  45.498  1
198267  100.525  -77.889  45.483  1
198268  100.550  -77.911  45.468  1
198269  100.571  -77.918  45.452  1
198270  100.585  -77.898  45.436  1
198271  100.600  -77.881  45.422  1
198272  100.618  -77.884  45.407  1
198273  100.638  -77.888  45.393  1
198274  100.661  -77.899  45.378  1
198275  100.684  -77.909  45.363  1
198276  100.707  -77.920  45.349  1
198277  100.731  -77.931  45.335  1
198278  100.753  -77.941  45.321  1
198279  100.776  -77.952  45.308  1
198280  100.799  -77.962  45.295  1
198281  100.823  -77.973  45.282  1
198282  100.846  -77.984  45.269  1
198283  100.868  -77.993  45.257  1
198284  100.892  -78.004  45.245  1
198285  100.915  -78.015  45.233  1
198286  100.937  -78.026  45.221  1
198287  100.960  -78.037  45.208  1
198288  100.984  -78.040  45.196  1
198289  101.007  -78.042  45.183  1
198290  101.031  -78.044  45.170  1
198291  101.054  -78.047  45.156  1
198292  101.091  -78.062  45.142  1
198293  101.127  -78.079  45.127  1
198294  101.164  -78.096  45.113  1
198295  101.200  -78.112  45.097  1
198296  101.237  -78.129  45.082  1
198297  101.273  -78.146  45.068  1
198298  101.310  -78.163  45.054  1
198299  101.346  -78.179  45.040  1
198300  101.377  -78.194  45.025  1
198301  101.394  -78.205  45.010  1
198302  101.411  -78.216  44.995  1
198303  101.428  -78.227  44.980  1
198304  101.445  -78.238  44.965  1
198305  101.462  -78.249  44.949  1
198306  101.479  -78.260  44.933  1
198307  101.495  -78.270  44.917  1
198308  101.513  -78.282  44.900  1
198309  101.530  -78.292  44.885  1
198310  101.546  -78.303  44.869  1
198311  101.570  -78.316  44.854  1
198312  101.595  -78.329  44.838  1
198313  101.619  -78.342  44.822  1
198314  101.643  -78.356  44.807  1
198315  101.668  -78.369  44.792  1
198316  101.692  -78.382  44.777  1
198317  101.717  -78.395  44.761  1
198318  101.741  -78.408  44.745  1
198319  101.772  -78.422  44.730  1
198320  101.802  -78.442  44.714  1
198321  101.831  -78.463  44.699  1
198322  101.861  -78.483  44.684  1
198323  101.890  -78.504  44.669  1
198324  101.920  -78.524  44.654  1
198325  101.965  -78.547  44.638  1
198326  102.011  -78.570  44.622  1
198327  102.056  -78.593  44.606  1
198328  102.102  -78.617  44.591  1
198329  102.147  -78.639  44.576  1
198330  102.192  -78.662  44.560  1
198331  102.238  -78.686  44.545  1
198332  102.283  -78.708  44.530  1
198333  102.326  -78.739  44.515  1
198334  102.369  -78.771  44.501  1
198335  102.399  -78.786  44.486  1
198336  102.418  -78.788  44.471  1
198337  102.438  -78.789  44.456  1
198338  102.458  -78.791  44.441  1
198339  102.477  -78.793  44.426  1
198340  102.497  -78.794  44.412  1
198341  102.516  -78.796  44.398  1
198342  102.535  -78.798  44.383  1
198343  102.555  -78.799  44.369  1
198344  102.574  -78.801  44.354  1
198345  102.594  -78.802  44.339  1
198346  102.613  -78.804  44.324  1
198631  93.528  -76.174  54.033  1
198632  93.546  -76.177  54.043  1
198633  93.565  -76.180  54.054  1
198634  93.583  -76.183  54.066  1
198635  93.602  -76.185  54.076  1
198636  93.620  -76.188  54.085  1
198637  93.638  -76.191  54.095  1
198638  93.656  -76.195  54.106  1
198639  93.675  -76.198  54.117  1
198640  93.693  -76.201  54.130  1
198641  93.708  -76.211  54.142  1
198642  93.712  -76.245  54.153  1
198643  93.716  -76.279  54.164  1
198644  93.741  -76.270  54.176  1
198645  93.773  -76.263  54.185  1
198646  93.805  -76.250  54.193  1
198647  93.838  -76.236  54.202  1
198648  93.870  -76.223  54.213  1
198649  93.902  -76.210  54.222  1
198650  93.921  -76.203  54.231  1
198651  93.930  -76.195  54.239  1
198652  93.933  -76.189  54.249  1
198653  93.936  -76.183  54.259  1
198654  93.939  -76.176  54.269  1
198655  93.959  -76.171  54.279  1
198656  93.980  -76.166  54.281  1
198657  94.009  -76.167  54.282  1
198658  94.040  -76.169  54.281  1
198659  94.070  -76.171  54.281  1
198660  94.100  -76.171  54.282  1
198661  94.129  -76.171  54.283  1
198662  94.157  -76.172  54.280  1
198663  94.187  -76.172  54.272  1
198664  94.210  -76.168  54.258  1
198665  94.231  -76.163  54.243  1
198666  94.253  -76.157  54.227  1
198667  94.271  -76.154  54.206  1
198668  94.289  -76.152  54.184  1
198669  94.307  -76.150  54.157  1
198670  94.325  -76.147  54.125  1
198671  94.342  -76.144  54.094  1
198672  94.360  -76.141  54.063  1
198673  94.379  -76.139  54.032  1
198674  94.397  -76.138  54.001  1
198675  94.415  -76.135  53.968  1
198676  94.433  -76.134  53.932  1
198677  94.447  -76.134  53.896  1
198678  94.458  -76.135  53.861  1
198679  94.470  -76.136  53.829  1
198680  94.481  -76.137  53.802  1
198681  94.493  -76.138  53.777  1
198682  94.504  -76.139  53.755  1
198683  94.516  -76.140  53.729  1
198684  94.528  -76.141  53.705  1
198685  94.541  -76.148  53.683  1
198686  94.555  -76.154  53.662  1
198687  94.569  -76.161  53.639  1
198688  94.591  -76.173  53.614  1
198689  94.612  -76.185  53.585  1
198690  94.633  -76.197  53.551  1
198691  94.654  -76.208  53.516  1
198692  94.668  -76.215  53.482  1
198693  94.679  -76.220  53.449  1
198694  94.690  -76.226  53.418  1
198695  94.701  -76.230  53.388  1
198696  94.712  -76.235  53.355  1
198697  94.723  -76.241  53.318  1
198698  94.735  -76.246  53.280  1
198699  94.746  -76.251  53.242  1
198700  94.757  -76.256  53.204  1
198701  94.768  -76.261  53.166  1
198702  94.779  -76.267  53.130  1
198703  94.790  -76.271  53.092  1
198704  94.802  -76.276  53.053  1
198705  94.813  -76.282  53.012  1
198706  94.824  -76.287  52.971  1
198707  94.835  -76.292  52.929  1
198708  94.847  -76.296  52.888  1
198709  94.859  -76.300  52.846  1
198710  94.872  -76.303  52.802  1
198711  94.885  -76.307  52.757  1
198712  94.897  -76.310  52.712  1
198713  94.910  -76.314  52.666  1
198714  94.922  -76.317  52.623  1
198715  94.935  -76.321  52.580  1
198716  94.947  -76.325  52.537  1
198717  94.933  -76.348  52.492  1
198718  94.929  -76.366  52.445  1
198719  94.954  -76.373  52.398  1
198720  94.979  -76.379  52.349  1
198721  95.025  -76.376  52.303  1
198722  95.074  -76.371  52.256  1
198723  95.124  -76.367  52.209  1
198724  95.173  -76.362  52.162  1
198725  95.222  -76.357  52.115  1
198726  95.272  -76.352  52.068  1
198727  95.322  -76.348  52.023  1
198728  95.361  -76.347  51.979  1
198729  95.384  -76.351  51.935  1
198730  95.407  -76.356  51.892  1
198731  95.430  -76.361  51.849  1
198732  95.453  -76.365  51.806  1
198733  95.476  -76.370  51.765  1
198734  95.499  -76.375  51.726  1
198735  95.523  -76.379  51.691  1
198736  95.546  -76.384  51.659  1
198737  95.568  -76.389  51.628  1
198738  95.592  -76.394  51.597  1
198739  95.615  -76.398  51.565  1
198740  95.641  -76.399  51.532  1
198741  95.666  -76.401  51.500  1
198742  95.692  -76.402  51.467  1
198743  95.718  -76.404  51.432  1
198744  95.752  -76.455  51.394  1
198745  95.779  -76.462  51.351  1
198746  95.803  -76.461  51.303  1
198747  95.827  -76.459  51.256  1
198748  95.851  -76.457  51.209  1
198749  95.875  -76.455  51.162  1
198750  95.898  -76.452  51.116  1
198751  95.922  -76.451  51.075  1
198752  95.945  -76.451  51.032  1
198753  95.966  -76.455  50.989  1
198754  95.988  -76.457  50.944  1
198755  96.010  -76.457  50.899  1
198756  96.031  -76.458  50.853  1
198757  96.051  -76.460  50.808  1
198758  96.064  -76.467  50.767  1
198759  96.078  -76.474  50.726  1
198760  96.091  -76.482  50.687  1
198761  96.106  -76.486  50.650  1
198762  96.126  -76.486  50.613  1
198763  96.144  -76.486  50.572  1
198764  96.157  -76.489  50.530  1
198765  96.171  -76.492  50.489  1
198766  96.193  -76.499  50.448  1
198767  96.215  -76.506  50.410  1
198768  96.237  -76.514  50.374  1
198769  96.258  -76.520  50.338  1
198770  96.281  -76.527  50.307  1
198771  96.302  -76.535  50.280  1
198772  96.315  -76.538  50.257  1
198773  96.322  -76.538  50.234  1
198774  96.337  -76.540  50.212  1
198775  96.353  -76.542  50.192  1
198776  96.368  -76.544  50.174  1
198777  96.398  -76.563  50.155  1
198778  96.439  -76.592  50.133  1
198779  96.467  -76.613  50.111  1
198780  96.476  -76.618  50.087  1
198781  96.484  -76.624  50.062  1
198782  96.508  -76.631  50.037  1
198783  96.556  -76.643  50.010  1
198784  96.596  -76.648  49.981  1
198785  96.619  -76.646  49.948  1
198786  96.651  -76.645  49.914  1
198787  96.696  -76.636  49.878  1
198788  96.732  -76.630  49.842  1
198789  96.760  -76.627  49.806  1
198790  96.787  -76.622  49.770  1
198791  96.815  -76.618  49.736  1
198792  96.842  -76.614  49.702  1
198793  96.870  -76.612  49.668  1
198794  96.896  -76.634  49.633  1
198795  96.923  -76.656  49.598  1
198796  96.946  -76.669  49.560  1
198797  96.963  -76.672  49.523  1
198798  96.981  -76.674  49.486  1
198799  96.999  -76.677  49.451  1
198800  97.016  -76.679  49.418  1
198801  97.034  -76.681  49.386  1
198802  97.051  -76.683  49.355  1
198803  97.069  -76.687  49.328  1
198804  97.086  -76.696  49.302  1
198805  97.096  -76.717  49.277  1
198806  97.108  -76.738  49.255  1
198807  97.120  -76.759  49.235  1
198808  97.132  -76.781  49.216  1
198809  97.144  -76.802  49.196  1
198810  97.156  -76.823  49.173  1
198811  97.168  -76.844  49.148  1
198812  97.180  -76.865  49.121  1
198813  97.192  -76.887  49.093  1
198814  97.204  -76.908  49.066  1
198815  97.231  -76.929  49.038  1
198816  97.296  -76.949  49.010  1
198817  97.366  -76.953  48.983  1
198818  97.441  -76.963  48.955  1
198819  97.468  -76.997  48.927  1
198820  97.492  -77.047  48.900  1
198821  97.515  -77.095  48.873  1
198822  97.533  -77.134  48.846  1
198823  97.541  -77.150  48.820  1
198824  97.557  -77.155  48.793  1
198825  97.572  -77.160  48.766  1
198826  97.583  -77.163  48.738  1
198827  97.583  -77.144  48.710  1
198828  97.583  -77.126  48.682  1
198829  97.584  -77.108  48.654  1
198830  97.584  -77.090  48.626  1
198831  97.585  -77.081  48.597  1
198832  97.590  -77.093  48.568  1
198833  97.609  -77.099  48.538  1
198834  97.632  -77.104  48.509  1
198835  97.654  -77.110  48.478  1
198836  97.675  -77.114  48.449  1
198837  97.698  -77.119  48.420  1
198838  97.720  -77.125  48.392  1
198839  97.742  -77.129  48.364  1
198840  97.765  -77.135  48.335  1
198841  97.788  -77.141  48.307  1
198842  97.812  -77.134  48.279  1
198843  97.841  -77.122  48.250  1
198844  97.872  -77.112  48.220  1
198845  97.902  -77.102  48.191  1
198846  97.933  -77.092  48.161  1
198847  97.963  -77.081  48.130  1
198848  97.991  -77.076  48.100  1
198849  98.011  -77.081  48.069  1
198850  98.031  -77.087  48.039  1
198851  98.051  -77.092  48.008  1
198852  98.071  -77.097  47.977  1
198853  98.091  -77.103  47.945  1
198854  98.110  -77.108  47.913  1
198855  98.131  -77.113  47.880  1
198856  98.156  -77.102  47.847  1
198857  98.181  -77.089  47.815  1
198858  98.207  -77.077  47.784  1
198859  98.232  -77.064  47.753  1
198860  98.258  -77.052  47.722  1
198861  98.283  -77.041  47.692  1
198862  98.308  -77.041  47.661  1
198863  98.333  -77.041  47.631  1
198864  98.357  -77.041  47.602  1
198865  98.381  -77.041  47.573  1
198866  98.406  -77.041  47.545  1
198867  98.430  -77.039  47.518  1
198868  98.454  -77.034  47.491  1
198869  98.478  -77.028  47.465  1
198870  98.502  -77.022  47.440  1
198871  98.526  -77.016  47.414  1
198872  98.535  -77.022  47.389  1
198873  98.528  -77.040  47.365  1
198874  98.522  -77.057  47.343  1
198875  98.515  -77.075  47.320  1
198876  98.507  -77.095  47.297  1
198877  98.505  -77.115  47.274  1
198878  98.531  -77.126  47.251  1
198879  98.575  -77.135  47.226  1
198880  98.625  -77.142  47.202  1
198881  98.675  -77.149  47.179  1
198882  98.725  -77.157  47.155  1
198883  98.775  -77.163  47.130  1
198884  98.826  -77.171  47.105  1
198885  98.844  -77.184  47.080  1
198886  98.858  -77.197  47.055  1
198887  98.872  -77.211  47.032  1
198888  98.886  -77.225  47.009  1
198889  98.900  -77.238  46.987  1
198890  98.914  -77.251  46.965  1
198891  98.928  -77.262  46.940  1
198892  98.943  -77.273  46.915  1
198893  98.957  -77.284  46.889  1
198894  98.973  -77.294  46.864  1
198895  98.987  -77.306  46.838  1
198896  99.002  -77.316  46.812  1
198897  99.016  -77.328  46.787  1
198898  99.031  -77.338  46.760  1
198899  99.046  -77.349  46.733  1
198900  99.059  -77.357  46.706  1
198901  99.072  -77.363  46.680  1
198902  99.085  -77.367  46.653  1
198903  99.097  -77.373  46.628  1
198904  99.108  -77.379  46.603  1
198905  99.119  -77.384  46.577  1
198906  99.129  -77.390  46.551  1
198907  99.140  -77.395  46.527  1
198908  99.150  -77.401  46.503  1
198909  99.161  -77.407  46.480  1
198910  99.172  -77.413  46.456  1
198911  99.183  -77.418  46.432  1
198912  99.193  -77.423  46.407  1
198913  99.204  -77.429  46.383  1
198914  99.214  -77.435  46.359  1
198915  99.225  -77.441  46.335  1
198916  99.235  -77.446  46.310  1
198917  99.266  -77.451  46.287  1
198918  99.297  -77.454  46.262  1
198919  99.328  -77.458  46.237  1
198920  99.348  -77.454  46.213  1
198921  99.367  -77.450  46.191  1
198922  99.387  -77.446  46.169  1
198923  99.406  -77.442  46.147  1
198924  99.426  -77.439  46.125  1
198925  99.445  -77.434  46.103  1
198926  99.465  -77.430  46.082  1
198927  99.485  -77.426  46.062  1
198928  99.504  -77.422  46.043  1
198929  99.524  -77.418  46.024  1
198930  99.547  -77.415  46.005  1
198931  99.569  -77.412  45.986  1
198932  99.591  -77.409  45.968  1
198933  99.613  -77.407  45.951  1
198934  99.639  -77.405  45.934  1
198935  99.680  -77.410  45.917  1
198936  99.725  -77.423  45.902  1
198937  99.770  -77.436  45.888  1
198938  99.815  -77.448  45.873  1
198939  99.859  -77.461  45.859  1
198940  99.904  -77.473  45.845  1
198941  99.949  -77.486  45.831  1
198942  99.994  -77.499  45.817  1
198943  100.031  -77.511  45.803  1
198944  100.044  -77.523  45.790  1
198945  100.057  -77.535  45.777  1
198946  100.070  -77.546  45.763  1
198947  100.083  -77.558  45.751  1
198948  100.097  -77.569  45.738  1
198949  100.110  -77.580  45.725  1
198950  100.124  -77.592  45.712  1
198951  100.139  -77.603  45.698  1
198952  100.154  -77.614  45.685  1
198953  100.170  -77.626  45.673  1
198954  100.185  -77.637  45.661  1
198955  100.200  -77.649  45.648  1
198956  100.215  -77.660  45.635  1
198957  100.239  -77.671  45.622  1
198958  100.271  -77.685  45.609  1
198959  100.302  -77.699  45.597  1
198960  100.334  -77.713  45.586  1
198961  100.366  -77.727  45.574  1
198962  100.398  -77.741  45.563  1
198963  100.420  -77.746  45.550  1
198964  100.443  -77.751  45.537  1
198965  100.467  -77.761  45.523  1
198966  100.497  -77.799  45.508  1
198967  100.528  -77.838  45.494  1
198968  100.558  -77.874  45.479  1
198969  100.583  -77.896  45.464  1
198970  100.601  -77.890  45.448  1
198971  100.616  -77.871  45.432  1
198972  100.630  -77.853  45.417  1
198973  100.650  -77.858  45.403  1
198974  100.673  -77.868  45.389  1
198975  100.696  -77.879  45.374  1
198976  100.719  -77.890  45.359  1
198977  100.742  -77.900  45.345  1
198978  100.765  -77.911  45.331  1
198979  100.787  -77.923  45.318  1
198980  100.810  -77.934  45.305  1
198981  100.832  -77.946  45.292  1
198982  100.854  -77.959  45.280  1
198983  100.877  -77.971  45.267  1
198984  100.899  -77.983  45.255  1
198985  100.921  -77.994  45.244  1
198986  100.944  -78.006  45.232  1
198987  100.966  -78.018  45.220  1
198988  100.989  -78.031  45.208  1
198989  101.012  -78.034  45.195  1
198990  101.036  -78.036  45.182  1
198991  101.059  -78.039  45.169  1
198992  101.082  -78.041  45.155  1
198993  101.106  -78.052  45.141  1
198994  101.142  -78.069  45.126  1
198995  101.179  -78.086  45.111  1
198996  101.215  -78.103  45.095  1
198997  101.252  -78.119  45.081  1
198998  101.288  -78.136  45.066  1
198999  101.325  -78.152  45.051  1
199000  101.361  -78.169  45.037  1
199001  101.397  -78.185  45.022  1
199002  101.414  -78.197  45.007  1
199003  101.431  -78.207  44.992  1
199004  101.448  -78.218  44.977  1
199005  101.465  -78.229  44.962  1
199006  101.482  -78.240  44.946  1
199007  101.499  -78.250  44.930  1
199008  101.516  -78.262  44.913  1
199009  101.533  -78.272  44.896  1
199010  101.550  -78.284  44.880  1
199011  101.573  -78.296  44.865  1
199012  101.597  -78.310  44.849  1
199013  101.622  -78.322  44.834  1
199014  101.646  -78.336  44.819  1
199015  101.671  -78.349  44.803  1
199016  101.695  -78.363  44.788  1
199017  101.720  -78.376  44.773  1
199018  101.744  -78.388  44.757  1
199019  101.768  -78.402  44.743  1
199020  101.793  -78.415  44.728  1
199021  101.818  -78.429  44.712  1
199022  101.848  -78.444  44.697  1
199023  101.878  -78.464  44.682  1
199024  101.907  -78.485  44.668  1
199025  101.937  -78.505  44.653  1
199026  101.982  -78.529  44.637  1
199027  102.028  -78.551  44.621  1
199028  102.073  -78.575  44.605  1
199029  102.118  -78.598  44.590  1
199030  102.164  -78.620  44.574  1
199031  102.209  -78.644  44.559  1
199032  102.254  -78.667  44.543  1
199033  102.300  -78.689  44.528  1
199034  102.345  -78.714  44.513  1
199035  102.388  -78.745  44.498  1
199036  102.424  -78.769  44.483  1
199037  102.444  -78.771  44.468  1
199038  102.463  -78.772  44.453  1
199039  102.483  -78.774  44.439  1
199040  102.502  -78.775  44.424  1
199041  102.522  -78.777  44.409  1
199042  102.541  -78.779  44.394  1
199043  102.560  -78.780  44.380  1
199044  102.580  -78.782  44.366  1
199045  102.599  -78.783  44.351  1
199046  102.617  -78.785  44.336  1
199047  102.633  -78.787  44.321  1
199048  102.649  -78.789  44.306  1
199333  93.538  -76.154  54.034  1
199334  93.557  -76.157  54.047  1
199335  93.575  -76.160  54.060  1
199336  93.593  -76.163  54.071  1
199337  93.612  -76.165  54.080  1
199338  93.630  -76.169  54.091  1
199339  93.648  -76.172  54.103  1
199340  93.666  -76.175  54.115  1
199341  93.685  -76.179  54.127  1
199342  93.700  -76.188  54.141  1
199343  93.704  -76.221  54.154  1
199344  93.708  -76.254  54.166  1
199345  93.740  -76.246  54.178  1
199346  93.771  -76.233  54.187  1
199347  93.803  -76.220  54.196  1
199348  93.836  -76.207  54.206  1
199349  93.868  -76.194  54.218  1
199350  93.888  -76.185  54.227  1
199351  93.905  -76.178  54.237  1
199352  93.915  -76.171  54.248  1
199353  93.918  -76.165  54.259  1
199354  93.920  -76.159  54.270  1
199355  93.939  -76.153  54.281  1
199356  93.960  -76.148  54.291  1
199357  93.982  -76.143  54.293  1
199358  94.012  -76.144  54.294  1
199359  94.043  -76.147  54.295  1
199360  94.073  -76.148  54.296  1
199361  94.104  -76.150  54.296  1
199362  94.133  -76.151  54.297  1
199363  94.161  -76.151  54.294  1
199364  94.191  -76.151  54.286  1
199365  94.213  -76.146  54.270  1
199366  94.235  -76.141  54.253  1
199367  94.254  -76.138  54.235  1
199368  94.271  -76.135  54.213  1
199369  94.289  -76.132  54.190  1
199370  94.308  -76.130  54.162  1
199371  94.325  -76.127  54.131  1
199372  94.343  -76.125  54.098  1
199373  94.361  -76.122  54.066  1
199374  94.379  -76.119  54.034  1
199375  94.397  -76.117  54.001  1
199376  94.415  -76.115  53.968  1
199377  94.433  -76.113  53.932  1
199378  94.448  -76.113  53.895  1
199379  94.459  -76.114  53.858  1
199380  94.471  -76.115  53.826  1
199381  94.482  -76.116  53.797  1
199382  94.494  -76.117  53.771  1
199383  94.505  -76.119  53.749  1
199384  94.518  -76.120  53.722  1
199385  94.532  -76.127  53.697  1
199386  94.546  -76.135  53.675  1
199387  94.560  -76.141  53.656  1
199388  94.574  -76.148  53.635  1
199389  94.592  -76.158  53.611  1
199390  94.613  -76.169  53.584  1
199391  94.634  -76.182  53.549  1
199392  94.655  -76.193  53.516  1
199393  94.669  -76.200  53.483  1
199394  94.680  -76.204  53.451  1
199395  94.691  -76.210  53.420  1
199396  94.702  -76.215  53.391  1
199397  94.713  -76.220  53.360  1
199398  94.724  -76.225  53.323  1
199399  94.736  -76.230  53.285  1
199400  94.747  -76.235  53.247  1
199401  94.758  -76.240  53.210  1
199402  94.769  -76.245  53.175  1
199403  94.780  -76.251  53.139  1
199404  94.791  -76.256  53.101  1
199405  94.802  -76.260  53.062  1
199406  94.813  -76.266  53.021  1
199407  94.824  -76.271  52.979  1
199408  94.835  -76.276  52.938  1
199409  94.846  -76.281  52.897  1
199410  94.857  -76.286  52.854  1
199411  94.870  -76.290  52.810  1
199412  94.883  -76.294  52.765  1
199413  94.895  -76.297  52.721  1
199414  94.908  -76.301  52.677  1
199415  94.920  -76.304  52.633  1
199416  94.933  -76.308  52.590  1
199417  94.946  -76.311  52.548  1
199418  94.933  -76.333  52.503  1
199419  94.919  -76.356  52.458  1
199420  94.944  -76.363  52.412  1
199421  94.972  -76.367  52.365  1
199422  95.022  -76.363  52.321  1
199423  95.071  -76.358  52.276  1
199424  95.120  -76.353  52.231  1
199425  95.170  -76.348  52.183  1
199426  95.219  -76.344  52.135  1
199427  95.269  -76.339  52.087  1
199428  95.318  -76.335  52.041  1
199429  95.365  -76.331  51.998  1
199430  95.388  -76.336  51.956  1
199431  95.411  -76.340  51.914  1
199432  95.434  -76.345  51.872  1
199433  95.457  -76.350  51.829  1
199434  95.480  -76.354  51.787  1
199435  95.503  -76.359  51.746  1
199436  95.527  -76.364  51.708  1
199437  95.550  -76.368  51.675  1
199438  95.573  -76.373  51.644  1
199439  95.596  -76.378  51.614  1
199440  95.621  -76.379  51.583  1
199441  95.647  -76.381  51.552  1
199442  95.672  -76.383  51.520  1
199443  95.698  -76.384  51.488  1
199444  95.724  -76.386  51.454  1
199445  95.756  -76.426  51.414  1
199446  95.782  -76.429  51.369  1
199447  95.809  -76.432  51.321  1
199448  95.834  -76.432  51.271  1
199449  95.858  -76.430  51.224  1
199450  95.881  -76.428  51.177  1
199451  95.904  -76.426  51.131  1
199452  95.926  -76.430  51.089  1
199453  95.948  -76.433  51.045  1
199454  95.970  -76.436  51.001  1
199455  95.992  -76.439  50.956  1
199456  96.014  -76.439  50.911  1
199457  96.035  -76.439  50.867  1
199458  96.053  -76.443  50.823  1
199459  96.066  -76.451  50.783  1
199460  96.080  -76.458  50.744  1
199461  96.095  -76.463  50.706  1
199462  96.114  -76.462  50.671  1
199463  96.133  -76.462  50.634  1
199464  96.151  -76.463  50.594  1
199465  96.164  -76.466  50.554  1
199466  96.177  -76.469  50.515  1
199467  96.194  -76.473  50.475  1
199468  96.216  -76.480  50.437  1
199469  96.238  -76.487  50.400  1
199470  96.260  -76.495  50.364  1
199471  96.282  -76.502  50.333  1
199472  96.304  -76.508  50.307  1
199473  96.310  -76.508  50.283  1
199474  96.315  -76.508  50.259  1
199475  96.326  -76.509  50.237  1
199476  96.341  -76.511  50.217  1
199477  96.361  -76.518  50.198  1
199478  96.402  -76.548  50.178  1
199479  96.443  -76.578  50.155  1
199480  96.476  -76.602  50.132  1
199481  96.484  -76.607  50.109  1
199482  96.493  -76.612  50.084  1
199483  96.536  -76.623  50.059  1
199484  96.578  -76.630  50.032  1
199485  96.597  -76.621  50.003  1
199486  96.622  -76.624  49.971  1
199487  96.653  -76.624  49.937  1
199488  96.698  -76.616  49.901  1
199489  96.744  -76.608  49.864  1
199490  96.781  -76.601  49.827  1
199491  96.808  -76.597  49.791  1
199492  96.835  -76.593  49.755  1
199493  96.863  -76.589  49.721  1
199494  96.890  -76.586  49.685  1
199495  96.918  -76.608  49.650  1
199496  96.944  -76.630  49.614  1
199497  96.963  -76.635  49.576  1
199498  96.980  -76.637  49.538  1
199499  96.998  -76.640  49.501  1
199500  97.016  -76.642  49.465  1
199501  97.033  -76.644  49.432  1
199502  97.051  -76.647  49.400  1
199503  97.067  -76.649  49.369  1
199504  97.061  -76.657  49.341  1
199505  97.087  -76.684  49.316  1
199506  97.115  -76.690  49.293  1
199507  97.127  -76.712  49.271  1
199508  97.140  -76.733  49.251  1
199509  97.152  -76.754  49.233  1
199510  97.164  -76.775  49.213  1
199511  97.175  -76.796  49.191  1
199512  97.187  -76.818  49.167  1
199513  97.199  -76.839  49.140  1
199514  97.212  -76.860  49.112  1
199515  97.224  -76.881  49.085  1
199516  97.242  -76.903  49.057  1
199517  97.307  -76.925  49.029  1
199518  97.374  -76.939  49.001  1
199519  97.444  -76.943  48.972  1
199520  97.478  -76.981  48.944  1
199521  97.502  -77.030  48.917  1
199522  97.521  -77.071  48.890  1
199523  97.529  -77.087  48.863  1
199524  97.537  -77.103  48.836  1
199525  97.545  -77.119  48.809  1
199526  97.563  -77.119  48.781  1
199527  97.583  -77.119  48.753  1
199528  97.595  -77.125  48.725  1
199529  97.596  -77.108  48.696  1
199530  97.596  -77.090  48.668  1
199531  97.597  -77.072  48.639  1
199532  97.598  -77.064  48.610  1
199533  97.608  -77.075  48.580  1
199534  97.630  -77.079  48.550  1
199535  97.652  -77.085  48.521  1
199536  97.674  -77.090  48.490  1
199537  97.697  -77.094  48.460  1
199538  97.719  -77.100  48.431  1
199539  97.742  -77.106  48.404  1
199540  97.765  -77.111  48.375  1
199541  97.788  -77.117  48.346  1
199542  97.811  -77.122  48.318  1
199543  97.836  -77.117  48.290  1
199544  97.860  -77.101  48.261  1
199545  97.890  -77.090  48.231  1
199546  97.920  -77.080  48.202  1
199547  97.951  -77.069  48.172  1
199548  97.981  -77.059  48.141  1
199549  98.008  -77.055  48.110  1
199550  98.028  -77.060  48.078  1
199551  98.048  -77.066  48.048  1
199552  98.068  -77.072  48.017  1
199553  98.088  -77.077  47.986  1
199554  98.108  -77.082  47.954  1
199555  98.128  -77.088  47.921  1
199556  98.148  -77.093  47.889  1
199557  98.168  -77.098  47.856  1
199558  98.193  -77.088  47.824  1
199559  98.218  -77.075  47.793  1
199560  98.244  -77.063  47.762  1
199561  98.269  -77.050  47.733  1
199562  98.294  -77.045  47.702  1
199563  98.318  -77.045  47.671  1
199564  98.343  -77.045  47.641  1
199565  98.367  -77.044  47.612  1
199566  98.392  -77.043  47.583  1
199567  98.416  -77.038  47.555  1
199568  98.440  -77.032  47.527  1
199569  98.464  -77.026  47.501  1
199570  98.488  -77.021  47.476  1
199571  98.512  -77.015  47.451  1
199572  98.536  -77.009  47.425  1
199573  98.550  -77.012  47.400  1
199574  98.543  -77.029  47.377  1
199575  98.536  -77.047  47.354  1
199576  98.530  -77.064  47.332  1
199577  98.523  -77.081  47.309  1
199578  98.516  -77.100  47.285  1
199579  98.538  -77.112  47.260  1
199580  98.589  -77.119  47.234  1
199581  98.639  -77.125  47.212  1
199582  98.689  -77.133  47.189  1
199583  98.739  -77.140  47.164  1
199584  98.789  -77.147  47.139  1
199585  98.839  -77.154  47.114  1
199586  98.856  -77.167  47.088  1
199587  98.870  -77.181  47.062  1
199588  98.883  -77.194  47.037  1
199589  98.898  -77.209  47.014  1
199590  98.911  -77.222  46.992  1
199591  98.925  -77.236  46.968  1
199592  98.940  -77.248  46.944  1
199593  98.954  -77.259  46.919  1
199594  98.969  -77.269  46.893  1
199595  98.984  -77.281  46.868  1
199596  98.998  -77.291  46.842  1
199597  99.013  -77.302  46.816  1
199598  99.027  -77.313  46.790  1
199599  99.042  -77.324  46.764  1
199600  99.057  -77.335  46.736  1
199601  99.070  -77.342  46.707  1
199602  99.083  -77.347  46.680  1
199603  99.095  -77.352  46.654  1
199604  99.109  -77.357  46.628  1
199605  99.121  -77.362  46.602  1
199606  99.132  -77.367  46.575  1
199607  99.143  -77.373  46.550  1
199608  99.153  -77.379  46.525  1
199609  99.164  -77.385  46.501  1
199610  99.174  -77.390  46.477  1
199611  99.186  -77.396  46.454  1
199612  99.196  -77.401  46.429  1
199613  99.207  -77.407  46.405  1
199614  99.217  -77.413  46.379  1
199615  99.228  -77.419  46.355  1
199616  99.238  -77.424  46.331  1
199617  99.262  -77.429  46.307  1
199618  99.293  -77.433  46.284  1
199619  99.325  -77.437  46.260  1
199620  99.356  -77.442  46.235  1
199621  99.388  -77.445  46.211  1
199622  99.412  -77.445  46.189  1
199623  99.432  -77.441  46.166  1
199624  99.451  -77.436  46.145  1
199625  99.471  -77.432  46.123  1
199626  99.490  -77.429  46.101  1
199627  99.510  -77.424  46.080  1
199628  99.529  -77.420  46.059  1
199629  99.549  -77.417  46.041  1
199630  99.569  -77.413  46.022  1
199631  99.588  -77.408  46.003  1
199632  99.608  -77.404  45.985  1
199633  99.627  -77.401  45.967  1
199634  99.647  -77.396  45.950  1
199635  99.666  -77.392  45.933  1
199636  99.689  -77.395  45.917  1
199637  99.733  -77.407  45.901  1
199638  99.778  -77.420  45.887  1
199639  99.823  -77.433  45.872  1
199640  99.868  -77.445  45.857  1
199641  99.913  -77.458  45.844  1
199642  99.958  -77.471  45.830  1
199643  100.002  -77.484  45.816  1
199644  100.047  -77.497  45.802  1
199645  100.066  -77.508  45.790  1
199646  100.079  -77.520  45.776  1
199647  100.092  -77.531  45.762  1
199648  100.105  -77.542  45.749  1
199649  100.118  -77.554  45.736  1
199650  100.132  -77.566  45.723  1
199651  100.147  -77.577  45.709  1
199652  100.162  -77.589  45.696  1
199653  100.177  -77.600  45.683  1
199654  100.193  -77.611  45.670  1
199655  100.208  -77.623  45.658  1
199656  100.225  -77.632  45.644  1
199657  100.244  -77.639  45.632  1
199658  100.263  -77.653  45.619  1
199659  100.294  -77.667  45.606  1
199660  100.327  -77.681  45.593  1
199661  100.358  -77.695  45.581  1
199662  100.390  -77.709  45.570  1
199663  100.419  -77.720  45.558  1
199664  100.441  -77.725  45.545  1
199665  100.464  -77.730  45.532  1
199666  100.487  -77.735  45.518  1
199667  100.509  -77.740  45.504  1
199668  100.531  -77.746  45.489  1
199669  100.561  -77.777  45.474  1
199670  100.592  -77.815  45.459  1
199671  100.618  -77.835  45.443  1
199672  100.635  -77.822  45.427  1
199673  100.656  -77.823  45.412  1
199674  100.682  -77.843  45.398  1
199675  100.704  -77.855  45.384  1
199676  100.727  -77.867  45.370  1
199677  100.749  -77.879  45.356  1
199678  100.772  -77.891  45.341  1
199679  100.794  -77.902  45.328  1
199680  100.816  -77.915  45.315  1
199681  100.839  -77.927  45.301  1
199682  100.861  -77.939  45.289  1
199683  100.884  -77.951  45.276  1
199684  100.906  -77.962  45.265  1
199685  100.928  -77.975  45.253  1
199686  100.951  -77.987  45.241  1
199687  100.973  -77.999  45.230  1
199688  100.995  -78.010  45.218  1
199689  101.018  -78.022  45.206  1
199690  101.041  -78.028  45.192  1
199691  101.064  -78.031  45.179  1
199692  101.088  -78.033  45.166  1
199693  101.109  -78.035  45.153  1
199694  101.118  -78.037  45.138  1
199695  101.157  -78.057  45.124  1
199696  101.195  -78.075  45.109  1
199697  101.231  -78.092  45.093  1
199698  101.267  -78.109  45.079  1
199699  101.304  -78.125  45.064  1
199700  101.340  -78.142  45.049  1
199701  101.377  -78.159  45.033  1
199702  101.413  -78.175  45.018  1
199703  101.434  -78.188  45.003  1
199704  101.452  -78.199  44.988  1
199705  101.469  -78.210  44.974  1
199706  101.485  -78.220  44.958  1
199707  101.502  -78.232  44.943  1
199708  101.519  -78.242  44.926  1
199709  101.536  -78.253  44.909  1
199710  101.553  -78.264  44.893  1
199711  101.575  -78.276  44.876  1
199712  101.600  -78.290  44.859  1
199713  101.624  -78.303  44.844  1
199714  101.649  -78.316  44.829  1
199715  101.673  -78.329  44.814  1
199716  101.698  -78.343  44.798  1
199717  101.723  -78.356  44.784  1
199718  101.747  -78.369  44.770  1
199719  101.771  -78.382  44.755  1
199720  101.796  -78.395  44.740  1
199721  101.820  -78.409  44.724  1
199722  101.845  -78.422  44.709  1
199723  101.869  -78.435  44.694  1
199724  101.894  -78.448  44.680  1
199725  101.923  -78.467  44.665  1
199726  101.954  -78.487  44.649  1
199727  101.999  -78.510  44.634  1
199728  102.044  -78.533  44.618  1
199729  102.090  -78.556  44.602  1
199730  102.135  -78.579  44.587  1
199731  102.180  -78.602  44.572  1
199732  102.226  -78.625  44.557  1
199733  102.271  -78.648  44.541  1
199734  102.316  -78.671  44.526  1
199735  102.362  -78.694  44.511  1
199736  102.406  -78.720  44.495  1
199737  102.450  -78.752  44.480  1
199738  102.469  -78.753  44.466  1
199739  102.488  -78.755  44.450  1
199740  102.508  -78.756  44.436  1
199741  102.527  -78.758  44.421  1
199742  102.547  -78.760  44.407  1
199743  102.566  -78.761  44.391  1
199744  102.586  -78.763  44.377  1
199745  102.601  -78.765  44.362  1
199746  102.616  -78.767  44.348  1
199747  102.632  -78.770  44.333  1
199748  102.647  -78.772  44.317  1
199749  102.663  -78.774  44.302  1
200034  93.530  -76.130  54.027  1
200035  93.549  -76.133  54.039  1
200036  93.567  -76.136  54.052  1
200037  93.585  -76.139  54.064  1
200038  93.604  -76.142  54.075  1
200039  93.622  -76.145  54.087  1
200040  93.640  -76.148  54.100  1
200041  93.658  -76.152  54.112  1
200042  93.677  -76.155  54.125  1
200043  93.693  -76.163  54.140  1
200044  93.697  -76.197  54.152  1
200045  93.701  -76.231  54.165  1
200046  93.737  -76.216  54.180  1
200047  93.769  -76.204  54.190  1
200048  93.801  -76.190  54.200  1
200049  93.834  -76.177  54.211  1
200050  93.854  -76.169  54.223  1
200051  93.872  -76.161  54.233  1
200052  93.890  -76.154  54.243  1
200053  93.899  -76.147  54.254  1
200054  93.902  -76.141  54.268  1
200055  93.920  -76.135  54.280  1
200056  93.941  -76.130  54.291  1
200057  93.962  -76.125  54.301  1
200058  93.984  -76.120  54.305  1
200059  94.014  -76.122  54.307  1
200060  94.045  -76.124  54.308  1
200061  94.076  -76.126  54.310  1
200062  94.107  -76.128  54.310  1
200063  94.137  -76.129  54.311  1
200064  94.166  -76.129  54.308  1
200065  94.195  -76.130  54.299  1
200066  94.217  -76.125  54.283  1
200067  94.237  -76.121  54.265  1
200068  94.254  -76.118  54.245  1
200069  94.272  -76.116  54.222  1
200070  94.290  -76.113  54.197  1
200071  94.308  -76.110  54.169  1
200072  94.326  -76.108  54.137  1
200073  94.344  -76.105  54.103  1
200074  94.362  -76.103  54.069  1
200075  94.380  -76.100  54.036  1
200076  94.398  -76.097  54.003  1
200077  94.416  -76.095  53.969  1
200078  94.434  -76.093  53.932  1
200079  94.449  -76.093  53.895  1
200080  94.461  -76.094  53.858  1
200081  94.472  -76.094  53.825  1
200082  94.484  -76.096  53.795  1
200083  94.495  -76.097  53.767  1
200084  94.508  -76.100  53.743  1
200085  94.522  -76.107  53.714  1
200086  94.536  -76.114  53.689  1
200087  94.550  -76.121  53.667  1
200088  94.564  -76.129  53.648  1
200089  94.578  -76.135  53.628  1
200090  94.594  -76.143  53.606  1
200091  94.615  -76.155  53.580  1
200092  94.636  -76.166  53.546  1
200093  94.657  -76.178  53.513  1
200094  94.669  -76.184  53.480  1
200095  94.680  -76.189  53.449  1
200096  94.691  -76.194  53.420  1
200097  94.702  -76.199  53.390  1
200098  94.713  -76.204  53.359  1
200099  94.725  -76.210  53.324  1
200100  94.736  -76.214  53.288  1
200101  94.747  -76.220  53.252  1
200102  94.758  -76.225  53.216  1
200103  94.769  -76.230  53.181  1
200104  94.780  -76.235  53.145  1
200105  94.791  -76.240  53.108  1
200106  94.803  -76.245  53.069  1
200107  94.814  -76.250  53.029  1
200108  94.825  -76.255  52.989  1
200109  94.836  -76.260  52.948  1
200110  94.847  -76.266  52.907  1
200111  94.858  -76.270  52.866  1
200112  94.869  -76.276  52.822  1
200113  94.881  -76.280  52.778  1
200114  94.894  -76.284  52.733  1
200115  94.906  -76.288  52.688  1
200116  94.919  -76.291  52.644  1
200117  94.931  -76.295  52.600  1
200118  94.944  -76.298  52.556  1
200119  94.932  -76.320  52.513  1
200120  94.919  -76.342  52.469  1
200121  94.933  -76.352  52.425  1
200122  94.969  -76.354  52.380  1
200123  95.018  -76.350  52.338  1
200124  95.067  -76.345  52.295  1
200125  95.117  -76.340  52.252  1
200126  95.167  -76.336  52.205  1
200127  95.216  -76.331  52.157  1
200128  95.265  -76.326  52.109  1
200129  95.315  -76.321  52.061  1
200130  95.365  -76.317  52.019  1
200131  95.392  -76.320  51.978  1
200132  95.415  -76.325  51.938  1
200133  95.438  -76.329  51.898  1
200134  95.461  -76.334  51.853  1
200135  95.484  -76.339  51.809  1
200136  95.508  -76.343  51.767  1
200137  95.531  -76.348  51.727  1
200138  95.554  -76.353  51.691  1
200139  95.577  -76.357  51.658  1
200140  95.602  -76.360  51.628  1
200141  95.627  -76.361  51.598  1
200142  95.653  -76.363  51.568  1
200143  95.678  -76.364  51.538  1
200144  95.704  -76.366  51.508  1
200145  95.730  -76.367  51.475  1
200146  95.760  -76.393  51.434  1
200147  95.786  -76.396  51.388  1
200148  95.812  -76.399  51.338  1
200149  95.839  -76.402  51.288  1
200150  95.864  -76.403  51.239  1
200151  95.886  -76.404  51.192  1
200152  95.908  -76.408  51.146  1
200153  95.930  -76.411  51.104  1
200154  95.952  -76.414  51.059  1
200155  95.974  -76.417  51.013  1
200156  95.996  -76.420  50.968  1
200157  96.018  -76.421  50.925  1
200158  96.039  -76.421  50.881  1
200159  96.055  -76.426  50.839  1
200160  96.068  -76.434  50.800  1
200161  96.083  -76.439  50.762  1
200162  96.103  -76.439  50.725  1
200163  96.122  -76.439  50.690  1
200164  96.142  -76.438  50.654  1
200165  96.157  -76.439  50.616  1
200166  96.170  -76.442  50.578  1
200167  96.184  -76.445  50.539  1
200168  96.197  -76.448  50.501  1
200169  96.217  -76.454  50.462  1
200170  96.239  -76.461  50.425  1
200171  96.261  -76.468  50.390  1
200172  96.283  -76.475  50.359  1
200173  96.300  -76.480  50.332  1
200174  96.304  -76.480  50.308  1
200175  96.309  -76.479  50.284  1
200176  96.316  -76.479  50.262  1
200177  96.331  -76.481  50.242  1
200178  96.365  -76.503  50.222  1
200179  96.406  -76.533  50.200  1
200180  96.447  -76.563  50.177  1
200181  96.484  -76.590  50.154  1
200182  96.492  -76.596  50.131  1
200183  96.516  -76.603  50.107  1
200184  96.559  -76.611  50.082  1
200185  96.576  -76.599  50.055  1
200186  96.601  -76.599  50.026  1
200187  96.626  -76.602  49.993  1
200188  96.655  -76.603  49.959  1
200189  96.701  -76.595  49.924  1
200190  96.746  -76.586  49.886  1
200191  96.792  -76.578  49.849  1
200192  96.829  -76.572  49.811  1
200193  96.857  -76.568  49.774  1
200194  96.884  -76.564  49.739  1
200195  96.911  -76.560  49.703  1
200196  96.938  -76.581  49.667  1
200197  96.962  -76.598  49.629  1
200198  96.980  -76.600  49.592  1
200199  96.998  -76.602  49.553  1
200200  97.015  -76.605  49.516  1
200201  97.033  -76.607  49.480  1
200202  97.050  -76.610  49.447  1
200203  97.045  -76.617  49.414  1
200204  97.038  -76.624  49.384  1
200205  97.070  -76.644  49.355  1
200206  97.085  -76.673  49.331  1
200207  97.103  -76.698  49.308  1
200208  97.141  -76.691  49.287  1
200209  97.159  -76.706  49.267  1
200210  97.171  -76.727  49.249  1
200211  97.183  -76.749  49.230  1
200212  97.195  -76.770  49.209  1
200213  97.207  -76.791  49.185  1
200214  97.219  -76.812  49.159  1
200215  97.231  -76.834  49.132  1
200216  97.243  -76.855  49.104  1
200217  97.255  -76.876  49.076  1
200218  97.318  -76.898  49.048  1
200219  97.383  -76.919  49.019  1
200220  97.452  -76.928  48.990  1
200221  97.488  -76.965  48.961  1
200222  97.509  -77.008  48.933  1
200223  97.517  -77.024  48.906  1
200224  97.525  -77.040  48.879  1
200225  97.532  -77.056  48.852  1
200226  97.540  -77.072  48.824  1
200227  97.549  -77.087  48.797  1
200228  97.570  -77.085  48.768  1
200229  97.591  -77.081  48.739  1
200230  97.607  -77.085  48.710  1
200231  97.609  -77.071  48.680  1
200232  97.609  -77.053  48.651  1
200233  97.612  -77.047  48.623  1
200234  97.629  -77.055  48.594  1
200235  97.651  -77.059  48.563  1
200236  97.673  -77.065  48.533  1
200237  97.696  -77.070  48.503  1
200238  97.719  -77.075  48.474  1
200239  97.742  -77.081  48.444  1
200240  97.765  -77.087  48.416  1
200241  97.788  -77.093  48.387  1
200242  97.811  -77.098  48.357  1
200243  97.835  -77.104  48.328  1
200244  97.859  -77.100  48.300  1
200245  97.883  -77.085  48.271  1
200246  97.909  -77.068  48.242  1
200247  97.938  -77.057  48.213  1
200248  97.969  -77.047  48.182  1
200249  97.999  -77.038  48.151  1
200250  98.025  -77.034  48.119  1
200251  98.045  -77.040  48.088  1
200252  98.065  -77.045  48.056  1
200253  98.085  -77.050  48.024  1
200254  98.105  -77.056  47.993  1
200255  98.125  -77.061  47.960  1
200256  98.145  -77.066  47.928  1
200257  98.165  -77.072  47.897  1
200258  98.185  -77.078  47.865  1
200259  98.205  -77.083  47.833  1
200260  98.229  -77.073  47.801  1
200261  98.255  -77.060  47.770  1
200262  98.280  -77.049  47.740  1
200263  98.305  -77.049  47.710  1
200264  98.329  -77.049  47.681  1
200265  98.354  -77.047  47.652  1
200266  98.378  -77.041  47.623  1
200267  98.402  -77.036  47.595  1
200268  98.426  -77.031  47.567  1
200269  98.450  -77.025  47.540  1
200270  98.474  -77.019  47.514  1
200271  98.498  -77.013  47.488  1
200272  98.522  -77.008  47.462  1
200273  98.546  -77.002  47.437  1
200274  98.565  -77.000  47.412  1
200275  98.558  -77.019  47.389  1
200276  98.551  -77.036  47.366  1
200277  98.545  -77.053  47.344  1
200278  98.537  -77.071  47.320  1
200279  98.531  -77.088  47.295  1
200280  98.553  -77.095  47.270  1
200281  98.602  -77.102  47.245  1
200282  98.652  -77.110  47.223  1
200283  98.702  -77.116  47.199  1
200284  98.752  -77.123  47.174  1
200285  98.802  -77.131  47.148  1
200286  98.852  -77.138  47.122  1
200287  98.867  -77.151  47.095  1
200288  98.881  -77.165  47.068  1
200289  98.895  -77.179  47.042  1
200290  98.909  -77.192  47.018  1
200291  98.923  -77.206  46.995  1
200292  98.937  -77.219  46.971  1
200293  98.951  -77.234  46.947  1
200294  98.966  -77.244  46.922  1
200295  98.980  -77.255  46.897  1
200296  98.995  -77.266  46.872  1
200297  99.009  -77.277  46.846  1
200298  99.024  -77.288  46.820  1
200299  99.039  -77.299  46.793  1
200300  99.053  -77.310  46.766  1
200301  99.068  -77.321  46.737  1
200302  99.081  -77.326  46.708  1
200303  99.093  -77.332  46.681  1
200304  99.106  -77.336  46.654  1
200305  99.119  -77.341  46.628  1
200306  99.132  -77.346  46.601  1
200307  99.145  -77.351  46.574  1
200308  99.156  -77.357  46.549  1
200309  99.167  -77.363  46.524  1
200310  99.178  -77.368  46.499  1
200311  99.188  -77.374  46.475  1
200312  99.199  -77.379  46.451  1
200313  99.210  -77.385  46.427  1
200314  99.220  -77.391  46.402  1
200315  99.231  -77.397  46.376  1
200316  99.241  -77.402  46.352  1
200317  99.257  -77.407  46.328  1
200318  99.289  -77.411  46.304  1
200319  99.321  -77.416  46.281  1
200320  99.352  -77.420  46.257  1
200321  99.384  -77.424  46.233  1
200322  99.415  -77.428  46.209  1
200323  99.447  -77.432  46.186  1
200324  99.477  -77.435  46.164  1
200325  99.496  -77.431  46.142  1
200326  99.516  -77.427  46.120  1
200327  99.536  -77.423  46.099  1
200328  99.555  -77.419  46.078  1
200329  99.574  -77.415  46.057  1
200330  99.594  -77.410  46.039  1
200331  99.614  -77.407  46.020  1
200332  99.633  -77.403  46.001  1
200333  99.653  -77.398  45.983  1
200334  99.673  -77.395  45.965  1
200335  99.688  -77.389  45.948  1
200336  99.699  -77.380  45.932  1
200337  99.717  -77.378  45.916  1
200338  99.751  -77.392  45.900  1
200339  99.787  -77.405  45.886  1
200340  99.832  -77.417  45.871  1
200341  99.876  -77.430  45.856  1
200342  99.921  -77.443  45.843  1
200343  99.966  -77.456  45.828  1
200344  100.011  -77.469  45.814  1
200345  100.056  -77.481  45.800  1
200346  100.087  -77.494  45.788  1
200347  100.101  -77.505  45.774  1
200348  100.114  -77.517  45.760  1
200349  100.127  -77.528  45.746  1
200350  100.140  -77.539  45.734  1
200351  100.154  -77.551  45.721  1
200352  100.170  -77.562  45.707  1
200353  100.185  -77.573  45.693  1
200354  100.200  -77.585  45.681  1
200355  100.216  -77.596  45.668  1
200356  100.234  -77.603  45.654  1
200357  100.253  -77.611  45.641  1
200358  100.271  -77.618  45.628  1
200359  100.290  -77.634  45.615  1
200360  100.319  -77.649  45.603  1
200361  100.350  -77.663  45.590  1
200362  100.382  -77.677  45.577  1
200363  100.414  -77.690  45.565  1
200364  100.440  -77.699  45.552  1
200365  100.463  -77.704  45.540  1
200366  100.485  -77.709  45.527  1
200367  100.508  -77.714  45.513  1
200368  100.531  -77.720  45.499  1
200369  100.553  -77.725  45.485  1
200370  100.575  -77.730  45.469  1
200371  100.598  -77.735  45.453  1
200372  100.624  -77.754  45.438  1
200373  100.648  -77.764  45.424  1
200374  100.676  -77.790  45.410  1
200375  100.703  -77.816  45.395  1
200376  100.732  -77.842  45.380  1
200377  100.756  -77.859  45.366  1
200378  100.778  -77.871  45.352  1
200379  100.800  -77.883  45.338  1
200380  100.823  -77.895  45.324  1
200381  100.845  -77.907  45.311  1
200382  100.867  -77.919  45.298  1
200383  100.890  -77.931  45.285  1
200384  100.912  -77.943  45.273  1
200385  100.934  -77.955  45.261  1
200386  100.957  -77.967  45.250  1
200387  100.979  -77.978  45.239  1
200388  101.001  -77.990  45.227  1
200389  101.024  -78.003  45.215  1
200390  101.046  -78.015  45.203  1
200391  101.069  -78.022  45.189  1
200392  101.093  -78.025  45.176  1
200393  101.116  -78.027  45.163  1
200394  101.135  -78.028  45.150  1
200395  101.140  -78.028  45.135  1
200396  101.170  -78.043  45.121  1
200397  101.208  -78.063  45.106  1
200398  101.247  -78.082  45.090  1
200399  101.283  -78.099  45.076  1
200400  101.320  -78.116  45.061  1
200401  101.356  -78.132  45.046  1
200402  101.392  -78.149  45.031  1
200403  101.429  -78.166  45.015  1
200404  101.455  -78.179  45.000  1
200405  101.472  -78.190  44.986  1
200406  101.489  -78.200  44.970  1
200407  101.506  -78.212  44.954  1
200408  101.523  -78.222  44.937  1
200409  101.540  -78.234  44.922  1
200410  101.557  -78.244  44.905  1
200411  101.579  -78.257  44.888  1
200412  101.603  -78.270  44.872  1
200413  101.627  -78.283  44.855  1
200414  101.652  -78.297  44.839  1
200415  101.676  -78.310  44.823  1
200416  101.701  -78.322  44.808  1
200417  101.725  -78.336  44.793  1
200418  101.750  -78.349  44.779  1
200419  101.774  -78.363  44.765  1
200420  101.799  -78.376  44.750  1
200421  101.823  -78.389  44.735  1
200422  101.847  -78.402  44.720  1
200423  101.872  -78.415  44.705  1
200424  101.896  -78.429  44.690  1
200425  101.921  -78.442  44.677  1
200426  101.945  -78.455  44.662  1
200427  101.970  -78.468  44.646  1
200428  102.016  -78.492  44.630  1
200429  102.061  -78.514  44.614  1
200430  102.106  -78.537  44.599  1
200431  102.152  -78.561  44.583  1
200432  102.197  -78.583  44.568  1
200433  102.242  -78.606  44.553  1
200434  102.287  -78.630  44.539  1
200435  102.333  -78.652  44.523  1
200436  102.378  -78.676  44.507  1
200437  102.423  -78.698  44.492  1
200438  102.468  -78.726  44.477  1
200439  102.494  -78.736  44.462  1
200440  102.514  -78.737  44.446  1
200441  102.533  -78.739  44.432  1
200442  102.552  -78.740  44.417  1
200443  102.569  -78.742  44.402  1
200444  102.585  -78.745  44.388  1
200445  102.600  -78.747  44.373  1
200446  102.615  -78.749  44.358  1
200447  102.631  -78.752  44.343  1
200448  102.647  -78.754  44.328  1
200449  102.662  -78.756  44.313  1
200450  102.677  -78.758  44.298  1
200735  93.522  -76.107  54.019  1
200736  93.541  -76.110  54.032  1
200737  93.559  -76.113  54.046  1
200738  93.577  -76.116  54.058  1
200739  93.595  -76.119  54.070  1
200740  93.614  -76.122  54.083  1
200741  93.632  -76.126  54.096  1
200742  93.650  -76.129  54.110  1
200743  93.669  -76.132  54.123  1
200744  93.685  -76.139  54.139  1
200745  93.689  -76.173  54.152  1
200746  93.695  -76.204  54.166  1
200747  93.732  -76.190  54.182  1
200748  93.767  -76.174  54.194  1
200749  93.799  -76.160  54.205  1
200750  93.821  -76.152  54.215  1
200751  93.839  -76.144  54.228  1
200752  93.856  -76.137  54.240  1
200753  93.873  -76.129  54.252  1
200754  93.884  -76.122  54.264  1
200755  93.901  -76.117  54.275  1
200756  93.921  -76.112  54.287  1
200757  93.942  -76.107  54.300  1
200758  93.963  -76.101  54.310  1
200759  93.987  -76.097  54.315  1
200760  94.017  -76.099  54.317  1
200761  94.048  -76.101  54.319  1
200762  94.078  -76.103  54.321  1
200763  94.109  -76.105  54.322  1
200764  94.140  -76.107  54.323  1
200765  94.170  -76.108  54.321  1
200766  94.199  -76.108  54.312  1
200767  94.219  -76.104  54.298  1
200768  94.237  -76.101  54.280  1
200769  94.255  -76.099  54.258  1
200770  94.273  -76.096  54.232  1
200771  94.291  -76.094  54.206  1
200772  94.309  -76.091  54.176  1
200773  94.327  -76.088  54.143  1
200774  94.345  -76.085  54.108  1
200775  94.362  -76.083  54.074  1
200776  94.381  -76.080  54.039  1
200777  94.398  -76.078  54.005  1
200778  94.416  -76.075  53.970  1
200779  94.434  -76.073  53.932  1
200780  94.451  -76.072  53.895  1
200781  94.462  -76.073  53.859  1
200782  94.474  -76.074  53.825  1
200783  94.485  -76.075  53.794  1
200784  94.498  -76.081  53.764  1
200785  94.512  -76.088  53.737  1
200786  94.527  -76.094  53.707  1
200787  94.541  -76.101  53.681  1
200788  94.555  -76.108  53.658  1
200789  94.569  -76.115  53.639  1
200790  94.583  -76.122  53.620  1
200791  94.597  -76.129  53.599  1
200792  94.616  -76.140  53.573  1
200793  94.637  -76.151  53.540  1
200794  94.659  -76.163  53.506  1
200795  94.670  -76.168  53.474  1
200796  94.681  -76.173  53.443  1
200797  94.692  -76.179  53.415  1
200798  94.703  -76.183  53.386  1
200799  94.714  -76.188  53.355  1
200800  94.725  -76.194  53.322  1
200801  94.737  -76.199  53.288  1
200802  94.748  -76.204  53.253  1
200803  94.759  -76.209  53.218  1
200804  94.770  -76.214  53.183  1
200805  94.781  -76.220  53.149  1
200806  94.792  -76.224  53.113  1
200807  94.803  -76.229  53.075  1
200808  94.814  -76.235  53.036  1
200809  94.825  -76.240  52.997  1
200810  94.836  -76.245  52.958  1
200811  94.847  -76.250  52.918  1
200812  94.858  -76.255  52.877  1
200813  94.870  -76.260  52.833  1
200814  94.881  -76.265  52.788  1
200815  94.892  -76.270  52.743  1
200816  94.904  -76.274  52.699  1
200817  94.917  -76.278  52.655  1
200818  94.929  -76.282  52.610  1
200819  94.942  -76.285  52.564  1
200820  94.931  -76.305  52.521  1
200821  94.918  -76.328  52.479  1
200822  94.923  -76.342  52.436  1
200823  94.965  -76.341  52.393  1
200824  95.015  -76.336  52.353  1
200825  95.064  -76.332  52.312  1
200826  95.114  -76.327  52.269  1
200827  95.163  -76.323  52.224  1
200828  95.212  -76.318  52.177  1
200829  95.262  -76.313  52.130  1
200830  95.312  -76.308  52.083  1
200831  95.361  -76.304  52.040  1
200832  95.396  -76.304  51.999  1
200833  95.419  -76.309  51.958  1
200834  95.442  -76.314  51.918  1
200835  95.465  -76.318  51.875  1
200836  95.488  -76.323  51.832  1
200837  95.512  -76.327  51.789  1
200838  95.535  -76.332  51.747  1
200839  95.558  -76.337  51.709  1
200840  95.583  -76.339  51.674  1
200841  95.608  -76.341  51.642  1
200842  95.633  -76.342  51.612  1
200843  95.659  -76.344  51.582  1
200844  95.685  -76.346  51.553  1
200845  95.710  -76.348  51.522  1
200846  95.736  -76.349  51.489  1
200847  95.763  -76.361  51.449  1
200848  95.790  -76.364  51.403  1
200849  95.816  -76.368  51.352  1
200850  95.842  -76.373  51.302  1
200851  95.869  -76.379  51.254  1
200852  95.890  -76.384  51.207  1
200853  95.912  -76.389  51.162  1
200854  95.934  -76.392  51.118  1
200855  95.956  -76.395  51.073  1
200856  95.977  -76.398  51.027  1
200857  96.000  -76.401  50.983  1
200858  96.021  -76.403  50.939  1
200859  96.043  -76.403  50.896  1
200860  96.056  -76.411  50.855  1
200861  96.072  -76.416  50.815  1
200862  96.091  -76.415  50.778  1
200863  96.110  -76.414  50.742  1
200864  96.130  -76.414  50.708  1
200865  96.149  -76.414  50.673  1
200866  96.164  -76.416  50.637  1
200867  96.177  -76.419  50.600  1
200868  96.190  -76.422  50.563  1
200869  96.204  -76.424  50.524  1
200870  96.218  -76.428  50.486  1
200871  96.240  -76.435  50.449  1
200872  96.262  -76.442  50.416  1
200873  96.284  -76.449  50.384  1
200874  96.294  -76.451  50.357  1
200875  96.299  -76.451  50.332  1
200876  96.304  -76.450  50.310  1
200877  96.309  -76.449  50.288  1
200878  96.327  -76.458  50.267  1
200879  96.368  -76.489  50.246  1
200880  96.409  -76.518  50.222  1
200881  96.450  -76.548  50.199  1
200882  96.491  -76.578  50.176  1
200883  96.501  -76.584  50.153  1
200884  96.541  -76.592  50.130  1
200885  96.557  -76.580  50.105  1
200886  96.579  -76.575  50.078  1
200887  96.605  -76.578  50.048  1
200888  96.630  -76.580  50.015  1
200889  96.658  -76.583  49.981  1
200890  96.703  -76.574  49.945  1
200891  96.749  -76.566  49.907  1
200892  96.794  -76.558  49.870  1
200893  96.840  -76.549  49.831  1
200894  96.878  -76.543  49.793  1
200895  96.905  -76.539  49.757  1
200896  96.933  -76.535  49.721  1
200897  96.959  -76.555  49.684  1
200898  96.979  -76.563  49.646  1
200899  96.997  -76.565  49.608  1
200900  97.015  -76.567  49.569  1
200901  97.032  -76.571  49.531  1
200902  97.029  -76.577  49.495  1
200903  97.023  -76.584  49.461  1
200904  97.017  -76.591  49.429  1
200905  97.016  -76.600  49.399  1
200906  97.069  -76.633  49.371  1
200907  97.084  -76.661  49.346  1
200908  97.099  -76.690  49.323  1
200909  97.124  -76.704  49.303  1
200910  97.162  -76.697  49.283  1
200911  97.190  -76.702  49.266  1
200912  97.203  -76.723  49.247  1
200913  97.214  -76.744  49.226  1
200914  97.226  -76.765  49.202  1
200915  97.238  -76.787  49.176  1
200916  97.250  -76.808  49.149  1
200917  97.262  -76.829  49.122  1
200918  97.275  -76.850  49.093  1
200919  97.329  -76.871  49.064  1
200920  97.394  -76.893  49.035  1
200921  97.460  -76.914  49.007  1
200922  97.497  -76.945  48.977  1
200923  97.505  -76.961  48.949  1
200924  97.512  -76.977  48.921  1
200925  97.520  -76.994  48.893  1
200926  97.528  -77.009  48.866  1
200927  97.536  -77.026  48.838  1
200928  97.544  -77.042  48.810  1
200929  97.556  -77.052  48.780  1
200930  97.577  -77.049  48.751  1
200931  97.597  -77.046  48.722  1
200932  97.618  -77.044  48.693  1
200933  97.623  -77.034  48.664  1
200934  97.628  -77.030  48.636  1
200935  97.650  -77.035  48.606  1
200936  97.672  -77.041  48.575  1
200937  97.696  -77.046  48.545  1
200938  97.719  -77.052  48.516  1
200939  97.742  -77.057  48.486  1
200940  97.765  -77.063  48.456  1
200941  97.788  -77.069  48.428  1
200942  97.812  -77.075  48.398  1
200943  97.835  -77.080  48.369  1
200944  97.858  -77.086  48.340  1
200945  97.882  -77.084  48.310  1
200946  97.907  -77.068  48.281  1
200947  97.932  -77.052  48.252  1
200948  97.956  -77.035  48.224  1
200949  97.987  -77.025  48.193  1
200950  98.017  -77.016  48.162  1
200951  98.042  -77.014  48.130  1
200952  98.062  -77.019  48.097  1
200953  98.082  -77.025  48.065  1
200954  98.102  -77.030  48.033  1
200955  98.122  -77.035  48.000  1
200956  98.142  -77.041  47.967  1
200957  98.162  -77.046  47.935  1
200958  98.182  -77.051  47.904  1
200959  98.202  -77.056  47.872  1
200960  98.222  -77.062  47.841  1
200961  98.242  -77.067  47.809  1
200962  98.266  -77.059  47.778  1
200963  98.291  -77.053  47.748  1
200964  98.315  -77.051  47.719  1
200965  98.340  -77.046  47.690  1
200966  98.364  -77.040  47.662  1
200967  98.387  -77.034  47.633  1
200968  98.412  -77.029  47.606  1
200969  98.436  -77.023  47.578  1
200970  98.460  -77.018  47.551  1
200971  98.484  -77.012  47.525  1
200972  98.508  -77.006  47.499  1
200973  98.532  -77.000  47.474  1
200974  98.556  -76.995  47.449  1
200975  98.579  -76.990  47.425  1
200976  98.573  -77.007  47.401  1
200977  98.566  -77.025  47.379  1
200978  98.559  -77.043  47.355  1
200979  98.553  -77.060  47.331  1
200980  98.546  -77.078  47.306  1
200981  98.575  -77.081  47.281  1
200982  98.616  -77.085  47.256  1
200983  98.666  -77.093  47.233  1
200984  98.716  -77.100  47.209  1
200985  98.766  -77.107  47.183  1
200986  98.816  -77.114  47.155  1
200987  98.865  -77.121  47.129  1
200988  98.879  -77.135  47.102  1
200989  98.893  -77.149  47.074  1
200990  98.907  -77.163  47.046  1
200991  98.921  -77.176  47.021  1
200992  98.935  -77.190  46.997  1
200993  98.948  -77.204  46.973  1
200994  98.962  -77.217  46.949  1
200995  98.977  -77.230  46.924  1
200996  98.991  -77.241  46.900  1
200997  99.006  -77.252  46.875  1
200998  99.020  -77.263  46.850  1
200999  99.035  -77.274  46.823  1
201000  99.050  -77.285  46.795  1
201001  99.064  -77.296  46.767  1
201002  99.079  -77.306  46.738  1
201003  99.091  -77.311  46.709  1
201004  99.104  -77.316  46.682  1
201005  99.117  -77.321  46.654  1
201006  99.130  -77.326  46.627  1
201007  99.143  -77.331  46.600  1
201008  99.155  -77.336  46.574  1
201009  99.168  -77.341  46.547  1
201010  99.181  -77.346  46.522  1
201011  99.191  -77.351  46.498  1
201012  99.202  -77.357  46.473  1
201013  99.213  -77.363  46.448  1
201014  99.223  -77.369  46.424  1
201015  99.234  -77.374  46.399  1
201016  99.244  -77.380  46.373  1
201017  99.255  -77.385  46.349  1
201018  99.285  -77.390  46.326  1
201019  99.316  -77.394  46.301  1
201020  99.348  -77.398  46.277  1
201021  99.379  -77.402  46.253  1
201022  99.411  -77.407  46.229  1
201023  99.443  -77.410  46.205  1
201024  99.475  -77.415  46.183  1
201025  99.506  -77.419  46.162  1
201026  99.538  -77.423  46.140  1
201027  99.561  -77.421  46.118  1
201028  99.580  -77.417  46.097  1
201029  99.600  -77.414  46.076  1
201030  99.620  -77.409  46.056  1
201031  99.639  -77.405  46.037  1
201032  99.658  -77.401  46.018  1
201033  99.678  -77.397  45.999  1
201034  99.697  -77.393  45.981  1
201035  99.709  -77.385  45.964  1
201036  99.721  -77.376  45.947  1
201037  99.733  -77.369  45.931  1
201038  99.745  -77.360  45.915  1
201039  99.779  -77.374  45.899  1
201040  99.813  -77.388  45.885  1
201041  99.847  -77.401  45.870  1
201042  99.885  -77.415  45.855  1
201043  99.930  -77.428  45.841  1
201044  99.975  -77.441  45.827  1
201045  100.019  -77.453  45.813  1
201046  100.064  -77.466  45.798  1
201047  100.109  -77.479  45.786  1
201048  100.122  -77.490  45.772  1
201049  100.135  -77.501  45.757  1
201050  100.148  -77.513  45.744  1
201051  100.162  -77.524  45.731  1
201052  100.177  -77.536  45.718  1
201053  100.193  -77.548  45.705  1
201054  100.208  -77.559  45.691  1
201055  100.225  -77.567  45.678  1
201056  100.244  -77.575  45.665  1
201057  100.262  -77.582  45.651  1
201058  100.280  -77.589  45.638  1
201059  100.299  -77.599  45.625  1
201060  100.318  -77.615  45.612  1
201061  100.343  -77.630  45.598  1
201062  100.374  -77.644  45.586  1
201063  100.406  -77.658  45.573  1
201064  100.438  -77.672  45.560  1
201065  100.461  -77.677  45.547  1
201066  100.484  -77.683  45.534  1
201067  100.506  -77.688  45.521  1
201068  100.529  -77.693  45.508  1
201069  100.552  -77.699  45.494  1
201070  100.574  -77.704  45.479  1
201071  100.597  -77.709  45.464  1
201072  100.619  -77.714  45.449  1
201073  100.642  -77.724  45.435  1
201074  100.668  -77.739  45.421  1
201075  100.695  -77.757  45.407  1
201076  100.722  -77.783  45.391  1
201077  100.750  -77.809  45.377  1
201078  100.778  -77.835  45.363  1
201079  100.806  -77.862  45.349  1
201080  100.829  -77.875  45.335  1
201081  100.851  -77.887  45.322  1
201082  100.874  -77.899  45.308  1
201083  100.896  -77.911  45.295  1
201084  100.918  -77.923  45.282  1
201085  100.941  -77.935  45.270  1
201086  100.963  -77.947  45.258  1
201087  100.986  -77.959  45.247  1
201088  101.008  -77.971  45.236  1
201089  101.030  -77.983  45.224  1
201090  101.053  -77.995  45.212  1
201091  101.075  -78.006  45.199  1
201092  101.098  -78.016  45.186  1
201093  101.121  -78.018  45.173  1
201094  101.145  -78.022  45.160  1
201095  101.161  -78.022  45.147  1
201096  101.166  -78.022  45.132  1
201097  101.182  -78.028  45.118  1
201098  101.221  -78.049  45.103  1
201099  101.260  -78.069  45.089  1
201100  101.299  -78.089  45.074  1
201101  101.335  -78.106  45.058  1
201102  101.372  -78.122  45.043  1
201103  101.408  -78.139  45.028  1
201104  101.445  -78.155  45.012  1
201105  101.475  -78.170  44.996  1
201106  101.492  -78.181  44.981  1
201107  101.509  -78.192  44.966  1
201108  101.526  -78.203  44.949  1
201109  101.543  -78.214  44.933  1
201110  101.560  -78.225  44.918  1
201111  101.581  -78.237  44.901  1
201112  101.606  -78.250  44.884  1
201113  101.630  -78.263  44.868  1
201114  101.655  -78.277  44.851  1
201115  101.679  -78.290  44.834  1
201116  101.703  -78.303  44.818  1
201117  101.728  -78.316  44.803  1
201118  101.752  -78.329  44.788  1
201119  101.777  -78.343  44.774  1
201120  101.801  -78.356  44.759  1
201121  101.826  -78.369  44.745  1
201122  101.850  -78.382  44.730  1
201123  101.875  -78.395  44.715  1
201124  101.899  -78.409  44.701  1
201125  101.920  -78.420  44.687  1
201126  101.941  -78.432  44.672  1
201127  101.961  -78.444  44.657  1
201128  101.995  -78.456  44.642  1
201129  102.036  -78.477  44.627  1
201130  102.069  -78.499  44.611  1
201131  102.112  -78.522  44.595  1
201132  102.160  -78.545  44.579  1
201133  102.207  -78.567  44.564  1
201134  102.254  -78.589  44.549  1
201135  102.301  -78.612  44.534  1
201136  102.348  -78.634  44.519  1
201137  102.395  -78.657  44.503  1
201138  102.440  -78.680  44.488  1
201139  102.485  -78.703  44.473  1
201140  102.519  -78.718  44.458  1
201141  102.537  -78.720  44.442  1
201142  102.552  -78.723  44.427  1
201143  102.568  -78.725  44.413  1
201144  102.584  -78.727  44.397  1
201145  102.599  -78.730  44.383  1
201146  102.614  -78.731  44.369  1
201147  102.630  -78.733  44.354  1
201148  102.646  -78.736  44.338  1
201149  102.661  -78.738  44.323  1
201150  102.677  -78.740  44.308  1
201151  102.692  -78.742  44.293  1
201437  93.533  -76.086  54.024  1
201438  93.551  -76.089  54.039  1
201439  93.569  -76.092  54.053  1
201440  93.587  -76.095  54.066  1
201441  93.606  -76.099  54.079  1
201442  93.624  -76.102  54.092  1
201443  93.642  -76.105  54.106  1
201444  93.660  -76.109  54.121  1
201445  93.677  -76.116  54.137  1
201446  93.681  -76.149  54.152  1
201447  93.690  -76.176  54.167  1
201448  93.723  -76.168  54.183  1
201449  93.765  -76.144  54.196  1
201450  93.788  -76.135  54.208  1
201451  93.805  -76.127  54.218  1
201452  93.823  -76.120  54.232  1
201453  93.841  -76.113  54.246  1
201454  93.859  -76.105  54.259  1
201455  93.881  -76.099  54.271  1
201456  93.902  -76.094  54.282  1
201457  93.923  -76.088  54.294  1
201458  93.944  -76.083  54.306  1
201459  93.965  -76.078  54.317  1
201460  93.989  -76.075  54.323  1
201461  94.019  -76.076  54.326  1
201462  94.050  -76.079  54.328  1
201463  94.081  -76.080  54.330  1
201464  94.112  -76.082  54.332  1
201465  94.142  -76.084  54.333  1
201466  94.173  -76.086  54.330  1
201467  94.202  -76.087  54.321  1
201468  94.220  -76.085  54.308  1
201469  94.238  -76.082  54.290  1
201470  94.256  -76.079  54.269  1
201471  94.274  -76.076  54.242  1
201472  94.291  -76.074  54.215  1
201473  94.310  -76.071  54.184  1
201474  94.327  -76.069  54.150  1
201475  94.345  -76.066  54.115  1
201476  94.363  -76.063  54.081  1
201477  94.381  -76.061  54.046  1
201478  94.399  -76.058  54.011  1
201479  94.417  -76.056  53.976  1
201480  94.435  -76.053  53.938  1
201481  94.452  -76.052  53.900  1
201482  94.464  -76.053  53.862  1
201483  94.475  -76.053  53.827  1
201484  94.489  -76.060  53.794  1
201485  94.503  -76.068  53.763  1
201486  94.517  -76.075  53.734  1
201487  94.531  -76.082  53.704  1
201488  94.545  -76.088  53.675  1
201489  94.559  -76.095  53.649  1
201490  94.573  -76.102  53.629  1
201491  94.588  -76.109  53.609  1
201492  94.602  -76.116  53.587  1
201493  94.618  -76.125  53.563  1
201494  94.639  -76.136  53.530  1
201495  94.659  -76.148  53.496  1
201496  94.670  -76.153  53.463  1
201497  94.681  -76.157  53.433  1
201498  94.692  -76.163  53.406  1
201499  94.703  -76.168  53.378  1
201500  94.715  -76.173  53.349  1
201501  94.726  -76.178  53.317  1
201502  94.737  -76.183  53.283  1
201503  94.748  -76.188  53.250  1
201504  94.759  -76.193  53.216  1
201505  94.770  -76.198  53.184  1
201506  94.781  -76.204  53.150  1
201507  94.792  -76.209  53.115  1
201508  94.804  -76.213  53.078  1
201509  94.815  -76.219  53.042  1
201510  94.826  -76.224  53.004  1
201511  94.837  -76.229  52.966  1
201512  94.848  -76.234  52.928  1
201513  94.859  -76.239  52.886  1
201514  94.870  -76.245  52.842  1
201515  94.882  -76.250  52.796  1
201516  94.893  -76.254  52.752  1
201517  94.904  -76.260  52.709  1
201518  94.915  -76.264  52.664  1
201519  94.927  -76.268  52.619  1
201520  94.940  -76.272  52.573  1
201521  94.930  -76.292  52.530  1
201522  94.917  -76.314  52.489  1
201523  94.913  -76.332  52.448  1
201524  94.962  -76.328  52.407  1
201525  95.012  -76.323  52.367  1
201526  95.061  -76.319  52.327  1
201527  95.110  -76.314  52.286  1
201528  95.160  -76.309  52.242  1
201529  95.209  -76.304  52.197  1
201530  95.259  -76.300  52.152  1
201531  95.308  -76.295  52.106  1
201532  95.357  -76.291  52.061  1
201533  95.400  -76.289  52.018  1
201534  95.423  -76.293  51.977  1
201535  95.447  -76.298  51.936  1
201536  95.469  -76.302  51.895  1
201537  95.492  -76.307  51.853  1
201538  95.516  -76.312  51.810  1
201539  95.539  -76.317  51.768  1
201540  95.563  -76.320  51.728  1
201541  95.589  -76.321  51.691  1
201542  95.614  -76.323  51.656  1
201543  95.639  -76.324  51.625  1
201544  95.665  -76.326  51.594  1
201545  95.691  -76.327  51.564  1
201546  95.716  -76.329  51.534  1
201547  95.742  -76.329  51.500  1
201548  95.767  -76.332  51.460  1
201549  95.793  -76.338  51.415  1
201550  95.820  -76.343  51.365  1
201551  95.846  -76.348  51.316  1
201552  95.873  -76.354  51.268  1
201553  95.895  -76.359  51.222  1
201554  95.917  -76.364  51.177  1
201555  95.938  -76.370  51.133  1
201556  95.960  -76.375  51.088  1
201557  95.981  -76.379  51.042  1
201558  96.003  -76.382  50.997  1
201559  96.025  -76.385  50.953  1
201560  96.045  -76.386  50.910  1
201561  96.060  -76.392  50.869  1
201562  96.079  -76.392  50.830  1
201563  96.099  -76.391  50.793  1
201564  96.118  -76.391  50.758  1
201565  96.137  -76.390  50.725  1
201566  96.157  -76.389  50.690  1
201567  96.170  -76.392  50.655  1
201568  96.184  -76.395  50.619  1
201569  96.197  -76.398  50.582  1
201570  96.210  -76.401  50.545  1
201571  96.224  -76.404  50.508  1
201572  96.241  -76.409  50.471  1
201573  96.263  -76.416  50.439  1
201574  96.284  -76.423  50.408  1
201575  96.289  -76.422  50.381  1
201576  96.294  -76.421  50.357  1
201577  96.299  -76.421  50.335  1
201578  96.312  -76.427  50.314  1
201579  96.338  -76.439  50.292  1
201580  96.379  -76.469  50.270  1
201581  96.413  -76.503  50.246  1
201582  96.454  -76.533  50.222  1
201583  96.495  -76.563  50.199  1
201584  96.523  -76.574  50.177  1
201585  96.539  -76.561  50.153  1
201586  96.556  -76.551  50.127  1
201587  96.583  -76.554  50.099  1
201588  96.609  -76.556  50.069  1
201589  96.635  -76.559  50.036  1
201590  96.661  -76.561  50.001  1
201591  96.705  -76.554  49.965  1
201592  96.751  -76.546  49.928  1
201593  96.797  -76.537  49.889  1
201594  96.842  -76.529  49.851  1
201595  96.888  -76.520  49.812  1
201596  96.926  -76.514  49.775  1
201597  96.953  -76.510  49.739  1
201598  96.979  -76.526  49.701  1
201599  96.997  -76.528  49.662  1
201600  97.014  -76.530  49.624  1
201601  97.013  -76.537  49.585  1
201602  97.007  -76.544  49.547  1
201603  97.001  -76.551  49.511  1
201604  96.995  -76.558  49.476  1
201605  96.989  -76.565  49.444  1
201606  97.046  -76.592  49.414  1
201607  97.068  -76.621  49.386  1
201608  97.083  -76.649  49.361  1
201609  97.098  -76.677  49.339  1
201610  97.113  -76.705  49.318  1
201611  97.145  -76.710  49.299  1
201612  97.183  -76.703  49.281  1
201613  97.221  -76.697  49.262  1
201614  97.234  -76.718  49.241  1
201615  97.246  -76.739  49.217  1
201616  97.258  -76.760  49.191  1
201617  97.270  -76.781  49.165  1
201618  97.282  -76.802  49.138  1
201619  97.294  -76.824  49.109  1
201620  97.341  -76.845  49.080  1
201621  97.405  -76.867  49.051  1
201622  97.471  -76.888  49.023  1
201623  97.492  -76.903  48.993  1
201624  97.500  -76.915  48.963  1
201625  97.508  -76.931  48.935  1
201626  97.516  -76.947  48.906  1
201627  97.524  -76.963  48.878  1
201628  97.532  -76.979  48.850  1
201629  97.539  -76.995  48.822  1
201630  97.547  -77.012  48.792  1
201631  97.563  -77.016  48.762  1
201632  97.584  -77.013  48.734  1
201633  97.604  -77.010  48.705  1
201634  97.625  -77.008  48.676  1
201635  97.649  -77.010  48.647  1
201636  97.672  -77.016  48.618  1
201637  97.696  -77.022  48.587  1
201638  97.719  -77.028  48.558  1
201639  97.742  -77.033  48.528  1
201640  97.765  -77.039  48.499  1
201641  97.789  -77.044  48.469  1
201642  97.812  -77.050  48.440  1
201643  97.835  -77.056  48.411  1
201644  97.858  -77.062  48.381  1
201645  97.881  -77.068  48.351  1
201646  97.905  -77.067  48.321  1
201647  97.930  -77.051  48.291  1
201648  97.955  -77.035  48.262  1
201649  97.980  -77.019  48.234  1
201650  98.005  -77.003  48.203  1
201651  98.035  -76.994  48.172  1
201652  98.059  -76.994  48.141  1
201653  98.079  -76.999  48.108  1
201654  98.099  -77.004  48.075  1
201655  98.119  -77.009  48.042  1
201656  98.139  -77.015  48.009  1
201657  98.159  -77.020  47.975  1
201658  98.179  -77.025  47.943  1
201659  98.199  -77.031  47.911  1
201660  98.219  -77.036  47.879  1
201661  98.239  -77.041  47.848  1
201662  98.259  -77.046  47.817  1
201663  98.279  -77.050  47.786  1
201664  98.301  -77.050  47.757  1
201665  98.325  -77.044  47.729  1
201666  98.350  -77.038  47.700  1
201667  98.373  -77.033  47.671  1
201668  98.397  -77.028  47.643  1
201669  98.422  -77.022  47.616  1
201670  98.446  -77.016  47.588  1
201671  98.469  -77.010  47.561  1
201672  98.494  -77.005  47.535  1
201673  98.518  -76.999  47.510  1
201674  98.542  -76.994  47.485  1
201675  98.566  -76.987  47.461  1
201676  98.590  -76.982  47.437  1
201677  98.587  -76.997  47.414  1
201678  98.581  -77.014  47.391  1
201679  98.574  -77.032  47.366  1
201680  98.567  -77.050  47.342  1
201681  98.565  -77.066  47.317  1
201682  98.598  -77.067  47.292  1
201683  98.631  -77.069  47.266  1
201684  98.679  -77.076  47.243  1
201685  98.729  -77.083  47.217  1
201686  98.779  -77.091  47.190  1
201687  98.829  -77.097  47.163  1
201688  98.877  -77.105  47.135  1
201689  98.891  -77.119  47.107  1
201690  98.905  -77.132  47.078  1
201691  98.919  -77.146  47.050  1
201692  98.932  -77.160  47.024  1
201693  98.946  -77.174  46.999  1
201694  98.960  -77.188  46.974  1
201695  98.974  -77.201  46.951  1
201696  98.988  -77.215  46.926  1
201697  99.002  -77.227  46.901  1
201698  99.017  -77.238  46.876  1
201699  99.031  -77.249  46.851  1
201700  99.046  -77.260  46.825  1
201701  99.061  -77.271  46.797  1
201702  99.075  -77.282  46.768  1
201703  99.089  -77.291  46.738  1
201704  99.102  -77.295  46.709  1
201705  99.115  -77.301  46.682  1
201706  99.128  -77.305  46.654  1
201707  99.141  -77.310  46.626  1
201708  99.153  -77.315  46.599  1
201709  99.166  -77.320  46.572  1
201710  99.179  -77.326  46.545  1
201711  99.192  -77.330  46.519  1
201712  99.205  -77.335  46.495  1
201713  99.215  -77.341  46.470  1
201714  99.226  -77.347  46.445  1
201715  99.237  -77.352  46.420  1
201716  99.248  -77.358  46.395  1
201717  99.258  -77.363  46.369  1
201718  99.280  -77.368  46.346  1
201719  99.312  -77.373  46.322  1
201720  99.344  -77.376  46.298  1
201721  99.375  -77.381  46.274  1
201722  99.407  -77.385  46.250  1
201723  99.438  -77.389  46.226  1
201724  99.470  -77.393  46.202  1
201725  99.502  -77.398  46.181  1
201726  99.534  -77.401  46.159  1
201727  99.565  -77.405  46.137  1
201728  99.596  -77.410  46.115  1
201729  99.625  -77.412  46.095  1
201730  99.645  -77.407  46.074  1
201731  99.664  -77.404  46.054  1
201732  99.684  -77.400  46.034  1
201733  99.704  -77.395  46.016  1
201734  99.719  -77.389  45.998  1
201735  99.730  -77.381  45.980  1
201736  99.743  -77.373  45.963  1
201737  99.755  -77.365  45.946  1
201738  99.767  -77.357  45.929  1
201739  99.779  -77.349  45.913  1
201740  99.807  -77.357  45.898  1
201741  99.841  -77.371  45.883  1
201742  99.875  -77.385  45.869  1
201743  99.909  -77.398  45.854  1
201744  99.943  -77.412  45.839  1
201745  99.983  -77.425  45.825  1
201746  100.028  -77.438  45.810  1
201747  100.073  -77.451  45.796  1
201748  100.118  -77.464  45.783  1
201749  100.144  -77.476  45.769  1
201750  100.157  -77.487  45.755  1
201751  100.170  -77.498  45.741  1
201752  100.185  -77.510  45.728  1
201753  100.200  -77.521  45.715  1
201754  100.216  -77.533  45.701  1
201755  100.234  -77.539  45.688  1
201756  100.253  -77.546  45.675  1
201757  100.271  -77.554  45.661  1
201758  100.290  -77.561  45.648  1
201759  100.309  -77.568  45.635  1
201760  100.327  -77.580  45.621  1
201761  100.346  -77.596  45.608  1
201762  100.367  -77.612  45.595  1
201763  100.399  -77.626  45.582  1
201764  100.430  -77.640  45.569  1
201765  100.460  -77.652  45.556  1
201766  100.482  -77.657  45.542  1
201767  100.505  -77.662  45.529  1
201768  100.528  -77.667  45.516  1
201769  100.550  -77.672  45.502  1
201770  100.573  -77.677  45.488  1
201771  100.596  -77.683  45.474  1
201772  100.618  -77.690  45.460  1
201773  100.641  -77.701  45.445  1
201774  100.664  -77.711  45.432  1
201775  100.690  -77.727  45.417  1
201776  100.716  -77.744  45.403  1
201777  100.743  -77.761  45.388  1
201778  100.770  -77.777  45.374  1
201779  100.797  -77.802  45.361  1
201780  100.825  -77.828  45.347  1
201781  100.853  -77.855  45.332  1
201782  100.880  -77.879  45.319  1
201783  100.903  -77.891  45.306  1
201784  100.925  -77.903  45.293  1
201785  100.948  -77.915  45.280  1
201786  100.970  -77.927  45.267  1
201787  100.992  -77.939  45.254  1
201788  101.015  -77.951  45.243  1
201789  101.037  -77.963  45.231  1
201790  101.059  -77.975  45.220  1
201791  101.081  -77.987  45.207  1
201792  101.104  -77.999  45.194  1
201793  101.126  -78.011  45.181  1
201794  101.150  -78.013  45.168  1
201795  101.174  -78.015  45.155  1
201796  101.187  -78.016  45.142  1
201797  101.192  -78.016  45.128  1
201798  101.198  -78.015  45.114  1
201799  101.234  -78.034  45.099  1
201800  101.273  -78.054  45.086  1
201801  101.312  -78.075  45.070  1
201802  101.350  -78.095  45.055  1
201803  101.387  -78.112  45.039  1
201804  101.423  -78.128  45.024  1
201805  101.460  -78.145  45.008  1
201806  101.496  -78.162  44.993  1
201807  101.513  -78.172  44.977  1
201808  101.530  -78.184  44.962  1
201809  101.546  -78.194  44.945  1
201810  101.563  -78.205  44.929  1
201811  101.584  -78.217  44.914  1
201812  101.608  -78.231  44.898  1
201813  101.633  -78.244  44.881  1
201814  101.657  -78.257  44.864  1
201815  101.682  -78.270  44.847  1
201816  101.706  -78.283  44.830  1
201817  101.731  -78.297  44.814  1
201818  101.755  -78.310  44.798  1
201819  101.779  -78.323  44.782  1
201820  101.804  -78.336  44.768  1
201821  101.829  -78.349  44.754  1
201822  101.851  -78.362  44.739  1
201823  101.871  -78.373  44.725  1
201824  101.892  -78.385  44.709  1
201825  101.912  -78.396  44.695  1
201826  101.933  -78.407  44.681  1
201827  101.953  -78.419  44.667  1
201828  101.983  -78.430  44.652  1
201829  102.020  -78.444  44.637  1
201830  102.061  -78.465  44.622  1
201831  102.102  -78.486  44.606  1
201832  102.137  -78.508  44.590  1
201833  102.168  -78.531  44.575  1
201834  102.208  -78.553  44.560  1
201835  102.255  -78.576  44.545  1
201836  102.303  -78.598  44.530  1
201837  102.349  -78.620  44.514  1
201838  102.397  -78.643  44.499  1
201839  102.444  -78.665  44.484  1
201840  102.491  -78.688  44.470  1
201841  102.536  -78.702  44.455  1
201842  102.552  -78.705  44.438  1
201843  102.567  -78.707  44.423  1
201844  102.583  -78.709  44.409  1
201845  102.598  -78.711  44.393  1
201846  102.614  -78.714  44.379  1
201847  102.629  -78.716  44.364  1
201848  102.644  -78.718  44.349  1
201849  102.660  -78.720  44.334  1
201850  102.676  -78.723  44.318  1
201851  102.691  -78.725  44.303  1
201852  102.706  -78.727  44.288  1
202138  93.524  -76.063  54.017  1
202139  93.543  -76.066  54.033  1
202140  93.561  -76.069  54.047  1
202141  93.579  -76.072  54.060  1
202142  93.597  -76.075  54.074  1
202143  93.616  -76.079  54.088  1
202144  93.634  -76.082  54.103  1
202145  93.652  -76.085  54.119  1
202146  93.670  -76.091  54.135  1
202147  93.674  -76.125  54.150  1
202148  93.685  -76.148  54.164  1
202149  93.717  -76.142  54.180  1
202150  93.759  -76.118  54.194  1
202151  93.777  -76.111  54.207  1
202152  93.795  -76.104  54.219  1
202153  93.814  -76.097  54.234  1
202154  93.833  -76.089  54.248  1
202155  93.851  -76.082  54.262  1
202156  93.874  -76.075  54.275  1
202157  93.904  -76.070  54.287  1
202158  93.924  -76.065  54.299  1
202159  93.945  -76.060  54.310  1
202160  93.966  -76.054  54.323  1
202161  93.992  -76.052  54.330  1
202162  94.022  -76.053  54.334  1
202163  94.053  -76.056  54.336  1
202164  94.083  -76.057  54.337  1
202165  94.114  -76.060  54.339  1
202166  94.145  -76.061  54.340  1
202167  94.173  -76.060  54.337  1
202168  94.201  -76.056  54.327  1
202169  94.222  -76.054  54.315  1
202170  94.240  -76.053  54.298  1
202171  94.258  -76.052  54.277  1
202172  94.275  -76.050  54.251  1
202173  94.293  -76.049  54.222  1
202174  94.311  -76.048  54.190  1
202175  94.328  -76.047  54.156  1
202176  94.346  -76.045  54.121  1
202177  94.364  -76.044  54.087  1
202178  94.382  -76.041  54.052  1
202179  94.400  -76.038  54.018  1
202180  94.418  -76.036  53.982  1
202181  94.435  -76.033  53.945  1
202182  94.453  -76.032  53.906  1
202183  94.466  -76.034  53.868  1
202184  94.480  -76.041  53.830  1
202185  94.493  -76.047  53.795  1
202186  94.507  -76.054  53.762  1
202187  94.522  -76.061  53.732  1
202188  94.536  -76.069  53.701  1
202189  94.550  -76.075  53.671  1
202190  94.564  -76.082  53.644  1
202191  94.578  -76.089  53.618  1
202192  94.592  -76.096  53.597  1
202193  94.606  -76.103  53.575  1
202194  94.620  -76.110  53.551  1
202195  94.640  -76.122  53.518  1
202196  94.660  -76.132  53.484  1
202197  94.671  -76.137  53.450  1
202198  94.682  -76.142  53.420  1
202199  94.693  -76.147  53.392  1
202200  94.704  -76.152  53.365  1
202201  94.715  -76.157  53.337  1
202202  94.726  -76.163  53.305  1
202203  94.738  -76.167  53.272  1
202204  94.749  -76.173  53.238  1
202205  94.760  -76.178  53.205  1
202206  94.771  -76.183  53.174  1
202207  94.782  -76.188  53.143  1
202208  94.793  -76.193  53.111  1
202209  94.804  -76.198  53.076  1
202210  94.815  -76.203  53.041  1
202211  94.826  -76.208  53.005  1
202212  94.837  -76.213  52.969  1
202213  94.848  -76.219  52.931  1
202214  94.859  -76.223  52.890  1
202215  94.871  -76.229  52.847  1
202216  94.882  -76.234  52.803  1
202217  94.893  -76.239  52.759  1
202218  94.904  -76.244  52.716  1
202219  94.915  -76.249  52.672  1
202220  94.926  -76.254  52.627  1
202221  94.938  -76.258  52.582  1
202222  94.930  -76.277  52.541  1
202223  94.925  -76.295  52.501  1
202224  94.933  -76.307  52.462  1
202225  94.959  -76.315  52.421  1
202226  95.008  -76.310  52.381  1
202227  95.057  -76.306  52.341  1
202228  95.107  -76.301  52.302  1
202229  95.157  -76.296  52.262  1
202230  95.206  -76.292  52.218  1
202231  95.255  -76.287  52.174  1
202232  95.305  -76.282  52.128  1
202233  95.354  -76.277  52.082  1
202234  95.404  -76.273  52.037  1
202235  95.427  -76.277  51.994  1
202236  95.451  -76.282  51.954  1
202237  95.473  -76.287  51.914  1
202238  95.496  -76.292  51.873  1
202239  95.520  -76.296  51.831  1
202240  95.544  -76.300  51.790  1
202241  95.569  -76.301  51.748  1
202242  95.595  -76.303  51.708  1
202243  95.620  -76.304  51.670  1
202244  95.645  -76.306  51.637  1
202245  95.671  -76.307  51.604  1
202246  95.697  -76.307  51.573  1
202247  95.725  -76.304  51.543  1
202248  95.750  -76.304  51.509  1
202249  95.773  -76.308  51.469  1
202250  95.797  -76.314  51.425  1
202251  95.823  -76.319  51.377  1
202252  95.850  -76.324  51.328  1
202253  95.876  -76.329  51.282  1
202254  95.900  -76.335  51.238  1
202255  95.922  -76.340  51.192  1
202256  95.943  -76.345  51.149  1
202257  95.965  -76.351  51.103  1
202258  95.986  -76.356  51.057  1
202259  96.008  -76.361  51.011  1
202260  96.029  -76.366  50.967  1
202261  96.048  -76.368  50.924  1
202262  96.067  -76.368  50.882  1
202263  96.087  -76.367  50.843  1
202264  96.107  -76.367  50.808  1
202265  96.126  -76.367  50.773  1
202266  96.146  -76.366  50.740  1
202267  96.164  -76.366  50.707  1
202268  96.177  -76.369  50.672  1
202269  96.190  -76.372  50.636  1
202270  96.204  -76.375  50.600  1
202271  96.217  -76.378  50.564  1
202272  96.231  -76.380  50.528  1
202273  96.244  -76.383  50.493  1
202274  96.264  -76.389  50.461  1
202275  96.279  -76.393  50.430  1
202276  96.284  -76.393  50.404  1
202277  96.295  -76.398  50.381  1
202278  96.312  -76.407  50.359  1
202279  96.329  -76.417  50.338  1
202280  96.346  -76.426  50.317  1
202281  96.398  -76.442  50.294  1
202282  96.442  -76.470  50.270  1
202283  96.474  -76.506  50.246  1
202284  96.507  -76.542  50.223  1
202285  96.520  -76.543  50.201  1
202286  96.536  -76.530  50.176  1
202287  96.560  -76.530  50.148  1
202288  96.587  -76.532  50.119  1
202289  96.613  -76.535  50.088  1
202290  96.639  -76.537  50.055  1
202291  96.665  -76.540  50.021  1
202292  96.708  -76.533  49.985  1
202293  96.753  -76.525  49.947  1
202294  96.799  -76.517  49.908  1
202295  96.844  -76.508  49.869  1
202296  96.890  -76.500  49.830  1
202297  96.936  -76.492  49.793  1
202298  96.974  -76.485  49.756  1
202299  96.996  -76.491  49.717  1
202300  96.997  -76.497  49.678  1
202301  96.991  -76.504  49.640  1
202302  96.985  -76.511  49.602  1
202303  96.979  -76.518  49.563  1
202304  96.972  -76.526  49.526  1
202305  96.966  -76.533  49.492  1
202306  96.980  -76.546  49.459  1
202307  97.051  -76.580  49.429  1
202308  97.066  -76.608  49.401  1
202309  97.081  -76.637  49.377  1
202310  97.097  -76.665  49.354  1
202311  97.112  -76.694  49.333  1
202312  97.127  -76.722  49.313  1
202313  97.166  -76.716  49.295  1
202314  97.204  -76.709  49.276  1
202315  97.242  -76.703  49.255  1
202316  97.265  -76.712  49.231  1
202317  97.277  -76.734  49.206  1
202318  97.289  -76.755  49.181  1
202319  97.301  -76.776  49.154  1
202320  97.313  -76.797  49.125  1
202321  97.352  -76.818  49.096  1
202322  97.417  -76.840  49.067  1
202323  97.471  -76.862  49.037  1
202324  97.485  -76.876  49.007  1
202325  97.494  -76.886  48.978  1
202326  97.502  -76.896  48.948  1
202327  97.511  -76.906  48.918  1
202328  97.519  -76.916  48.890  1
202329  97.527  -76.932  48.861  1
202330  97.535  -76.949  48.832  1
202331  97.543  -76.965  48.803  1
202332  97.551  -76.981  48.774  1
202333  97.570  -76.981  48.745  1
202334  97.590  -76.978  48.717  1
202335  97.618  -76.980  48.688  1
202336  97.657  -76.990  48.658  1
202337  97.696  -76.998  48.629  1
202338  97.719  -77.003  48.598  1
202339  97.742  -77.009  48.569  1
202340  97.765  -77.015  48.540  1
202341  97.789  -77.021  48.512  1
202342  97.812  -77.026  48.482  1
202343  97.835  -77.032  48.453  1
202344  97.858  -77.038  48.423  1
202345  97.881  -77.044  48.393  1
202346  97.904  -77.049  48.362  1
202347  97.928  -77.051  48.331  1
202348  97.953  -77.034  48.302  1
202349  97.978  -77.019  48.273  1
202350  98.003  -77.002  48.244  1
202351  98.027  -76.986  48.213  1
202352  98.054  -76.972  48.183  1
202353  98.076  -76.972  48.151  1
202354  98.096  -76.978  48.119  1
202355  98.117  -76.983  48.085  1
202356  98.136  -76.988  48.052  1
202357  98.156  -76.992  48.019  1
202358  98.176  -76.995  47.986  1
202359  98.196  -76.999  47.953  1
202360  98.216  -77.003  47.921  1
202361  98.235  -77.006  47.889  1
202362  98.255  -77.010  47.857  1
202363  98.275  -77.013  47.826  1
202364  98.295  -77.018  47.795  1
202365  98.313  -77.034  47.766  1
202366  98.335  -77.037  47.738  1
202367  98.359  -77.031  47.709  1
202368  98.383  -77.026  47.679  1
202369  98.408  -77.020  47.650  1
202370  98.432  -77.015  47.623  1
202371  98.455  -77.009  47.597  1
202372  98.480  -77.003  47.571  1
202373  98.504  -76.997  47.546  1
202374  98.528  -76.992  47.521  1
202375  98.552  -76.986  47.496  1
202376  98.576  -76.981  47.472  1
202377  98.600  -76.975  47.449  1
202378  98.602  -76.986  47.426  1
202379  98.595  -77.003  47.403  1
202380  98.588  -77.021  47.378  1
202381  98.582  -77.039  47.353  1
202382  98.587  -77.051  47.328  1
202383  98.621  -77.053  47.303  1
202384  98.653  -77.056  47.276  1
202385  98.693  -77.059  47.251  1
202386  98.743  -77.067  47.225  1
202387  98.793  -77.074  47.197  1
202388  98.843  -77.081  47.169  1
202389  98.888  -77.089  47.140  1
202390  98.903  -77.103  47.111  1
202391  98.917  -77.116  47.081  1
202392  98.930  -77.130  47.054  1
202393  98.944  -77.144  47.027  1
202394  98.958  -77.157  47.001  1
202395  98.972  -77.171  46.976  1
202396  98.986  -77.185  46.951  1
202397  99.000  -77.199  46.927  1
202398  99.014  -77.213  46.902  1
202399  99.028  -77.224  46.877  1
202400  99.043  -77.235  46.851  1
202401  99.058  -77.246  46.825  1
202402  99.072  -77.257  46.797  1
202403  99.087  -77.267  46.769  1
202404  99.100  -77.275  46.738  1
202405  99.113  -77.280  46.709  1
202406  99.126  -77.285  46.681  1
202407  99.139  -77.290  46.653  1
202408  99.151  -77.294  46.625  1
202409  99.164  -77.300  46.596  1
202410  99.177  -77.305  46.569  1
202411  99.190  -77.310  46.542  1
202412  99.203  -77.315  46.517  1
202413  99.215  -77.320  46.491  1
202414  99.228  -77.325  46.466  1
202415  99.239  -77.330  46.442  1
202416  99.251  -77.335  46.416  1
202417  99.261  -77.341  46.391  1
202418  99.276  -77.347  46.366  1
202419  99.307  -77.351  46.342  1
202420  99.339  -77.355  46.318  1
202421  99.371  -77.359  46.294  1
202422  99.403  -77.363  46.271  1
202423  99.434  -77.367  46.247  1
202424  99.466  -77.372  46.223  1
202425  99.497  -77.376  46.200  1
202426  99.529  -77.379  46.179  1
202427  99.561  -77.384  46.156  1
202428  99.592  -77.388  46.134  1
202429  99.624  -77.392  46.113  1
202430  99.656  -77.396  46.092  1
202431  99.687  -77.401  46.071  1
202432  99.709  -77.398  46.052  1
202433  99.728  -77.394  46.032  1
202434  99.740  -77.385  46.015  1
202435  99.752  -77.378  45.997  1
202436  99.764  -77.370  45.978  1
202437  99.776  -77.361  45.961  1
202438  99.788  -77.354  45.944  1
202439  99.800  -77.345  45.927  1
202440  99.812  -77.338  45.912  1
202441  99.835  -77.340  45.897  1
202442  99.869  -77.354  45.882  1
202443  99.903  -77.367  45.866  1
202444  99.937  -77.381  45.851  1
202445  99.971  -77.395  45.836  1
202446  100.005  -77.409  45.822  1
202447  100.039  -77.423  45.807  1
202448  100.081  -77.436  45.794  1
202449  100.126  -77.448  45.780  1
202450  100.165  -77.461  45.766  1
202451  100.179  -77.472  45.752  1
202452  100.193  -77.483  45.738  1
202453  100.208  -77.495  45.725  1
202454  100.225  -77.504  45.711  1
202455  100.244  -77.511  45.697  1
202456  100.262  -77.518  45.685  1
202457  100.280  -77.525  45.671  1
202458  100.299  -77.533  45.658  1
202459  100.318  -77.539  45.645  1
202460  100.336  -77.547  45.631  1
202461  100.355  -77.561  45.618  1
202462  100.373  -77.577  45.605  1
202463  100.392  -77.593  45.592  1
202464  100.423  -77.608  45.578  1
202465  100.455  -77.621  45.565  1
202466  100.481  -77.630  45.551  1
202467  100.503  -77.636  45.537  1
202468  100.526  -77.641  45.524  1
202469  100.549  -77.646  45.510  1
202470  100.571  -77.652  45.496  1
202471  100.594  -77.658  45.483  1
202472  100.617  -77.667  45.469  1
202473  100.639  -77.678  45.455  1
202474  100.662  -77.688  45.441  1
202475  100.685  -77.699  45.427  1
202476  100.711  -77.715  45.412  1
202477  100.738  -77.732  45.398  1
202478  100.765  -77.749  45.384  1
202479  100.791  -77.766  45.371  1
202480  100.818  -77.783  45.357  1
202481  100.845  -77.799  45.343  1
202482  100.872  -77.821  45.329  1
202483  100.900  -77.848  45.316  1
202484  100.928  -77.874  45.302  1
202485  100.954  -77.895  45.289  1
202486  100.976  -77.907  45.276  1
202487  100.998  -77.919  45.263  1
202488  101.021  -77.931  45.251  1
202489  101.043  -77.943  45.239  1
202490  101.065  -77.955  45.227  1
202491  101.088  -77.967  45.215  1
202492  101.110  -77.979  45.202  1
202493  101.133  -77.991  45.189  1
202494  101.155  -78.003  45.177  1
202495  101.178  -78.007  45.164  1
202496  101.202  -78.009  45.151  1
202497  101.213  -78.010  45.137  1
202498  101.218  -78.009  45.123  1
202499  101.224  -78.009  45.109  1
202500  101.247  -78.019  45.095  1
202501  101.285  -78.040  45.081  1
202502  101.324  -78.060  45.066  1
202503  101.363  -78.081  45.051  1
202504  101.402  -78.100  45.035  1
202505  101.439  -78.119  45.020  1
202506  101.475  -78.135  45.004  1
202507  101.512  -78.152  44.988  1
202508  101.533  -78.164  44.973  1
202509  101.550  -78.175  44.957  1
202510  101.567  -78.186  44.942  1
202511  101.587  -78.197  44.926  1
202512  101.611  -78.211  44.910  1
202513  101.635  -78.224  44.893  1
202514  101.660  -78.237  44.876  1
202515  101.684  -78.250  44.860  1
202516  101.709  -78.263  44.843  1
202517  101.734  -78.277  44.825  1
202518  101.758  -78.290  44.809  1
202519  101.781  -78.303  44.793  1
202520  101.802  -78.314  44.777  1
202521  101.822  -78.326  44.762  1
202522  101.842  -78.337  44.748  1
202523  101.863  -78.349  44.734  1
202524  101.883  -78.360  44.719  1
202525  101.904  -78.372  44.703  1
202526  101.924  -78.383  44.689  1
202527  101.944  -78.395  44.675  1
202528  101.973  -78.406  44.662  1
202529  102.007  -78.416  44.647  1
202530  102.045  -78.432  44.632  1
202531  102.086  -78.453  44.616  1
202532  102.127  -78.474  44.601  1
202533  102.168  -78.496  44.585  1
202534  102.205  -78.517  44.570  1
202535  102.236  -78.540  44.555  1
202536  102.267  -78.562  44.539  1
202537  102.304  -78.584  44.524  1
202538  102.351  -78.607  44.509  1
202539  102.398  -78.630  44.494  1
202540  102.445  -78.651  44.479  1
202541  102.492  -78.674  44.465  1
202542  102.551  -78.686  44.449  1
202543  102.567  -78.689  44.434  1
202544  102.582  -78.691  44.419  1
202545  102.597  -78.693  44.404  1
202546  102.613  -78.695  44.388  1
202547  102.628  -78.698  44.374  1
202548  102.644  -78.700  44.359  1
202549  102.659  -78.702  44.344  1
202550  102.675  -78.705  44.329  1
202551  102.690  -78.707  44.313  1
202552  102.705  -78.709  44.298  1
202553  102.721  -78.711  44.282  1
202554  102.737  -78.714  44.266  1
202839  93.516  -76.039  54.011  1
202840  93.535  -76.042  54.027  1
202841  93.553  -76.046  54.042  1
202842  93.571  -76.049  54.055  1
202843  93.589  -76.052  54.069  1
202844  93.608  -76.056  54.085  1
202845  93.626  -76.059  54.100  1
202846  93.644  -76.062  54.116  1
202847  93.662  -76.067  54.133  1
202848  93.665  -76.101  54.147  1
202849  93.680  -76.121  54.161  1
202850  93.712  -76.114  54.175  1
202851  93.752  -76.094  54.189  1
202852  93.770  -76.088  54.202  1
202853  93.788  -76.081  54.215  1
202854  93.806  -76.074  54.232  1
202855  93.825  -76.066  54.246  1
202856  93.844  -76.060  54.261  1
202857  93.864  -76.052  54.275  1
202858  93.898  -76.047  54.289  1
202859  93.926  -76.041  54.301  1
202860  93.947  -76.036  54.315  1
202861  93.968  -76.031  54.329  1
202862  93.994  -76.029  54.337  1
202863  94.025  -76.032  54.341  1
202864  94.055  -76.033  54.343  1
202865  94.086  -76.035  54.343  1
202866  94.116  -76.035  54.344  1
202867  94.143  -76.032  54.343  1
202868  94.171  -76.028  54.340  1
202869  94.199  -76.025  54.331  1
202870  94.224  -76.022  54.319  1
202871  94.242  -76.021  54.303  1
202872  94.260  -76.019  54.283  1
202873  94.278  -76.018  54.258  1
202874  94.295  -76.017  54.229  1
202875  94.313  -76.016  54.196  1
202876  94.331  -76.015  54.161  1
202877  94.349  -76.013  54.126  1
202878  94.366  -76.012  54.091  1
202879  94.384  -76.011  54.057  1
202880  94.402  -76.010  54.024  1
202881  94.419  -76.008  53.989  1
202882  94.437  -76.007  53.952  1
202883  94.456  -76.008  53.913  1
202884  94.470  -76.018  53.875  1
202885  94.484  -76.028  53.835  1
202886  94.498  -76.035  53.797  1
202887  94.512  -76.041  53.762  1
202888  94.526  -76.048  53.732  1
202889  94.540  -76.055  53.700  1
202890  94.554  -76.063  53.669  1
202891  94.568  -76.069  53.638  1
202892  94.582  -76.076  53.609  1
202893  94.597  -76.083  53.585  1
202894  94.610  -76.090  53.562  1
202895  94.624  -76.097  53.538  1
202896  94.642  -76.107  53.506  1
202897  94.660  -76.116  53.472  1
202898  94.671  -76.121  53.438  1
202899  94.682  -76.126  53.407  1
202900  94.693  -76.132  53.379  1
202901  94.704  -76.136  53.352  1
202902  94.716  -76.141  53.324  1
202903  94.727  -76.147  53.292  1
202904  94.738  -76.152  53.259  1
202905  94.749  -76.157  53.225  1
202906  94.760  -76.162  53.192  1
202907  94.771  -76.167  53.161  1
202908  94.782  -76.173  53.132  1
202909  94.793  -76.177  53.101  1
202910  94.805  -76.182  53.068  1
202911  94.816  -76.188  53.034  1
202912  94.827  -76.193  53.000  1
202913  94.838  -76.198  52.965  1
202914  94.849  -76.203  52.929  1
202915  94.860  -76.208  52.889  1
202916  94.872  -76.213  52.848  1
202917  94.883  -76.218  52.805  1
202918  94.894  -76.223  52.762  1
202919  94.905  -76.226  52.721  1
202920  94.916  -76.230  52.678  1
202921  94.927  -76.233  52.634  1
202922  94.938  -76.237  52.590  1
202923  94.973  -76.241  52.549  1
202924  94.981  -76.253  52.510  1
202925  94.988  -76.265  52.472  1
202926  94.997  -76.276  52.433  1
202927  95.026  -76.284  52.395  1
202928  95.055  -76.292  52.358  1
202929  95.104  -76.288  52.322  1
202930  95.153  -76.283  52.285  1
202931  95.202  -76.279  52.243  1
202932  95.252  -76.274  52.198  1
202933  95.302  -76.269  52.152  1
202934  95.351  -76.264  52.105  1
202935  95.400  -76.260  52.059  1
202936  95.431  -76.261  52.014  1
202937  95.455  -76.267  51.971  1
202938  95.477  -76.271  51.930  1
202939  95.500  -76.276  51.890  1
202940  95.524  -76.279  51.849  1
202941  95.550  -76.281  51.807  1
202942  95.576  -76.282  51.765  1
202943  95.601  -76.285  51.724  1
202944  95.626  -76.286  51.684  1
202945  95.653  -76.285  51.647  1
202946  95.680  -76.282  51.613  1
202947  95.707  -76.279  51.581  1
202948  95.734  -76.276  51.548  1
202949  95.757  -76.281  51.513  1
202950  95.780  -76.285  51.474  1
202951  95.803  -76.289  51.432  1
202952  95.827  -76.294  51.387  1
202953  95.853  -76.299  51.341  1
202954  95.880  -76.304  51.297  1
202955  95.905  -76.310  51.253  1
202956  95.926  -76.315  51.208  1
202957  95.948  -76.320  51.164  1
202958  95.969  -76.326  51.118  1
202959  95.991  -76.331  51.071  1
202960  96.012  -76.336  51.025  1
202961  96.034  -76.341  50.981  1
202962  96.055  -76.342  50.937  1
202963  96.076  -76.344  50.894  1
202964  96.095  -76.343  50.856  1
202965  96.114  -76.343  50.820  1
202966  96.134  -76.342  50.787  1
202967  96.153  -76.342  50.754  1
202968  96.170  -76.342  50.722  1
202969  96.184  -76.345  50.687  1
202970  96.197  -76.348  50.651  1
202971  96.210  -76.351  50.616  1
202972  96.224  -76.354  50.581  1
202973  96.237  -76.357  50.546  1
202974  96.251  -76.360  50.513  1
202975  96.265  -76.364  50.482  1
202976  96.278  -76.367  50.451  1
202977  96.295  -76.377  50.426  1
202978  96.312  -76.387  50.404  1
202979  96.329  -76.396  50.382  1
202980  96.346  -76.406  50.362  1
202981  96.363  -76.415  50.341  1
202982  96.400  -76.428  50.319  1
202983  96.459  -76.445  50.295  1
202984  96.505  -76.473  50.272  1
202985  96.516  -76.483  50.249  1
202986  96.526  -76.493  50.226  1
202987  96.539  -76.505  50.199  1
202988  96.565  -76.508  50.169  1
202989  96.591  -76.511  50.137  1
202990  96.616  -76.513  50.106  1
202991  96.643  -76.516  50.073  1
202992  96.669  -76.518  50.038  1
202993  96.710  -76.512  50.002  1
202994  96.755  -76.504  49.964  1
202995  96.801  -76.495  49.927  1
202996  96.847  -76.487  49.888  1
202997  96.892  -76.479  49.849  1
202998  96.939  -76.471  49.811  1
202999  96.980  -76.467  49.773  1
203000  96.975  -76.464  49.734  1
203001  96.969  -76.471  49.695  1
203002  96.963  -76.478  49.656  1
203003  96.957  -76.486  49.617  1
203004  96.951  -76.492  49.578  1
203005  96.944  -76.500  49.542  1
203006  96.938  -76.507  49.508  1
203007  97.011  -76.537  49.475  1
203008  97.049  -76.568  49.445  1
203009  97.065  -76.597  49.417  1
203010  97.080  -76.625  49.392  1
203011  97.095  -76.654  49.369  1
203012  97.111  -76.682  49.347  1
203013  97.126  -76.710  49.329  1
203014  97.148  -76.728  49.310  1
203015  97.186  -76.722  49.290  1
203016  97.225  -76.715  49.269  1
203017  97.263  -76.709  49.246  1
203018  97.297  -76.707  49.221  1
203019  97.309  -76.728  49.196  1
203020  97.320  -76.749  49.169  1
203021  97.332  -76.771  49.141  1
203022  97.363  -76.793  49.112  1
203023  97.428  -76.814  49.082  1
203024  97.463  -76.834  49.052  1
203025  97.478  -76.850  49.020  1
203026  97.487  -76.859  48.990  1
203027  97.496  -76.869  48.960  1
203028  97.504  -76.880  48.930  1
203029  97.513  -76.890  48.900  1
203030  97.521  -76.900  48.872  1
203031  97.530  -76.909  48.843  1
203032  97.538  -76.920  48.814  1
203033  97.546  -76.934  48.785  1
203034  97.556  -76.948  48.756  1
203035  97.580  -76.947  48.727  1
203036  97.618  -76.957  48.698  1
203037  97.657  -76.968  48.669  1
203038  97.697  -76.977  48.639  1
203039  97.737  -76.984  48.609  1
203040  97.766  -76.991  48.579  1
203041  97.789  -76.997  48.550  1
203042  97.812  -77.003  48.522  1
203043  97.835  -77.008  48.493  1
203044  97.858  -77.014  48.464  1
203045  97.881  -77.019  48.434  1
203046  97.904  -77.025  48.404  1
203047  97.928  -77.031  48.374  1
203048  97.951  -77.034  48.343  1
203049  97.976  -77.018  48.312  1
203050  98.001  -77.002  48.282  1
203051  98.026  -76.986  48.253  1
203052  98.051  -76.969  48.223  1
203053  98.075  -76.954  48.193  1
203054  98.093  -76.947  48.162  1
203055  98.113  -76.949  48.130  1
203056  98.133  -76.952  48.097  1
203057  98.152  -76.956  48.064  1
203058  98.172  -76.959  48.031  1
203059  98.192  -76.963  47.998  1
203060  98.212  -76.967  47.965  1
203061  98.232  -76.970  47.932  1
203062  98.251  -76.974  47.900  1
203063  98.272  -76.978  47.868  1
203064  98.291  -76.981  47.836  1
203065  98.311  -76.987  47.805  1
203066  98.329  -77.003  47.774  1
203067  98.348  -77.019  47.746  1
203068  98.369  -77.025  47.717  1
203069  98.393  -77.019  47.688  1
203070  98.417  -77.013  47.658  1
203071  98.441  -77.007  47.630  1
203072  98.465  -77.002  47.604  1
203073  98.490  -76.996  47.580  1
203074  98.514  -76.990  47.556  1
203075  98.537  -76.984  47.532  1
203076  98.562  -76.979  47.508  1
203077  98.586  -76.973  47.484  1
203078  98.610  -76.968  47.461  1
203079  98.617  -76.975  47.438  1
203080  98.610  -76.993  47.414  1
203081  98.603  -77.010  47.389  1
203082  98.596  -77.028  47.364  1
203083  98.610  -77.038  47.338  1
203084  98.643  -77.040  47.312  1
203085  98.676  -77.042  47.285  1
203086  98.709  -77.044  47.259  1
203087  98.756  -77.050  47.231  1
203088  98.806  -77.057  47.203  1
203089  98.856  -77.065  47.175  1
203090  98.901  -77.072  47.145  1
203091  98.914  -77.086  47.115  1
203092  98.928  -77.100  47.085  1
203093  98.942  -77.114  47.056  1
203094  98.956  -77.128  47.028  1
203095  98.970  -77.141  47.001  1
203096  98.984  -77.155  46.977  1
203097  98.998  -77.169  46.951  1
203098  99.011  -77.182  46.926  1
203099  99.025  -77.196  46.901  1
203100  99.040  -77.210  46.877  1
203101  99.054  -77.220  46.850  1
203102  99.069  -77.232  46.823  1
203103  99.083  -77.242  46.796  1
203104  99.098  -77.254  46.767  1
203105  99.111  -77.260  46.736  1
203106  99.124  -77.264  46.707  1
203107  99.137  -77.269  46.679  1
203108  99.149  -77.274  46.651  1
203109  99.162  -77.279  46.622  1
203110  99.175  -77.284  46.594  1
203111  99.188  -77.289  46.567  1
203112  99.201  -77.294  46.540  1
203113  99.213  -77.299  46.514  1
203114  99.226  -77.304  46.488  1
203115  99.239  -77.309  46.463  1
203116  99.252  -77.314  46.438  1
203117  99.264  -77.320  46.413  1
203118  99.275  -77.325  46.388  1
203119  99.303  -77.329  46.362  1
203120  99.335  -77.333  46.338  1
203121  99.367  -77.338  46.314  1
203122  99.398  -77.341  46.291  1
203123  99.430  -77.346  46.267  1
203124  99.462  -77.350  46.244  1
203125  99.493  -77.354  46.220  1
203126  99.525  -77.358  46.197  1
203127  99.557  -77.362  46.175  1
203128  99.586  -77.366  46.154  1
203129  99.616  -77.369  46.132  1
203130  99.645  -77.373  46.111  1
203131  99.675  -77.376  46.089  1
203132  99.704  -77.379  46.069  1
203133  99.742  -77.382  46.050  1
203134  99.762  -77.382  46.031  1
203135  99.774  -77.374  46.013  1
203136  99.786  -77.366  45.995  1
203137  99.798  -77.358  45.977  1
203138  99.810  -77.350  45.959  1
203139  99.822  -77.341  45.942  1
203140  99.834  -77.334  45.925  1
203141  99.846  -77.326  45.910  1
203142  99.863  -77.323  45.895  1
203143  99.897  -77.337  45.880  1
203144  99.931  -77.351  45.864  1
203145  99.965  -77.364  45.848  1
203146  99.999  -77.378  45.833  1
203147  100.033  -77.392  45.818  1
203148  100.067  -77.405  45.804  1
203149  100.101  -77.419  45.790  1
203150  100.135  -77.432  45.776  1
203151  100.179  -77.445  45.762  1
203152  100.201  -77.457  45.748  1
203153  100.216  -77.468  45.734  1
203154  100.234  -77.476  45.721  1
203155  100.253  -77.483  45.708  1
203156  100.271  -77.490  45.693  1
203157  100.290  -77.497  45.680  1
203158  100.309  -77.504  45.668  1
203159  100.327  -77.511  45.655  1
203160  100.345  -77.518  45.642  1
203161  100.364  -77.526  45.627  1
203162  100.382  -77.542  45.614  1
203163  100.401  -77.558  45.602  1
203164  100.420  -77.574  45.589  1
203165  100.446  -77.589  45.575  1
203166  100.479  -77.603  45.562  1
203167  100.502  -77.609  45.548  1
203168  100.525  -77.614  45.533  1
203169  100.547  -77.620  45.520  1
203170  100.570  -77.625  45.506  1
203171  100.593  -77.635  45.492  1
203172  100.615  -77.645  45.478  1
203173  100.638  -77.655  45.465  1
203174  100.661  -77.665  45.451  1
203175  100.684  -77.676  45.436  1
203176  100.707  -77.686  45.422  1
203177  100.734  -77.704  45.408  1
203178  100.760  -77.721  45.394  1
203179  100.786  -77.737  45.381  1
203180  100.813  -77.754  45.367  1
203181  100.840  -77.771  45.353  1
203182  100.866  -77.788  45.339  1
203183  100.893  -77.805  45.326  1
203184  100.920  -77.821  45.313  1
203185  100.947  -77.841  45.299  1
203186  100.975  -77.868  45.285  1
203187  101.003  -77.893  45.272  1
203188  101.027  -77.912  45.260  1
203189  101.050  -77.923  45.247  1
203190  101.072  -77.935  45.235  1
203191  101.095  -77.947  45.223  1
203192  101.117  -77.959  45.210  1
203193  101.139  -77.971  45.197  1
203194  101.162  -77.983  45.185  1
203195  101.184  -77.995  45.172  1
203196  101.207  -78.001  45.159  1
203197  101.231  -78.004  45.145  1
203198  101.240  -78.004  45.132  1
203199  101.245  -78.003  45.118  1
203200  101.250  -78.003  45.104  1
203201  101.259  -78.005  45.090  1
203202  101.298  -78.025  45.076  1
203203  101.337  -78.046  45.061  1
203204  101.376  -78.065  45.046  1
203205  101.414  -78.086  45.030  1
203206  101.453  -78.106  45.015  1
203207  101.491  -78.125  44.999  1
203208  101.527  -78.142  44.984  1
203209  101.553  -78.155  44.968  1
203210  101.570  -78.166  44.953  1
203211  101.590  -78.178  44.937  1
203212  101.614  -78.191  44.921  1
203213  101.638  -78.204  44.905  1
203214  101.663  -78.217  44.888  1
203215  101.687  -78.231  44.872  1
203216  101.712  -78.244  44.855  1
203217  101.733  -78.256  44.838  1
203218  101.753  -78.267  44.821  1
203219  101.773  -78.279  44.805  1
203220  101.793  -78.290  44.788  1
203221  101.814  -78.301  44.772  1
203222  101.834  -78.313  44.756  1
203223  101.854  -78.324  44.741  1
203224  101.875  -78.335  44.727  1
203225  101.895  -78.347  44.712  1
203226  101.915  -78.359  44.697  1
203227  101.936  -78.370  44.683  1
203228  101.962  -78.382  44.669  1
203229  101.996  -78.392  44.656  1
203230  102.032  -78.402  44.642  1
203231  102.070  -78.420  44.627  1
203232  102.111  -78.441  44.611  1
203233  102.153  -78.463  44.596  1
203234  102.193  -78.484  44.580  1
203235  102.235  -78.505  44.565  1
203236  102.272  -78.526  44.550  1
203237  102.304  -78.548  44.534  1
203238  102.335  -78.571  44.519  1
203239  102.366  -78.593  44.504  1
203240  102.399  -78.615  44.489  1
203241  102.447  -78.638  44.474  1
203242  102.494  -78.661  44.459  1
203243  102.565  -78.671  44.444  1
203244  102.581  -78.673  44.429  1
203245  102.596  -78.676  44.414  1
203246  102.612  -78.678  44.399  1
203247  102.627  -78.680  44.383  1
203248  102.643  -78.683  44.369  1
203249  102.658  -78.685  44.354  1
203250  102.674  -78.687  44.339  1
203251  102.689  -78.689  44.323  1
203252  102.705  -78.691  44.308  1
203253  102.720  -78.693  44.292  1
203254  102.736  -78.695  44.276  1
203255  102.751  -78.698  44.261  1
203541  93.526  -76.019  54.020  1
203542  93.545  -76.022  54.036  1
203543  93.563  -76.025  54.051  1
203544  93.581  -76.029  54.066  1
203545  93.600  -76.032  54.081  1
203546  93.618  -76.035  54.096  1
203547  93.636  -76.039  54.113  1
203548  93.654  -76.043  54.130  1
203549  93.658  -76.077  54.145  1
203550  93.675  -76.093  54.157  1
203551  93.707  -76.087  54.170  1
203552  93.745  -76.070  54.184  1
203553  93.763  -76.063  54.197  1
203554  93.781  -76.057  54.211  1
203555  93.799  -76.050  54.228  1
203556  93.818  -76.044  54.244  1
203557  93.836  -76.036  54.260  1
203558  93.855  -76.029  54.276  1
203559  93.887  -76.023  54.291  1
203560  93.921  -76.018  54.306  1
203561  93.948  -76.013  54.321  1
203562  93.969  -76.007  54.337  1
203563  93.996  -76.007  54.344  1
203564  94.027  -76.009  54.349  1
203565  94.058  -76.010  54.350  1
203566  94.085  -76.007  54.349  1
203567  94.114  -76.003  54.348  1
203568  94.141  -76.000  54.346  1
203569  94.169  -75.997  54.342  1
203570  94.197  -75.994  54.332  1
203571  94.224  -75.991  54.320  1
203572  94.245  -75.988  54.304  1
203573  94.262  -75.988  54.284  1
203574  94.280  -75.986  54.260  1
203575  94.298  -75.985  54.233  1
203576  94.316  -75.984  54.202  1
203577  94.333  -75.982  54.165  1
203578  94.351  -75.981  54.130  1
203579  94.369  -75.980  54.096  1
203580  94.387  -75.978  54.063  1
203581  94.404  -75.978  54.030  1
203582  94.422  -75.976  53.996  1
203583  94.441  -75.979  53.959  1
203584  94.459  -75.983  53.920  1
203585  94.473  -75.992  53.881  1
203586  94.487  -76.002  53.841  1
203587  94.502  -76.011  53.802  1
203588  94.516  -76.021  53.765  1
203589  94.530  -76.030  53.733  1
203590  94.544  -76.040  53.699  1
203591  94.559  -76.049  53.666  1
203592  94.573  -76.057  53.633  1
203593  94.587  -76.063  53.602  1
203594  94.601  -76.070  53.576  1
203595  94.615  -76.077  53.551  1
203596  94.629  -76.084  53.526  1
203597  94.644  -76.091  53.494  1
203598  94.661  -76.100  53.460  1
203599  94.672  -76.106  53.427  1
203600  94.683  -76.110  53.396  1
203601  94.694  -76.116  53.367  1
203602  94.705  -76.121  53.339  1
203603  94.716  -76.126  53.311  1
203604  94.728  -76.131  53.280  1
203605  94.739  -76.136  53.246  1
203606  94.750  -76.141  53.212  1
203607  94.761  -76.146  53.179  1
203608  94.772  -76.151  53.147  1
203609  94.783  -76.157  53.117  1
203610  94.794  -76.161  53.087  1
203611  94.805  -76.164  53.055  1
203612  94.816  -76.168  53.023  1
203613  94.827  -76.172  52.990  1
203614  94.838  -76.176  52.956  1
203615  94.849  -76.179  52.922  1
203616  94.860  -76.182  52.884  1
203617  94.872  -76.186  52.844  1
203618  94.883  -76.189  52.804  1
203619  94.894  -76.193  52.763  1
203620  94.905  -76.197  52.723  1
203621  94.916  -76.201  52.681  1
203622  94.927  -76.204  52.639  1
203623  94.938  -76.207  52.597  1
203624  94.988  -76.207  52.557  1
203625  95.036  -76.210  52.518  1
203626  95.043  -76.223  52.481  1
203627  95.050  -76.234  52.444  1
203628  95.067  -76.245  52.408  1
203629  95.096  -76.252  52.373  1
203630  95.124  -76.260  52.341  1
203631  95.153  -76.268  52.307  1
203632  95.199  -76.265  52.267  1
203633  95.249  -76.260  52.223  1
203634  95.298  -76.256  52.176  1
203635  95.347  -76.251  52.127  1
203636  95.397  -76.247  52.080  1
203637  95.436  -76.246  52.034  1
203638  95.459  -76.251  51.989  1
203639  95.482  -76.255  51.947  1
203640  95.505  -76.260  51.905  1
203641  95.530  -76.261  51.864  1
203642  95.556  -76.263  51.823  1
203643  95.582  -76.264  51.781  1
203644  95.608  -76.263  51.739  1
203645  95.635  -76.260  51.698  1
203646  95.662  -76.257  51.659  1
203647  95.689  -76.255  51.622  1
203648  95.716  -76.252  51.587  1
203649  95.741  -76.253  51.553  1
203650  95.764  -76.257  51.517  1
203651  95.788  -76.261  51.479  1
203652  95.810  -76.266  51.440  1
203653  95.833  -76.270  51.398  1
203654  95.858  -76.275  51.355  1
203655  95.884  -76.280  51.312  1
203656  95.910  -76.285  51.268  1
203657  95.932  -76.291  51.223  1
203658  95.953  -76.296  51.177  1
203659  95.974  -76.301  51.131  1
203660  95.996  -76.307  51.084  1
203661  96.017  -76.310  51.038  1
203662  96.038  -76.312  50.993  1
203663  96.060  -76.314  50.949  1
203664  96.081  -76.317  50.906  1
203665  96.102  -76.319  50.868  1
203666  96.122  -76.319  50.833  1
203667  96.142  -76.318  50.800  1
203668  96.161  -76.317  50.767  1
203669  96.177  -76.319  50.735  1
203670  96.190  -76.322  50.700  1
203671  96.204  -76.325  50.666  1
203672  96.217  -76.328  50.631  1
203673  96.231  -76.331  50.598  1
203674  96.244  -76.333  50.565  1
203675  96.257  -76.337  50.533  1
203676  96.269  -76.342  50.502  1
203677  96.287  -76.351  50.472  1
203678  96.311  -76.366  50.446  1
203679  96.329  -76.376  50.424  1
203680  96.346  -76.386  50.403  1
203681  96.363  -76.395  50.383  1
203682  96.380  -76.404  50.363  1
203683  96.402  -76.414  50.342  1
203684  96.461  -76.432  50.320  1
203685  96.504  -76.443  50.297  1
203686  96.530  -76.451  50.273  1
203687  96.541  -76.464  50.248  1
203688  96.551  -76.477  50.219  1
203689  96.572  -76.483  50.187  1
203690  96.596  -76.487  50.155  1
203691  96.621  -76.492  50.123  1
203692  96.647  -76.494  50.090  1
203693  96.673  -76.497  50.056  1
203694  96.713  -76.492  50.020  1
203695  96.758  -76.483  49.983  1
203696  96.805  -76.477  49.944  1
203697  96.856  -76.472  49.905  1
203698  96.906  -76.468  49.865  1
203699  96.949  -76.464  49.828  1
203700  96.956  -76.455  49.790  1
203701  96.954  -76.445  49.751  1
203702  96.941  -76.445  49.712  1
203703  96.935  -76.453  49.672  1
203704  96.929  -76.460  49.633  1
203705  96.923  -76.467  49.595  1
203706  96.916  -76.474  49.559  1
203707  96.945  -76.492  49.525  1
203708  97.033  -76.528  49.492  1
203709  97.048  -76.557  49.461  1
203710  97.064  -76.585  49.432  1
203711  97.079  -76.613  49.407  1
203712  97.094  -76.642  49.384  1
203713  97.109  -76.670  49.363  1
203714  97.124  -76.699  49.344  1
203715  97.140  -76.727  49.325  1
203716  97.169  -76.734  49.304  1
203717  97.207  -76.728  49.283  1
203718  97.245  -76.721  49.260  1
203719  97.284  -76.715  49.237  1
203720  97.322  -76.708  49.211  1
203721  97.340  -76.724  49.185  1
203722  97.352  -76.745  49.156  1
203723  97.375  -76.766  49.127  1
203724  97.438  -76.787  49.096  1
203725  97.455  -76.806  49.065  1
203726  97.472  -76.823  49.033  1
203727  97.480  -76.833  49.001  1
203728  97.489  -76.843  48.970  1
203729  97.498  -76.853  48.940  1
203730  97.506  -76.863  48.911  1
203731  97.515  -76.873  48.882  1
203732  97.523  -76.883  48.853  1
203733  97.532  -76.893  48.824  1
203734  97.540  -76.903  48.796  1
203735  97.551  -76.913  48.767  1
203736  97.580  -76.925  48.738  1
203737  97.618  -76.935  48.709  1
203738  97.657  -76.945  48.679  1
203739  97.696  -76.955  48.650  1
203740  97.736  -76.963  48.620  1
203741  97.777  -76.971  48.590  1
203742  97.812  -76.978  48.561  1
203743  97.835  -76.984  48.532  1
203744  97.858  -76.990  48.502  1
203745  97.881  -76.995  48.474  1
203746  97.904  -77.001  48.444  1
203747  97.928  -77.006  48.413  1
203748  97.951  -77.012  48.383  1
203749  97.974  -77.018  48.352  1
203750  97.999  -77.001  48.321  1
203751  98.024  -76.985  48.291  1
203752  98.049  -76.969  48.262  1
203753  98.074  -76.953  48.232  1
203754  98.093  -76.944  48.202  1
203755  98.112  -76.937  48.171  1
203756  98.131  -76.929  48.139  1
203757  98.149  -76.921  48.107  1
203758  98.169  -76.923  48.075  1
203759  98.189  -76.927  48.043  1
203760  98.208  -76.931  48.009  1
203761  98.228  -76.934  47.976  1
203762  98.248  -76.938  47.943  1
203763  98.268  -76.941  47.910  1
203764  98.288  -76.945  47.878  1
203765  98.307  -76.949  47.845  1
203766  98.327  -76.955  47.814  1
203767  98.346  -76.972  47.783  1
203768  98.364  -76.987  47.755  1
203769  98.382  -77.003  47.726  1
203770  98.403  -77.012  47.697  1
203771  98.427  -77.006  47.667  1
203772  98.451  -77.000  47.638  1
203773  98.476  -76.994  47.612  1
203774  98.500  -76.989  47.588  1
203775  98.523  -76.983  47.565  1
203776  98.548  -76.978  47.542  1
203777  98.572  -76.972  47.519  1
203778  98.596  -76.966  47.495  1
203779  98.620  -76.961  47.473  1
203780  98.632  -76.964  47.449  1
203781  98.625  -76.982  47.425  1
203782  98.618  -77.000  47.400  1
203783  98.611  -77.017  47.373  1
203784  98.633  -77.024  47.347  1
203785  98.665  -77.026  47.320  1
203786  98.699  -77.028  47.292  1
203787  98.731  -77.030  47.266  1
203788  98.770  -77.034  47.238  1
203789  98.819  -77.041  47.208  1
203790  98.870  -77.048  47.179  1
203791  98.912  -77.056  47.149  1
203792  98.926  -77.070  47.118  1
203793  98.940  -77.084  47.087  1
203794  98.954  -77.097  47.059  1
203795  98.968  -77.112  47.029  1
203796  98.982  -77.125  47.001  1
203797  98.995  -77.139  46.975  1
203798  99.009  -77.153  46.949  1
203799  99.023  -77.166  46.924  1
203800  99.037  -77.180  46.900  1
203801  99.051  -77.194  46.874  1
203802  99.065  -77.207  46.848  1
203803  99.080  -77.217  46.821  1
203804  99.094  -77.229  46.794  1
203805  99.109  -77.238  46.765  1
203806  99.122  -77.244  46.735  1
203807  99.135  -77.249  46.705  1
203808  99.147  -77.254  46.677  1
203809  99.160  -77.259  46.648  1
203810  99.173  -77.263  46.620  1
203811  99.186  -77.269  46.592  1
203812  99.199  -77.274  46.564  1
203813  99.211  -77.279  46.537  1
203814  99.224  -77.284  46.510  1
203815  99.237  -77.288  46.485  1
203816  99.250  -77.294  46.459  1
203817  99.262  -77.298  46.434  1
203818  99.281  -77.298  46.409  1
203819  99.289  -77.304  46.384  1
203820  99.319  -77.307  46.358  1
203821  99.348  -77.311  46.335  1
203822  99.377  -77.314  46.311  1
203823  99.407  -77.318  46.287  1
203824  99.436  -77.321  46.264  1
203825  99.466  -77.325  46.241  1
203826  99.495  -77.328  46.218  1
203827  99.525  -77.332  46.195  1
203828  99.555  -77.335  46.172  1
203829  99.584  -77.338  46.151  1
203830  99.614  -77.341  46.130  1
203831  99.643  -77.345  46.109  1
203832  99.683  -77.350  46.087  1
203833  99.733  -77.357  46.068  1
203834  99.761  -77.352  46.048  1
203835  99.792  -77.364  46.029  1
203836  99.807  -77.362  46.011  1
203837  99.820  -77.354  45.993  1
203838  99.832  -77.346  45.975  1
203839  99.844  -77.338  45.958  1
203840  99.856  -77.330  45.941  1
203841  99.868  -77.323  45.924  1
203842  99.879  -77.314  45.907  1
203843  99.892  -77.306  45.893  1
203844  99.925  -77.320  45.877  1
203845  99.960  -77.333  45.861  1
203846  99.993  -77.347  45.845  1
203847  100.028  -77.360  45.830  1
203848  100.061  -77.375  45.815  1
203849  100.096  -77.389  45.800  1
203850  100.129  -77.402  45.786  1
203851  100.163  -77.416  45.771  1
203852  100.197  -77.429  45.757  1
203853  100.223  -77.440  45.743  1
203854  100.243  -77.447  45.729  1
203855  100.262  -77.454  45.716  1
203856  100.281  -77.461  45.702  1
203857  100.299  -77.469  45.688  1
203858  100.318  -77.476  45.675  1
203859  100.336  -77.483  45.663  1
203860  100.355  -77.490  45.650  1
203861  100.373  -77.497  45.637  1
203862  100.392  -77.507  45.623  1
203863  100.410  -77.523  45.610  1
203864  100.429  -77.539  45.598  1
203865  100.448  -77.555  45.585  1
203866  100.471  -77.571  45.571  1
203867  100.501  -77.583  45.557  1
203868  100.524  -77.589  45.543  1
203869  100.546  -77.594  45.529  1
203870  100.569  -77.602  45.516  1
203871  100.592  -77.612  45.502  1
203872  100.614  -77.622  45.487  1
203873  100.637  -77.633  45.473  1
203874  100.659  -77.642  45.460  1
203875  100.682  -77.653  45.446  1
203876  100.705  -77.663  45.432  1
203877  100.728  -77.675  45.417  1
203878  100.755  -77.692  45.404  1
203879  100.782  -77.708  45.391  1
203880  100.809  -77.726  45.377  1
203881  100.835  -77.743  45.363  1
203882  100.862  -77.759  45.349  1
203883  100.889  -77.776  45.336  1
203884  100.915  -77.793  45.323  1
203885  100.942  -77.810  45.309  1
203886  100.968  -77.827  45.296  1
203887  100.995  -77.843  45.282  1
203888  101.022  -77.861  45.269  1
203889  101.050  -77.887  45.256  1
203890  101.077  -77.913  45.243  1
203891  101.101  -77.928  45.231  1
203892  101.123  -77.939  45.218  1
203893  101.145  -77.951  45.206  1
203894  101.168  -77.963  45.193  1
203895  101.190  -77.975  45.179  1
203896  101.212  -77.987  45.166  1
203897  101.236  -77.996  45.153  1
203898  101.259  -77.998  45.140  1
203899  101.266  -77.998  45.127  1
203900  101.271  -77.997  45.113  1
203901  101.276  -77.997  45.099  1
203902  101.282  -77.996  45.084  1
203903  101.311  -78.011  45.070  1
203904  101.349  -78.031  45.055  1
203905  101.388  -78.051  45.040  1
203906  101.427  -78.072  45.025  1
203907  101.466  -78.092  45.009  1
203908  101.504  -78.112  44.994  1
203909  101.543  -78.131  44.978  1
203910  101.573  -78.147  44.963  1
203911  101.592  -78.158  44.948  1
203912  101.617  -78.171  44.932  1
203913  101.641  -78.184  44.916  1
203914  101.663  -78.197  44.900  1
203915  101.683  -78.208  44.883  1
203916  101.704  -78.219  44.867  1
203917  101.724  -78.231  44.850  1
203918  101.744  -78.242  44.834  1
203919  101.765  -78.254  44.818  1
203920  101.785  -78.266  44.802  1
203921  101.806  -78.277  44.785  1
203922  101.826  -78.288  44.767  1
203923  101.846  -78.300  44.750  1
203924  101.867  -78.311  44.735  1
203925  101.887  -78.322  44.721  1
203926  101.907  -78.335  44.706  1
203927  101.927  -78.346  44.691  1
203928  101.951  -78.357  44.677  1
203929  101.986  -78.367  44.663  1
203930  102.021  -78.378  44.649  1
203931  102.055  -78.388  44.635  1
203932  102.095  -78.407  44.620  1
203933  102.136  -78.429  44.605  1
203934  102.177  -78.451  44.590  1
203935  102.219  -78.472  44.575  1
203936  102.259  -78.493  44.559  1
203937  102.301  -78.514  44.544  1
203938  102.340  -78.535  44.528  1
203939  102.372  -78.557  44.513  1
203940  102.403  -78.580  44.499  1
203941  102.434  -78.602  44.483  1
203942  102.465  -78.624  44.468  1
203943  102.500  -78.645  44.453  1
203944  102.580  -78.655  44.438  1
203945  102.595  -78.658  44.423  1
203946  102.611  -78.660  44.409  1
203947  102.626  -78.662  44.394  1
203948  102.642  -78.664  44.378  1
203949  102.657  -78.667  44.363  1
203950  102.673  -78.669  44.347  1
203951  102.688  -78.671  44.332  1
203952  102.704  -78.673  44.317  1
203953  102.719  -78.676  44.301  1
203954  102.735  -78.678  44.286  1
203955  102.755  -78.680  44.270  1
203956  102.781  -78.683  44.255  1
204242  93.518  -75.996  54.015  1
204243  93.537  -75.999  54.031  1
204244  93.555  -76.003  54.047  1
204245  93.573  -76.006  54.062  1
204246  93.591  -76.009  54.077  1
204247  93.610  -76.013  54.093  1
204248  93.628  -76.016  54.111  1
204249  93.646  -76.019  54.128  1
204250  93.650  -76.053  54.143  1
204251  93.669  -76.066  54.156  1
204252  93.702  -76.059  54.168  1
204253  93.738  -76.047  54.180  1
204254  93.757  -76.040  54.193  1
204255  93.775  -76.033  54.207  1
204256  93.793  -76.026  54.224  1
204257  93.811  -76.019  54.240  1
204258  93.829  -76.013  54.257  1
204259  93.847  -76.006  54.278  1
204260  93.877  -76.000  54.295  1
204261  93.910  -75.994  54.313  1
204262  93.944  -75.989  54.330  1
204263  93.971  -75.984  54.346  1
204264  93.999  -75.984  54.351  1
204265  94.028  -75.983  54.355  1
204266  94.056  -75.979  54.356  1
204267  94.083  -75.976  54.355  1
204268  94.111  -75.972  54.352  1
204269  94.139  -75.969  54.348  1
204270  94.167  -75.966  54.342  1
204271  94.195  -75.963  54.332  1
204272  94.222  -75.960  54.319  1
204273  94.247  -75.956  54.303  1
204274  94.265  -75.955  54.284  1
204275  94.282  -75.954  54.261  1
204276  94.300  -75.953  54.236  1
204277  94.318  -75.951  54.206  1
204278  94.336  -75.950  54.170  1
204279  94.353  -75.949  54.134  1
204280  94.371  -75.947  54.101  1
204281  94.389  -75.947  54.069  1
204282  94.407  -75.947  54.037  1
204283  94.426  -75.950  54.004  1
204284  94.445  -75.953  53.968  1
204285  94.462  -75.957  53.929  1
204286  94.477  -75.966  53.890  1
204287  94.491  -75.976  53.851  1
204288  94.505  -75.985  53.811  1
204289  94.520  -75.995  53.772  1
204290  94.534  -76.005  53.738  1
204291  94.548  -76.014  53.701  1
204292  94.562  -76.024  53.666  1
204293  94.576  -76.033  53.632  1
204294  94.591  -76.043  53.600  1
204295  94.605  -76.052  53.571  1
204296  94.619  -76.062  53.544  1
204297  94.633  -76.071  53.518  1
204298  94.647  -76.078  53.485  1
204299  94.661  -76.085  53.452  1
204300  94.672  -76.090  53.418  1
204301  94.683  -76.095  53.386  1
204302  94.694  -76.099  53.356  1
204303  94.705  -76.103  53.328  1
204304  94.716  -76.107  53.299  1
204305  94.728  -76.110  53.268  1
204306  94.739  -76.113  53.234  1
204307  94.750  -76.117  53.201  1
204308  94.761  -76.120  53.167  1
204309  94.772  -76.124  53.135  1
204310  94.783  -76.128  53.104  1
204311  94.794  -76.132  53.073  1
204312  94.805  -76.135  53.040  1
204313  94.816  -76.138  53.008  1
204314  94.827  -76.142  52.975  1
204315  94.838  -76.146  52.942  1
204316  94.849  -76.149  52.908  1
204317  94.860  -76.153  52.872  1
204318  94.872  -76.157  52.834  1
204319  94.883  -76.160  52.796  1
204320  94.894  -76.163  52.759  1
204321  94.905  -76.167  52.720  1
204322  94.916  -76.171  52.681  1
204323  94.927  -76.174  52.642  1
204324  94.938  -76.178  52.603  1
204325  94.986  -76.179  52.565  1
204326  95.049  -76.177  52.527  1
204327  95.098  -76.180  52.490  1
204328  95.106  -76.191  52.455  1
204329  95.113  -76.204  52.421  1
204330  95.136  -76.213  52.388  1
204331  95.165  -76.220  52.359  1
204332  95.193  -76.229  52.327  1
204333  95.222  -76.236  52.290  1
204334  95.251  -76.245  52.247  1
204335  95.295  -76.243  52.200  1
204336  95.344  -76.238  52.149  1
204337  95.394  -76.233  52.102  1
204338  95.440  -76.230  52.056  1
204339  95.463  -76.235  52.008  1
204340  95.486  -76.239  51.963  1
204341  95.511  -76.242  51.919  1
204342  95.536  -76.243  51.877  1
204343  95.563  -76.242  51.837  1
204344  95.590  -76.239  51.795  1
204345  95.617  -76.236  51.754  1
204346  95.644  -76.233  51.713  1
204347  95.672  -76.230  51.671  1
204348  95.698  -76.227  51.632  1
204349  95.726  -76.225  51.594  1
204350  95.749  -76.229  51.558  1
204351  95.771  -76.233  51.522  1
204352  95.795  -76.238  51.486  1
204353  95.817  -76.242  51.448  1
204354  95.840  -76.246  51.409  1
204355  95.863  -76.251  51.368  1
204356  95.887  -76.255  51.326  1
204357  95.914  -76.261  51.282  1
204358  95.937  -76.267  51.237  1
204359  95.958  -76.271  51.190  1
204360  95.979  -76.276  51.143  1
204361  96.001  -76.280  51.096  1
204362  96.022  -76.282  51.050  1
204363  96.043  -76.284  51.005  1
204364  96.064  -76.286  50.961  1
204365  96.086  -76.289  50.918  1
204366  96.107  -76.290  50.881  1
204367  96.128  -76.292  50.846  1
204368  96.150  -76.294  50.813  1
204369  96.169  -76.294  50.780  1
204370  96.184  -76.295  50.748  1
204371  96.197  -76.298  50.714  1
204372  96.210  -76.301  50.679  1
204373  96.223  -76.304  50.646  1
204374  96.236  -76.308  50.614  1
204375  96.249  -76.311  50.583  1
204376  96.261  -76.314  50.552  1
204377  96.273  -76.322  50.522  1
204378  96.285  -76.329  50.492  1
204379  96.307  -76.341  50.466  1
204380  96.331  -76.355  50.443  1
204381  96.355  -76.369  50.423  1
204382  96.379  -76.383  50.404  1
204383  96.397  -76.393  50.385  1
204384  96.414  -76.403  50.365  1
204385  96.461  -76.417  50.344  1
204386  96.491  -76.423  50.319  1
204387  96.521  -76.430  50.294  1
204388  96.550  -76.436  50.267  1
204389  96.567  -76.447  50.237  1
204390  96.580  -76.458  50.205  1
204391  96.604  -76.462  50.173  1
204392  96.629  -76.466  50.140  1
204393  96.654  -76.470  50.108  1
204394  96.680  -76.474  50.074  1
204395  96.722  -76.477  50.038  1
204396  96.772  -76.473  50.001  1
204397  96.823  -76.469  49.962  1
204398  96.874  -76.465  49.922  1
204399  96.919  -76.461  49.882  1
204400  96.925  -76.452  49.845  1
204401  96.931  -76.444  49.808  1
204402  96.937  -76.436  49.769  1
204403  96.915  -76.422  49.730  1
204404  96.906  -76.427  49.689  1
204405  96.900  -76.434  49.650  1
204406  96.894  -76.442  49.613  1
204407  96.888  -76.448  49.576  1
204408  96.975  -76.483  49.542  1
204409  97.031  -76.517  49.509  1
204410  97.047  -76.545  49.477  1
204411  97.062  -76.573  49.447  1
204412  97.078  -76.602  49.422  1
204413  97.093  -76.630  49.400  1
204414  97.108  -76.658  49.379  1
204415  97.123  -76.687  49.359  1
204416  97.139  -76.715  49.339  1
204417  97.154  -76.743  49.319  1
204418  97.190  -76.740  49.298  1
204419  97.228  -76.734  49.275  1
204420  97.266  -76.727  49.252  1
204421  97.305  -76.721  49.227  1
204422  97.343  -76.715  49.200  1
204423  97.371  -76.718  49.171  1
204424  97.386  -76.740  49.141  1
204425  97.430  -76.760  49.109  1
204426  97.448  -76.778  49.077  1
204427  97.465  -76.796  49.045  1
204428  97.474  -76.806  49.012  1
204429  97.483  -76.817  48.980  1
204430  97.491  -76.827  48.950  1
204431  97.500  -76.837  48.921  1
204432  97.508  -76.846  48.892  1
204433  97.517  -76.857  48.863  1
204434  97.525  -76.867  48.835  1
204435  97.542  -76.878  48.806  1
204436  97.566  -76.890  48.778  1
204437  97.589  -76.901  48.749  1
204438  97.618  -76.912  48.720  1
204439  97.657  -76.922  48.690  1
204440  97.696  -76.933  48.660  1
204441  97.735  -76.941  48.631  1
204442  97.776  -76.950  48.600  1
204443  97.816  -76.957  48.571  1
204444  97.856  -76.965  48.542  1
204445  97.881  -76.972  48.511  1
204446  97.904  -76.977  48.483  1
204447  97.928  -76.983  48.453  1
204448  97.951  -76.988  48.422  1
204449  97.974  -76.994  48.391  1
204450  97.998  -77.000  48.360  1
204451  98.022  -76.985  48.330  1
204452  98.047  -76.969  48.300  1
204453  98.072  -76.953  48.271  1
204454  98.094  -76.941  48.240  1
204455  98.112  -76.934  48.209  1
204456  98.131  -76.927  48.179  1
204457  98.149  -76.919  48.147  1
204458  98.168  -76.911  48.116  1
204459  98.186  -76.903  48.085  1
204460  98.205  -76.895  48.053  1
204461  98.225  -76.898  48.020  1
204462  98.244  -76.902  47.986  1
204463  98.264  -76.906  47.953  1
204464  98.284  -76.909  47.921  1
204465  98.304  -76.913  47.886  1
204466  98.324  -76.916  47.854  1
204467  98.343  -76.924  47.823  1
204468  98.362  -76.940  47.793  1
204469  98.380  -76.956  47.765  1
204470  98.398  -76.972  47.736  1
204471  98.417  -76.988  47.707  1
204472  98.437  -76.999  47.677  1
204473  98.461  -76.993  47.649  1
204474  98.485  -76.987  47.622  1
204475  98.509  -76.981  47.597  1
204476  98.533  -76.976  47.573  1
204477  98.558  -76.970  47.550  1
204478  98.582  -76.965  47.528  1
204479  98.605  -76.959  47.506  1
204480  98.630  -76.953  47.483  1
204481  98.646  -76.953  47.459  1
204482  98.639  -76.971  47.435  1
204483  98.633  -76.989  47.409  1
204484  98.626  -77.006  47.382  1
204485  98.655  -77.010  47.355  1
204486  98.688  -77.012  47.328  1
204487  98.721  -77.014  47.299  1
204488  98.754  -77.016  47.272  1
204489  98.787  -77.019  47.243  1
204490  98.833  -77.025  47.213  1
204491  98.883  -77.031  47.183  1
204492  98.924  -77.041  47.152  1
204493  98.938  -77.054  47.120  1
204494  98.951  -77.068  47.088  1
204495  98.966  -77.081  47.059  1
204496  98.979  -77.095  47.028  1
204497  98.993  -77.109  47.000  1
204498  99.007  -77.122  46.973  1
204499  99.021  -77.137  46.946  1
204500  99.035  -77.150  46.921  1
204501  99.049  -77.164  46.896  1
204502  99.063  -77.178  46.871  1
204503  99.076  -77.191  46.845  1
204504  99.091  -77.203  46.818  1
204505  99.106  -77.214  46.791  1
204506  99.120  -77.223  46.762  1
204507  99.132  -77.229  46.732  1
204508  99.145  -77.233  46.703  1
204509  99.158  -77.238  46.674  1
204510  99.171  -77.243  46.645  1
204511  99.184  -77.248  46.618  1
204512  99.196  -77.253  46.590  1
204513  99.209  -77.258  46.561  1
204514  99.222  -77.263  46.533  1
204515  99.237  -77.266  46.507  1
204516  99.263  -77.260  46.481  1
204517  99.289  -77.259  46.455  1
204518  99.311  -77.274  46.430  1
204519  99.316  -77.286  46.404  1
204520  99.302  -77.280  46.379  1
204521  99.316  -77.280  46.354  1
204522  99.346  -77.284  46.331  1
204523  99.375  -77.287  46.307  1
204524  99.405  -77.291  46.284  1
204525  99.434  -77.294  46.261  1
204526  99.464  -77.298  46.238  1
204527  99.493  -77.301  46.214  1
204528  99.522  -77.304  46.192  1
204529  99.552  -77.307  46.170  1
204530  99.581  -77.311  46.148  1
204531  99.616  -77.315  46.127  1
204532  99.667  -77.322  46.107  1
204533  99.718  -77.329  46.085  1
204534  99.749  -77.326  46.066  1
204535  99.779  -77.322  46.047  1
204536  99.813  -77.332  46.028  1
204537  99.838  -77.346  46.009  1
204538  99.853  -77.343  45.991  1
204539  99.865  -77.335  45.974  1
204540  99.877  -77.326  45.956  1
204541  99.889  -77.319  45.939  1
204542  99.901  -77.310  45.922  1
204543  99.913  -77.303  45.906  1
204544  99.925  -77.294  45.890  1
204545  99.954  -77.303  45.873  1
204546  99.988  -77.316  45.857  1
204547  100.021  -77.330  45.841  1
204548  100.055  -77.344  45.826  1
204549  100.089  -77.357  45.810  1
204550  100.123  -77.371  45.795  1
204551  100.157  -77.385  45.780  1
204552  100.191  -77.398  45.765  1
204553  100.224  -77.412  45.751  1
204554  100.235  -77.418  45.737  1
204555  100.253  -77.426  45.724  1
204556  100.272  -77.433  45.711  1
204557  100.291  -77.440  45.697  1
204558  100.311  -77.448  45.683  1
204559  100.330  -77.454  45.670  1
204560  100.349  -77.462  45.657  1
204561  100.368  -77.469  45.645  1
204562  100.387  -77.476  45.632  1
204563  100.410  -77.490  45.619  1
204564  100.434  -77.505  45.606  1
204565  100.457  -77.520  45.593  1
204566  100.476  -77.536  45.581  1
204567  100.495  -77.552  45.567  1
204568  100.522  -77.562  45.553  1
204569  100.545  -77.569  45.539  1
204570  100.567  -77.579  45.524  1
204571  100.590  -77.589  45.511  1
204572  100.613  -77.599  45.496  1
204573  100.635  -77.610  45.482  1
204574  100.658  -77.620  45.468  1
204575  100.681  -77.630  45.454  1
204576  100.703  -77.640  45.441  1
204577  100.726  -77.651  45.427  1
204578  100.750  -77.663  45.413  1
204579  100.777  -77.680  45.400  1
204580  100.804  -77.697  45.386  1
204581  100.830  -77.714  45.372  1
204582  100.857  -77.730  45.359  1
204583  100.884  -77.748  45.344  1
204584  100.910  -77.765  45.331  1
204585  100.937  -77.781  45.319  1
204586  100.964  -77.798  45.304  1
204587  100.990  -77.815  45.291  1
204588  101.017  -77.832  45.278  1
204589  101.044  -77.849  45.264  1
204590  101.070  -77.865  45.252  1
204591  101.097  -77.883  45.239  1
204592  101.124  -77.906  45.226  1
204593  101.152  -77.931  45.213  1
204594  101.174  -77.943  45.200  1
204595  101.197  -77.956  45.187  1
204596  101.219  -77.967  45.173  1
204597  101.241  -77.979  45.160  1
204598  101.264  -77.990  45.148  1
204599  101.286  -77.992  45.135  1
204600  101.292  -77.992  45.121  1
204601  101.297  -77.991  45.107  1
204602  101.302  -77.990  45.092  1
204603  101.308  -77.990  45.078  1
204604  101.323  -77.996  45.063  1
204605  101.362  -78.016  45.049  1
204606  101.401  -78.037  45.034  1
204607  101.440  -78.057  45.018  1
204608  101.478  -78.078  45.002  1
204609  101.517  -78.097  44.987  1
204610  101.556  -78.118  44.972  1
204611  101.594  -78.138  44.957  1
204612  101.614  -78.149  44.942  1
204613  101.634  -78.160  44.926  1
204614  101.655  -78.172  44.910  1
204615  101.675  -78.184  44.894  1
204616  101.695  -78.195  44.878  1
204617  101.715  -78.206  44.862  1
204618  101.736  -78.218  44.846  1
204619  101.756  -78.229  44.830  1
204620  101.777  -78.241  44.813  1
204621  101.797  -78.253  44.796  1
204622  101.818  -78.264  44.779  1
204623  101.838  -78.275  44.762  1
204624  101.858  -78.287  44.745  1
204625  101.879  -78.298  44.729  1
204626  101.899  -78.310  44.714  1
204627  101.919  -78.321  44.699  1
204628  101.941  -78.332  44.684  1
204629  101.975  -78.343  44.670  1
204630  102.010  -78.354  44.656  1
204631  102.045  -78.364  44.642  1
204632  102.080  -78.375  44.627  1
204633  102.120  -78.395  44.613  1
204634  102.161  -78.417  44.598  1
204635  102.202  -78.438  44.583  1
204636  102.243  -78.460  44.568  1
204637  102.284  -78.481  44.553  1
204638  102.325  -78.502  44.537  1
204639  102.367  -78.523  44.521  1
204640  102.407  -78.545  44.507  1
204641  102.440  -78.567  44.492  1
204642  102.470  -78.589  44.477  1
204643  102.501  -78.611  44.462  1
204644  102.533  -78.633  44.447  1
204645  102.591  -78.639  44.432  1
204646  102.610  -78.642  44.417  1
204647  102.625  -78.644  44.403  1
204648  102.641  -78.646  44.387  1
204649  102.657  -78.648  44.372  1
204650  102.672  -78.651  44.356  1
204651  102.687  -78.653  44.342  1
204652  102.703  -78.655  44.327  1
204653  102.719  -78.658  44.311  1
204654  102.740  -78.660  44.295  1
204655  102.766  -78.663  44.279  1
204656  102.792  -78.665  44.263  1
204657  102.817  -78.668  44.248  1
204943  93.510  -75.972  54.010  1
204944  93.529  -75.976  54.027  1
204945  93.547  -75.979  54.043  1
204946  93.565  -75.982  54.058  1
204947  93.583  -75.986  54.075  1
204948  93.602  -75.989  54.091  1
204949  93.620  -75.992  54.109  1
204950  93.638  -75.996  54.127  1
204951  93.642  -76.028  54.142  1
204952  93.664  -76.038  54.155  1
204953  93.696  -76.032  54.167  1
204954  93.729  -76.025  54.179  1
204955  93.750  -76.016  54.192  1
204956  93.768  -76.009  54.205  1
204957  93.787  -76.002  54.222  1
204958  93.807  -75.994  54.238  1
204959  93.829  -75.987  54.255  1
204960  93.850  -75.979  54.275  1
204961  93.876  -75.973  54.295  1
204962  93.907  -75.969  54.315  1
204963  93.939  -75.964  54.333  1
204964  93.971  -75.960  54.347  1
204965  93.998  -75.955  54.352  1
204966  94.026  -75.951  54.357  1
204967  94.054  -75.948  54.360  1
204968  94.081  -75.945  54.358  1
204969  94.109  -75.941  54.354  1
204970  94.137  -75.938  54.349  1
204971  94.165  -75.934  54.342  1
204972  94.192  -75.931  54.331  1
204973  94.220  -75.928  54.317  1
204974  94.248  -75.925  54.302  1
204975  94.267  -75.923  54.283  1
204976  94.285  -75.922  54.261  1
204977  94.303  -75.921  54.237  1
204978  94.321  -75.919  54.210  1
204979  94.338  -75.918  54.176  1
204980  94.356  -75.917  54.140  1
204981  94.374  -75.916  54.107  1
204982  94.393  -75.919  54.076  1
204983  94.411  -75.921  54.045  1
204984  94.430  -75.924  54.013  1
204985  94.449  -75.926  53.977  1
204986  94.466  -75.931  53.939  1
204987  94.480  -75.941  53.902  1
204988  94.494  -75.950  53.862  1
204989  94.508  -75.960  53.822  1
204990  94.523  -75.969  53.783  1
204991  94.537  -75.979  53.746  1
204992  94.551  -75.988  53.708  1
204993  94.565  -75.998  53.670  1
204994  94.580  -76.007  53.634  1
204995  94.594  -76.017  53.601  1
204996  94.608  -76.027  53.570  1
204997  94.623  -76.036  53.540  1
204998  94.637  -76.046  53.513  1
204999  94.652  -76.054  53.480  1
205000  94.664  -76.060  53.447  1
205001  94.673  -76.063  53.415  1
205002  94.684  -76.066  53.383  1
205003  94.695  -76.069  53.351  1
205004  94.706  -76.073  53.322  1
205005  94.717  -76.077  53.291  1
205006  94.728  -76.080  53.258  1
205007  94.739  -76.084  53.225  1
205008  94.750  -76.088  53.192  1
205009  94.761  -76.091  53.159  1
205010  94.772  -76.094  53.128  1
205011  94.783  -76.098  53.097  1
205012  94.794  -76.102  53.065  1
205013  94.805  -76.105  53.032  1
205014  94.816  -76.109  52.998  1
205015  94.827  -76.113  52.964  1
205016  94.838  -76.116  52.930  1
205017  94.849  -76.119  52.895  1
205018  94.860  -76.123  52.860  1
205019  94.872  -76.127  52.823  1
205020  94.883  -76.130  52.787  1
205021  94.894  -76.134  52.751  1
205022  94.905  -76.138  52.715  1
205023  94.916  -76.141  52.679  1
205024  94.927  -76.144  52.643  1
205025  94.938  -76.148  52.608  1
205026  94.985  -76.149  52.573  1
205027  95.048  -76.148  52.538  1
205028  95.110  -76.148  52.503  1
205029  95.161  -76.149  52.469  1
205030  95.168  -76.161  52.436  1
205031  95.177  -76.173  52.404  1
205032  95.205  -76.181  52.374  1
205033  95.234  -76.188  52.344  1
205034  95.263  -76.197  52.310  1
205035  95.291  -76.204  52.270  1
205036  95.320  -76.213  52.223  1
205037  95.348  -76.220  52.172  1
205038  95.390  -76.220  52.124  1
205039  95.440  -76.216  52.076  1
205040  95.467  -76.219  52.028  1
205041  95.491  -76.221  51.981  1
205042  95.518  -76.220  51.935  1
205043  95.545  -76.217  51.890  1
205044  95.572  -76.214  51.847  1
205045  95.600  -76.211  51.806  1
205046  95.626  -76.209  51.765  1
205047  95.654  -76.206  51.724  1
205048  95.681  -76.203  51.683  1
205049  95.708  -76.200  51.643  1
205050  95.733  -76.201  51.603  1
205051  95.756  -76.205  51.565  1
205052  95.779  -76.210  51.529  1
205053  95.802  -76.214  51.494  1
205054  95.825  -76.219  51.458  1
205055  95.847  -76.223  51.418  1
205056  95.871  -76.227  51.380  1
205057  95.893  -76.232  51.339  1
205058  95.917  -76.236  51.295  1
205059  95.942  -76.242  51.249  1
205060  95.963  -76.247  51.203  1
205061  95.984  -76.250  51.155  1
205062  96.006  -76.252  51.107  1
205063  96.027  -76.254  51.062  1
205064  96.048  -76.256  51.017  1
205065  96.070  -76.258  50.973  1
205066  96.091  -76.260  50.931  1
205067  96.112  -76.262  50.895  1
205068  96.133  -76.264  50.860  1
205069  96.155  -76.266  50.827  1
205070  96.177  -76.267  50.793  1
205071  96.189  -76.273  50.759  1
205072  96.202  -76.276  50.725  1
205073  96.215  -76.279  50.692  1
205074  96.228  -76.282  50.660  1
205075  96.240  -76.285  50.630  1
205076  96.253  -76.289  50.600  1
205077  96.265  -76.295  50.569  1
205078  96.277  -76.301  50.539  1
205079  96.289  -76.308  50.510  1
205080  96.302  -76.316  50.485  1
205081  96.326  -76.330  50.464  1
205082  96.350  -76.344  50.444  1
205083  96.375  -76.358  50.426  1
205084  96.399  -76.373  50.407  1
205085  96.423  -76.386  50.388  1
205086  96.455  -76.395  50.365  1
205087  96.478  -76.404  50.339  1
205088  96.508  -76.411  50.311  1
205089  96.538  -76.417  50.282  1
205090  96.568  -76.423  50.251  1
205091  96.592  -76.430  50.221  1
205092  96.612  -76.437  50.190  1
205093  96.640  -76.442  50.158  1
205094  96.676  -76.449  50.126  1
205095  96.712  -76.456  50.091  1
205096  96.749  -76.464  50.055  1
205097  96.791  -76.466  50.018  1
205098  96.841  -76.461  49.979  1
205099  96.888  -76.458  49.939  1
205100  96.894  -76.449  49.900  1
205101  96.900  -76.441  49.864  1
205102  96.906  -76.433  49.827  1
205103  96.912  -76.424  49.789  1
205104  96.904  -76.414  49.750  1
205105  96.878  -76.401  49.709  1
205106  96.872  -76.408  49.669  1
205107  96.866  -76.416  49.630  1
205108  96.909  -76.438  49.593  1
205109  97.005  -76.475  49.558  1
205110  97.030  -76.505  49.525  1
205111  97.045  -76.533  49.494  1
205112  97.061  -76.561  49.464  1
205113  97.076  -76.589  49.439  1
205114  97.091  -76.618  49.415  1
205115  97.107  -76.646  49.393  1
205116  97.122  -76.674  49.373  1
205117  97.138  -76.703  49.353  1
205118  97.153  -76.731  49.333  1
205119  97.172  -76.752  49.313  1
205120  97.211  -76.746  49.290  1
205121  97.249  -76.740  49.266  1
205122  97.287  -76.734  49.241  1
205123  97.325  -76.727  49.215  1
205124  97.364  -76.721  49.185  1
205125  97.402  -76.714  49.153  1
205126  97.422  -76.732  49.121  1
205127  97.440  -76.751  49.088  1
205128  97.458  -76.769  49.055  1
205129  97.467  -76.781  49.022  1
205130  97.476  -76.790  48.990  1
205131  97.485  -76.800  48.959  1
205132  97.493  -76.810  48.930  1
205133  97.502  -76.820  48.901  1
205134  97.511  -76.831  48.872  1
205135  97.534  -76.842  48.844  1
205136  97.557  -76.854  48.817  1
205137  97.580  -76.865  48.788  1
205138  97.603  -76.878  48.760  1
205139  97.627  -76.889  48.730  1
205140  97.657  -76.900  48.701  1
205141  97.696  -76.910  48.671  1
205142  97.735  -76.920  48.640  1
205143  97.775  -76.928  48.610  1
205144  97.815  -76.936  48.580  1
205145  97.856  -76.943  48.550  1
205146  97.896  -76.952  48.521  1
205147  97.928  -76.959  48.491  1
205148  97.951  -76.964  48.460  1
205149  97.974  -76.970  48.430  1
205150  97.998  -76.975  48.399  1
205151  98.021  -76.981  48.367  1
205152  98.045  -76.969  48.337  1
205153  98.070  -76.952  48.308  1
205154  98.094  -76.937  48.279  1
205155  98.112  -76.931  48.248  1
205156  98.131  -76.925  48.217  1
205157  98.149  -76.917  48.187  1
205158  98.168  -76.909  48.156  1
205159  98.186  -76.901  48.125  1
205160  98.205  -76.893  48.094  1
205161  98.224  -76.885  48.062  1
205162  98.242  -76.878  48.028  1
205163  98.261  -76.869  47.995  1
205164  98.281  -76.873  47.962  1
205165  98.300  -76.877  47.930  1
205166  98.320  -76.881  47.897  1
205167  98.340  -76.884  47.865  1
205168  98.359  -76.893  47.834  1
205169  98.378  -76.909  47.804  1
205170  98.396  -76.925  47.775  1
205171  98.415  -76.941  47.746  1
205172  98.433  -76.957  47.717  1
205173  98.452  -76.973  47.689  1
205174  98.471  -76.986  47.661  1
205175  98.495  -76.980  47.634  1
205176  98.519  -76.975  47.609  1
205177  98.544  -76.969  47.583  1
205178  98.568  -76.963  47.560  1
205179  98.591  -76.958  47.537  1
205180  98.616  -76.952  47.515  1
205181  98.640  -76.947  47.492  1
205182  98.661  -76.943  47.468  1
205183  98.654  -76.960  47.443  1
205184  98.647  -76.978  47.418  1
205185  98.645  -76.994  47.390  1
205186  98.677  -76.996  47.363  1
205187  98.711  -76.998  47.335  1
205188  98.743  -77.000  47.305  1
205189  98.777  -77.003  47.278  1
205190  98.809  -77.004  47.248  1
205191  98.847  -77.008  47.218  1
205192  98.897  -77.015  47.186  1
205193  98.935  -77.024  47.154  1
205194  98.949  -77.038  47.122  1
205195  98.963  -77.052  47.089  1
205196  98.977  -77.066  47.059  1
205197  98.991  -77.079  47.028  1
205198  99.005  -77.093  46.998  1
205199  99.019  -77.106  46.971  1
205200  99.032  -77.120  46.943  1
205201  99.047  -77.134  46.917  1
205202  99.060  -77.147  46.892  1
205203  99.074  -77.162  46.867  1
205204  99.088  -77.175  46.841  1
205205  99.102  -77.189  46.814  1
205206  99.117  -77.200  46.787  1
205207  99.130  -77.207  46.758  1
205208  99.143  -77.213  46.729  1
205209  99.156  -77.218  46.700  1
205210  99.169  -77.222  46.672  1
205211  99.182  -77.228  46.643  1
205212  99.194  -77.232  46.614  1
205213  99.219  -77.228  46.586  1
205214  99.245  -77.222  46.558  1
205215  99.271  -77.216  46.530  1
205216  99.296  -77.219  46.503  1
205217  99.321  -77.235  46.477  1
205218  99.337  -77.249  46.452  1
205219  99.343  -77.263  46.426  1
205220  99.336  -77.264  46.401  1
205221  99.323  -77.258  46.376  1
205222  99.314  -77.253  46.351  1
205223  99.343  -77.257  46.327  1
205224  99.373  -77.260  46.303  1
205225  99.402  -77.263  46.280  1
205226  99.432  -77.266  46.257  1
205227  99.462  -77.270  46.234  1
205228  99.491  -77.273  46.211  1
205229  99.520  -77.276  46.188  1
205230  99.550  -77.280  46.167  1
205231  99.600  -77.287  46.145  1
205232  99.651  -77.294  46.124  1
205233  99.702  -77.301  46.104  1
205234  99.739  -77.301  46.083  1
205235  99.764  -77.294  46.064  1
205236  99.797  -77.291  46.044  1
205237  99.833  -77.297  46.025  1
205238  99.862  -77.318  46.007  1
205239  99.885  -77.328  45.989  1
205240  99.899  -77.323  45.972  1
205241  99.911  -77.315  45.954  1
205242  99.923  -77.307  45.936  1
205243  99.935  -77.299  45.919  1
205244  99.947  -77.291  45.903  1
205245  99.959  -77.283  45.886  1
205246  99.982  -77.285  45.870  1
205247  100.015  -77.299  45.853  1
205248  100.050  -77.313  45.837  1
205249  100.083  -77.326  45.821  1
205250  100.118  -77.340  45.805  1
205251  100.151  -77.354  45.789  1
205252  100.186  -77.368  45.774  1
205253  100.219  -77.382  45.759  1
205254  100.240  -77.389  45.745  1
205255  100.251  -77.395  45.731  1
205256  100.263  -77.405  45.717  1
205257  100.282  -77.412  45.704  1
205258  100.301  -77.420  45.691  1
205259  100.321  -77.426  45.678  1
205260  100.340  -77.433  45.665  1
205261  100.359  -77.441  45.652  1
205262  100.379  -77.448  45.639  1
205263  100.400  -77.458  45.627  1
205264  100.424  -77.473  45.614  1
205265  100.447  -77.489  45.601  1
205266  100.471  -77.504  45.589  1
205267  100.495  -77.519  45.576  1
205268  100.519  -77.534  45.562  1
205269  100.543  -77.546  45.548  1
205270  100.566  -77.556  45.534  1
205271  100.588  -77.567  45.520  1
205272  100.611  -77.577  45.505  1
205273  100.634  -77.587  45.491  1
205274  100.656  -77.597  45.477  1
205275  100.680  -77.608  45.463  1
205276  100.702  -77.617  45.449  1
205277  100.725  -77.628  45.435  1
205278  100.748  -77.638  45.422  1
205279  100.772  -77.652  45.408  1
205280  100.799  -77.668  45.395  1
205281  100.826  -77.685  45.381  1
205282  100.852  -77.702  45.368  1
205283  100.879  -77.719  45.355  1
205284  100.905  -77.736  45.340  1
205285  100.932  -77.752  45.326  1
205286  100.959  -77.770  45.314  1
205287  100.985  -77.787  45.300  1
205288  101.012  -77.803  45.286  1
205289  101.039  -77.820  45.273  1
205290  101.065  -77.837  45.259  1
205291  101.092  -77.854  45.247  1
205292  101.119  -77.871  45.234  1
205293  101.145  -77.888  45.221  1
205294  101.172  -77.905  45.208  1
205295  101.199  -77.925  45.194  1
205296  101.226  -77.947  45.180  1
205297  101.248  -77.959  45.167  1
205298  101.270  -77.971  45.155  1
205299  101.292  -77.984  45.142  1
205300  101.313  -77.986  45.128  1
205301  101.318  -77.985  45.115  1
205302  101.323  -77.985  45.101  1
205303  101.329  -77.984  45.087  1
205304  101.334  -77.984  45.072  1
205305  101.339  -77.984  45.058  1
205306  101.375  -78.002  45.042  1
205307  101.414  -78.022  45.027  1
205308  101.453  -78.043  45.011  1
205309  101.494  -78.065  44.995  1
205310  101.538  -78.088  44.980  1
205311  101.582  -78.112  44.965  1
205312  101.611  -78.128  44.950  1
205313  101.626  -78.136  44.934  1
205314  101.646  -78.147  44.919  1
205315  101.667  -78.159  44.903  1
205316  101.687  -78.171  44.887  1
205317  101.707  -78.182  44.871  1
205318  101.728  -78.194  44.855  1
205319  101.748  -78.205  44.840  1
205320  101.768  -78.216  44.824  1
205321  101.789  -78.228  44.807  1
205322  101.809  -78.239  44.790  1
205323  101.829  -78.251  44.773  1
205324  101.850  -78.263  44.756  1
205325  101.870  -78.274  44.740  1
205326  101.891  -78.285  44.724  1
205327  101.911  -78.297  44.708  1
205328  101.931  -78.308  44.691  1
205329  101.965  -78.319  44.677  1
205330  101.999  -78.329  44.662  1
205331  102.034  -78.340  44.648  1
205332  102.069  -78.351  44.634  1
205333  102.104  -78.362  44.620  1
205334  102.146  -78.383  44.605  1
205335  102.186  -78.405  44.591  1
205336  102.228  -78.426  44.575  1
205337  102.268  -78.448  44.560  1
205338  102.310  -78.469  44.545  1
205339  102.350  -78.490  44.530  1
205340  102.392  -78.511  44.515  1
205341  102.433  -78.532  44.500  1
205342  102.474  -78.554  44.485  1
205343  102.507  -78.576  44.470  1
205344  102.538  -78.598  44.456  1
205345  102.570  -78.620  44.441  1
205346  102.599  -78.623  44.426  1
205347  102.624  -78.626  44.411  1
205348  102.640  -78.629  44.396  1
205349  102.656  -78.631  44.381  1
205350  102.671  -78.633  44.365  1
205351  102.686  -78.636  44.351  1
205352  102.702  -78.638  44.336  1
205353  102.726  -78.640  44.320  1
205354  102.751  -78.642  44.304  1
205355  102.777  -78.645  44.289  1
205356  102.803  -78.648  44.272  1
205357  102.828  -78.650  44.256  1
205358  102.854  -78.653  44.240  1
205644  93.502  -75.950  54.006  1
205645  93.520  -75.953  54.023  1
205646  93.539  -75.956  54.040  1
205647  93.557  -75.960  54.056  1
205648  93.575  -75.963  54.073  1
205649  93.593  -75.966  54.091  1
205650  93.612  -75.969  54.109  1
205651  93.630  -75.972  54.127  1
205652  93.635  -76.005  54.142  1
205653  93.659  -76.010  54.155  1
205654  93.691  -76.003  54.168  1
205655  93.723  -75.997  54.180  1
205656  93.748  -75.991  54.193  1
205657  93.769  -75.983  54.206  1
205658  93.790  -75.975  54.222  1
205659  93.811  -75.968  54.236  1
205660  93.832  -75.960  54.252  1
205661  93.853  -75.953  54.271  1
205662  93.876  -75.946  54.293  1
205663  93.908  -75.941  54.313  1
205664  93.939  -75.937  54.331  1
205665  93.971  -75.932  54.345  1
205666  93.998  -75.927  54.351  1
205667  94.025  -75.922  54.356  1
205668  94.052  -75.918  54.358  1
205669  94.079  -75.914  54.356  1
205670  94.107  -75.910  54.351  1
205671  94.135  -75.907  54.344  1
205672  94.163  -75.903  54.336  1
205673  94.190  -75.900  54.323  1
205674  94.218  -75.897  54.309  1
205675  94.246  -75.894  54.294  1
205676  94.270  -75.891  54.278  1
205677  94.287  -75.890  54.259  1
205678  94.305  -75.888  54.237  1
205679  94.323  -75.887  54.211  1
205680  94.341  -75.886  54.179  1
205681  94.359  -75.887  54.146  1
205682  94.378  -75.890  54.115  1
205683  94.397  -75.892  54.085  1
205684  94.415  -75.895  54.054  1
205685  94.434  -75.897  54.025  1
205686  94.453  -75.900  53.991  1
205687  94.469  -75.906  53.953  1
205688  94.483  -75.916  53.915  1
205689  94.498  -75.925  53.878  1
205690  94.512  -75.934  53.839  1
205691  94.526  -75.944  53.799  1
205692  94.541  -75.953  53.761  1
205693  94.555  -75.963  53.722  1
205694  94.569  -75.972  53.682  1
205695  94.583  -75.982  53.643  1
205696  94.598  -75.991  53.608  1
205697  94.612  -76.000  53.575  1
205698  94.627  -76.010  53.543  1
205699  94.642  -76.018  53.512  1
205700  94.657  -76.026  53.479  1
205701  94.669  -76.032  53.447  1
205702  94.678  -76.035  53.417  1
205703  94.687  -76.038  53.386  1
205704  94.696  -76.041  53.353  1
205705  94.706  -76.044  53.320  1
205706  94.717  -76.047  53.287  1
205707  94.728  -76.050  53.251  1
205708  94.739  -76.054  53.218  1
205709  94.750  -76.058  53.186  1
205710  94.761  -76.061  53.153  1
205711  94.772  -76.065  53.123  1
205712  94.783  -76.069  53.092  1
205713  94.794  -76.072  53.061  1
205714  94.806  -76.075  53.027  1
205715  94.817  -76.079  52.992  1
205716  94.828  -76.083  52.956  1
205717  94.839  -76.086  52.919  1
205718  94.850  -76.090  52.883  1
205719  94.861  -76.094  52.848  1
205720  94.872  -76.097  52.813  1
205721  94.883  -76.100  52.778  1
205722  94.894  -76.104  52.744  1
205723  94.905  -76.108  52.711  1
205724  94.916  -76.111  52.679  1
205725  94.927  -76.115  52.647  1
205726  94.938  -76.119  52.616  1
205727  94.983  -76.119  52.584  1
205728  95.046  -76.119  52.551  1
205729  95.109  -76.118  52.518  1
205730  95.172  -76.117  52.485  1
205731  95.224  -76.119  52.452  1
205732  95.231  -76.131  52.420  1
205733  95.246  -76.141  52.390  1
205734  95.275  -76.149  52.361  1
205735  95.304  -76.157  52.328  1
205736  95.332  -76.165  52.290  1
205737  95.360  -76.173  52.245  1
205738  95.389  -76.181  52.193  1
205739  95.418  -76.188  52.143  1
205740  95.447  -76.197  52.094  1
205741  95.473  -76.198  52.046  1
205742  95.500  -76.196  51.998  1
205743  95.528  -76.193  51.950  1
205744  95.554  -76.190  51.902  1
205745  95.582  -76.187  51.858  1
205746  95.609  -76.184  51.815  1
205747  95.636  -76.182  51.773  1
205748  95.663  -76.179  51.734  1
205749  95.690  -76.176  51.694  1
205750  95.717  -76.173  51.653  1
205751  95.740  -76.177  51.613  1
205752  95.763  -76.182  51.573  1
205753  95.786  -76.186  51.535  1
205754  95.809  -76.191  51.500  1
205755  95.832  -76.195  51.465  1
205756  95.854  -76.199  51.426  1
205757  95.878  -76.204  51.387  1
205758  95.901  -76.208  51.347  1
205759  95.923  -76.212  51.305  1
205760  95.947  -76.217  51.259  1
205761  95.968  -76.220  51.214  1
205762  95.989  -76.221  51.167  1
205763  96.012  -76.223  51.120  1
205764  96.033  -76.225  51.075  1
205765  96.055  -76.226  51.029  1
205766  96.078  -76.229  50.986  1
205767  96.099  -76.230  50.945  1
205768  96.121  -76.232  50.909  1
205769  96.143  -76.233  50.874  1
205770  96.165  -76.235  50.839  1
205771  96.187  -76.237  50.806  1
205772  96.196  -76.246  50.772  1
205773  96.206  -76.254  50.738  1
205774  96.220  -76.257  50.705  1
205775  96.232  -76.260  50.675  1
205776  96.245  -76.263  50.645  1
205777  96.257  -76.268  50.615  1
205778  96.269  -76.275  50.585  1
205779  96.281  -76.282  50.555  1
205780  96.293  -76.289  50.527  1
205781  96.305  -76.295  50.504  1
205782  96.321  -76.305  50.484  1
205783  96.345  -76.319  50.465  1
205784  96.370  -76.333  50.447  1
205785  96.394  -76.348  50.428  1
205786  96.418  -76.361  50.408  1
205787  96.455  -76.374  50.383  1
205788  96.500  -76.385  50.356  1
205789  96.537  -76.377  50.327  1
205790  96.562  -76.383  50.297  1
205791  96.586  -76.392  50.267  1
205792  96.609  -76.400  50.237  1
205793  96.639  -76.409  50.206  1
205794  96.674  -76.418  50.175  1
205795  96.710  -76.427  50.142  1
205796  96.745  -76.436  50.107  1
205797  96.781  -76.445  50.071  1
205798  96.817  -76.452  50.035  1
205799  96.857  -76.454  49.997  1
205800  96.863  -76.446  49.958  1
205801  96.869  -76.438  49.920  1
205802  96.875  -76.430  49.883  1
205803  96.881  -76.421  49.846  1
205804  96.887  -76.413  49.808  1
205805  96.893  -76.404  49.769  1
205806  96.865  -76.390  49.729  1
205807  96.844  -76.383  49.689  1
205808  96.843  -76.392  49.649  1
205809  96.939  -76.430  49.612  1
205810  97.013  -76.464  49.576  1
205811  97.029  -76.492  49.543  1
205812  97.044  -76.521  49.511  1
205813  97.060  -76.549  49.481  1
205814  97.075  -76.577  49.455  1
205815  97.090  -76.606  49.431  1
205816  97.105  -76.634  49.409  1
205817  97.121  -76.663  49.389  1
205818  97.136  -76.691  49.369  1
205819  97.151  -76.719  49.348  1
205820  97.167  -76.748  49.327  1
205821  97.193  -76.759  49.305  1
205822  97.232  -76.752  49.280  1
205823  97.270  -76.746  49.255  1
205824  97.308  -76.740  49.228  1
205825  97.347  -76.733  49.197  1
205826  97.403  -76.683  49.164  1
205827  97.414  -76.704  49.131  1
205828  97.432  -76.723  49.099  1
205829  97.450  -76.741  49.065  1
205830  97.461  -76.754  49.031  1
205831  97.469  -76.764  48.999  1
205832  97.478  -76.774  48.968  1
205833  97.487  -76.784  48.939  1
205834  97.502  -76.795  48.910  1
205835  97.525  -76.806  48.882  1
205836  97.548  -76.818  48.854  1
205837  97.571  -76.830  48.827  1
205838  97.594  -76.841  48.799  1
205839  97.618  -76.853  48.771  1
205840  97.641  -76.865  48.741  1
205841  97.664  -76.877  48.712  1
205842  97.696  -76.887  48.682  1
205843  97.734  -76.898  48.651  1
205844  97.775  -76.906  48.620  1
205845  97.815  -76.914  48.589  1
205846  97.855  -76.922  48.559  1
205847  97.895  -76.930  48.528  1
205848  97.936  -76.938  48.498  1
205849  97.974  -76.946  48.468  1
205850  97.998  -76.952  48.437  1
205851  98.021  -76.957  48.406  1
205852  98.044  -76.963  48.375  1
205853  98.069  -76.952  48.344  1
205854  98.093  -76.935  48.315  1
205855  98.113  -76.928  48.286  1
205856  98.131  -76.921  48.255  1
205857  98.150  -76.915  48.225  1
205858  98.168  -76.907  48.195  1
205859  98.186  -76.900  48.165  1
205860  98.205  -76.891  48.134  1
205861  98.224  -76.884  48.103  1
205862  98.242  -76.875  48.071  1
205863  98.261  -76.868  48.037  1
205864  98.279  -76.859  48.004  1
205865  98.298  -76.852  47.972  1
205866  98.316  -76.844  47.940  1
205867  98.336  -76.848  47.908  1
205868  98.356  -76.852  47.876  1
205869  98.375  -76.861  47.845  1
205870  98.394  -76.878  47.815  1
205871  98.413  -76.893  47.786  1
205872  98.431  -76.909  47.756  1
205873  98.449  -76.926  47.728  1
205874  98.468  -76.942  47.701  1
205875  98.487  -76.958  47.675  1
205876  98.505  -76.973  47.648  1
205877  98.529  -76.967  47.622  1
205878  98.553  -76.962  47.596  1
205879  98.577  -76.956  47.570  1
205880  98.601  -76.950  47.546  1
205881  98.626  -76.945  47.523  1
205882  98.650  -76.939  47.500  1
205883  98.673  -76.934  47.476  1
205884  98.669  -76.950  47.452  1
205885  98.662  -76.967  47.425  1
205886  98.667  -76.980  47.397  1
205887  98.700  -76.982  47.370  1
205888  98.733  -76.984  47.341  1
205889  98.766  -76.987  47.310  1
205890  98.799  -76.988  47.283  1
205891  98.832  -76.990  47.253  1
205892  98.865  -76.993  47.221  1
205893  98.910  -76.998  47.188  1
205894  98.947  -77.008  47.156  1
205895  98.961  -77.022  47.123  1
205896  98.975  -77.035  47.090  1
205897  98.989  -77.049  47.059  1
205898  99.003  -77.063  47.028  1
205899  99.016  -77.077  46.997  1
205900  99.030  -77.091  46.968  1
205901  99.045  -77.104  46.940  1
205902  99.058  -77.118  46.913  1
205903  99.072  -77.132  46.887  1
205904  99.086  -77.145  46.862  1
205905  99.100  -77.159  46.835  1
205906  99.114  -77.172  46.809  1
205907  99.128  -77.185  46.782  1
205908  99.141  -77.192  46.753  1
205909  99.154  -77.197  46.723  1
205910  99.174  -77.196  46.696  1
205911  99.201  -77.190  46.668  1
205912  99.227  -77.184  46.640  1
205913  99.253  -77.179  46.612  1
205914  99.279  -77.172  46.583  1
205915  99.304  -77.180  46.555  1
205916  99.329  -77.195  46.526  1
205917  99.353  -77.210  46.500  1
205918  99.362  -77.224  46.474  1
205919  99.368  -77.238  46.448  1
205920  99.370  -77.248  46.422  1
205921  99.356  -77.241  46.397  1
205922  99.342  -77.235  46.372  1
205923  99.329  -77.229  46.346  1
205924  99.341  -77.229  46.322  1
205925  99.370  -77.232  46.299  1
205926  99.400  -77.235  46.276  1
205927  99.429  -77.239  46.253  1
205928  99.459  -77.242  46.230  1
205929  99.488  -77.246  46.207  1
205930  99.534  -77.252  46.185  1
205931  99.584  -77.259  46.164  1
205932  99.636  -77.266  46.142  1
205933  99.687  -77.273  46.121  1
205934  99.730  -77.276  46.101  1
205935  99.755  -77.269  46.081  1
205936  99.780  -77.263  46.061  1
205937  99.816  -77.262  46.042  1
205938  99.852  -77.263  46.023  1
205939  99.883  -77.285  46.005  1
205940  99.909  -77.300  45.988  1
205941  99.932  -77.310  45.969  1
205942  99.944  -77.304  45.950  1
205943  99.957  -77.295  45.933  1
205944  99.969  -77.288  45.916  1
205945  99.981  -77.279  45.899  1
205946  99.993  -77.271  45.882  1
205947  100.010  -77.269  45.865  1
205948  100.044  -77.282  45.849  1
205949  100.078  -77.296  45.832  1
205950  100.112  -77.310  45.815  1
205951  100.146  -77.323  45.800  1
205952  100.180  -77.337  45.784  1
205953  100.214  -77.351  45.768  1
205954  100.244  -77.363  45.753  1
205955  100.255  -77.366  45.739  1
205956  100.266  -77.372  45.724  1
205957  100.277  -77.382  45.710  1
205958  100.293  -77.391  45.697  1
205959  100.312  -77.398  45.685  1
205960  100.331  -77.405  45.671  1
205961  100.350  -77.413  45.658  1
205962  100.369  -77.420  45.646  1
205963  100.389  -77.427  45.633  1
205964  100.413  -77.442  45.621  1
205965  100.437  -77.457  45.609  1
205966  100.461  -77.473  45.595  1
205967  100.485  -77.488  45.583  1
205968  100.508  -77.506  45.570  1
205969  100.531  -77.526  45.556  1
205970  100.559  -77.537  45.542  1
205971  100.587  -77.544  45.528  1
205972  100.610  -77.554  45.514  1
205973  100.633  -77.564  45.500  1
205974  100.655  -77.574  45.486  1
205975  100.678  -77.585  45.472  1
205976  100.701  -77.595  45.458  1
205977  100.723  -77.605  45.444  1
205978  100.746  -77.615  45.430  1
205979  100.769  -77.625  45.416  1
205980  100.794  -77.639  45.402  1
205981  100.821  -77.657  45.389  1
205982  100.847  -77.674  45.376  1
205983  100.874  -77.690  45.363  1
205984  100.901  -77.707  45.350  1
205985  100.927  -77.724  45.336  1
205986  100.954  -77.741  45.322  1
205987  100.981  -77.758  45.309  1
205988  101.007  -77.774  45.297  1
205989  101.034  -77.792  45.282  1
205990  101.060  -77.808  45.269  1
205991  101.087  -77.825  45.255  1
205992  101.114  -77.842  45.242  1
205993  101.140  -77.859  45.229  1
205994  101.167  -77.876  45.215  1
205995  101.194  -77.893  45.202  1
205996  101.220  -77.910  45.188  1
205997  101.247  -77.927  45.175  1
205998  101.274  -77.945  45.162  1
205999  101.299  -77.963  45.149  1
206000  101.321  -77.975  45.136  1
206001  101.339  -77.980  45.122  1
206002  101.344  -77.979  45.109  1
206003  101.350  -77.979  45.096  1
206004  101.355  -77.978  45.081  1
206005  101.360  -77.978  45.067  1
206006  101.367  -77.978  45.052  1
206007  101.393  -77.990  45.036  1
206008  101.437  -78.014  45.020  1
206009  101.480  -78.037  45.004  1
206010  101.524  -78.061  44.988  1
206011  101.568  -78.084  44.973  1
206012  101.611  -78.107  44.958  1
206013  101.629  -78.118  44.942  1
206014  101.640  -78.124  44.927  1
206015  101.658  -78.134  44.912  1
206016  101.679  -78.146  44.896  1
206017  101.699  -78.158  44.880  1
206018  101.720  -78.169  44.864  1
206019  101.740  -78.181  44.848  1
206020  101.760  -78.192  44.833  1
206021  101.780  -78.203  44.817  1
206022  101.801  -78.215  44.799  1
206023  101.821  -78.226  44.784  1
206024  101.841  -78.238  44.768  1
206025  101.862  -78.250  44.751  1
206026  101.882  -78.261  44.734  1
206027  101.902  -78.272  44.718  1
206028  101.923  -78.284  44.702  1
206029  101.954  -78.294  44.686  1
206030  101.988  -78.305  44.671  1
206031  102.024  -78.316  44.657  1
206032  102.058  -78.326  44.643  1
206033  102.093  -78.337  44.629  1
206034  102.129  -78.350  44.614  1
206035  102.170  -78.371  44.599  1
206036  102.211  -78.393  44.584  1
206037  102.252  -78.414  44.569  1
206038  102.293  -78.435  44.553  1
206039  102.334  -78.457  44.538  1
206040  102.376  -78.478  44.523  1
206041  102.416  -78.499  44.509  1
206042  102.458  -78.520  44.493  1
206043  102.499  -78.542  44.478  1
206044  102.540  -78.563  44.464  1
206045  102.575  -78.585  44.449  1
206046  102.606  -78.607  44.435  1
206047  102.608  -78.607  44.420  1
206048  102.639  -78.611  44.405  1
206049  102.655  -78.613  44.390  1
206050  102.670  -78.615  44.375  1
206051  102.685  -78.617  44.359  1
206052  102.711  -78.620  44.345  1
206053  102.736  -78.623  44.329  1
206054  102.762  -78.625  44.313  1
206055  102.787  -78.627  44.298  1
206056  102.813  -78.630  44.282  1
206057  102.839  -78.633  44.265  1
206058  102.865  -78.636  44.249  1
206059  102.890  -78.638  44.233  1
206344  93.476  -75.923  53.982  1
206345  93.494  -75.926  54.001  1
206346  93.512  -75.929  54.020  1
206347  93.531  -75.933  54.037  1
206348  93.549  -75.936  54.055  1
206349  93.567  -75.939  54.073  1
206350  93.585  -75.943  54.092  1
206351  93.604  -75.946  54.110  1
206352  93.622  -75.949  54.128  1
206353  93.627  -75.981  54.144  1
206354  93.654  -75.982  54.158  1
206355  93.686  -75.976  54.171  1
206356  93.718  -75.970  54.183  1
206357  93.751  -75.964  54.196  1
206358  93.772  -75.956  54.209  1
206359  93.793  -75.949  54.223  1
206360  93.815  -75.941  54.235  1
206361  93.835  -75.934  54.249  1
206362  93.856  -75.926  54.266  1
206363  93.877  -75.919  54.288  1
206364  93.909  -75.914  54.307  1
206365  93.940  -75.909  54.325  1
206366  93.972  -75.905  54.341  1
206367  93.999  -75.900  54.348  1
206368  94.025  -75.894  54.351  1
206369  94.052  -75.890  54.352  1
206370  94.079  -75.886  54.350  1
206371  94.106  -75.881  54.344  1
206372  94.133  -75.877  54.336  1
206373  94.160  -75.872  54.326  1
206374  94.188  -75.869  54.312  1
206375  94.216  -75.865  54.298  1
206376  94.244  -75.862  54.284  1
206377  94.271  -75.859  54.270  1
206378  94.290  -75.857  54.254  1
206379  94.308  -75.856  54.235  1
206380  94.326  -75.856  54.211  1
206381  94.344  -75.858  54.181  1
206382  94.363  -75.861  54.149  1
206383  94.382  -75.863  54.120  1
206384  94.400  -75.865  54.091  1
206385  94.419  -75.869  54.064  1
206386  94.438  -75.871  54.036  1
206387  94.457  -75.874  54.003  1
206388  94.473  -75.880  53.966  1
206389  94.487  -75.890  53.929  1
206390  94.501  -75.899  53.891  1
206391  94.516  -75.909  53.853  1
206392  94.530  -75.918  53.815  1
206393  94.544  -75.928  53.777  1
206394  94.558  -75.938  53.738  1
206395  94.572  -75.947  53.698  1
206396  94.587  -75.956  53.659  1
206397  94.602  -75.964  53.624  1
206398  94.617  -75.973  53.589  1
206399  94.632  -75.981  53.556  1
206400  94.646  -75.990  53.523  1
206401  94.661  -75.999  53.490  1
206402  94.673  -76.004  53.458  1
206403  94.683  -76.007  53.426  1
206404  94.692  -76.010  53.393  1
206405  94.701  -76.013  53.359  1
206406  94.710  -76.016  53.325  1
206407  94.720  -76.019  53.290  1
206408  94.729  -76.022  53.253  1
206409  94.739  -76.025  53.218  1
206410  94.750  -76.028  53.184  1
206411  94.761  -76.032  53.150  1
206412  94.772  -76.035  53.120  1
206413  94.783  -76.039  53.090  1
206414  94.794  -76.042  53.059  1
206415  94.806  -76.046  53.025  1
206416  94.817  -76.050  52.991  1
206417  94.828  -76.053  52.953  1
206418  94.839  -76.057  52.915  1
206419  94.850  -76.060  52.877  1
206420  94.861  -76.064  52.841  1
206421  94.872  -76.067  52.807  1
206422  94.883  -76.071  52.774  1
206423  94.894  -76.075  52.743  1
206424  94.905  -76.079  52.713  1
206425  94.916  -76.082  52.685  1
206426  94.927  -76.085  52.657  1
206427  94.938  -76.089  52.629  1
206428  94.982  -76.090  52.598  1
206429  95.045  -76.089  52.567  1
206430  95.108  -76.088  52.535  1
206431  95.170  -76.088  52.503  1
206432  95.233  -76.087  52.470  1
206433  95.286  -76.088  52.437  1
206434  95.293  -76.100  52.406  1
206435  95.316  -76.109  52.378  1
206436  95.344  -76.117  52.345  1
206437  95.373  -76.125  52.307  1
206438  95.401  -76.133  52.264  1
206439  95.430  -76.141  52.211  1
206440  95.459  -76.149  52.159  1
206441  95.486  -76.153  52.109  1
206442  95.511  -76.151  52.061  1
206443  95.536  -76.150  52.014  1
206444  95.561  -76.148  51.964  1
206445  95.587  -76.147  51.914  1
206446  95.612  -76.145  51.868  1
206447  95.637  -76.144  51.823  1
206448  95.662  -76.142  51.781  1
206449  95.687  -76.141  51.741  1
206450  95.705  -76.143  51.703  1
206451  95.718  -76.150  51.663  1
206452  95.740  -76.154  51.623  1
206453  95.762  -76.158  51.582  1
206454  95.784  -76.163  51.543  1
206455  95.807  -76.167  51.507  1
206456  95.829  -76.172  51.472  1
206457  95.851  -76.176  51.433  1
206458  95.874  -76.180  51.394  1
206459  95.896  -76.185  51.354  1
206460  95.918  -76.189  51.312  1
206461  95.951  -76.191  51.268  1
206462  95.976  -76.191  51.223  1
206463  96.000  -76.191  51.178  1
206464  96.021  -76.192  51.132  1
206465  96.043  -76.195  51.088  1
206466  96.065  -76.196  51.042  1
206467  96.087  -76.198  50.999  1
206468  96.109  -76.200  50.959  1
206469  96.131  -76.201  50.922  1
206470  96.153  -76.203  50.886  1
206471  96.175  -76.205  50.851  1
206472  96.197  -76.207  50.817  1
206473  96.206  -76.216  50.784  1
206474  96.215  -76.226  50.751  1
206475  96.224  -76.234  50.718  1
206476  96.237  -76.237  50.689  1
206477  96.249  -76.242  50.660  1
206478  96.261  -76.248  50.630  1
206479  96.273  -76.255  50.601  1
206480  96.285  -76.262  50.571  1
206481  96.297  -76.269  50.544  1
206482  96.309  -76.276  50.522  1
206483  96.321  -76.282  50.503  1
206484  96.341  -76.294  50.484  1
206485  96.365  -76.308  50.466  1
206486  96.389  -76.322  50.447  1
206487  96.413  -76.336  50.426  1
206488  96.452  -76.348  50.400  1
206489  96.497  -76.360  50.372  1
206490  96.542  -76.371  50.343  1
206491  96.583  -76.371  50.313  1
206492  96.619  -76.360  50.283  1
206493  96.647  -76.361  50.253  1
206494  96.681  -76.370  50.223  1
206495  96.715  -76.380  50.191  1
206496  96.740  -76.389  50.159  1
206497  96.765  -76.399  50.124  1
206498  96.790  -76.408  50.088  1
206499  96.815  -76.418  50.052  1
206500  96.840  -76.427  50.015  1
206501  96.846  -76.420  49.977  1
206502  96.852  -76.411  49.939  1
206503  96.858  -76.404  49.902  1
206504  96.864  -76.395  49.864  1
206505  96.870  -76.388  49.826  1
206506  96.858  -76.379  49.788  1
206507  96.839  -76.371  49.749  1
206508  96.820  -76.364  49.709  1
206509  96.873  -76.383  49.669  1
206510  96.970  -76.421  49.631  1
206511  97.012  -76.452  49.595  1
206512  97.027  -76.481  49.561  1
206513  97.043  -76.509  49.529  1
206514  97.058  -76.537  49.498  1
206515  97.074  -76.566  49.472  1
206516  97.089  -76.594  49.447  1
206517  97.104  -76.623  49.425  1
206518  97.119  -76.651  49.404  1
206519  97.135  -76.679  49.383  1
206520  97.150  -76.708  49.363  1
206521  97.165  -76.736  49.341  1
206522  97.181  -76.765  49.319  1
206523  97.214  -76.765  49.294  1
206524  97.252  -76.759  49.267  1
206525  97.291  -76.752  49.240  1
206526  97.350  -76.697  49.208  1
206527  97.403  -76.652  49.175  1
206528  97.418  -76.668  49.141  1
206529  97.424  -76.696  49.107  1
206530  97.442  -76.714  49.073  1
206531  97.454  -76.727  49.039  1
206532  97.463  -76.737  49.007  1
206533  97.471  -76.747  48.976  1
206534  97.493  -76.759  48.948  1
206535  97.516  -76.771  48.920  1
206536  97.539  -76.782  48.893  1
206537  97.563  -76.794  48.865  1
206538  97.586  -76.806  48.838  1
206539  97.609  -76.818  48.810  1
206540  97.632  -76.829  48.782  1
206541  97.655  -76.841  48.752  1
206542  97.678  -76.853  48.723  1
206543  97.702  -76.865  48.693  1
206544  97.735  -76.875  48.662  1
206545  97.774  -76.884  48.630  1
206546  97.814  -76.893  48.599  1
206547  97.855  -76.900  48.567  1
206548  97.895  -76.909  48.536  1
206549  97.935  -76.916  48.506  1
206550  97.975  -76.925  48.475  1
206551  98.016  -76.933  48.444  1
206552  98.044  -76.939  48.412  1
206553  98.068  -76.944  48.383  1
206554  98.092  -76.935  48.352  1
206555  98.113  -76.924  48.322  1
206556  98.132  -76.918  48.293  1
206557  98.150  -76.911  48.263  1
206558  98.168  -76.904  48.233  1
206559  98.187  -76.897  48.203  1
206560  98.206  -76.890  48.173  1
206561  98.224  -76.881  48.143  1
206562  98.242  -76.874  48.112  1
206563  98.261  -76.865  48.080  1
206564  98.280  -76.858  48.048  1
206565  98.298  -76.850  48.015  1
206566  98.316  -76.842  47.984  1
206567  98.335  -76.834  47.952  1
206568  98.354  -76.826  47.921  1
206569  98.372  -76.819  47.889  1
206570  98.391  -76.830  47.858  1
206571  98.410  -76.846  47.827  1
206572  98.429  -76.862  47.797  1
206573  98.447  -76.878  47.769  1
206574  98.465  -76.894  47.742  1
206575  98.484  -76.910  47.715  1
206576  98.502  -76.927  47.690  1
206577  98.521  -76.943  47.664  1
206578  98.539  -76.959  47.638  1
206579  98.563  -76.955  47.610  1
206580  98.587  -76.949  47.583  1
206581  98.612  -76.943  47.557  1
206582  98.635  -76.937  47.532  1
206583  98.659  -76.932  47.507  1
206584  98.684  -76.926  47.483  1
206585  98.684  -76.939  47.459  1
206586  98.677  -76.956  47.433  1
206587  98.690  -76.966  47.405  1
206588  98.723  -76.969  47.375  1
206589  98.756  -76.971  47.345  1
206590  98.789  -76.972  47.315  1
206591  98.821  -76.975  47.286  1
206592  98.855  -76.977  47.256  1
206593  98.887  -76.979  47.224  1
206594  98.924  -76.982  47.191  1
206595  98.959  -76.992  47.157  1
206596  98.973  -77.006  47.124  1
206597  98.987  -77.019  47.090  1
206598  99.000  -77.033  47.058  1
206599  99.014  -77.047  47.027  1
206600  99.028  -77.060  46.996  1
206601  99.042  -77.074  46.966  1
206602  99.056  -77.088  46.937  1
206603  99.070  -77.102  46.908  1
206604  99.084  -77.116  46.881  1
206605  99.097  -77.129  46.857  1
206606  99.114  -77.143  46.829  1
206607  99.131  -77.157  46.803  1
206608  99.154  -77.160  46.776  1
206609  99.183  -77.152  46.747  1
206610  99.208  -77.146  46.718  1
206611  99.234  -77.140  46.691  1
206612  99.261  -77.135  46.664  1
206613  99.287  -77.128  46.636  1
206614  99.311  -77.141  46.608  1
206615  99.336  -77.156  46.580  1
206616  99.360  -77.171  46.551  1
206617  99.381  -77.185  46.523  1
206618  99.387  -77.199  46.496  1
206619  99.394  -77.213  46.470  1
206620  99.400  -77.227  46.443  1
206621  99.390  -77.225  46.418  1
206622  99.376  -77.219  46.392  1
206623  99.362  -77.213  46.367  1
206624  99.348  -77.207  46.341  1
206625  99.339  -77.201  46.318  1
206626  99.368  -77.205  46.295  1
206627  99.398  -77.208  46.272  1
206628  99.427  -77.212  46.249  1
206629  99.467  -77.216  46.225  1
206630  99.518  -77.224  46.203  1
206631  99.569  -77.231  46.181  1
206632  99.620  -77.238  46.159  1
206633  99.671  -77.244  46.138  1
206634  99.721  -77.251  46.118  1
206635  99.746  -77.244  46.097  1
206636  99.771  -77.238  46.077  1
206637  99.797  -77.232  46.058  1
206638  99.834  -77.232  46.038  1
206639  99.870  -77.232  46.020  1
206640  99.903  -77.251  46.001  1
206641  99.933  -77.272  45.984  1
206642  99.956  -77.282  45.966  1
206643  99.978  -77.291  45.947  1
206644  99.990  -77.284  45.930  1
206645  100.002  -77.276  45.912  1
206646  100.014  -77.268  45.895  1
206647  100.027  -77.260  45.878  1
206648  100.038  -77.251  45.860  1
206649  100.072  -77.265  45.843  1
206650  100.106  -77.279  45.826  1
206651  100.140  -77.292  45.809  1
206652  100.174  -77.306  45.793  1
206653  100.208  -77.320  45.778  1
206654  100.242  -77.334  45.762  1
206655  100.259  -77.340  45.747  1
206656  100.271  -77.343  45.732  1
206657  100.282  -77.348  45.718  1
206658  100.292  -77.360  45.704  1
206659  100.303  -77.370  45.691  1
206660  100.323  -77.377  45.678  1
206661  100.342  -77.384  45.665  1
206662  100.361  -77.392  45.652  1
206663  100.380  -77.398  45.640  1
206664  100.402  -77.411  45.627  1
206665  100.426  -77.426  45.615  1
206666  100.450  -77.442  45.602  1
206667  100.474  -77.457  45.589  1
206668  100.497  -77.477  45.576  1
206669  100.521  -77.497  45.563  1
206670  100.544  -77.517  45.550  1
206671  100.570  -77.532  45.536  1
206672  100.601  -77.536  45.522  1
206673  100.631  -77.542  45.507  1
206674  100.654  -77.551  45.494  1
206675  100.677  -77.562  45.479  1
206676  100.699  -77.572  45.465  1
206677  100.722  -77.582  45.451  1
206678  100.745  -77.592  45.437  1
206679  100.767  -77.602  45.424  1
206680  100.790  -77.613  45.410  1
206681  100.816  -77.628  45.397  1
206682  100.842  -77.645  45.385  1
206683  100.869  -77.661  45.372  1
206684  100.896  -77.679  45.359  1
206685  100.922  -77.696  45.346  1
206686  100.949  -77.712  45.332  1
206687  100.976  -77.729  45.318  1
206688  101.002  -77.746  45.305  1
206689  101.029  -77.763  45.291  1
206690  101.056  -77.780  45.278  1
206691  101.082  -77.796  45.264  1
206692  101.109  -77.814  45.250  1
206693  101.136  -77.830  45.236  1
206694  101.162  -77.847  45.223  1
206695  101.189  -77.865  45.210  1
206696  101.216  -77.881  45.196  1
206697  101.243  -77.898  45.182  1
206698  101.269  -77.915  45.169  1
206699  101.296  -77.932  45.156  1
206700  101.322  -77.949  45.143  1
206701  101.349  -77.965  45.130  1
206702  101.365  -77.974  45.116  1
206703  101.373  -77.975  45.103  1
206704  101.383  -77.977  45.090  1
206705  101.392  -77.979  45.076  1
206706  101.402  -77.981  45.061  1
206707  101.411  -77.984  45.045  1
206708  101.422  -77.987  45.030  1
206709  101.466  -78.010  45.014  1
206710  101.510  -78.034  44.998  1
206711  101.553  -78.056  44.982  1
206712  101.597  -78.080  44.966  1
206713  101.636  -78.101  44.950  1
206714  101.647  -78.108  44.934  1
206715  101.658  -78.114  44.920  1
206716  101.670  -78.122  44.904  1
206717  101.691  -78.133  44.888  1
206718  101.711  -78.144  44.872  1
206719  101.732  -78.156  44.857  1
206720  101.752  -78.168  44.841  1
206721  101.772  -78.179  44.825  1
206722  101.793  -78.191  44.809  1
206723  101.813  -78.202  44.793  1
206724  101.833  -78.213  44.777  1
206725  101.853  -78.225  44.761  1
206726  101.874  -78.236  44.745  1
206727  101.894  -78.248  44.729  1
206728  101.914  -78.260  44.712  1
206729  101.943  -78.270  44.697  1
206730  101.978  -78.281  44.681  1
206731  102.013  -78.291  44.666  1
206732  102.047  -78.302  44.651  1
206733  102.082  -78.313  44.637  1
206734  102.117  -78.323  44.624  1
206735  102.155  -78.338  44.609  1
206736  102.195  -78.360  44.594  1
206737  102.237  -78.381  44.578  1
206738  102.277  -78.402  44.563  1
206739  102.319  -78.423  44.547  1
206740  102.360  -78.445  44.532  1
206741  102.401  -78.466  44.518  1
206742  102.442  -78.487  44.502  1
206743  102.483  -78.508  44.487  1
206744  102.524  -78.529  44.472  1
206745  102.564  -78.551  44.458  1
206746  102.606  -78.572  44.443  1
206747  102.643  -78.594  44.429  1
206748  102.637  -78.595  44.414  1
206749  102.654  -78.595  44.399  1
206750  102.670  -78.597  44.384  1
206751  102.696  -78.600  44.368  1
206752  102.722  -78.602  44.352  1
206753  102.747  -78.605  44.337  1
206754  102.773  -78.608  44.322  1
206755  102.799  -78.610  44.306  1
206756  102.824  -78.613  44.290  1
206757  102.850  -78.615  44.274  1
206758  102.876  -78.617  44.258  1
206759  102.901  -78.620  44.242  1
206760  102.927  -78.623  44.225  1
207045  93.468  -75.900  53.978  1
207046  93.486  -75.903  53.997  1
207047  93.504  -75.906  54.017  1
207048  93.522  -75.909  54.035  1
207049  93.541  -75.912  54.054  1
207050  93.559  -75.916  54.073  1
207051  93.577  -75.919  54.093  1
207052  93.595  -75.922  54.111  1
207053  93.614  -75.926  54.130  1
207054  93.619  -75.956  54.147  1
207055  93.648  -75.955  54.161  1
207056  93.681  -75.949  54.176  1
207057  93.713  -75.942  54.189  1
207058  93.746  -75.936  54.202  1
207059  93.776  -75.930  54.214  1
207060  93.797  -75.922  54.227  1
207061  93.818  -75.915  54.237  1
207062  93.839  -75.907  54.248  1
207063  93.860  -75.900  54.261  1
207064  93.880  -75.892  54.278  1
207065  93.910  -75.887  54.296  1
207066  93.941  -75.882  54.314  1
207067  93.973  -75.878  54.331  1
207068  93.999  -75.872  54.339  1
207069  94.026  -75.867  54.341  1
207070  94.052  -75.862  54.340  1
207071  94.079  -75.858  54.336  1
207072  94.106  -75.853  54.329  1
207073  94.133  -75.849  54.321  1
207074  94.160  -75.844  54.312  1
207075  94.188  -75.840  54.296  1
207076  94.215  -75.836  54.282  1
207077  94.242  -75.831  54.269  1
207078  94.269  -75.828  54.259  1
207079  94.292  -75.825  54.246  1
207080  94.311  -75.826  54.231  1
207081  94.330  -75.829  54.210  1
207082  94.348  -75.831  54.182  1
207083  94.367  -75.834  54.151  1
207084  94.386  -75.837  54.122  1
207085  94.404  -75.839  54.096  1
207086  94.423  -75.842  54.072  1
207087  94.442  -75.844  54.045  1
207088  94.461  -75.847  54.014  1
207089  94.476  -75.854  53.978  1
207090  94.490  -75.864  53.941  1
207091  94.504  -75.873  53.902  1
207092  94.519  -75.883  53.864  1
207093  94.533  -75.893  53.827  1
207094  94.548  -75.902  53.792  1
207095  94.562  -75.910  53.754  1
207096  94.577  -75.919  53.715  1
207097  94.592  -75.928  53.677  1
207098  94.607  -75.937  53.642  1
207099  94.622  -75.945  53.607  1
207100  94.636  -75.953  53.572  1
207101  94.651  -75.963  53.538  1
207102  94.666  -75.971  53.504  1
207103  94.678  -75.977  53.469  1
207104  94.688  -75.980  53.435  1
207105  94.697  -75.982  53.401  1
207106  94.706  -75.985  53.365  1
207107  94.715  -75.988  53.330  1
207108  94.725  -75.991  53.294  1
207109  94.734  -75.994  53.257  1
207110  94.744  -75.997  53.221  1
207111  94.753  -76.000  53.185  1
207112  94.762  -76.003  53.150  1
207113  94.772  -76.006  53.118  1
207114  94.783  -76.010  53.086  1
207115  94.794  -76.013  53.055  1
207116  94.806  -76.016  53.021  1
207117  94.817  -76.020  52.986  1
207118  94.828  -76.023  52.949  1
207119  94.839  -76.027  52.912  1
207120  94.850  -76.031  52.874  1
207121  94.861  -76.035  52.839  1
207122  94.872  -76.038  52.806  1
207123  94.883  -76.041  52.774  1
207124  94.894  -76.045  52.747  1
207125  94.905  -76.048  52.721  1
207126  94.916  -76.052  52.696  1
207127  94.927  -76.056  52.670  1
207128  94.938  -76.060  52.641  1
207129  94.980  -76.060  52.612  1
207130  95.043  -76.060  52.581  1
207131  95.106  -76.059  52.550  1
207132  95.169  -76.058  52.518  1
207133  95.232  -76.057  52.485  1
207134  95.295  -76.057  52.451  1
207135  95.348  -76.057  52.418  1
207136  95.356  -76.069  52.389  1
207137  95.385  -76.077  52.356  1
207138  95.413  -76.085  52.319  1
207139  95.442  -76.093  52.276  1
207140  95.471  -76.101  52.225  1
207141  95.498  -76.107  52.172  1
207142  95.524  -76.106  52.119  1
207143  95.549  -76.104  52.069  1
207144  95.574  -76.103  52.021  1
207145  95.600  -76.101  51.972  1
207146  95.625  -76.100  51.923  1
207147  95.650  -76.098  51.876  1
207148  95.669  -76.100  51.830  1
207149  95.679  -76.107  51.786  1
207150  95.689  -76.113  51.746  1
207151  95.698  -76.119  51.707  1
207152  95.708  -76.126  51.669  1
207153  95.731  -76.131  51.631  1
207154  95.753  -76.135  51.592  1
207155  95.775  -76.140  51.552  1
207156  95.798  -76.144  51.516  1
207157  95.820  -76.148  51.480  1
207158  95.842  -76.153  51.441  1
207159  95.865  -76.157  51.401  1
207160  95.887  -76.162  51.361  1
207161  95.910  -76.166  51.318  1
207162  95.951  -76.166  51.275  1
207163  95.983  -76.166  51.232  1
207164  96.007  -76.165  51.188  1
207165  96.030  -76.164  51.144  1
207166  96.053  -76.163  51.101  1
207167  96.075  -76.166  51.056  1
207168  96.097  -76.167  51.012  1
207169  96.119  -76.169  50.970  1
207170  96.141  -76.171  50.933  1
207171  96.163  -76.173  50.896  1
207172  96.185  -76.174  50.861  1
207173  96.206  -76.176  50.828  1
207174  96.217  -76.185  50.795  1
207175  96.225  -76.195  50.763  1
207176  96.233  -76.205  50.732  1
207177  96.242  -76.214  50.703  1
207178  96.253  -76.221  50.674  1
207179  96.265  -76.228  50.645  1
207180  96.277  -76.235  50.615  1
207181  96.289  -76.242  50.587  1
207182  96.301  -76.249  50.560  1
207183  96.313  -76.256  50.538  1
207184  96.325  -76.263  50.519  1
207185  96.337  -76.270  50.501  1
207186  96.360  -76.283  50.482  1
207187  96.384  -76.297  50.463  1
207188  96.409  -76.311  50.442  1
207189  96.449  -76.323  50.415  1
207190  96.495  -76.334  50.387  1
207191  96.540  -76.345  50.358  1
207192  96.585  -76.357  50.329  1
207193  96.629  -76.364  50.300  1
207194  96.657  -76.355  50.270  1
207195  96.674  -76.348  50.240  1
207196  96.694  -76.345  50.208  1
207197  96.719  -76.354  50.175  1
207198  96.744  -76.364  50.141  1
207199  96.769  -76.373  50.107  1
207200  96.795  -76.383  50.071  1
207201  96.820  -76.392  50.034  1
207202  96.831  -76.389  49.996  1
207203  96.837  -76.381  49.959  1
207204  96.842  -76.373  49.922  1
207205  96.849  -76.365  49.883  1
207206  96.830  -76.357  49.845  1
207207  96.812  -76.348  49.806  1
207208  96.843  -76.359  49.767  1
207209  96.889  -76.374  49.728  1
207210  96.935  -76.389  49.688  1
207211  96.996  -76.412  49.650  1
207212  97.011  -76.441  49.615  1
207213  97.026  -76.469  49.580  1
207214  97.041  -76.497  49.547  1
207215  97.056  -76.526  49.515  1
207216  97.072  -76.554  49.488  1
207217  97.087  -76.583  49.463  1
207218  97.103  -76.611  49.440  1
207219  97.118  -76.639  49.418  1
207220  97.134  -76.668  49.397  1
207221  97.149  -76.696  49.376  1
207222  97.164  -76.724  49.355  1
207223  97.179  -76.752  49.331  1
207224  97.197  -76.777  49.306  1
207225  97.237  -76.766  49.279  1
207226  97.285  -76.730  49.249  1
207227  97.318  -76.715  49.217  1
207228  97.353  -76.699  49.184  1
207229  97.386  -76.684  49.149  1
207230  97.420  -76.669  49.113  1
207231  97.434  -76.686  49.078  1
207232  97.447  -76.701  49.046  1
207233  97.461  -76.712  49.015  1
207234  97.484  -76.723  48.985  1
207235  97.507  -76.735  48.957  1
207236  97.530  -76.746  48.930  1
207237  97.554  -76.759  48.903  1
207238  97.577  -76.770  48.876  1
207239  97.600  -76.782  48.849  1
207240  97.623  -76.793  48.821  1
207241  97.646  -76.806  48.792  1
207242  97.670  -76.817  48.764  1
207243  97.693  -76.829  48.734  1
207244  97.716  -76.840  48.703  1
207245  97.739  -76.852  48.672  1
207246  97.774  -76.862  48.639  1
207247  97.813  -76.871  48.608  1
207248  97.854  -76.879  48.576  1
207249  97.894  -76.887  48.544  1
207250  97.934  -76.895  48.514  1
207251  97.975  -76.903  48.483  1
207252  98.015  -76.911  48.452  1
207253  98.056  -76.919  48.420  1
207254  98.091  -76.926  48.391  1
207255  98.113  -76.921  48.360  1
207256  98.132  -76.914  48.329  1
207257  98.150  -76.908  48.299  1
207258  98.169  -76.901  48.270  1
207259  98.187  -76.894  48.240  1
207260  98.206  -76.887  48.210  1
207261  98.224  -76.880  48.180  1
207262  98.243  -76.871  48.150  1
207263  98.261  -76.864  48.121  1
207264  98.280  -76.856  48.091  1
207265  98.298  -76.848  48.059  1
207266  98.317  -76.840  48.027  1
207267  98.336  -76.832  47.995  1
207268  98.354  -76.824  47.964  1
207269  98.372  -76.816  47.932  1
207270  98.394  -76.816  47.902  1
207271  98.415  -76.812  47.871  1
207272  98.428  -76.818  47.841  1
207273  98.444  -76.831  47.811  1
207274  98.463  -76.847  47.783  1
207275  98.482  -76.863  47.756  1
207276  98.500  -76.879  47.729  1
207277  98.518  -76.895  47.704  1
207278  98.537  -76.912  47.679  1
207279  98.556  -76.928  47.652  1
207280  98.574  -76.943  47.624  1
207281  98.597  -76.942  47.597  1
207282  98.621  -76.936  47.569  1
207283  98.645  -76.931  47.542  1
207284  98.669  -76.925  47.515  1
207285  98.694  -76.919  47.490  1
207286  98.698  -76.928  47.465  1
207287  98.692  -76.946  47.439  1
207288  98.713  -76.953  47.411  1
207289  98.745  -76.954  47.381  1
207290  98.778  -76.956  47.350  1
207291  98.811  -76.959  47.320  1
207292  98.844  -76.961  47.289  1
207293  98.877  -76.963  47.258  1
207294  98.910  -76.965  47.226  1
207295  98.943  -76.967  47.194  1
207296  98.971  -76.975  47.158  1
207297  98.984  -76.989  47.124  1
207298  98.998  -77.003  47.090  1
207299  99.014  -77.016  47.058  1
207300  99.031  -77.030  47.026  1
207301  99.048  -77.044  46.995  1
207302  99.065  -77.057  46.964  1
207303  99.082  -77.071  46.933  1
207304  99.098  -77.085  46.903  1
207305  99.115  -77.098  46.876  1
207306  99.132  -77.112  46.850  1
207307  99.149  -77.125  46.823  1
207308  99.179  -77.116  46.796  1
207309  99.210  -77.107  46.768  1
207310  99.241  -77.097  46.740  1
207311  99.268  -77.091  46.712  1
207312  99.294  -77.087  46.685  1
207313  99.319  -77.101  46.658  1
207314  99.343  -77.116  46.630  1
207315  99.368  -77.131  46.603  1
207316  99.393  -77.146  46.576  1
207317  99.406  -77.160  46.547  1
207318  99.413  -77.175  46.518  1
207319  99.419  -77.188  46.491  1
207320  99.425  -77.203  46.465  1
207321  99.424  -77.209  46.439  1
207322  99.410  -77.203  46.413  1
207323  99.396  -77.197  46.387  1
207324  99.382  -77.190  46.361  1
207325  99.368  -77.184  46.335  1
207326  99.355  -77.178  46.312  1
207327  99.366  -77.178  46.290  1
207328  99.400  -77.182  46.267  1
207329  99.451  -77.188  46.243  1
207330  99.502  -77.195  46.221  1
207331  99.554  -77.203  46.198  1
207332  99.605  -77.210  46.176  1
207333  99.655  -77.216  46.154  1
207334  99.707  -77.223  46.133  1
207335  99.737  -77.219  46.113  1
207336  99.762  -77.213  46.093  1
207337  99.787  -77.207  46.073  1
207338  99.815  -77.202  46.053  1
207339  99.852  -77.202  46.034  1
207340  99.889  -77.201  46.015  1
207341  99.922  -77.216  45.997  1
207342  99.954  -77.238  45.979  1
207343  99.979  -77.254  45.961  1
207344  100.002  -77.263  45.943  1
207345  100.024  -77.272  45.925  1
207346  100.036  -77.264  45.908  1
207347  100.048  -77.256  45.890  1
207348  100.060  -77.248  45.873  1
207349  100.072  -77.240  45.855  1
207350  100.100  -77.248  45.837  1
207351  100.134  -77.262  45.820  1
207352  100.168  -77.276  45.803  1
207353  100.202  -77.289  45.787  1
207354  100.236  -77.303  45.771  1
207355  100.263  -77.313  45.755  1
207356  100.274  -77.316  45.740  1
207357  100.286  -77.320  45.726  1
207358  100.297  -77.326  45.712  1
207359  100.308  -77.336  45.697  1
207360  100.318  -77.347  45.684  1
207361  100.333  -77.356  45.670  1
207362  100.352  -77.363  45.658  1
207363  100.371  -77.370  45.645  1
207364  100.392  -77.379  45.633  1
207365  100.416  -77.395  45.620  1
207366  100.439  -77.410  45.608  1
207367  100.463  -77.429  45.595  1
207368  100.486  -77.448  45.583  1
207369  100.510  -77.468  45.569  1
207370  100.533  -77.489  45.556  1
207371  100.557  -77.508  45.543  1
207372  100.581  -77.526  45.529  1
207373  100.612  -77.531  45.515  1
207374  100.642  -77.536  45.501  1
207375  100.673  -77.541  45.487  1
207376  100.698  -77.549  45.473  1
207377  100.721  -77.559  45.459  1
207378  100.744  -77.570  45.445  1
207379  100.766  -77.580  45.432  1
207380  100.789  -77.590  45.418  1
207381  100.812  -77.600  45.405  1
207382  100.838  -77.616  45.391  1
207383  100.864  -77.633  45.379  1
207384  100.891  -77.650  45.366  1
207385  100.918  -77.667  45.353  1
207386  100.945  -77.683  45.340  1
207387  100.971  -77.701  45.327  1
207388  100.997  -77.718  45.314  1
207389  101.024  -77.734  45.300  1
207390  101.051  -77.751  45.286  1
207391  101.077  -77.768  45.273  1
207392  101.104  -77.785  45.259  1
207393  101.131  -77.802  45.245  1
207394  101.158  -77.818  45.232  1
207395  101.184  -77.836  45.218  1
207396  101.211  -77.852  45.205  1
207397  101.238  -77.869  45.191  1
207398  101.264  -77.887  45.176  1
207399  101.290  -77.903  45.163  1
207400  101.315  -77.922  45.150  1
207401  101.339  -77.941  45.137  1
207402  101.364  -77.951  45.124  1
207403  101.393  -77.967  45.110  1
207404  101.418  -77.980  45.097  1
207405  101.427  -77.982  45.084  1
207406  101.437  -77.984  45.069  1
207407  101.446  -77.987  45.054  1
207408  101.456  -77.989  45.039  1
207409  101.465  -77.991  45.024  1
207410  101.495  -78.006  45.007  1
207411  101.539  -78.029  44.991  1
207412  101.583  -78.053  44.974  1
207413  101.627  -78.076  44.958  1
207414  101.654  -78.091  44.942  1
207415  101.665  -78.097  44.926  1
207416  101.676  -78.104  44.910  1
207417  101.686  -78.111  44.896  1
207418  101.703  -78.120  44.880  1
207419  101.723  -78.131  44.864  1
207420  101.743  -78.143  44.849  1
207421  101.764  -78.155  44.833  1
207422  101.784  -78.166  44.818  1
207423  101.805  -78.178  44.802  1
207424  101.825  -78.189  44.787  1
207425  101.845  -78.200  44.770  1
207426  101.866  -78.212  44.754  1
207427  101.886  -78.223  44.738  1
207428  101.906  -78.235  44.723  1
207429  101.933  -78.246  44.707  1
207430  101.967  -78.257  44.691  1
207431  102.002  -78.267  44.676  1
207432  102.037  -78.278  44.661  1
207433  102.071  -78.288  44.645  1
207434  102.106  -78.299  44.631  1
207435  102.141  -78.310  44.617  1
207436  102.179  -78.326  44.603  1
207437  102.221  -78.347  44.588  1
207438  102.261  -78.369  44.572  1
207439  102.303  -78.390  44.555  1
207440  102.343  -78.411  44.540  1
207441  102.385  -78.432  44.525  1
207442  102.426  -78.454  44.510  1
207443  102.467  -78.475  44.495  1
207444  102.507  -78.496  44.480  1
207445  102.549  -78.517  44.465  1
207446  102.590  -78.539  44.451  1
207447  102.631  -78.560  44.436  1
207448  102.672  -78.581  44.422  1
207449  102.682  -78.582  44.407  1
207450  102.681  -78.579  44.392  1
207451  102.707  -78.582  44.377  1
207452  102.733  -78.585  44.361  1
207453  102.758  -78.587  44.345  1
207454  102.784  -78.590  44.330  1
207455  102.810  -78.592  44.314  1
207456  102.835  -78.595  44.298  1
207457  102.861  -78.598  44.281  1
207458  102.887  -78.600  44.266  1
207459  102.912  -78.603  44.250  1
207460  102.938  -78.605  44.233  1
207461  102.964  -78.608  44.217  1
207746  93.460  -75.876  53.974  1
207747  93.478  -75.880  53.993  1
207748  93.496  -75.883  54.014  1
207749  93.514  -75.886  54.033  1
207750  93.533  -75.890  54.053  1
207751  93.551  -75.893  54.073  1
207752  93.569  -75.896  54.093  1
207753  93.587  -75.900  54.113  1
207754  93.606  -75.903  54.133  1
207755  93.612  -75.933  54.151  1
207756  93.643  -75.927  54.166  1
207757  93.676  -75.921  54.183  1
207758  93.708  -75.915  54.198  1
207759  93.741  -75.909  54.211  1
207760  93.773  -75.903  54.224  1
207761  93.800  -75.896  54.235  1
207762  93.821  -75.888  54.244  1
207763  93.842  -75.881  54.251  1
207764  93.863  -75.873  54.259  1
207765  93.884  -75.865  54.272  1
207766  93.910  -75.859  54.287  1
207767  93.942  -75.855  54.304  1
207768  93.974  -75.850  54.319  1
207769  94.000  -75.845  54.326  1
207770  94.026  -75.840  54.328  1
207771  94.052  -75.834  54.326  1
207772  94.079  -75.830  54.321  1
207773  94.106  -75.825  54.313  1
207774  94.133  -75.821  54.304  1
207775  94.160  -75.816  54.295  1
207776  94.187  -75.812  54.278  1
207777  94.214  -75.808  54.264  1
207778  94.242  -75.803  54.252  1
207779  94.269  -75.799  54.244  1
207780  94.293  -75.800  54.233  1
207781  94.313  -75.801  54.220  1
207782  94.333  -75.803  54.203  1
207783  94.352  -75.805  54.177  1
207784  94.371  -75.808  54.149  1
207785  94.390  -75.810  54.122  1
207786  94.408  -75.813  54.097  1
207787  94.427  -75.815  54.075  1
207788  94.445  -75.818  54.050  1
207789  94.464  -75.821  54.020  1
207790  94.480  -75.828  53.984  1
207791  94.494  -75.838  53.946  1
207792  94.508  -75.848  53.908  1
207793  94.523  -75.856  53.871  1
207794  94.538  -75.865  53.835  1
207795  94.552  -75.874  53.801  1
207796  94.567  -75.883  53.767  1
207797  94.582  -75.891  53.732  1
207798  94.597  -75.900  53.698  1
207799  94.612  -75.909  53.664  1
207800  94.626  -75.917  53.629  1
207801  94.641  -75.926  53.593  1
207802  94.656  -75.934  53.556  1
207803  94.671  -75.944  53.519  1
207804  94.683  -75.950  53.482  1
207805  94.692  -75.952  53.446  1
207806  94.702  -75.955  53.410  1
207807  94.711  -75.958  53.372  1
207808  94.720  -75.960  53.335  1
207809  94.730  -75.963  53.300  1
207810  94.739  -75.966  53.262  1
207811  94.748  -75.969  53.226  1
207812  94.758  -75.972  53.189  1
207813  94.767  -75.975  53.152  1
207814  94.776  -75.978  53.117  1
207815  94.785  -75.981  53.083  1
207816  94.795  -75.983  53.050  1
207817  94.806  -75.987  53.015  1
207818  94.817  -75.991  52.981  1
207819  94.828  -75.994  52.945  1
207820  94.839  -75.997  52.908  1
207821  94.850  -76.001  52.872  1
207822  94.861  -76.005  52.838  1
207823  94.872  -76.008  52.806  1
207824  94.883  -76.012  52.776  1
207825  94.894  -76.016  52.751  1
207826  94.905  -76.019  52.729  1
207827  94.916  -76.022  52.706  1
207828  94.927  -76.026  52.681  1
207829  94.938  -76.030  52.652  1
207830  94.979  -76.031  52.623  1
207831  95.042  -76.030  52.594  1
207832  95.105  -76.029  52.563  1
207833  95.167  -76.028  52.531  1
207834  95.230  -76.028  52.497  1
207835  95.293  -76.027  52.463  1
207836  95.356  -76.026  52.429  1
207837  95.411  -76.027  52.397  1
207838  95.426  -76.038  52.364  1
207839  95.454  -76.045  52.327  1
207840  95.483  -76.053  52.285  1
207841  95.512  -76.061  52.234  1
207842  95.537  -76.060  52.180  1
207843  95.562  -76.058  52.125  1
207844  95.587  -76.057  52.074  1
207845  95.612  -76.055  52.025  1
207846  95.634  -76.056  51.977  1
207847  95.643  -76.063  51.929  1
207848  95.653  -76.069  51.882  1
207849  95.663  -76.076  51.836  1
207850  95.673  -76.083  51.791  1
207851  95.682  -76.090  51.750  1
207852  95.692  -76.096  51.711  1
207853  95.702  -76.103  51.673  1
207854  95.722  -76.108  51.637  1
207855  95.744  -76.113  51.600  1
207856  95.766  -76.116  51.561  1
207857  95.789  -76.121  51.525  1
207858  95.811  -76.126  51.489  1
207859  95.833  -76.130  51.450  1
207860  95.856  -76.135  51.411  1
207861  95.878  -76.138  51.370  1
207862  95.910  -76.141  51.328  1
207863  95.950  -76.141  51.286  1
207864  95.990  -76.140  51.244  1
207865  96.013  -76.140  51.201  1
207866  96.036  -76.139  51.158  1
207867  96.060  -76.138  51.115  1
207868  96.083  -76.138  51.070  1
207869  96.107  -76.137  51.025  1
207870  96.129  -76.138  50.982  1
207871  96.151  -76.140  50.945  1
207872  96.173  -76.142  50.908  1
207873  96.194  -76.144  50.873  1
207874  96.217  -76.145  50.839  1
207875  96.227  -76.154  50.808  1
207876  96.235  -76.164  50.776  1
207877  96.242  -76.175  50.745  1
207878  96.245  -76.190  50.717  1
207879  96.267  -76.201  50.689  1
207880  96.273  -76.208  50.659  1
207881  96.282  -76.215  50.630  1
207882  96.293  -76.222  50.602  1
207883  96.305  -76.229  50.576  1
207884  96.317  -76.236  50.553  1
207885  96.329  -76.243  50.534  1
207886  96.341  -76.250  50.516  1
207887  96.356  -76.258  50.496  1
207888  96.380  -76.272  50.476  1
207889  96.404  -76.286  50.453  1
207890  96.447  -76.298  50.427  1
207891  96.492  -76.309  50.400  1
207892  96.537  -76.320  50.373  1
207893  96.583  -76.332  50.345  1
207894  96.626  -76.345  50.316  1
207895  96.660  -76.348  50.287  1
207896  96.675  -76.348  50.256  1
207897  96.690  -76.348  50.224  1
207898  96.708  -76.340  50.192  1
207899  96.726  -76.332  50.159  1
207900  96.749  -76.337  50.125  1
207901  96.774  -76.347  50.089  1
207902  96.799  -76.357  50.053  1
207903  96.816  -76.358  50.015  1
207904  96.822  -76.351  49.978  1
207905  96.822  -76.342  49.940  1
207906  96.804  -76.334  49.901  1
207907  96.844  -76.348  49.862  1
207908  96.890  -76.363  49.823  1
207909  96.929  -76.376  49.785  1
207910  96.952  -76.383  49.746  1
207911  96.975  -76.391  49.707  1
207912  96.998  -76.398  49.669  1
207913  97.036  -76.423  49.633  1
207914  97.050  -76.452  49.598  1
207915  97.065  -76.481  49.564  1
207916  97.079  -76.509  49.532  1
207917  97.094  -76.538  49.505  1
207918  97.108  -76.566  49.480  1
207919  97.122  -76.595  49.456  1
207920  97.137  -76.624  49.433  1
207921  97.151  -76.652  49.412  1
207922  97.166  -76.680  49.390  1
207923  97.180  -76.708  49.368  1
207924  97.194  -76.737  49.343  1
207925  97.197  -76.759  49.316  1
207926  97.232  -76.756  49.287  1
207927  97.264  -76.743  49.256  1
207928  97.296  -76.730  49.223  1
207929  97.328  -76.716  49.189  1
207930  97.361  -76.703  49.153  1
207931  97.393  -76.690  49.119  1
207932  97.426  -76.676  49.085  1
207933  97.450  -76.675  49.053  1
207934  97.473  -76.687  49.023  1
207935  97.497  -76.699  48.993  1
207936  97.521  -76.711  48.966  1
207937  97.545  -76.723  48.940  1
207938  97.568  -76.734  48.913  1
207939  97.591  -76.746  48.886  1
207940  97.614  -76.758  48.860  1
207941  97.638  -76.769  48.832  1
207942  97.661  -76.781  48.804  1
207943  97.684  -76.793  48.775  1
207944  97.707  -76.805  48.745  1
207945  97.730  -76.816  48.714  1
207946  97.753  -76.828  48.682  1
207947  97.777  -76.840  48.649  1
207948  97.813  -76.850  48.617  1
207949  97.853  -76.857  48.585  1
207950  97.893  -76.865  48.552  1
207951  97.934  -76.874  48.522  1
207952  97.974  -76.881  48.490  1
207953  98.017  -76.888  48.459  1
207954  98.062  -76.893  48.428  1
207955  98.107  -76.897  48.398  1
207956  98.132  -76.909  48.367  1
207957  98.151  -76.904  48.337  1
207958  98.169  -76.897  48.306  1
207959  98.187  -76.891  48.277  1
207960  98.206  -76.884  48.247  1
207961  98.224  -76.878  48.218  1
207962  98.243  -76.869  48.188  1
207963  98.262  -76.862  48.158  1
207964  98.280  -76.854  48.129  1
207965  98.299  -76.846  48.101  1
207966  98.317  -76.838  48.070  1
207967  98.336  -76.830  48.039  1
207968  98.354  -76.822  48.007  1
207969  98.375  -76.821  47.976  1
207970  98.397  -76.822  47.944  1
207971  98.419  -76.822  47.915  1
207972  98.443  -76.811  47.885  1
207973  98.458  -76.813  47.856  1
207974  98.471  -76.818  47.826  1
207975  98.484  -76.824  47.798  1
207976  98.498  -76.831  47.771  1
207977  98.516  -76.848  47.743  1
207978  98.534  -76.864  47.719  1
207979  98.553  -76.880  47.693  1
207980  98.572  -76.897  47.667  1
207981  98.590  -76.912  47.639  1
207982  98.608  -76.928  47.610  1
207983  98.631  -76.929  47.581  1
207984  98.655  -76.923  47.552  1
207985  98.679  -76.918  47.525  1
207986  98.703  -76.912  47.497  1
207987  98.713  -76.917  47.471  1
207988  98.706  -76.935  47.445  1
207989  98.735  -76.938  47.417  1
207990  98.768  -76.940  47.387  1
207991  98.801  -76.943  47.356  1
207992  98.834  -76.945  47.324  1
207993  98.867  -76.947  47.293  1
207994  98.900  -76.949  47.260  1
207995  98.933  -76.951  47.228  1
207996  98.966  -76.953  47.194  1
207997  98.999  -76.959  47.159  1
207998  99.015  -76.972  47.125  1
207999  99.032  -76.985  47.091  1
208000  99.049  -76.999  47.058  1
208001  99.066  -77.012  47.027  1
208002  99.083  -77.026  46.995  1
208003  99.099  -77.040  46.963  1
208004  99.116  -77.053  46.930  1
208005  99.133  -77.067  46.900  1
208006  99.150  -77.080  46.871  1
208007  99.173  -77.084  46.844  1
208008  99.204  -77.074  46.816  1
208009  99.235  -77.065  46.788  1
208010  99.266  -77.055  46.761  1
208011  99.289  -77.049  46.733  1
208012  99.307  -77.064  46.705  1
208013  99.351  -77.077  46.679  1
208014  99.375  -77.091  46.652  1
208015  99.400  -77.106  46.624  1
208016  99.424  -77.122  46.597  1
208017  99.431  -77.135  46.570  1
208018  99.438  -77.150  46.541  1
208019  99.444  -77.163  46.512  1
208020  99.451  -77.178  46.485  1
208021  99.457  -77.191  46.459  1
208022  99.444  -77.186  46.432  1
208023  99.430  -77.180  46.406  1
208024  99.416  -77.174  46.380  1
208025  99.402  -77.168  46.354  1
208026  99.389  -77.162  46.328  1
208027  99.375  -77.156  46.306  1
208028  99.385  -77.153  46.283  1
208029  99.436  -77.160  46.260  1
208030  99.487  -77.167  46.237  1
208031  99.538  -77.174  46.215  1
208032  99.589  -77.182  46.192  1
208033  99.640  -77.188  46.170  1
208034  99.691  -77.195  46.149  1
208035  99.728  -77.195  46.128  1
208036  99.753  -77.188  46.108  1
208037  99.778  -77.182  46.088  1
208038  99.802  -77.175  46.068  1
208039  99.833  -77.172  46.047  1
208040  99.870  -77.172  46.028  1
208041  99.907  -77.172  46.010  1
208042  99.941  -77.181  45.992  1
208043  99.973  -77.204  45.974  1
208044  100.003  -77.225  45.956  1
208045  100.026  -77.235  45.938  1
208046  100.049  -77.245  45.920  1
208047  100.069  -77.253  45.902  1
208048  100.081  -77.244  45.885  1
208049  100.093  -77.236  45.867  1
208050  100.106  -77.229  45.850  1
208051  100.128  -77.231  45.832  1
208052  100.162  -77.244  45.814  1
208053  100.196  -77.258  45.796  1
208054  100.230  -77.272  45.780  1
208055  100.264  -77.285  45.764  1
208056  100.278  -77.290  45.748  1
208057  100.289  -77.294  45.733  1
208058  100.301  -77.298  45.719  1
208059  100.313  -77.302  45.705  1
208060  100.323  -77.313  45.691  1
208061  100.333  -77.324  45.677  1
208062  100.343  -77.335  45.664  1
208063  100.362  -77.342  45.651  1
208064  100.382  -77.349  45.638  1
208065  100.405  -77.363  45.625  1
208066  100.429  -77.379  45.613  1
208067  100.452  -77.400  45.600  1
208068  100.476  -77.420  45.588  1
208069  100.499  -77.440  45.576  1
208070  100.522  -77.460  45.562  1
208071  100.546  -77.479  45.549  1
208072  100.569  -77.500  45.536  1
208073  100.593  -77.520  45.522  1
208074  100.623  -77.525  45.508  1
208075  100.653  -77.530  45.495  1
208076  100.684  -77.535  45.481  1
208077  100.714  -77.540  45.468  1
208078  100.742  -77.547  45.454  1
208079  100.765  -77.557  45.441  1
208080  100.787  -77.567  45.426  1
208081  100.810  -77.577  45.413  1
208082  100.833  -77.588  45.400  1
208083  100.859  -77.605  45.386  1
208084  100.886  -77.621  45.374  1
208085  100.913  -77.638  45.361  1
208086  100.939  -77.655  45.348  1
208087  100.966  -77.672  45.335  1
208088  100.993  -77.689  45.322  1
208089  101.019  -77.705  45.309  1
208090  101.046  -77.723  45.296  1
208091  101.073  -77.740  45.282  1
208092  101.100  -77.756  45.268  1
208093  101.126  -77.773  45.254  1
208094  101.153  -77.790  45.240  1
208095  101.179  -77.807  45.228  1
208096  101.204  -77.825  45.214  1
208097  101.229  -77.844  45.200  1
208098  101.252  -77.863  45.186  1
208099  101.276  -77.882  45.171  1
208100  101.301  -77.901  45.158  1
208101  101.326  -77.912  45.144  1
208102  101.352  -77.921  45.131  1
208103  101.379  -77.934  45.117  1
208104  101.408  -77.950  45.104  1
208105  101.437  -77.967  45.090  1
208106  101.466  -77.983  45.076  1
208107  101.481  -77.990  45.061  1
208108  101.491  -77.992  45.046  1
208109  101.500  -77.994  45.031  1
208110  101.510  -77.996  45.016  1
208111  101.525  -78.002  45.000  1
208112  101.568  -78.025  44.983  1
208113  101.612  -78.049  44.966  1
208114  101.656  -78.072  44.950  1
208115  101.672  -78.081  44.934  1
208116  101.682  -78.087  44.918  1
208117  101.693  -78.094  44.902  1
208118  101.704  -78.101  44.887  1
208119  101.715  -78.107  44.872  1
208120  101.735  -78.119  44.856  1
208121  101.755  -78.130  44.841  1
208122  101.776  -78.141  44.825  1
208123  101.796  -78.153  44.810  1
208124  101.816  -78.165  44.796  1
208125  101.837  -78.176  44.781  1
208126  101.857  -78.188  44.764  1
208127  101.878  -78.199  44.747  1
208128  101.898  -78.210  44.731  1
208129  101.921  -78.222  44.717  1
208130  101.957  -78.232  44.701  1
208131  101.991  -78.243  44.685  1
208132  102.026  -78.253  44.670  1
208133  102.061  -78.264  44.654  1
208134  102.096  -78.275  44.639  1
208135  102.130  -78.285  44.624  1
208136  102.165  -78.296  44.609  1
208137  102.204  -78.313  44.595  1
208138  102.245  -78.335  44.580  1
208139  102.287  -78.357  44.565  1
208140  102.327  -78.378  44.548  1
208141  102.369  -78.399  44.532  1
208142  102.409  -78.420  44.517  1
208143  102.451  -78.442  44.501  1
208144  102.491  -78.463  44.487  1
208145  102.533  -78.484  44.472  1
208146  102.574  -78.505  44.458  1
208147  102.615  -78.526  44.443  1
208148  102.655  -78.547  44.429  1
208149  102.686  -78.553  44.415  1
208150  102.701  -78.543  44.400  1
208151  102.699  -78.546  44.385  1
208152  102.736  -78.560  44.370  1
208153  102.769  -78.570  44.353  1
208154  102.795  -78.573  44.337  1
208155  102.820  -78.575  44.322  1
208156  102.846  -78.577  44.306  1
208157  102.872  -78.580  44.289  1
208158  102.897  -78.582  44.273  1
208159  102.923  -78.585  44.258  1
208160  102.949  -78.588  44.241  1
208161  102.974  -78.590  44.225  1
208162  103.000  -78.593  44.208  1
208446  93.433  -75.850  53.951  1
208447  93.451  -75.853  53.970  1
208448  93.470  -75.856  53.990  1
208449  93.488  -75.859  54.011  1
208450  93.506  -75.863  54.030  1
208451  93.524  -75.866  54.051  1
208452  93.543  -75.869  54.072  1
208453  93.561  -75.873  54.093  1
208454  93.579  -75.876  54.115  1
208455  93.597  -75.879  54.136  1
208456  93.606  -75.906  54.156  1
208457  93.638  -75.900  54.173  1
208458  93.671  -75.894  54.193  1
208459  93.703  -75.887  54.211  1
208460  93.735  -75.881  54.226  1
208461  93.768  -75.875  54.239  1
208462  93.800  -75.869  54.249  1
208463  93.825  -75.862  54.255  1
208464  93.845  -75.854  54.258  1
208465  93.866  -75.847  54.261  1
208466  93.887  -75.839  54.269  1
208467  93.911  -75.832  54.280  1
208468  93.943  -75.828  54.293  1
208469  93.974  -75.823  54.307  1
208470  94.001  -75.818  54.312  1
208471  94.027  -75.812  54.313  1
208472  94.053  -75.807  54.311  1
208473  94.079  -75.802  54.306  1
208474  94.106  -75.797  54.297  1
208475  94.133  -75.793  54.288  1
208476  94.160  -75.789  54.278  1
208477  94.187  -75.784  54.261  1
208478  94.214  -75.780  54.248  1
208479  94.241  -75.777  54.237  1
208480  94.266  -75.777  54.229  1
208481  94.291  -75.777  54.220  1
208482  94.313  -75.778  54.209  1
208483  94.332  -75.780  54.194  1
208484  94.352  -75.782  54.171  1
208485  94.371  -75.784  54.145  1
208486  94.391  -75.785  54.120  1
208487  94.411  -75.787  54.097  1
208488  94.431  -75.789  54.077  1
208489  94.450  -75.792  54.053  1
208490  94.468  -75.794  54.024  1
208491  94.483  -75.803  53.988  1
208492  94.498  -75.812  53.950  1
208493  94.512  -75.820  53.913  1
208494  94.528  -75.829  53.878  1
208495  94.542  -75.837  53.845  1
208496  94.557  -75.847  53.815  1
208497  94.572  -75.855  53.784  1
208498  94.586  -75.864  53.752  1
208499  94.602  -75.872  53.719  1
208500  94.616  -75.881  53.685  1
208501  94.631  -75.890  53.650  1
208502  94.646  -75.898  53.613  1
208503  94.661  -75.907  53.575  1
208504  94.676  -75.916  53.536  1
208505  94.688  -75.922  53.497  1
208506  94.697  -75.925  53.458  1
208507  94.706  -75.928  53.420  1
208508  94.716  -75.930  53.382  1
208509  94.725  -75.933  53.345  1
208510  94.735  -75.936  53.308  1
208511  94.744  -75.939  53.271  1
208512  94.753  -75.941  53.234  1
208513  94.762  -75.944  53.197  1
208514  94.772  -75.947  53.157  1
208515  94.781  -75.950  53.119  1
208516  94.790  -75.953  53.082  1
208517  94.800  -75.956  53.046  1
208518  94.809  -75.959  53.011  1
208519  94.819  -75.961  52.976  1
208520  94.828  -75.964  52.940  1
208521  94.839  -75.968  52.904  1
208522  94.850  -75.972  52.869  1
208523  94.861  -75.975  52.836  1
208524  94.873  -75.978  52.806  1
208525  94.884  -75.982  52.778  1
208526  94.895  -75.986  52.755  1
208527  94.905  -75.989  52.735  1
208528  94.916  -75.993  52.714  1
208529  94.927  -75.997  52.690  1
208530  94.938  -76.000  52.662  1
208531  94.977  -76.001  52.633  1
208532  95.040  -76.000  52.604  1
208533  95.103  -76.000  52.573  1
208534  95.166  -75.999  52.542  1
208535  95.229  -75.998  52.507  1
208536  95.291  -75.997  52.472  1
208537  95.354  -75.997  52.437  1
208538  95.417  -75.996  52.403  1
208539  95.473  -75.997  52.368  1
208540  95.495  -76.006  52.331  1
208541  95.524  -76.013  52.288  1
208542  95.550  -76.014  52.238  1
208543  95.575  -76.013  52.184  1
208544  95.598  -76.012  52.129  1
208545  95.608  -76.019  52.076  1
208546  95.618  -76.025  52.027  1
208547  95.627  -76.032  51.980  1
208548  95.637  -76.039  51.933  1
208549  95.647  -76.046  51.887  1
208550  95.657  -76.053  51.841  1
208551  95.666  -76.060  51.797  1
208552  95.676  -76.066  51.754  1
208553  95.686  -76.073  51.713  1
208554  95.695  -76.079  51.676  1
208555  95.712  -76.085  51.641  1
208556  95.735  -76.089  51.606  1
208557  95.757  -76.094  51.570  1
208558  95.780  -76.098  51.534  1
208559  95.802  -76.103  51.498  1
208560  95.824  -76.107  51.459  1
208561  95.847  -76.111  51.420  1
208562  95.870  -76.116  51.381  1
208563  95.910  -76.116  51.340  1
208564  95.950  -76.115  51.299  1
208565  95.990  -76.115  51.257  1
208566  96.020  -76.115  51.215  1
208567  96.043  -76.114  51.171  1
208568  96.066  -76.113  51.128  1
208569  96.090  -76.113  51.083  1
208570  96.113  -76.112  51.039  1
208571  96.136  -76.111  50.996  1
208572  96.160  -76.110  50.958  1
208573  96.182  -76.111  50.921  1
208574  96.204  -76.113  50.885  1
208575  96.226  -76.115  50.852  1
208576  96.237  -76.123  50.820  1
208577  96.242  -76.135  50.788  1
208578  96.241  -76.151  50.758  1
208579  96.248  -76.166  50.731  1
208580  96.270  -76.176  50.702  1
208581  96.292  -76.188  50.673  1
208582  96.300  -76.195  50.645  1
208583  96.306  -76.202  50.617  1
208584  96.312  -76.209  50.591  1
208585  96.321  -76.216  50.568  1
208586  96.333  -76.223  50.548  1
208587  96.345  -76.230  50.529  1
208588  96.357  -76.237  50.509  1
208589  96.375  -76.247  50.488  1
208590  96.399  -76.261  50.464  1
208591  96.444  -76.273  50.439  1
208592  96.489  -76.284  50.413  1
208593  96.534  -76.295  50.387  1
208594  96.577  -76.310  50.360  1
208595  96.620  -76.323  50.332  1
208596  96.655  -76.328  50.303  1
208597  96.683  -76.326  50.273  1
208598  96.698  -76.326  50.241  1
208599  96.714  -76.326  50.209  1
208600  96.729  -76.326  50.177  1
208601  96.744  -76.325  50.142  1
208602  96.759  -76.325  50.107  1
208603  96.779  -76.321  50.071  1
208604  96.801  -76.328  50.033  1
208605  96.799  -76.321  49.995  1
208606  96.839  -76.334  49.957  1
208607  96.862  -76.342  49.918  1
208608  96.885  -76.349  49.879  1
208609  96.908  -76.357  49.841  1
208610  96.931  -76.365  49.802  1
208611  96.954  -76.373  49.764  1
208612  96.977  -76.380  49.725  1
208613  97.000  -76.388  49.687  1
208614  97.043  -76.409  49.650  1
208615  97.084  -76.434  49.615  1
208616  97.098  -76.462  49.582  1
208617  97.112  -76.491  49.549  1
208618  97.126  -76.520  49.522  1
208619  97.141  -76.548  49.496  1
208620  97.156  -76.577  49.473  1
208621  97.170  -76.605  49.450  1
208622  97.184  -76.633  49.428  1
208623  97.199  -76.662  49.404  1
208624  97.213  -76.690  49.380  1
208625  97.180  -76.701  49.354  1
208626  97.220  -76.719  49.325  1
208627  97.255  -76.718  49.294  1
208628  97.288  -76.705  49.262  1
208629  97.320  -76.692  49.228  1
208630  97.352  -76.678  49.193  1
208631  97.384  -76.665  49.158  1
208632  97.417  -76.652  49.124  1
208633  97.449  -76.638  49.092  1
208634  97.460  -76.649  49.061  1
208635  97.479  -76.661  49.031  1
208636  97.503  -76.673  49.002  1
208637  97.527  -76.685  48.976  1
208638  97.550  -76.696  48.950  1
208639  97.574  -76.708  48.924  1
208640  97.598  -76.721  48.897  1
208641  97.622  -76.732  48.870  1
208642  97.646  -76.744  48.843  1
208643  97.669  -76.756  48.815  1
208644  97.693  -76.768  48.786  1
208645  97.717  -76.780  48.756  1
208646  97.741  -76.792  48.724  1
208647  97.764  -76.803  48.692  1
208648  97.788  -76.815  48.659  1
208649  97.820  -76.825  48.626  1
208650  97.865  -76.828  48.594  1
208651  97.911  -76.833  48.561  1
208652  97.956  -76.838  48.530  1
208653  98.001  -76.843  48.498  1
208654  98.046  -76.847  48.466  1
208655  98.092  -76.853  48.436  1
208656  98.125  -76.862  48.405  1
208657  98.147  -76.875  48.374  1
208658  98.168  -76.887  48.344  1
208659  98.188  -76.887  48.314  1
208660  98.206  -76.881  48.284  1
208661  98.225  -76.875  48.254  1
208662  98.243  -76.868  48.225  1
208663  98.262  -76.859  48.196  1
208664  98.280  -76.852  48.167  1
208665  98.299  -76.844  48.139  1
208666  98.317  -76.836  48.111  1
208667  98.336  -76.828  48.082  1
208668  98.357  -76.826  48.051  1
208669  98.378  -76.827  48.020  1
208670  98.400  -76.828  47.989  1
208671  98.422  -76.829  47.957  1
208672  98.444  -76.825  47.928  1
208673  98.469  -76.815  47.900  1
208674  98.490  -76.809  47.871  1
208675  98.502  -76.815  47.841  1
208676  98.515  -76.820  47.813  1
208677  98.527  -76.825  47.785  1
208678  98.541  -76.831  47.758  1
208679  98.553  -76.837  47.733  1
208680  98.569  -76.849  47.707  1
208681  98.588  -76.865  47.680  1
208682  98.606  -76.881  47.652  1
208683  98.625  -76.897  47.623  1
208684  98.643  -76.913  47.594  1
208685  98.665  -76.916  47.564  1
208686  98.689  -76.910  47.535  1
208687  98.713  -76.905  47.505  1
208688  98.727  -76.906  47.477  1
208689  98.725  -76.922  47.449  1
208690  98.758  -76.925  47.421  1
208691  98.791  -76.927  47.391  1
208692  98.823  -76.929  47.360  1
208693  98.856  -76.931  47.328  1
208694  98.889  -76.933  47.295  1
208695  98.922  -76.935  47.262  1
208696  98.955  -76.937  47.228  1
208697  98.995  -76.937  47.195  1
208698  99.033  -76.940  47.160  1
208699  99.050  -76.954  47.125  1
208700  99.067  -76.968  47.092  1
208701  99.084  -76.981  47.059  1
208702  99.100  -76.995  47.027  1
208703  99.118  -77.009  46.994  1
208704  99.134  -77.022  46.961  1
208705  99.151  -77.035  46.927  1
208706  99.168  -77.049  46.896  1
208707  99.198  -77.041  46.866  1
208708  99.228  -77.031  46.838  1
208709  99.260  -77.022  46.809  1
208710  99.274  -77.014  46.781  1
208711  99.292  -77.028  46.753  1
208712  99.309  -77.044  46.725  1
208713  99.327  -77.058  46.698  1
208714  99.368  -77.071  46.671  1
208715  99.432  -77.082  46.644  1
208716  99.450  -77.097  46.617  1
208717  99.457  -77.110  46.590  1
208718  99.463  -77.125  46.563  1
208719  99.470  -77.138  46.534  1
208720  99.476  -77.153  46.505  1
208721  99.483  -77.167  46.478  1
208722  99.478  -77.169  46.452  1
208723  99.464  -77.163  46.425  1
208724  99.450  -77.157  46.399  1
208725  99.436  -77.151  46.373  1
208726  99.422  -77.145  46.347  1
208727  99.430  -77.143  46.321  1
208728  99.440  -77.141  46.299  1
208729  99.450  -77.138  46.275  1
208730  99.471  -77.139  46.252  1
208731  99.522  -77.146  46.230  1
208732  99.573  -77.153  46.208  1
208733  99.625  -77.160  46.185  1
208734  99.676  -77.167  46.162  1
208735  99.719  -77.170  46.141  1
208736  99.744  -77.163  46.122  1
208737  99.769  -77.157  46.101  1
208738  99.793  -77.150  46.081  1
208739  99.818  -77.144  46.060  1
208740  99.851  -77.142  46.041  1
208741  99.889  -77.142  46.022  1
208742  99.925  -77.141  46.004  1
208743  99.961  -77.146  45.985  1
208744  99.992  -77.169  45.968  1
208745  100.023  -77.191  45.950  1
208746  100.050  -77.207  45.932  1
208747  100.072  -77.217  45.914  1
208748  100.095  -77.227  45.896  1
208749  100.115  -77.233  45.879  1
208750  100.127  -77.225  45.861  1
208751  100.139  -77.216  45.843  1
208752  100.156  -77.213  45.825  1
208753  100.190  -77.228  45.807  1
208754  100.224  -77.241  45.790  1
208755  100.258  -77.255  45.774  1
208756  100.282  -77.264  45.758  1
208757  100.293  -77.267  45.742  1
208758  100.305  -77.271  45.726  1
208759  100.317  -77.274  45.712  1
208760  100.328  -77.279  45.698  1
208761  100.338  -77.290  45.684  1
208762  100.348  -77.301  45.670  1
208763  100.359  -77.311  45.657  1
208764  100.373  -77.321  45.644  1
208765  100.395  -77.332  45.631  1
208766  100.418  -77.351  45.618  1
208767  100.441  -77.371  45.606  1
208768  100.465  -77.391  45.593  1
208769  100.488  -77.411  45.580  1
208770  100.511  -77.431  45.568  1
208771  100.535  -77.451  45.555  1
208772  100.558  -77.471  45.542  1
208773  100.581  -77.491  45.529  1
208774  100.605  -77.511  45.515  1
208775  100.634  -77.519  45.502  1
208776  100.665  -77.524  45.489  1
208777  100.695  -77.530  45.475  1
208778  100.725  -77.534  45.463  1
208779  100.756  -77.539  45.450  1
208780  100.786  -77.545  45.437  1
208781  100.809  -77.555  45.422  1
208782  100.832  -77.565  45.409  1
208783  100.855  -77.576  45.396  1
208784  100.881  -77.592  45.383  1
208785  100.908  -77.609  45.370  1
208786  100.934  -77.627  45.357  1
208787  100.961  -77.643  45.344  1
208788  100.988  -77.660  45.331  1
208789  101.015  -77.677  45.318  1
208790  101.041  -77.694  45.305  1
208791  101.068  -77.711  45.291  1
208792  101.094  -77.728  45.277  1
208793  101.118  -77.747  45.263  1
208794  101.142  -77.766  45.249  1
208795  101.166  -77.785  45.235  1
208796  101.190  -77.804  45.223  1
208797  101.214  -77.823  45.209  1
208798  101.238  -77.842  45.196  1
208799  101.262  -77.861  45.181  1
208800  101.287  -77.874  45.166  1
208801  101.314  -77.883  45.152  1
208802  101.339  -77.893  45.138  1
208803  101.365  -77.902  45.125  1
208804  101.394  -77.918  45.111  1
208805  101.423  -77.934  45.097  1
208806  101.452  -77.950  45.083  1
208807  101.481  -77.967  45.067  1
208808  101.510  -77.983  45.052  1
208809  101.536  -77.997  45.038  1
208810  101.545  -78.000  45.023  1
208811  101.554  -78.002  45.007  1
208812  101.564  -78.004  44.991  1
208813  101.598  -78.022  44.975  1
208814  101.642  -78.044  44.958  1
208815  101.679  -78.065  44.941  1
208816  101.689  -78.071  44.925  1
208817  101.700  -78.078  44.909  1
208818  101.711  -78.084  44.894  1
208819  101.722  -78.091  44.879  1
208820  101.733  -78.097  44.863  1
208821  101.747  -78.106  44.848  1
208822  101.767  -78.117  44.834  1
208823  101.787  -78.128  44.818  1
208824  101.808  -78.140  44.803  1
208825  101.828  -78.152  44.788  1
208826  101.849  -78.163  44.772  1
208827  101.869  -78.175  44.756  1
208828  101.890  -78.186  44.740  1
208829  101.911  -78.197  44.724  1
208830  101.946  -78.208  44.708  1
208831  101.980  -78.219  44.693  1
208832  102.015  -78.229  44.677  1
208833  102.050  -78.240  44.662  1
208834  102.085  -78.250  44.646  1
208835  102.120  -78.261  44.631  1
208836  102.155  -78.272  44.616  1
208837  102.189  -78.282  44.601  1
208838  102.230  -78.302  44.587  1
208839  102.270  -78.323  44.572  1
208840  102.312  -78.344  44.556  1
208841  102.352  -78.366  44.540  1
208842  102.394  -78.387  44.524  1
208843  102.435  -78.408  44.508  1
208844  102.476  -78.429  44.493  1
208845  102.517  -78.451  44.479  1
208846  102.558  -78.472  44.465  1
208847  102.599  -78.493  44.450  1
208848  102.633  -78.505  44.435  1
208849  102.664  -78.511  44.421  1
208850  102.694  -78.517  44.407  1
208851  102.709  -78.504  44.392  1
208852  102.716  -78.512  44.377  1
208853  102.753  -78.526  44.361  1
208854  102.790  -78.539  44.345  1
208855  102.827  -78.553  44.329  1
208856  102.857  -78.560  44.313  1
208857  102.883  -78.563  44.297  1
208858  102.908  -78.565  44.280  1
208859  102.934  -78.567  44.264  1
208860  102.960  -78.570  44.249  1
208861  102.985  -78.573  44.232  1
208862  103.011  -78.575  44.216  1
208863  103.037  -78.578  44.199  1
209147  93.425  -75.827  53.947  1
209148  93.443  -75.830  53.966  1
209149  93.462  -75.833  53.987  1
209150  93.480  -75.837  54.008  1
209151  93.498  -75.840  54.028  1
209152  93.516  -75.843  54.050  1
209153  93.535  -75.847  54.072  1
209154  93.553  -75.850  54.094  1
209155  93.571  -75.853  54.118  1
209156  93.589  -75.856  54.140  1
209157  93.601  -75.878  54.161  1
209158  93.633  -75.872  54.181  1
209159  93.665  -75.865  54.202  1
209160  93.698  -75.859  54.223  1
209161  93.730  -75.853  54.242  1
209162  93.763  -75.847  54.257  1
209163  93.795  -75.841  54.267  1
209164  93.828  -75.835  54.273  1
209165  93.849  -75.828  54.274  1
209166  93.870  -75.820  54.273  1
209167  93.891  -75.812  54.275  1
209168  93.912  -75.805  54.279  1
209169  93.943  -75.800  54.286  1
209170  93.975  -75.796  54.296  1
209171  94.001  -75.790  54.299  1
209172  94.028  -75.785  54.299  1
209173  94.053  -75.780  54.296  1
209174  94.079  -75.775  54.292  1
209175  94.106  -75.769  54.284  1
209176  94.133  -75.765  54.274  1
209177  94.160  -75.761  54.264  1
209178  94.187  -75.756  54.249  1
209179  94.213  -75.754  54.235  1
209180  94.238  -75.755  54.224  1
209181  94.263  -75.755  54.215  1
209182  94.288  -75.755  54.207  1
209183  94.312  -75.756  54.198  1
209184  94.331  -75.757  54.186  1
209185  94.351  -75.759  54.164  1
209186  94.371  -75.761  54.140  1
209187  94.391  -75.762  54.116  1
209188  94.410  -75.765  54.095  1
209189  94.430  -75.766  54.076  1
209190  94.450  -75.768  54.054  1
209191  94.467  -75.771  54.026  1
209192  94.483  -75.778  53.990  1
209193  94.502  -75.784  53.955  1
209194  94.518  -75.793  53.919  1
209195  94.532  -75.801  53.885  1
209196  94.547  -75.810  53.856  1
209197  94.562  -75.818  53.830  1
209198  94.576  -75.828  53.802  1
209199  94.592  -75.836  53.771  1
209200  94.606  -75.844  53.739  1
209201  94.621  -75.853  53.705  1
209202  94.636  -75.862  53.669  1
209203  94.650  -75.871  53.632  1
209204  94.666  -75.879  53.593  1
209205  94.680  -75.887  53.552  1
209206  94.693  -75.894  53.510  1
209207  94.702  -75.897  53.469  1
209208  94.711  -75.900  53.431  1
209209  94.720  -75.903  53.392  1
209210  94.730  -75.906  53.355  1
209211  94.740  -75.908  53.319  1
209212  94.749  -75.911  53.281  1
209213  94.758  -75.914  53.243  1
209214  94.767  -75.917  53.204  1
209215  94.777  -75.919  53.164  1
209216  94.786  -75.922  53.124  1
209217  94.795  -75.925  53.084  1
209218  94.805  -75.928  53.046  1
209219  94.814  -75.931  53.008  1
209220  94.823  -75.934  52.972  1
209221  94.833  -75.937  52.936  1
209222  94.842  -75.939  52.901  1
209223  94.851  -75.942  52.867  1
209224  94.861  -75.945  52.836  1
209225  94.873  -75.949  52.806  1
209226  94.884  -75.953  52.779  1
209227  94.895  -75.956  52.757  1
209228  94.906  -75.960  52.737  1
209229  94.917  -75.963  52.716  1
209230  94.928  -75.967  52.694  1
209231  94.939  -75.970  52.667  1
209232  94.976  -75.972  52.639  1
209233  95.039  -75.971  52.609  1
209234  95.102  -75.970  52.579  1
209235  95.165  -75.969  52.548  1
209236  95.227  -75.969  52.514  1
209237  95.290  -75.968  52.478  1
209238  95.353  -75.967  52.442  1
209239  95.416  -75.966  52.405  1
209240  95.478  -75.966  52.367  1
209241  95.536  -75.966  52.328  1
209242  95.562  -75.969  52.285  1
209243  95.572  -75.975  52.235  1
209244  95.582  -75.981  52.182  1
209245  95.592  -75.988  52.127  1
209246  95.602  -75.995  52.073  1
209247  95.611  -76.002  52.024  1
209248  95.621  -76.009  51.978  1
209249  95.631  -76.016  51.934  1
209250  95.640  -76.022  51.889  1
209251  95.651  -76.029  51.844  1
209252  95.660  -76.036  51.800  1
209253  95.670  -76.043  51.758  1
209254  95.680  -76.050  51.717  1
209255  95.689  -76.056  51.677  1
209256  95.704  -76.062  51.641  1
209257  95.726  -76.066  51.608  1
209258  95.748  -76.071  51.575  1
209259  95.771  -76.075  51.542  1
209260  95.793  -76.079  51.507  1
209261  95.815  -76.084  51.469  1
209262  95.838  -76.088  51.432  1
209263  95.869  -76.091  51.393  1
209264  95.910  -76.090  51.354  1
209265  95.950  -76.090  51.314  1
209266  95.990  -76.090  51.272  1
209267  96.026  -76.089  51.229  1
209268  96.049  -76.089  51.184  1
209269  96.073  -76.088  51.141  1
209270  96.096  -76.088  51.096  1
209271  96.120  -76.087  51.052  1
209272  96.143  -76.086  51.011  1
209273  96.167  -76.085  50.972  1
209274  96.190  -76.085  50.934  1
209275  96.213  -76.085  50.898  1
209276  96.236  -76.085  50.864  1
209277  96.243  -76.095  50.832  1
209278  96.241  -76.112  50.801  1
209279  96.239  -76.128  50.771  1
209280  96.251  -76.141  50.743  1
209281  96.273  -76.152  50.715  1
209282  96.295  -76.163  50.686  1
209283  96.317  -76.174  50.658  1
209284  96.327  -76.182  50.631  1
209285  96.333  -76.189  50.605  1
209286  96.339  -76.196  50.581  1
209287  96.345  -76.203  50.560  1
209288  96.352  -76.210  50.541  1
209289  96.361  -76.216  50.521  1
209290  96.373  -76.223  50.499  1
209291  96.396  -76.236  50.477  1
209292  96.442  -76.247  50.451  1
209293  96.485  -76.260  50.426  1
209294  96.528  -76.274  50.401  1
209295  96.571  -76.289  50.375  1
209296  96.613  -76.302  50.348  1
209297  96.650  -76.307  50.319  1
209298  96.679  -76.306  50.289  1
209299  96.707  -76.304  50.259  1
209300  96.722  -76.304  50.227  1
209301  96.738  -76.304  50.194  1
209302  96.753  -76.304  50.159  1
209303  96.768  -76.303  50.124  1
209304  96.784  -76.303  50.088  1
209305  96.799  -76.303  50.050  1
209306  96.818  -76.316  50.012  1
209307  96.841  -76.323  49.973  1
209308  96.864  -76.331  49.934  1
209309  96.887  -76.339  49.895  1
209310  96.910  -76.346  49.857  1
209311  96.933  -76.354  49.820  1
209312  96.956  -76.361  49.781  1
209313  96.979  -76.369  49.743  1
209314  97.002  -76.376  49.705  1
209315  97.042  -76.395  49.668  1
209316  97.089  -76.420  49.631  1
209317  97.131  -76.444  49.597  1
209318  97.146  -76.473  49.566  1
209319  97.160  -76.501  49.538  1
209320  97.174  -76.530  49.513  1
209321  97.188  -76.558  49.489  1
209322  97.203  -76.586  49.466  1
209323  97.218  -76.615  49.442  1
209324  97.232  -76.643  49.417  1
209325  97.163  -76.643  49.390  1
209326  97.203  -76.661  49.363  1
209327  97.243  -76.679  49.333  1
209328  97.279  -76.680  49.301  1
209329  97.311  -76.667  49.267  1
209330  97.344  -76.654  49.232  1
209331  97.376  -76.640  49.197  1
209332  97.408  -76.627  49.164  1
209333  97.440  -76.614  49.132  1
209334  97.465  -76.611  49.101  1
209335  97.475  -76.622  49.070  1
209336  97.485  -76.635  49.040  1
209337  97.509  -76.647  49.012  1
209338  97.532  -76.659  48.985  1
209339  97.556  -76.671  48.960  1
209340  97.580  -76.683  48.934  1
209341  97.604  -76.695  48.907  1
209342  97.628  -76.706  48.882  1
209343  97.651  -76.718  48.855  1
209344  97.675  -76.730  48.827  1
209345  97.699  -76.742  48.798  1
209346  97.723  -76.754  48.767  1
209347  97.746  -76.765  48.736  1
209348  97.770  -76.777  48.703  1
209349  97.794  -76.790  48.671  1
209350  97.845  -76.796  48.638  1
209351  97.897  -76.792  48.605  1
209352  97.940  -76.793  48.572  1
209353  97.986  -76.797  48.540  1
209354  98.031  -76.802  48.507  1
209355  98.076  -76.807  48.475  1
209356  98.118  -76.814  48.444  1
209357  98.139  -76.827  48.413  1
209358  98.161  -76.840  48.382  1
209359  98.183  -76.853  48.352  1
209360  98.205  -76.865  48.323  1
209361  98.225  -76.871  48.293  1
209362  98.243  -76.865  48.264  1
209363  98.262  -76.858  48.235  1
209364  98.281  -76.850  48.205  1
209365  98.299  -76.842  48.177  1
209366  98.317  -76.834  48.149  1
209367  98.338  -76.831  48.121  1
209368  98.360  -76.832  48.092  1
209369  98.381  -76.833  48.062  1
209370  98.403  -76.834  48.032  1
209371  98.425  -76.834  48.001  1
209372  98.447  -76.835  47.971  1
209373  98.470  -76.828  47.941  1
209374  98.495  -76.818  47.912  1
209375  98.519  -76.807  47.885  1
209376  98.533  -76.810  47.856  1
209377  98.546  -76.815  47.828  1
209378  98.559  -76.821  47.800  1
209379  98.571  -76.827  47.772  1
209380  98.584  -76.832  47.745  1
209381  98.596  -76.838  47.719  1
209382  98.609  -76.843  47.692  1
209383  98.623  -76.850  47.663  1
209384  98.641  -76.865  47.636  1
209385  98.659  -76.882  47.607  1
209386  98.678  -76.898  47.576  1
209387  98.699  -76.903  47.545  1
209388  98.723  -76.897  47.515  1
209389  98.742  -76.896  47.484  1
209390  98.747  -76.909  47.454  1
209391  98.780  -76.911  47.425  1
209392  98.813  -76.913  47.394  1
209393  98.846  -76.915  47.363  1
209394  98.879  -76.917  47.331  1
209395  98.912  -76.919  47.297  1
209396  98.944  -76.921  47.263  1
209397  98.977  -76.923  47.230  1
209398  99.027  -76.921  47.197  1
209399  99.068  -76.923  47.161  1
209400  99.085  -76.937  47.127  1
209401  99.101  -76.950  47.093  1
209402  99.119  -76.964  47.061  1
209403  99.135  -76.978  47.027  1
209404  99.152  -76.990  46.994  1
209405  99.169  -77.004  46.960  1
209406  99.192  -77.008  46.924  1
209407  99.222  -76.999  46.892  1
209408  99.254  -76.989  46.862  1
209409  99.260  -76.979  46.832  1
209410  99.277  -76.994  46.803  1
209411  99.294  -77.008  46.774  1
209412  99.312  -77.023  46.746  1
209413  99.330  -77.038  46.718  1
209414  99.347  -77.052  46.689  1
209415  99.365  -77.067  46.663  1
209416  99.428  -77.078  46.637  1
209417  99.477  -77.087  46.610  1
209418  99.489  -77.100  46.583  1
209419  99.495  -77.114  46.555  1
209420  99.501  -77.128  46.526  1
209421  99.508  -77.142  46.498  1
209422  99.511  -77.153  46.471  1
209423  99.498  -77.147  46.444  1
209424  99.484  -77.141  46.418  1
209425  99.470  -77.135  46.391  1
209426  99.474  -77.132  46.364  1
209427  99.484  -77.130  46.338  1
209428  99.494  -77.128  46.313  1
209429  99.504  -77.125  46.290  1
209430  99.514  -77.124  46.267  1
209431  99.524  -77.122  46.244  1
209432  99.558  -77.125  46.221  1
209433  99.609  -77.132  46.199  1
209434  99.660  -77.138  46.177  1
209435  99.710  -77.145  46.155  1
209436  99.735  -77.139  46.134  1
209437  99.760  -77.132  46.114  1
209438  99.784  -77.126  46.093  1
209439  99.809  -77.119  46.073  1
209440  99.834  -77.113  46.054  1
209441  99.870  -77.112  46.034  1
209442  99.907  -77.112  46.015  1
209443  99.943  -77.111  45.997  1
209444  99.980  -77.111  45.979  1
209445  100.011  -77.134  45.961  1
209446  100.043  -77.157  45.943  1
209447  100.073  -77.179  45.925  1
209448  100.097  -77.189  45.908  1
209449  100.119  -77.199  45.890  1
209450  100.142  -77.210  45.872  1
209451  100.161  -77.213  45.854  1
209452  100.173  -77.205  45.837  1
209453  100.185  -77.197  45.819  1
209454  100.218  -77.210  45.801  1
209455  100.253  -77.224  45.784  1
209456  100.285  -77.238  45.767  1
209457  100.297  -77.241  45.751  1
209458  100.309  -77.244  45.735  1
209459  100.320  -77.248  45.720  1
209460  100.332  -77.251  45.705  1
209461  100.343  -77.257  45.691  1
209462  100.353  -77.268  45.678  1
209463  100.364  -77.279  45.663  1
209464  100.374  -77.291  45.650  1
209465  100.385  -77.304  45.637  1
209466  100.407  -77.323  45.624  1
209467  100.430  -77.342  45.611  1
209468  100.454  -77.363  45.598  1
209469  100.477  -77.382  45.585  1
209470  100.500  -77.402  45.572  1
209471  100.524  -77.423  45.560  1
209472  100.547  -77.442  45.548  1
209473  100.570  -77.463  45.535  1
209474  100.594  -77.483  45.522  1
209475  100.617  -77.502  45.509  1
209476  100.645  -77.513  45.496  1
209477  100.676  -77.518  45.483  1
209478  100.706  -77.523  45.471  1
209479  100.737  -77.529  45.458  1
209480  100.767  -77.533  45.446  1
209481  100.797  -77.539  45.433  1
209482  100.828  -77.544  45.418  1
209483  100.853  -77.552  45.405  1
209484  100.876  -77.564  45.392  1
209485  100.903  -77.581  45.379  1
209486  100.930  -77.598  45.366  1
209487  100.957  -77.614  45.353  1
209488  100.983  -77.631  45.340  1
209489  101.008  -77.650  45.327  1
209490  101.032  -77.669  45.314  1
209491  101.056  -77.688  45.301  1
209492  101.080  -77.707  45.287  1
209493  101.104  -77.726  45.272  1
209494  101.128  -77.745  45.258  1
209495  101.152  -77.763  45.244  1
209496  101.176  -77.782  45.231  1
209497  101.200  -77.801  45.218  1
209498  101.224  -77.820  45.204  1
209499  101.249  -77.836  45.191  1
209500  101.275  -77.845  45.177  1
209501  101.301  -77.854  45.162  1
209502  101.327  -77.863  45.147  1
209503  101.353  -77.872  45.132  1
209504  101.381  -77.885  45.119  1
209505  101.409  -77.902  45.104  1
209506  101.439  -77.918  45.090  1
209507  101.467  -77.934  45.074  1
209508  101.496  -77.950  45.059  1
209509  101.525  -77.967  45.043  1
209510  101.553  -77.983  45.029  1
209511  101.582  -78.000  45.014  1
209512  101.599  -78.007  44.998  1
209513  101.609  -78.009  44.983  1
209514  101.627  -78.017  44.966  1
209515  101.671  -78.040  44.949  1
209516  101.696  -78.054  44.932  1
209517  101.707  -78.061  44.917  1
209518  101.718  -78.068  44.901  1
209519  101.729  -78.074  44.885  1
209520  101.740  -78.081  44.870  1
209521  101.751  -78.087  44.855  1
209522  101.761  -78.094  44.840  1
209523  101.779  -78.104  44.825  1
209524  101.799  -78.116  44.810  1
209525  101.820  -78.127  44.795  1
209526  101.840  -78.138  44.780  1
209527  101.861  -78.150  44.764  1
209528  101.881  -78.162  44.748  1
209529  101.901  -78.173  44.731  1
209530  101.935  -78.184  44.715  1
209531  101.970  -78.194  44.700  1
209532  102.004  -78.205  44.684  1
209533  102.039  -78.216  44.669  1
209534  102.074  -78.226  44.653  1
209535  102.109  -78.237  44.637  1
209536  102.144  -78.247  44.622  1
209537  102.179  -78.257  44.607  1
209538  102.214  -78.268  44.592  1
209539  102.254  -78.290  44.577  1
209540  102.296  -78.311  44.562  1
209541  102.336  -78.332  44.547  1
209542  102.378  -78.354  44.531  1
209543  102.418  -78.375  44.514  1
209544  102.460  -78.396  44.499  1
209545  102.501  -78.417  44.485  1
209546  102.542  -78.438  44.471  1
209547  102.581  -78.457  44.457  1
209548  102.611  -78.463  44.443  1
209549  102.642  -78.469  44.428  1
209550  102.673  -78.475  44.414  1
209551  102.703  -78.480  44.399  1
209552  102.722  -78.470  44.385  1
209553  102.733  -78.478  44.369  1
209554  102.770  -78.492  44.353  1
209555  102.807  -78.505  44.337  1
209556  102.844  -78.519  44.320  1
209557  102.881  -78.532  44.304  1
209558  102.918  -78.546  44.288  1
209559  102.945  -78.550  44.272  1
209560  102.971  -78.553  44.255  1
209561  102.997  -78.555  44.239  1
209562  103.022  -78.557  44.224  1
209563  103.048  -78.561  44.207  1
209564  103.074  -78.563  44.189  1
209848  93.417  -75.803  53.944  1
209849  93.435  -75.806  53.962  1
209850  93.453  -75.810  53.983  1
209851  93.472  -75.813  54.005  1
209852  93.490  -75.816  54.026  1
209853  93.508  -75.820  54.048  1
209854  93.526  -75.823  54.071  1
209855  93.545  -75.826  54.095  1
209856  93.563  -75.830  54.120  1
209857  93.581  -75.833  54.144  1
209858  93.595  -75.850  54.167  1
209859  93.628  -75.844  54.188  1
209860  93.660  -75.838  54.211  1
209861  93.693  -75.832  54.235  1
209862  93.725  -75.825  54.257  1
209863  93.758  -75.819  54.275  1
209864  93.790  -75.813  54.287  1
209865  93.823  -75.807  54.293  1
209866  93.852  -75.801  54.293  1
209867  93.873  -75.793  54.290  1
209868  93.894  -75.786  54.286  1
209869  93.915  -75.778  54.284  1
209870  93.944  -75.773  54.285  1
209871  93.976  -75.768  54.292  1
209872  94.002  -75.763  54.292  1
209873  94.028  -75.758  54.289  1
209874  94.054  -75.753  54.286  1
209875  94.080  -75.747  54.281  1
209876  94.106  -75.742  54.273  1
209877  94.132  -75.737  54.263  1
209878  94.159  -75.733  54.254  1
209879  94.185  -75.732  54.240  1
209880  94.210  -75.732  54.229  1
209881  94.235  -75.732  54.218  1
209882  94.260  -75.733  54.208  1
209883  94.285  -75.733  54.199  1
209884  94.310  -75.733  54.190  1
209885  94.330  -75.734  54.178  1
209886  94.350  -75.736  54.158  1
209887  94.370  -75.738  54.136  1
209888  94.390  -75.740  54.113  1
209889  94.409  -75.742  54.092  1
209890  94.429  -75.743  54.074  1
209891  94.448  -75.746  54.053  1
209892  94.461  -75.752  54.025  1
209893  94.473  -75.757  53.992  1
209894  94.492  -75.764  53.959  1
209895  94.511  -75.771  53.926  1
209896  94.530  -75.777  53.896  1
209897  94.549  -75.784  53.870  1
209898  94.566  -75.791  53.847  1
209899  94.581  -75.800  53.819  1
209900  94.596  -75.808  53.789  1
209901  94.611  -75.817  53.757  1
209902  94.626  -75.825  53.723  1
209903  94.640  -75.834  53.686  1
209904  94.655  -75.843  53.648  1
209905  94.670  -75.851  53.609  1
209906  94.685  -75.860  53.566  1
209907  94.698  -75.866  53.523  1
209908  94.707  -75.869  53.481  1
209909  94.716  -75.872  53.441  1
209910  94.725  -75.875  53.402  1
209911  94.735  -75.878  53.365  1
209912  94.744  -75.881  53.331  1
209913  94.754  -75.884  53.292  1
209914  94.763  -75.886  53.252  1
209915  94.772  -75.889  53.212  1
209916  94.781  -75.892  53.172  1
209917  94.791  -75.895  53.129  1
209918  94.800  -75.897  53.088  1
209919  94.810  -75.900  53.048  1
209920  94.819  -75.903  53.007  1
209921  94.828  -75.906  52.970  1
209922  94.837  -75.909  52.934  1
209923  94.847  -75.912  52.899  1
209924  94.856  -75.915  52.866  1
209925  94.865  -75.918  52.835  1
209926  94.875  -75.920  52.806  1
209927  94.884  -75.923  52.779  1
209928  94.895  -75.926  52.757  1
209929  94.906  -75.930  52.737  1
209930  94.917  -75.934  52.716  1
209931  94.928  -75.938  52.694  1
209932  94.939  -75.941  52.670  1
209933  94.975  -75.942  52.642  1
209934  95.037  -75.941  52.612  1
209935  95.100  -75.941  52.582  1
209936  95.163  -75.940  52.551  1
209937  95.226  -75.939  52.517  1
209938  95.288  -75.938  52.482  1
209939  95.351  -75.938  52.443  1
209940  95.412  -75.938  52.405  1
209941  95.469  -75.939  52.365  1
209942  95.527  -75.941  52.323  1
209943  95.556  -75.941  52.279  1
209944  95.566  -75.952  52.229  1
209945  95.576  -75.958  52.176  1
209946  95.586  -75.965  52.123  1
209947  95.595  -75.972  52.070  1
209948  95.605  -75.978  52.020  1
209949  95.615  -75.985  51.975  1
209950  95.624  -75.992  51.931  1
209951  95.634  -75.999  51.887  1
209952  95.644  -76.006  51.844  1
209953  95.654  -76.013  51.802  1
209954  95.664  -76.019  51.760  1
209955  95.673  -76.026  51.719  1
209956  95.683  -76.032  51.679  1
209957  95.695  -76.039  51.641  1
209958  95.717  -76.044  51.608  1
209959  95.739  -76.047  51.576  1
209960  95.762  -76.052  51.545  1
209961  95.784  -76.057  51.513  1
209962  95.806  -76.061  51.477  1
209963  95.829  -76.066  51.441  1
209964  95.869  -76.065  51.404  1
209965  95.909  -76.065  51.365  1
209966  95.950  -76.065  51.326  1
209967  95.990  -76.065  51.284  1
209968  96.031  -76.064  51.241  1
209969  96.056  -76.064  51.197  1
209970  96.080  -76.063  51.152  1
209971  96.103  -76.063  51.108  1
209972  96.126  -76.062  51.065  1
209973  96.150  -76.061  51.024  1
209974  96.173  -76.060  50.984  1
209975  96.196  -76.060  50.947  1
209976  96.215  -76.062  50.912  1
209977  96.232  -76.064  50.878  1
209978  96.241  -76.072  50.845  1
209979  96.239  -76.088  50.814  1
209980  96.238  -76.104  50.784  1
209981  96.254  -76.116  50.756  1
209982  96.275  -76.127  50.729  1
209983  96.298  -76.138  50.701  1
209984  96.320  -76.150  50.673  1
209985  96.341  -76.160  50.646  1
209986  96.354  -76.169  50.620  1
209987  96.360  -76.176  50.596  1
209988  96.366  -76.183  50.574  1
209989  96.372  -76.190  50.553  1
209990  96.378  -76.197  50.532  1
209991  96.384  -76.204  50.510  1
209992  96.393  -76.212  50.488  1
209993  96.436  -76.226  50.464  1
209994  96.478  -76.239  50.440  1
209995  96.522  -76.253  50.415  1
209996  96.565  -76.267  50.390  1
209997  96.607  -76.281  50.363  1
209998  96.645  -76.286  50.335  1
209999  96.674  -76.285  50.306  1
210000  96.703  -76.284  50.275  1
210001  96.731  -76.282  50.243  1
210002  96.746  -76.282  50.210  1
210003  96.761  -76.282  50.176  1
210004  96.777  -76.282  50.140  1
210005  96.792  -76.281  50.102  1
210006  96.808  -76.282  50.064  1
210007  96.826  -76.297  50.025  1
210008  96.845  -76.310  49.986  1
210009  96.867  -76.320  49.947  1
210010  96.889  -76.328  49.910  1
210011  96.912  -76.336  49.873  1
210012  96.936  -76.343  49.836  1
210013  96.958  -76.351  49.798  1
210014  96.981  -76.358  49.760  1
210015  97.005  -76.366  49.722  1
210016  97.040  -76.383  49.685  1
210017  97.088  -76.406  49.649  1
210018  97.135  -76.430  49.615  1
210019  97.178  -76.455  49.583  1
210020  97.193  -76.483  49.554  1
210021  97.207  -76.511  49.528  1
210022  97.222  -76.539  49.504  1
210023  97.236  -76.568  49.481  1
210024  97.250  -76.597  49.455  1
210025  97.146  -76.585  49.429  1
210026  97.186  -76.603  49.401  1
210027  97.226  -76.621  49.371  1
210028  97.266  -76.639  49.339  1
210029  97.303  -76.643  49.306  1
210030  97.335  -76.629  49.272  1
210031  97.367  -76.616  49.238  1
210032  97.399  -76.602  49.204  1
210033  97.432  -76.589  49.171  1
210034  97.464  -76.576  49.140  1
210035  97.480  -76.584  49.110  1
210036  97.490  -76.596  49.080  1
210037  97.494  -76.609  49.050  1
210038  97.514  -76.621  49.022  1
210039  97.538  -76.633  48.996  1
210040  97.562  -76.645  48.971  1
210041  97.585  -76.657  48.946  1
210042  97.609  -76.669  48.920  1
210043  97.633  -76.680  48.894  1
210044  97.657  -76.693  48.868  1
210045  97.680  -76.704  48.840  1
210046  97.705  -76.716  48.810  1
210047  97.728  -76.728  48.780  1
210048  97.752  -76.740  48.748  1
210049  97.776  -76.752  48.716  1
210050  97.800  -76.764  48.682  1
210051  97.868  -76.768  48.649  1
210052  97.934  -76.769  48.616  1
210053  97.972  -76.758  48.584  1
210054  98.015  -76.757  48.551  1
210055  98.061  -76.762  48.517  1
210056  98.106  -76.767  48.485  1
210057  98.132  -76.779  48.453  1
210058  98.154  -76.792  48.422  1
210059  98.175  -76.805  48.391  1
210060  98.197  -76.818  48.361  1
210061  98.219  -76.831  48.332  1
210062  98.241  -76.843  48.303  1
210063  98.263  -76.855  48.274  1
210064  98.281  -76.848  48.245  1
210065  98.299  -76.840  48.215  1
210066  98.319  -76.836  48.187  1
210067  98.341  -76.837  48.159  1
210068  98.363  -76.837  48.131  1
210069  98.384  -76.838  48.102  1
210070  98.406  -76.840  48.073  1
210071  98.428  -76.840  48.043  1
210072  98.450  -76.841  48.013  1
210073  98.472  -76.842  47.984  1
210074  98.496  -76.831  47.954  1
210075  98.520  -76.821  47.925  1
210076  98.544  -76.806  47.897  1
210077  98.562  -76.803  47.869  1
210078  98.576  -76.811  47.841  1
210079  98.589  -76.817  47.814  1
210080  98.602  -76.822  47.786  1
210081  98.615  -76.828  47.758  1
210082  98.628  -76.834  47.730  1
210083  98.640  -76.839  47.703  1
210084  98.653  -76.845  47.674  1
210085  98.666  -76.850  47.648  1
210086  98.678  -76.856  47.619  1
210087  98.694  -76.867  47.588  1
210088  98.712  -76.883  47.557  1
210089  98.733  -76.890  47.524  1
210090  98.757  -76.885  47.492  1
210091  98.770  -76.895  47.460  1
210092  98.803  -76.897  47.428  1
210093  98.836  -76.899  47.397  1
210094  98.868  -76.901  47.365  1
210095  98.901  -76.903  47.333  1
210096  98.934  -76.905  47.300  1
210097  98.966  -76.906  47.266  1
210098  99.007  -76.906  47.232  1
210099  99.060  -76.903  47.199  1
210100  99.102  -76.906  47.164  1
210101  99.120  -76.919  47.129  1
210102  99.136  -76.932  47.096  1
210103  99.153  -76.946  47.063  1
210104  99.170  -76.959  47.029  1
210105  99.187  -76.973  46.994  1
210106  99.216  -76.965  46.959  1
210107  99.247  -76.956  46.924  1
210108  99.248  -76.947  46.889  1
210109  99.261  -76.958  46.858  1
210110  99.279  -76.973  46.828  1
210111  99.296  -76.987  46.798  1
210112  99.314  -77.003  46.769  1
210113  99.332  -77.017  46.740  1
210114  99.350  -77.031  46.712  1
210115  99.367  -77.047  46.683  1
210116  99.385  -77.061  46.656  1
210117  99.422  -77.075  46.629  1
210118  99.474  -77.084  46.603  1
210119  99.509  -77.091  46.575  1
210120  99.526  -77.103  46.547  1
210121  99.533  -77.117  46.518  1
210122  99.540  -77.131  46.489  1
210123  99.532  -77.131  46.462  1
210124  99.517  -77.125  46.435  1
210125  99.519  -77.121  46.408  1
210126  99.529  -77.119  46.381  1
210127  99.539  -77.117  46.355  1
210128  99.549  -77.115  46.329  1
210129  99.559  -77.113  46.304  1
210130  99.569  -77.111  46.281  1
210131  99.579  -77.109  46.258  1
210132  99.589  -77.106  46.235  1
210133  99.598  -77.105  46.213  1
210134  99.644  -77.110  46.191  1
210135  99.696  -77.117  46.169  1
210136  99.726  -77.114  46.147  1
210137  99.751  -77.107  46.126  1
210138  99.776  -77.101  46.106  1
210139  99.800  -77.094  46.085  1
210140  99.825  -77.088  46.066  1
210141  99.851  -77.082  46.046  1
210142  99.888  -77.082  46.027  1
210143  99.925  -77.081  46.008  1
210144  99.962  -77.081  45.990  1
210145  99.999  -77.081  45.972  1
210146  100.031  -77.099  45.953  1
210147  100.062  -77.122  45.935  1
210148  100.093  -77.144  45.918  1
210149  100.120  -77.160  45.901  1
210150  100.143  -77.171  45.883  1
210151  100.165  -77.181  45.866  1
210152  100.189  -77.191  45.848  1
210153  100.207  -77.194  45.830  1
210154  100.218  -77.185  45.812  1
210155  100.247  -77.193  45.794  1
210156  100.280  -77.207  45.778  1
210157  100.301  -77.214  45.761  1
210158  100.313  -77.218  45.744  1
210159  100.324  -77.222  45.728  1
210160  100.336  -77.226  45.713  1
210161  100.346  -77.238  45.698  1
210162  100.357  -77.250  45.684  1
210163  100.367  -77.262  45.670  1
210164  100.378  -77.274  45.657  1
210165  100.388  -77.285  45.643  1
210166  100.400  -77.298  45.629  1
210167  100.421  -77.316  45.616  1
210168  100.443  -77.334  45.604  1
210169  100.466  -77.354  45.591  1
210170  100.490  -77.374  45.579  1
210171  100.513  -77.394  45.566  1
210172  100.536  -77.414  45.554  1
210173  100.560  -77.434  45.541  1
210174  100.583  -77.454  45.529  1
210175  100.607  -77.474  45.516  1
210176  100.630  -77.494  45.503  1
210177  100.656  -77.508  45.491  1
210178  100.687  -77.512  45.478  1
210179  100.717  -77.517  45.467  1
210180  100.748  -77.523  45.454  1
210181  100.778  -77.528  45.441  1
210182  100.809  -77.533  45.428  1
210183  100.839  -77.538  45.415  1
210184  100.869  -77.543  45.401  1
210185  100.897  -77.553  45.388  1
210186  100.921  -77.572  45.375  1
210187  100.946  -77.591  45.361  1
210188  100.970  -77.610  45.349  1
210189  100.994  -77.629  45.336  1
210190  101.018  -77.647  45.323  1
210191  101.042  -77.666  45.310  1
210192  101.066  -77.685  45.297  1
210193  101.090  -77.704  45.283  1
210194  101.114  -77.723  45.268  1
210195  101.138  -77.742  45.254  1
210196  101.162  -77.761  45.240  1
210197  101.186  -77.780  45.225  1
210198  101.210  -77.797  45.212  1
210199  101.237  -77.806  45.198  1
210200  101.262  -77.815  45.185  1
210201  101.288  -77.824  45.170  1
210202  101.315  -77.834  45.155  1
210203  101.341  -77.843  45.141  1
210204  101.367  -77.853  45.126  1
210205  101.396  -77.869  45.112  1
210206  101.424  -77.885  45.097  1
210207  101.454  -77.902  45.082  1
210208  101.482  -77.918  45.066  1
210209  101.511  -77.934  45.049  1
210210  101.540  -77.950  45.034  1
210211  101.568  -77.967  45.019  1
210212  101.597  -77.983  45.004  1
210213  101.626  -78.000  44.989  1
210214  101.653  -78.015  44.973  1
210215  101.663  -78.017  44.957  1
210216  101.701  -78.037  44.940  1
210217  101.714  -78.044  44.923  1
210218  101.725  -78.051  44.908  1
210219  101.736  -78.058  44.893  1
210220  101.747  -78.064  44.877  1
210221  101.758  -78.071  44.861  1
210222  101.768  -78.078  44.845  1
210223  101.779  -78.084  44.830  1
210224  101.792  -78.091  44.816  1
210225  101.812  -78.103  44.801  1
210226  101.832  -78.114  44.786  1
210227  101.852  -78.125  44.771  1
210228  101.873  -78.137  44.756  1
210229  101.893  -78.149  44.739  1
210230  101.924  -78.159  44.723  1
210231  101.959  -78.170  44.707  1
210232  101.994  -78.181  44.691  1
210233  102.029  -78.191  44.675  1
210234  102.063  -78.202  44.659  1
210235  102.098  -78.213  44.644  1
210236  102.133  -78.222  44.628  1
210237  102.168  -78.233  44.612  1
210238  102.203  -78.244  44.597  1
210239  102.239  -78.256  44.583  1
210240  102.279  -78.278  44.569  1
210241  102.321  -78.299  44.553  1
210242  102.362  -78.320  44.538  1
210243  102.403  -78.341  44.522  1
210244  102.444  -78.363  44.506  1
210245  102.485  -78.384  44.491  1
210246  102.526  -78.405  44.477  1
210247  102.559  -78.415  44.463  1
210248  102.590  -78.421  44.449  1
210249  102.620  -78.426  44.435  1
210250  102.650  -78.432  44.421  1
210251  102.681  -78.438  44.406  1
210252  102.712  -78.445  44.392  1
210253  102.734  -78.435  44.376  1
210254  102.750  -78.443  44.360  1
210255  102.787  -78.457  44.344  1
210256  102.824  -78.470  44.328  1
210257  102.861  -78.484  44.312  1
210258  102.898  -78.498  44.295  1
210259  102.935  -78.511  44.279  1
210260  102.972  -78.525  44.263  1
210261  103.007  -78.538  44.247  1
210262  103.033  -78.540  44.230  1
210263  103.058  -78.542  44.214  1
210264  103.084  -78.545  44.197  1
210265  103.110  -78.548  44.180  1
210548  93.390  -75.777  53.925  1
210549  93.409  -75.780  53.941  1
210550  93.427  -75.784  53.959  1
210551  93.445  -75.787  53.980  1
210552  93.464  -75.790  54.003  1
210553  93.482  -75.793  54.024  1
210554  93.500  -75.796  54.047  1
210555  93.518  -75.800  54.071  1
210556  93.537  -75.803  54.095  1
210557  93.555  -75.806  54.121  1
210558  93.573  -75.809  54.147  1
210559  93.590  -75.822  54.172  1
210560  93.623  -75.816  54.194  1
210561  93.655  -75.810  54.221  1
210562  93.688  -75.804  54.247  1
210563  93.720  -75.798  54.271  1
210564  93.753  -75.792  54.291  1
210565  93.785  -75.786  54.308  1
210566  93.818  -75.780  54.316  1
210567  93.850  -75.774  54.315  1
210568  93.876  -75.767  54.309  1
210569  93.897  -75.759  54.302  1
210570  93.918  -75.752  54.295  1
210571  93.945  -75.746  54.291  1
210572  93.977  -75.741  54.293  1
210573  94.003  -75.736  54.290  1
210574  94.029  -75.731  54.285  1
210575  94.055  -75.725  54.280  1
210576  94.081  -75.720  54.273  1
210577  94.107  -75.715  54.265  1
210578  94.133  -75.709  54.256  1
210579  94.157  -75.710  54.247  1
210580  94.182  -75.710  54.235  1
210581  94.207  -75.710  54.224  1
210582  94.232  -75.710  54.214  1
210583  94.257  -75.710  54.203  1
210584  94.282  -75.710  54.194  1
210585  94.308  -75.711  54.184  1
210586  94.330  -75.712  54.173  1
210587  94.349  -75.713  54.154  1
210588  94.369  -75.715  54.133  1
210589  94.389  -75.717  54.111  1
210590  94.408  -75.718  54.088  1
210591  94.428  -75.721  54.071  1
210592  94.442  -75.726  54.051  1
210593  94.455  -75.731  54.026  1
210594  94.467  -75.737  53.996  1
210595  94.481  -75.743  53.966  1
210596  94.500  -75.750  53.937  1
210597  94.520  -75.756  53.909  1
210598  94.539  -75.763  53.884  1
210599  94.558  -75.770  53.861  1
210600  94.576  -75.776  53.834  1
210601  94.596  -75.783  53.804  1
210602  94.615  -75.790  53.770  1
210603  94.630  -75.798  53.735  1
210604  94.645  -75.806  53.698  1
210605  94.660  -75.815  53.658  1
210606  94.675  -75.824  53.620  1
210607  94.690  -75.832  53.578  1
210608  94.702  -75.839  53.535  1
210609  94.712  -75.842  53.492  1
210610  94.721  -75.844  53.452  1
210611  94.731  -75.847  53.414  1
210612  94.740  -75.850  53.377  1
210613  94.749  -75.853  53.342  1
210614  94.758  -75.856  53.303  1
210615  94.768  -75.859  53.263  1
210616  94.777  -75.862  53.222  1
210617  94.786  -75.864  53.179  1
210618  94.795  -75.867  53.136  1
210619  94.805  -75.870  53.094  1
210620  94.814  -75.873  53.052  1
210621  94.824  -75.875  53.009  1
210622  94.833  -75.878  52.970  1
210623  94.842  -75.881  52.934  1
210624  94.851  -75.884  52.900  1
210625  94.861  -75.887  52.867  1
210626  94.870  -75.890  52.837  1
210627  94.880  -75.893  52.807  1
210628  94.889  -75.896  52.780  1
210629  94.898  -75.898  52.756  1
210630  94.908  -75.901  52.735  1
210631  94.917  -75.904  52.714  1
210632  94.928  -75.908  52.692  1
210633  94.939  -75.911  52.670  1
210634  94.973  -75.912  52.642  1
210635  95.036  -75.912  52.612  1
210636  95.099  -75.911  52.581  1
210637  95.162  -75.910  52.550  1
210638  95.219  -75.912  52.517  1
210639  95.276  -75.913  52.482  1
210640  95.334  -75.915  52.441  1
210641  95.391  -75.916  52.402  1
210642  95.448  -75.918  52.361  1
210643  95.506  -75.919  52.317  1
210644  95.547  -75.910  52.271  1
210645  95.558  -75.916  52.220  1
210646  95.569  -75.932  52.169  1
210647  95.580  -75.941  52.117  1
210648  95.589  -75.948  52.065  1
210649  95.599  -75.955  52.016  1
210650  95.609  -75.962  51.970  1
210651  95.618  -75.969  51.927  1
210652  95.628  -75.975  51.884  1
210653  95.638  -75.982  51.842  1
210654  95.648  -75.989  51.801  1
210655  95.657  -75.996  51.760  1
210656  95.667  -76.003  51.719  1
210657  95.677  -76.009  51.680  1
210658  95.686  -76.016  51.642  1
210659  95.708  -76.020  51.607  1
210660  95.730  -76.025  51.575  1
210661  95.753  -76.029  51.546  1
210662  95.775  -76.034  51.517  1
210663  95.797  -76.038  51.483  1
210664  95.829  -76.040  51.448  1
210665  95.869  -76.040  51.412  1
210666  95.909  -76.040  51.375  1
210667  95.950  -76.040  51.335  1
210668  95.990  -76.039  51.294  1
210669  96.030  -76.039  51.252  1
210670  96.063  -76.038  51.209  1
210671  96.086  -76.038  51.164  1
210672  96.109  -76.038  51.120  1
210673  96.133  -76.037  51.077  1
210674  96.152  -76.038  51.036  1
210675  96.170  -76.040  50.997  1
210676  96.187  -76.042  50.960  1
210677  96.204  -76.044  50.924  1
210678  96.222  -76.047  50.891  1
210679  96.239  -76.048  50.858  1
210680  96.238  -76.064  50.827  1
210681  96.236  -76.080  50.797  1
210682  96.257  -76.091  50.769  1
210683  96.278  -76.103  50.743  1
210684  96.301  -76.113  50.715  1
210685  96.323  -76.125  50.687  1
210686  96.344  -76.136  50.660  1
210687  96.367  -76.147  50.634  1
210688  96.381  -76.157  50.609  1
210689  96.387  -76.163  50.587  1
210690  96.393  -76.170  50.565  1
210691  96.399  -76.177  50.543  1
210692  96.405  -76.184  50.522  1
210693  96.407  -76.192  50.499  1
210694  96.430  -76.204  50.477  1
210695  96.472  -76.218  50.454  1
210696  96.515  -76.232  50.430  1
210697  96.558  -76.246  50.405  1
210698  96.601  -76.260  50.378  1
210699  96.640  -76.266  50.351  1
210700  96.669  -76.264  50.322  1
210701  96.698  -76.263  50.291  1
210702  96.727  -76.262  50.258  1
210703  96.755  -76.261  50.225  1
210704  96.770  -76.260  50.191  1
210705  96.785  -76.260  50.155  1
210706  96.800  -76.260  50.116  1
210707  96.816  -76.262  50.077  1
210708  96.835  -76.276  50.038  1
210709  96.854  -76.290  49.998  1
210710  96.872  -76.304  49.959  1
210711  96.892  -76.317  49.923  1
210712  96.914  -76.325  49.887  1
210713  96.938  -76.332  49.850  1
210714  96.961  -76.340  49.813  1
210715  96.983  -76.348  49.776  1
210716  97.007  -76.355  49.738  1
210717  97.039  -76.369  49.700  1
210718  97.086  -76.393  49.665  1
210719  97.133  -76.417  49.631  1
210720  97.180  -76.440  49.599  1
210721  97.226  -76.464  49.570  1
210722  97.240  -76.493  49.543  1
210723  97.255  -76.521  49.518  1
210724  97.239  -76.540  49.494  1
210725  97.129  -76.527  49.467  1
210726  97.169  -76.545  49.439  1
210727  97.209  -76.563  49.410  1
210728  97.249  -76.581  49.379  1
210729  97.289  -76.599  49.346  1
210730  97.326  -76.605  49.312  1
210731  97.359  -76.591  49.278  1
210732  97.391  -76.578  49.244  1
210733  97.423  -76.564  49.212  1
210734  97.455  -76.552  49.180  1
210735  97.480  -76.549  49.149  1
210736  97.497  -76.558  49.120  1
210737  97.505  -76.569  49.090  1
210738  97.509  -76.583  49.061  1
210739  97.520  -76.596  49.033  1
210740  97.543  -76.607  49.008  1
210741  97.567  -76.619  48.983  1
210742  97.591  -76.631  48.958  1
210743  97.615  -76.643  48.933  1
210744  97.639  -76.655  48.907  1
210745  97.662  -76.667  48.880  1
210746  97.686  -76.678  48.852  1
210747  97.710  -76.690  48.823  1
210748  97.734  -76.702  48.792  1
210749  97.757  -76.714  48.761  1
210750  97.782  -76.726  48.729  1
210751  97.823  -76.734  48.695  1
210752  97.892  -76.738  48.661  1
210753  97.961  -76.742  48.628  1
210754  98.010  -76.736  48.595  1
210755  98.048  -76.724  48.562  1
210756  98.090  -76.722  48.528  1
210757  98.125  -76.730  48.495  1
210758  98.146  -76.743  48.463  1
210759  98.168  -76.756  48.431  1
210760  98.190  -76.769  48.400  1
210761  98.212  -76.783  48.370  1
210762  98.233  -76.796  48.341  1
210763  98.255  -76.809  48.312  1
210764  98.277  -76.821  48.283  1
210765  98.298  -76.833  48.254  1
210766  98.322  -76.827  48.225  1
210767  98.344  -76.824  48.197  1
210768  98.365  -76.821  48.169  1
210769  98.387  -76.819  48.141  1
210770  98.409  -76.817  48.113  1
210771  98.431  -76.814  48.083  1
210772  98.452  -76.815  48.054  1
210773  98.474  -76.821  48.025  1
210774  98.495  -76.826  47.996  1
210775  98.518  -76.815  47.966  1
210776  98.541  -76.800  47.937  1
210777  98.565  -76.784  47.909  1
210778  98.583  -76.783  47.880  1
210779  98.595  -76.795  47.853  1
210780  98.609  -76.802  47.826  1
210781  98.624  -76.809  47.798  1
210782  98.638  -76.816  47.770  1
210783  98.652  -76.823  47.742  1
210784  98.666  -76.830  47.713  1
210785  98.680  -76.837  47.685  1
210786  98.694  -76.843  47.658  1
210787  98.708  -76.851  47.629  1
210788  98.722  -76.857  47.598  1
210789  98.735  -76.862  47.565  1
210790  98.747  -76.868  47.532  1
210791  98.767  -76.878  47.500  1
210792  98.792  -76.881  47.467  1
210793  98.825  -76.883  47.435  1
210794  98.858  -76.885  47.402  1
210795  98.890  -76.887  47.368  1
210796  98.923  -76.889  47.335  1
210797  98.955  -76.890  47.302  1
210798  98.988  -76.893  47.267  1
210799  99.040  -76.890  47.233  1
210800  99.093  -76.887  47.201  1
210801  99.137  -76.887  47.166  1
210802  99.154  -76.901  47.132  1
210803  99.171  -76.915  47.098  1
210804  99.188  -76.928  47.065  1
210805  99.210  -76.933  47.030  1
210806  99.241  -76.923  46.995  1
210807  99.235  -76.913  46.959  1
210808  99.246  -76.923  46.923  1
210809  99.264  -76.937  46.888  1
210810  99.281  -76.953  46.856  1
210811  99.299  -76.967  46.826  1
210812  99.316  -76.982  46.796  1
210813  99.334  -76.997  46.766  1
210814  99.352  -77.011  46.737  1
210815  99.370  -77.026  46.708  1
210816  99.387  -77.041  46.678  1
210817  99.405  -77.056  46.650  1
210818  99.423  -77.070  46.623  1
210819  99.472  -77.081  46.596  1
210820  99.507  -77.088  46.567  1
210821  99.542  -77.096  46.539  1
210822  99.565  -77.106  46.510  1
210823  99.565  -77.114  46.481  1
210824  99.563  -77.110  46.453  1
210825  99.573  -77.108  46.426  1
210826  99.583  -77.106  46.398  1
210827  99.593  -77.104  46.372  1
210828  99.603  -77.102  46.345  1
210829  99.613  -77.100  46.319  1
210830  99.623  -77.098  46.294  1
210831  99.633  -77.096  46.272  1
210832  99.643  -77.094  46.249  1
210833  99.653  -77.092  46.226  1
210834  99.663  -77.090  46.205  1
210835  99.680  -77.089  46.182  1
210836  99.717  -77.089  46.160  1
210837  99.742  -77.083  46.138  1
210838  99.767  -77.076  46.117  1
210839  99.791  -77.070  46.097  1
210840  99.816  -77.063  46.078  1
210841  99.841  -77.057  46.058  1
210842  99.869  -77.053  46.038  1
210843  99.906  -77.052  46.019  1
210844  99.943  -77.052  46.000  1
210845  99.980  -77.051  45.982  1
210846  100.017  -77.051  45.965  1
210847  100.051  -77.064  45.946  1
210848  100.082  -77.087  45.928  1
210849  100.113  -77.110  45.910  1
210850  100.144  -77.132  45.892  1
210851  100.167  -77.143  45.875  1
210852  100.190  -77.153  45.858  1
210853  100.212  -77.163  45.841  1
210854  100.235  -77.173  45.823  1
210855  100.252  -77.174  45.806  1
210856  100.275  -77.176  45.788  1
210857  100.304  -77.188  45.771  1
210858  100.316  -77.191  45.754  1
210859  100.328  -77.195  45.737  1
210860  100.338  -77.207  45.721  1
210861  100.349  -77.219  45.706  1
210862  100.360  -77.232  45.691  1
210863  100.370  -77.244  45.677  1
210864  100.381  -77.256  45.664  1
210865  100.391  -77.268  45.650  1
210866  100.402  -77.279  45.636  1
210867  100.416  -77.294  45.622  1
210868  100.437  -77.311  45.609  1
210869  100.458  -77.328  45.597  1
210870  100.479  -77.345  45.584  1
210871  100.502  -77.365  45.572  1
210872  100.525  -77.385  45.560  1
210873  100.549  -77.405  45.547  1
210874  100.572  -77.425  45.534  1
210875  100.596  -77.445  45.522  1
210876  100.619  -77.465  45.510  1
210877  100.642  -77.486  45.497  1
210878  100.668  -77.501  45.485  1
210879  100.698  -77.507  45.473  1
210880  100.728  -77.511  45.462  1
210881  100.759  -77.517  45.450  1
210882  100.789  -77.522  45.437  1
210883  100.820  -77.527  45.423  1
210884  100.850  -77.532  45.410  1
210885  100.878  -77.536  45.397  1
210886  100.904  -77.546  45.384  1
210887  100.931  -77.569  45.371  1
210888  100.956  -77.588  45.357  1
210889  100.980  -77.607  45.345  1
210890  101.003  -77.626  45.332  1
210891  101.028  -77.645  45.318  1
210892  101.052  -77.664  45.305  1
210893  101.076  -77.683  45.292  1
210894  101.100  -77.702  45.278  1
210895  101.124  -77.721  45.264  1
210896  101.148  -77.740  45.250  1
210897  101.172  -77.758  45.235  1
210898  101.198  -77.768  45.221  1
210899  101.224  -77.777  45.207  1
210900  101.250  -77.786  45.192  1
210901  101.276  -77.795  45.178  1
210902  101.302  -77.804  45.164  1
210903  101.328  -77.813  45.149  1
210904  101.354  -77.822  45.134  1
210905  101.382  -77.837  45.119  1
210906  101.411  -77.853  45.104  1
210907  101.440  -77.869  45.089  1
210908  101.468  -77.885  45.073  1
210909  101.497  -77.902  45.057  1
210910  101.526  -77.918  45.040  1
210911  101.555  -77.934  45.025  1
210912  101.584  -77.950  45.010  1
210913  101.612  -77.967  44.995  1
210914  101.641  -77.983  44.979  1
210915  101.670  -78.000  44.963  1
210916  101.699  -78.015  44.946  1
210917  101.721  -78.028  44.930  1
210918  101.732  -78.034  44.914  1
210919  101.743  -78.041  44.900  1
210920  101.754  -78.047  44.885  1
210921  101.764  -78.054  44.869  1
210922  101.775  -78.061  44.853  1
210923  101.786  -78.067  44.836  1
210924  101.797  -78.074  44.820  1
210925  101.808  -78.081  44.806  1
210926  101.824  -78.090  44.792  1
210927  101.844  -78.101  44.777  1
210928  101.865  -78.112  44.761  1
210929  101.885  -78.124  44.746  1
210930  101.913  -78.135  44.730  1
210931  101.949  -78.146  44.714  1
210932  101.983  -78.156  44.697  1
210933  102.018  -78.167  44.681  1
210934  102.053  -78.178  44.666  1
210935  102.088  -78.188  44.650  1
210936  102.122  -78.198  44.635  1
210937  102.157  -78.209  44.619  1
210938  102.192  -78.219  44.603  1
210939  102.227  -78.230  44.588  1
210940  102.263  -78.244  44.574  1
210941  102.305  -78.266  44.560  1
210942  102.345  -78.287  44.544  1
210943  102.387  -78.308  44.528  1
210944  102.427  -78.329  44.513  1
210945  102.469  -78.351  44.498  1
210946  102.507  -78.366  44.483  1
210947  102.537  -78.373  44.469  1
210948  102.568  -78.379  44.455  1
210949  102.598  -78.385  44.441  1
210950  102.629  -78.391  44.427  1
210951  102.660  -78.396  44.412  1
210952  102.690  -78.402  44.398  1
210953  102.721  -78.408  44.383  1
210954  102.747  -78.401  44.367  1
210955  102.767  -78.409  44.351  1
210956  102.804  -78.423  44.335  1
210957  102.841  -78.436  44.319  1
210958  102.878  -78.450  44.303  1
210959  102.915  -78.463  44.287  1
210960  102.952  -78.477  44.271  1
210961  102.988  -78.491  44.254  1
210962  103.026  -78.504  44.237  1
210963  103.063  -78.518  44.220  1
210964  103.095  -78.528  44.204  1
210965  103.121  -78.530  44.187  1
210966  103.147  -78.532  44.170  1
211249  93.382  -75.753  53.922  1
211250  93.401  -75.757  53.938  1
211251  93.419  -75.760  53.957  1
211252  93.437  -75.763  53.978  1
211253  93.455  -75.767  54.001  1
211254  93.474  -75.770  54.022  1
211255  93.492  -75.773  54.046  1
211256  93.510  -75.777  54.070  1
211257  93.529  -75.780  54.095  1
211258  93.547  -75.783  54.121  1
211259  93.565  -75.787  54.149  1
211260  93.585  -75.795  54.175  1
211261  93.618  -75.789  54.199  1
211262  93.650  -75.783  54.226  1
211263  93.683  -75.777  54.253  1
211264  93.715  -75.771  54.280  1
211265  93.748  -75.764  54.305  1
211266  93.780  -75.758  54.324  1
211267  93.812  -75.752  54.336  1
211268  93.845  -75.746  54.340  1
211269  93.877  -75.740  54.336  1
211270  93.901  -75.732  54.327  1
211271  93.922  -75.725  54.317  1
211272  93.946  -75.718  54.308  1
211273  93.977  -75.714  54.306  1
211274  94.003  -75.709  54.299  1
211275  94.030  -75.703  54.290  1
211276  94.055  -75.698  54.279  1
211277  94.081  -75.693  54.270  1
211278  94.107  -75.687  54.260  1
211279  94.131  -75.686  54.251  1
211280  94.155  -75.685  54.244  1
211281  94.180  -75.687  54.234  1
211282  94.204  -75.688  54.222  1
211283  94.229  -75.688  54.211  1
211284  94.254  -75.688  54.200  1
211285  94.279  -75.688  54.191  1
211286  94.305  -75.688  54.181  1
211287  94.329  -75.689  54.169  1
211288  94.348  -75.690  54.151  1
211289  94.368  -75.693  54.131  1
211290  94.388  -75.694  54.108  1
211291  94.408  -75.696  54.086  1
211292  94.423  -75.700  54.068  1
211293  94.436  -75.706  54.049  1
211294  94.449  -75.712  54.027  1
211295  94.461  -75.718  54.002  1
211296  94.473  -75.723  53.975  1
211297  94.490  -75.730  53.948  1
211298  94.509  -75.736  53.923  1
211299  94.528  -75.743  53.898  1
211300  94.547  -75.749  53.874  1
211301  94.566  -75.756  53.847  1
211302  94.585  -75.762  53.816  1
211303  94.604  -75.769  53.781  1
211304  94.623  -75.776  53.745  1
211305  94.642  -75.782  53.707  1
211306  94.662  -75.789  53.667  1
211307  94.680  -75.796  53.628  1
211308  94.694  -75.805  53.587  1
211309  94.707  -75.811  53.544  1
211310  94.716  -75.814  53.502  1
211311  94.726  -75.817  53.462  1
211312  94.735  -75.820  53.425  1
211313  94.745  -75.822  53.388  1
211314  94.754  -75.825  53.352  1
211315  94.763  -75.828  53.313  1
211316  94.772  -75.831  53.272  1
211317  94.782  -75.834  53.230  1
211318  94.791  -75.837  53.187  1
211319  94.801  -75.840  53.144  1
211320  94.810  -75.843  53.101  1
211321  94.819  -75.845  53.058  1
211322  94.829  -75.848  53.015  1
211323  94.838  -75.851  52.976  1
211324  94.847  -75.853  52.939  1
211325  94.856  -75.856  52.905  1
211326  94.866  -75.859  52.872  1
211327  94.875  -75.862  52.841  1
211328  94.885  -75.865  52.810  1
211329  94.894  -75.868  52.781  1
211330  94.903  -75.871  52.754  1
211331  94.912  -75.874  52.730  1
211332  94.922  -75.876  52.707  1
211333  94.931  -75.879  52.684  1
211334  94.940  -75.882  52.661  1
211335  94.969  -75.884  52.633  1
211336  95.026  -75.886  52.603  1
211337  95.083  -75.887  52.571  1
211338  95.140  -75.889  52.539  1
211339  95.198  -75.891  52.507  1
211340  95.255  -75.892  52.472  1
211341  95.312  -75.894  52.431  1
211342  95.370  -75.895  52.391  1
211343  95.426  -75.897  52.350  1
211344  95.484  -75.898  52.306  1
211345  95.537  -75.897  52.258  1
211346  95.549  -75.876  52.209  1
211347  95.560  -75.892  52.159  1
211348  95.571  -75.909  52.108  1
211349  95.583  -75.925  52.058  1
211350  95.593  -75.931  52.011  1
211351  95.602  -75.938  51.965  1
211352  95.612  -75.945  51.922  1
211353  95.622  -75.952  51.880  1
211354  95.631  -75.959  51.837  1
211355  95.641  -75.966  51.796  1
211356  95.651  -75.972  51.757  1
211357  95.661  -75.979  51.717  1
211358  95.671  -75.985  51.680  1
211359  95.680  -75.992  51.643  1
211360  95.699  -75.997  51.607  1
211361  95.721  -76.002  51.573  1
211362  95.744  -76.007  51.543  1
211363  95.766  -76.010  51.514  1
211364  95.788  -76.015  51.484  1
211365  95.828  -76.015  51.451  1
211366  95.869  -76.015  51.416  1
211367  95.909  -76.014  51.381  1
211368  95.950  -76.014  51.341  1
211369  95.990  -76.014  51.302  1
211370  96.030  -76.014  51.260  1
211371  96.070  -76.013  51.218  1
211372  96.090  -76.014  51.174  1
211373  96.108  -76.016  51.131  1
211374  96.125  -76.019  51.088  1
211375  96.142  -76.020  51.047  1
211376  96.160  -76.022  51.010  1
211377  96.177  -76.025  50.972  1
211378  96.194  -76.027  50.936  1
211379  96.212  -76.029  50.903  1
211380  96.229  -76.031  50.870  1
211381  96.236  -76.040  50.839  1
211382  96.238  -76.056  50.808  1
211383  96.260  -76.066  50.781  1
211384  96.282  -76.078  50.756  1
211385  96.304  -76.089  50.730  1
211386  96.326  -76.100  50.703  1
211387  96.347  -76.111  50.675  1
211388  96.370  -76.122  50.647  1
211389  96.392  -76.134  50.622  1
211390  96.408  -76.143  50.599  1
211391  96.414  -76.150  50.577  1
211392  96.420  -76.157  50.554  1
211393  96.426  -76.164  50.532  1
211394  96.426  -76.174  50.512  1
211395  96.427  -76.183  50.490  1
211396  96.466  -76.197  50.468  1
211397  96.509  -76.210  50.444  1
211398  96.552  -76.225  50.420  1
211399  96.595  -76.238  50.394  1
211400  96.635  -76.245  50.366  1
211401  96.664  -76.244  50.337  1
211402  96.693  -76.242  50.306  1
211403  96.722  -76.242  50.274  1
211404  96.751  -76.240  50.240  1
211405  96.779  -76.239  50.204  1
211406  96.794  -76.238  50.167  1
211407  96.809  -76.238  50.128  1
211408  96.825  -76.242  50.089  1
211409  96.843  -76.255  50.048  1
211410  96.863  -76.270  50.008  1
211411  96.881  -76.283  49.971  1
211412  96.900  -76.298  49.934  1
211413  96.919  -76.311  49.898  1
211414  96.940  -76.321  49.862  1
211415  96.963  -76.329  49.826  1
211416  96.986  -76.337  49.790  1
211417  97.009  -76.345  49.752  1
211418  97.038  -76.356  49.714  1
211419  97.085  -76.379  49.679  1
211420  97.132  -76.404  49.645  1
211421  97.178  -76.427  49.614  1
211422  97.225  -76.451  49.584  1
211423  97.273  -76.475  49.557  1
211424  97.225  -76.483  49.531  1
211425  97.111  -76.468  49.505  1
211426  97.152  -76.486  49.477  1
211427  97.191  -76.505  49.449  1
211428  97.232  -76.523  49.419  1
211429  97.272  -76.541  49.387  1
211430  97.312  -76.559  49.353  1
211431  97.350  -76.567  49.319  1
211432  97.382  -76.553  49.286  1
211433  97.415  -76.540  49.253  1
211434  97.447  -76.527  49.221  1
211435  97.479  -76.514  49.190  1
211436  97.496  -76.521  49.160  1
211437  97.512  -76.530  49.130  1
211438  97.519  -76.542  49.101  1
211439  97.524  -76.556  49.073  1
211440  97.528  -76.569  49.046  1
211441  97.549  -76.581  49.020  1
211442  97.573  -76.593  48.996  1
211443  97.597  -76.605  48.972  1
211444  97.620  -76.617  48.946  1
211445  97.644  -76.629  48.920  1
211446  97.668  -76.641  48.893  1
211447  97.692  -76.652  48.865  1
211448  97.716  -76.665  48.835  1
211449  97.739  -76.677  48.805  1
211450  97.763  -76.688  48.774  1
211451  97.787  -76.700  48.741  1
211452  97.847  -76.705  48.708  1
211453  97.916  -76.709  48.673  1
211454  97.985  -76.712  48.639  1
211455  98.047  -76.713  48.606  1
211456  98.085  -76.702  48.572  1
211457  98.124  -76.690  48.537  1
211458  98.136  -76.696  48.503  1
211459  98.157  -76.710  48.471  1
211460  98.177  -76.723  48.439  1
211461  98.199  -76.736  48.408  1
211462  98.220  -76.749  48.377  1
211463  98.241  -76.762  48.348  1
211464  98.262  -76.775  48.319  1
211465  98.283  -76.788  48.290  1
211466  98.308  -76.792  48.262  1
211467  98.346  -76.761  48.233  1
211468  98.367  -76.758  48.206  1
211469  98.389  -76.761  48.178  1
211470  98.410  -76.766  48.150  1
211471  98.432  -76.771  48.122  1
211472  98.453  -76.777  48.092  1
211473  98.475  -76.783  48.064  1
211474  98.496  -76.788  48.036  1
211475  98.517  -76.793  48.006  1
211476  98.539  -76.794  47.977  1
211477  98.563  -76.779  47.948  1
211478  98.586  -76.763  47.920  1
211479  98.604  -76.761  47.892  1
211480  98.617  -76.773  47.863  1
211481  98.629  -76.785  47.835  1
211482  98.642  -76.793  47.807  1
211483  98.657  -76.800  47.779  1
211484  98.671  -76.807  47.751  1
211485  98.685  -76.815  47.723  1
211486  98.699  -76.821  47.695  1
211487  98.713  -76.828  47.666  1
211488  98.727  -76.835  47.636  1
211489  98.741  -76.842  47.605  1
211490  98.756  -76.849  47.571  1
211491  98.770  -76.856  47.539  1
211492  98.784  -76.860  47.507  1
211493  98.806  -76.855  47.474  1
211494  98.844  -76.863  47.441  1
211495  98.880  -76.871  47.407  1
211496  98.913  -76.872  47.372  1
211497  98.945  -76.875  47.338  1
211498  98.978  -76.876  47.304  1
211499  99.020  -76.876  47.269  1
211500  99.073  -76.873  47.235  1
211501  99.126  -76.870  47.202  1
211502  99.172  -76.870  47.169  1
211503  99.189  -76.884  47.135  1
211504  99.206  -76.897  47.100  1
211505  99.235  -76.890  47.066  1
211506  99.223  -76.881  47.031  1
211507  99.230  -76.887  46.995  1
211508  99.248  -76.903  46.959  1
211509  99.266  -76.917  46.923  1
211510  99.284  -76.932  46.888  1
211511  99.301  -76.947  46.855  1
211512  99.319  -76.961  46.825  1
211513  99.337  -76.976  46.794  1
211514  99.354  -76.990  46.764  1
211515  99.372  -77.006  46.734  1
211516  99.390  -77.020  46.704  1
211517  99.408  -77.035  46.674  1
211518  99.425  -77.050  46.646  1
211519  99.443  -77.064  46.618  1
211520  99.470  -77.077  46.589  1
211521  99.505  -77.085  46.560  1
211522  99.543  -77.089  46.530  1
211523  99.582  -77.091  46.501  1
211524  99.594  -77.093  46.472  1
211525  99.604  -77.091  46.445  1
211526  99.613  -77.088  46.417  1
211527  99.622  -77.086  46.390  1
211528  99.631  -77.084  46.363  1
211529  99.640  -77.082  46.337  1
211530  99.649  -77.080  46.311  1
211531  99.658  -77.078  46.285  1
211532  99.667  -77.075  46.263  1
211533  99.677  -77.073  46.240  1
211534  99.686  -77.071  46.217  1
211535  99.695  -77.069  46.195  1
211536  99.704  -77.066  46.174  1
211537  99.732  -77.058  46.151  1
211538  99.758  -77.051  46.130  1
211539  99.782  -77.045  46.109  1
211540  99.807  -77.039  46.089  1
211541  99.832  -77.032  46.069  1
211542  99.856  -77.026  46.050  1
211543  99.888  -77.022  46.030  1
211544  99.925  -77.022  46.011  1
211545  99.962  -77.022  45.992  1
211546  99.998  -77.022  45.974  1
211547  100.035  -77.021  45.956  1
211548  100.070  -77.029  45.938  1
211549  100.101  -77.052  45.920  1
211550  100.132  -77.075  45.902  1
211551  100.163  -77.098  45.884  1
211552  100.191  -77.114  45.867  1
211553  100.213  -77.125  45.850  1
211554  100.236  -77.135  45.833  1
211555  100.259  -77.145  45.816  1
211556  100.282  -77.155  45.799  1
211557  100.303  -77.159  45.781  1
211558  100.320  -77.165  45.764  1
211559  100.331  -77.177  45.747  1
211560  100.341  -77.189  45.731  1
211561  100.352  -77.201  45.715  1
211562  100.363  -77.213  45.700  1
211563  100.373  -77.226  45.685  1
211564  100.384  -77.238  45.672  1
211565  100.395  -77.250  45.658  1
211566  100.405  -77.262  45.644  1
211567  100.415  -77.273  45.629  1
211568  100.432  -77.288  45.616  1
211569  100.453  -77.306  45.603  1
211570  100.474  -77.323  45.590  1
211571  100.495  -77.341  45.578  1
211572  100.516  -77.358  45.566  1
211573  100.538  -77.376  45.553  1
211574  100.561  -77.397  45.539  1
211575  100.584  -77.417  45.527  1
211576  100.608  -77.436  45.516  1
211577  100.631  -77.457  45.504  1
211578  100.655  -77.476  45.491  1
211579  100.679  -77.495  45.480  1
211580  100.709  -77.501  45.468  1
211581  100.740  -77.506  45.458  1
211582  100.770  -77.511  45.445  1
211583  100.800  -77.516  45.432  1
211584  100.831  -77.521  45.419  1
211585  100.860  -77.526  45.405  1
211586  100.882  -77.528  45.393  1
211587  100.907  -77.536  45.380  1
211588  100.941  -77.566  45.367  1
211589  100.966  -77.586  45.354  1
211590  100.989  -77.605  45.340  1
211591  101.013  -77.624  45.327  1
211592  101.038  -77.642  45.313  1
211593  101.062  -77.661  45.300  1
211594  101.086  -77.680  45.286  1
211595  101.110  -77.699  45.272  1
211596  101.134  -77.718  45.258  1
211597  101.159  -77.729  45.244  1
211598  101.186  -77.738  45.230  1
211599  101.211  -77.747  45.215  1
211600  101.238  -77.756  45.201  1
211601  101.264  -77.765  45.186  1
211602  101.289  -77.774  45.171  1
211603  101.316  -77.783  45.157  1
211604  101.342  -77.793  45.142  1
211605  101.369  -77.804  45.127  1
211606  101.397  -77.821  45.111  1
211607  101.426  -77.837  45.096  1
211608  101.455  -77.853  45.080  1
211609  101.483  -77.869  45.064  1
211610  101.513  -77.885  45.048  1
211611  101.541  -77.902  45.031  1
211612  101.570  -77.918  45.015  1
211613  101.599  -77.934  45.000  1
211614  101.627  -77.950  44.984  1
211615  101.656  -77.967  44.969  1
211616  101.683  -77.982  44.953  1
211617  101.707  -77.997  44.938  1
211618  101.754  -78.007  44.922  1
211619  101.760  -78.017  44.906  1
211620  101.766  -78.027  44.891  1
211621  101.772  -78.037  44.875  1
211622  101.782  -78.044  44.859  1
211623  101.793  -78.051  44.843  1
211624  101.804  -78.057  44.826  1
211625  101.815  -78.064  44.811  1
211626  101.826  -78.071  44.796  1
211627  101.836  -78.077  44.782  1
211628  101.856  -78.088  44.768  1
211629  101.877  -78.100  44.752  1
211630  101.903  -78.111  44.736  1
211631  101.938  -78.122  44.721  1
211632  101.972  -78.132  44.704  1
211633  102.007  -78.143  44.688  1
211634  102.042  -78.153  44.672  1
211635  102.077  -78.163  44.656  1
211636  102.112  -78.174  44.641  1
211637  102.147  -78.184  44.626  1
211638  102.181  -78.195  44.609  1
211639  102.216  -78.206  44.594  1
211640  102.251  -78.216  44.579  1
211641  102.289  -78.232  44.565  1
211642  102.329  -78.253  44.550  1
211643  102.371  -78.275  44.534  1
211644  102.411  -78.296  44.519  1
211645  102.453  -78.317  44.505  1
211646  102.484  -78.325  44.489  1
211647  102.515  -78.331  44.475  1
211648  102.546  -78.336  44.461  1
211649  102.576  -78.342  44.447  1
211650  102.607  -78.348  44.433  1
211651  102.638  -78.354  44.419  1
211652  102.668  -78.360  44.404  1
211653  102.699  -78.366  44.390  1
211654  102.726  -78.368  44.374  1
211655  102.760  -78.366  44.358  1
211656  102.784  -78.374  44.342  1
211657  102.821  -78.388  44.326  1
211658  102.858  -78.401  44.310  1
211659  102.895  -78.415  44.294  1
211660  102.932  -78.429  44.278  1
211661  102.969  -78.442  44.262  1
211662  103.006  -78.457  44.244  1
211663  103.042  -78.470  44.227  1
211664  103.080  -78.484  44.210  1
211665  103.116  -78.498  44.194  1
211666  103.153  -78.511  44.177  1
211667  103.183  -78.518  44.159  1
211950  93.374  -75.731  53.919  1
211951  93.392  -75.734  53.935  1
211952  93.411  -75.737  53.954  1
211953  93.429  -75.740  53.975  1
211954  93.447  -75.743  53.999  1
211955  93.466  -75.746  54.020  1
211956  93.484  -75.750  54.044  1
211957  93.502  -75.753  54.069  1
211958  93.520  -75.756  54.095  1
211959  93.539  -75.760  54.122  1
211960  93.557  -75.763  54.150  1
211961  93.580  -75.767  54.178  1
211962  93.613  -75.761  54.203  1
211963  93.645  -75.755  54.229  1
211964  93.678  -75.749  54.257  1
211965  93.710  -75.743  54.285  1
211966  93.742  -75.737  54.313  1
211967  93.775  -75.731  54.336  1
211968  93.807  -75.724  54.352  1
211969  93.840  -75.718  54.359  1
211970  93.872  -75.712  54.359  1
211971  93.904  -75.706  54.352  1
211972  93.925  -75.698  54.343  1
211973  93.946  -75.691  54.333  1
211974  93.978  -75.686  54.326  1
211975  94.004  -75.681  54.317  1
211976  94.030  -75.676  54.305  1
211977  94.056  -75.671  54.290  1
211978  94.082  -75.665  54.278  1
211979  94.106  -75.664  54.266  1
211980  94.130  -75.662  54.256  1
211981  94.154  -75.660  54.246  1
211982  94.178  -75.662  54.234  1
211983  94.202  -75.664  54.223  1
211984  94.226  -75.665  54.212  1
211985  94.252  -75.666  54.202  1
211986  94.276  -75.666  54.191  1
211987  94.301  -75.666  54.179  1
211988  94.327  -75.666  54.166  1
211989  94.348  -75.668  54.149  1
211990  94.367  -75.669  54.129  1
211991  94.387  -75.671  54.108  1
211992  94.405  -75.674  54.086  1
211993  94.417  -75.680  54.068  1
211994  94.430  -75.686  54.051  1
211995  94.442  -75.692  54.032  1
211996  94.455  -75.697  54.010  1
211997  94.467  -75.703  53.986  1
211998  94.480  -75.709  53.962  1
211999  94.499  -75.716  53.938  1
212000  94.518  -75.722  53.913  1
212001  94.537  -75.729  53.888  1
212002  94.556  -75.736  53.859  1
212003  94.575  -75.742  53.827  1
212004  94.594  -75.749  53.792  1
212005  94.613  -75.756  53.754  1
212006  94.632  -75.762  53.715  1
212007  94.651  -75.768  53.675  1
212008  94.670  -75.775  53.635  1
212009  94.690  -75.781  53.594  1
212010  94.705  -75.781  53.552  1
212011  94.710  -75.784  53.511  1
212012  94.719  -75.786  53.472  1
212013  94.728  -75.789  53.434  1
212014  94.737  -75.791  53.398  1
212015  94.746  -75.794  53.362  1
212016  94.755  -75.796  53.322  1
212017  94.764  -75.800  53.281  1
212018  94.772  -75.802  53.239  1
212019  94.781  -75.805  53.196  1
212020  94.790  -75.808  53.153  1
212021  94.799  -75.810  53.109  1
212022  94.808  -75.813  53.066  1
212023  94.817  -75.815  53.022  1
212024  94.826  -75.818  52.983  1
212025  94.834  -75.821  52.946  1
212026  94.843  -75.824  52.911  1
212027  94.852  -75.826  52.878  1
212028  94.861  -75.829  52.847  1
212029  94.870  -75.832  52.816  1
212030  94.879  -75.834  52.784  1
212031  94.888  -75.837  52.754  1
212032  94.896  -75.840  52.726  1
212033  94.905  -75.843  52.700  1
212034  94.914  -75.845  52.675  1
212035  94.936  -75.850  52.650  1
212036  94.965  -75.856  52.622  1
212037  95.004  -75.865  52.591  1
212038  95.062  -75.866  52.559  1
212039  95.119  -75.868  52.525  1
212040  95.176  -75.869  52.492  1
212041  95.234  -75.871  52.458  1
212042  95.291  -75.872  52.419  1
212043  95.348  -75.874  52.378  1
212044  95.405  -75.875  52.336  1
212045  95.463  -75.877  52.293  1
212046  95.520  -75.878  52.246  1
212047  95.540  -75.855  52.197  1
212048  95.551  -75.852  52.148  1
212049  95.563  -75.869  52.098  1
212050  95.574  -75.884  52.050  1
212051  95.585  -75.900  52.004  1
212052  95.596  -75.915  51.960  1
212053  95.606  -75.922  51.916  1
212054  95.615  -75.928  51.875  1
212055  95.625  -75.935  51.833  1
212056  95.635  -75.942  51.792  1
212057  95.644  -75.949  51.752  1
212058  95.655  -75.956  51.714  1
212059  95.664  -75.962  51.678  1
212060  95.674  -75.969  51.641  1
212061  95.690  -75.975  51.605  1
212062  95.712  -75.979  51.572  1
212063  95.735  -75.983  51.540  1
212064  95.757  -75.988  51.510  1
212065  95.788  -75.990  51.481  1
212066  95.828  -75.990  51.450  1
212067  95.869  -75.989  51.417  1
212068  95.909  -75.989  51.382  1
212069  95.949  -75.989  51.345  1
212070  95.990  -75.989  51.306  1
212071  96.033  -75.989  51.266  1
212072  96.071  -75.989  51.225  1
212073  96.097  -75.991  51.183  1
212074  96.109  -75.994  51.141  1
212075  96.121  -75.999  51.099  1
212076  96.133  -76.003  51.058  1
212077  96.149  -76.005  51.020  1
212078  96.167  -76.007  50.983  1
212079  96.184  -76.010  50.947  1
212080  96.201  -76.012  50.913  1
212081  96.219  -76.013  50.881  1
212082  96.235  -76.016  50.849  1
212083  96.241  -76.031  50.819  1
212084  96.262  -76.042  50.792  1
212085  96.285  -76.053  50.767  1
212086  96.307  -76.064  50.741  1
212087  96.328  -76.075  50.715  1
212088  96.350  -76.087  50.687  1
212089  96.373  -76.097  50.659  1
212090  96.395  -76.109  50.634  1
212091  96.416  -76.120  50.611  1
212092  96.435  -76.130  50.588  1
212093  96.441  -76.137  50.565  1
212094  96.444  -76.145  50.543  1
212095  96.445  -76.155  50.522  1
212096  96.445  -76.165  50.502  1
212097  96.460  -76.176  50.480  1
212098  96.503  -76.189  50.457  1
212099  96.546  -76.204  50.433  1
212100  96.589  -76.217  50.408  1
212101  96.629  -76.224  50.380  1
212102  96.659  -76.223  50.351  1
212103  96.688  -76.222  50.320  1
212104  96.717  -76.220  50.287  1
212105  96.746  -76.220  50.253  1
212106  96.776  -76.218  50.217  1
212107  96.802  -76.217  50.178  1
212108  96.817  -76.216  50.140  1
212109  96.834  -76.221  50.100  1
212110  96.853  -76.235  50.059  1
212111  96.871  -76.249  50.019  1
212112  96.890  -76.263  49.980  1
212113  96.908  -76.277  49.943  1
212114  96.927  -76.291  49.907  1
212115  96.946  -76.305  49.871  1
212116  96.965  -76.318  49.836  1
212117  96.988  -76.326  49.800  1
212118  97.011  -76.333  49.763  1
212119  97.036  -76.342  49.726  1
212120  97.083  -76.367  49.691  1
212121  97.130  -76.390  49.657  1
212122  97.177  -76.414  49.626  1
212123  97.224  -76.437  49.596  1
212124  97.271  -76.450  49.568  1
212125  97.177  -76.438  49.541  1
212126  97.134  -76.432  49.516  1
212127  97.174  -76.446  49.487  1
212128  97.215  -76.464  49.457  1
212129  97.255  -76.483  49.426  1
212130  97.295  -76.501  49.394  1
212131  97.335  -76.519  49.361  1
212132  97.374  -76.529  49.328  1
212133  97.406  -76.515  49.295  1
212134  97.438  -76.502  49.263  1
212135  97.470  -76.489  49.232  1
212136  97.495  -76.486  49.202  1
212137  97.512  -76.495  49.172  1
212138  97.528  -76.504  49.142  1
212139  97.534  -76.516  49.114  1
212140  97.538  -76.530  49.086  1
212141  97.543  -76.542  49.059  1
212142  97.555  -76.555  49.034  1
212143  97.578  -76.567  49.010  1
212144  97.602  -76.580  48.986  1
212145  97.626  -76.591  48.960  1
212146  97.650  -76.603  48.933  1
212147  97.673  -76.614  48.906  1
212148  97.698  -76.627  48.877  1
212149  97.721  -76.639  48.848  1
212150  97.745  -76.650  48.818  1
212151  97.769  -76.662  48.786  1
212152  97.801  -76.673  48.753  1
212153  97.870  -76.676  48.719  1
212154  97.939  -76.680  48.685  1
212155  98.008  -76.683  48.651  1
212156  98.077  -76.687  48.617  1
212157  98.123  -76.679  48.581  1
212158  98.155  -76.670  48.546  1
212159  98.158  -76.673  48.511  1
212160  98.163  -76.677  48.478  1
212161  98.184  -76.690  48.446  1
212162  98.206  -76.703  48.415  1
212163  98.227  -76.716  48.384  1
212164  98.248  -76.729  48.355  1
212165  98.269  -76.743  48.326  1
212166  98.290  -76.755  48.297  1
212167  98.318  -76.752  48.268  1
212168  98.355  -76.724  48.241  1
212169  98.383  -76.726  48.213  1
212170  98.411  -76.728  48.185  1
212171  98.433  -76.734  48.157  1
212172  98.454  -76.739  48.129  1
212173  98.476  -76.744  48.101  1
212174  98.497  -76.749  48.073  1
212175  98.518  -76.755  48.045  1
212176  98.539  -76.760  48.016  1
212177  98.561  -76.765  47.987  1
212178  98.584  -76.758  47.958  1
212179  98.607  -76.742  47.930  1
212180  98.626  -76.739  47.902  1
212181  98.638  -76.751  47.873  1
212182  98.650  -76.763  47.844  1
212183  98.662  -76.775  47.816  1
212184  98.675  -76.785  47.788  1
212185  98.690  -76.792  47.760  1
212186  98.704  -76.799  47.732  1
212187  98.718  -76.806  47.704  1
212188  98.732  -76.812  47.673  1
212189  98.746  -76.820  47.642  1
212190  98.761  -76.827  47.610  1
212191  98.775  -76.834  47.577  1
212192  98.789  -76.840  47.546  1
212193  98.802  -76.831  47.513  1
212194  98.814  -76.816  47.480  1
212195  98.844  -76.818  47.448  1
212196  98.881  -76.827  47.412  1
212197  98.919  -76.835  47.378  1
212198  98.956  -76.843  47.344  1
212199  98.994  -76.852  47.309  1
212200  99.044  -76.855  47.273  1
212201  99.106  -76.856  47.238  1
212202  99.158  -76.853  47.205  1
212203  99.207  -76.853  47.172  1
212204  99.226  -76.857  47.137  1
212205  99.211  -76.848  47.102  1
212206  99.215  -76.853  47.067  1
212207  99.233  -76.867  47.032  1
212208  99.251  -76.882  46.996  1
212209  99.268  -76.897  46.960  1
212210  99.286  -76.912  46.924  1
212211  99.304  -76.926  46.888  1
212212  99.322  -76.940  46.856  1
212213  99.339  -76.956  46.825  1
212214  99.357  -76.970  46.793  1
212215  99.374  -76.984  46.762  1
212216  99.391  -76.997  46.731  1
212217  99.408  -77.009  46.700  1
212218  99.425  -77.021  46.669  1
212219  99.442  -77.033  46.640  1
212220  99.460  -77.046  46.612  1
212221  99.488  -77.053  46.583  1
212222  99.527  -77.055  46.552  1
212223  99.567  -77.056  46.522  1
212224  99.589  -77.071  46.493  1
212225  99.598  -77.069  46.464  1
212226  99.608  -77.066  46.436  1
212227  99.617  -77.063  46.409  1
212228  99.626  -77.059  46.381  1
212229  99.635  -77.058  46.354  1
212230  99.644  -77.056  46.328  1
212231  99.653  -77.053  46.302  1
212232  99.662  -77.051  46.278  1
212233  99.671  -77.049  46.255  1
212234  99.681  -77.047  46.232  1
212235  99.690  -77.044  46.209  1
212236  99.699  -77.042  46.187  1
212237  99.708  -77.040  46.165  1
212238  99.736  -77.032  46.143  1
212239  99.767  -77.023  46.122  1
212240  99.798  -77.014  46.101  1
212241  99.823  -77.007  46.081  1
212242  99.848  -77.001  46.061  1
212243  99.872  -76.994  46.042  1
212244  99.906  -76.993  46.022  1
212245  99.943  -76.992  46.003  1
212246  99.980  -76.992  45.984  1
212247  100.016  -76.991  45.966  1
212248  100.054  -76.991  45.948  1
212249  100.089  -76.995  45.930  1
212250  100.121  -77.018  45.911  1
212251  100.152  -77.041  45.894  1
212252  100.183  -77.063  45.876  1
212253  100.214  -77.086  45.859  1
212254  100.237  -77.097  45.843  1
212255  100.260  -77.106  45.826  1
212256  100.283  -77.116  45.808  1
212257  100.304  -77.129  45.791  1
212258  100.324  -77.144  45.774  1
212259  100.334  -77.158  45.756  1
212260  100.344  -77.171  45.740  1
212261  100.355  -77.183  45.724  1
212262  100.366  -77.195  45.709  1
212263  100.376  -77.207  45.693  1
212264  100.387  -77.219  45.681  1
212265  100.398  -77.232  45.667  1
212266  100.408  -77.244  45.653  1
212267  100.419  -77.256  45.638  1
212268  100.429  -77.267  45.624  1
212269  100.448  -77.284  45.610  1
212270  100.469  -77.301  45.598  1
212271  100.490  -77.318  45.585  1
212272  100.511  -77.335  45.572  1
212273  100.531  -77.353  45.560  1
212274  100.553  -77.370  45.547  1
212275  100.574  -77.388  45.534  1
212276  100.597  -77.408  45.522  1
212277  100.621  -77.428  45.510  1
212278  100.644  -77.448  45.498  1
212279  100.667  -77.468  45.486  1
212280  100.691  -77.488  45.474  1
212281  100.720  -77.495  45.464  1
212282  100.751  -77.500  45.453  1
212283  100.781  -77.505  45.441  1
212284  100.812  -77.511  45.428  1
212285  100.841  -77.515  45.415  1
212286  100.863  -77.517  45.401  1
212287  100.886  -77.520  45.389  1
212288  100.909  -77.526  45.375  1
212289  100.944  -77.556  45.362  1
212290  100.975  -77.583  45.349  1
212291  100.999  -77.602  45.336  1
212292  101.024  -77.620  45.322  1
212293  101.048  -77.639  45.308  1
212294  101.071  -77.658  45.295  1
212295  101.096  -77.677  45.280  1
212296  101.121  -77.690  45.266  1
212297  101.147  -77.699  45.251  1
212298  101.173  -77.708  45.238  1
212299  101.199  -77.718  45.223  1
212300  101.225  -77.727  45.208  1
212301  101.251  -77.736  45.193  1
212302  101.277  -77.746  45.180  1
212303  101.303  -77.755  45.165  1
212304  101.329  -77.764  45.149  1
212305  101.355  -77.773  45.134  1
212306  101.384  -77.788  45.118  1
212307  101.412  -77.804  45.102  1
212308  101.441  -77.821  45.086  1
212309  101.470  -77.837  45.070  1
212310  101.498  -77.853  45.055  1
212311  101.528  -77.869  45.038  1
212312  101.556  -77.885  45.022  1
212313  101.585  -77.902  45.005  1
212314  101.613  -77.918  44.990  1
212315  101.638  -77.933  44.975  1
212316  101.663  -77.948  44.959  1
212317  101.687  -77.963  44.944  1
212318  101.712  -77.978  44.928  1
212319  101.780  -77.985  44.912  1
212320  101.797  -77.994  44.896  1
212321  101.803  -78.004  44.881  1
212322  101.809  -78.014  44.865  1
212323  101.815  -78.024  44.849  1
212324  101.821  -78.034  44.833  1
212325  101.827  -78.044  44.816  1
212326  101.834  -78.053  44.801  1
212327  101.843  -78.060  44.786  1
212328  101.854  -78.067  44.773  1
212329  101.868  -78.075  44.759  1
212330  101.892  -78.087  44.743  1
212331  101.927  -78.097  44.727  1
212332  101.962  -78.108  44.711  1
212333  101.996  -78.118  44.694  1
212334  102.031  -78.128  44.678  1
212335  102.066  -78.139  44.661  1
212336  102.101  -78.150  44.646  1
212337  102.136  -78.160  44.631  1
212338  102.171  -78.171  44.616  1
212339  102.205  -78.181  44.601  1
212340  102.240  -78.192  44.585  1
212341  102.275  -78.203  44.570  1
212342  102.314  -78.220  44.555  1
212343  102.355  -78.241  44.540  1
212344  102.396  -78.263  44.525  1
212345  102.432  -78.276  44.510  1
212346  102.462  -78.282  44.495  1
212347  102.493  -78.288  44.480  1
212348  102.524  -78.294  44.466  1
212349  102.554  -78.300  44.452  1
212350  102.585  -78.306  44.438  1
212351  102.615  -78.312  44.424  1
212352  102.646  -78.318  44.410  1
212353  102.677  -78.324  44.395  1
212354  102.708  -78.329  44.381  1
212355  102.739  -78.333  44.365  1
212356  102.773  -78.331  44.349  1
212357  102.801  -78.340  44.333  1
212358  102.838  -78.354  44.318  1
212359  102.875  -78.367  44.301  1
212360  102.912  -78.381  44.284  1
212361  102.949  -78.395  44.268  1
212362  102.986  -78.408  44.252  1
212363  103.023  -78.422  44.235  1
212364  103.059  -78.435  44.218  1
212365  103.096  -78.449  44.201  1
212366  103.134  -78.463  44.183  1
212367  103.170  -78.476  44.167  1
212368  103.207  -78.490  44.149  1
212651  93.366  -75.707  53.918  1
212652  93.384  -75.710  53.934  1
212653  93.403  -75.714  53.952  1
212654  93.421  -75.717  53.973  1
212655  93.439  -75.720  53.995  1
212656  93.458  -75.724  54.018  1
212657  93.476  -75.727  54.042  1
212658  93.494  -75.730  54.067  1
212659  93.512  -75.734  54.094  1
212660  93.531  -75.737  54.122  1
212661  93.549  -75.740  54.151  1
212662  93.575  -75.740  54.181  1
212663  93.608  -75.734  54.205  1
212664  93.640  -75.728  54.230  1
212665  93.672  -75.721  54.257  1
212666  93.705  -75.715  54.287  1
212667  93.737  -75.709  54.315  1
212668  93.770  -75.702  54.342  1
212669  93.802  -75.696  54.362  1
212670  93.834  -75.690  54.373  1
212671  93.867  -75.684  54.378  1
212672  93.899  -75.678  54.377  1
212673  93.928  -75.671  54.370  1
212674  93.949  -75.664  54.360  1
212675  93.979  -75.659  54.350  1
212676  94.005  -75.654  54.338  1
212677  94.031  -75.649  54.323  1
212678  94.057  -75.643  54.305  1
212679  94.080  -75.642  54.290  1
212680  94.105  -75.640  54.277  1
212681  94.129  -75.638  54.265  1
212682  94.153  -75.637  54.253  1
212683  94.177  -75.637  54.239  1
212684  94.201  -75.639  54.226  1
212685  94.225  -75.640  54.215  1
212686  94.249  -75.643  54.204  1
212687  94.274  -75.644  54.192  1
212688  94.298  -75.644  54.179  1
212689  94.324  -75.644  54.166  1
212690  94.347  -75.645  54.149  1
212691  94.366  -75.646  54.130  1
212692  94.386  -75.649  54.111  1
212693  94.399  -75.654  54.090  1
212694  94.411  -75.660  54.072  1
212695  94.424  -75.666  54.057  1
212696  94.436  -75.671  54.041  1
212697  94.449  -75.677  54.021  1
212698  94.461  -75.684  53.999  1
212699  94.474  -75.690  53.975  1
212700  94.489  -75.696  53.950  1
212701  94.507  -75.702  53.925  1
212702  94.527  -75.709  53.898  1
212703  94.546  -75.715  53.869  1
212704  94.565  -75.721  53.837  1
212705  94.583  -75.728  53.801  1
212706  94.603  -75.735  53.763  1
212707  94.622  -75.741  53.724  1
212708  94.641  -75.748  53.685  1
212709  94.666  -75.748  53.645  1
212710  94.691  -75.746  53.604  1
212711  94.707  -75.746  53.562  1
212712  94.698  -75.749  53.521  1
212713  94.702  -75.752  53.482  1
212714  94.711  -75.755  53.444  1
212715  94.720  -75.757  53.406  1
212716  94.729  -75.760  53.369  1
212717  94.738  -75.762  53.330  1
212718  94.747  -75.765  53.290  1
212719  94.755  -75.768  53.249  1
212720  94.764  -75.771  53.207  1
212721  94.773  -75.774  53.164  1
212722  94.782  -75.776  53.121  1
212723  94.790  -75.779  53.077  1
212724  94.800  -75.781  53.032  1
212725  94.809  -75.784  52.990  1
212726  94.817  -75.787  52.952  1
212727  94.826  -75.790  52.918  1
212728  94.835  -75.793  52.887  1
212729  94.844  -75.795  52.857  1
212730  94.852  -75.798  52.826  1
212731  94.861  -75.800  52.792  1
212732  94.871  -75.803  52.757  1
212733  94.879  -75.806  52.724  1
212734  94.888  -75.809  52.694  1
212735  94.915  -75.814  52.665  1
212736  94.945  -75.820  52.637  1
212737  94.971  -75.824  52.607  1
212738  95.005  -75.834  52.576  1
212739  95.041  -75.845  52.544  1
212740  95.098  -75.847  52.510  1
212741  95.155  -75.848  52.475  1
212742  95.212  -75.850  52.440  1
212743  95.269  -75.851  52.403  1
212744  95.327  -75.853  52.362  1
212745  95.384  -75.854  52.321  1
212746  95.441  -75.856  52.278  1
212747  95.498  -75.857  52.232  1
212748  95.530  -75.841  52.185  1
212749  95.543  -75.813  52.137  1
212750  95.554  -75.828  52.088  1
212751  95.565  -75.844  52.042  1
212752  95.576  -75.860  51.998  1
212753  95.588  -75.877  51.954  1
212754  95.599  -75.893  51.911  1
212755  95.609  -75.905  51.870  1
212756  95.619  -75.912  51.828  1
212757  95.629  -75.919  51.787  1
212758  95.638  -75.925  51.748  1
212759  95.648  -75.932  51.711  1
212760  95.658  -75.938  51.674  1
212761  95.668  -75.945  51.638  1
212762  95.681  -75.951  51.603  1
212763  95.703  -75.956  51.570  1
212764  95.726  -75.960  51.537  1
212765  95.748  -75.965  51.506  1
212766  95.788  -75.965  51.477  1
212767  95.828  -75.964  51.448  1
212768  95.869  -75.964  51.416  1
212769  95.909  -75.964  51.382  1
212770  95.949  -75.964  51.346  1
212771  95.998  -75.964  51.309  1
212772  96.037  -75.966  51.270  1
212773  96.071  -75.966  51.230  1
212774  96.115  -75.964  51.191  1
212775  96.127  -75.968  51.150  1
212776  96.139  -75.972  51.109  1
212777  96.152  -75.975  51.069  1
212778  96.164  -75.979  51.031  1
212779  96.176  -75.983  50.994  1
212780  96.188  -75.987  50.958  1
212781  96.200  -75.991  50.923  1
212782  96.212  -75.995  50.891  1
212783  96.226  -75.998  50.860  1
212784  96.244  -76.006  50.830  1
212785  96.265  -76.017  50.803  1
212786  96.288  -76.028  50.777  1
212787  96.310  -76.040  50.751  1
212788  96.331  -76.050  50.726  1
212789  96.354  -76.062  50.698  1
212790  96.376  -76.073  50.670  1
212791  96.397  -76.084  50.645  1
212792  96.419  -76.095  50.622  1
212793  96.442  -76.107  50.599  1
212794  96.462  -76.117  50.576  1
212795  96.462  -76.127  50.554  1
212796  96.463  -76.136  50.532  1
212797  96.463  -76.146  50.512  1
212798  96.464  -76.155  50.491  1
212799  96.497  -76.168  50.470  1
212800  96.540  -76.182  50.447  1
212801  96.583  -76.196  50.421  1
212802  96.623  -76.204  50.394  1
212803  96.654  -76.202  50.364  1
212804  96.683  -76.201  50.333  1
212805  96.712  -76.200  50.299  1
212806  96.741  -76.199  50.265  1
212807  96.770  -76.198  50.229  1
212808  96.800  -76.196  50.190  1
212809  96.826  -76.195  50.151  1
212810  96.842  -76.201  50.111  1
212811  96.861  -76.214  50.070  1
212812  96.880  -76.229  50.029  1
212813  96.898  -76.242  49.989  1
212814  96.917  -76.257  49.951  1
212815  96.936  -76.270  49.915  1
212816  96.955  -76.285  49.880  1
212817  96.973  -76.298  49.844  1
212818  96.992  -76.313  49.809  1
212819  97.013  -76.323  49.773  1
212820  97.036  -76.330  49.738  1
212821  97.082  -76.353  49.702  1
212822  97.129  -76.376  49.669  1
212823  97.175  -76.392  49.637  1
212824  97.222  -76.405  49.607  1
212825  97.268  -76.417  49.578  1
212826  97.160  -76.403  49.551  1
212827  97.155  -76.402  49.524  1
212828  97.197  -76.408  49.495  1
212829  97.238  -76.424  49.465  1
212830  97.278  -76.442  49.434  1
212831  97.318  -76.461  49.402  1
212832  97.359  -76.479  49.370  1
212833  97.397  -76.491  49.337  1
212834  97.430  -76.477  49.305  1
212835  97.462  -76.464  49.274  1
212836  97.494  -76.451  49.244  1
212837  97.511  -76.459  49.214  1
212838  97.527  -76.467  49.185  1
212839  97.543  -76.477  49.156  1
212840  97.549  -76.489  49.127  1
212841  97.554  -76.503  49.100  1
212842  97.558  -76.516  49.073  1
212843  97.562  -76.530  49.049  1
212844  97.584  -76.542  49.025  1
212845  97.608  -76.553  49.000  1
212846  97.632  -76.565  48.974  1
212847  97.655  -76.577  48.947  1
212848  97.679  -76.589  48.918  1
212849  97.703  -76.601  48.890  1
212850  97.727  -76.613  48.861  1
212851  97.750  -76.624  48.830  1
212852  97.775  -76.636  48.798  1
212853  97.825  -76.643  48.764  1
212854  97.894  -76.647  48.730  1
212855  97.963  -76.651  48.695  1
212856  98.032  -76.654  48.661  1
212857  98.101  -76.658  48.626  1
212858  98.160  -76.657  48.591  1
212859  98.185  -76.650  48.555  1
212860  98.189  -76.653  48.519  1
212861  98.193  -76.657  48.485  1
212862  98.196  -76.660  48.453  1
212863  98.213  -76.670  48.421  1
212864  98.233  -76.683  48.391  1
212865  98.254  -76.696  48.360  1
212866  98.276  -76.709  48.331  1
212867  98.297  -76.723  48.302  1
212868  98.327  -76.711  48.274  1
212869  98.360  -76.699  48.247  1
212870  98.388  -76.701  48.219  1
212871  98.417  -76.702  48.192  1
212872  98.445  -76.705  48.164  1
212873  98.474  -76.707  48.135  1
212874  98.498  -76.711  48.109  1
212875  98.519  -76.716  48.081  1
212876  98.541  -76.721  48.053  1
212877  98.562  -76.727  48.025  1
212878  98.583  -76.732  47.997  1
212879  98.605  -76.737  47.968  1
212880  98.629  -76.721  47.940  1
212881  98.647  -76.717  47.911  1
212882  98.659  -76.729  47.882  1
212883  98.672  -76.741  47.854  1
212884  98.684  -76.753  47.827  1
212885  98.696  -76.765  47.799  1
212886  98.709  -76.776  47.769  1
212887  98.723  -76.783  47.740  1
212888  98.737  -76.790  47.711  1
212889  98.751  -76.797  47.680  1
212890  98.766  -76.804  47.648  1
212891  98.780  -76.811  47.615  1
212892  98.794  -76.818  47.582  1
212893  98.807  -76.817  47.551  1
212894  98.819  -76.802  47.519  1
212895  98.832  -76.787  47.485  1
212896  98.845  -76.772  47.452  1
212897  98.882  -76.781  47.417  1
212898  98.919  -76.790  47.382  1
212899  98.956  -76.798  47.347  1
212900  99.002  -76.802  47.312  1
212901  99.048  -76.805  47.276  1
212902  99.094  -76.808  47.241  1
212903  99.140  -76.811  47.207  1
212904  99.199  -76.815  47.174  1
212905  99.200  -76.817  47.139  1
212906  99.218  -76.832  47.103  1
212907  99.235  -76.846  47.069  1
212908  99.252  -76.858  47.033  1
212909  99.269  -76.870  46.997  1
212910  99.286  -76.882  46.961  1
212911  99.303  -76.895  46.924  1
212912  99.320  -76.907  46.888  1
212913  99.337  -76.919  46.855  1
212914  99.354  -76.931  46.823  1
212915  99.371  -76.943  46.791  1
212916  99.389  -76.956  46.760  1
212917  99.406  -76.969  46.728  1
212918  99.422  -76.981  46.695  1
212919  99.439  -76.993  46.664  1
212920  99.456  -77.006  46.635  1
212921  99.474  -77.018  46.606  1
212922  99.512  -77.020  46.576  1
212923  99.553  -77.022  46.545  1
212924  99.580  -77.035  46.515  1
212925  99.593  -77.047  46.485  1
212926  99.603  -77.044  46.456  1
212927  99.612  -77.041  46.428  1
212928  99.621  -77.038  46.401  1
212929  99.630  -77.035  46.373  1
212930  99.639  -77.032  46.346  1
212931  99.648  -77.029  46.320  1
212932  99.657  -77.027  46.295  1
212933  99.666  -77.025  46.270  1
212934  99.675  -77.022  46.247  1
212935  99.684  -77.020  46.224  1
212936  99.694  -77.018  46.201  1
212937  99.703  -77.016  46.178  1
212938  99.712  -77.014  46.157  1
212939  99.739  -77.006  46.134  1
212940  99.771  -76.997  46.113  1
212941  99.802  -76.987  46.093  1
212942  99.834  -76.978  46.073  1
212943  99.863  -76.970  46.053  1
212944  99.888  -76.963  46.033  1
212945  99.924  -76.962  46.014  1
212946  99.961  -76.962  45.995  1
212947  99.998  -76.962  45.976  1
212948  100.035  -76.962  45.957  1
212949  100.072  -76.961  45.939  1
212950  100.109  -76.960  45.921  1
212951  100.140  -76.983  45.903  1
212952  100.171  -77.006  45.886  1
212953  100.202  -77.028  45.868  1
212954  100.234  -77.051  45.851  1
212955  100.259  -77.073  45.835  1
212956  100.279  -77.088  45.818  1
212957  100.299  -77.102  45.801  1
212958  100.320  -77.116  45.784  1
212959  100.339  -77.133  45.767  1
212960  100.354  -77.149  45.750  1
212961  100.363  -77.162  45.733  1
212962  100.372  -77.175  45.717  1
212963  100.381  -77.188  45.702  1
212964  100.390  -77.201  45.687  1
212965  100.401  -77.213  45.675  1
212966  100.411  -77.226  45.661  1
212967  100.422  -77.238  45.647  1
212968  100.433  -77.250  45.632  1
212969  100.443  -77.262  45.618  1
212970  100.464  -77.279  45.605  1
212971  100.485  -77.296  45.592  1
212972  100.506  -77.313  45.580  1
212973  100.527  -77.331  45.567  1
212974  100.548  -77.348  45.554  1
212975  100.568  -77.366  45.541  1
212976  100.590  -77.382  45.528  1
212977  100.610  -77.400  45.517  1
212978  100.633  -77.420  45.505  1
212979  100.656  -77.439  45.493  1
212980  100.680  -77.459  45.481  1
212981  100.703  -77.479  45.469  1
212982  100.732  -77.489  45.458  1
212983  100.762  -77.494  45.448  1
212984  100.792  -77.499  45.436  1
212985  100.823  -77.504  45.424  1
212986  100.845  -77.507  45.411  1
212987  100.867  -77.509  45.397  1
212988  100.889  -77.511  45.384  1
212989  100.912  -77.516  45.370  1
212990  100.947  -77.545  45.356  1
212991  100.981  -77.576  45.344  1
212992  101.009  -77.599  45.331  1
212993  101.034  -77.618  45.317  1
212994  101.058  -77.637  45.303  1
212995  101.082  -77.652  45.289  1
212996  101.109  -77.661  45.274  1
212997  101.134  -77.671  45.260  1
212998  101.161  -77.680  45.245  1
212999  101.187  -77.689  45.230  1
213000  101.212  -77.698  45.216  1
213001  101.239  -77.707  45.201  1
213002  101.265  -77.716  45.186  1
213003  101.290  -77.725  45.171  1
213004  101.317  -77.734  45.156  1
213005  101.343  -77.743  45.140  1
213006  101.370  -77.755  45.124  1
213007  101.399  -77.771  45.109  1
213008  101.427  -77.788  45.092  1
213009  101.456  -77.804  45.076  1
213010  101.485  -77.821  45.061  1
213011  101.513  -77.837  45.045  1
213012  101.543  -77.853  45.028  1
213013  101.568  -77.868  45.011  1
213014  101.593  -77.884  44.994  1
213015  101.618  -77.899  44.980  1
213016  101.642  -77.914  44.965  1
213017  101.668  -77.929  44.949  1
213018  101.692  -77.944  44.934  1
213019  101.717  -77.959  44.918  1
213020  101.791  -77.965  44.902  1
213021  101.834  -77.971  44.886  1
213022  101.840  -77.981  44.870  1
213023  101.846  -77.990  44.854  1
213024  101.852  -78.000  44.838  1
213025  101.858  -78.010  44.823  1
213026  101.865  -78.020  44.807  1
213027  101.871  -78.030  44.791  1
213028  101.877  -78.040  44.777  1
213029  101.883  -78.050  44.763  1
213030  101.882  -78.061  44.749  1
213031  101.916  -78.072  44.733  1
213032  101.951  -78.083  44.717  1
213033  101.986  -78.094  44.701  1
213034  102.021  -78.104  44.684  1
213035  102.055  -78.115  44.667  1
213036  102.090  -78.125  44.651  1
213037  102.125  -78.136  44.636  1
213038  102.160  -78.147  44.621  1
213039  102.195  -78.157  44.606  1
213040  102.230  -78.168  44.590  1
213041  102.264  -78.178  44.575  1
213042  102.299  -78.189  44.560  1
213043  102.338  -78.208  44.545  1
213044  102.379  -78.228  44.531  1
213045  102.410  -78.235  44.516  1
213046  102.441  -78.241  44.501  1
213047  102.471  -78.246  44.486  1
213048  102.501  -78.252  44.471  1
213049  102.532  -78.258  44.456  1
213050  102.563  -78.264  44.442  1
213051  102.594  -78.265  44.429  1
213052  102.624  -78.266  44.414  1
213053  102.655  -78.266  44.400  1
213054  102.685  -78.267  44.386  1
213055  102.716  -78.268  44.371  1
213056  102.750  -78.285  44.356  1
213057  102.786  -78.296  44.339  1
213058  102.818  -78.305  44.323  1
213059  102.855  -78.319  44.307  1
213060  102.892  -78.333  44.291  1
213061  102.929  -78.347  44.275  1
213062  102.966  -78.360  44.258  1
213063  103.003  -78.374  44.242  1
213064  103.040  -78.388  44.224  1
213065  103.077  -78.401  44.207  1
213066  103.113  -78.415  44.190  1
213067  103.151  -78.429  44.173  1
213068  103.187  -78.442  44.156  1
213069  103.224  -78.456  44.138  1
213352  93.358  -75.684  53.917  1
213353  93.376  -75.687  53.932  1
213354  93.395  -75.690  53.950  1
213355  93.413  -75.693  53.970  1
213356  93.431  -75.697  53.992  1
213357  93.449  -75.700  54.015  1
213358  93.468  -75.703  54.038  1
213359  93.486  -75.707  54.064  1
213360  93.504  -75.710  54.092  1
213361  93.522  -75.713  54.122  1
213362  93.542  -75.716  54.153  1
213363  93.574  -75.711  54.184  1
213364  93.603  -75.706  54.208  1
213365  93.635  -75.699  54.232  1
213366  93.667  -75.693  54.257  1
213367  93.700  -75.687  54.286  1
213368  93.732  -75.681  54.315  1
213369  93.764  -75.675  54.340  1
213370  93.797  -75.669  54.362  1
213371  93.829  -75.663  54.379  1
213372  93.862  -75.657  54.389  1
213373  93.894  -75.650  54.391  1
213374  93.926  -75.644  54.389  1
213375  93.953  -75.637  54.385  1
213376  93.979  -75.631  54.377  1
213377  94.005  -75.627  54.363  1
213378  94.031  -75.621  54.344  1
213379  94.055  -75.620  54.325  1
213380  94.079  -75.618  54.307  1
213381  94.104  -75.616  54.293  1
213382  94.128  -75.615  54.281  1
213383  94.152  -75.612  54.266  1
213384  94.176  -75.612  54.249  1
213385  94.200  -75.614  54.232  1
213386  94.224  -75.616  54.217  1
213387  94.248  -75.618  54.206  1
213388  94.272  -75.619  54.193  1
213389  94.296  -75.621  54.181  1
213390  94.321  -75.622  54.170  1
213391  94.346  -75.622  54.153  1
213392  94.365  -75.624  54.136  1
213393  94.380  -75.628  54.118  1
213394  94.393  -75.634  54.098  1
213395  94.405  -75.640  54.081  1
213396  94.418  -75.646  54.068  1
213397  94.430  -75.652  54.053  1
213398  94.442  -75.658  54.034  1
213399  94.455  -75.664  54.012  1
213400  94.468  -75.669  53.987  1
213401  94.480  -75.675  53.961  1
213402  94.497  -75.682  53.934  1
213403  94.517  -75.688  53.907  1
213404  94.535  -75.695  53.877  1
213405  94.554  -75.702  53.845  1
213406  94.573  -75.708  53.810  1
213407  94.593  -75.715  53.773  1
213408  94.616  -75.716  53.734  1
213409  94.641  -75.715  53.696  1
213410  94.667  -75.714  53.656  1
213411  94.693  -75.713  53.614  1
213412  94.709  -75.712  53.572  1
213413  94.700  -75.715  53.531  1
213414  94.691  -75.718  53.492  1
213415  94.694  -75.721  53.454  1
213416  94.703  -75.724  53.417  1
213417  94.711  -75.726  53.379  1
213418  94.720  -75.729  53.340  1
213419  94.730  -75.731  53.301  1
213420  94.738  -75.734  53.261  1
213421  94.747  -75.737  53.218  1
213422  94.756  -75.740  53.176  1
213423  94.765  -75.742  53.133  1
213424  94.773  -75.745  53.090  1
213425  94.782  -75.747  53.044  1
213426  94.791  -75.750  53.000  1
213427  94.800  -75.753  52.960  1
213428  94.809  -75.756  52.924  1
213429  94.818  -75.759  52.894  1
213430  94.827  -75.761  52.866  1
213431  94.835  -75.764  52.836  1
213432  94.844  -75.766  52.803  1
213433  94.853  -75.769  52.765  1
213434  94.862  -75.772  52.728  1
213435  94.893  -75.778  52.693  1
213436  94.923  -75.784  52.660  1
213437  94.952  -75.790  52.627  1
213438  94.977  -75.793  52.594  1
213439  95.010  -75.803  52.560  1
213440  95.044  -75.813  52.527  1
213441  95.078  -75.825  52.492  1
213442  95.133  -75.827  52.458  1
213443  95.191  -75.828  52.423  1
213444  95.248  -75.830  52.387  1
213445  95.305  -75.831  52.347  1
213446  95.362  -75.833  52.307  1
213447  95.420  -75.834  52.266  1
213448  95.477  -75.836  52.220  1
213449  95.521  -75.828  52.174  1
213450  95.533  -75.800  52.127  1
213451  95.545  -75.788  52.080  1
213452  95.556  -75.804  52.035  1
213453  95.567  -75.820  51.992  1
213454  95.579  -75.837  51.950  1
213455  95.590  -75.853  51.908  1
213456  95.601  -75.869  51.867  1
213457  95.612  -75.885  51.825  1
213458  95.622  -75.895  51.784  1
213459  95.632  -75.902  51.745  1
213460  95.642  -75.909  51.707  1
213461  95.652  -75.915  51.671  1
213462  95.661  -75.922  51.635  1
213463  95.672  -75.928  51.600  1
213464  95.694  -75.933  51.567  1
213465  95.716  -75.938  51.535  1
213466  95.747  -75.940  51.504  1
213467  95.788  -75.939  51.476  1
213468  95.828  -75.939  51.446  1
213469  95.868  -75.939  51.414  1
213470  95.913  -75.939  51.381  1
213471  95.963  -75.939  51.347  1
213472  96.005  -75.941  51.310  1
213473  96.037  -75.945  51.273  1
213474  96.072  -75.941  51.235  1
213475  96.133  -75.937  51.198  1
213476  96.145  -75.941  51.159  1
213477  96.157  -75.944  51.118  1
213478  96.169  -75.948  51.078  1
213479  96.181  -75.952  51.041  1
213480  96.193  -75.956  51.004  1
213481  96.205  -75.960  50.969  1
213482  96.218  -75.964  50.934  1
213483  96.227  -75.966  50.901  1
213484  96.235  -75.969  50.870  1
213485  96.256  -75.977  50.841  1
213486  96.277  -75.988  50.814  1
213487  96.300  -75.999  50.787  1
213488  96.322  -76.010  50.762  1
213489  96.344  -76.021  50.737  1
213490  96.366  -76.032  50.709  1
213491  96.388  -76.044  50.680  1
213492  96.410  -76.054  50.655  1
213493  96.432  -76.066  50.632  1
213494  96.454  -76.076  50.610  1
213495  96.473  -76.089  50.587  1
213496  96.477  -76.108  50.564  1
213497  96.481  -76.117  50.542  1
213498  96.482  -76.127  50.522  1
213499  96.482  -76.137  50.501  1
213500  96.490  -76.147  50.481  1
213501  96.533  -76.160  50.460  1
213502  96.577  -76.175  50.434  1
213503  96.617  -76.182  50.406  1
213504  96.649  -76.182  50.377  1
213505  96.678  -76.181  50.345  1
213506  96.707  -76.179  50.312  1
213507  96.736  -76.178  50.277  1
213508  96.765  -76.177  50.241  1
213509  96.795  -76.176  50.202  1
213510  96.824  -76.174  50.163  1
213511  96.848  -76.182  50.123  1
213512  96.867  -76.195  50.081  1
213513  96.887  -76.209  50.039  1
213514  96.906  -76.223  49.999  1
213515  96.926  -76.236  49.960  1
213516  96.945  -76.250  49.924  1
213517  96.963  -76.263  49.888  1
213518  96.982  -76.278  49.853  1
213519  97.001  -76.292  49.817  1
213520  97.019  -76.306  49.782  1
213521  97.038  -76.320  49.749  1
213522  97.080  -76.336  49.714  1
213523  97.126  -76.348  49.680  1
213524  97.173  -76.361  49.648  1
213525  97.219  -76.373  49.617  1
213526  97.265  -76.386  49.587  1
213527  97.143  -76.369  49.559  1
213528  97.176  -76.373  49.532  1
213529  97.218  -76.379  49.503  1
213530  97.261  -76.385  49.473  1
213531  97.301  -76.402  49.442  1
213532  97.342  -76.420  49.411  1
213533  97.381  -76.439  49.380  1
213534  97.421  -76.453  49.348  1
213535  97.453  -76.439  49.316  1
213536  97.486  -76.426  49.286  1
213537  97.511  -76.423  49.256  1
213538  97.527  -76.432  49.227  1
213539  97.543  -76.441  49.198  1
213540  97.559  -76.450  49.169  1
213541  97.564  -76.463  49.140  1
213542  97.568  -76.477  49.113  1
213543  97.573  -76.489  49.086  1
213544  97.577  -76.503  49.063  1
213545  97.590  -76.516  49.039  1
213546  97.613  -76.527  49.014  1
213547  97.637  -76.539  48.988  1
213548  97.661  -76.552  48.959  1
213549  97.685  -76.563  48.930  1
213550  97.709  -76.575  48.901  1
213551  97.732  -76.587  48.872  1
213552  97.756  -76.599  48.840  1
213553  97.780  -76.611  48.808  1
213554  97.849  -76.614  48.774  1
213555  97.918  -76.618  48.740  1
213556  97.987  -76.621  48.705  1
213557  98.056  -76.625  48.669  1
213558  98.125  -76.629  48.634  1
213559  98.194  -76.632  48.599  1
213560  98.216  -76.631  48.563  1
213561  98.220  -76.634  48.527  1
213562  98.223  -76.637  48.492  1
213563  98.226  -76.640  48.459  1
213564  98.230  -76.643  48.427  1
213565  98.240  -76.650  48.395  1
213566  98.262  -76.664  48.365  1
213567  98.283  -76.677  48.336  1
213568  98.304  -76.690  48.307  1
213569  98.337  -76.671  48.278  1
213570  98.365  -76.674  48.251  1
213571  98.393  -76.676  48.224  1
213572  98.422  -76.677  48.197  1
213573  98.450  -76.680  48.170  1
213574  98.479  -76.682  48.141  1
213575  98.507  -76.683  48.114  1
213576  98.536  -76.686  48.087  1
213577  98.563  -76.688  48.059  1
213578  98.584  -76.693  48.032  1
213579  98.606  -76.699  48.004  1
213580  98.627  -76.705  47.976  1
213581  98.650  -76.699  47.947  1
213582  98.668  -76.695  47.920  1
213583  98.681  -76.707  47.891  1
213584  98.693  -76.719  47.863  1
213585  98.706  -76.731  47.835  1
213586  98.718  -76.743  47.805  1
213587  98.730  -76.755  47.775  1
213588  98.742  -76.768  47.745  1
213589  98.757  -76.774  47.715  1
213590  98.771  -76.781  47.683  1
213591  98.785  -76.789  47.651  1
213592  98.799  -76.796  47.619  1
213593  98.813  -76.802  47.587  1
213594  98.826  -76.788  47.556  1
213595  98.838  -76.773  47.524  1
213596  98.850  -76.758  47.491  1
213597  98.862  -76.743  47.458  1
213598  98.882  -76.736  47.423  1
213599  98.920  -76.744  47.387  1
213600  98.964  -76.748  47.352  1
213601  99.010  -76.752  47.317  1
213602  99.056  -76.755  47.280  1
213603  99.102  -76.768  47.244  1
213604  99.149  -76.782  47.208  1
213605  99.195  -76.797  47.175  1
213606  99.215  -76.797  47.140  1
213607  99.232  -76.806  47.104  1
213608  99.249  -76.818  47.069  1
213609  99.266  -76.830  47.034  1
213610  99.283  -76.842  46.998  1
213611  99.300  -76.855  46.961  1
213612  99.317  -76.867  46.924  1
213613  99.335  -76.879  46.888  1
213614  99.351  -76.891  46.854  1
213615  99.368  -76.903  46.821  1
213616  99.385  -76.916  46.788  1
213617  99.403  -76.928  46.756  1
213618  99.420  -76.940  46.724  1
213619  99.437  -76.953  46.691  1
213620  99.453  -76.965  46.658  1
213621  99.471  -76.978  46.629  1
213622  99.497  -76.985  46.600  1
213623  99.538  -76.987  46.569  1
213624  99.570  -76.996  46.538  1
213625  99.587  -77.019  46.508  1
213626  99.597  -77.022  46.477  1
213627  99.607  -77.019  46.448  1
213628  99.616  -77.016  46.420  1
213629  99.625  -77.013  46.393  1
213630  99.634  -77.010  46.366  1
213631  99.643  -77.007  46.339  1
213632  99.652  -77.004  46.314  1
213633  99.661  -77.002  46.289  1
213634  99.670  -76.999  46.264  1
213635  99.679  -76.996  46.240  1
213636  99.688  -76.994  46.217  1
213637  99.697  -76.992  46.195  1
213638  99.706  -76.990  46.172  1
213639  99.716  -76.987  46.150  1
213640  99.744  -76.979  46.128  1
213641  99.775  -76.970  46.107  1
213642  99.806  -76.961  46.087  1
213643  99.838  -76.952  46.066  1
213644  99.869  -76.943  46.046  1
213645  99.907  -76.942  46.025  1
213646  99.943  -76.937  46.005  1
213647  99.979  -76.932  45.986  1
213648  100.016  -76.931  45.968  1
213649  100.053  -76.931  45.949  1
213650  100.090  -76.931  45.931  1
213651  100.127  -76.931  45.913  1
213652  100.159  -76.948  45.895  1
213653  100.191  -76.971  45.878  1
213654  100.225  -77.022  45.860  1
213655  100.253  -77.049  45.844  1
213656  100.275  -77.060  45.827  1
213657  100.295  -77.075  45.810  1
213658  100.316  -77.090  45.794  1
213659  100.336  -77.104  45.776  1
213660  100.354  -77.122  45.759  1
213661  100.372  -77.139  45.743  1
213662  100.382  -77.153  45.726  1
213663  100.391  -77.166  45.710  1
213664  100.400  -77.179  45.694  1
213665  100.409  -77.191  45.680  1
213666  100.418  -77.205  45.668  1
213667  100.427  -77.218  45.654  1
213668  100.436  -77.231  45.641  1
213669  100.446  -77.244  45.627  1
213670  100.459  -77.257  45.613  1
213671  100.480  -77.274  45.600  1
213672  100.501  -77.291  45.587  1
213673  100.522  -77.309  45.574  1
213674  100.543  -77.326  45.561  1
213675  100.563  -77.343  45.548  1
213676  100.584  -77.360  45.535  1
213677  100.605  -77.378  45.522  1
213678  100.626  -77.395  45.511  1
213679  100.647  -77.413  45.500  1
213680  100.669  -77.431  45.488  1
213681  100.692  -77.451  45.477  1
213682  100.715  -77.470  45.465  1
213683  100.743  -77.483  45.453  1
213684  100.773  -77.489  45.442  1
213685  100.804  -77.493  45.431  1
213686  100.826  -77.496  45.419  1
213687  100.848  -77.498  45.405  1
213688  100.870  -77.501  45.392  1
213689  100.893  -77.503  45.379  1
213690  100.915  -77.505  45.365  1
213691  100.949  -77.536  45.352  1
213692  100.984  -77.565  45.339  1
213693  101.019  -77.595  45.325  1
213694  101.044  -77.614  45.312  1
213695  101.070  -77.623  45.297  1
213696  101.096  -77.632  45.283  1
213697  101.122  -77.641  45.268  1
213698  101.148  -77.650  45.253  1
213699  101.174  -77.659  45.238  1
213700  101.200  -77.668  45.223  1
213701  101.226  -77.677  45.208  1
213702  101.252  -77.686  45.193  1
213703  101.278  -77.696  45.178  1
213704  101.304  -77.705  45.162  1
213705  101.330  -77.714  45.147  1
213706  101.356  -77.723  45.131  1
213707  101.385  -77.739  45.115  1
213708  101.414  -77.755  45.099  1
213709  101.443  -77.771  45.083  1
213710  101.471  -77.788  45.066  1
213711  101.498  -77.803  45.050  1
213712  101.523  -77.819  45.034  1
213713  101.548  -77.834  45.017  1
213714  101.573  -77.849  45.001  1
213715  101.598  -77.865  44.984  1
213716  101.622  -77.880  44.969  1
213717  101.647  -77.895  44.954  1
213718  101.672  -77.910  44.939  1
213719  101.697  -77.925  44.925  1
213720  101.722  -77.940  44.908  1
213721  101.802  -77.945  44.891  1
213722  101.872  -77.947  44.875  1
213723  101.878  -77.957  44.859  1
213724  101.884  -77.967  44.842  1
213725  101.890  -77.977  44.826  1
213726  101.896  -77.987  44.811  1
213727  101.902  -77.996  44.795  1
213728  101.908  -78.006  44.780  1
213729  101.914  -78.016  44.765  1
213730  101.906  -78.034  44.752  1
213731  101.893  -78.040  44.738  1
213732  101.939  -78.053  44.722  1
213733  101.974  -78.065  44.706  1
213734  102.009  -78.076  44.690  1
213735  102.044  -78.087  44.672  1
213736  102.079  -78.098  44.656  1
213737  102.114  -78.109  44.641  1
213738  102.149  -78.120  44.626  1
213739  102.184  -78.131  44.610  1
213740  102.219  -78.143  44.595  1
213741  102.253  -78.154  44.579  1
213742  102.289  -78.165  44.564  1
213743  102.323  -78.175  44.550  1
213744  102.358  -78.186  44.536  1
213745  102.388  -78.190  44.521  1
213746  102.418  -78.191  44.507  1
213747  102.449  -78.191  44.492  1
213748  102.480  -78.192  44.477  1
213749  102.510  -78.193  44.461  1
213750  102.541  -78.194  44.446  1
213751  102.572  -78.194  44.432  1
213752  102.602  -78.195  44.418  1
213753  102.632  -78.196  44.404  1
213754  102.663  -78.197  44.390  1
213755  102.694  -78.197  44.375  1
213756  102.725  -78.200  44.361  1
213757  102.761  -78.225  44.346  1
213758  102.798  -78.251  44.330  1
213759  102.835  -78.271  44.313  1
213760  102.872  -78.285  44.297  1
213761  102.909  -78.298  44.281  1
213762  102.946  -78.312  44.265  1
213763  102.983  -78.326  44.248  1
213764  103.020  -78.339  44.231  1
213765  103.056  -78.353  44.214  1
213766  103.094  -78.366  44.197  1
213767  103.130  -78.380  44.180  1
213768  103.167  -78.394  44.162  1
213769  103.205  -78.407  44.145  1
213770  103.241  -78.422  44.127  1
214053  93.350  -75.661  53.915  1
214054  93.368  -75.664  53.929  1
214055  93.386  -75.667  53.946  1
214056  93.405  -75.671  53.966  1
214057  93.423  -75.674  53.989  1
214058  93.441  -75.677  54.011  1
214059  93.460  -75.681  54.034  1
214060  93.478  -75.684  54.060  1
214061  93.496  -75.687  54.090  1
214062  93.517  -75.687  54.121  1
214063  93.541  -75.687  54.154  1
214064  93.578  -75.681  54.187  1
214065  93.615  -75.672  54.212  1
214066  93.644  -75.667  54.236  1
214067  93.674  -75.662  54.260  1
214068  93.703  -75.657  54.287  1
214069  93.733  -75.652  54.314  1
214070  93.763  -75.646  54.339  1
214071  93.792  -75.641  54.361  1
214072  93.824  -75.635  54.380  1
214073  93.856  -75.629  54.391  1
214074  93.889  -75.623  54.398  1
214075  93.921  -75.617  54.403  1
214076  93.954  -75.611  54.404  1
214077  93.980  -75.604  54.399  1
214078  94.006  -75.599  54.386  1
214079  94.030  -75.598  54.368  1
214080  94.054  -75.596  54.347  1
214081  94.078  -75.594  54.327  1
214082  94.102  -75.592  54.311  1
214083  94.126  -75.590  54.298  1
214084  94.150  -75.589  54.284  1
214085  94.175  -75.587  54.266  1
214086  94.199  -75.589  54.247  1
214087  94.223  -75.591  54.227  1
214088  94.247  -75.593  54.212  1
214089  94.271  -75.594  54.199  1
214090  94.295  -75.596  54.189  1
214091  94.319  -75.598  54.180  1
214092  94.343  -75.599  54.167  1
214093  94.362  -75.602  54.152  1
214094  94.374  -75.609  54.134  1
214095  94.387  -75.615  54.114  1
214096  94.399  -75.620  54.098  1
214097  94.411  -75.626  54.084  1
214098  94.424  -75.632  54.069  1
214099  94.436  -75.638  54.049  1
214100  94.449  -75.643  54.025  1
214101  94.461  -75.649  53.998  1
214102  94.474  -75.656  53.970  1
214103  94.487  -75.662  53.942  1
214104  94.506  -75.668  53.915  1
214105  94.525  -75.674  53.884  1
214106  94.544  -75.681  53.851  1
214107  94.566  -75.684  53.818  1
214108  94.592  -75.683  53.782  1
214109  94.617  -75.682  53.745  1
214110  94.643  -75.681  53.706  1
214111  94.669  -75.680  53.667  1
214112  94.694  -75.679  53.625  1
214113  94.712  -75.679  53.582  1
214114  94.702  -75.681  53.541  1
214115  94.693  -75.684  53.502  1
214116  94.684  -75.687  53.464  1
214117  94.686  -75.690  53.426  1
214118  94.694  -75.692  53.389  1
214119  94.703  -75.695  53.351  1
214120  94.712  -75.697  53.312  1
214121  94.721  -75.700  53.272  1
214122  94.730  -75.702  53.229  1
214123  94.739  -75.706  53.187  1
214124  94.748  -75.709  53.145  1
214125  94.756  -75.711  53.103  1
214126  94.765  -75.714  53.056  1
214127  94.774  -75.716  53.011  1
214128  94.783  -75.719  52.968  1
214129  94.792  -75.721  52.931  1
214130  94.801  -75.724  52.900  1
214131  94.810  -75.727  52.873  1
214132  94.818  -75.730  52.845  1
214133  94.827  -75.733  52.813  1
214134  94.841  -75.736  52.775  1
214135  94.871  -75.742  52.736  1
214136  94.901  -75.748  52.697  1
214137  94.931  -75.754  52.659  1
214138  94.959  -75.759  52.622  1
214139  94.984  -75.762  52.586  1
214140  95.016  -75.771  52.549  1
214141  95.050  -75.781  52.514  1
214142  95.084  -75.792  52.478  1
214143  95.118  -75.803  52.442  1
214144  95.170  -75.807  52.406  1
214145  95.227  -75.809  52.370  1
214146  95.284  -75.810  52.331  1
214147  95.341  -75.812  52.293  1
214148  95.398  -75.813  52.253  1
214149  95.456  -75.815  52.209  1
214150  95.512  -75.815  52.164  1
214151  95.524  -75.786  52.118  1
214152  95.536  -75.758  52.073  1
214153  95.547  -75.764  52.029  1
214154  95.558  -75.780  51.987  1
214155  95.569  -75.796  51.945  1
214156  95.581  -75.812  51.905  1
214157  95.592  -75.828  51.863  1
214158  95.603  -75.845  51.822  1
214159  95.614  -75.861  51.781  1
214160  95.626  -75.877  51.742  1
214161  95.635  -75.885  51.704  1
214162  95.645  -75.891  51.667  1
214163  95.655  -75.898  51.632  1
214164  95.665  -75.905  51.599  1
214165  95.685  -75.910  51.566  1
214166  95.707  -75.914  51.534  1
214167  95.747  -75.914  51.505  1
214168  95.788  -75.914  51.476  1
214169  95.828  -75.914  51.446  1
214170  95.879  -75.914  51.416  1
214171  95.928  -75.915  51.384  1
214172  95.971  -75.916  51.349  1
214173  96.004  -75.920  51.315  1
214174  96.037  -75.924  51.280  1
214175  96.072  -75.917  51.242  1
214176  96.151  -75.909  51.205  1
214177  96.163  -75.913  51.166  1
214178  96.175  -75.917  51.127  1
214179  96.187  -75.922  51.088  1
214180  96.199  -75.925  51.050  1
214181  96.212  -75.929  51.014  1
214182  96.220  -75.931  50.978  1
214183  96.223  -75.931  50.944  1
214184  96.228  -75.933  50.911  1
214185  96.249  -75.939  50.879  1
214186  96.269  -75.947  50.850  1
214187  96.291  -75.957  50.823  1
214188  96.313  -75.969  50.797  1
214189  96.335  -75.980  50.772  1
214190  96.357  -75.991  50.746  1
214191  96.379  -76.002  50.719  1
214192  96.401  -76.013  50.691  1
214193  96.424  -76.024  50.666  1
214194  96.446  -76.035  50.643  1
214195  96.467  -76.047  50.619  1
214196  96.483  -76.061  50.596  1
214197  96.493  -76.077  50.574  1
214198  96.493  -76.097  50.553  1
214199  96.501  -76.108  50.532  1
214200  96.501  -76.118  50.512  1
214201  96.502  -76.127  50.491  1
214202  96.527  -76.139  50.469  1
214203  96.570  -76.154  50.443  1
214204  96.611  -76.162  50.416  1
214205  96.644  -76.161  50.387  1
214206  96.673  -76.160  50.356  1
214207  96.702  -76.159  50.323  1
214208  96.731  -76.157  50.289  1
214209  96.760  -76.156  50.253  1
214210  96.790  -76.155  50.214  1
214211  96.816  -76.157  50.174  1
214212  96.837  -76.169  50.133  1
214213  96.856  -76.183  50.091  1
214214  96.876  -76.197  50.050  1
214215  96.895  -76.210  50.010  1
214216  96.914  -76.224  49.971  1
214217  96.934  -76.238  49.933  1
214218  96.953  -76.251  49.897  1
214219  96.973  -76.265  49.862  1
214220  96.993  -76.279  49.827  1
214221  97.016  -76.289  49.792  1
214222  97.044  -76.295  49.758  1
214223  97.078  -76.303  49.724  1
214224  97.124  -76.316  49.689  1
214225  97.170  -76.329  49.656  1
214226  97.217  -76.341  49.625  1
214227  97.253  -76.351  49.595  1
214228  97.154  -76.338  49.567  1
214229  97.196  -76.344  49.538  1
214230  97.239  -76.349  49.509  1
214231  97.282  -76.355  49.480  1
214232  97.324  -76.362  49.450  1
214233  97.364  -76.380  49.419  1
214234  97.404  -76.398  49.389  1
214235  97.444  -76.415  49.358  1
214236  97.476  -76.401  49.328  1
214237  97.509  -76.389  49.299  1
214238  97.526  -76.396  49.270  1
214239  97.542  -76.405  49.241  1
214240  97.559  -76.414  49.212  1
214241  97.574  -76.423  49.183  1
214242  97.579  -76.436  49.154  1
214243  97.583  -76.450  49.127  1
214244  97.587  -76.463  49.102  1
214245  97.592  -76.477  49.077  1
214246  97.596  -76.489  49.052  1
214247  97.619  -76.502  49.027  1
214248  97.643  -76.514  49.000  1
214249  97.667  -76.525  48.971  1
214250  97.690  -76.537  48.942  1
214251  97.714  -76.549  48.912  1
214252  97.738  -76.561  48.882  1
214253  97.762  -76.573  48.850  1
214254  97.803  -76.581  48.817  1
214255  97.872  -76.585  48.783  1
214256  97.941  -76.589  48.748  1
214257  98.010  -76.592  48.713  1
214258  98.079  -76.596  48.677  1
214259  98.148  -76.599  48.641  1
214260  98.211  -76.605  48.607  1
214261  98.236  -76.618  48.570  1
214262  98.246  -76.617  48.534  1
214263  98.253  -76.618  48.498  1
214264  98.257  -76.621  48.464  1
214265  98.261  -76.624  48.432  1
214266  98.264  -76.627  48.400  1
214267  98.268  -76.630  48.369  1
214268  98.289  -76.644  48.340  1
214269  98.310  -76.657  48.311  1
214270  98.342  -76.646  48.282  1
214271  98.371  -76.649  48.255  1
214272  98.399  -76.650  48.228  1
214273  98.427  -76.652  48.201  1
214274  98.456  -76.655  48.174  1
214275  98.484  -76.656  48.146  1
214276  98.513  -76.658  48.118  1
214277  98.541  -76.661  48.092  1
214278  98.570  -76.663  48.065  1
214279  98.598  -76.665  48.039  1
214280  98.627  -76.667  48.011  1
214281  98.650  -76.671  47.983  1
214282  98.671  -76.677  47.954  1
214283  98.690  -76.674  47.927  1
214284  98.702  -76.685  47.899  1
214285  98.715  -76.697  47.871  1
214286  98.727  -76.709  47.841  1
214287  98.739  -76.721  47.811  1
214288  98.751  -76.734  47.781  1
214289  98.764  -76.746  47.750  1
214290  98.776  -76.758  47.719  1
214291  98.790  -76.766  47.687  1
214292  98.804  -76.773  47.655  1
214293  98.818  -76.780  47.623  1
214294  98.831  -76.774  47.591  1
214295  98.843  -76.759  47.560  1
214296  98.855  -76.743  47.528  1
214297  98.868  -76.729  47.496  1
214298  98.880  -76.714  47.464  1
214299  98.892  -76.699  47.429  1
214300  98.926  -76.703  47.394  1
214301  98.973  -76.718  47.359  1
214302  99.019  -76.733  47.323  1
214303  99.065  -76.747  47.285  1
214304  99.112  -76.762  47.247  1
214305  99.158  -76.777  47.210  1
214306  99.205  -76.791  47.176  1
214307  99.227  -76.793  47.141  1
214308  99.245  -76.793  47.105  1
214309  99.263  -76.793  47.069  1
214310  99.280  -76.802  47.034  1
214311  99.297  -76.815  46.997  1
214312  99.314  -76.827  46.961  1
214313  99.332  -76.839  46.924  1
214314  99.349  -76.851  46.887  1
214315  99.366  -76.864  46.852  1
214316  99.382  -76.876  46.818  1
214317  99.400  -76.888  46.785  1
214318  99.417  -76.900  46.753  1
214319  99.434  -76.912  46.720  1
214320  99.451  -76.925  46.687  1
214321  99.468  -76.937  46.655  1
214322  99.485  -76.950  46.625  1
214323  99.522  -76.953  46.595  1
214324  99.559  -76.957  46.564  1
214325  99.576  -76.980  46.532  1
214326  99.593  -77.000  46.502  1
214327  99.602  -76.997  46.472  1
214328  99.611  -76.994  46.442  1
214329  99.620  -76.991  46.415  1
214330  99.629  -76.988  46.387  1
214331  99.638  -76.985  46.361  1
214332  99.647  -76.982  46.335  1
214333  99.656  -76.980  46.310  1
214334  99.665  -76.977  46.285  1
214335  99.674  -76.974  46.260  1
214336  99.683  -76.972  46.236  1
214337  99.692  -76.969  46.214  1
214338  99.701  -76.965  46.191  1
214339  99.710  -76.963  46.168  1
214340  99.719  -76.961  46.145  1
214341  99.747  -76.953  46.122  1
214342  99.779  -76.943  46.101  1
214343  99.816  -76.942  46.080  1
214344  99.854  -76.942  46.060  1
214345  99.893  -76.942  46.038  1
214346  99.931  -76.942  46.017  1
214347  99.970  -76.942  45.997  1
214348  100.006  -76.938  45.978  1
214349  100.042  -76.931  45.959  1
214350  100.077  -76.925  45.941  1
214351  100.113  -76.918  45.923  1
214352  100.148  -76.911  45.905  1
214353  100.183  -76.944  45.887  1
214354  100.218  -76.997  45.870  1
214355  100.245  -77.025  45.852  1
214356  100.268  -77.038  45.836  1
214357  100.291  -77.047  45.820  1
214358  100.311  -77.063  45.803  1
214359  100.332  -77.077  45.786  1
214360  100.352  -77.092  45.769  1
214361  100.369  -77.110  45.752  1
214362  100.388  -77.128  45.735  1
214363  100.402  -77.143  45.718  1
214364  100.411  -77.156  45.703  1
214365  100.420  -77.169  45.688  1
214366  100.429  -77.182  45.673  1
214367  100.438  -77.195  45.660  1
214368  100.447  -77.208  45.647  1
214369  100.456  -77.222  45.634  1
214370  100.465  -77.235  45.621  1
214371  100.478  -77.249  45.607  1
214372  100.498  -77.267  45.594  1
214373  100.518  -77.285  45.581  1
214374  100.538  -77.303  45.568  1
214375  100.558  -77.321  45.555  1
214376  100.579  -77.338  45.542  1
214377  100.600  -77.356  45.530  1
214378  100.621  -77.373  45.517  1
214379  100.642  -77.390  45.506  1
214380  100.663  -77.407  45.494  1
214381  100.684  -77.425  45.482  1
214382  100.705  -77.442  45.471  1
214383  100.728  -77.462  45.460  1
214384  100.754  -77.477  45.448  1
214385  100.784  -77.483  45.437  1
214386  100.808  -77.486  45.425  1
214387  100.830  -77.488  45.412  1
214388  100.852  -77.490  45.399  1
214389  100.874  -77.492  45.387  1
214390  100.896  -77.495  45.373  1
214391  100.918  -77.497  45.360  1
214392  100.952  -77.525  45.346  1
214393  100.987  -77.555  45.333  1
214394  101.024  -77.576  45.319  1
214395  101.059  -77.592  45.305  1
214396  101.085  -77.602  45.291  1
214397  101.111  -77.611  45.277  1
214398  101.136  -77.620  45.262  1
214399  101.162  -77.630  45.247  1
214400  101.188  -77.639  45.231  1
214401  101.213  -77.648  45.217  1
214402  101.240  -77.657  45.200  1
214403  101.266  -77.666  45.184  1
214404  101.292  -77.675  45.168  1
214405  101.318  -77.684  45.153  1
214406  101.344  -77.693  45.137  1
214407  101.372  -77.706  45.120  1
214408  101.400  -77.723  45.104  1
214409  101.428  -77.739  45.087  1
214410  101.453  -77.754  45.072  1
214411  101.478  -77.769  45.056  1
214412  101.503  -77.784  45.040  1
214413  101.528  -77.799  45.023  1
214414  101.553  -77.815  45.007  1
214415  101.578  -77.830  44.990  1
214416  101.603  -77.846  44.973  1
214417  101.627  -77.861  44.958  1
214418  101.652  -77.876  44.943  1
214419  101.677  -77.891  44.928  1
214420  101.702  -77.906  44.913  1
214421  101.727  -77.921  44.896  1
214422  101.812  -77.925  44.880  1
214423  101.908  -77.924  44.863  1
214424  101.914  -77.934  44.847  1
214425  101.921  -77.944  44.831  1
214426  101.927  -77.954  44.814  1
214427  101.933  -77.964  44.799  1
214428  101.939  -77.974  44.783  1
214429  101.942  -77.985  44.768  1
214430  101.929  -78.006  44.753  1
214431  101.901  -78.012  44.739  1
214432  101.909  -78.021  44.725  1
214433  101.962  -78.035  44.710  1
214434  101.997  -78.046  44.693  1
214435  102.032  -78.057  44.677  1
214436  102.067  -78.069  44.660  1
214437  102.102  -78.080  44.645  1
214438  102.137  -78.091  44.630  1
214439  102.172  -78.102  44.613  1
214440  102.207  -78.113  44.599  1
214441  102.242  -78.124  44.584  1
214442  102.276  -78.135  44.569  1
214443  102.309  -78.148  44.556  1
214444  102.338  -78.161  44.541  1
214445  102.364  -78.175  44.527  1
214446  102.395  -78.174  44.513  1
214447  102.427  -78.168  44.498  1
214448  102.459  -78.162  44.482  1
214449  102.490  -78.156  44.467  1
214450  102.522  -78.150  44.451  1
214451  102.553  -78.142  44.436  1
214452  102.581  -78.131  44.422  1
214453  102.611  -78.126  44.407  1
214454  102.641  -78.127  44.393  1
214455  102.672  -78.128  44.379  1
214456  102.702  -78.128  44.364  1
214457  102.736  -78.141  44.350  1
214458  102.766  -78.183  44.335  1
214459  102.802  -78.257  44.319  1
214460  102.844  -78.261  44.303  1
214461  102.886  -78.260  44.287  1
214462  102.926  -78.264  44.270  1
214463  102.963  -78.278  44.254  1
214464  103.000  -78.291  44.237  1
214465  103.037  -78.305  44.220  1
214466  103.074  -78.319  44.203  1
214467  103.110  -78.332  44.186  1
214468  103.148  -78.346  44.169  1
214469  103.184  -78.360  44.151  1
214470  103.221  -78.373  44.133  1
214471  103.258  -78.387  44.115  1
214753  93.323  -75.634  53.906  1
214754  93.342  -75.637  53.914  1
214755  93.360  -75.640  53.928  1
214756  93.378  -75.644  53.944  1
214757  93.397  -75.647  53.962  1
214758  93.415  -75.650  53.984  1
214759  93.433  -75.654  54.006  1
214760  93.451  -75.657  54.030  1
214761  93.470  -75.660  54.057  1
214762  93.493  -75.659  54.086  1
214763  93.516  -75.659  54.118  1
214764  93.539  -75.657  54.154  1
214765  93.574  -75.656  54.190  1
214766  93.625  -75.640  54.216  1
214767  93.655  -75.634  54.242  1
214768  93.685  -75.629  54.266  1
214769  93.714  -75.624  54.290  1
214770  93.744  -75.618  54.313  1
214771  93.774  -75.613  54.337  1
214772  93.803  -75.608  54.360  1
214773  93.833  -75.602  54.376  1
214774  93.863  -75.598  54.389  1
214775  93.893  -75.593  54.401  1
214776  93.922  -75.587  54.412  1
214777  93.952  -75.582  54.418  1
214778  93.980  -75.577  54.417  1
214779  94.004  -75.576  54.408  1
214780  94.029  -75.574  54.391  1
214781  94.053  -75.572  54.369  1
214782  94.077  -75.570  54.348  1
214783  94.101  -75.568  54.331  1
214784  94.125  -75.567  54.317  1
214785  94.149  -75.565  54.304  1
214786  94.173  -75.563  54.285  1
214787  94.197  -75.565  54.265  1
214788  94.221  -75.566  54.243  1
214789  94.246  -75.568  54.225  1
214790  94.270  -75.569  54.211  1
214791  94.294  -75.571  54.199  1
214792  94.318  -75.573  54.191  1
214793  94.343  -75.574  54.181  1
214794  94.362  -75.577  54.168  1
214795  94.373  -75.584  54.152  1
214796  94.385  -75.591  54.134  1
214797  94.396  -75.597  54.118  1
214798  94.408  -75.604  54.103  1
214799  94.419  -75.611  54.086  1
214800  94.431  -75.618  54.065  1
214801  94.443  -75.624  54.039  1
214802  94.455  -75.630  54.011  1
214803  94.468  -75.636  53.981  1
214804  94.480  -75.641  53.950  1
214805  94.496  -75.647  53.921  1
214806  94.517  -75.652  53.890  1
214807  94.542  -75.651  53.856  1
214808  94.567  -75.650  53.823  1
214809  94.593  -75.649  53.789  1
214810  94.619  -75.648  53.752  1
214811  94.644  -75.647  53.714  1
214812  94.670  -75.646  53.674  1
214813  94.695  -75.645  53.632  1
214814  94.714  -75.645  53.589  1
214815  94.705  -75.647  53.548  1
214816  94.695  -75.650  53.508  1
214817  94.686  -75.652  53.469  1
214818  94.677  -75.656  53.432  1
214819  94.677  -75.658  53.396  1
214820  94.686  -75.661  53.358  1
214821  94.695  -75.664  53.318  1
214822  94.704  -75.666  53.278  1
214823  94.713  -75.669  53.237  1
214824  94.721  -75.671  53.196  1
214825  94.731  -75.674  53.155  1
214826  94.739  -75.677  53.113  1
214827  94.748  -75.680  53.067  1
214828  94.757  -75.682  53.020  1
214829  94.766  -75.685  52.976  1
214830  94.775  -75.687  52.936  1
214831  94.783  -75.690  52.906  1
214832  94.792  -75.693  52.879  1
214833  94.801  -75.696  52.852  1
214834  94.819  -75.700  52.821  1
214835  94.849  -75.706  52.785  1
214836  94.879  -75.712  52.745  1
214837  94.909  -75.718  52.704  1
214838  94.939  -75.724  52.664  1
214839  94.966  -75.728  52.623  1
214840  94.991  -75.731  52.582  1
214841  95.021  -75.738  52.543  1
214842  95.055  -75.749  52.505  1
214843  95.089  -75.760  52.466  1
214844  95.123  -75.771  52.428  1
214845  95.158  -75.782  52.391  1
214846  95.205  -75.787  52.355  1
214847  95.263  -75.789  52.317  1
214848  95.320  -75.790  52.279  1
214849  95.377  -75.792  52.240  1
214850  95.435  -75.793  52.199  1
214851  95.491  -75.795  52.155  1
214852  95.514  -75.773  52.110  1
214853  95.526  -75.744  52.067  1
214854  95.538  -75.724  52.024  1
214855  95.549  -75.740  51.982  1
214856  95.561  -75.756  51.941  1
214857  95.572  -75.772  51.900  1
214858  95.583  -75.788  51.860  1
214859  95.594  -75.805  51.819  1
214860  95.606  -75.821  51.778  1
214861  95.617  -75.837  51.740  1
214862  95.628  -75.853  51.701  1
214863  95.639  -75.868  51.665  1
214864  95.649  -75.875  51.631  1
214865  95.659  -75.881  51.598  1
214866  95.676  -75.887  51.567  1
214867  95.706  -75.889  51.536  1
214868  95.747  -75.889  51.507  1
214869  95.794  -75.889  51.479  1
214870  95.844  -75.890  51.450  1
214871  95.894  -75.890  51.420  1
214872  95.939  -75.891  51.389  1
214873  95.971  -75.895  51.355  1
214874  96.001  -75.897  51.321  1
214875  96.025  -75.894  51.287  1
214876  96.075  -75.892  51.250  1
214877  96.169  -75.883  51.212  1
214878  96.181  -75.887  51.173  1
214879  96.193  -75.891  51.135  1
214880  96.205  -75.894  51.096  1
214881  96.213  -75.897  51.060  1
214882  96.216  -75.897  51.023  1
214883  96.219  -75.897  50.988  1
214884  96.222  -75.897  50.953  1
214885  96.242  -75.903  50.920  1
214886  96.262  -75.910  50.888  1
214887  96.283  -75.917  50.859  1
214888  96.304  -75.927  50.832  1
214889  96.326  -75.938  50.806  1
214890  96.348  -75.950  50.781  1
214891  96.371  -75.960  50.756  1
214892  96.393  -75.972  50.729  1
214893  96.415  -75.983  50.702  1
214894  96.437  -75.994  50.677  1
214895  96.459  -76.005  50.653  1
214896  96.477  -76.018  50.628  1
214897  96.493  -76.032  50.606  1
214898  96.509  -76.047  50.584  1
214899  96.509  -76.067  50.562  1
214900  96.508  -76.088  50.541  1
214901  96.519  -76.099  50.522  1
214902  96.520  -76.109  50.501  1
214903  96.521  -76.118  50.478  1
214904  96.564  -76.132  50.452  1
214905  96.605  -76.141  50.426  1
214906  96.639  -76.141  50.397  1
214907  96.668  -76.139  50.367  1
214908  96.697  -76.138  50.334  1
214909  96.726  -76.137  50.300  1
214910  96.754  -76.137  50.264  1
214911  96.781  -76.139  50.225  1
214912  96.806  -76.144  50.185  1
214913  96.826  -76.157  50.143  1
214914  96.845  -76.171  50.101  1
214915  96.865  -76.185  50.061  1
214916  96.884  -76.199  50.020  1
214917  96.903  -76.213  49.981  1
214918  96.923  -76.226  49.944  1
214919  96.943  -76.240  49.907  1
214920  96.969  -76.248  49.871  1
214921  96.997  -76.254  49.836  1
214922  97.024  -76.260  49.802  1
214923  97.052  -76.267  49.767  1
214924  97.080  -76.273  49.732  1
214925  97.121  -76.284  49.698  1
214926  97.168  -76.296  49.664  1
214927  97.215  -76.309  49.633  1
214928  97.235  -76.317  49.603  1
214929  97.175  -76.308  49.574  1
214930  97.218  -76.314  49.544  1
214931  97.260  -76.320  49.515  1
214932  97.303  -76.326  49.487  1
214933  97.346  -76.332  49.458  1
214934  97.387  -76.340  49.428  1
214935  97.428  -76.358  49.398  1
214936  97.468  -76.376  49.369  1
214937  97.500  -76.364  49.340  1
214938  97.526  -76.360  49.312  1
214939  97.542  -76.369  49.283  1
214940  97.558  -76.378  49.254  1
214941  97.574  -76.387  49.226  1
214942  97.589  -76.397  49.196  1
214943  97.593  -76.410  49.168  1
214944  97.598  -76.423  49.141  1
214945  97.602  -76.436  49.117  1
214946  97.607  -76.450  49.092  1
214947  97.611  -76.463  49.066  1
214948  97.625  -76.476  49.039  1
214949  97.648  -76.488  49.012  1
214950  97.672  -76.499  48.983  1
214951  97.696  -76.511  48.954  1
214952  97.720  -76.524  48.924  1
214953  97.743  -76.535  48.892  1
214954  97.768  -76.547  48.860  1
214955  97.827  -76.552  48.827  1
214956  97.896  -76.556  48.792  1
214957  97.965  -76.559  48.757  1
214958  98.034  -76.563  48.720  1
214959  98.103  -76.567  48.684  1
214960  98.163  -76.573  48.648  1
214961  98.206  -76.586  48.613  1
214962  98.249  -76.611  48.577  1
214963  98.249  -76.614  48.540  1
214964  98.259  -76.613  48.504  1
214965  98.269  -76.612  48.469  1
214966  98.279  -76.612  48.436  1
214967  98.288  -76.611  48.404  1
214968  98.298  -76.611  48.372  1
214969  98.301  -76.614  48.343  1
214970  98.318  -76.621  48.313  1
214971  98.348  -76.621  48.285  1
214972  98.376  -76.624  48.258  1
214973  98.404  -76.625  48.231  1
214974  98.433  -76.627  48.204  1
214975  98.461  -76.630  48.177  1
214976  98.490  -76.631  48.149  1
214977  98.518  -76.633  48.122  1
214978  98.547  -76.636  48.096  1
214979  98.575  -76.637  48.070  1
214980  98.603  -76.640  48.044  1
214981  98.632  -76.642  48.017  1
214982  98.660  -76.643  47.989  1
214983  98.689  -76.646  47.961  1
214984  98.712  -76.652  47.934  1
214985  98.724  -76.664  47.905  1
214986  98.736  -76.675  47.876  1
214987  98.748  -76.687  47.847  1
214988  98.761  -76.699  47.817  1
214989  98.773  -76.712  47.788  1
214990  98.785  -76.724  47.757  1
214991  98.797  -76.736  47.725  1
214992  98.810  -76.748  47.693  1
214993  98.823  -76.757  47.661  1
214994  98.837  -76.759  47.629  1
214995  98.849  -76.744  47.596  1
214996  98.861  -76.730  47.566  1
214997  98.873  -76.718  47.535  1
214998  98.885  -76.708  47.503  1
214999  98.898  -76.697  47.470  1
215000  98.910  -76.687  47.437  1
215001  98.935  -76.696  47.401  1
215002  98.982  -76.712  47.364  1
215003  99.028  -76.727  47.328  1
215004  99.075  -76.742  47.290  1
215005  99.122  -76.756  47.252  1
215006  99.168  -76.771  47.213  1
215007  99.214  -76.786  47.177  1
215008  99.240  -76.790  47.140  1
215009  99.258  -76.790  47.104  1
215010  99.276  -76.790  47.069  1
215011  99.294  -76.789  47.033  1
215012  99.311  -76.789  46.997  1
215013  99.329  -76.799  46.960  1
215014  99.346  -76.811  46.923  1
215015  99.363  -76.824  46.886  1
215016  99.380  -76.836  46.851  1
215017  99.397  -76.848  46.816  1
215018  99.414  -76.860  46.783  1
215019  99.431  -76.872  46.750  1
215020  99.448  -76.885  46.718  1
215021  99.465  -76.897  46.685  1
215022  99.482  -76.909  46.653  1
215023  99.507  -76.918  46.622  1
215024  99.548  -76.920  46.591  1
215025  99.566  -76.940  46.559  1
215026  99.583  -76.963  46.527  1
215027  99.597  -76.975  46.497  1
215028  99.606  -76.972  46.467  1
215029  99.615  -76.969  46.437  1
215030  99.624  -76.966  46.410  1
215031  99.633  -76.963  46.383  1
215032  99.642  -76.960  46.357  1
215033  99.651  -76.958  46.332  1
215034  99.660  -76.955  46.307  1
215035  99.669  -76.952  46.282  1
215036  99.679  -76.950  46.258  1
215037  99.688  -76.947  46.235  1
215038  99.697  -76.943  46.212  1
215039  99.706  -76.940  46.188  1
215040  99.714  -76.938  46.165  1
215041  99.728  -76.937  46.141  1
215042  99.761  -76.942  46.118  1
215043  99.801  -76.942  46.095  1
215044  99.840  -76.942  46.074  1
215045  99.878  -76.942  46.053  1
215046  99.917  -76.942  46.031  1
215047  99.955  -76.942  46.010  1
215048  99.994  -76.942  45.990  1
215049  100.032  -76.942  45.970  1
215050  100.069  -76.940  45.952  1
215051  100.105  -76.933  45.933  1
215052  100.140  -76.926  45.915  1
215053  100.176  -76.919  45.897  1
215054  100.210  -76.972  45.879  1
215055  100.238  -77.001  45.862  1
215056  100.261  -77.016  45.845  1
215057  100.284  -77.025  45.829  1
215058  100.307  -77.035  45.813  1
215059  100.327  -77.050  45.796  1
215060  100.348  -77.064  45.778  1
215061  100.367  -77.080  45.761  1
215062  100.385  -77.098  45.744  1
215063  100.403  -77.116  45.728  1
215064  100.421  -77.134  45.712  1
215065  100.430  -77.147  45.695  1
215066  100.439  -77.160  45.680  1
215067  100.448  -77.172  45.665  1
215068  100.457  -77.186  45.651  1
215069  100.466  -77.199  45.639  1
215070  100.475  -77.212  45.626  1
215071  100.484  -77.226  45.613  1
215072  100.499  -77.241  45.600  1
215073  100.519  -77.258  45.587  1
215074  100.539  -77.276  45.574  1
215075  100.559  -77.294  45.561  1
215076  100.579  -77.312  45.548  1
215077  100.600  -77.330  45.536  1
215078  100.620  -77.348  45.524  1
215079  100.640  -77.366  45.511  1
215080  100.660  -77.384  45.500  1
215081  100.680  -77.402  45.488  1
215082  100.700  -77.420  45.476  1
215083  100.721  -77.437  45.465  1
215084  100.742  -77.454  45.454  1
215085  100.765  -77.471  45.442  1
215086  100.789  -77.475  45.431  1
215087  100.811  -77.477  45.419  1
215088  100.833  -77.479  45.406  1
215089  100.855  -77.482  45.393  1
215090  100.878  -77.484  45.381  1
215091  100.900  -77.486  45.367  1
215092  100.922  -77.489  45.353  1
215093  100.956  -77.513  45.339  1
215094  100.994  -77.530  45.326  1
215095  101.032  -77.548  45.312  1
215096  101.071  -77.566  45.298  1
215097  101.102  -77.580  45.284  1
215098  101.127  -77.589  45.270  1
215099  101.153  -77.598  45.254  1
215100  101.178  -77.608  45.239  1
215101  101.204  -77.617  45.223  1
215102  101.230  -77.627  45.208  1
215103  101.255  -77.636  45.192  1
215104  101.280  -77.645  45.175  1
215105  101.305  -77.655  45.159  1
215106  101.331  -77.664  45.144  1
215107  101.357  -77.674  45.127  1
215108  101.383  -77.689  45.111  1
215109  101.408  -77.705  45.094  1
215110  101.433  -77.720  45.076  1
215111  101.458  -77.735  45.061  1
215112  101.483  -77.750  45.045  1
215113  101.507  -77.765  45.029  1
215114  101.533  -77.780  45.012  1
215115  101.557  -77.796  44.996  1
215116  101.583  -77.812  44.979  1
215117  101.607  -77.827  44.962  1
215118  101.632  -77.842  44.947  1
215119  101.657  -77.857  44.931  1
215120  101.682  -77.872  44.916  1
215121  101.707  -77.887  44.900  1
215122  101.732  -77.902  44.884  1
215123  101.823  -77.905  44.868  1
215124  101.946  -77.901  44.851  1
215125  101.952  -77.911  44.835  1
215126  101.958  -77.921  44.819  1
215127  101.964  -77.931  44.803  1
215128  101.970  -77.940  44.786  1
215129  101.964  -77.957  44.771  1
215130  101.952  -77.978  44.755  1
215131  101.925  -77.986  44.741  1
215132  101.897  -77.990  44.727  1
215133  101.925  -78.002  44.712  1
215134  101.981  -78.015  44.696  1
215135  102.020  -78.028  44.680  1
215136  102.055  -78.039  44.664  1
215137  102.090  -78.050  44.648  1
215138  102.125  -78.061  44.633  1
215139  102.160  -78.072  44.618  1
215140  102.195  -78.084  44.603  1
215141  102.230  -78.094  44.588  1
215142  102.261  -78.108  44.574  1
215143  102.291  -78.122  44.559  1
215144  102.321  -78.135  44.545  1
215145  102.349  -78.145  44.531  1
215146  102.371  -78.150  44.517  1
215147  102.400  -78.172  44.503  1
215148  102.430  -78.185  44.487  1
215149  102.463  -78.179  44.472  1
215150  102.494  -78.173  44.456  1
215151  102.526  -78.166  44.441  1
215152  102.558  -78.160  44.426  1
215153  102.590  -78.154  44.411  1
215154  102.621  -78.148  44.396  1
215155  102.653  -78.142  44.382  1
215156  102.685  -78.135  44.367  1
215157  102.717  -78.129  44.353  1
215158  102.732  -78.112  44.338  1
215159  102.751  -78.144  44.323  1
215160  102.809  -78.260  44.307  1
215161  102.851  -78.259  44.292  1
215162  102.893  -78.257  44.276  1
215163  102.935  -78.256  44.258  1
215164  102.976  -78.253  44.243  1
215165  103.017  -78.257  44.226  1
215166  103.054  -78.270  44.209  1
215167  103.091  -78.284  44.191  1
215168  103.127  -78.298  44.174  1
215169  103.164  -78.312  44.157  1
215170  103.201  -78.326  44.140  1
215171  103.238  -78.339  44.122  1
215172  103.275  -78.353  44.104  1
215455  93.333  -75.614  53.914  1
215456  93.352  -75.618  53.926  1
215457  93.370  -75.621  53.941  1
215458  93.389  -75.624  53.959  1
215459  93.407  -75.627  53.980  1
215460  93.425  -75.630  54.002  1
215461  93.445  -75.633  54.025  1
215462  93.468  -75.631  54.052  1
215463  93.491  -75.630  54.081  1
215464  93.515  -75.629  54.115  1
215465  93.538  -75.627  54.151  1
215466  93.572  -75.626  54.190  1
215467  93.620  -75.615  54.221  1
215468  93.666  -75.601  54.250  1
215469  93.696  -75.596  54.277  1
215470  93.726  -75.590  54.300  1
215471  93.756  -75.585  54.319  1
215472  93.785  -75.580  54.339  1
215473  93.815  -75.575  54.356  1
215474  93.844  -75.570  54.371  1
215475  93.874  -75.565  54.388  1
215476  93.904  -75.559  54.401  1
215477  93.933  -75.554  54.412  1
215478  93.957  -75.552  54.422  1
215479  93.979  -75.549  54.427  1
215480  94.003  -75.549  54.424  1
215481  94.028  -75.549  54.413  1
215482  94.052  -75.548  54.392  1
215483  94.075  -75.546  54.370  1
215484  94.100  -75.545  54.352  1
215485  94.124  -75.543  54.340  1
215486  94.148  -75.541  54.326  1
215487  94.172  -75.539  54.307  1
215488  94.196  -75.540  54.286  1
215489  94.220  -75.541  54.265  1
215490  94.244  -75.543  54.245  1
215491  94.268  -75.545  54.227  1
215492  94.292  -75.546  54.212  1
215493  94.318  -75.547  54.204  1
215494  94.343  -75.547  54.196  1
215495  94.364  -75.550  54.185  1
215496  94.376  -75.557  54.172  1
215497  94.387  -75.564  54.155  1
215498  94.398  -75.571  54.139  1
215499  94.410  -75.577  54.123  1
215500  94.421  -75.583  54.104  1
215501  94.433  -75.590  54.081  1
215502  94.445  -75.597  54.054  1
215503  94.456  -75.604  54.024  1
215504  94.467  -75.610  53.992  1
215505  94.480  -75.615  53.960  1
215506  94.494  -75.618  53.929  1
215507  94.518  -75.618  53.896  1
215508  94.543  -75.618  53.861  1
215509  94.569  -75.616  53.828  1
215510  94.594  -75.615  53.794  1
215511  94.620  -75.615  53.758  1
215512  94.645  -75.613  53.720  1
215513  94.671  -75.612  53.680  1
215514  94.696  -75.612  53.637  1
215515  94.716  -75.611  53.594  1
215516  94.707  -75.614  53.552  1
215517  94.698  -75.616  53.511  1
215518  94.688  -75.619  53.473  1
215519  94.679  -75.621  53.435  1
215520  94.670  -75.624  53.399  1
215521  94.669  -75.627  53.361  1
215522  94.678  -75.630  53.322  1
215523  94.687  -75.632  53.282  1
215524  94.696  -75.635  53.243  1
215525  94.704  -75.637  53.204  1
215526  94.713  -75.640  53.164  1
215527  94.722  -75.643  53.122  1
215528  94.731  -75.646  53.075  1
215529  94.740  -75.649  53.029  1
215530  94.749  -75.651  52.984  1
215531  94.758  -75.654  52.943  1
215532  94.766  -75.656  52.908  1
215533  94.775  -75.659  52.881  1
215534  94.797  -75.664  52.854  1
215535  94.827  -75.670  52.824  1
215536  94.857  -75.676  52.790  1
215537  94.888  -75.682  52.752  1
215538  94.918  -75.688  52.712  1
215539  94.947  -75.693  52.671  1
215540  94.972  -75.697  52.628  1
215541  94.998  -75.700  52.585  1
215542  95.027  -75.706  52.543  1
215543  95.060  -75.717  52.501  1
215544  95.095  -75.728  52.460  1
215545  95.129  -75.739  52.420  1
215546  95.163  -75.749  52.380  1
215547  95.197  -75.761  52.342  1
215548  95.241  -75.768  52.304  1
215549  95.299  -75.769  52.266  1
215550  95.356  -75.771  52.227  1
215551  95.413  -75.772  52.187  1
215552  95.470  -75.774  52.145  1
215553  95.505  -75.759  52.103  1
215554  95.517  -75.731  52.061  1
215555  95.529  -75.702  52.021  1
215556  95.541  -75.699  51.979  1
215557  95.552  -75.716  51.937  1
215558  95.563  -75.732  51.897  1
215559  95.574  -75.748  51.855  1
215560  95.586  -75.765  51.815  1
215561  95.597  -75.781  51.776  1
215562  95.608  -75.796  51.738  1
215563  95.619  -75.813  51.700  1
215564  95.630  -75.829  51.665  1
215565  95.641  -75.845  51.632  1
215566  95.652  -75.858  51.600  1
215567  95.667  -75.864  51.570  1
215568  95.709  -75.864  51.542  1
215569  95.759  -75.865  51.514  1
215570  95.809  -75.865  51.487  1
215571  95.860  -75.865  51.460  1
215572  95.906  -75.866  51.431  1
215573  95.937  -75.869  51.399  1
215574  95.967  -75.865  51.364  1
215575  96.005  -75.862  51.329  1
215576  96.042  -75.857  51.294  1
215577  96.095  -75.856  51.258  1
215578  96.172  -75.858  51.219  1
215579  96.199  -75.859  51.181  1
215580  96.206  -75.862  51.143  1
215581  96.209  -75.862  51.105  1
215582  96.212  -75.862  51.068  1
215583  96.215  -75.862  51.033  1
215584  96.218  -75.862  50.997  1
215585  96.236  -75.868  50.962  1
215586  96.256  -75.875  50.929  1
215587  96.276  -75.881  50.897  1
215588  96.297  -75.888  50.868  1
215589  96.318  -75.897  50.841  1
215590  96.340  -75.908  50.815  1
215591  96.362  -75.919  50.789  1
215592  96.384  -75.930  50.764  1
215593  96.406  -75.941  50.739  1
215594  96.428  -75.953  50.713  1
215595  96.450  -75.963  50.688  1
215596  96.471  -75.975  50.664  1
215597  96.487  -75.990  50.639  1
215598  96.504  -76.003  50.616  1
215599  96.520  -76.018  50.593  1
215600  96.524  -76.036  50.571  1
215601  96.524  -76.057  50.550  1
215602  96.523  -76.078  50.530  1
215603  96.536  -76.090  50.509  1
215604  96.539  -76.100  50.486  1
215605  96.558  -76.111  50.461  1
215606  96.599  -76.120  50.434  1
215607  96.633  -76.119  50.406  1
215608  96.663  -76.119  50.376  1
215609  96.692  -76.117  50.344  1
215610  96.720  -76.118  50.310  1
215611  96.746  -76.121  50.274  1
215612  96.773  -76.123  50.235  1
215613  96.796  -76.132  50.196  1
215614  96.815  -76.146  50.155  1
215615  96.834  -76.160  50.112  1
215616  96.854  -76.173  50.071  1
215617  96.873  -76.187  50.031  1
215618  96.893  -76.201  49.992  1
215619  96.921  -76.207  49.954  1
215620  96.949  -76.213  49.917  1
215621  96.977  -76.220  49.880  1
215622  97.005  -76.226  49.845  1
215623  97.033  -76.232  49.811  1
215624  97.061  -76.238  49.776  1
215625  97.089  -76.245  49.741  1
215626  97.119  -76.251  49.706  1
215627  97.166  -76.264  49.672  1
215628  97.212  -76.276  49.641  1
215629  97.218  -76.282  49.611  1
215630  97.196  -76.279  49.581  1
215631  97.239  -76.285  49.552  1
215632  97.281  -76.291  49.523  1
215633  97.324  -76.297  49.494  1
215634  97.366  -76.303  49.466  1
215635  97.409  -76.308  49.437  1
215636  97.451  -76.318  49.408  1
215637  97.491  -76.336  49.380  1
215638  97.524  -76.326  49.352  1
215639  97.541  -76.333  49.324  1
215640  97.558  -76.342  49.296  1
215641  97.574  -76.351  49.267  1
215642  97.590  -76.361  49.238  1
215643  97.604  -76.370  49.209  1
215644  97.608  -76.383  49.182  1
215645  97.612  -76.397  49.156  1
215646  97.617  -76.410  49.130  1
215647  97.621  -76.423  49.105  1
215648  97.626  -76.436  49.079  1
215649  97.631  -76.450  49.052  1
215650  97.654  -76.462  49.024  1
215651  97.678  -76.473  48.995  1
215652  97.702  -76.486  48.965  1
215653  97.725  -76.498  48.935  1
215654  97.749  -76.509  48.904  1
215655  97.782  -76.520  48.871  1
215656  97.851  -76.523  48.837  1
215657  97.920  -76.527  48.803  1
215658  97.989  -76.530  48.767  1
215659  98.058  -76.534  48.730  1
215660  98.114  -76.541  48.692  1
215661  98.158  -76.552  48.654  1
215662  98.202  -76.571  48.618  1
215663  98.244  -76.596  48.582  1
215664  98.271  -76.613  48.546  1
215665  98.262  -76.610  48.510  1
215666  98.272  -76.609  48.474  1
215667  98.282  -76.608  48.440  1
215668  98.291  -76.608  48.407  1
215669  98.301  -76.608  48.376  1
215670  98.314  -76.605  48.346  1
215671  98.337  -76.605  48.317  1
215672  98.357  -76.609  48.288  1
215673  98.383  -76.611  48.259  1
215674  98.412  -76.614  48.232  1
215675  98.440  -76.618  48.205  1
215676  98.468  -76.620  48.177  1
215677  98.497  -76.623  48.150  1
215678  98.525  -76.625  48.124  1
215679  98.554  -76.628  48.098  1
215680  98.583  -76.631  48.071  1
215681  98.611  -76.633  48.045  1
215682  98.640  -76.636  48.019  1
215683  98.668  -76.639  47.992  1
215684  98.697  -76.642  47.965  1
215685  98.715  -76.650  47.938  1
215686  98.722  -76.666  47.910  1
215687  98.730  -76.681  47.882  1
215688  98.744  -76.691  47.853  1
215689  98.759  -76.701  47.822  1
215690  98.774  -76.711  47.792  1
215691  98.788  -76.721  47.762  1
215692  98.802  -76.730  47.730  1
215693  98.817  -76.740  47.698  1
215694  98.835  -76.746  47.666  1
215695  98.854  -76.740  47.634  1
215696  98.867  -76.729  47.601  1
215697  98.879  -76.718  47.571  1
215698  98.891  -76.708  47.540  1
215699  98.903  -76.697  47.509  1
215700  98.915  -76.687  47.476  1
215701  98.928  -76.678  47.442  1
215702  98.951  -76.688  47.406  1
215703  98.990  -76.705  47.370  1
215704  99.038  -76.721  47.334  1
215705  99.084  -76.737  47.296  1
215706  99.131  -76.751  47.257  1
215707  99.178  -76.765  47.218  1
215708  99.224  -76.781  47.180  1
215709  99.253  -76.786  47.142  1
215710  99.271  -76.786  47.105  1
215711  99.288  -76.786  47.069  1
215712  99.306  -76.785  47.033  1
215713  99.324  -76.785  46.996  1
215714  99.342  -76.785  46.959  1
215715  99.360  -76.784  46.922  1
215716  99.377  -76.796  46.885  1
215717  99.394  -76.808  46.849  1
215718  99.411  -76.820  46.815  1
215719  99.428  -76.832  46.782  1
215720  99.445  -76.845  46.749  1
215721  99.462  -76.857  46.716  1
215722  99.479  -76.869  46.684  1
215723  99.496  -76.881  46.651  1
215724  99.533  -76.885  46.620  1
215725  99.556  -76.902  46.588  1
215726  99.573  -76.925  46.556  1
215727  99.590  -76.947  46.523  1
215728  99.601  -76.950  46.493  1
215729  99.610  -76.947  46.463  1
215730  99.619  -76.944  46.433  1
215731  99.628  -76.941  46.407  1
215732  99.637  -76.938  46.381  1
215733  99.646  -76.936  46.356  1
215734  99.655  -76.933  46.331  1
215735  99.664  -76.930  46.307  1
215736  99.674  -76.928  46.282  1
215737  99.683  -76.925  46.258  1
215738  99.692  -76.922  46.235  1
215739  99.701  -76.918  46.211  1
215740  99.710  -76.916  46.187  1
215741  99.732  -76.919  46.163  1
215742  99.753  -76.922  46.139  1
215743  99.784  -76.928  46.114  1
215744  99.816  -76.935  46.090  1
215745  99.854  -76.939  46.069  1
215746  99.896  -76.940  46.047  1
215747  99.937  -76.940  46.025  1
215748  99.979  -76.942  46.004  1
215749  100.017  -76.942  45.984  1
215750  100.056  -76.941  45.963  1
215751  100.095  -76.941  45.944  1
215752  100.132  -76.940  45.926  1
215753  100.168  -76.934  45.907  1
215754  100.203  -76.947  45.889  1
215755  100.231  -76.977  45.872  1
215756  100.253  -76.992  45.855  1
215757  100.276  -77.006  45.838  1
215758  100.300  -77.012  45.822  1
215759  100.323  -77.022  45.805  1
215760  100.343  -77.037  45.789  1
215761  100.363  -77.052  45.771  1
215762  100.382  -77.069  45.755  1
215763  100.400  -77.086  45.738  1
215764  100.418  -77.104  45.721  1
215765  100.436  -77.122  45.705  1
215766  100.450  -77.137  45.688  1
215767  100.459  -77.150  45.673  1
215768  100.468  -77.163  45.658  1
215769  100.477  -77.176  45.643  1
215770  100.486  -77.189  45.631  1
215771  100.495  -77.203  45.618  1
215772  100.504  -77.216  45.604  1
215773  100.519  -77.232  45.592  1
215774  100.540  -77.250  45.579  1
215775  100.560  -77.267  45.566  1
215776  100.580  -77.285  45.553  1
215777  100.600  -77.304  45.541  1
215778  100.620  -77.321  45.529  1
215779  100.640  -77.339  45.517  1
215780  100.661  -77.357  45.505  1
215781  100.681  -77.375  45.493  1
215782  100.701  -77.393  45.482  1
215783  100.721  -77.410  45.471  1
215784  100.741  -77.429  45.459  1
215785  100.761  -77.447  45.448  1
215786  100.787  -77.458  45.436  1
215787  100.809  -77.466  45.425  1
215788  100.830  -77.468  45.413  1
215789  100.852  -77.470  45.401  1
215790  100.874  -77.473  45.388  1
215791  100.896  -77.476  45.375  1
215792  100.917  -77.478  45.361  1
215793  100.939  -77.480  45.347  1
215794  100.966  -77.486  45.332  1
215795  101.002  -77.502  45.318  1
215796  101.041  -77.520  45.304  1
215797  101.079  -77.539  45.290  1
215798  101.118  -77.556  45.276  1
215799  101.144  -77.567  45.261  1
215800  101.170  -77.576  45.246  1
215801  101.195  -77.586  45.230  1
215802  101.220  -77.595  45.215  1
215803  101.246  -77.604  45.199  1
215804  101.272  -77.614  45.183  1
215805  101.297  -77.623  45.166  1
215806  101.323  -77.633  45.150  1
215807  101.334  -77.645  45.134  1
215808  101.347  -77.660  45.117  1
215809  101.378  -77.674  45.101  1
215810  101.408  -77.687  45.084  1
215811  101.438  -77.701  45.066  1
215812  101.463  -77.716  45.049  1
215813  101.488  -77.731  45.033  1
215814  101.513  -77.746  45.018  1
215815  101.537  -77.761  45.001  1
215816  101.562  -77.777  44.985  1
215817  101.587  -77.793  44.968  1
215818  101.612  -77.808  44.951  1
215819  101.637  -77.823  44.935  1
215820  101.662  -77.838  44.920  1
215821  101.687  -77.853  44.904  1
215822  101.711  -77.868  44.888  1
215823  101.737  -77.884  44.871  1
215824  101.833  -77.885  44.855  1
215825  101.958  -77.881  44.839  1
215826  101.989  -77.887  44.823  1
215827  101.995  -77.897  44.807  1
215828  101.999  -77.909  44.791  1
215829  101.986  -77.929  44.775  1
215830  101.974  -77.950  44.760  1
215831  101.950  -77.959  44.743  1
215832  101.921  -77.964  44.728  1
215833  101.892  -77.968  44.714  1
215834  101.941  -77.982  44.699  1
215835  101.997  -77.996  44.684  1
215836  102.043  -78.009  44.667  1
215837  102.079  -78.020  44.651  1
215838  102.113  -78.031  44.636  1
215839  102.148  -78.043  44.621  1
215840  102.183  -78.054  44.606  1
215841  102.213  -78.068  44.592  1
215842  102.243  -78.081  44.577  1
215843  102.274  -78.095  44.563  1
215844  102.304  -78.109  44.549  1
215845  102.334  -78.122  44.535  1
215846  102.360  -78.130  44.521  1
215847  102.382  -78.134  44.507  1
215848  102.407  -78.147  44.491  1
215849  102.437  -78.170  44.476  1
215850  102.467  -78.193  44.461  1
215851  102.498  -78.190  44.445  1
215852  102.530  -78.184  44.430  1
215853  102.561  -78.178  44.414  1
215854  102.594  -78.172  44.399  1
215855  102.625  -78.166  44.384  1
215856  102.657  -78.159  44.369  1
215857  102.689  -78.153  44.355  1
215858  102.721  -78.147  44.341  1
215859  102.736  -78.122  44.325  1
215860  102.761  -78.172  44.310  1
215861  102.816  -78.258  44.294  1
215862  102.858  -78.257  44.279  1
215863  102.899  -78.255  44.263  1
215864  102.941  -78.253  44.247  1
215865  102.983  -78.251  44.231  1
215866  103.025  -78.250  44.214  1
215867  103.067  -78.248  44.197  1
215868  103.108  -78.250  44.179  1
215869  103.144  -78.263  44.162  1
215870  103.181  -78.277  44.145  1
215871  103.219  -78.291  44.127  1
215872  103.255  -78.304  44.110  1
215873  103.292  -78.318  44.092  1
216156  93.325  -75.591  53.914  1
216157  93.344  -75.594  53.925  1
216158  93.362  -75.597  53.939  1
216159  93.380  -75.601  53.956  1
216160  93.399  -75.604  53.976  1
216161  93.420  -75.604  53.997  1
216162  93.444  -75.603  54.020  1
216163  93.467  -75.602  54.046  1
216164  93.490  -75.600  54.076  1
216165  93.513  -75.599  54.110  1
216166  93.537  -75.598  54.147  1
216167  93.571  -75.596  54.186  1
216168  93.614  -75.590  54.222  1
216169  93.667  -75.574  54.255  1
216170  93.707  -75.562  54.285  1
216171  93.737  -75.558  54.311  1
216172  93.767  -75.552  54.331  1
216173  93.796  -75.547  54.347  1
216174  93.826  -75.542  54.361  1
216175  93.855  -75.536  54.374  1
216176  93.885  -75.531  54.389  1
216177  93.911  -75.528  54.403  1
216178  93.933  -75.526  54.416  1
216179  93.956  -75.524  54.427  1
216180  93.978  -75.521  54.434  1
216181  94.002  -75.521  54.433  1
216182  94.026  -75.521  54.425  1
216183  94.050  -75.521  54.408  1
216184  94.074  -75.521  54.391  1
216185  94.099  -75.521  54.374  1
216186  94.123  -75.519  54.359  1
216187  94.147  -75.517  54.347  1
216188  94.171  -75.515  54.329  1
216189  94.195  -75.514  54.310  1
216190  94.219  -75.516  54.289  1
216191  94.243  -75.518  54.268  1
216192  94.267  -75.520  54.248  1
216193  94.293  -75.520  54.232  1
216194  94.319  -75.521  54.219  1
216195  94.344  -75.521  54.212  1
216196  94.366  -75.523  54.203  1
216197  94.378  -75.530  54.191  1
216198  94.389  -75.536  54.176  1
216199  94.400  -75.543  54.160  1
216200  94.412  -75.549  54.144  1
216201  94.423  -75.556  54.125  1
216202  94.435  -75.563  54.100  1
216203  94.448  -75.568  54.071  1
216204  94.462  -75.571  54.040  1
216205  94.476  -75.575  54.006  1
216206  94.489  -75.579  53.971  1
216207  94.503  -75.583  53.938  1
216208  94.521  -75.584  53.904  1
216209  94.545  -75.583  53.867  1
216210  94.570  -75.583  53.832  1
216211  94.596  -75.581  53.798  1
216212  94.621  -75.580  53.762  1
216213  94.646  -75.580  53.724  1
216214  94.672  -75.578  53.684  1
216215  94.698  -75.577  53.640  1
216216  94.719  -75.577  53.597  1
216217  94.709  -75.580  53.555  1
216218  94.700  -75.582  53.514  1
216219  94.691  -75.585  53.475  1
216220  94.681  -75.587  53.438  1
216221  94.672  -75.590  53.401  1
216222  94.663  -75.593  53.364  1
216223  94.661  -75.596  53.325  1
216224  94.670  -75.598  53.286  1
216225  94.679  -75.601  53.249  1
216226  94.687  -75.603  53.212  1
216227  94.696  -75.606  53.173  1
216228  94.705  -75.609  53.130  1
216229  94.714  -75.612  53.083  1
216230  94.722  -75.615  53.036  1
216231  94.732  -75.617  52.991  1
216232  94.741  -75.620  52.949  1
216233  94.749  -75.622  52.911  1
216234  94.775  -75.627  52.881  1
216235  94.805  -75.634  52.853  1
216236  94.835  -75.640  52.824  1
216237  94.865  -75.646  52.791  1
216238  94.896  -75.652  52.755  1
216239  94.926  -75.659  52.716  1
216240  94.954  -75.663  52.675  1
216241  94.979  -75.666  52.631  1
216242  95.005  -75.670  52.586  1
216243  95.032  -75.674  52.542  1
216244  95.066  -75.685  52.497  1
216245  95.100  -75.696  52.455  1
216246  95.134  -75.707  52.413  1
216247  95.168  -75.718  52.372  1
216248  95.202  -75.728  52.332  1
216249  95.236  -75.740  52.293  1
216250  95.277  -75.748  52.254  1
216251  95.334  -75.749  52.215  1
216252  95.392  -75.750  52.176  1
216253  95.449  -75.752  52.136  1
216254  95.495  -75.746  52.095  1
216255  95.507  -75.718  52.055  1
216256  95.520  -75.689  52.015  1
216257  95.532  -75.660  51.974  1
216258  95.543  -75.676  51.933  1
216259  95.554  -75.692  51.892  1
216260  95.565  -75.708  51.852  1
216261  95.577  -75.724  51.812  1
216262  95.588  -75.740  51.773  1
216263  95.599  -75.756  51.735  1
216264  95.610  -75.773  51.698  1
216265  95.621  -75.789  51.664  1
216266  95.632  -75.805  51.632  1
216267  95.645  -75.822  51.601  1
216268  95.676  -75.837  51.573  1
216269  95.722  -75.840  51.545  1
216270  95.774  -75.840  51.518  1
216271  95.825  -75.840  51.494  1
216272  95.873  -75.841  51.467  1
216273  95.909  -75.837  51.437  1
216274  95.947  -75.834  51.404  1
216275  95.984  -75.829  51.369  1
216276  96.022  -75.825  51.333  1
216277  96.060  -75.822  51.298  1
216278  96.115  -75.821  51.263  1
216279  96.182  -75.824  51.224  1
216280  96.202  -75.827  51.186  1
216281  96.205  -75.827  51.149  1
216282  96.207  -75.827  51.112  1
216283  96.210  -75.827  51.075  1
216284  96.213  -75.827  51.040  1
216285  96.229  -75.832  51.005  1
216286  96.249  -75.839  50.971  1
216287  96.270  -75.845  50.937  1
216288  96.290  -75.852  50.905  1
216289  96.310  -75.859  50.876  1
216290  96.331  -75.867  50.849  1
216291  96.353  -75.878  50.823  1
216292  96.375  -75.889  50.798  1
216293  96.397  -75.900  50.773  1
216294  96.419  -75.911  50.748  1
216295  96.442  -75.922  50.721  1
216296  96.463  -75.934  50.696  1
216297  96.481  -75.947  50.672  1
216298  96.498  -75.961  50.648  1
216299  96.514  -75.975  50.625  1
216300  96.530  -75.989  50.602  1
216301  96.540  -76.006  50.579  1
216302  96.539  -76.026  50.558  1
216303  96.539  -76.047  50.537  1
216304  96.538  -76.067  50.516  1
216305  96.548  -76.082  50.493  1
216306  96.557  -76.090  50.468  1
216307  96.593  -76.100  50.442  1
216308  96.628  -76.099  50.414  1
216309  96.658  -76.097  50.384  1
216310  96.684  -76.100  50.353  1
216311  96.711  -76.103  50.321  1
216312  96.738  -76.105  50.285  1
216313  96.764  -76.107  50.247  1
216314  96.785  -76.120  50.206  1
216315  96.804  -76.134  50.165  1
216316  96.823  -76.148  50.123  1
216317  96.846  -76.159  50.082  1
216318  96.874  -76.166  50.041  1
216319  96.901  -76.172  50.002  1
216320  96.930  -76.178  49.964  1
216321  96.957  -76.185  49.926  1
216322  96.985  -76.191  49.890  1
216323  97.013  -76.197  49.853  1
216324  97.041  -76.204  49.817  1
216325  97.069  -76.210  49.782  1
216326  97.097  -76.216  49.747  1
216327  97.125  -76.223  49.713  1
216328  97.163  -76.232  49.679  1
216329  97.210  -76.245  49.647  1
216330  97.201  -76.248  49.617  1
216331  97.217  -76.250  49.588  1
216332  97.260  -76.256  49.559  1
216333  97.302  -76.261  49.530  1
216334  97.345  -76.267  49.502  1
216335  97.387  -76.273  49.474  1
216336  97.430  -76.279  49.446  1
216337  97.472  -76.285  49.418  1
216338  97.514  -76.296  49.390  1
216339  97.541  -76.298  49.362  1
216340  97.557  -76.307  49.335  1
216341  97.573  -76.315  49.306  1
216342  97.589  -76.324  49.278  1
216343  97.605  -76.333  49.249  1
216344  97.618  -76.344  49.222  1
216345  97.623  -76.357  49.196  1
216346  97.628  -76.370  49.169  1
216347  97.632  -76.383  49.142  1
216348  97.636  -76.397  49.117  1
216349  97.641  -76.410  49.091  1
216350  97.645  -76.423  49.064  1
216351  97.660  -76.436  49.035  1
216352  97.683  -76.448  49.005  1
216353  97.707  -76.460  48.975  1
216354  97.731  -76.471  48.945  1
216355  97.755  -76.483  48.914  1
216356  97.805  -76.490  48.881  1
216357  97.874  -76.494  48.847  1
216358  97.943  -76.498  48.812  1
216359  98.012  -76.501  48.775  1
216360  98.066  -76.509  48.737  1
216361  98.110  -76.520  48.699  1
216362  98.153  -76.532  48.660  1
216363  98.197  -76.555  48.623  1
216364  98.240  -76.579  48.586  1
216365  98.283  -76.604  48.550  1
216366  98.272  -76.608  48.514  1
216367  98.275  -76.606  48.478  1
216368  98.285  -76.605  48.443  1
216369  98.298  -76.602  48.410  1
216370  98.319  -76.596  48.378  1
216371  98.339  -76.589  48.348  1
216372  98.365  -76.599  48.318  1
216373  98.388  -76.604  48.289  1
216374  98.409  -76.608  48.260  1
216375  98.426  -76.611  48.233  1
216376  98.448  -76.614  48.205  1
216377  98.477  -76.616  48.178  1
216378  98.505  -76.619  48.150  1
216379  98.533  -76.621  48.125  1
216380  98.562  -76.624  48.098  1
216381  98.591  -76.627  48.072  1
216382  98.619  -76.630  48.045  1
216383  98.648  -76.633  48.019  1
216384  98.676  -76.635  47.993  1
216385  98.705  -76.638  47.967  1
216386  98.722  -76.648  47.940  1
216387  98.728  -76.663  47.913  1
216388  98.735  -76.679  47.886  1
216389  98.742  -76.695  47.857  1
216390  98.749  -76.710  47.826  1
216391  98.763  -76.721  47.796  1
216392  98.777  -76.731  47.766  1
216393  98.794  -76.738  47.735  1
216394  98.819  -76.735  47.703  1
216395  98.845  -76.731  47.671  1
216396  98.871  -76.728  47.639  1
216397  98.884  -76.718  47.606  1
216398  98.897  -76.708  47.575  1
216399  98.909  -76.697  47.545  1
216400  98.921  -76.687  47.514  1
216401  98.933  -76.676  47.481  1
216402  98.948  -76.672  47.446  1
216403  98.968  -76.681  47.410  1
216404  99.000  -76.696  47.374  1
216405  99.046  -76.713  47.339  1
216406  99.094  -76.730  47.300  1
216407  99.140  -76.746  47.262  1
216408  99.187  -76.760  47.223  1
216409  99.233  -76.775  47.184  1
216410  99.265  -76.782  47.145  1
216411  99.283  -76.782  47.107  1
216412  99.301  -76.781  47.070  1
216413  99.319  -76.781  47.032  1
216414  99.337  -76.781  46.996  1
216415  99.355  -76.781  46.959  1
216416  99.372  -76.781  46.922  1
216417  99.391  -76.781  46.885  1
216418  99.408  -76.780  46.850  1
216419  99.425  -76.793  46.816  1
216420  99.442  -76.805  46.782  1
216421  99.460  -76.817  46.750  1
216422  99.477  -76.829  46.716  1
216423  99.493  -76.841  46.683  1
216424  99.517  -76.851  46.651  1
216425  99.546  -76.863  46.619  1
216426  99.563  -76.885  46.587  1
216427  99.580  -76.908  46.554  1
216428  99.596  -76.928  46.522  1
216429  99.605  -76.925  46.492  1
216430  99.614  -76.922  46.462  1
216431  99.623  -76.919  46.434  1
216432  99.632  -76.916  46.407  1
216433  99.641  -76.914  46.382  1
216434  99.650  -76.911  46.357  1
216435  99.659  -76.908  46.332  1
216436  99.668  -76.906  46.307  1
216437  99.678  -76.903  46.283  1
216438  99.687  -76.900  46.259  1
216439  99.696  -76.897  46.236  1
216440  99.714  -76.898  46.212  1
216441  99.735  -76.901  46.187  1
216442  99.757  -76.903  46.162  1
216443  99.779  -76.906  46.136  1
216444  99.810  -76.913  46.111  1
216445  99.842  -76.921  46.087  1
216446  99.873  -76.928  46.064  1
216447  99.905  -76.934  46.042  1
216448  99.946  -76.936  46.020  1
216449  99.988  -76.937  45.999  1
216450  100.030  -76.937  45.978  1
216451  100.071  -76.939  45.957  1
216452  100.113  -76.940  45.938  1
216453  100.155  -76.940  45.919  1
216454  100.195  -76.941  45.900  1
216455  100.223  -76.953  45.882  1
216456  100.246  -76.968  45.865  1
216457  100.269  -76.982  45.848  1
216458  100.292  -76.994  45.831  1
216459  100.317  -76.999  45.814  1
216460  100.339  -77.009  45.798  1
216461  100.359  -77.025  45.782  1
216462  100.379  -77.039  45.765  1
216463  100.397  -77.057  45.749  1
216464  100.415  -77.075  45.732  1
216465  100.433  -77.092  45.715  1
216466  100.451  -77.110  45.697  1
216467  100.469  -77.128  45.681  1
216468  100.478  -77.141  45.666  1
216469  100.487  -77.153  45.651  1
216470  100.496  -77.167  45.636  1
216471  100.505  -77.180  45.623  1
216472  100.514  -77.193  45.609  1
216473  100.523  -77.207  45.596  1
216474  100.540  -77.222  45.584  1
216475  100.560  -77.241  45.571  1
216476  100.580  -77.259  45.559  1
216477  100.601  -77.276  45.547  1
216478  100.621  -77.294  45.534  1
216479  100.641  -77.313  45.523  1
216480  100.661  -77.330  45.511  1
216481  100.681  -77.348  45.499  1
216482  100.701  -77.366  45.487  1
216483  100.721  -77.384  45.476  1
216484  100.742  -77.402  45.464  1
216485  100.763  -77.420  45.453  1
216486  100.790  -77.430  45.441  1
216487  100.817  -77.441  45.430  1
216488  100.838  -77.451  45.419  1
216489  100.859  -77.460  45.407  1
216490  100.881  -77.462  45.395  1
216491  100.903  -77.464  45.382  1
216492  100.924  -77.467  45.368  1
216493  100.946  -77.469  45.354  1
216494  100.968  -77.471  45.339  1
216495  100.992  -77.476  45.324  1
216496  101.021  -77.484  45.309  1
216497  101.049  -77.492  45.295  1
216498  101.088  -77.511  45.281  1
216499  101.126  -77.528  45.266  1
216500  101.161  -77.544  45.252  1
216501  101.187  -77.554  45.237  1
216502  101.212  -77.563  45.221  1
216503  101.238  -77.573  45.205  1
216504  101.263  -77.582  45.189  1
216505  101.288  -77.592  45.173  1
216506  101.307  -77.603  45.156  1
216507  101.311  -77.617  45.140  1
216508  101.314  -77.633  45.124  1
216509  101.331  -77.647  45.107  1
216510  101.362  -77.661  45.090  1
216511  101.393  -77.674  45.073  1
216512  101.423  -77.688  45.056  1
216513  101.454  -77.701  45.039  1
216514  101.485  -77.714  45.023  1
216515  101.516  -77.728  45.006  1
216516  101.542  -77.743  44.990  1
216517  101.567  -77.758  44.973  1
216518  101.592  -77.773  44.956  1
216519  101.617  -77.789  44.939  1
216520  101.642  -77.804  44.923  1
216521  101.667  -77.819  44.907  1
216522  101.692  -77.834  44.891  1
216523  101.716  -77.849  44.876  1
216524  101.741  -77.865  44.859  1
216525  101.843  -77.865  44.843  1
216526  101.969  -77.860  44.827  1
216527  102.026  -77.864  44.810  1
216528  102.022  -77.881  44.795  1
216529  102.009  -77.902  44.780  1
216530  101.996  -77.922  44.764  1
216531  101.974  -77.934  44.748  1
216532  101.945  -77.937  44.732  1
216533  101.916  -77.942  44.716  1
216534  101.901  -77.948  44.700  1
216535  101.958  -77.962  44.686  1
216536  102.013  -77.977  44.670  1
216537  102.066  -77.990  44.654  1
216538  102.101  -78.002  44.638  1
216539  102.135  -78.013  44.623  1
216540  102.165  -78.027  44.608  1
216541  102.196  -78.040  44.594  1
216542  102.226  -78.054  44.580  1
216543  102.256  -78.068  44.566  1
216544  102.287  -78.081  44.553  1
216545  102.317  -78.095  44.539  1
216546  102.347  -78.109  44.524  1
216547  102.371  -78.115  44.510  1
216548  102.393  -78.119  44.495  1
216549  102.415  -78.122  44.480  1
216550  102.444  -78.145  44.464  1
216551  102.474  -78.168  44.449  1
216552  102.503  -78.191  44.433  1
216553  102.534  -78.201  44.417  1
216554  102.565  -78.195  44.402  1
216555  102.597  -78.189  44.387  1
216556  102.629  -78.182  44.372  1
216557  102.661  -78.176  44.358  1
216558  102.693  -78.170  44.343  1
216559  102.725  -78.164  44.328  1
216560  102.745  -78.145  44.313  1
216561  102.772  -78.200  44.298  1
216562  102.822  -78.256  44.282  1
216563  102.864  -78.254  44.266  1
216564  102.906  -78.253  44.251  1
216565  102.948  -78.251  44.235  1
216566  102.989  -78.249  44.219  1
216567  103.032  -78.247  44.202  1
216568  103.074  -78.246  44.185  1
216569  103.115  -78.244  44.168  1
216570  103.157  -78.243  44.150  1
216571  103.198  -78.243  44.132  1
216572  103.235  -78.257  44.114  1
216573  103.272  -78.270  44.097  1
216857  93.317  -75.568  53.916  1
216858  93.336  -75.571  53.925  1
216859  93.354  -75.574  53.937  1
216860  93.372  -75.577  53.953  1
216861  93.396  -75.576  53.972  1
216862  93.419  -75.574  53.992  1
216863  93.442  -75.574  54.015  1
216864  93.466  -75.572  54.041  1
216865  93.489  -75.571  54.070  1
216866  93.512  -75.570  54.104  1
216867  93.536  -75.568  54.140  1
216868  93.570  -75.567  54.180  1
216869  93.609  -75.565  54.219  1
216870  93.661  -75.549  54.257  1
216871  93.714  -75.532  54.292  1
216872  93.748  -75.524  54.322  1
216873  93.778  -75.519  54.345  1
216874  93.807  -75.514  54.361  1
216875  93.837  -75.508  54.372  1
216876  93.865  -75.504  54.383  1
216877  93.887  -75.502  54.394  1
216878  93.910  -75.500  54.409  1
216879  93.932  -75.498  54.424  1
216880  93.955  -75.496  54.434  1
216881  93.977  -75.494  54.441  1
216882  94.001  -75.494  54.441  1
216883  94.025  -75.493  54.434  1
216884  94.049  -75.493  54.423  1
216885  94.073  -75.493  54.409  1
216886  94.097  -75.493  54.394  1
216887  94.121  -75.493  54.378  1
216888  94.145  -75.493  54.366  1
216889  94.170  -75.492  54.350  1
216890  94.194  -75.489  54.332  1
216891  94.218  -75.491  54.312  1
216892  94.242  -75.493  54.289  1
216893  94.268  -75.493  54.268  1
216894  94.293  -75.493  54.250  1
216895  94.319  -75.494  54.236  1
216896  94.345  -75.494  54.228  1
216897  94.368  -75.496  54.218  1
216898  94.380  -75.502  54.207  1
216899  94.391  -75.509  54.193  1
216900  94.403  -75.516  54.177  1
216901  94.416  -75.520  54.162  1
216902  94.429  -75.524  54.145  1
216903  94.443  -75.527  54.117  1
216904  94.457  -75.531  54.088  1
216905  94.471  -75.535  54.055  1
216906  94.484  -75.539  54.021  1
216907  94.498  -75.543  53.985  1
216908  94.511  -75.546  53.949  1
216909  94.529  -75.548  53.912  1
216910  94.546  -75.549  53.873  1
216911  94.571  -75.549  53.836  1
216912  94.597  -75.548  53.800  1
216913  94.622  -75.546  53.764  1
216914  94.648  -75.546  53.726  1
216915  94.673  -75.545  53.687  1
216916  94.699  -75.544  53.644  1
216917  94.721  -75.543  53.600  1
216918  94.712  -75.546  53.558  1
216919  94.702  -75.549  53.519  1
216920  94.693  -75.551  53.480  1
216921  94.684  -75.554  53.442  1
216922  94.674  -75.556  53.404  1
216923  94.665  -75.559  53.366  1
216924  94.655  -75.561  53.328  1
216925  94.652  -75.565  53.292  1
216926  94.662  -75.567  53.257  1
216927  94.670  -75.570  53.219  1
216928  94.679  -75.572  53.179  1
216929  94.688  -75.575  53.137  1
216930  94.697  -75.577  53.089  1
216931  94.705  -75.580  53.043  1
216932  94.714  -75.583  52.998  1
216933  94.723  -75.586  52.954  1
216934  94.753  -75.592  52.915  1
216935  94.783  -75.598  52.880  1
216936  94.814  -75.604  52.850  1
216937  94.844  -75.610  52.821  1
216938  94.874  -75.616  52.789  1
216939  94.904  -75.622  52.755  1
216940  94.934  -75.628  52.718  1
216941  94.961  -75.632  52.676  1
216942  94.986  -75.636  52.632  1
216943  95.012  -75.639  52.586  1
216944  95.038  -75.643  52.539  1
216945  95.071  -75.652  52.494  1
216946  95.105  -75.664  52.450  1
216947  95.139  -75.674  52.408  1
216948  95.174  -75.686  52.365  1
216949  95.207  -75.696  52.324  1
216950  95.242  -75.707  52.283  1
216951  95.276  -75.718  52.244  1
216952  95.313  -75.728  52.205  1
216953  95.370  -75.729  52.166  1
216954  95.427  -75.731  52.127  1
216955  95.485  -75.732  52.087  1
216956  95.498  -75.704  52.047  1
216957  95.510  -75.676  52.009  1
216958  95.522  -75.647  51.969  1
216959  95.534  -75.636  51.928  1
216960  95.545  -75.652  51.887  1
216961  95.556  -75.668  51.848  1
216962  95.567  -75.684  51.808  1
216963  95.579  -75.700  51.769  1
216964  95.590  -75.716  51.732  1
216965  95.601  -75.733  51.697  1
216966  95.616  -75.751  51.664  1
216967  95.640  -75.784  51.632  1
216968  95.659  -75.812  51.602  1
216969  95.700  -75.810  51.573  1
216970  95.726  -75.815  51.546  1
216971  95.778  -75.815  51.520  1
216972  95.830  -75.815  51.495  1
216973  95.878  -75.817  51.468  1
216974  95.905  -75.817  51.438  1
216975  95.948  -75.809  51.405  1
216976  95.991  -75.801  51.370  1
216977  96.034  -75.793  51.334  1
216978  96.077  -75.785  51.299  1
216979  96.122  -75.783  51.265  1
216980  96.168  -75.781  51.227  1
216981  96.217  -75.775  51.190  1
216982  96.203  -75.792  51.154  1
216983  96.206  -75.792  51.117  1
216984  96.209  -75.792  51.081  1
216985  96.223  -75.796  51.046  1
216986  96.243  -75.803  51.012  1
216987  96.263  -75.809  50.979  1
216988  96.284  -75.816  50.945  1
216989  96.304  -75.823  50.913  1
216990  96.324  -75.830  50.884  1
216991  96.344  -75.837  50.857  1
216992  96.367  -75.847  50.831  1
216993  96.389  -75.859  50.806  1
216994  96.411  -75.870  50.780  1
216995  96.433  -75.881  50.755  1
216996  96.455  -75.892  50.729  1
216997  96.475  -75.904  50.703  1
216998  96.491  -75.918  50.680  1
216999  96.508  -75.932  50.656  1
217000  96.524  -75.947  50.633  1
217001  96.540  -75.960  50.610  1
217002  96.555  -75.975  50.588  1
217003  96.555  -75.995  50.565  1
217004  96.554  -76.016  50.544  1
217005  96.554  -76.037  50.522  1
217006  96.553  -76.057  50.500  1
217007  96.559  -76.074  50.476  1
217008  96.587  -76.079  50.450  1
217009  96.622  -76.079  50.422  1
217010  96.649  -76.082  50.393  1
217011  96.676  -76.084  50.364  1
217012  96.703  -76.087  50.331  1
217013  96.730  -76.089  50.296  1
217014  96.754  -76.095  50.258  1
217015  96.773  -76.109  50.217  1
217016  96.798  -76.118  50.175  1
217017  96.826  -76.124  50.133  1
217018  96.854  -76.131  50.092  1
217019  96.882  -76.137  50.051  1
217020  96.910  -76.143  50.011  1
217021  96.938  -76.150  49.972  1
217022  96.966  -76.156  49.934  1
217023  96.994  -76.162  49.897  1
217024  97.022  -76.169  49.860  1
217025  97.049  -76.175  49.824  1
217026  97.078  -76.181  49.788  1
217027  97.105  -76.188  49.753  1
217028  97.133  -76.194  49.719  1
217029  97.161  -76.200  49.685  1
217030  97.208  -76.213  49.653  1
217031  97.195  -76.214  49.623  1
217032  97.238  -76.220  49.594  1
217033  97.281  -76.226  49.565  1
217034  97.323  -76.232  49.536  1
217035  97.366  -76.238  49.509  1
217036  97.408  -76.244  49.482  1
217037  97.451  -76.250  49.455  1
217038  97.494  -76.256  49.427  1
217039  97.533  -76.263  49.399  1
217040  97.557  -76.270  49.371  1
217041  97.573  -76.279  49.344  1
217042  97.589  -76.289  49.315  1
217043  97.605  -76.298  49.287  1
217044  97.621  -76.307  49.260  1
217045  97.633  -76.317  49.233  1
217046  97.638  -76.330  49.207  1
217047  97.642  -76.344  49.181  1
217048  97.647  -76.357  49.154  1
217049  97.651  -76.370  49.128  1
217050  97.656  -76.383  49.101  1
217051  97.660  -76.397  49.074  1
217052  97.665  -76.410  49.044  1
217053  97.689  -76.422  49.015  1
217054  97.713  -76.434  48.984  1
217055  97.737  -76.445  48.954  1
217056  97.760  -76.458  48.922  1
217057  97.829  -76.461  48.890  1
217058  97.898  -76.465  48.856  1
217059  97.967  -76.468  48.820  1
217060  98.018  -76.477  48.783  1
217061  98.062  -76.489  48.744  1
217062  98.105  -76.500  48.704  1
217063  98.149  -76.514  48.665  1
217064  98.192  -76.539  48.626  1
217065  98.235  -76.563  48.590  1
217066  98.278  -76.588  48.553  1
217067  98.295  -76.599  48.517  1
217068  98.283  -76.600  48.482  1
217069  98.303  -76.593  48.447  1
217070  98.323  -76.586  48.412  1
217071  98.344  -76.580  48.379  1
217072  98.364  -76.572  48.348  1
217073  98.393  -76.593  48.319  1
217074  98.416  -76.598  48.290  1
217075  98.439  -76.603  48.260  1
217076  98.460  -76.607  48.232  1
217077  98.478  -76.609  48.205  1
217078  98.496  -76.612  48.178  1
217079  98.513  -76.615  48.151  1
217080  98.541  -76.618  48.124  1
217081  98.570  -76.621  48.098  1
217082  98.598  -76.623  48.071  1
217083  98.627  -76.626  48.045  1
217084  98.656  -76.629  48.019  1
217085  98.684  -76.631  47.993  1
217086  98.713  -76.634  47.967  1
217087  98.728  -76.645  47.941  1
217088  98.735  -76.661  47.914  1
217089  98.741  -76.676  47.888  1
217090  98.748  -76.692  47.860  1
217091  98.756  -76.708  47.831  1
217092  98.764  -76.721  47.802  1
217093  98.779  -76.726  47.772  1
217094  98.804  -76.724  47.740  1
217095  98.830  -76.721  47.707  1
217096  98.856  -76.717  47.675  1
217097  98.881  -76.714  47.642  1
217098  98.902  -76.708  47.610  1
217099  98.914  -76.697  47.579  1
217100  98.926  -76.687  47.549  1
217101  98.939  -76.676  47.518  1
217102  98.951  -76.666  47.486  1
217103  98.967  -76.666  47.452  1
217104  98.987  -76.675  47.415  1
217105  99.016  -76.688  47.378  1
217106  99.053  -76.704  47.341  1
217107  99.101  -76.722  47.303  1
217108  99.150  -76.740  47.265  1
217109  99.196  -76.755  47.226  1
217110  99.243  -76.769  47.186  1
217111  99.278  -76.778  47.148  1
217112  99.296  -76.778  47.110  1
217113  99.313  -76.777  47.073  1
217114  99.332  -76.777  47.034  1
217115  99.349  -76.777  46.997  1
217116  99.367  -76.777  46.961  1
217117  99.385  -76.777  46.923  1
217118  99.403  -76.777  46.886  1
217119  99.421  -76.776  46.851  1
217120  99.439  -76.776  46.817  1
217121  99.456  -76.777  46.783  1
217122  99.474  -76.789  46.750  1
217123  99.491  -76.801  46.717  1
217124  99.508  -76.814  46.683  1
217125  99.535  -76.824  46.650  1
217126  99.552  -76.846  46.619  1
217127  99.569  -76.868  46.587  1
217128  99.586  -76.891  46.554  1
217129  99.600  -76.903  46.522  1
217130  99.610  -76.900  46.492  1
217131  99.619  -76.897  46.463  1
217132  99.628  -76.894  46.435  1
217133  99.637  -76.892  46.408  1
217134  99.646  -76.889  46.383  1
217135  99.654  -76.886  46.358  1
217136  99.663  -76.884  46.334  1
217137  99.673  -76.881  46.309  1
217138  99.682  -76.878  46.285  1
217139  99.696  -76.877  46.261  1
217140  99.717  -76.880  46.237  1
217141  99.739  -76.883  46.213  1
217142  99.761  -76.885  46.187  1
217143  99.782  -76.888  46.161  1
217144  99.805  -76.891  46.134  1
217145  99.837  -76.899  46.108  1
217146  99.868  -76.906  46.084  1
217147  99.900  -76.912  46.060  1
217148  99.931  -76.919  46.038  1
217149  99.962  -76.927  46.015  1
217150  99.997  -76.932  45.993  1
217151  100.039  -76.933  45.972  1
217152  100.080  -76.934  45.951  1
217153  100.122  -76.935  45.932  1
217154  100.164  -76.936  45.912  1
217155  100.206  -76.937  45.893  1
217156  100.239  -76.943  45.876  1
217157  100.262  -76.958  45.858  1
217158  100.284  -76.973  45.841  1
217159  100.308  -76.981  45.824  1
217160  100.333  -76.986  45.807  1
217161  100.354  -76.997  45.791  1
217162  100.375  -77.012  45.775  1
217163  100.395  -77.028  45.759  1
217164  100.412  -77.045  45.742  1
217165  100.430  -77.063  45.725  1
217166  100.449  -77.081  45.708  1
217167  100.467  -77.098  45.691  1
217168  100.484  -77.116  45.675  1
217169  100.497  -77.132  45.660  1
217170  100.506  -77.144  45.644  1
217171  100.515  -77.157  45.629  1
217172  100.525  -77.170  45.615  1
217173  100.534  -77.184  45.602  1
217174  100.543  -77.197  45.589  1
217175  100.561  -77.214  45.576  1
217176  100.581  -77.232  45.563  1
217177  100.602  -77.250  45.551  1
217178  100.622  -77.268  45.539  1
217179  100.642  -77.285  45.526  1
217180  100.662  -77.304  45.515  1
217181  100.682  -77.321  45.503  1
217182  100.702  -77.339  45.492  1
217183  100.722  -77.357  45.480  1
217184  100.743  -77.375  45.469  1
217185  100.765  -77.391  45.457  1
217186  100.792  -77.401  45.446  1
217187  100.819  -77.412  45.435  1
217188  100.846  -77.423  45.424  1
217189  100.868  -77.434  45.413  1
217190  100.889  -77.444  45.401  1
217191  100.909  -77.454  45.388  1
217192  100.931  -77.456  45.375  1
217193  100.953  -77.458  45.361  1
217194  100.975  -77.461  45.347  1
217195  100.997  -77.463  45.332  1
217196  101.019  -77.466  45.316  1
217197  101.048  -77.474  45.301  1
217198  101.075  -77.482  45.286  1
217199  101.104  -77.490  45.271  1
217200  101.134  -77.501  45.256  1
217201  101.173  -77.518  45.241  1
217202  101.203  -77.531  45.226  1
217203  101.229  -77.541  45.211  1
217204  101.255  -77.550  45.195  1
217205  101.279  -77.560  45.179  1
217206  101.283  -77.575  45.162  1
217207  101.286  -77.590  45.146  1
217208  101.290  -77.605  45.130  1
217209  101.294  -77.620  45.113  1
217210  101.316  -77.634  45.096  1
217211  101.346  -77.648  45.078  1
217212  101.377  -77.661  45.061  1
217213  101.408  -77.675  45.045  1
217214  101.439  -77.688  45.029  1
217215  101.469  -77.702  45.012  1
217216  101.500  -77.715  44.995  1
217217  101.531  -77.729  44.978  1
217218  101.561  -77.742  44.962  1
217219  101.592  -77.755  44.945  1
217220  101.622  -77.769  44.928  1
217221  101.646  -77.785  44.911  1
217222  101.672  -77.800  44.895  1
217223  101.696  -77.815  44.879  1
217224  101.722  -77.830  44.864  1
217225  101.746  -77.846  44.848  1
217226  101.854  -77.845  44.831  1
217227  101.979  -77.840  44.814  1
217228  102.017  -77.849  44.798  1
217229  102.032  -77.874  44.783  1
217230  102.019  -77.894  44.768  1
217231  101.998  -77.907  44.752  1
217232  101.974  -77.911  44.736  1
217233  101.961  -77.915  44.719  1
217234  101.972  -77.911  44.703  1
217235  102.013  -77.898  44.688  1
217236  102.051  -77.906  44.673  1
217237  102.075  -77.932  44.656  1
217238  102.082  -77.965  44.641  1
217239  102.118  -77.987  44.627  1
217240  102.148  -78.000  44.612  1
217241  102.178  -78.014  44.597  1
217242  102.208  -78.028  44.583  1
217243  102.239  -78.041  44.568  1
217244  102.269  -78.055  44.554  1
217245  102.300  -78.069  44.541  1
217246  102.330  -78.082  44.527  1
217247  102.360  -78.096  44.512  1
217248  102.382  -78.100  44.498  1
217249  102.404  -78.103  44.483  1
217250  102.426  -78.107  44.467  1
217251  102.451  -78.120  44.452  1
217252  102.481  -78.143  44.436  1
217253  102.511  -78.166  44.420  1
217254  102.540  -78.188  44.404  1
217255  102.570  -78.210  44.390  1
217256  102.601  -78.206  44.375  1
217257  102.633  -78.200  44.360  1
217258  102.665  -78.194  44.346  1
217259  102.696  -78.188  44.331  1
217260  102.728  -78.181  44.316  1
217261  102.754  -78.168  44.301  1
217262  102.783  -78.227  44.286  1
217263  102.829  -78.253  44.270  1
217264  102.871  -78.252  44.254  1
217265  102.912  -78.250  44.238  1
217266  102.954  -78.249  44.223  1
217267  102.996  -78.247  44.206  1
217268  103.038  -78.245  44.189  1
217269  103.080  -78.244  44.172  1
217270  103.122  -78.242  44.154  1
217271  103.164  -78.241  44.138  1
217272  103.206  -78.239  44.120  1
217273  103.247  -78.237  44.102  1
217274  103.289  -78.235  44.085  1
217559  93.328  -75.548  53.925  1
217560  93.348  -75.549  53.936  1
217561  93.371  -75.548  53.951  1
217562  93.395  -75.546  53.969  1
217563  93.418  -75.545  53.988  1
217564  93.441  -75.544  54.010  1
217565  93.465  -75.543  54.034  1
217566  93.488  -75.541  54.063  1
217567  93.511  -75.540  54.095  1
217568  93.535  -75.539  54.130  1
217569  93.569  -75.537  54.168  1
217570  93.608  -75.536  54.208  1
217571  93.656  -75.524  54.248  1
217572  93.709  -75.507  54.288  1
217573  93.759  -75.491  54.324  1
217574  93.789  -75.486  54.352  1
217575  93.819  -75.480  54.373  1
217576  93.841  -75.478  54.390  1
217577  93.864  -75.477  54.402  1
217578  93.886  -75.474  54.411  1
217579  93.908  -75.472  54.422  1
217580  93.931  -75.470  54.435  1
217581  93.953  -75.468  54.447  1
217582  93.976  -75.466  54.451  1
217583  94.000  -75.466  54.448  1
217584  94.024  -75.466  54.439  1
217585  94.048  -75.466  54.437  1
217586  94.072  -75.466  54.424  1
217587  94.096  -75.465  54.409  1
217588  94.120  -75.465  54.398  1
217589  94.144  -75.465  54.384  1
217590  94.168  -75.465  54.369  1
217591  94.192  -75.465  54.352  1
217592  94.217  -75.465  54.332  1
217593  94.243  -75.466  54.308  1
217594  94.269  -75.466  54.287  1
217595  94.294  -75.467  54.268  1
217596  94.320  -75.467  54.253  1
217597  94.345  -75.467  54.243  1
217598  94.370  -75.468  54.233  1
217599  94.384  -75.473  54.221  1
217600  94.397  -75.477  54.206  1
217601  94.411  -75.480  54.192  1
217602  94.425  -75.484  54.178  1
217603  94.438  -75.488  54.161  1
217604  94.452  -75.492  54.133  1
217605  94.466  -75.496  54.102  1
217606  94.479  -75.499  54.069  1
217607  94.493  -75.503  54.034  1
217608  94.507  -75.507  53.997  1
217609  94.521  -75.511  53.960  1
217610  94.537  -75.512  53.921  1
217611  94.555  -75.514  53.880  1
217612  94.572  -75.514  53.842  1
217613  94.598  -75.514  53.804  1
217614  94.624  -75.513  53.767  1
217615  94.649  -75.512  53.730  1
217616  94.675  -75.511  53.691  1
217617  94.700  -75.510  53.650  1
217618  94.723  -75.509  53.606  1
217619  94.714  -75.511  53.564  1
217620  94.705  -75.514  53.525  1
217621  94.695  -75.517  53.486  1
217622  94.686  -75.520  53.447  1
217623  94.677  -75.522  53.409  1
217624  94.667  -75.525  53.371  1
217625  94.657  -75.527  53.334  1
217626  94.648  -75.530  53.298  1
217627  94.644  -75.533  53.263  1
217628  94.653  -75.536  53.224  1
217629  94.662  -75.538  53.184  1
217630  94.671  -75.541  53.141  1
217631  94.680  -75.543  53.093  1
217632  94.688  -75.546  53.046  1
217633  94.701  -75.549  53.001  1
217634  94.731  -75.555  52.958  1
217635  94.761  -75.561  52.917  1
217636  94.791  -75.568  52.880  1
217637  94.822  -75.574  52.845  1
217638  94.852  -75.580  52.812  1
217639  94.882  -75.587  52.780  1
217640  94.912  -75.593  52.746  1
217641  94.942  -75.598  52.709  1
217642  94.968  -75.602  52.668  1
217643  94.993  -75.605  52.625  1
217644  95.019  -75.609  52.580  1
217645  95.045  -75.612  52.534  1
217646  95.076  -75.621  52.489  1
217647  95.111  -75.631  52.444  1
217648  95.145  -75.643  52.401  1
217649  95.179  -75.653  52.358  1
217650  95.213  -75.665  52.316  1
217651  95.247  -75.675  52.275  1
217652  95.281  -75.686  52.235  1
217653  95.315  -75.697  52.195  1
217654  95.349  -75.708  52.156  1
217655  95.406  -75.709  52.117  1
217656  95.463  -75.711  52.077  1
217657  95.488  -75.691  52.038  1
217658  95.500  -75.662  52.000  1
217659  95.513  -75.634  51.961  1
217660  95.525  -75.605  51.921  1
217661  95.536  -75.612  51.882  1
217662  95.547  -75.627  51.843  1
217663  95.559  -75.644  51.804  1
217664  95.570  -75.660  51.766  1
217665  95.587  -75.680  51.729  1
217666  95.617  -75.708  51.695  1
217667  95.629  -75.750  51.662  1
217668  95.641  -75.785  51.630  1
217669  95.683  -75.784  51.599  1
217670  95.725  -75.782  51.570  1
217671  95.767  -75.781  51.543  1
217672  95.782  -75.790  51.517  1
217673  95.834  -75.790  51.490  1
217674  95.886  -75.791  51.463  1
217675  95.900  -75.800  51.433  1
217676  95.932  -75.798  51.401  1
217677  95.975  -75.790  51.365  1
217678  96.018  -75.782  51.330  1
217679  96.061  -75.772  51.297  1
217680  96.108  -75.755  51.264  1
217681  96.154  -75.738  51.228  1
217682  96.200  -75.737  51.193  1
217683  96.206  -75.753  51.157  1
217684  96.205  -75.757  51.122  1
217685  96.216  -75.760  51.088  1
217686  96.237  -75.767  51.053  1
217687  96.257  -75.774  51.019  1
217688  96.277  -75.781  50.986  1
217689  96.298  -75.787  50.952  1
217690  96.318  -75.793  50.920  1
217691  96.338  -75.800  50.891  1
217692  96.359  -75.807  50.864  1
217693  96.380  -75.817  50.838  1
217694  96.402  -75.828  50.812  1
217695  96.424  -75.840  50.787  1
217696  96.446  -75.850  50.761  1
217697  96.468  -75.862  50.736  1
217698  96.485  -75.875  50.711  1
217699  96.502  -75.890  50.686  1
217700  96.518  -75.903  50.664  1
217701  96.534  -75.918  50.641  1
217702  96.550  -75.932  50.618  1
217703  96.566  -75.946  50.596  1
217704  96.571  -75.965  50.573  1
217705  96.570  -75.985  50.551  1
217706  96.570  -76.006  50.529  1
217707  96.570  -76.026  50.506  1
217708  96.590  -76.041  50.483  1
217709  96.659  -76.041  50.458  1
217710  96.700  -76.033  50.431  1
217711  96.706  -76.033  50.403  1
217712  96.716  -76.044  50.375  1
217713  96.726  -76.055  50.342  1
217714  96.736  -76.066  50.307  1
217715  96.751  -76.077  50.270  1
217716  96.779  -76.083  50.228  1
217717  96.806  -76.090  50.186  1
217718  96.834  -76.096  50.143  1
217719  96.862  -76.102  50.102  1
217720  96.890  -76.109  50.061  1
217721  96.918  -76.115  50.020  1
217722  96.946  -76.121  49.979  1
217723  96.974  -76.127  49.942  1
217724  97.002  -76.134  49.904  1
217725  97.030  -76.140  49.866  1
217726  97.058  -76.146  49.829  1
217727  97.086  -76.153  49.792  1
217728  97.113  -76.159  49.758  1
217729  97.142  -76.165  49.724  1
217730  97.169  -76.172  49.691  1
217731  97.205  -76.180  49.660  1
217732  97.217  -76.185  49.629  1
217733  97.259  -76.191  49.599  1
217734  97.302  -76.197  49.569  1
217735  97.344  -76.203  49.541  1
217736  97.387  -76.209  49.515  1
217737  97.426  -76.217  49.489  1
217738  97.464  -76.226  49.462  1
217739  97.502  -76.235  49.434  1
217740  97.532  -76.236  49.407  1
217741  97.565  -76.243  49.379  1
217742  97.588  -76.253  49.351  1
217743  97.604  -76.262  49.323  1
217744  97.621  -76.271  49.296  1
217745  97.637  -76.279  49.270  1
217746  97.648  -76.291  49.243  1
217747  97.653  -76.304  49.218  1
217748  97.657  -76.317  49.192  1
217749  97.661  -76.330  49.165  1
217750  97.666  -76.344  49.138  1
217751  97.670  -76.357  49.110  1
217752  97.675  -76.370  49.082  1
217753  97.679  -76.383  49.052  1
217754  97.695  -76.396  49.023  1
217755  97.718  -76.408  48.992  1
217756  97.742  -76.420  48.961  1
217757  97.784  -76.429  48.929  1
217758  97.853  -76.432  48.898  1
217759  97.922  -76.436  48.864  1
217760  97.970  -76.445  48.828  1
217761  98.013  -76.457  48.789  1
217762  98.057  -76.468  48.749  1
217763  98.100  -76.480  48.710  1
217764  98.144  -76.498  48.671  1
217765  98.187  -76.522  48.630  1
217766  98.230  -76.547  48.592  1
217767  98.281  -76.565  48.555  1
217768  98.266  -76.567  48.519  1
217769  98.288  -76.574  48.483  1
217770  98.319  -76.584  48.447  1
217771  98.349  -76.570  48.413  1
217772  98.369  -76.563  48.380  1
217773  98.399  -76.583  48.348  1
217774  98.422  -76.587  48.318  1
217775  98.445  -76.592  48.288  1
217776  98.467  -76.597  48.259  1
217777  98.490  -76.602  48.230  1
217778  98.511  -76.605  48.203  1
217779  98.529  -76.608  48.176  1
217780  98.547  -76.611  48.149  1
217781  98.565  -76.614  48.121  1
217782  98.583  -76.617  48.095  1
217783  98.606  -76.619  48.069  1
217784  98.635  -76.622  48.042  1
217785  98.664  -76.625  48.017  1
217786  98.692  -76.627  47.992  1
217787  98.721  -76.630  47.967  1
217788  98.734  -76.643  47.942  1
217789  98.741  -76.658  47.916  1
217790  98.748  -76.674  47.889  1
217791  98.756  -76.688  47.862  1
217792  98.768  -76.693  47.833  1
217793  98.781  -76.699  47.804  1
217794  98.795  -76.704  47.774  1
217795  98.816  -76.707  47.743  1
217796  98.841  -76.706  47.710  1
217797  98.866  -76.702  47.678  1
217798  98.892  -76.699  47.646  1
217799  98.918  -76.696  47.615  1
217800  98.932  -76.687  47.585  1
217801  98.944  -76.677  47.555  1
217802  98.956  -76.666  47.523  1
217803  98.969  -76.655  47.491  1
217804  98.987  -76.660  47.457  1
217805  99.006  -76.669  47.420  1
217806  99.033  -76.681  47.382  1
217807  99.065  -76.695  47.344  1
217808  99.109  -76.712  47.306  1
217809  99.157  -76.730  47.268  1
217810  99.206  -76.749  47.230  1
217811  99.253  -76.764  47.190  1
217812  99.290  -76.774  47.151  1
217813  99.308  -76.774  47.113  1
217814  99.326  -76.774  47.075  1
217815  99.344  -76.774  47.037  1
217816  99.362  -76.774  47.000  1
217817  99.380  -76.773  46.962  1
217818  99.398  -76.773  46.925  1
217819  99.416  -76.773  46.888  1
217820  99.433  -76.772  46.853  1
217821  99.451  -76.772  46.818  1
217822  99.469  -76.772  46.784  1
217823  99.487  -76.771  46.750  1
217824  99.505  -76.774  46.717  1
217825  99.525  -76.786  46.684  1
217826  99.542  -76.808  46.650  1
217827  99.559  -76.830  46.619  1
217828  99.576  -76.853  46.587  1
217829  99.593  -76.875  46.555  1
217830  99.605  -76.878  46.522  1
217831  99.614  -76.875  46.493  1
217832  99.623  -76.872  46.464  1
217833  99.632  -76.870  46.436  1
217834  99.641  -76.867  46.409  1
217835  99.650  -76.864  46.385  1
217836  99.659  -76.862  46.360  1
217837  99.668  -76.859  46.336  1
217838  99.678  -76.856  46.312  1
217839  99.700  -76.859  46.287  1
217840  99.721  -76.862  46.263  1
217841  99.743  -76.865  46.239  1
217842  99.764  -76.867  46.213  1
217843  99.786  -76.870  46.187  1
217844  99.807  -76.872  46.160  1
217845  99.832  -76.877  46.132  1
217846  99.863  -76.884  46.105  1
217847  99.894  -76.890  46.080  1
217848  99.926  -76.897  46.056  1
217849  99.957  -76.905  46.033  1
217850  99.988  -76.912  46.010  1
217851  100.020  -76.918  45.988  1
217852  100.051  -76.925  45.966  1
217853  100.089  -76.929  45.945  1
217854  100.131  -76.930  45.925  1
217855  100.173  -76.931  45.906  1
217856  100.214  -76.932  45.887  1
217857  100.254  -76.934  45.869  1
217858  100.277  -76.949  45.851  1
217859  100.299  -76.963  45.834  1
217860  100.324  -76.969  45.817  1
217861  100.349  -76.972  45.801  1
217862  100.370  -76.984  45.785  1
217863  100.391  -76.999  45.769  1
217864  100.410  -77.016  45.752  1
217865  100.427  -77.034  45.735  1
217866  100.445  -77.051  45.718  1
217867  100.464  -77.069  45.701  1
217868  100.482  -77.087  45.685  1
217869  100.499  -77.104  45.669  1
217870  100.517  -77.122  45.653  1
217871  100.526  -77.135  45.637  1
217872  100.535  -77.148  45.622  1
217873  100.544  -77.161  45.607  1
217874  100.553  -77.174  45.594  1
217875  100.562  -77.188  45.581  1
217876  100.582  -77.205  45.567  1
217877  100.602  -77.223  45.554  1
217878  100.622  -77.241  45.542  1
217879  100.642  -77.259  45.530  1
217880  100.662  -77.277  45.517  1
217881  100.683  -77.294  45.506  1
217882  100.703  -77.313  45.496  1
217883  100.723  -77.330  45.485  1
217884  100.743  -77.348  45.473  1
217885  100.767  -77.363  45.462  1
217886  100.794  -77.373  45.450  1
217887  100.822  -77.384  45.439  1
217888  100.849  -77.395  45.429  1
217889  100.876  -77.405  45.418  1
217890  100.898  -77.416  45.406  1
217891  100.919  -77.426  45.395  1
217892  100.939  -77.437  45.382  1
217893  100.960  -77.447  45.369  1
217894  100.982  -77.449  45.355  1
217895  101.003  -77.452  45.340  1
217896  101.025  -77.454  45.324  1
217897  101.047  -77.457  45.308  1
217898  101.075  -77.464  45.293  1
217899  101.103  -77.472  45.278  1
217900  101.130  -77.480  45.263  1
217901  101.159  -77.488  45.247  1
217902  101.186  -77.495  45.231  1
217903  101.219  -77.508  45.216  1
217904  101.246  -77.519  45.201  1
217905  101.255  -77.533  45.185  1
217906  101.259  -77.547  45.168  1
217907  101.263  -77.562  45.152  1
217908  101.267  -77.577  45.135  1
217909  101.270  -77.592  45.118  1
217910  101.274  -77.608  45.102  1
217911  101.300  -77.621  45.084  1
217912  101.331  -77.635  45.067  1
217913  101.361  -77.649  45.050  1
217914  101.392  -77.662  45.034  1
217915  101.423  -77.675  45.018  1
217916  101.454  -77.689  45.001  1
217917  101.484  -77.702  44.984  1
217918  101.515  -77.716  44.967  1
217919  101.546  -77.729  44.950  1
217920  101.576  -77.743  44.933  1
217921  101.607  -77.756  44.916  1
217922  101.638  -77.770  44.900  1
217923  101.669  -77.783  44.884  1
217924  101.699  -77.796  44.867  1
217925  101.726  -77.812  44.851  1
217926  101.751  -77.827  44.835  1
217927  101.845  -77.819  44.819  1
217928  101.934  -77.812  44.803  1
217929  101.957  -77.832  44.787  1
217930  101.983  -77.859  44.772  1
217931  102.009  -77.884  44.756  1
217932  101.998  -77.881  44.740  1
217933  102.004  -77.884  44.723  1
217934  102.009  -77.878  44.706  1
217935  102.021  -77.873  44.692  1
217936  102.042  -77.882  44.677  1
217937  102.036  -77.906  44.661  1
217938  102.050  -77.917  44.645  1
217939  102.081  -77.933  44.630  1
217940  102.130  -77.974  44.615  1
217941  102.161  -77.987  44.600  1
217942  102.191  -78.001  44.585  1
217943  102.222  -78.015  44.571  1
217944  102.252  -78.028  44.556  1
217945  102.282  -78.042  44.541  1
217946  102.313  -78.056  44.528  1
217947  102.343  -78.069  44.514  1
217948  102.372  -78.081  44.499  1
217949  102.393  -78.084  44.485  1
217950  102.415  -78.088  44.470  1
217951  102.437  -78.092  44.454  1
217952  102.459  -78.096  44.439  1
217953  102.488  -78.118  44.422  1
217954  102.518  -78.141  44.407  1
217955  102.547  -78.163  44.392  1
217956  102.577  -78.185  44.377  1
217957  102.606  -78.208  44.362  1
217958  102.636  -78.217  44.348  1
217959  102.669  -78.211  44.333  1
217960  102.700  -78.205  44.318  1
217961  102.732  -78.198  44.303  1
217962  102.763  -78.191  44.288  1
217963  102.794  -78.253  44.273  1
217964  102.835  -78.251  44.258  1
217965  102.877  -78.250  44.242  1
217966  102.919  -78.248  44.226  1
217967  102.961  -78.247  44.210  1
217968  103.003  -78.244  44.194  1
217969  103.045  -78.243  44.176  1
217970  103.087  -78.241  44.159  1
217971  103.128  -78.240  44.142  1
217972  103.170  -78.238  44.125  1
217973  103.212  -78.237  44.108  1
217974  103.254  -78.235  44.090  1
217975  103.296  -78.233  44.073  1
218218  92.394  -75.523  54.153  1
218219  92.418  -75.533  54.161  1
218220  92.440  -75.545  54.168  1
218221  92.454  -75.557  54.173  1
218222  92.465  -75.562  54.175  1
218223  92.486  -75.554  54.177  1
218224  92.506  -75.545  54.181  1
218260  93.324  -75.521  53.925  1
218261  93.347  -75.519  53.935  1
218262  93.370  -75.518  53.949  1
218263  93.394  -75.517  53.966  1
218264  93.417  -75.515  53.984  1
218265  93.440  -75.514  54.005  1
218266  93.464  -75.513  54.028  1
218267  93.487  -75.512  54.056  1
218268  93.510  -75.511  54.087  1
218269  93.534  -75.509  54.120  1
218270  93.568  -75.508  54.157  1
218271  93.607  -75.506  54.195  1
218272  93.650  -75.499  54.235  1
218273  93.703  -75.483  54.277  1
218274  93.756  -75.465  54.317  1
218275  93.795  -75.455  54.349  1
218276  93.818  -75.453  54.377  1
218277  93.840  -75.451  54.399  1
218278  93.862  -75.449  54.413  1
218279  93.885  -75.446  54.424  1
218280  93.907  -75.444  54.437  1
218281  93.929  -75.442  54.450  1
218282  93.952  -75.440  54.462  1
218283  93.974  -75.438  54.467  1
218284  93.998  -75.438  54.464  1
218285  94.023  -75.438  54.454  1
218286  94.047  -75.438  54.447  1
218287  94.071  -75.438  54.437  1
218288  94.095  -75.438  54.426  1
218289  94.119  -75.438  54.415  1
218290  94.142  -75.437  54.402  1
218291  94.166  -75.436  54.387  1
218292  94.189  -75.436  54.369  1
218293  94.215  -75.442  54.348  1
218294  94.241  -75.444  54.325  1
218295  94.267  -75.445  54.304  1
218296  94.292  -75.445  54.284  1
218297  94.318  -75.446  54.268  1
218298  94.343  -75.446  54.255  1
218299  94.368  -75.444  54.244  1
218300  94.390  -75.440  54.232  1
218301  94.406  -75.440  54.217  1
218302  94.420  -75.444  54.203  1
218303  94.433  -75.448  54.189  1
218304  94.447  -75.452  54.172  1
218305  94.461  -75.455  54.145  1
218306  94.475  -75.459  54.114  1
218307  94.488  -75.463  54.081  1
218308  94.502  -75.467  54.045  1
218309  94.516  -75.471  54.007  1
218310  94.530  -75.474  53.968  1
218311  94.546  -75.477  53.929  1
218312  94.563  -75.478  53.888  1
218313  94.581  -75.479  53.848  1
218314  94.599  -75.480  53.810  1
218315  94.625  -75.479  53.773  1
218316  94.650  -75.478  53.736  1
218317  94.676  -75.477  53.698  1
218318  94.701  -75.476  53.657  1
218319  94.726  -75.475  53.615  1
218320  94.716  -75.478  53.573  1
218321  94.707  -75.480  53.533  1
218322  94.698  -75.483  53.493  1
218323  94.688  -75.486  53.454  1
218324  94.679  -75.489  53.416  1
218325  94.670  -75.491  53.377  1
218326  94.660  -75.493  53.339  1
218327  94.650  -75.496  53.303  1
218328  94.641  -75.499  53.268  1
218329  94.636  -75.502  53.230  1
218330  94.645  -75.504  53.189  1
218331  94.653  -75.507  53.146  1
218332  94.663  -75.510  53.098  1
218333  94.679  -75.514  53.051  1
218334  94.709  -75.520  53.005  1
218335  94.740  -75.526  52.961  1
218336  94.770  -75.532  52.920  1
218337  94.800  -75.538  52.879  1
218338  94.830  -75.544  52.841  1
218339  94.860  -75.550  52.805  1
218340  94.891  -75.556  52.771  1
218341  94.921  -75.562  52.737  1
218342  94.949  -75.568  52.700  1
218343  94.974  -75.571  52.659  1
218344  95.000  -75.574  52.617  1
218345  95.026  -75.577  52.572  1
218346  95.052  -75.581  52.526  1
218347  95.082  -75.589  52.482  1
218348  95.116  -75.599  52.437  1
218349  95.150  -75.610  52.394  1
218350  95.184  -75.621  52.351  1
218351  95.218  -75.632  52.308  1
218352  95.252  -75.643  52.266  1
218353  95.286  -75.654  52.226  1
218354  95.321  -75.665  52.186  1
218355  95.354  -75.676  52.146  1
218356  95.389  -75.687  52.107  1
218357  95.442  -75.690  52.068  1
218358  95.479  -75.677  52.029  1
218359  95.491  -75.649  51.991  1
218360  95.503  -75.621  51.953  1
218361  95.516  -75.592  51.914  1
218362  95.527  -75.571  51.877  1
218363  95.539  -75.587  51.838  1
218364  95.557  -75.609  51.800  1
218365  95.588  -75.637  51.763  1
218366  95.618  -75.665  51.727  1
218367  95.617  -75.717  51.694  1
218368  95.624  -75.759  51.661  1
218369  95.666  -75.758  51.628  1
218370  95.708  -75.756  51.596  1
218371  95.750  -75.755  51.566  1
218372  95.791  -75.753  51.538  1
218373  95.833  -75.752  51.511  1
218374  95.838  -75.765  51.483  1
218375  95.890  -75.766  51.454  1
218376  95.914  -75.773  51.423  1
218377  95.922  -75.784  51.392  1
218378  95.959  -75.778  51.357  1
218379  96.002  -75.771  51.323  1
218380  96.048  -75.754  51.291  1
218381  96.094  -75.737  51.259  1
218382  96.140  -75.719  51.226  1
218383  96.186  -75.702  51.193  1
218384  96.205  -75.707  51.159  1
218385  96.210  -75.724  51.125  1
218386  96.230  -75.731  51.092  1
218387  96.250  -75.738  51.058  1
218388  96.271  -75.745  51.024  1
218389  96.291  -75.751  50.991  1
218390  96.311  -75.758  50.958  1
218391  96.332  -75.765  50.927  1
218392  96.352  -75.771  50.898  1
218393  96.372  -75.778  50.871  1
218394  96.393  -75.787  50.844  1
218395  96.415  -75.798  50.818  1
218396  96.438  -75.809  50.793  1
218397  96.460  -75.820  50.767  1
218398  96.479  -75.833  50.742  1
218399  96.496  -75.847  50.717  1
218400  96.512  -75.861  50.694  1
218401  96.528  -75.875  50.671  1
218402  96.544  -75.889  50.648  1
218403  96.560  -75.903  50.626  1
218404  96.576  -75.918  50.604  1
218405  96.587  -75.934  50.580  1
218406  96.586  -75.954  50.558  1
218407  96.586  -75.975  50.536  1
218408  96.589  -75.994  50.515  1
218409  96.659  -75.994  50.492  1
218410  96.709  -75.990  50.468  1
218411  96.749  -75.982  50.441  1
218412  96.783  -75.974  50.413  1
218413  96.800  -75.995  50.384  1
218414  96.837  -76.043  50.353  1
218415  96.810  -76.064  50.319  1
218416  96.772  -76.058  50.280  1
218417  96.799  -76.064  50.238  1
218418  96.825  -76.069  50.196  1
218419  96.852  -76.075  50.152  1
218420  96.879  -76.080  50.111  1
218421  96.906  -76.085  50.069  1
218422  96.933  -76.091  50.028  1
218423  96.960  -76.097  49.988  1
218424  96.986  -76.102  49.950  1
218425  97.013  -76.107  49.911  1
218426  97.040  -76.113  49.874  1
218427  97.067  -76.119  49.837  1
218428  97.094  -76.124  49.800  1
218429  97.122  -76.130  49.765  1
218430  97.150  -76.137  49.731  1
218431  97.178  -76.143  49.698  1
218432  97.206  -76.149  49.667  1
218433  97.238  -76.156  49.636  1
218434  97.279  -76.163  49.606  1
218435  97.317  -76.171  49.577  1
218436  97.356  -76.180  49.548  1
218437  97.394  -76.188  49.521  1
218438  97.432  -76.198  49.495  1
218439  97.470  -76.206  49.468  1
218440  97.501  -76.208  49.441  1
218441  97.531  -76.210  49.414  1
218442  97.564  -76.216  49.387  1
218443  97.597  -76.226  49.359  1
218444  97.620  -76.235  49.331  1
218445  97.637  -76.244  49.305  1
218446  97.653  -76.253  49.279  1
218447  97.663  -76.264  49.253  1
218448  97.667  -76.277  49.228  1
218449  97.672  -76.291  49.202  1
218450  97.676  -76.304  49.175  1
218451  97.680  -76.317  49.148  1
218452  97.685  -76.330  49.119  1
218453  97.689  -76.344  49.090  1
218454  97.694  -76.357  49.060  1
218455  97.700  -76.370  49.030  1
218456  97.724  -76.382  48.999  1
218457  97.748  -76.394  48.967  1
218458  97.808  -76.399  48.935  1
218459  97.877  -76.403  48.904  1
218460  97.922  -76.414  48.869  1
218461  97.965  -76.425  48.833  1
218462  98.009  -76.436  48.794  1
218463  98.052  -76.448  48.754  1
218464  98.096  -76.458  48.714  1
218465  98.139  -76.481  48.675  1
218466  98.182  -76.506  48.634  1
218467  98.232  -76.525  48.593  1
218468  98.263  -76.533  48.555  1
218469  98.261  -76.537  48.518  1
218470  98.293  -76.547  48.482  1
218471  98.325  -76.557  48.447  1
218472  98.357  -76.567  48.412  1
218473  98.394  -76.547  48.379  1
218474  98.427  -76.577  48.346  1
218475  98.450  -76.581  48.315  1
218476  98.473  -76.586  48.285  1
218477  98.496  -76.591  48.256  1
218478  98.519  -76.596  48.226  1
218479  98.541  -76.600  48.199  1
218480  98.563  -76.605  48.172  1
218481  98.581  -76.607  48.145  1
218482  98.598  -76.610  48.118  1
218483  98.617  -76.613  48.092  1
218484  98.634  -76.615  48.066  1
218485  98.652  -76.618  48.040  1
218486  98.672  -76.621  48.016  1
218487  98.700  -76.624  47.992  1
218488  98.729  -76.627  47.967  1
218489  98.740  -76.640  47.942  1
218490  98.747  -76.655  47.916  1
218491  98.760  -76.660  47.890  1
218492  98.773  -76.665  47.863  1
218493  98.786  -76.671  47.835  1
218494  98.798  -76.676  47.806  1
218495  98.811  -76.681  47.776  1
218496  98.832  -76.685  47.745  1
218497  98.854  -76.687  47.713  1
218498  98.877  -76.688  47.681  1
218499  98.903  -76.685  47.650  1
218500  98.928  -76.682  47.620  1
218501  98.950  -76.677  47.591  1
218502  98.962  -76.666  47.561  1
218503  98.974  -76.655  47.529  1
218504  98.987  -76.646  47.496  1
218505  99.006  -76.655  47.461  1
218506  99.025  -76.663  47.425  1
218507  99.050  -76.674  47.387  1
218508  99.082  -76.688  47.349  1
218509  99.117  -76.703  47.311  1
218510  99.165  -76.721  47.273  1
218511  99.213  -76.740  47.234  1
218512  99.261  -76.758  47.195  1
218513  99.303  -76.771  47.154  1
218514  99.321  -76.771  47.115  1
218515  99.339  -76.770  47.078  1
218516  99.357  -76.770  47.039  1
218517  99.375  -76.770  47.002  1
218518  99.393  -76.769  46.964  1
218519  99.411  -76.769  46.926  1
218520  99.429  -76.768  46.889  1
218521  99.447  -76.768  46.855  1
218522  99.466  -76.767  46.821  1
218523  99.484  -76.766  46.786  1
218524  99.502  -76.765  46.752  1
218525  99.521  -76.764  46.718  1
218526  99.532  -76.769  46.685  1
218527  99.549  -76.791  46.652  1
218528  99.566  -76.813  46.621  1
218529  99.583  -76.836  46.588  1
218530  99.600  -76.856  46.557  1
218531  99.609  -76.853  46.526  1
218532  99.618  -76.850  46.495  1
218533  99.627  -76.848  46.466  1
218534  99.636  -76.845  46.438  1
218535  99.645  -76.842  46.413  1
218536  99.654  -76.840  46.388  1
218537  99.663  -76.837  46.363  1
218538  99.682  -76.838  46.339  1
218539  99.703  -76.840  46.315  1
218540  99.725  -76.843  46.290  1
218541  99.747  -76.846  46.266  1
218542  99.768  -76.849  46.241  1
218543  99.789  -76.852  46.214  1
218544  99.811  -76.854  46.187  1
218545  99.832  -76.857  46.159  1
218546  99.858  -76.862  46.130  1
218547  99.889  -76.868  46.103  1
218548  99.920  -76.875  46.078  1
218549  99.952  -76.883  46.053  1
218550  99.983  -76.890  46.029  1
218551  100.014  -76.897  46.005  1
218552  100.046  -76.903  45.983  1
218553  100.077  -76.911  45.961  1
218554  100.109  -76.918  45.939  1
218555  100.140  -76.925  45.918  1
218556  100.182  -76.926  45.899  1
218557  100.223  -76.927  45.881  1
218558  100.265  -76.928  45.862  1
218559  100.292  -76.939  45.844  1
218560  100.315  -76.952  45.827  1
218561  100.340  -76.956  45.810  1
218562  100.365  -76.959  45.794  1
218563  100.387  -76.972  45.778  1
218564  100.407  -76.987  45.762  1
218565  100.425  -77.004  45.746  1
218566  100.443  -77.022  45.728  1
218567  100.461  -77.040  45.712  1
218568  100.479  -77.057  45.696  1
218569  100.497  -77.075  45.680  1
218570  100.515  -77.093  45.663  1
218571  100.533  -77.110  45.647  1
218572  100.545  -77.125  45.631  1
218573  100.554  -77.138  45.616  1
218574  100.563  -77.151  45.600  1
218575  100.572  -77.165  45.586  1
218576  100.582  -77.179  45.572  1
218577  100.603  -77.196  45.559  1
218578  100.623  -77.214  45.546  1
218579  100.643  -77.232  45.534  1
218580  100.663  -77.250  45.522  1
218581  100.683  -77.268  45.509  1
218582  100.703  -77.285  45.499  1
218583  100.723  -77.304  45.487  1
218584  100.744  -77.322  45.476  1
218585  100.769  -77.334  45.465  1
218586  100.796  -77.345  45.454  1
218587  100.824  -77.355  45.442  1
218588  100.851  -77.367  45.431  1
218589  100.878  -77.377  45.421  1
218590  100.905  -77.388  45.410  1
218591  100.928  -77.398  45.399  1
218592  100.949  -77.409  45.387  1
218593  100.970  -77.420  45.374  1
218594  100.990  -77.429  45.361  1
218595  101.010  -77.440  45.347  1
218596  101.032  -77.443  45.332  1
218597  101.054  -77.445  45.317  1
218598  101.076  -77.448  45.301  1
218599  101.102  -77.454  45.285  1
218600  101.130  -77.462  45.270  1
218601  101.158  -77.470  45.255  1
218602  101.186  -77.478  45.238  1
218603  101.213  -77.486  45.222  1
218604  101.236  -77.495  45.207  1
218605  101.234  -77.506  45.190  1
218606  101.235  -77.520  45.175  1
218607  101.239  -77.535  45.158  1
218608  101.243  -77.550  45.141  1
218609  101.247  -77.565  45.123  1
218610  101.250  -77.580  45.106  1
218611  101.254  -77.595  45.090  1
218612  101.284  -77.608  45.072  1
218613  101.315  -77.622  45.055  1
218614  101.346  -77.636  45.039  1
218615  101.376  -77.649  45.022  1
218616  101.407  -77.662  45.005  1
218617  101.438  -77.676  44.989  1
218618  101.469  -77.689  44.972  1
218619  101.499  -77.703  44.955  1
218620  101.530  -77.716  44.939  1
218621  101.561  -77.730  44.922  1
218622  101.592  -77.743  44.905  1
218623  101.622  -77.757  44.888  1
218624  101.653  -77.771  44.872  1
218625  101.688  -77.783  44.856  1
218626  101.724  -77.797  44.839  1
218627  101.764  -77.808  44.824  1
218628  101.835  -77.809  44.807  1
218629  101.926  -77.804  44.791  1
218630  101.944  -77.821  44.776  1
218631  101.958  -77.846  44.759  1
218632  101.983  -77.872  44.743  1
218633  101.976  -77.872  44.727  1
218634  101.965  -77.864  44.711  1
218635  101.995  -77.869  44.695  1
218636  102.012  -77.881  44.680  1
218637  102.011  -77.900  44.666  1
218638  102.040  -77.902  44.650  1
218639  102.069  -77.905  44.635  1
218640  102.094  -77.915  44.619  1
218641  102.139  -77.955  44.603  1
218642  102.174  -77.975  44.587  1
218643  102.204  -77.988  44.572  1
218644  102.235  -78.002  44.558  1
218645  102.265  -78.015  44.544  1
218646  102.295  -78.028  44.529  1
218647  102.325  -78.042  44.515  1
218648  102.356  -78.056  44.500  1
218649  102.383  -78.065  44.486  1
218650  102.404  -78.069  44.472  1
218651  102.426  -78.073  44.456  1
218652  102.448  -78.077  44.441  1
218653  102.470  -78.081  44.426  1
218654  102.495  -78.094  44.410  1
218655  102.525  -78.116  44.395  1
218656  102.554  -78.138  44.380  1
218657  102.584  -78.161  44.366  1
218658  102.613  -78.183  44.350  1
218659  102.643  -78.206  44.336  1
218660  102.672  -78.228  44.321  1
218661  102.704  -78.222  44.306  1
218662  102.736  -78.216  44.291  1
218663  102.767  -78.210  44.276  1
218664  102.800  -78.250  44.261  1
218665  102.842  -78.249  44.245  1
218666  102.884  -78.247  44.229  1
218667  102.926  -78.246  44.213  1
218668  102.968  -78.244  44.197  1
218669  103.010  -78.242  44.181  1
218670  103.051  -78.241  44.164  1
218671  103.093  -78.239  44.146  1
218672  103.135  -78.238  44.129  1
218673  103.177  -78.236  44.113  1
218674  103.219  -78.235  44.096  1
218675  103.260  -78.232  44.078  1
218918  92.359  -75.483  54.162  1
218919  92.382  -75.493  54.172  1
218920  92.405  -75.505  54.180  1
218921  92.428  -75.515  54.186  1
218922  92.447  -75.527  54.191  1
218923  92.455  -75.539  54.192  1
218924  92.475  -75.530  54.194  1
218925  92.496  -75.521  54.197  1
218926  92.516  -75.512  54.197  1
218927  92.536  -75.505  54.196  1
218928  92.555  -75.502  54.193  1
218961  93.323  -75.491  53.926  1
218962  93.346  -75.489  53.935  1
218963  93.369  -75.489  53.947  1
218964  93.392  -75.487  53.963  1
218965  93.416  -75.486  53.981  1
218966  93.439  -75.485  54.000  1
218967  93.462  -75.483  54.022  1
218968  93.486  -75.483  54.048  1
218969  93.509  -75.481  54.077  1
218970  93.532  -75.480  54.110  1
218971  93.567  -75.478  54.144  1
218972  93.606  -75.477  54.181  1
218973  93.645  -75.474  54.221  1
218974  93.698  -75.458  54.262  1
218975  93.750  -75.441  54.302  1
218976  93.788  -75.431  54.340  1
218977  93.812  -75.428  54.373  1
218978  93.836  -75.425  54.401  1
218979  93.860  -75.421  54.418  1
218980  93.884  -75.419  54.434  1
218981  93.906  -75.417  54.449  1
218982  93.928  -75.414  54.464  1
218983  93.951  -75.412  54.475  1
218984  93.973  -75.411  54.481  1
218985  93.997  -75.410  54.479  1
218986  94.021  -75.410  54.470  1
218987  94.045  -75.410  54.460  1
218988  94.069  -75.409  54.450  1
218989  94.092  -75.408  54.442  1
218990  94.115  -75.408  54.432  1
218991  94.138  -75.407  54.420  1
218992  94.161  -75.406  54.405  1
218993  94.186  -75.408  54.387  1
218994  94.212  -75.416  54.367  1
218995  94.239  -75.422  54.346  1
218996  94.264  -75.423  54.324  1
218997  94.290  -75.424  54.304  1
218998  94.316  -75.424  54.286  1
218999  94.341  -75.424  54.269  1
219000  94.366  -75.421  54.254  1
219001  94.390  -75.415  54.241  1
219002  94.409  -75.412  54.227  1
219003  94.426  -75.411  54.213  1
219004  94.442  -75.411  54.198  1
219005  94.456  -75.415  54.181  1
219006  94.470  -75.419  54.154  1
219007  94.483  -75.423  54.123  1
219008  94.497  -75.427  54.090  1
219009  94.511  -75.430  54.054  1
219010  94.525  -75.434  54.016  1
219011  94.538  -75.438  53.979  1
219012  94.554  -75.440  53.940  1
219013  94.571  -75.442  53.900  1
219014  94.589  -75.443  53.861  1
219015  94.607  -75.445  53.824  1
219016  94.626  -75.446  53.787  1
219017  94.651  -75.444  53.749  1
219018  94.677  -75.443  53.710  1
219019  94.703  -75.442  53.669  1
219020  94.728  -75.441  53.627  1
219021  94.719  -75.444  53.586  1
219022  94.709  -75.446  53.545  1
219023  94.700  -75.449  53.505  1
219024  94.691  -75.452  53.465  1
219025  94.681  -75.455  53.425  1
219026  94.672  -75.457  53.385  1
219027  94.662  -75.460  53.345  1
219028  94.653  -75.462  53.307  1
219029  94.643  -75.465  53.272  1
219030  94.634  -75.467  53.234  1
219031  94.628  -75.471  53.194  1
219032  94.636  -75.473  53.151  1
219033  94.657  -75.477  53.104  1
219034  94.687  -75.483  53.056  1
219035  94.717  -75.489  53.009  1
219036  94.748  -75.496  52.964  1
219037  94.778  -75.502  52.922  1
219038  94.808  -75.508  52.879  1
219039  94.838  -75.514  52.838  1
219040  94.868  -75.521  52.799  1
219041  94.899  -75.527  52.762  1
219042  94.929  -75.533  52.726  1
219043  94.956  -75.536  52.689  1
219044  94.981  -75.540  52.650  1
219045  95.007  -75.543  52.608  1
219046  95.033  -75.546  52.564  1
219047  95.058  -75.550  52.518  1
219048  95.088  -75.556  52.474  1
219049  95.121  -75.568  52.430  1
219050  95.156  -75.578  52.386  1
219051  95.190  -75.589  52.342  1
219052  95.224  -75.600  52.299  1
219053  95.258  -75.611  52.257  1
219054  95.292  -75.622  52.216  1
219055  95.326  -75.633  52.175  1
219056  95.360  -75.643  52.136  1
219057  95.394  -75.655  52.098  1
219058  95.428  -75.665  52.059  1
219059  95.469  -75.665  52.020  1
219060  95.481  -75.636  51.981  1
219061  95.494  -75.607  51.944  1
219062  95.510  -75.580  51.907  1
219063  95.531  -75.554  51.870  1
219064  95.558  -75.565  51.834  1
219065  95.589  -75.593  51.797  1
219066  95.607  -75.630  51.761  1
219067  95.606  -75.684  51.727  1
219068  95.607  -75.733  51.693  1
219069  95.649  -75.731  51.659  1
219070  95.691  -75.730  51.625  1
219071  95.732  -75.728  51.592  1
219072  95.774  -75.727  51.561  1
219073  95.816  -75.725  51.532  1
219074  95.858  -75.724  51.504  1
219075  95.899  -75.722  51.475  1
219076  95.894  -75.741  51.445  1
219077  95.928  -75.746  51.414  1
219078  95.937  -75.756  51.382  1
219079  95.944  -75.767  51.348  1
219080  95.988  -75.754  51.316  1
219081  96.036  -75.737  51.284  1
219082  96.086  -75.721  51.253  1
219083  96.135  -75.706  51.222  1
219084  96.185  -75.690  51.191  1
219085  96.221  -75.684  51.159  1
219086  96.224  -75.702  51.127  1
219087  96.243  -75.705  51.095  1
219088  96.264  -75.709  51.062  1
219089  96.285  -75.715  51.029  1
219090  96.305  -75.722  50.996  1
219091  96.325  -75.729  50.964  1
219092  96.345  -75.736  50.933  1
219093  96.366  -75.743  50.903  1
219094  96.386  -75.749  50.876  1
219095  96.407  -75.757  50.850  1
219096  96.429  -75.768  50.824  1
219097  96.451  -75.779  50.798  1
219098  96.473  -75.790  50.772  1
219099  96.489  -75.804  50.747  1
219100  96.506  -75.818  50.723  1
219101  96.522  -75.832  50.701  1
219102  96.538  -75.847  50.678  1
219103  96.554  -75.861  50.656  1
219104  96.570  -75.875  50.633  1
219105  96.586  -75.889  50.611  1
219106  96.602  -75.903  50.588  1
219107  96.602  -75.924  50.566  1
219108  96.601  -75.944  50.544  1
219109  96.658  -75.948  50.523  1
219110  96.702  -75.941  50.501  1
219111  96.743  -75.934  50.477  1
219112  96.801  -75.955  50.451  1
219113  96.869  -75.991  50.422  1
219114  96.936  -76.028  50.393  1
219115  96.960  -76.066  50.362  1
219116  96.841  -76.047  50.328  1
219117  96.793  -76.039  50.289  1
219118  96.819  -76.044  50.248  1
219119  96.847  -76.050  50.205  1
219120  96.873  -76.056  50.162  1
219121  96.900  -76.061  50.119  1
219122  96.927  -76.066  50.077  1
219123  96.954  -76.072  50.036  1
219124  96.980  -76.078  49.996  1
219125  97.007  -76.083  49.957  1
219126  97.034  -76.088  49.918  1
219127  97.061  -76.094  49.881  1
219128  97.088  -76.100  49.844  1
219129  97.115  -76.105  49.808  1
219130  97.142  -76.110  49.773  1
219131  97.168  -76.116  49.739  1
219132  97.192  -76.122  49.706  1
219133  97.217  -76.127  49.675  1
219134  97.247  -76.134  49.644  1
219135  97.286  -76.142  49.614  1
219136  97.324  -76.151  49.584  1
219137  97.362  -76.160  49.555  1
219138  97.400  -76.169  49.528  1
219139  97.439  -76.177  49.502  1
219140  97.469  -76.179  49.476  1
219141  97.500  -76.181  49.448  1
219142  97.530  -76.183  49.421  1
219143  97.562  -76.188  49.394  1
219144  97.595  -76.198  49.367  1
219145  97.629  -76.207  49.340  1
219146  97.652  -76.217  49.315  1
219147  97.668  -76.226  49.290  1
219148  97.677  -76.238  49.263  1
219149  97.682  -76.251  49.238  1
219150  97.686  -76.264  49.212  1
219151  97.691  -76.277  49.185  1
219152  97.696  -76.291  49.156  1
219153  97.700  -76.304  49.127  1
219154  97.704  -76.317  49.097  1
219155  97.709  -76.330  49.066  1
219156  97.713  -76.344  49.035  1
219157  97.730  -76.356  49.004  1
219158  97.762  -76.367  48.972  1
219159  97.830  -76.370  48.941  1
219160  97.874  -76.382  48.909  1
219161  97.917  -76.393  48.874  1
219162  97.960  -76.404  48.837  1
219163  98.004  -76.416  48.798  1
219164  98.048  -76.426  48.757  1
219165  98.091  -76.441  48.717  1
219166  98.134  -76.465  48.677  1
219167  98.183  -76.485  48.636  1
219168  98.240  -76.497  48.594  1
219169  98.234  -76.500  48.555  1
219170  98.267  -76.510  48.517  1
219171  98.298  -76.520  48.481  1
219172  98.330  -76.530  48.445  1
219173  98.362  -76.539  48.411  1
219174  98.394  -76.549  48.377  1
219175  98.456  -76.571  48.342  1
219176  98.479  -76.575  48.311  1
219177  98.501  -76.580  48.281  1
219178  98.524  -76.585  48.252  1
219179  98.547  -76.589  48.222  1
219180  98.570  -76.594  48.194  1
219181  98.593  -76.599  48.167  1
219182  98.615  -76.603  48.141  1
219183  98.632  -76.606  48.115  1
219184  98.650  -76.609  48.088  1
219185  98.668  -76.611  48.062  1
219186  98.686  -76.614  48.038  1
219187  98.704  -76.617  48.015  1
219188  98.721  -76.620  47.991  1
219189  98.739  -76.623  47.966  1
219190  98.751  -76.627  47.942  1
219191  98.765  -76.632  47.915  1
219192  98.777  -76.637  47.888  1
219193  98.790  -76.643  47.861  1
219194  98.803  -76.649  47.834  1
219195  98.816  -76.654  47.805  1
219196  98.829  -76.659  47.776  1
219197  98.848  -76.662  47.746  1
219198  98.869  -76.665  47.716  1
219199  98.891  -76.668  47.685  1
219200  98.913  -76.671  47.654  1
219201  98.939  -76.668  47.624  1
219202  98.964  -76.664  47.595  1
219203  98.980  -76.655  47.566  1
219204  98.992  -76.645  47.534  1
219205  99.006  -76.640  47.501  1
219206  99.025  -76.649  47.466  1
219207  99.045  -76.657  47.429  1
219208  99.067  -76.667  47.392  1
219209  99.099  -76.681  47.355  1
219210  99.131  -76.695  47.316  1
219211  99.172  -76.712  47.277  1
219212  99.220  -76.730  47.239  1
219213  99.269  -76.748  47.199  1
219214  99.308  -76.759  47.159  1
219215  99.337  -76.763  47.120  1
219216  99.355  -76.762  47.081  1
219217  99.373  -76.762  47.043  1
219218  99.392  -76.761  47.005  1
219219  99.410  -76.760  46.967  1
219220  99.429  -76.759  46.930  1
219221  99.447  -76.759  46.892  1
219222  99.466  -76.758  46.857  1
219223  99.484  -76.756  46.822  1
219224  99.502  -76.755  46.788  1
219225  99.520  -76.755  46.754  1
219226  99.532  -76.756  46.721  1
219227  99.541  -76.759  46.687  1
219228  99.556  -76.774  46.653  1
219229  99.573  -76.796  46.622  1
219230  99.590  -76.819  46.590  1
219231  99.604  -76.831  46.559  1
219232  99.613  -76.828  46.528  1
219233  99.622  -76.826  46.497  1
219234  99.631  -76.823  46.469  1
219235  99.640  -76.820  46.442  1
219236  99.649  -76.818  46.416  1
219237  99.664  -76.817  46.391  1
219238  99.686  -76.820  46.366  1
219239  99.707  -76.823  46.342  1
219240  99.728  -76.825  46.318  1
219241  99.750  -76.828  46.293  1
219242  99.772  -76.831  46.269  1
219243  99.793  -76.834  46.243  1
219244  99.815  -76.836  46.215  1
219245  99.836  -76.839  46.187  1
219246  99.857  -76.842  46.159  1
219247  99.884  -76.846  46.129  1
219248  99.915  -76.853  46.101  1
219249  99.946  -76.860  46.076  1
219250  99.978  -76.868  46.050  1
219251  100.009  -76.875  46.025  1
219252  100.041  -76.881  46.001  1
219253  100.072  -76.889  45.978  1
219254  100.104  -76.896  45.955  1
219255  100.135  -76.903  45.932  1
219256  100.167  -76.909  45.912  1
219257  100.198  -76.917  45.893  1
219258  100.232  -76.922  45.874  1
219259  100.274  -76.923  45.856  1
219260  100.308  -76.930  45.838  1
219261  100.331  -76.939  45.820  1
219262  100.356  -76.943  45.803  1
219263  100.381  -76.947  45.787  1
219264  100.403  -76.959  45.771  1
219265  100.422  -76.975  45.755  1
219266  100.440  -76.993  45.739  1
219267  100.458  -77.010  45.723  1
219268  100.476  -77.028  45.706  1
219269  100.494  -77.046  45.690  1
219270  100.512  -77.063  45.674  1
219271  100.530  -77.081  45.656  1
219272  100.548  -77.099  45.640  1
219273  100.565  -77.116  45.624  1
219274  100.574  -77.129  45.609  1
219275  100.583  -77.142  45.593  1
219276  100.592  -77.155  45.578  1
219277  100.603  -77.169  45.564  1
219278  100.623  -77.188  45.551  1
219279  100.644  -77.205  45.539  1
219280  100.664  -77.223  45.526  1
219281  100.684  -77.241  45.514  1
219282  100.704  -77.259  45.502  1
219283  100.724  -77.277  45.491  1
219284  100.745  -77.294  45.479  1
219285  100.772  -77.306  45.468  1
219286  100.799  -77.316  45.456  1
219287  100.826  -77.327  45.445  1
219288  100.853  -77.338  45.434  1
219289  100.881  -77.348  45.423  1
219290  100.908  -77.359  45.413  1
219291  100.935  -77.370  45.402  1
219292  100.959  -77.381  45.391  1
219293  100.979  -77.391  45.379  1
219294  101.000  -77.401  45.366  1
219295  101.020  -77.412  45.353  1
219296  101.041  -77.423  45.339  1
219297  101.061  -77.433  45.325  1
219298  101.082  -77.437  45.311  1
219299  101.105  -77.439  45.294  1
219300  101.129  -77.444  45.278  1
219301  101.157  -77.452  45.262  1
219302  101.185  -77.460  45.246  1
219303  101.213  -77.467  45.229  1
219304  101.230  -77.477  45.212  1
219305  101.228  -77.489  45.196  1
219306  101.226  -77.501  45.178  1
219307  101.224  -77.513  45.162  1
219308  101.222  -77.524  45.145  1
219309  101.222  -77.537  45.127  1
219310  101.227  -77.552  45.110  1
219311  101.231  -77.567  45.092  1
219312  101.239  -77.582  45.076  1
219313  101.269  -77.595  45.059  1
219314  101.300  -77.609  45.042  1
219315  101.330  -77.623  45.025  1
219316  101.361  -77.636  45.008  1
219317  101.392  -77.649  44.992  1
219318  101.422  -77.663  44.976  1
219319  101.453  -77.677  44.959  1
219320  101.487  -77.690  44.943  1
219321  101.523  -77.703  44.926  1
219322  101.559  -77.717  44.910  1
219323  101.595  -77.730  44.893  1
219324  101.631  -77.743  44.877  1
219325  101.668  -77.757  44.860  1
219326  101.704  -77.771  44.844  1
219327  101.746  -77.780  44.828  1
219328  101.790  -77.790  44.812  1
219329  101.828  -77.802  44.795  1
219330  101.919  -77.796  44.779  1
219331  101.943  -77.812  44.763  1
219332  101.942  -77.835  44.747  1
219333  101.959  -77.861  44.731  1
219334  101.959  -77.866  44.716  1
219335  101.969  -77.865  44.700  1
219336  101.982  -77.879  44.685  1
219337  102.001  -77.887  44.669  1
219338  102.030  -77.889  44.654  1
219339  102.059  -77.891  44.639  1
219340  102.088  -77.893  44.623  1
219341  102.113  -77.905  44.607  1
219342  102.139  -77.923  44.590  1
219343  102.187  -77.961  44.574  1
219344  102.217  -77.975  44.560  1
219345  102.247  -77.988  44.546  1
219346  102.278  -78.002  44.531  1
219347  102.308  -78.015  44.517  1
219348  102.338  -78.029  44.502  1
219349  102.369  -78.043  44.487  1
219350  102.394  -78.050  44.473  1
219351  102.415  -78.054  44.458  1
219352  102.437  -78.058  44.443  1
219353  102.459  -78.062  44.428  1
219354  102.481  -78.065  44.413  1
219355  102.503  -78.069  44.397  1
219356  102.532  -78.091  44.382  1
219357  102.561  -78.113  44.368  1
219358  102.591  -78.136  44.354  1
219359  102.620  -78.159  44.338  1
219360  102.650  -78.181  44.324  1
219361  102.679  -78.203  44.309  1
219362  102.709  -78.226  44.293  1
219363  102.740  -78.233  44.278  1
219364  102.771  -78.227  44.263  1
219365  102.807  -78.248  44.248  1
219366  102.848  -78.247  44.233  1
219367  102.890  -78.245  44.216  1
219368  102.932  -78.244  44.200  1
219369  102.974  -78.242  44.185  1
219370  103.016  -78.240  44.168  1
219371  103.058  -78.238  44.151  1
219372  103.100  -78.237  44.133  1
219373  103.141  -78.235  44.116  1
219374  103.183  -78.234  44.101  1
219375  103.225  -78.232  44.083  1
219376  103.267  -78.230  44.066  1
219618  92.323  -75.442  54.169  1
219619  92.346  -75.453  54.180  1
219620  92.369  -75.464  54.189  1
219621  92.392  -75.475  54.196  1
219622  92.415  -75.486  54.203  1
219623  92.438  -75.498  54.208  1
219624  92.448  -75.510  54.210  1
219625  92.465  -75.506  54.211  1
219626  92.485  -75.498  54.215  1
219627  92.505  -75.489  54.215  1
219628  92.525  -75.481  54.214  1
219629  92.545  -75.478  54.211  1
219630  92.564  -75.475  54.206  1
219631  92.583  -75.472  54.199  1
219639  92.823  -75.439  54.132  1
219640  92.854  -75.436  54.122  1
219641  92.884  -75.431  54.110  1
219642  92.916  -75.427  54.098  1
219643  92.946  -75.423  54.087  1
219644  92.973  -75.420  54.075  1
219645  92.992  -75.424  54.062  1
219646  93.010  -75.427  54.050  1
219662  93.321  -75.461  53.927  1
219663  93.344  -75.461  53.935  1
219664  93.368  -75.459  53.946  1
219665  93.391  -75.458  53.961  1
219666  93.414  -75.457  53.978  1
219667  93.438  -75.455  53.996  1
219668  93.461  -75.454  54.017  1
219669  93.484  -75.453  54.042  1
219670  93.508  -75.452  54.070  1
219671  93.531  -75.450  54.101  1
219672  93.566  -75.449  54.133  1
219673  93.605  -75.447  54.167  1
219674  93.644  -75.445  54.203  1
219675  93.692  -75.433  54.242  1
219676  93.745  -75.416  54.281  1
219677  93.781  -75.407  54.320  1
219678  93.805  -75.404  54.357  1
219679  93.829  -75.401  54.390  1
219680  93.853  -75.398  54.413  1
219681  93.877  -75.395  54.434  1
219682  93.901  -75.392  54.453  1
219683  93.925  -75.389  54.471  1
219684  93.948  -75.385  54.481  1
219685  93.972  -75.383  54.490  1
219686  93.995  -75.382  54.493  1
219687  94.018  -75.381  54.489  1
219688  94.041  -75.380  54.478  1
219689  94.064  -75.380  54.466  1
219690  94.087  -75.379  54.456  1
219691  94.110  -75.377  54.449  1
219692  94.133  -75.377  54.439  1
219693  94.156  -75.376  54.425  1
219694  94.183  -75.382  54.407  1
219695  94.209  -75.389  54.389  1
219696  94.236  -75.396  54.369  1
219697  94.262  -75.401  54.347  1
219698  94.288  -75.402  54.325  1
219699  94.314  -75.402  54.305  1
219700  94.339  -75.402  54.284  1
219701  94.363  -75.398  54.266  1
219702  94.387  -75.392  54.252  1
219703  94.411  -75.386  54.239  1
219704  94.428  -75.384  54.225  1
219705  94.445  -75.384  54.209  1
219706  94.462  -75.383  54.191  1
219707  94.479  -75.383  54.164  1
219708  94.492  -75.386  54.133  1
219709  94.506  -75.390  54.100  1
219710  94.520  -75.394  54.065  1
219711  94.534  -75.398  54.029  1
219712  94.547  -75.402  53.992  1
219713  94.562  -75.405  53.955  1
219714  94.580  -75.406  53.916  1
219715  94.598  -75.408  53.878  1
219716  94.615  -75.408  53.840  1
219717  94.633  -75.410  53.802  1
219718  94.653  -75.411  53.763  1
219719  94.678  -75.409  53.724  1
219720  94.704  -75.408  53.684  1
219721  94.730  -75.408  53.642  1
219722  94.721  -75.410  53.600  1
219723  94.712  -75.413  53.560  1
219724  94.702  -75.415  53.520  1
219725  94.693  -75.418  53.479  1
219726  94.684  -75.420  53.439  1
219727  94.674  -75.423  53.398  1
219728  94.665  -75.426  53.357  1
219729  94.655  -75.428  53.316  1
219730  94.646  -75.431  53.278  1
219731  94.636  -75.433  53.239  1
219732  94.627  -75.437  53.199  1
219733  94.635  -75.442  53.157  1
219734  94.666  -75.448  53.110  1
219735  94.696  -75.454  53.063  1
219736  94.726  -75.460  53.016  1
219737  94.756  -75.466  52.970  1
219738  94.786  -75.472  52.925  1
219739  94.817  -75.478  52.882  1
219740  94.847  -75.484  52.839  1
219741  94.877  -75.490  52.799  1
219742  94.907  -75.496  52.762  1
219743  94.937  -75.502  52.726  1
219744  94.963  -75.505  52.689  1
219745  94.988  -75.509  52.646  1
219746  95.014  -75.512  52.603  1
219747  95.040  -75.516  52.558  1
219748  95.065  -75.519  52.512  1
219749  95.093  -75.524  52.467  1
219750  95.127  -75.535  52.422  1
219751  95.161  -75.546  52.378  1
219752  95.195  -75.557  52.333  1
219753  95.229  -75.568  52.289  1
219754  95.263  -75.579  52.245  1
219755  95.297  -75.590  52.204  1
219756  95.331  -75.601  52.164  1
219757  95.366  -75.612  52.124  1
219758  95.400  -75.622  52.085  1
219759  95.433  -75.634  52.046  1
219760  95.462  -75.646  52.009  1
219761  95.486  -75.642  51.971  1
219762  95.517  -75.609  51.935  1
219763  95.543  -75.579  51.898  1
219764  95.564  -75.553  51.863  1
219765  95.590  -75.550  51.829  1
219766  95.595  -75.597  51.794  1
219767  95.594  -75.650  51.760  1
219768  95.593  -75.702  51.726  1
219769  95.631  -75.705  51.693  1
219770  95.673  -75.703  51.659  1
219771  95.715  -75.702  51.624  1
219772  95.757  -75.700  51.590  1
219773  95.799  -75.699  51.556  1
219774  95.840  -75.697  51.525  1
219775  95.882  -75.696  51.495  1
219776  95.924  -75.694  51.466  1
219777  95.966  -75.693  51.436  1
219778  95.943  -75.718  51.405  1
219779  95.962  -75.724  51.373  1
219780  95.975  -75.726  51.340  1
219781  95.990  -75.731  51.307  1
219782  96.036  -75.726  51.276  1
219783  96.085  -75.710  51.246  1
219784  96.135  -75.694  51.216  1
219785  96.184  -75.678  51.187  1
219786  96.234  -75.662  51.157  1
219787  96.238  -75.680  51.126  1
219788  96.256  -75.683  51.096  1
219789  96.276  -75.686  51.065  1
219790  96.298  -75.690  51.034  1
219791  96.319  -75.693  51.001  1
219792  96.339  -75.699  50.969  1
219793  96.359  -75.706  50.938  1
219794  96.380  -75.713  50.908  1
219795  96.400  -75.720  50.881  1
219796  96.420  -75.727  50.855  1
219797  96.442  -75.737  50.829  1
219798  96.464  -75.749  50.803  1
219799  96.483  -75.762  50.777  1
219800  96.500  -75.775  50.752  1
219801  96.516  -75.790  50.729  1
219802  96.532  -75.804  50.708  1
219803  96.548  -75.818  50.686  1
219804  96.564  -75.832  50.663  1
219805  96.580  -75.847  50.640  1
219806  96.596  -75.860  50.618  1
219807  96.612  -75.875  50.595  1
219808  96.617  -75.893  50.573  1
219809  96.654  -75.900  50.552  1
219810  96.695  -75.894  50.532  1
219811  96.763  -75.930  50.509  1
219812  96.830  -75.966  50.486  1
219813  96.877  -75.991  50.460  1
219814  96.909  -76.009  50.432  1
219815  96.941  -76.026  50.402  1
219816  96.973  -76.044  50.370  1
219817  96.873  -76.029  50.336  1
219818  96.814  -76.020  50.299  1
219819  96.840  -76.025  50.258  1
219820  96.867  -76.031  50.215  1
219821  96.894  -76.037  50.170  1
219822  96.921  -76.042  50.127  1
219823  96.948  -76.047  50.084  1
219824  96.974  -76.053  50.043  1
219825  97.002  -76.059  50.003  1
219826  97.028  -76.064  49.964  1
219827  97.055  -76.069  49.925  1
219828  97.081  -76.075  49.888  1
219829  97.106  -76.081  49.852  1
219830  97.130  -76.086  49.815  1
219831  97.155  -76.091  49.780  1
219832  97.179  -76.097  49.746  1
219833  97.204  -76.103  49.714  1
219834  97.229  -76.108  49.683  1
219835  97.254  -76.113  49.652  1
219836  97.293  -76.122  49.622  1
219837  97.331  -76.131  49.592  1
219838  97.369  -76.140  49.564  1
219839  97.407  -76.148  49.537  1
219840  97.438  -76.151  49.510  1
219841  97.468  -76.153  49.484  1
219842  97.499  -76.154  49.456  1
219843  97.529  -76.157  49.429  1
219844  97.561  -76.160  49.402  1
219845  97.594  -76.170  49.376  1
219846  97.628  -76.180  49.350  1
219847  97.661  -76.190  49.325  1
219848  97.684  -76.199  49.301  1
219849  97.692  -76.211  49.274  1
219850  97.697  -76.224  49.247  1
219851  97.701  -76.238  49.220  1
219852  97.706  -76.251  49.193  1
219853  97.710  -76.264  49.164  1
219854  97.715  -76.277  49.134  1
219855  97.719  -76.291  49.102  1
219856  97.724  -76.304  49.070  1
219857  97.728  -76.317  49.037  1
219858  97.735  -76.330  49.006  1
219859  97.782  -76.339  48.975  1
219860  97.825  -76.350  48.945  1
219861  97.869  -76.361  48.914  1
219862  97.913  -76.373  48.878  1
219863  97.956  -76.383  48.839  1
219864  98.000  -76.395  48.800  1
219865  98.043  -76.406  48.760  1
219866  98.086  -76.424  48.719  1
219867  98.135  -76.445  48.677  1
219868  98.191  -76.457  48.634  1
219869  98.231  -76.467  48.593  1
219870  98.240  -76.473  48.553  1
219871  98.272  -76.483  48.515  1
219872  98.303  -76.492  48.478  1
219873  98.336  -76.502  48.443  1
219874  98.366  -76.515  48.408  1
219875  98.395  -76.531  48.373  1
219876  98.455  -76.552  48.340  1
219877  98.488  -76.561  48.307  1
219878  98.520  -76.570  48.276  1
219879  98.553  -76.579  48.246  1
219880  98.575  -76.583  48.217  1
219881  98.598  -76.589  48.189  1
219882  98.621  -76.593  48.162  1
219883  98.644  -76.598  48.136  1
219884  98.666  -76.602  48.109  1
219885  98.684  -76.605  48.084  1
219886  98.702  -76.608  48.059  1
219887  98.719  -76.611  48.035  1
219888  98.737  -76.613  48.010  1
219889  98.754  -76.615  47.986  1
219890  98.762  -76.611  47.962  1
219891  98.771  -76.607  47.937  1
219892  98.782  -76.610  47.911  1
219893  98.795  -76.615  47.886  1
219894  98.808  -76.621  47.859  1
219895  98.820  -76.626  47.831  1
219896  98.834  -76.631  47.804  1
219897  98.846  -76.636  47.776  1
219898  98.863  -76.640  47.747  1
219899  98.885  -76.643  47.717  1
219900  98.907  -76.646  47.687  1
219901  98.928  -76.649  47.656  1
219902  98.950  -76.652  47.627  1
219903  98.975  -76.649  47.599  1
219904  98.997  -76.645  47.570  1
219905  99.010  -76.634  47.538  1
219906  99.025  -76.633  47.505  1
219907  99.045  -76.643  47.470  1
219908  99.065  -76.651  47.433  1
219909  99.084  -76.660  47.397  1
219910  99.116  -76.674  47.360  1
219911  99.148  -76.688  47.322  1
219912  99.180  -76.702  47.283  1
219913  99.222  -76.715  47.243  1
219914  99.262  -76.725  47.204  1
219915  99.300  -76.735  47.163  1
219916  99.339  -76.745  47.124  1
219917  99.373  -76.752  47.085  1
219918  99.392  -76.752  47.047  1
219919  99.410  -76.751  47.009  1
219920  99.428  -76.750  46.971  1
219921  99.447  -76.749  46.933  1
219922  99.465  -76.748  46.895  1
219923  99.484  -76.747  46.860  1
219924  99.502  -76.746  46.825  1
219925  99.520  -76.746  46.790  1
219926  99.533  -76.746  46.757  1
219927  99.542  -76.749  46.724  1
219928  99.551  -76.750  46.690  1
219929  99.562  -76.758  46.656  1
219930  99.579  -76.781  46.624  1
219931  99.596  -76.802  46.592  1
219932  99.608  -76.806  46.561  1
219933  99.617  -76.804  46.529  1
219934  99.626  -76.801  46.500  1
219935  99.635  -76.798  46.472  1
219936  99.646  -76.796  46.445  1
219937  99.667  -76.799  46.419  1
219938  99.689  -76.802  46.394  1
219939  99.711  -76.805  46.370  1
219940  99.732  -76.807  46.345  1
219941  99.754  -76.810  46.321  1
219942  99.775  -76.812  46.296  1
219943  99.797  -76.815  46.270  1
219944  99.818  -76.818  46.244  1
219945  99.840  -76.821  46.216  1
219946  99.861  -76.824  46.188  1
219947  99.883  -76.826  46.158  1
219948  99.910  -76.831  46.128  1
219949  99.941  -76.838  46.100  1
219950  99.973  -76.846  46.073  1
219951  100.004  -76.853  46.047  1
219952  100.036  -76.859  46.022  1
219953  100.067  -76.866  45.997  1
219954  100.099  -76.874  45.973  1
219955  100.130  -76.881  45.949  1
219956  100.161  -76.887  45.927  1
219957  100.193  -76.895  45.906  1
219958  100.224  -76.902  45.887  1
219959  100.256  -76.909  45.867  1
219960  100.287  -76.915  45.848  1
219961  100.323  -76.920  45.831  1
219962  100.347  -76.926  45.813  1
219963  100.372  -76.930  45.796  1
219964  100.397  -76.934  45.780  1
219965  100.418  -76.947  45.765  1
219966  100.437  -76.963  45.749  1
219967  100.455  -76.981  45.732  1
219968  100.473  -76.999  45.717  1
219969  100.491  -77.016  45.700  1
219970  100.509  -77.034  45.684  1
219971  100.527  -77.052  45.668  1
219972  100.545  -77.069  45.650  1
219973  100.563  -77.088  45.633  1
219974  100.581  -77.105  45.617  1
219975  100.593  -77.119  45.602  1
219976  100.602  -77.132  45.585  1
219977  100.611  -77.146  45.571  1
219978  100.624  -77.160  45.557  1
219979  100.644  -77.179  45.544  1
219980  100.665  -77.197  45.531  1
219981  100.685  -77.214  45.519  1
219982  100.705  -77.232  45.507  1
219983  100.725  -77.250  45.495  1
219984  100.747  -77.266  45.483  1
219985  100.774  -77.277  45.472  1
219986  100.801  -77.288  45.460  1
219987  100.828  -77.298  45.448  1
219988  100.855  -77.310  45.437  1
219989  100.882  -77.320  45.426  1
219990  100.910  -77.331  45.415  1
219991  100.937  -77.341  45.405  1
219992  100.964  -77.352  45.394  1
219993  100.989  -77.363  45.384  1
219994  101.009  -77.373  45.372  1
219995  101.030  -77.384  45.358  1
219996  101.050  -77.395  45.344  1
219997  101.071  -77.405  45.330  1
219998  101.091  -77.415  45.316  1
219999  101.112  -77.426  45.302  1
220000  101.133  -77.431  45.286  1
220001  101.156  -77.434  45.270  1
220002  101.184  -77.442  45.254  1
220003  101.212  -77.450  45.237  1
220004  101.223  -77.460  45.219  1
220005  101.221  -77.472  45.201  1
220006  101.219  -77.483  45.184  1
220007  101.218  -77.495  45.166  1
220008  101.216  -77.507  45.149  1
220009  101.214  -77.519  45.132  1
220010  101.213  -77.530  45.113  1
220011  101.211  -77.542  45.096  1
220012  101.210  -77.555  45.079  1
220013  101.223  -77.569  45.062  1
220014  101.254  -77.583  45.046  1
220015  101.286  -77.596  45.029  1
220016  101.322  -77.610  45.012  1
220017  101.358  -77.623  44.995  1
220018  101.394  -77.636  44.980  1
220019  101.430  -77.650  44.963  1
220020  101.467  -77.664  44.946  1
220021  101.502  -77.677  44.930  1
220022  101.539  -77.690  44.913  1
220023  101.575  -77.704  44.897  1
220024  101.611  -77.717  44.881  1
220025  101.647  -77.730  44.864  1
220026  101.685  -77.743  44.849  1
220027  101.729  -77.752  44.832  1
220028  101.771  -77.763  44.816  1
220029  101.815  -77.773  44.799  1
220030  101.849  -77.785  44.782  1
220031  101.911  -77.789  44.766  1
220032  101.942  -77.802  44.751  1
220033  101.941  -77.826  44.735  1
220034  101.939  -77.849  44.720  1
220035  101.943  -77.861  44.704  1
220036  101.963  -77.870  44.688  1
220037  101.991  -77.872  44.673  1
220038  102.021  -77.874  44.657  1
220039  102.049  -77.877  44.641  1
220040  102.078  -77.879  44.626  1
220041  102.107  -77.881  44.610  1
220042  102.131  -77.893  44.594  1
220043  102.155  -77.909  44.578  1
220044  102.198  -77.945  44.562  1
220045  102.230  -77.962  44.548  1
220046  102.260  -77.975  44.533  1
220047  102.290  -77.989  44.518  1
220048  102.321  -78.003  44.504  1
220049  102.351  -78.016  44.488  1
220050  102.382  -78.030  44.474  1
220051  102.405  -78.035  44.459  1
220052  102.427  -78.039  44.445  1
220053  102.448  -78.043  44.430  1
220054  102.470  -78.047  44.415  1
220055  102.492  -78.050  44.399  1
220056  102.514  -78.054  44.384  1
220057  102.539  -78.066  44.370  1
220058  102.569  -78.088  44.355  1
220059  102.598  -78.111  44.341  1
220060  102.627  -78.134  44.326  1
220061  102.657  -78.156  44.311  1
220062  102.686  -78.178  44.297  1
220063  102.716  -78.201  44.282  1
220064  102.746  -78.224  44.267  1
220065  102.775  -78.244  44.252  1
220066  102.813  -78.246  44.236  1
220067  102.855  -78.244  44.220  1
220068  102.897  -78.243  44.203  1
220069  102.939  -78.241  44.188  1
220070  102.981  -78.240  44.172  1
220071  103.023  -78.238  44.155  1
220072  103.065  -78.236  44.138  1
220073  103.106  -78.235  44.120  1
220074  103.148  -78.233  44.104  1
220075  103.190  -78.232  44.088  1
220076  103.232  -78.230  44.070  1
220077  103.274  -78.228  44.053  1
220317  92.265  -75.391  54.172  1
220318  92.287  -75.402  54.178  1
220319  92.310  -75.413  54.186  1
220320  92.334  -75.424  54.196  1
220321  92.357  -75.435  54.205  1
220322  92.380  -75.446  54.213  1
220323  92.403  -75.458  54.220  1
220324  92.426  -75.468  54.224  1
220325  92.441  -75.480  54.227  1
220326  92.454  -75.483  54.228  1
220327  92.475  -75.474  54.231  1
220328  92.495  -75.465  54.232  1
220329  92.515  -75.458  54.231  1
220330  92.534  -75.455  54.227  1
220331  92.554  -75.452  54.222  1
220332  92.573  -75.449  54.216  1
220333  92.600  -75.445  54.210  1
220334  92.631  -75.440  54.204  1
220339  92.785  -75.420  54.157  1
220340  92.816  -75.415  54.147  1
220341  92.847  -75.411  54.136  1
220342  92.877  -75.407  54.125  1
220343  92.908  -75.403  54.113  1
220344  92.939  -75.398  54.101  1
220345  92.965  -75.398  54.089  1
220346  92.984  -75.400  54.076  1
220347  93.002  -75.403  54.063  1
220348  93.020  -75.406  54.051  1
220349  93.039  -75.409  54.038  1
220363  93.320  -75.432  53.929  1
220364  93.343  -75.431  53.936  1
220365  93.366  -75.430  53.945  1
220366  93.390  -75.428  53.960  1
220367  93.413  -75.427  53.976  1
220368  93.436  -75.426  53.993  1
220369  93.460  -75.424  54.013  1
220370  93.483  -75.424  54.037  1
220371  93.506  -75.422  54.064  1
220372  93.530  -75.420  54.093  1
220373  93.565  -75.419  54.124  1
220374  93.604  -75.417  54.155  1
220375  93.643  -75.415  54.189  1
220376  93.687  -75.408  54.224  1
220377  93.740  -75.392  54.262  1
220378  93.774  -75.383  54.300  1
220379  93.798  -75.380  54.337  1
220380  93.822  -75.377  54.373  1
220381  93.846  -75.373  54.400  1
220382  93.869  -75.370  54.423  1
220383  93.894  -75.367  54.443  1
220384  93.917  -75.364  54.462  1
220385  93.942  -75.361  54.475  1
220386  93.968  -75.356  54.487  1
220387  93.990  -75.350  54.493  1
220388  94.013  -75.350  54.490  1
220389  94.037  -75.349  54.482  1
220390  94.060  -75.349  54.473  1
220391  94.083  -75.348  54.464  1
220392  94.106  -75.348  54.457  1
220393  94.129  -75.346  54.453  1
220394  94.152  -75.348  54.443  1
220395  94.180  -75.355  54.428  1
220396  94.206  -75.362  54.410  1
220397  94.233  -75.369  54.391  1
220398  94.260  -75.377  54.369  1
220399  94.286  -75.380  54.346  1
220400  94.312  -75.380  54.324  1
220401  94.337  -75.380  54.300  1
220402  94.361  -75.374  54.281  1
220403  94.385  -75.368  54.268  1
220404  94.408  -75.362  54.254  1
220405  94.430  -75.357  54.241  1
220406  94.448  -75.357  54.226  1
220407  94.464  -75.356  54.206  1
220408  94.481  -75.355  54.177  1
220409  94.498  -75.355  54.146  1
220410  94.515  -75.355  54.114  1
220411  94.529  -75.358  54.080  1
220412  94.542  -75.362  54.044  1
220413  94.556  -75.366  54.010  1
220414  94.571  -75.369  53.974  1
220415  94.589  -75.370  53.936  1
220416  94.606  -75.371  53.897  1
220417  94.623  -75.373  53.858  1
220418  94.641  -75.374  53.818  1
220419  94.659  -75.375  53.777  1
220420  94.680  -75.376  53.739  1
220421  94.705  -75.374  53.700  1
220422  94.731  -75.373  53.659  1
220423  94.723  -75.376  53.617  1
220424  94.714  -75.379  53.577  1
220425  94.705  -75.381  53.537  1
220426  94.695  -75.384  53.496  1
220427  94.686  -75.386  53.456  1
220428  94.677  -75.389  53.414  1
220429  94.667  -75.392  53.371  1
220430  94.657  -75.395  53.329  1
220431  94.651  -75.400  53.287  1
220432  94.644  -75.405  53.246  1
220433  94.637  -75.411  53.205  1
220434  94.651  -75.414  53.162  1
220435  94.674  -75.417  53.117  1
220436  94.704  -75.424  53.070  1
220437  94.734  -75.430  53.023  1
220438  94.764  -75.436  52.976  1
220439  94.794  -75.442  52.930  1
220440  94.825  -75.449  52.886  1
220441  94.855  -75.455  52.842  1
220442  94.885  -75.461  52.800  1
220443  94.915  -75.467  52.762  1
220444  94.944  -75.471  52.725  1
220445  94.969  -75.475  52.687  1
220446  94.995  -75.478  52.643  1
220447  95.021  -75.482  52.598  1
220448  95.047  -75.485  52.552  1
220449  95.072  -75.489  52.505  1
220450  95.098  -75.492  52.459  1
220451  95.132  -75.503  52.413  1
220452  95.166  -75.514  52.367  1
220453  95.200  -75.525  52.322  1
220454  95.235  -75.536  52.278  1
220455  95.268  -75.546  52.235  1
220456  95.303  -75.558  52.192  1
220457  95.337  -75.568  52.152  1
220458  95.371  -75.579  52.113  1
220459  95.405  -75.590  52.074  1
220460  95.436  -75.602  52.035  1
220461  95.457  -75.615  51.998  1
220462  95.477  -75.629  51.961  1
220463  95.498  -75.643  51.925  1
220464  95.528  -75.615  51.890  1
220465  95.559  -75.582  51.856  1
220466  95.584  -75.564  51.823  1
220467  95.583  -75.617  51.790  1
220468  95.582  -75.669  51.757  1
220469  95.614  -75.679  51.726  1
220470  95.656  -75.677  51.693  1
220471  95.698  -75.676  51.659  1
220472  95.740  -75.674  51.623  1
220473  95.781  -75.673  51.589  1
220474  95.823  -75.671  51.553  1
220475  95.865  -75.670  51.520  1
220476  95.907  -75.668  51.489  1
220477  95.949  -75.667  51.459  1
220478  95.990  -75.665  51.428  1
220479  96.024  -75.662  51.397  1
220480  96.016  -75.671  51.366  1
220481  96.008  -75.679  51.333  1
220482  96.003  -75.687  51.301  1
220483  96.046  -75.688  51.271  1
220484  96.089  -75.690  51.241  1
220485  96.135  -75.683  51.212  1
220486  96.184  -75.667  51.182  1
220487  96.234  -75.651  51.153  1
220488  96.253  -75.657  51.124  1
220489  96.270  -75.661  51.096  1
220490  96.288  -75.664  51.067  1
220491  96.309  -75.668  51.037  1
220492  96.330  -75.671  51.005  1
220493  96.352  -75.674  50.973  1
220494  96.373  -75.677  50.942  1
220495  96.393  -75.684  50.913  1
220496  96.414  -75.691  50.886  1
220497  96.434  -75.697  50.860  1
220498  96.456  -75.707  50.834  1
220499  96.477  -75.718  50.808  1
220500  96.493  -75.733  50.782  1
220501  96.510  -75.747  50.758  1
220502  96.526  -75.761  50.736  1
220503  96.542  -75.775  50.714  1
220504  96.558  -75.790  50.692  1
220505  96.574  -75.803  50.670  1
220506  96.590  -75.818  50.648  1
220507  96.606  -75.832  50.625  1
220508  96.622  -75.846  50.602  1
220509  96.643  -75.861  50.581  1
220510  96.674  -75.878  50.560  1
220511  96.707  -75.896  50.540  1
220512  96.738  -75.913  50.518  1
220513  96.770  -75.931  50.494  1
220514  96.802  -75.948  50.468  1
220515  96.834  -75.966  50.439  1
220516  96.866  -75.983  50.409  1
220517  96.898  -76.000  50.376  1
220518  96.904  -76.012  50.342  1
220519  96.834  -76.001  50.305  1
220520  96.861  -76.007  50.263  1
220521  96.888  -76.012  50.219  1
220522  96.915  -76.018  50.176  1
220523  96.942  -76.023  50.134  1
220524  96.968  -76.028  50.091  1
220525  96.994  -76.034  50.050  1
220526  97.019  -76.040  50.010  1
220527  97.043  -76.045  49.971  1
220528  97.068  -76.050  49.933  1
220529  97.092  -76.056  49.897  1
220530  97.117  -76.062  49.861  1
220531  97.142  -76.067  49.825  1
220532  97.166  -76.072  49.790  1
220533  97.191  -76.079  49.756  1
220534  97.216  -76.084  49.724  1
220535  97.240  -76.089  49.693  1
220536  97.265  -76.094  49.662  1
220537  97.299  -76.103  49.632  1
220538  97.337  -76.111  49.602  1
220539  97.376  -76.120  49.574  1
220540  97.406  -76.122  49.547  1
220541  97.437  -76.124  49.521  1
220542  97.467  -76.126  49.494  1
220543  97.498  -76.128  49.466  1
220544  97.528  -76.129  49.439  1
220545  97.560  -76.133  49.413  1
220546  97.593  -76.143  49.386  1
220547  97.627  -76.153  49.361  1
220548  97.660  -76.163  49.336  1
220549  97.693  -76.172  49.311  1
220550  97.699  -76.185  49.285  1
220551  97.701  -76.199  49.257  1
220552  97.704  -76.212  49.230  1
220553  97.706  -76.226  49.201  1
220554  97.709  -76.239  49.171  1
220555  97.712  -76.252  49.140  1
220556  97.714  -76.266  49.107  1
220557  97.717  -76.279  49.073  1
220558  97.719  -76.293  49.040  1
220559  97.744  -76.305  49.008  1
220560  97.785  -76.317  48.977  1
220561  97.822  -76.329  48.946  1
220562  97.864  -76.341  48.913  1
220563  97.908  -76.351  48.877  1
220564  97.951  -76.363  48.838  1
220565  97.995  -76.374  48.799  1
220566  98.038  -76.386  48.760  1
220567  98.086  -76.404  48.718  1
220568  98.143  -76.417  48.675  1
220569  98.199  -76.430  48.632  1
220570  98.213  -76.436  48.591  1
220571  98.245  -76.445  48.551  1
220572  98.277  -76.455  48.512  1
220573  98.309  -76.466  48.475  1
220574  98.338  -76.482  48.439  1
220575  98.368  -76.498  48.404  1
220576  98.397  -76.514  48.369  1
220577  98.452  -76.531  48.336  1
220578  98.485  -76.540  48.303  1
220579  98.517  -76.549  48.271  1
220580  98.550  -76.559  48.240  1
220581  98.583  -76.568  48.212  1
220582  98.616  -76.577  48.184  1
220583  98.648  -76.586  48.157  1
220584  98.672  -76.592  48.130  1
220585  98.695  -76.596  48.104  1
220586  98.718  -76.601  48.079  1
220587  98.735  -76.604  48.055  1
220588  98.753  -76.607  48.030  1
220589  98.769  -76.608  48.005  1
220590  98.777  -76.603  47.981  1
220591  98.785  -76.599  47.956  1
220592  98.793  -76.595  47.931  1
220593  98.801  -76.591  47.906  1
220594  98.812  -76.592  47.882  1
220595  98.825  -76.598  47.856  1
220596  98.838  -76.603  47.829  1
220597  98.851  -76.608  47.802  1
220598  98.864  -76.614  47.774  1
220599  98.879  -76.618  47.747  1
220600  98.901  -76.621  47.718  1
220601  98.922  -76.624  47.688  1
220602  98.944  -76.627  47.658  1
220603  98.966  -76.630  47.629  1
220604  98.987  -76.633  47.602  1
220605  99.011  -76.632  47.573  1
220606  99.027  -76.624  47.542  1
220607  99.045  -76.627  47.508  1
220608  99.065  -76.636  47.474  1
220609  99.084  -76.645  47.438  1
220610  99.103  -76.654  47.401  1
220611  99.133  -76.667  47.365  1
220612  99.164  -76.679  47.328  1
220613  99.195  -76.680  47.288  1
220614  99.225  -76.691  47.248  1
220615  99.255  -76.702  47.208  1
220616  99.292  -76.712  47.168  1
220617  99.332  -76.721  47.128  1
220618  99.370  -76.731  47.090  1
220619  99.409  -76.741  47.051  1
220620  99.428  -76.740  47.012  1
220621  99.446  -76.740  46.974  1
220622  99.465  -76.739  46.937  1
220623  99.483  -76.738  46.899  1
220624  99.501  -76.737  46.864  1
220625  99.520  -76.737  46.829  1
220626  99.535  -76.737  46.794  1
220627  99.544  -76.739  46.760  1
220628  99.553  -76.741  46.726  1
220629  99.561  -76.743  46.692  1
220630  99.570  -76.745  46.659  1
220631  99.586  -76.764  46.626  1
220632  99.603  -76.784  46.595  1
220633  99.612  -76.782  46.564  1
220634  99.621  -76.779  46.534  1
220635  99.630  -76.776  46.505  1
220636  99.650  -76.778  46.476  1
220637  99.672  -76.781  46.449  1
220638  99.693  -76.784  46.423  1
220639  99.714  -76.787  46.398  1
220640  99.736  -76.789  46.374  1
220641  99.757  -76.792  46.349  1
220642  99.779  -76.794  46.324  1
220643  99.800  -76.797  46.298  1
220644  99.822  -76.799  46.271  1
220645  99.843  -76.802  46.244  1
220646  99.865  -76.806  46.217  1
220647  99.887  -76.808  46.188  1
220648  99.908  -76.811  46.158  1
220649  99.936  -76.816  46.128  1
220650  99.968  -76.824  46.099  1
220651  99.999  -76.831  46.071  1
220652  100.031  -76.837  46.044  1
220653  100.062  -76.844  46.019  1
220654  100.093  -76.852  45.994  1
220655  100.125  -76.859  45.969  1
220656  100.156  -76.865  45.945  1
220657  100.187  -76.872  45.922  1
220658  100.219  -76.880  45.901  1
220659  100.250  -76.887  45.881  1
220660  100.282  -76.893  45.861  1
220661  100.313  -76.901  45.841  1
220662  100.333  -76.893  45.824  1
220663  100.363  -76.913  45.807  1
220664  100.388  -76.917  45.790  1
220665  100.413  -76.921  45.775  1
220666  100.434  -76.934  45.758  1
220667  100.453  -76.952  45.742  1
220668  100.470  -76.969  45.726  1
220669  100.488  -76.987  45.710  1
220670  100.506  -77.005  45.694  1
220671  100.525  -77.022  45.678  1
220672  100.542  -77.040  45.662  1
220673  100.560  -77.058  45.644  1
220674  100.578  -77.075  45.628  1
220675  100.596  -77.094  45.611  1
220676  100.613  -77.110  45.594  1
220677  100.622  -77.123  45.579  1
220678  100.631  -77.136  45.565  1
220679  100.645  -77.152  45.550  1
220680  100.665  -77.169  45.536  1
220681  100.685  -77.188  45.524  1
220682  100.705  -77.205  45.512  1
220683  100.725  -77.223  45.500  1
220684  100.749  -77.238  45.488  1
220685  100.776  -77.249  45.477  1
220686  100.804  -77.260  45.465  1
220687  100.831  -77.270  45.453  1
220688  100.858  -77.281  45.441  1
220689  100.885  -77.291  45.430  1
220690  100.912  -77.302  45.418  1
220691  100.939  -77.313  45.407  1
220692  100.967  -77.324  45.396  1
220693  100.994  -77.335  45.385  1
220694  101.019  -77.345  45.374  1
220695  101.040  -77.356  45.362  1
220696  101.060  -77.367  45.348  1
220697  101.080  -77.376  45.334  1
220698  101.101  -77.387  45.320  1
220699  101.121  -77.398  45.306  1
220700  101.142  -77.408  45.292  1
220701  101.162  -77.419  45.277  1
220702  101.184  -77.424  45.261  1
220703  101.211  -77.432  45.245  1
220704  101.216  -77.442  45.227  1
220705  101.215  -77.454  45.208  1
220706  101.213  -77.466  45.190  1
220707  101.211  -77.478  45.172  1
220708  101.210  -77.490  45.154  1
220709  101.209  -77.502  45.137  1
220710  101.211  -77.515  45.119  1
220711  101.212  -77.528  45.100  1
220712  101.213  -77.541  45.083  1
220713  101.219  -77.551  45.067  1
220714  101.237  -77.553  45.050  1
220715  101.265  -77.570  45.035  1
220716  101.302  -77.583  45.017  1
220717  101.338  -77.596  45.000  1
220718  101.374  -77.610  44.982  1
220719  101.410  -77.624  44.967  1
220720  101.446  -77.636  44.950  1
220721  101.482  -77.650  44.934  1
220722  101.519  -77.664  44.919  1
220723  101.555  -77.677  44.902  1
220724  101.591  -77.690  44.885  1
220725  101.627  -77.704  44.870  1
220726  101.668  -77.715  44.853  1
220727  101.710  -77.725  44.837  1
220728  101.754  -77.735  44.820  1
220729  101.796  -77.745  44.802  1
220730  101.840  -77.755  44.786  1
220731  101.880  -77.765  44.770  1
220732  101.904  -77.781  44.754  1
220733  101.941  -77.793  44.739  1
220734  101.940  -77.816  44.724  1
220735  101.939  -77.840  44.709  1
220736  101.953  -77.856  44.693  1
220737  101.982  -77.859  44.677  1
220738  102.010  -77.861  44.660  1
220739  102.039  -77.863  44.644  1
220740  102.068  -77.865  44.628  1
220741  102.097  -77.868  44.613  1
220742  102.126  -77.870  44.597  1
220743  102.150  -77.883  44.581  1
220744  102.174  -77.897  44.566  1
220745  102.197  -77.913  44.551  1
220746  102.243  -77.949  44.536  1
220747  102.273  -77.962  44.520  1
220748  102.304  -77.976  44.505  1
220749  102.334  -77.990  44.491  1
220750  102.364  -78.003  44.474  1
220751  102.394  -78.016  44.460  1
220752  102.416  -78.020  44.446  1
220753  102.438  -78.024  44.431  1
220754  102.459  -78.028  44.416  1
220755  102.481  -78.031  44.401  1
220756  102.503  -78.035  44.387  1
220757  102.525  -78.038  44.372  1
220758  102.546  -78.042  44.358  1
220759  102.576  -78.064  44.344  1
220760  102.605  -78.086  44.329  1
220761  102.634  -78.109  44.314  1
220762  102.664  -78.131  44.299  1
220763  102.694  -78.153  44.284  1
220764  102.723  -78.176  44.269  1
220765  102.753  -78.199  44.255  1
220766  102.783  -78.216  44.240  1
220767  102.822  -78.227  44.224  1
220768  102.863  -78.238  44.207  1
220769  102.903  -78.241  44.191  1
220770  102.946  -78.239  44.175  1
220771  102.987  -78.238  44.159  1
220772  103.029  -78.235  44.142  1
220773  103.071  -78.234  44.125  1
220774  103.113  -78.232  44.107  1
220775  103.155  -78.231  44.090  1
220776  103.196  -78.229  44.074  1
220777  103.239  -78.228  44.057  1
220778  103.281  -78.225  44.040  1
221017  92.229  -75.351  54.180  1
221018  92.252  -75.362  54.186  1
221019  92.275  -75.373  54.193  1
221020  92.298  -75.384  54.200  1
221021  92.321  -75.395  54.211  1
221022  92.344  -75.406  54.220  1
221023  92.367  -75.417  54.228  1
221024  92.390  -75.428  54.236  1
221025  92.413  -75.439  54.240  1
221026  92.434  -75.451  54.242  1
221027  92.444  -75.459  54.244  1
221028  92.464  -75.450  54.247  1
221029  92.485  -75.442  54.248  1
221030  92.505  -75.434  54.247  1
221031  92.524  -75.431  54.243  1
221032  92.543  -75.427  54.239  1
221033  92.563  -75.425  54.232  1
221034  92.593  -75.420  54.226  1
221035  92.624  -75.417  54.220  1
221036  92.654  -75.412  54.212  1
221037  92.686  -75.408  54.203  1
221039  92.747  -75.400  54.184  1
221040  92.778  -75.395  54.172  1
221041  92.809  -75.392  54.161  1
221042  92.840  -75.387  54.151  1
221043  92.870  -75.383  54.139  1
221044  92.901  -75.379  54.127  1
221045  92.932  -75.375  54.115  1
221046  92.957  -75.374  54.103  1
221047  92.975  -75.377  54.089  1
221048  92.994  -75.380  54.077  1
221049  93.012  -75.383  54.064  1
221050  93.030  -75.386  54.051  1
221051  93.049  -75.389  54.037  1
221052  93.067  -75.392  54.025  1
221064  93.319  -75.402  53.931  1
221065  93.342  -75.402  53.937  1
221066  93.365  -75.400  53.946  1
221067  93.389  -75.398  53.960  1
221068  93.412  -75.398  53.974  1
221069  93.435  -75.396  53.991  1
221070  93.459  -75.395  54.010  1
221071  93.482  -75.394  54.033  1
221072  93.505  -75.392  54.059  1
221073  93.529  -75.391  54.087  1
221074  93.564  -75.389  54.118  1
221075  93.603  -75.388  54.147  1
221076  93.642  -75.386  54.178  1
221077  93.681  -75.383  54.211  1
221078  93.734  -75.367  54.247  1
221079  93.767  -75.359  54.282  1
221080  93.791  -75.356  54.318  1
221081  93.815  -75.353  54.353  1
221082  93.839  -75.350  54.384  1
221083  93.862  -75.347  54.407  1
221084  93.887  -75.344  54.428  1
221085  93.913  -75.339  54.448  1
221086  93.939  -75.336  54.463  1
221087  93.964  -75.329  54.477  1
221088  93.984  -75.318  54.485  1
221089  94.007  -75.317  54.483  1
221090  94.031  -75.317  54.478  1
221091  94.054  -75.317  54.472  1
221092  94.077  -75.317  54.466  1
221093  94.101  -75.316  54.461  1
221094  94.124  -75.316  54.460  1
221095  94.149  -75.320  54.454  1
221096  94.177  -75.327  54.442  1
221097  94.203  -75.335  54.425  1
221098  94.230  -75.342  54.406  1
221099  94.257  -75.349  54.385  1
221100  94.283  -75.357  54.363  1
221101  94.310  -75.358  54.342  1
221102  94.334  -75.358  54.318  1
221103  94.358  -75.351  54.298  1
221104  94.382  -75.345  54.284  1
221105  94.406  -75.339  54.271  1
221106  94.429  -75.333  54.259  1
221107  94.450  -75.330  54.244  1
221108  94.467  -75.329  54.224  1
221109  94.483  -75.328  54.196  1
221110  94.500  -75.327  54.166  1
221111  94.518  -75.326  54.134  1
221112  94.535  -75.326  54.100  1
221113  94.551  -75.326  54.065  1
221114  94.565  -75.330  54.031  1
221115  94.579  -75.333  53.996  1
221116  94.597  -75.334  53.956  1
221117  94.614  -75.336  53.916  1
221118  94.632  -75.337  53.875  1
221119  94.649  -75.338  53.835  1
221120  94.667  -75.339  53.794  1
221121  94.685  -75.341  53.757  1
221122  94.706  -75.341  53.718  1
221123  94.732  -75.340  53.678  1
221124  94.726  -75.342  53.638  1
221125  94.716  -75.345  53.598  1
221126  94.707  -75.347  53.557  1
221127  94.698  -75.350  53.516  1
221128  94.688  -75.352  53.476  1
221129  94.681  -75.357  53.432  1
221130  94.674  -75.363  53.389  1
221131  94.668  -75.368  53.345  1
221132  94.661  -75.373  53.300  1
221133  94.654  -75.379  53.256  1
221134  94.652  -75.383  53.211  1
221135  94.670  -75.386  53.167  1
221136  94.688  -75.389  53.123  1
221137  94.712  -75.394  53.078  1
221138  94.743  -75.400  53.031  1
221139  94.773  -75.406  52.985  1
221140  94.803  -75.412  52.937  1
221141  94.833  -75.418  52.890  1
221142  94.863  -75.424  52.846  1
221143  94.894  -75.430  52.802  1
221144  94.924  -75.436  52.761  1
221145  94.951  -75.441  52.722  1
221146  94.976  -75.444  52.682  1
221147  95.002  -75.448  52.639  1
221148  95.028  -75.451  52.593  1
221149  95.053  -75.455  52.545  1
221150  95.079  -75.458  52.497  1
221151  95.105  -75.461  52.449  1
221152  95.137  -75.471  52.402  1
221153  95.172  -75.482  52.356  1
221154  95.206  -75.493  52.311  1
221155  95.240  -75.504  52.267  1
221156  95.274  -75.514  52.224  1
221157  95.308  -75.525  52.182  1
221158  95.342  -75.536  52.140  1
221159  95.376  -75.547  52.102  1
221160  95.410  -75.558  52.063  1
221161  95.430  -75.572  52.025  1
221162  95.451  -75.586  51.987  1
221163  95.472  -75.599  51.951  1
221164  95.493  -75.612  51.916  1
221165  95.514  -75.626  51.882  1
221166  95.539  -75.621  51.849  1
221167  95.569  -75.588  51.816  1
221168  95.570  -75.636  51.785  1
221169  95.597  -75.652  51.754  1
221170  95.639  -75.651  51.724  1
221171  95.681  -75.649  51.692  1
221172  95.723  -75.648  51.657  1
221173  95.764  -75.646  51.622  1
221174  95.804  -75.644  51.587  1
221175  95.839  -75.640  51.550  1
221176  95.874  -75.636  51.516  1
221177  95.909  -75.632  51.484  1
221178  95.945  -75.627  51.453  1
221179  95.980  -75.624  51.422  1
221180  96.017  -75.622  51.391  1
221181  96.048  -75.624  51.359  1
221182  96.040  -75.631  51.327  1
221183  96.032  -75.640  51.296  1
221184  96.058  -75.643  51.267  1
221185  96.101  -75.645  51.237  1
221186  96.144  -75.646  51.207  1
221187  96.187  -75.648  51.179  1
221188  96.234  -75.640  51.150  1
221189  96.268  -75.635  51.122  1
221190  96.285  -75.639  51.095  1
221191  96.303  -75.642  51.068  1
221192  96.320  -75.646  51.039  1
221193  96.341  -75.649  51.008  1
221194  96.363  -75.652  50.976  1
221195  96.385  -75.655  50.946  1
221196  96.406  -75.658  50.917  1
221197  96.428  -75.662  50.891  1
221198  96.448  -75.668  50.865  1
221199  96.469  -75.677  50.840  1
221200  96.487  -75.690  50.815  1
221201  96.504  -75.704  50.789  1
221202  96.520  -75.718  50.765  1
221203  96.536  -75.733  50.742  1
221204  96.552  -75.746  50.721  1
221205  96.569  -75.760  50.698  1
221206  96.585  -75.773  50.677  1
221207  96.601  -75.786  50.655  1
221208  96.618  -75.800  50.632  1
221209  96.633  -75.813  50.609  1
221210  96.644  -75.833  50.587  1
221211  96.660  -75.850  50.567  1
221212  96.683  -75.865  50.547  1
221213  96.705  -75.881  50.525  1
221214  96.728  -75.896  50.502  1
221215  96.750  -75.911  50.475  1
221216  96.772  -75.926  50.445  1
221217  96.795  -75.941  50.414  1
221218  96.823  -75.957  50.380  1
221219  96.855  -75.975  50.345  1
221220  96.856  -75.982  50.308  1
221221  96.882  -75.988  50.266  1
221222  96.907  -75.993  50.223  1
221223  96.932  -75.999  50.180  1
221224  96.956  -76.004  50.139  1
221225  96.981  -76.010  50.097  1
221226  97.006  -76.015  50.057  1
221227  97.030  -76.021  50.017  1
221228  97.054  -76.026  49.979  1
221229  97.079  -76.032  49.942  1
221230  97.104  -76.038  49.905  1
221231  97.129  -76.043  49.869  1
221232  97.153  -76.048  49.834  1
221233  97.178  -76.053  49.800  1
221234  97.203  -76.060  49.766  1
221235  97.227  -76.065  49.734  1
221236  97.252  -76.070  49.702  1
221237  97.276  -76.075  49.671  1
221238  97.306  -76.082  49.641  1
221239  97.345  -76.091  49.612  1
221240  97.375  -76.094  49.584  1
221241  97.405  -76.095  49.557  1
221242  97.436  -76.097  49.530  1
221243  97.466  -76.099  49.505  1
221244  97.497  -76.101  49.477  1
221245  97.527  -76.103  49.450  1
221246  97.558  -76.106  49.424  1
221247  97.592  -76.116  49.396  1
221248  97.625  -76.125  49.372  1
221249  97.658  -76.135  49.347  1
221250  97.660  -76.149  49.322  1
221251  97.647  -76.165  49.296  1
221252  97.649  -76.178  49.267  1
221253  97.652  -76.191  49.238  1
221254  97.654  -76.205  49.209  1
221255  97.657  -76.218  49.178  1
221256  97.660  -76.232  49.145  1
221257  97.678  -76.245  49.111  1
221258  97.706  -76.257  49.076  1
221259  97.733  -76.269  49.041  1
221260  97.761  -76.282  49.009  1
221261  97.804  -76.294  48.977  1
221262  97.849  -76.307  48.945  1
221263  97.887  -76.318  48.911  1
221264  97.924  -76.330  48.873  1
221265  97.961  -76.342  48.835  1
221266  97.999  -76.353  48.796  1
221267  98.037  -76.364  48.756  1
221268  98.094  -76.377  48.715  1
221269  98.150  -76.389  48.671  1
221270  98.200  -76.401  48.628  1
221271  98.219  -76.408  48.587  1
221272  98.250  -76.418  48.547  1
221273  98.281  -76.433  48.508  1
221274  98.310  -76.448  48.470  1
221275  98.340  -76.464  48.434  1
221276  98.369  -76.480  48.399  1
221277  98.407  -76.499  48.365  1
221278  98.449  -76.511  48.331  1
221279  98.482  -76.520  48.299  1
221280  98.515  -76.530  48.267  1
221281  98.548  -76.539  48.235  1
221282  98.580  -76.548  48.206  1
221283  98.613  -76.557  48.179  1
221284  98.645  -76.566  48.152  1
221285  98.678  -76.576  48.125  1
221286  98.711  -76.585  48.100  1
221287  98.743  -76.594  48.075  1
221288  98.769  -76.600  48.050  1
221289  98.783  -76.600  48.024  1
221290  98.791  -76.596  48.000  1
221291  98.799  -76.592  47.975  1
221292  98.808  -76.587  47.950  1
221293  98.816  -76.583  47.925  1
221294  98.824  -76.579  47.900  1
221295  98.833  -76.575  47.876  1
221296  98.843  -76.575  47.851  1
221297  98.856  -76.580  47.826  1
221298  98.868  -76.586  47.800  1
221299  98.881  -76.591  47.773  1
221300  98.895  -76.596  47.746  1
221301  98.916  -76.599  47.717  1
221302  98.938  -76.602  47.688  1
221303  98.959  -76.605  47.659  1
221304  98.981  -76.608  47.630  1
221305  99.003  -76.611  47.603  1
221306  99.024  -76.614  47.575  1
221307  99.045  -76.613  47.544  1
221308  99.064  -76.621  47.512  1
221309  99.084  -76.630  47.477  1
221310  99.103  -76.639  47.442  1
221311  99.122  -76.646  47.406  1
221312  99.148  -76.649  47.369  1
221313  99.179  -76.649  47.331  1
221314  99.209  -76.655  47.292  1
221315  99.239  -76.665  47.253  1
221316  99.269  -76.676  47.213  1
221317  99.299  -76.687  47.172  1
221318  99.329  -76.698  47.132  1
221319  99.362  -76.708  47.093  1
221320  99.402  -76.718  47.056  1
221321  99.440  -76.727  47.017  1
221322  99.465  -76.730  46.979  1
221323  99.483  -76.729  46.941  1
221324  99.501  -76.728  46.903  1
221325  99.519  -76.727  46.868  1
221326  99.536  -76.727  46.833  1
221327  99.545  -76.730  46.798  1
221328  99.554  -76.731  46.763  1
221329  99.563  -76.734  46.729  1
221330  99.572  -76.735  46.695  1
221331  99.581  -76.737  46.662  1
221332  99.593  -76.747  46.629  1
221333  99.607  -76.760  46.599  1
221334  99.616  -76.757  46.568  1
221335  99.632  -76.757  46.538  1
221336  99.653  -76.760  46.510  1
221337  99.675  -76.762  46.481  1
221338  99.697  -76.765  46.454  1
221339  99.718  -76.768  46.428  1
221340  99.739  -76.771  46.403  1
221341  99.761  -76.774  46.378  1
221342  99.782  -76.776  46.352  1
221343  99.804  -76.779  46.327  1
221344  99.826  -76.782  46.299  1
221345  99.847  -76.784  46.272  1
221346  99.868  -76.787  46.245  1
221347  99.890  -76.790  46.218  1
221348  99.912  -76.793  46.188  1
221349  99.933  -76.795  46.157  1
221350  99.963  -76.802  46.127  1
221351  99.994  -76.809  46.098  1
221352  100.025  -76.815  46.070  1
221353  100.057  -76.822  46.043  1
221354  100.088  -76.830  46.017  1
221355  100.119  -76.837  45.990  1
221356  100.151  -76.843  45.965  1
221357  100.182  -76.850  45.941  1
221358  100.213  -76.858  45.918  1
221359  100.245  -76.865  45.896  1
221360  100.276  -76.871  45.875  1
221361  100.304  -76.875  45.855  1
221362  100.319  -76.859  45.835  1
221363  100.339  -76.856  45.817  1
221364  100.374  -76.887  45.800  1
221365  100.404  -76.904  45.784  1
221366  100.429  -76.908  45.769  1
221367  100.450  -76.922  45.752  1
221368  100.468  -76.940  45.736  1
221369  100.485  -76.958  45.720  1
221370  100.503  -76.975  45.704  1
221371  100.522  -76.993  45.688  1
221372  100.540  -77.011  45.671  1
221373  100.557  -77.028  45.655  1
221374  100.575  -77.046  45.637  1
221375  100.594  -77.064  45.621  1
221376  100.612  -77.081  45.605  1
221377  100.629  -77.099  45.588  1
221378  100.641  -77.113  45.573  1
221379  100.650  -77.127  45.558  1
221380  100.665  -77.143  45.544  1
221381  100.686  -77.160  45.530  1
221382  100.706  -77.179  45.518  1
221383  100.726  -77.197  45.506  1
221384  100.751  -77.210  45.494  1
221385  100.778  -77.220  45.481  1
221386  100.805  -77.231  45.470  1
221387  100.833  -77.241  45.458  1
221388  100.860  -77.253  45.446  1
221389  100.887  -77.263  45.435  1
221390  100.914  -77.274  45.423  1
221391  100.941  -77.285  45.411  1
221392  100.969  -77.295  45.399  1
221393  100.996  -77.306  45.387  1
221394  101.023  -77.317  45.376  1
221395  101.049  -77.328  45.365  1
221396  101.070  -77.338  45.352  1
221397  101.090  -77.348  45.339  1
221398  101.111  -77.359  45.325  1
221399  101.131  -77.370  45.311  1
221400  101.151  -77.380  45.297  1
221401  101.172  -77.391  45.282  1
221402  101.193  -77.401  45.267  1
221403  101.213  -77.411  45.251  1
221404  101.217  -77.428  45.235  1
221405  101.218  -77.441  45.216  1
221406  101.220  -77.454  45.198  1
221407  101.221  -77.467  45.180  1
221408  101.222  -77.479  45.163  1
221409  101.223  -77.492  45.144  1
221410  101.225  -77.505  45.125  1
221411  101.227  -77.518  45.107  1
221412  101.228  -77.531  45.088  1
221413  101.241  -77.536  45.071  1
221414  101.258  -77.539  45.055  1
221415  101.276  -77.541  45.039  1
221416  101.281  -77.556  45.023  1
221417  101.318  -77.570  45.006  1
221418  101.353  -77.583  44.988  1
221419  101.390  -77.597  44.971  1
221420  101.426  -77.610  44.954  1
221421  101.462  -77.624  44.938  1
221422  101.498  -77.637  44.923  1
221423  101.534  -77.650  44.907  1
221424  101.570  -77.664  44.891  1
221425  101.607  -77.677  44.874  1
221426  101.650  -77.687  44.858  1
221427  101.693  -77.697  44.842  1
221428  101.736  -77.707  44.825  1
221429  101.779  -77.717  44.807  1
221430  101.822  -77.727  44.790  1
221431  101.865  -77.736  44.774  1
221432  101.908  -77.746  44.759  1
221433  101.928  -77.763  44.743  1
221434  101.941  -77.783  44.728  1
221435  101.942  -77.806  44.713  1
221436  101.944  -77.829  44.698  1
221437  101.972  -77.840  44.682  1
221438  102.001  -77.846  44.665  1
221439  102.030  -77.849  44.647  1
221440  102.058  -77.851  44.632  1
221441  102.087  -77.853  44.616  1
221442  102.116  -77.855  44.600  1
221443  102.145  -77.858  44.584  1
221444  102.169  -77.871  44.569  1
221445  102.192  -77.887  44.553  1
221446  102.216  -77.902  44.538  1
221447  102.256  -77.935  44.524  1
221448  102.286  -77.949  44.509  1
221449  102.317  -77.962  44.494  1
221450  102.347  -77.976  44.479  1
221451  102.377  -77.990  44.463  1
221452  102.405  -78.001  44.447  1
221453  102.427  -78.005  44.433  1
221454  102.449  -78.009  44.419  1
221455  102.470  -78.012  44.404  1
221456  102.492  -78.015  44.389  1
221457  102.514  -78.019  44.375  1
221458  102.536  -78.023  44.361  1
221459  102.557  -78.027  44.347  1
221460  102.583  -78.039  44.332  1
221461  102.612  -78.061  44.317  1
221462  102.642  -78.084  44.302  1
221463  102.671  -78.106  44.287  1
221464  102.701  -78.129  44.272  1
221465  102.730  -78.151  44.257  1
221466  102.761  -78.167  44.243  1
221467  102.795  -78.179  44.227  1
221468  102.834  -78.191  44.211  1
221469  102.874  -78.201  44.194  1
221470  102.914  -78.213  44.178  1
221471  102.954  -78.224  44.161  1
221472  102.994  -78.235  44.145  1
221473  103.036  -78.233  44.129  1
221474  103.078  -78.232  44.112  1
221475  103.119  -78.230  44.095  1
221476  103.161  -78.228  44.078  1
221477  103.204  -78.227  44.061  1
221478  103.245  -78.225  44.044  1
221718  92.216  -75.322  54.193  1
221719  92.239  -75.333  54.199  1
221720  92.262  -75.344  54.206  1
221721  92.285  -75.355  54.213  1
221722  92.308  -75.366  54.223  1
221723  92.332  -75.377  54.233  1
221724  92.355  -75.388  54.241  1
221725  92.377  -75.399  54.249  1
221726  92.401  -75.411  54.254  1
221727  92.424  -75.421  54.257  1
221728  92.434  -75.433  54.258  1
221729  92.454  -75.427  54.262  1
221730  92.474  -75.418  54.263  1
221731  92.494  -75.411  54.262  1
221732  92.513  -75.407  54.259  1
221733  92.533  -75.404  54.254  1
221734  92.555  -75.401  54.248  1
221735  92.586  -75.396  54.241  1
221736  92.617  -75.392  54.235  1
221737  92.647  -75.388  54.228  1
221738  92.678  -75.384  54.219  1
221739  92.709  -75.380  54.209  1
221740  92.740  -75.376  54.198  1
221741  92.771  -75.371  54.187  1
221742  92.802  -75.367  54.176  1
221743  92.833  -75.363  54.165  1
221744  92.863  -75.359  54.153  1
221745  92.894  -75.355  54.141  1
221746  92.925  -75.351  54.129  1
221747  92.949  -75.351  54.116  1
221748  92.967  -75.353  54.103  1
221749  92.986  -75.356  54.090  1
221750  93.004  -75.359  54.077  1
221751  93.022  -75.362  54.064  1
221752  93.041  -75.366  54.051  1
221753  93.059  -75.369  54.037  1
221754  93.077  -75.372  54.025  1
221765  93.318  -75.373  53.935  1
221766  93.341  -75.372  53.940  1
221767  93.364  -75.370  53.949  1
221768  93.388  -75.369  53.961  1
221769  93.411  -75.368  53.974  1
221770  93.434  -75.367  53.989  1
221771  93.458  -75.365  54.008  1
221772  93.481  -75.364  54.031  1
221773  93.504  -75.363  54.056  1
221774  93.528  -75.362  54.083  1
221775  93.563  -75.360  54.113  1
221776  93.602  -75.358  54.143  1
221777  93.641  -75.357  54.175  1
221778  93.680  -75.355  54.208  1
221779  93.728  -75.342  54.244  1
221780  93.760  -75.336  54.274  1
221781  93.783  -75.333  54.305  1
221782  93.807  -75.330  54.336  1
221783  93.831  -75.326  54.364  1
221784  93.857  -75.323  54.388  1
221785  93.884  -75.318  54.409  1
221786  93.910  -75.314  54.429  1
221787  93.936  -75.311  54.444  1
221788  93.960  -75.302  54.457  1
221789  93.978  -75.286  54.466  1
221790  94.001  -75.286  54.469  1
221791  94.025  -75.285  54.466  1
221792  94.048  -75.285  54.464  1
221793  94.071  -75.284  54.462  1
221794  94.097  -75.286  54.462  1
221795  94.122  -75.289  54.462  1
221796  94.147  -75.289  54.458  1
221797  94.172  -75.291  54.449  1
221798  94.199  -75.301  54.436  1
221799  94.226  -75.311  54.418  1
221800  94.254  -75.321  54.399  1
221801  94.280  -75.330  54.379  1
221802  94.307  -75.337  54.359  1
221803  94.332  -75.334  54.336  1
221804  94.356  -75.328  54.316  1
221805  94.380  -75.322  54.301  1
221806  94.403  -75.315  54.288  1
221807  94.427  -75.309  54.275  1
221808  94.451  -75.303  54.261  1
221809  94.469  -75.301  54.243  1
221810  94.486  -75.301  54.217  1
221811  94.503  -75.300  54.187  1
221812  94.520  -75.299  54.154  1
221813  94.537  -75.298  54.121  1
221814  94.554  -75.298  54.087  1
221815  94.571  -75.298  54.053  1
221816  94.588  -75.297  54.017  1
221817  94.605  -75.298  53.976  1
221818  94.623  -75.300  53.934  1
221819  94.640  -75.301  53.892  1
221820  94.658  -75.302  53.852  1
221821  94.676  -75.304  53.812  1
221822  94.693  -75.305  53.775  1
221823  94.710  -75.306  53.736  1
221824  94.733  -75.306  53.697  1
221825  94.729  -75.308  53.657  1
221826  94.719  -75.311  53.617  1
221827  94.711  -75.314  53.577  1
221828  94.704  -75.320  53.536  1
221829  94.697  -75.326  53.494  1
221830  94.691  -75.331  53.449  1
221831  94.684  -75.336  53.404  1
221832  94.678  -75.342  53.360  1
221833  94.671  -75.347  53.313  1
221834  94.665  -75.352  53.267  1
221835  94.671  -75.357  53.221  1
221836  94.688  -75.359  53.174  1
221837  94.706  -75.362  53.128  1
221838  94.724  -75.365  53.083  1
221839  94.751  -75.370  53.037  1
221840  94.781  -75.377  52.991  1
221841  94.811  -75.383  52.944  1
221842  94.841  -75.389  52.897  1
221843  94.872  -75.395  52.850  1
221844  94.902  -75.401  52.803  1
221845  94.932  -75.407  52.760  1
221846  94.958  -75.410  52.717  1
221847  94.983  -75.414  52.674  1
221848  95.009  -75.417  52.628  1
221849  95.035  -75.420  52.583  1
221850  95.060  -75.424  52.535  1
221851  95.086  -75.427  52.487  1
221852  95.112  -75.430  52.438  1
221853  95.143  -75.439  52.392  1
221854  95.177  -75.449  52.346  1
221855  95.211  -75.461  52.300  1
221856  95.245  -75.471  52.256  1
221857  95.279  -75.483  52.214  1
221858  95.313  -75.493  52.172  1
221859  95.347  -75.504  52.131  1
221860  95.382  -75.515  52.091  1
221861  95.404  -75.528  52.052  1
221862  95.425  -75.542  52.014  1
221863  95.446  -75.555  51.977  1
221864  95.467  -75.569  51.942  1
221865  95.487  -75.583  51.908  1
221866  95.509  -75.596  51.875  1
221867  95.529  -75.610  51.841  1
221868  95.550  -75.624  51.809  1
221869  95.580  -75.627  51.777  1
221870  95.617  -75.623  51.747  1
221871  95.652  -75.619  51.719  1
221872  95.688  -75.615  51.687  1
221873  95.723  -75.611  51.654  1
221874  95.758  -75.607  51.619  1
221875  95.794  -75.602  51.584  1
221876  95.829  -75.599  51.548  1
221877  95.865  -75.594  51.514  1
221878  95.900  -75.590  51.481  1
221879  95.935  -75.587  51.449  1
221880  95.970  -75.582  51.418  1
221881  96.008  -75.581  51.386  1
221882  96.045  -75.582  51.354  1
221883  96.072  -75.584  51.322  1
221884  96.064  -75.592  51.293  1
221885  96.071  -75.599  51.264  1
221886  96.114  -75.600  51.233  1
221887  96.157  -75.602  51.204  1
221888  96.200  -75.603  51.176  1
221889  96.243  -75.605  51.148  1
221890  96.281  -75.611  51.120  1
221891  96.300  -75.616  51.094  1
221892  96.317  -75.620  51.067  1
221893  96.335  -75.623  51.040  1
221894  96.353  -75.627  51.011  1
221895  96.374  -75.630  50.978  1
221896  96.396  -75.633  50.948  1
221897  96.417  -75.636  50.921  1
221898  96.439  -75.639  50.896  1
221899  96.461  -75.642  50.871  1
221900  96.481  -75.647  50.846  1
221901  96.498  -75.661  50.821  1
221902  96.515  -75.674  50.796  1
221903  96.531  -75.687  50.771  1
221904  96.547  -75.699  50.748  1
221905  96.564  -75.713  50.727  1
221906  96.581  -75.726  50.705  1
221907  96.597  -75.739  50.684  1
221908  96.614  -75.752  50.662  1
221909  96.630  -75.765  50.639  1
221910  96.641  -75.784  50.616  1
221911  96.652  -75.804  50.594  1
221912  96.663  -75.824  50.573  1
221913  96.680  -75.840  50.552  1
221914  96.703  -75.856  50.531  1
221915  96.725  -75.871  50.507  1
221916  96.747  -75.886  50.481  1
221917  96.770  -75.901  50.450  1
221918  96.792  -75.916  50.417  1
221919  96.815  -75.931  50.383  1
221920  96.837  -75.946  50.347  1
221921  96.877  -75.956  50.309  1
221922  96.901  -75.962  50.268  1
221923  96.925  -75.968  50.226  1
221924  96.949  -75.974  50.185  1
221925  96.973  -75.980  50.143  1
221926  96.998  -75.986  50.103  1
221927  97.022  -75.992  50.063  1
221928  97.046  -75.998  50.024  1
221929  97.070  -76.003  49.987  1
221930  97.094  -76.010  49.950  1
221931  97.118  -76.016  49.914  1
221932  97.143  -76.022  49.879  1
221933  97.167  -76.028  49.843  1
221934  97.191  -76.034  49.809  1
221935  97.215  -76.040  49.776  1
221936  97.239  -76.045  49.744  1
221937  97.263  -76.051  49.711  1
221938  97.288  -76.057  49.681  1
221939  97.313  -76.063  49.652  1
221940  97.344  -76.065  49.621  1
221941  97.374  -76.067  49.594  1
221942  97.405  -76.069  49.566  1
221943  97.435  -76.071  49.540  1
221944  97.466  -76.072  49.515  1
221945  97.496  -76.075  49.487  1
221946  97.527  -76.076  49.461  1
221947  97.557  -76.079  49.434  1
221948  97.590  -76.088  49.407  1
221949  97.624  -76.097  49.383  1
221950  97.641  -76.110  49.359  1
221951  97.615  -76.127  49.334  1
221952  97.595  -76.144  49.307  1
221953  97.597  -76.157  49.277  1
221954  97.600  -76.171  49.246  1
221955  97.611  -76.184  49.216  1
221956  97.639  -76.196  49.183  1
221957  97.667  -76.208  49.148  1
221958  97.695  -76.221  49.112  1
221959  97.722  -76.233  49.076  1
221960  97.750  -76.245  49.041  1
221961  97.778  -76.257  49.008  1
221962  97.820  -76.270  48.975  1
221963  97.866  -76.283  48.942  1
221964  97.912  -76.296  48.906  1
221965  97.951  -76.307  48.867  1
221966  97.989  -76.320  48.828  1
221967  98.026  -76.331  48.790  1
221968  98.047  -76.345  48.750  1
221969  98.101  -76.349  48.707  1
221970  98.158  -76.362  48.664  1
221971  98.192  -76.371  48.621  1
221972  98.223  -76.383  48.579  1
221973  98.253  -76.398  48.539  1
221974  98.283  -76.414  48.501  1
221975  98.312  -76.430  48.463  1
221976  98.342  -76.446  48.427  1
221977  98.371  -76.462  48.393  1
221978  98.414  -76.482  48.359  1
221979  98.447  -76.491  48.326  1
221980  98.480  -76.500  48.294  1
221981  98.512  -76.509  48.261  1
221982  98.545  -76.518  48.230  1
221983  98.577  -76.528  48.199  1
221984  98.610  -76.537  48.171  1
221985  98.643  -76.546  48.145  1
221986  98.675  -76.555  48.118  1
221987  98.708  -76.564  48.092  1
221988  98.740  -76.571  48.066  1
221989  98.773  -76.579  48.040  1
221990  98.794  -76.582  48.015  1
221991  98.811  -76.583  47.991  1
221992  98.822  -76.580  47.967  1
221993  98.831  -76.576  47.943  1
221994  98.839  -76.571  47.918  1
221995  98.847  -76.567  47.893  1
221996  98.855  -76.563  47.869  1
221997  98.863  -76.559  47.845  1
221998  98.873  -76.558  47.821  1
221999  98.886  -76.563  47.796  1
222000  98.899  -76.568  47.769  1
222001  98.912  -76.574  47.743  1
222002  98.932  -76.577  47.715  1
222003  98.953  -76.580  47.688  1
222004  98.975  -76.583  47.659  1
222005  98.997  -76.586  47.631  1
222006  99.018  -76.589  47.604  1
222007  99.040  -76.591  47.576  1
222008  99.060  -76.592  47.545  1
222009  99.079  -76.596  47.513  1
222010  99.098  -76.602  47.479  1
222011  99.117  -76.610  47.444  1
222012  99.136  -76.617  47.409  1
222013  99.162  -76.619  47.372  1
222014  99.193  -76.619  47.334  1
222015  99.222  -76.629  47.295  1
222016  99.253  -76.640  47.256  1
222017  99.283  -76.650  47.216  1
222018  99.313  -76.661  47.175  1
222019  99.343  -76.672  47.136  1
222020  99.373  -76.683  47.098  1
222021  99.404  -76.693  47.061  1
222022  99.433  -76.705  47.022  1
222023  99.472  -76.715  46.983  1
222024  99.501  -76.719  46.945  1
222025  99.519  -76.718  46.907  1
222026  99.537  -76.718  46.872  1
222027  99.546  -76.720  46.837  1
222028  99.555  -76.721  46.802  1
222029  99.564  -76.724  46.767  1
222030  99.573  -76.725  46.733  1
222031  99.582  -76.727  46.699  1
222032  99.591  -76.729  46.665  1
222033  99.600  -76.731  46.633  1
222034  99.614  -76.737  46.603  1
222035  99.636  -76.739  46.572  1
222036  99.657  -76.742  46.542  1
222037  99.679  -76.744  46.514  1
222038  99.700  -76.747  46.486  1
222039  99.722  -76.750  46.459  1
222040  99.743  -76.752  46.434  1
222041  99.765  -76.755  46.408  1
222042  99.786  -76.758  46.381  1
222043  99.807  -76.761  46.355  1
222044  99.829  -76.764  46.329  1
222045  99.851  -76.766  46.301  1
222046  99.872  -76.769  46.274  1
222047  99.894  -76.771  46.247  1
222048  99.915  -76.774  46.217  1
222049  99.936  -76.777  46.186  1
222050  99.958  -76.780  46.156  1
222051  99.989  -76.787  46.126  1
222052  100.020  -76.793  46.096  1
222053  100.051  -76.800  46.069  1
222054  100.083  -76.808  46.042  1
222055  100.114  -76.815  46.015  1
222056  100.145  -76.821  45.987  1
222057  100.177  -76.828  45.962  1
222058  100.208  -76.836  45.937  1
222059  100.240  -76.843  45.914  1
222060  100.271  -76.850  45.891  1
222061  100.293  -76.843  45.870  1
222062  100.307  -76.828  45.850  1
222063  100.321  -76.812  45.830  1
222064  100.346  -76.818  45.812  1
222065  100.381  -76.849  45.795  1
222066  100.416  -76.879  45.778  1
222067  100.445  -76.895  45.763  1
222068  100.465  -76.911  45.746  1
222069  100.483  -76.928  45.730  1
222070  100.501  -76.946  45.714  1
222071  100.519  -76.964  45.698  1
222072  100.537  -76.981  45.681  1
222073  100.555  -76.999  45.665  1
222074  100.573  -77.017  45.648  1
222075  100.591  -77.034  45.631  1
222076  100.609  -77.052  45.615  1
222077  100.627  -77.070  45.598  1
222078  100.644  -77.088  45.582  1
222079  100.661  -77.104  45.566  1
222080  100.670  -77.117  45.552  1
222081  100.687  -77.134  45.538  1
222082  100.707  -77.152  45.525  1
222083  100.727  -77.169  45.512  1
222084  100.754  -77.181  45.500  1
222085  100.781  -77.191  45.488  1
222086  100.808  -77.203  45.475  1
222087  100.835  -77.213  45.463  1
222088  100.862  -77.224  45.451  1
222089  100.890  -77.235  45.440  1
222090  100.917  -77.245  45.428  1
222091  100.944  -77.257  45.416  1
222092  100.971  -77.267  45.404  1
222093  100.998  -77.278  45.392  1
222094  101.025  -77.288  45.381  1
222095  101.053  -77.299  45.368  1
222096  101.079  -77.310  45.356  1
222097  101.100  -77.320  45.343  1
222098  101.120  -77.331  45.331  1
222099  101.141  -77.341  45.315  1
222100  101.162  -77.352  45.301  1
222101  101.182  -77.362  45.287  1
222102  101.202  -77.373  45.272  1
222103  101.218  -77.390  45.257  1
222104  101.229  -77.415  45.241  1
222105  101.233  -77.431  45.224  1
222106  101.234  -77.444  45.206  1
222107  101.236  -77.457  45.188  1
222108  101.237  -77.470  45.170  1
222109  101.238  -77.483  45.152  1
222110  101.240  -77.495  45.133  1
222111  101.241  -77.508  45.115  1
222112  101.244  -77.520  45.096  1
222113  101.262  -77.522  45.078  1
222114  101.279  -77.524  45.060  1
222115  101.297  -77.526  45.044  1
222116  101.315  -77.529  45.028  1
222117  101.332  -77.531  45.011  1
222118  101.333  -77.557  44.994  1
222119  101.370  -77.570  44.976  1
222120  101.405  -77.583  44.959  1
222121  101.442  -77.597  44.942  1
222122  101.478  -77.611  44.926  1
222123  101.514  -77.624  44.911  1
222124  101.550  -77.637  44.895  1
222125  101.589  -77.649  44.880  1
222126  101.632  -77.659  44.863  1
222127  101.675  -77.669  44.846  1
222128  101.718  -77.679  44.830  1
222129  101.761  -77.689  44.812  1
222130  101.804  -77.699  44.795  1
222131  101.842  -77.710  44.779  1
222132  101.879  -77.722  44.763  1
222133  101.915  -77.733  44.748  1
222134  101.930  -77.755  44.733  1
222135  101.946  -77.773  44.717  1
222136  101.948  -77.796  44.701  1
222137  101.963  -77.812  44.685  1
222138  101.991  -77.824  44.669  1
222139  102.020  -77.834  44.652  1
222140  102.049  -77.837  44.635  1
222141  102.078  -77.840  44.619  1
222142  102.106  -77.842  44.603  1
222143  102.135  -77.844  44.587  1
222144  102.164  -77.846  44.572  1
222145  102.187  -77.861  44.557  1
222146  102.211  -77.876  44.542  1
222147  102.234  -77.890  44.526  1
222148  102.257  -77.906  44.512  1
222149  102.299  -77.936  44.497  1
222150  102.329  -77.949  44.482  1
222151  102.360  -77.963  44.467  1
222152  102.390  -77.977  44.451  1
222153  102.416  -77.986  44.436  1
222154  102.438  -77.990  44.421  1
222155  102.460  -77.993  44.407  1
222156  102.481  -77.996  44.393  1
222157  102.504  -78.000  44.378  1
222158  102.525  -78.004  44.363  1
222159  102.547  -78.008  44.350  1
222160  102.569  -78.012  44.336  1
222161  102.591  -78.015  44.320  1
222162  102.619  -78.037  44.305  1
222163  102.649  -78.059  44.291  1
222164  102.678  -78.081  44.275  1
222165  102.708  -78.104  44.260  1
222166  102.739  -78.119  44.245  1
222167  102.769  -78.131  44.231  1
222168  102.807  -78.143  44.214  1
222169  102.846  -78.153  44.198  1
222170  102.886  -78.165  44.181  1
222171  102.926  -78.176  44.165  1
222172  102.966  -78.187  44.149  1
222173  103.006  -78.198  44.132  1
222174  103.046  -78.210  44.115  1
222175  103.086  -78.221  44.099  1
222176  103.126  -78.228  44.082  1
222177  103.168  -78.226  44.065  1
222178  103.210  -78.225  44.048  1
222179  103.252  -78.222  44.031  1
222419  92.204  -75.292  54.205  1
222420  92.227  -75.304  54.211  1
222421  92.249  -75.314  54.217  1
222422  92.273  -75.326  54.224  1
222423  92.296  -75.337  54.235  1
222424  92.319  -75.348  54.245  1
222425  92.342  -75.359  54.253  1
222426  92.365  -75.370  54.260  1
222427  92.388  -75.381  54.266  1
222428  92.411  -75.392  54.270  1
222429  92.428  -75.404  54.272  1
222430  92.443  -75.403  54.277  1
222431  92.463  -75.394  54.278  1
222432  92.484  -75.386  54.277  1
222433  92.503  -75.383  54.275  1
222434  92.522  -75.380  54.269  1
222435  92.548  -75.377  54.263  1
222436  92.579  -75.373  54.256  1
222437  92.609  -75.368  54.250  1
222438  92.640  -75.364  54.243  1
222439  92.671  -75.360  54.234  1
222440  92.702  -75.356  54.224  1
222441  92.733  -75.352  54.213  1
222442  92.764  -75.348  54.201  1
222443  92.794  -75.343  54.189  1
222444  92.826  -75.339  54.178  1
222445  92.856  -75.335  54.166  1
222446  92.887  -75.331  54.154  1
222447  92.918  -75.326  54.142  1
222448  92.941  -75.327  54.129  1
222449  92.959  -75.330  54.116  1
222450  92.978  -75.333  54.103  1
222451  92.996  -75.336  54.090  1
222452  93.014  -75.339  54.077  1
222453  93.032  -75.342  54.064  1
222454  93.051  -75.345  54.051  1
222455  93.069  -75.349  54.037  1
222456  93.087  -75.352  54.023  1
222466  93.317  -75.343  53.941  1
222467  93.340  -75.342  53.945  1
222468  93.363  -75.341  53.951  1
222469  93.387  -75.339  53.963  1
222470  93.410  -75.339  53.975  1
222471  93.433  -75.337  53.989  1
222472  93.457  -75.336  54.007  1
222473  93.480  -75.335  54.029  1
222474  93.503  -75.333  54.054  1
222475  93.526  -75.333  54.081  1
222476  93.562  -75.330  54.111  1
222477  93.601  -75.329  54.142  1
222478  93.640  -75.327  54.176  1
222479  93.679  -75.325  54.213  1
222480  93.723  -75.317  54.248  1
222481  93.753  -75.311  54.276  1
222482  93.776  -75.308  54.302  1
222483  93.801  -75.305  54.328  1
222484  93.828  -75.301  54.351  1
222485  93.854  -75.297  54.372  1
222486  93.880  -75.293  54.391  1
222487  93.907  -75.289  54.409  1
222488  93.933  -75.286  54.423  1
222489  93.956  -75.276  54.434  1
222490  93.974  -75.259  54.443  1
222491  93.995  -75.253  54.446  1
222492  94.018  -75.253  54.447  1
222493  94.044  -75.254  54.447  1
222494  94.069  -75.257  54.449  1
222495  94.096  -75.260  54.453  1
222496  94.121  -75.262  54.457  1
222497  94.146  -75.262  54.456  1
222498  94.170  -75.260  54.452  1
222499  94.195  -75.262  54.445  1
222500  94.222  -75.272  54.431  1
222501  94.249  -75.283  54.415  1
222502  94.276  -75.292  54.397  1
222503  94.303  -75.302  54.376  1
222504  94.329  -75.307  54.355  1
222505  94.353  -75.305  54.336  1
222506  94.377  -75.298  54.319  1
222507  94.401  -75.292  54.303  1
222508  94.424  -75.286  54.291  1
222509  94.448  -75.279  54.278  1
222510  94.471  -75.274  54.261  1
222511  94.488  -75.273  54.237  1
222512  94.505  -75.273  54.207  1
222513  94.522  -75.272  54.175  1
222514  94.539  -75.272  54.143  1
222515  94.556  -75.271  54.109  1
222516  94.572  -75.270  54.074  1
222517  94.586  -75.270  54.036  1
222518  94.600  -75.271  53.994  1
222519  94.619  -75.271  53.951  1
222520  94.638  -75.271  53.909  1
222521  94.657  -75.272  53.869  1
222522  94.676  -75.272  53.831  1
222523  94.696  -75.273  53.794  1
222524  94.715  -75.273  53.756  1
222525  94.734  -75.273  53.716  1
222526  94.734  -75.277  53.676  1
222527  94.728  -75.283  53.636  1
222528  94.721  -75.289  53.596  1
222529  94.714  -75.294  53.555  1
222530  94.707  -75.299  53.511  1
222531  94.701  -75.305  53.465  1
222532  94.694  -75.310  53.419  1
222533  94.688  -75.315  53.373  1
222534  94.681  -75.320  53.325  1
222535  94.675  -75.326  53.278  1
222536  94.689  -75.330  53.231  1
222537  94.707  -75.332  53.183  1
222538  94.724  -75.335  53.135  1
222539  94.743  -75.338  53.089  1
222540  94.760  -75.341  53.044  1
222541  94.789  -75.346  52.998  1
222542  94.820  -75.352  52.951  1
222543  94.850  -75.358  52.904  1
222544  94.880  -75.364  52.856  1
222545  94.910  -75.370  52.807  1
222546  94.938  -75.376  52.760  1
222547  94.965  -75.380  52.714  1
222548  94.990  -75.383  52.668  1
222549  95.016  -75.386  52.621  1
222550  95.042  -75.389  52.575  1
222551  95.067  -75.393  52.527  1
222552  95.093  -75.396  52.478  1
222553  95.119  -75.400  52.430  1
222554  95.148  -75.407  52.382  1
222555  95.182  -75.417  52.336  1
222556  95.216  -75.428  52.290  1
222557  95.251  -75.439  52.247  1
222558  95.284  -75.450  52.205  1
222559  95.319  -75.461  52.163  1
222560  95.353  -75.472  52.122  1
222561  95.378  -75.485  52.082  1
222562  95.399  -75.499  52.042  1
222563  95.420  -75.512  52.004  1
222564  95.441  -75.526  51.967  1
222565  95.461  -75.539  51.933  1
222566  95.482  -75.552  51.899  1
222567  95.503  -75.566  51.867  1
222568  95.525  -75.579  51.834  1
222569  95.549  -75.590  51.802  1
222570  95.577  -75.587  51.771  1
222571  95.607  -75.581  51.740  1
222572  95.642  -75.577  51.712  1
222573  95.678  -75.574  51.680  1
222574  95.713  -75.569  51.648  1
222575  95.748  -75.565  51.615  1
222576  95.784  -75.561  51.581  1
222577  95.819  -75.557  51.547  1
222578  95.854  -75.553  51.513  1
222579  95.890  -75.549  51.479  1
222580  95.925  -75.545  51.447  1
222581  95.961  -75.541  51.415  1
222582  95.998  -75.541  51.383  1
222583  96.035  -75.542  51.351  1
222584  96.073  -75.542  51.319  1
222585  96.096  -75.545  51.289  1
222586  96.088  -75.553  51.260  1
222587  96.126  -75.555  51.231  1
222588  96.169  -75.557  51.202  1
222589  96.212  -75.558  51.174  1
222590  96.253  -75.565  51.146  1
222591  96.289  -75.577  51.119  1
222592  96.310  -75.586  51.093  1
222593  96.330  -75.595  51.067  1
222594  96.349  -75.601  51.040  1
222595  96.367  -75.604  51.011  1
222596  96.386  -75.608  50.981  1
222597  96.407  -75.611  50.952  1
222598  96.429  -75.614  50.925  1
222599  96.450  -75.617  50.901  1
222600  96.471  -75.620  50.876  1
222601  96.490  -75.623  50.852  1
222602  96.509  -75.630  50.827  1
222603  96.527  -75.640  50.802  1
222604  96.543  -75.652  50.779  1
222605  96.560  -75.665  50.756  1
222606  96.577  -75.678  50.734  1
222607  96.593  -75.692  50.713  1
222608  96.609  -75.705  50.691  1
222609  96.626  -75.718  50.668  1
222610  96.638  -75.736  50.645  1
222611  96.649  -75.756  50.621  1
222612  96.659  -75.775  50.599  1
222613  96.670  -75.795  50.578  1
222614  96.681  -75.815  50.557  1
222615  96.700  -75.831  50.536  1
222616  96.723  -75.846  50.512  1
222617  96.745  -75.861  50.485  1
222618  96.767  -75.876  50.455  1
222619  96.790  -75.891  50.420  1
222620  96.812  -75.906  50.384  1
222621  96.834  -75.921  50.347  1
222622  96.893  -75.927  50.310  1
222623  96.924  -75.933  50.269  1
222624  96.948  -75.939  50.229  1
222625  96.972  -75.944  50.189  1
222626  96.997  -75.950  50.148  1
222627  97.021  -75.956  50.108  1
222628  97.045  -75.963  50.070  1
222629  97.069  -75.969  50.033  1
222630  97.093  -75.975  49.996  1
222631  97.117  -75.981  49.960  1
222632  97.142  -75.986  49.924  1
222633  97.165  -75.992  49.889  1
222634  97.189  -75.998  49.854  1
222635  97.214  -76.004  49.819  1
222636  97.238  -76.010  49.786  1
222637  97.262  -76.016  49.753  1
222638  97.286  -76.022  49.720  1
222639  97.307  -76.029  49.690  1
222640  97.330  -76.039  49.660  1
222641  97.370  -76.041  49.631  1
222642  97.384  -76.041  49.603  1
222643  97.404  -76.042  49.575  1
222644  97.434  -76.044  49.549  1
222645  97.465  -76.046  49.523  1
222646  97.495  -76.047  49.497  1
222647  97.526  -76.050  49.471  1
222648  97.556  -76.051  49.445  1
222649  97.589  -76.060  49.419  1
222650  97.621  -76.070  49.394  1
222651  97.596  -76.088  49.369  1
222652  97.571  -76.105  49.343  1
222653  97.546  -76.123  49.315  1
222654  97.572  -76.135  49.285  1
222655  97.600  -76.148  49.253  1
222656  97.628  -76.160  49.220  1
222657  97.656  -76.173  49.186  1
222658  97.683  -76.185  49.150  1
222659  97.711  -76.197  49.113  1
222660  97.739  -76.209  49.074  1
222661  97.767  -76.221  49.039  1
222662  97.795  -76.234  49.004  1
222663  97.837  -76.246  48.969  1
222664  97.883  -76.259  48.934  1
222665  97.929  -76.272  48.897  1
222666  97.974  -76.285  48.859  1
222667  98.016  -76.297  48.820  1
222668  98.054  -76.308  48.781  1
222669  98.072  -76.323  48.739  1
222670  98.096  -76.333  48.697  1
222671  98.166  -76.335  48.654  1
222672  98.196  -76.349  48.612  1
222673  98.225  -76.365  48.570  1
222674  98.254  -76.381  48.530  1
222675  98.284  -76.397  48.491  1
222676  98.314  -76.413  48.454  1
222677  98.343  -76.429  48.419  1
222678  98.373  -76.445  48.386  1
222679  98.412  -76.461  48.353  1
222680  98.444  -76.471  48.320  1
222681  98.477  -76.480  48.287  1
222682  98.509  -76.489  48.255  1
222683  98.542  -76.499  48.223  1
222684  98.575  -76.508  48.192  1
222685  98.607  -76.516  48.164  1
222686  98.640  -76.523  48.136  1
222687  98.672  -76.530  48.110  1
222688  98.704  -76.538  48.083  1
222689  98.736  -76.546  48.058  1
222690  98.769  -76.552  48.032  1
222691  98.791  -76.555  48.006  1
222692  98.808  -76.556  47.983  1
222693  98.826  -76.558  47.959  1
222694  98.843  -76.558  47.935  1
222695  98.860  -76.559  47.911  1
222696  98.870  -76.555  47.887  1
222697  98.878  -76.552  47.863  1
222698  98.886  -76.547  47.840  1
222699  98.895  -76.543  47.815  1
222700  98.903  -76.540  47.791  1
222701  98.916  -76.546  47.765  1
222702  98.929  -76.551  47.740  1
222703  98.947  -76.555  47.714  1
222704  98.969  -76.558  47.687  1
222705  98.991  -76.561  47.659  1
222706  99.012  -76.564  47.631  1
222707  99.033  -76.565  47.605  1
222708  99.053  -76.566  47.576  1
222709  99.073  -76.567  47.545  1
222710  99.092  -76.567  47.513  1
222711  99.112  -76.574  47.479  1
222712  99.131  -76.580  47.445  1
222713  99.149  -76.587  47.410  1
222714  99.176  -76.589  47.374  1
222715  99.206  -76.592  47.335  1
222716  99.236  -76.602  47.297  1
222717  99.267  -76.614  47.258  1
222718  99.297  -76.624  47.219  1
222719  99.327  -76.635  47.179  1
222720  99.357  -76.646  47.140  1
222721  99.387  -76.657  47.103  1
222722  99.417  -76.668  47.066  1
222723  99.447  -76.679  47.026  1
222724  99.478  -76.690  46.988  1
222725  99.508  -76.700  46.950  1
222726  99.538  -76.708  46.913  1
222727  99.548  -76.710  46.877  1
222728  99.558  -76.712  46.841  1
222729  99.569  -76.714  46.806  1
222730  99.581  -76.715  46.771  1
222731  99.592  -76.717  46.737  1
222732  99.604  -76.718  46.702  1
222733  99.616  -76.720  46.669  1
222734  99.627  -76.721  46.637  1
222735  99.642  -76.722  46.606  1
222736  99.661  -76.724  46.577  1
222737  99.683  -76.726  46.548  1
222738  99.704  -76.729  46.520  1
222739  99.725  -76.732  46.492  1
222740  99.747  -76.734  46.465  1
222741  99.768  -76.737  46.439  1
222742  99.790  -76.740  46.412  1
222743  99.811  -76.743  46.385  1
222744  99.833  -76.746  46.358  1
222745  99.854  -76.748  46.331  1
222746  99.876  -76.751  46.303  1
222747  99.897  -76.753  46.275  1
222748  99.919  -76.756  46.246  1
222749  99.940  -76.759  46.217  1
222750  99.962  -76.762  46.187  1
222751  99.983  -76.765  46.156  1
222752  100.015  -76.771  46.126  1
222753  100.046  -76.778  46.095  1
222754  100.077  -76.785  46.067  1
222755  100.109  -76.793  46.040  1
222756  100.140  -76.799  46.013  1
222757  100.171  -76.806  45.985  1
222758  100.203  -76.814  45.959  1
222759  100.234  -76.821  45.934  1
222760  100.266  -76.828  45.910  1
222761  100.281  -76.812  45.887  1
222762  100.295  -76.796  45.865  1
222763  100.310  -76.781  45.845  1
222764  100.324  -76.765  45.826  1
222765  100.352  -76.781  45.807  1
222766  100.388  -76.812  45.789  1
222767  100.423  -76.842  45.773  1
222768  100.456  -76.873  45.757  1
222769  100.480  -76.897  45.741  1
222770  100.498  -76.916  45.724  1
222771  100.516  -76.934  45.708  1
222772  100.534  -76.952  45.691  1
222773  100.552  -76.970  45.675  1
222774  100.570  -76.987  45.659  1
222775  100.588  -77.005  45.642  1
222776  100.606  -77.023  45.625  1
222777  100.624  -77.041  45.609  1
222778  100.642  -77.058  45.592  1
222779  100.660  -77.076  45.576  1
222780  100.678  -77.094  45.560  1
222781  100.689  -77.108  45.546  1
222782  100.707  -77.125  45.532  1
222783  100.728  -77.142  45.519  1
222784  100.756  -77.153  45.507  1
222785  100.783  -77.163  45.495  1
222786  100.810  -77.174  45.482  1
222787  100.837  -77.185  45.468  1
222788  100.864  -77.195  45.456  1
222789  100.892  -77.207  45.445  1
222790  100.919  -77.217  45.433  1
222791  100.946  -77.228  45.422  1
222792  100.973  -77.238  45.409  1
222793  101.000  -77.249  45.398  1
222794  101.028  -77.260  45.387  1
222795  101.055  -77.271  45.376  1
222796  101.082  -77.282  45.363  1
222797  101.109  -77.292  45.350  1
222798  101.130  -77.303  45.337  1
222799  101.150  -77.313  45.323  1
222800  101.171  -77.324  45.308  1
222801  101.191  -77.334  45.293  1
222802  101.212  -77.345  45.278  1
222803  101.223  -77.369  45.263  1
222804  101.234  -77.394  45.247  1
222805  101.245  -77.419  45.230  1
222806  101.249  -77.434  45.213  1
222807  101.250  -77.447  45.196  1
222808  101.251  -77.460  45.178  1
222809  101.252  -77.473  45.160  1
222810  101.254  -77.486  45.141  1
222811  101.255  -77.498  45.123  1
222812  101.265  -77.506  45.104  1
222813  101.283  -77.508  45.085  1
222814  101.301  -77.511  45.067  1
222815  101.318  -77.513  45.049  1
222816  101.336  -77.515  45.032  1
222817  101.353  -77.517  45.016  1
222818  101.371  -77.519  44.999  1
222819  101.389  -77.521  44.982  1
222820  101.385  -77.557  44.964  1
222821  101.421  -77.570  44.946  1
222822  101.458  -77.583  44.930  1
222823  101.493  -77.597  44.914  1
222824  101.530  -77.611  44.898  1
222825  101.571  -77.621  44.883  1
222826  101.614  -77.631  44.867  1
222827  101.657  -77.641  44.850  1
222828  101.700  -77.651  44.834  1
222829  101.737  -77.663  44.817  1
222830  101.773  -77.674  44.800  1
222831  101.810  -77.686  44.784  1
222832  101.846  -77.698  44.768  1
222833  101.882  -77.710  44.752  1
222834  101.918  -77.722  44.736  1
222835  101.932  -77.743  44.721  1
222836  101.946  -77.765  44.706  1
222837  101.954  -77.785  44.690  1
222838  101.983  -77.796  44.674  1
222839  102.011  -77.807  44.657  1
222840  102.039  -77.818  44.640  1
222841  102.068  -77.825  44.623  1
222842  102.097  -77.827  44.608  1
222843  102.125  -77.830  44.592  1
222844  102.154  -77.832  44.576  1
222845  102.183  -77.835  44.560  1
222846  102.206  -77.850  44.546  1
222847  102.230  -77.865  44.531  1
222848  102.253  -77.880  44.515  1
222849  102.276  -77.894  44.500  1
222850  102.312  -77.923  44.485  1
222851  102.342  -77.937  44.470  1
222852  102.373  -77.950  44.456  1
222853  102.403  -77.964  44.441  1
222854  102.427  -77.970  44.426  1
222855  102.449  -77.974  44.411  1
222856  102.471  -77.978  44.396  1
222857  102.493  -77.981  44.382  1
222858  102.515  -77.985  44.367  1
222859  102.536  -77.989  44.353  1
222860  102.558  -77.993  44.339  1
222861  102.580  -77.996  44.323  1
222862  102.602  -78.000  44.309  1
222863  102.626  -78.012  44.294  1
222864  102.656  -78.034  44.279  1
222865  102.685  -78.056  44.264  1
222866  102.716  -78.070  44.249  1
222867  102.747  -78.082  44.233  1
222868  102.778  -78.094  44.218  1
222869  102.818  -78.106  44.202  1
222870  102.858  -78.117  44.185  1
222871  102.898  -78.128  44.168  1
222872  102.938  -78.139  44.152  1
222873  102.978  -78.150  44.136  1
222874  103.018  -78.162  44.119  1
222875  103.057  -78.173  44.103  1
222876  103.098  -78.184  44.086  1
222877  103.138  -78.195  44.070  1
222878  103.177  -78.206  44.053  1
222879  103.217  -78.217  44.035  1
222880  103.258  -78.220  44.019  1
223120  92.191  -75.264  54.214  1
223121  92.214  -75.274  54.220  1
223122  92.237  -75.286  54.227  1
223123  92.260  -75.297  54.234  1
223124  92.283  -75.308  54.245  1
223125  92.306  -75.319  54.255  1
223126  92.330  -75.330  54.264  1
223127  92.352  -75.341  54.272  1
223128  92.375  -75.352  54.279  1
223129  92.399  -75.363  54.283  1
223130  92.421  -75.374  54.285  1
223131  92.433  -75.380  54.290  1
223132  92.453  -75.370  54.293  1
223133  92.473  -75.363  54.292  1
223134  92.493  -75.360  54.290  1
223135  92.512  -75.357  54.284  1
223136  92.541  -75.353  54.277  1
223137  92.572  -75.348  54.271  1
223138  92.602  -75.345  54.265  1
223139  92.633  -75.340  54.258  1
223140  92.664  -75.336  54.249  1
223141  92.695  -75.332  54.239  1
223142  92.726  -75.328  54.227  1
223143  92.757  -75.323  54.215  1
223144  92.787  -75.320  54.203  1
223145  92.818  -75.315  54.192  1
223146  92.849  -75.311  54.180  1
223147  92.880  -75.307  54.168  1
223148  92.911  -75.303  54.155  1
223149  92.933  -75.304  54.142  1
223150  92.951  -75.307  54.130  1
223151  92.970  -75.309  54.117  1
223152  92.988  -75.313  54.104  1
223153  93.006  -75.316  54.091  1
223154  93.024  -75.319  54.077  1
223155  93.043  -75.323  54.063  1
223156  93.061  -75.326  54.049  1
223157  93.082  -75.326  54.035  1
223167  93.315  -75.314  53.947  1
223168  93.339  -75.313  53.949  1
223169  93.362  -75.311  53.955  1
223170  93.385  -75.311  53.965  1
223171  93.409  -75.309  53.977  1
223172  93.432  -75.308  53.990  1
223173  93.455  -75.307  54.007  1
223174  93.478  -75.305  54.028  1
223175  93.502  -75.304  54.052  1
223176  93.525  -75.303  54.080  1
223177  93.561  -75.301  54.112  1
223178  93.600  -75.299  54.144  1
223179  93.639  -75.298  54.180  1
223180  93.678  -75.295  54.222  1
223181  93.717  -75.292  54.258  1
223182  93.745  -75.288  54.284  1
223183  93.772  -75.284  54.306  1
223184  93.798  -75.280  54.328  1
223185  93.825  -75.276  54.345  1
223186  93.851  -75.272  54.362  1
223187  93.877  -75.268  54.378  1
223188  93.904  -75.264  54.394  1
223189  93.930  -75.261  54.405  1
223190  93.952  -75.248  54.415  1
223191  93.970  -75.232  54.422  1
223192  93.990  -75.223  54.426  1
223193  94.016  -75.225  54.430  1
223194  94.042  -75.228  54.433  1
223195  94.068  -75.230  54.436  1
223196  94.094  -75.233  54.443  1
223197  94.120  -75.236  54.450  1
223198  94.145  -75.236  54.453  1
223199  94.169  -75.233  54.453  1
223200  94.192  -75.231  54.451  1
223201  94.217  -75.232  54.442  1
223202  94.244  -75.243  54.431  1
223203  94.271  -75.253  54.417  1
223204  94.298  -75.264  54.397  1
223205  94.325  -75.269  54.378  1
223206  94.349  -75.268  54.359  1
223207  94.373  -75.267  54.341  1
223208  94.398  -75.267  54.322  1
223209  94.422  -75.263  54.306  1
223210  94.445  -75.257  54.292  1
223211  94.469  -75.250  54.277  1
223212  94.490  -75.246  54.254  1
223213  94.507  -75.245  54.226  1
223214  94.524  -75.245  54.195  1
223215  94.541  -75.245  54.162  1
223216  94.556  -75.245  54.127  1
223217  94.570  -75.245  54.092  1
223218  94.584  -75.245  54.055  1
223219  94.599  -75.245  54.013  1
223220  94.613  -75.245  53.970  1
223221  94.630  -75.245  53.928  1
223222  94.649  -75.245  53.888  1
223223  94.668  -75.246  53.851  1
223224  94.688  -75.246  53.814  1
223225  94.707  -75.246  53.776  1
223226  94.728  -75.248  53.736  1
223227  94.744  -75.251  53.695  1
223228  94.738  -75.257  53.654  1
223229  94.731  -75.262  53.613  1
223230  94.724  -75.267  53.570  1
223231  94.717  -75.273  53.526  1
223232  94.711  -75.278  53.479  1
223233  94.704  -75.283  53.431  1
223234  94.698  -75.289  53.383  1
223235  94.691  -75.295  53.335  1
223236  94.689  -75.299  53.288  1
223237  94.707  -75.302  53.241  1
223238  94.725  -75.305  53.194  1
223239  94.743  -75.308  53.145  1
223240  94.761  -75.311  53.097  1
223241  94.779  -75.314  53.051  1
223242  94.797  -75.317  53.006  1
223243  94.828  -75.323  52.959  1
223244  94.858  -75.329  52.911  1
223245  94.888  -75.335  52.862  1
223246  94.918  -75.341  52.812  1
223247  94.946  -75.345  52.762  1
223248  94.971  -75.348  52.713  1
223249  94.997  -75.352  52.665  1
223250  95.023  -75.355  52.617  1
223251  95.049  -75.359  52.568  1
223252  95.074  -75.362  52.519  1
223253  95.100  -75.366  52.471  1
223254  95.126  -75.369  52.422  1
223255  95.154  -75.374  52.374  1
223256  95.188  -75.386  52.327  1
223257  95.222  -75.396  52.282  1
223258  95.256  -75.407  52.239  1
223259  95.290  -75.418  52.197  1
223260  95.324  -75.429  52.155  1
223261  95.352  -75.441  52.113  1
223262  95.373  -75.455  52.074  1
223263  95.394  -75.468  52.034  1
223264  95.414  -75.482  51.995  1
223265  95.435  -75.496  51.958  1
223266  95.456  -75.509  51.925  1
223267  95.477  -75.522  51.892  1
223268  95.501  -75.533  51.859  1
223269  95.526  -75.543  51.828  1
223270  95.550  -75.554  51.796  1
223271  95.578  -75.551  51.764  1
223272  95.606  -75.543  51.733  1
223273  95.635  -75.536  51.704  1
223274  95.668  -75.532  51.673  1
223275  95.703  -75.527  51.642  1
223276  95.739  -75.524  51.611  1
223277  95.774  -75.519  51.578  1
223278  95.809  -75.515  51.545  1
223279  95.845  -75.511  51.511  1
223280  95.880  -75.507  51.478  1
223281  95.915  -75.503  51.446  1
223282  95.952  -75.501  51.413  1
223283  95.989  -75.501  51.381  1
223284  96.026  -75.502  51.350  1
223285  96.063  -75.502  51.318  1
223286  96.101  -75.502  51.288  1
223287  96.120  -75.505  51.259  1
223288  96.138  -75.510  51.230  1
223289  96.182  -75.512  51.202  1
223290  96.223  -75.517  51.174  1
223291  96.259  -75.530  51.146  1
223292  96.295  -75.543  51.120  1
223293  96.318  -75.552  51.093  1
223294  96.339  -75.561  51.067  1
223295  96.359  -75.570  51.041  1
223296  96.380  -75.578  51.013  1
223297  96.399  -75.586  50.984  1
223298  96.418  -75.589  50.957  1
223299  96.440  -75.592  50.931  1
223300  96.459  -75.595  50.907  1
223301  96.479  -75.598  50.883  1
223302  96.498  -75.600  50.858  1
223303  96.517  -75.608  50.833  1
223304  96.535  -75.615  50.809  1
223305  96.553  -75.624  50.786  1
223306  96.572  -75.631  50.764  1
223307  96.589  -75.644  50.742  1
223308  96.605  -75.657  50.720  1
223309  96.622  -75.671  50.698  1
223310  96.635  -75.687  50.675  1
223311  96.646  -75.707  50.651  1
223312  96.656  -75.727  50.627  1
223313  96.667  -75.746  50.604  1
223314  96.678  -75.766  50.583  1
223315  96.688  -75.786  50.561  1
223316  96.699  -75.806  50.540  1
223317  96.721  -75.821  50.515  1
223318  96.743  -75.836  50.487  1
223319  96.765  -75.851  50.456  1
223320  96.788  -75.866  50.422  1
223321  96.810  -75.881  50.385  1
223322  96.842  -75.894  50.348  1
223323  96.906  -75.898  50.311  1
223324  96.947  -75.903  50.271  1
223325  96.971  -75.909  50.232  1
223326  96.996  -75.916  50.194  1
223327  97.019  -75.922  50.154  1
223328  97.043  -75.927  50.116  1
223329  97.068  -75.933  50.078  1
223330  97.092  -75.939  50.042  1
223331  97.116  -75.945  50.006  1
223332  97.140  -75.951  49.970  1
223333  97.164  -75.957  49.935  1
223334  97.188  -75.963  49.900  1
223335  97.213  -75.969  49.865  1
223336  97.237  -75.975  49.830  1
223337  97.259  -75.981  49.796  1
223338  97.281  -75.988  49.763  1
223339  97.302  -75.995  49.730  1
223340  97.323  -76.002  49.700  1
223341  97.348  -76.016  49.670  1
223342  97.384  -76.019  49.640  1
223343  97.427  -76.019  49.612  1
223344  97.451  -76.018  49.584  1
223345  97.460  -76.019  49.557  1
223346  97.468  -76.019  49.532  1
223347  97.494  -76.021  49.506  1
223348  97.525  -76.023  49.480  1
223349  97.555  -76.025  49.455  1
223350  97.588  -76.032  49.431  1
223351  97.577  -76.048  49.406  1
223352  97.569  -76.069  49.381  1
223353  97.581  -76.083  49.354  1
223354  97.582  -76.092  49.324  1
223355  97.590  -76.110  49.292  1
223356  97.616  -76.124  49.259  1
223357  97.645  -76.136  49.225  1
223358  97.672  -76.148  49.189  1
223359  97.700  -76.160  49.151  1
223360  97.728  -76.173  49.113  1
223361  97.756  -76.185  49.073  1
223362  97.784  -76.198  49.036  1
223363  97.811  -76.210  49.000  1
223364  97.854  -76.223  48.963  1
223365  97.899  -76.235  48.925  1
223366  97.945  -76.248  48.888  1
223367  97.991  -76.260  48.849  1
223368  98.036  -76.273  48.810  1
223369  98.081  -76.286  48.770  1
223370  98.096  -76.301  48.728  1
223371  98.096  -76.326  48.686  1
223372  98.180  -76.344  48.644  1
223373  98.211  -76.354  48.602  1
223374  98.236  -76.363  48.561  1
223375  98.262  -76.372  48.521  1
223376  98.287  -76.381  48.482  1
223377  98.315  -76.395  48.445  1
223378  98.345  -76.411  48.411  1
223379  98.375  -76.427  48.378  1
223380  98.409  -76.442  48.346  1
223381  98.441  -76.451  48.313  1
223382  98.474  -76.460  48.281  1
223383  98.506  -76.467  48.249  1
223384  98.539  -76.474  48.216  1
223385  98.571  -76.482  48.185  1
223386  98.603  -76.489  48.155  1
223387  98.636  -76.497  48.127  1
223388  98.668  -76.504  48.101  1
223389  98.701  -76.511  48.075  1
223390  98.733  -76.519  48.049  1
223391  98.766  -76.527  48.023  1
223392  98.788  -76.529  47.998  1
223393  98.805  -76.530  47.974  1
223394  98.822  -76.531  47.951  1
223395  98.840  -76.532  47.927  1
223396  98.857  -76.533  47.904  1
223397  98.874  -76.533  47.881  1
223398  98.892  -76.535  47.858  1
223399  98.909  -76.536  47.834  1
223400  98.917  -76.531  47.809  1
223401  98.925  -76.527  47.786  1
223402  98.934  -76.523  47.762  1
223403  98.946  -76.529  47.737  1
223404  98.963  -76.533  47.713  1
223405  98.985  -76.536  47.686  1
223406  99.006  -76.539  47.659  1
223407  99.026  -76.539  47.632  1
223408  99.046  -76.540  47.604  1
223409  99.066  -76.541  47.574  1
223410  99.086  -76.541  47.543  1
223411  99.106  -76.542  47.511  1
223412  99.125  -76.544  47.478  1
223413  99.144  -76.551  47.443  1
223414  99.163  -76.558  47.408  1
223415  99.190  -76.560  47.372  1
223416  99.220  -76.566  47.336  1
223417  99.251  -76.577  47.298  1
223418  99.281  -76.588  47.260  1
223419  99.311  -76.599  47.221  1
223420  99.341  -76.609  47.181  1
223421  99.371  -76.620  47.143  1
223422  99.401  -76.631  47.106  1
223423  99.431  -76.642  47.069  1
223424  99.462  -76.652  47.030  1
223425  99.491  -76.664  46.992  1
223426  99.521  -76.676  46.955  1
223427  99.552  -76.689  46.918  1
223428  99.582  -76.699  46.881  1
223429  99.594  -76.701  46.845  1
223430  99.606  -76.702  46.810  1
223431  99.617  -76.704  46.775  1
223432  99.629  -76.705  46.740  1
223433  99.640  -76.707  46.706  1
223434  99.652  -76.708  46.672  1
223435  99.663  -76.711  46.642  1
223436  99.679  -76.712  46.611  1
223437  99.695  -76.712  46.582  1
223438  99.711  -76.712  46.554  1
223439  99.729  -76.714  46.526  1
223440  99.751  -76.716  46.498  1
223441  99.772  -76.719  46.470  1
223442  99.793  -76.721  46.444  1
223443  99.815  -76.724  46.417  1
223444  99.837  -76.727  46.389  1
223445  99.858  -76.730  46.361  1
223446  99.879  -76.733  46.333  1
223447  99.901  -76.735  46.305  1
223448  99.922  -76.738  46.276  1
223449  99.944  -76.740  46.246  1
223450  99.966  -76.743  46.217  1
223451  99.987  -76.746  46.187  1
223452  100.009  -76.749  46.156  1
223453  100.041  -76.756  46.125  1
223454  100.072  -76.763  46.094  1
223455  100.104  -76.771  46.066  1
223456  100.135  -76.777  46.038  1
223457  100.167  -76.784  46.010  1
223458  100.198  -76.791  45.983  1
223459  100.229  -76.799  45.955  1
223460  100.255  -76.798  45.930  1
223461  100.269  -76.782  45.907  1
223462  100.283  -76.765  45.884  1
223463  100.298  -76.749  45.861  1
223464  100.312  -76.734  45.841  1
223465  100.326  -76.718  45.821  1
223466  100.359  -76.743  45.803  1
223467  100.394  -76.774  45.785  1
223468  100.429  -76.804  45.768  1
223469  100.456  -76.840  45.752  1
223470  100.483  -76.875  45.734  1
223471  100.506  -76.897  45.718  1
223472  100.528  -76.915  45.702  1
223473  100.551  -76.934  45.686  1
223474  100.570  -76.953  45.669  1
223475  100.587  -76.972  45.652  1
223476  100.605  -76.990  45.636  1
223477  100.622  -77.009  45.619  1
223478  100.639  -77.028  45.603  1
223479  100.657  -77.047  45.586  1
223480  100.675  -77.064  45.570  1
223481  100.693  -77.082  45.554  1
223482  100.708  -77.098  45.540  1
223483  100.731  -77.113  45.526  1
223484  100.758  -77.124  45.512  1
223485  100.785  -77.135  45.500  1
223486  100.813  -77.146  45.487  1
223487  100.840  -77.157  45.475  1
223488  100.867  -77.167  45.462  1
223489  100.894  -77.178  45.450  1
223490  100.921  -77.188  45.438  1
223491  100.949  -77.199  45.427  1
223492  100.976  -77.210  45.416  1
223493  101.003  -77.221  45.403  1
223494  101.030  -77.232  45.392  1
223495  101.057  -77.242  45.382  1
223496  101.085  -77.253  45.371  1
223497  101.112  -77.263  45.359  1
223498  101.139  -77.275  45.345  1
223499  101.160  -77.285  45.331  1
223500  101.181  -77.295  45.316  1
223501  101.201  -77.306  45.301  1
223502  101.218  -77.322  45.286  1
223503  101.229  -77.347  45.270  1
223504  101.240  -77.372  45.255  1
223505  101.250  -77.397  45.237  1
223506  101.261  -77.423  45.220  1
223507  101.264  -77.438  45.203  1
223508  101.265  -77.451  45.186  1
223509  101.267  -77.464  45.167  1
223510  101.268  -77.476  45.148  1
223511  101.269  -77.489  45.129  1
223512  101.286  -77.492  45.111  1
223513  101.304  -77.494  45.093  1
223514  101.322  -77.496  45.075  1
223515  101.339  -77.498  45.057  1
223516  101.357  -77.501  45.038  1
223517  101.375  -77.503  45.021  1
223518  101.392  -77.505  45.004  1
223519  101.410  -77.508  44.987  1
223520  101.428  -77.510  44.970  1
223521  101.446  -77.512  44.952  1
223522  101.437  -77.557  44.934  1
223523  101.473  -77.570  44.918  1
223524  101.510  -77.583  44.901  1
223525  101.553  -77.593  44.886  1
223526  101.596  -77.604  44.870  1
223527  101.632  -77.615  44.854  1
223528  101.668  -77.627  44.837  1
223529  101.704  -77.639  44.821  1
223530  101.741  -77.651  44.805  1
223531  101.777  -77.662  44.788  1
223532  101.813  -77.674  44.772  1
223533  101.849  -77.686  44.757  1
223534  101.886  -77.698  44.741  1
223535  101.920  -77.711  44.724  1
223536  101.934  -77.732  44.710  1
223537  101.948  -77.754  44.695  1
223538  101.973  -77.769  44.679  1
223539  102.002  -77.780  44.663  1
223540  102.030  -77.790  44.646  1
223541  102.058  -77.801  44.629  1
223542  102.087  -77.812  44.613  1
223543  102.116  -77.815  44.597  1
223544  102.144  -77.818  44.582  1
223545  102.173  -77.820  44.566  1
223546  102.201  -77.824  44.550  1
223547  102.225  -77.839  44.535  1
223548  102.248  -77.854  44.520  1
223549  102.271  -77.868  44.505  1
223550  102.295  -77.884  44.490  1
223551  102.318  -77.899  44.475  1
223552  102.356  -77.924  44.461  1
223553  102.386  -77.937  44.446  1
223554  102.416  -77.950  44.431  1
223555  102.439  -77.955  44.416  1
223556  102.460  -77.959  44.401  1
223557  102.482  -77.962  44.386  1
223558  102.504  -77.966  44.372  1
223559  102.526  -77.970  44.357  1
223560  102.547  -77.974  44.342  1
223561  102.569  -77.978  44.328  1
223562  102.591  -77.981  44.312  1
223563  102.613  -77.985  44.297  1
223564  102.634  -77.989  44.283  1
223565  102.663  -78.009  44.267  1
223566  102.694  -78.022  44.253  1
223567  102.725  -78.034  44.238  1
223568  102.756  -78.046  44.222  1
223569  102.790  -78.058  44.205  1
223570  102.830  -78.069  44.189  1
223571  102.870  -78.080  44.173  1
223572  102.910  -78.091  44.156  1
223573  102.950  -78.103  44.139  1
223574  102.990  -78.114  44.122  1
223575  103.030  -78.125  44.106  1
223576  103.070  -78.136  44.090  1
223577  103.109  -78.147  44.073  1
223578  103.149  -78.159  44.057  1
223579  103.189  -78.169  44.040  1
223580  103.229  -78.181  44.023  1
223821  92.178  -75.234  54.222  1
223822  92.202  -75.245  54.229  1
223823  92.224  -75.257  54.236  1
223824  92.247  -75.267  54.243  1
223825  92.271  -75.279  54.254  1
223826  92.294  -75.290  54.264  1
223827  92.317  -75.301  54.274  1
223828  92.340  -75.312  54.282  1
223829  92.363  -75.323  54.289  1
223830  92.386  -75.334  54.294  1
223831  92.409  -75.345  54.297  1
223832  92.422  -75.355  54.303  1
223833  92.443  -75.347  54.306  1
223834  92.463  -75.339  54.306  1
223835  92.482  -75.336  54.305  1
223836  92.503  -75.333  54.299  1
223837  92.533  -75.329  54.292  1
223838  92.564  -75.324  54.286  1
223839  92.595  -75.320  54.279  1
223840  92.626  -75.316  54.272  1
223841  92.657  -75.312  54.263  1
223842  92.688  -75.308  54.254  1
223843  92.719  -75.304  54.242  1
223844  92.749  -75.299  54.230  1
223845  92.780  -75.295  54.218  1
223846  92.811  -75.291  54.207  1
223847  92.842  -75.287  54.194  1
223848  92.873  -75.283  54.182  1
223849  92.904  -75.279  54.169  1
223850  92.925  -75.280  54.156  1
223851  92.943  -75.283  54.144  1
223852  92.961  -75.286  54.131  1
223853  92.980  -75.289  54.118  1
223854  92.998  -75.292  54.105  1
223855  93.016  -75.296  54.091  1
223856  93.035  -75.299  54.076  1
223857  93.058  -75.298  54.062  1
223858  93.081  -75.297  54.049  1
223859  93.104  -75.295  54.034  1
223867  93.291  -75.286  53.956  1
223868  93.314  -75.285  53.954  1
223869  93.337  -75.283  53.956  1
223870  93.361  -75.282  53.960  1
223871  93.384  -75.281  53.970  1
223872  93.407  -75.279  53.980  1
223873  93.431  -75.278  53.992  1
223874  93.454  -75.277  54.009  1
223875  93.477  -75.276  54.029  1
223876  93.500  -75.274  54.053  1
223877  93.524  -75.273  54.082  1
223878  93.560  -75.272  54.115  1
223879  93.599  -75.270  54.150  1
223880  93.638  -75.268  54.190  1
223881  93.677  -75.266  54.235  1
223882  93.713  -75.264  54.272  1
223883  93.742  -75.262  54.300  1
223884  93.769  -75.258  54.321  1
223885  93.795  -75.254  54.339  1
223886  93.822  -75.251  54.351  1
223887  93.848  -75.247  54.364  1
223888  93.874  -75.243  54.375  1
223889  93.901  -75.239  54.385  1
223890  93.927  -75.236  54.395  1
223891  93.947  -75.222  54.402  1
223892  93.968  -75.210  54.407  1
223893  93.991  -75.201  54.411  1
223894  94.015  -75.198  54.416  1
223895  94.041  -75.201  54.420  1
223896  94.067  -75.204  54.425  1
223897  94.093  -75.206  54.433  1
223898  94.119  -75.209  54.442  1
223899  94.144  -75.209  54.449  1
223900  94.168  -75.207  54.453  1
223901  94.191  -75.204  54.454  1
223902  94.215  -75.202  54.451  1
223903  94.240  -75.204  54.445  1
223904  94.267  -75.214  54.436  1
223905  94.294  -75.224  54.420  1
223906  94.320  -75.231  54.402  1
223907  94.345  -75.230  54.382  1
223908  94.369  -75.230  54.364  1
223909  94.394  -75.229  54.343  1
223910  94.418  -75.229  54.323  1
223911  94.442  -75.228  54.305  1
223912  94.467  -75.227  54.292  1
223913  94.491  -75.220  54.270  1
223914  94.509  -75.218  54.243  1
223915  94.526  -75.218  54.213  1
223916  94.540  -75.218  54.180  1
223917  94.554  -75.218  54.145  1
223918  94.568  -75.218  54.110  1
223919  94.582  -75.219  54.072  1
223920  94.597  -75.219  54.030  1
223921  94.611  -75.219  53.988  1
223922  94.625  -75.219  53.948  1
223923  94.641  -75.220  53.909  1
223924  94.661  -75.220  53.872  1
223925  94.680  -75.220  53.835  1
223926  94.699  -75.220  53.797  1
223927  94.722  -75.223  53.757  1
223928  94.747  -75.226  53.714  1
223929  94.748  -75.230  53.672  1
223930  94.741  -75.236  53.629  1
223931  94.735  -75.241  53.584  1
223932  94.728  -75.246  53.539  1
223933  94.721  -75.251  53.492  1
223934  94.714  -75.258  53.443  1
223935  94.708  -75.263  53.395  1
223936  94.701  -75.268  53.347  1
223937  94.708  -75.272  53.299  1
223938  94.725  -75.275  53.251  1
223939  94.744  -75.278  53.205  1
223940  94.761  -75.280  53.156  1
223941  94.779  -75.283  53.108  1
223942  94.797  -75.286  53.061  1
223943  94.815  -75.289  53.014  1
223944  94.836  -75.292  52.967  1
223945  94.866  -75.298  52.918  1
223946  94.897  -75.305  52.868  1
223947  94.927  -75.311  52.818  1
223948  94.953  -75.314  52.766  1
223949  94.978  -75.318  52.715  1
223950  95.004  -75.321  52.665  1
223951  95.030  -75.325  52.616  1
223952  95.055  -75.328  52.566  1
223953  95.082  -75.331  52.517  1
223954  95.107  -75.335  52.467  1
223955  95.133  -75.338  52.418  1
223956  95.159  -75.342  52.369  1
223957  95.193  -75.353  52.322  1
223958  95.228  -75.364  52.277  1
223959  95.261  -75.375  52.233  1
223960  95.296  -75.386  52.190  1
223961  95.326  -75.398  52.149  1
223962  95.346  -75.411  52.107  1
223963  95.367  -75.425  52.067  1
223964  95.388  -75.439  52.028  1
223965  95.409  -75.452  51.989  1
223966  95.430  -75.465  51.953  1
223967  95.454  -75.476  51.919  1
223968  95.478  -75.486  51.886  1
223969  95.502  -75.497  51.853  1
223970  95.527  -75.508  51.822  1
223971  95.551  -75.518  51.789  1
223972  95.579  -75.514  51.757  1
223973  95.608  -75.507  51.726  1
223974  95.636  -75.500  51.696  1
223975  95.665  -75.493  51.666  1
223976  95.693  -75.486  51.637  1
223977  95.729  -75.482  51.606  1
223978  95.764  -75.478  51.574  1
223979  95.800  -75.474  51.542  1
223980  95.835  -75.470  51.510  1
223981  95.870  -75.465  51.478  1
223982  95.906  -75.461  51.445  1
223983  95.942  -75.460  51.412  1
223984  95.979  -75.461  51.380  1
223985  96.017  -75.461  51.349  1
223986  96.054  -75.461  51.317  1
223987  96.091  -75.461  51.288  1
223988  96.128  -75.462  51.259  1
223989  96.151  -75.465  51.230  1
223990  96.192  -75.470  51.202  1
223991  96.229  -75.483  51.174  1
223992  96.265  -75.496  51.147  1
223993  96.301  -75.509  51.121  1
223994  96.327  -75.519  51.095  1
223995  96.347  -75.527  51.069  1
223996  96.368  -75.536  51.042  1
223997  96.388  -75.545  51.015  1
223998  96.408  -75.554  50.988  1
223999  96.429  -75.564  50.962  1
224000  96.448  -75.570  50.937  1
224001  96.467  -75.572  50.913  1
224002  96.486  -75.575  50.889  1
224003  96.506  -75.578  50.865  1
224004  96.525  -75.584  50.840  1
224005  96.543  -75.593  50.817  1
224006  96.562  -75.600  50.794  1
224007  96.580  -75.608  50.772  1
224008  96.599  -75.616  50.751  1
224009  96.617  -75.624  50.728  1
224010  96.631  -75.639  50.705  1
224011  96.643  -75.659  50.681  1
224012  96.653  -75.678  50.658  1
224013  96.664  -75.698  50.633  1
224014  96.674  -75.718  50.610  1
224015  96.685  -75.737  50.587  1
224016  96.696  -75.757  50.565  1
224017  96.707  -75.776  50.543  1
224018  96.718  -75.796  50.517  1
224019  96.740  -75.811  50.488  1
224020  96.763  -75.826  50.457  1
224021  96.785  -75.841  50.422  1
224022  96.808  -75.856  50.386  1
224023  96.855  -75.865  50.349  1
224024  96.920  -75.869  50.312  1
224025  96.970  -75.874  50.275  1
224026  96.994  -75.880  50.237  1
224027  97.018  -75.886  50.200  1
224028  97.042  -75.892  50.162  1
224029  97.067  -75.898  50.125  1
224030  97.091  -75.904  50.088  1
224031  97.115  -75.909  50.051  1
224032  97.139  -75.916  50.016  1
224033  97.163  -75.922  49.982  1
224034  97.187  -75.928  49.947  1
224035  97.211  -75.934  49.912  1
224036  97.233  -75.941  49.877  1
224037  97.254  -75.947  49.843  1
224038  97.276  -75.954  49.808  1
224039  97.297  -75.962  49.774  1
224040  97.318  -75.969  49.741  1
224041  97.341  -75.977  49.710  1
224042  97.365  -75.991  49.679  1
224043  97.398  -75.999  49.649  1
224044  97.441  -75.997  49.621  1
224045  97.484  -75.996  49.593  1
224046  97.519  -75.995  49.566  1
224047  97.527  -75.996  49.540  1
224048  97.535  -75.997  49.515  1
224049  97.543  -75.997  49.490  1
224050  97.554  -75.998  49.466  1
224051  97.591  -76.014  49.442  1
224052  97.603  -76.028  49.418  1
224053  97.614  -76.043  49.392  1
224054  97.627  -76.057  49.365  1
224055  97.615  -76.061  49.333  1
224056  97.616  -76.075  49.299  1
224057  97.634  -76.100  49.264  1
224058  97.661  -76.112  49.229  1
224059  97.689  -76.125  49.190  1
224060  97.717  -76.137  49.152  1
224061  97.745  -76.149  49.112  1
224062  97.773  -76.161  49.072  1
224063  97.800  -76.173  49.032  1
224064  97.828  -76.186  48.993  1
224065  97.870  -76.198  48.955  1
224066  97.916  -76.211  48.916  1
224067  97.962  -76.224  48.878  1
224068  98.007  -76.237  48.839  1
224069  98.053  -76.250  48.798  1
224070  98.099  -76.263  48.757  1
224071  98.150  -76.288  48.716  1
224072  98.144  -76.332  48.675  1
224073  98.194  -76.358  48.633  1
224074  98.233  -76.369  48.593  1
224075  98.258  -76.378  48.551  1
224076  98.284  -76.387  48.512  1
224077  98.309  -76.396  48.474  1
224078  98.334  -76.405  48.437  1
224079  98.359  -76.414  48.403  1
224080  98.382  -76.418  48.370  1
224081  98.407  -76.420  48.338  1
224082  98.438  -76.426  48.305  1
224083  98.471  -76.433  48.274  1
224084  98.503  -76.441  48.243  1
224085  98.535  -76.448  48.211  1
224086  98.568  -76.455  48.180  1
224087  98.600  -76.463  48.149  1
224088  98.632  -76.470  48.120  1
224089  98.665  -76.478  48.091  1
224090  98.697  -76.485  48.064  1
224091  98.729  -76.492  48.038  1
224092  98.762  -76.500  48.013  1
224093  98.784  -76.503  47.989  1
224094  98.802  -76.504  47.966  1
224095  98.819  -76.505  47.943  1
224096  98.837  -76.505  47.920  1
224097  98.854  -76.507  47.898  1
224098  98.871  -76.508  47.875  1
224099  98.888  -76.508  47.853  1
224100  98.906  -76.509  47.829  1
224101  98.923  -76.510  47.805  1
224102  98.941  -76.511  47.782  1
224103  98.956  -76.511  47.758  1
224104  98.964  -76.507  47.735  1
224105  98.979  -76.511  47.711  1
224106  99.000  -76.514  47.685  1
224107  99.020  -76.514  47.658  1
224108  99.040  -76.514  47.630  1
224109  99.059  -76.515  47.601  1
224110  99.079  -76.515  47.571  1
224111  99.099  -76.516  47.540  1
224112  99.119  -76.517  47.508  1
224113  99.138  -76.517  47.475  1
224114  99.157  -76.522  47.441  1
224115  99.177  -76.529  47.406  1
224116  99.204  -76.530  47.371  1
224117  99.234  -76.540  47.335  1
224118  99.265  -76.551  47.298  1
224119  99.295  -76.561  47.260  1
224120  99.325  -76.573  47.222  1
224121  99.355  -76.583  47.183  1
224122  99.385  -76.594  47.146  1
224123  99.415  -76.605  47.109  1
224124  99.444  -76.618  47.071  1
224125  99.474  -76.630  47.033  1
224126  99.503  -76.642  46.995  1
224127  99.533  -76.654  46.958  1
224128  99.565  -76.668  46.922  1
224129  99.600  -76.680  46.885  1
224130  99.630  -76.690  46.849  1
224131  99.642  -76.692  46.813  1
224132  99.653  -76.693  46.779  1
224133  99.665  -76.695  46.744  1
224134  99.677  -76.696  46.710  1
224135  99.688  -76.698  46.677  1
224136  99.700  -76.699  46.647  1
224137  99.714  -76.700  46.617  1
224138  99.731  -76.701  46.588  1
224139  99.747  -76.702  46.560  1
224140  99.763  -76.702  46.532  1
224141  99.779  -76.702  46.503  1
224142  99.797  -76.703  46.476  1
224143  99.819  -76.706  46.449  1
224144  99.840  -76.709  46.421  1
224145  99.862  -76.712  46.393  1
224146  99.883  -76.715  46.364  1
224147  99.905  -76.717  46.335  1
224148  99.926  -76.720  46.306  1
224149  99.947  -76.723  46.276  1
224150  99.969  -76.725  46.246  1
224151  99.991  -76.728  46.217  1
224152  100.012  -76.730  46.187  1
224153  100.036  -76.734  46.155  1
224154  100.067  -76.741  46.124  1
224155  100.099  -76.749  46.094  1
224156  100.130  -76.755  46.065  1
224157  100.161  -76.762  46.036  1
224158  100.193  -76.769  46.008  1
224159  100.224  -76.777  45.980  1
224160  100.243  -76.767  45.953  1
224161  100.258  -76.751  45.928  1
224162  100.272  -76.735  45.904  1
224163  100.286  -76.719  45.880  1
224164  100.300  -76.703  45.858  1
224165  100.315  -76.687  45.837  1
224166  100.331  -76.675  45.817  1
224167  100.366  -76.706  45.798  1
224168  100.401  -76.737  45.780  1
224169  100.428  -76.771  45.763  1
224170  100.456  -76.806  45.747  1
224171  100.482  -76.840  45.729  1
224172  100.509  -76.875  45.713  1
224173  100.532  -76.897  45.696  1
224174  100.554  -76.915  45.680  1
224175  100.577  -76.934  45.663  1
224176  100.599  -76.952  45.646  1
224177  100.622  -76.970  45.630  1
224178  100.641  -76.988  45.613  1
224179  100.659  -77.007  45.596  1
224180  100.676  -77.027  45.579  1
224181  100.694  -77.046  45.563  1
224182  100.711  -77.065  45.549  1
224183  100.732  -77.090  45.533  1
224184  100.760  -77.085  45.519  1
224185  100.787  -77.099  45.505  1
224186  100.815  -77.113  45.492  1
224187  100.842  -77.126  45.480  1
224188  100.869  -77.138  45.468  1
224189  100.896  -77.150  45.456  1
224190  100.923  -77.160  45.444  1
224191  100.951  -77.171  45.432  1
224192  100.978  -77.182  45.420  1
224193  101.005  -77.192  45.409  1
224194  101.032  -77.203  45.398  1
224195  101.059  -77.214  45.387  1
224196  101.087  -77.225  45.376  1
224197  101.114  -77.235  45.365  1
224198  101.141  -77.246  45.353  1
224199  101.168  -77.257  45.340  1
224200  101.190  -77.267  45.326  1
224201  101.211  -77.278  45.311  1
224202  101.223  -77.301  45.294  1
224203  101.234  -77.326  45.280  1
224204  101.245  -77.351  45.265  1
224205  101.256  -77.376  45.248  1
224206  101.266  -77.401  45.231  1
224207  101.277  -77.426  45.213  1
224208  101.280  -77.441  45.195  1
224209  101.281  -77.454  45.177  1
224210  101.282  -77.467  45.158  1
224211  101.290  -77.476  45.139  1
224212  101.308  -77.478  45.120  1
224213  101.325  -77.480  45.101  1
224214  101.343  -77.483  45.083  1
224215  101.360  -77.485  45.064  1
224216  101.378  -77.486  45.046  1
224217  101.396  -77.489  45.028  1
224218  101.413  -77.491  45.010  1
224219  101.431  -77.493  44.993  1
224220  101.449  -77.495  44.976  1
224221  101.467  -77.498  44.959  1
224222  101.484  -77.500  44.941  1
224223  101.502  -77.502  44.923  1
224224  101.490  -77.556  44.907  1
224225  101.527  -77.568  44.890  1
224226  101.563  -77.580  44.874  1
224227  101.599  -77.592  44.858  1
224228  101.635  -77.603  44.841  1
224229  101.672  -77.615  44.824  1
224230  101.708  -77.627  44.807  1
224231  101.744  -77.639  44.792  1
224232  101.780  -77.651  44.777  1
224233  101.817  -77.662  44.761  1
224234  101.853  -77.674  44.745  1
224235  101.889  -77.686  44.729  1
224236  101.921  -77.699  44.713  1
224237  101.936  -77.721  44.699  1
224238  101.949  -77.743  44.683  1
224239  101.987  -77.751  44.667  1
224240  102.020  -77.763  44.651  1
224241  102.049  -77.774  44.635  1
224242  102.078  -77.784  44.618  1
224243  102.106  -77.796  44.602  1
224244  102.134  -77.804  44.587  1
224245  102.164  -77.806  44.571  1
224246  102.192  -77.808  44.556  1
224247  102.220  -77.813  44.540  1
224248  102.243  -77.828  44.525  1
224249  102.267  -77.843  44.510  1
224250  102.290  -77.858  44.495  1
224251  102.313  -77.873  44.481  1
224252  102.337  -77.887  44.466  1
224253  102.369  -77.910  44.452  1
224254  102.399  -77.924  44.437  1
224255  102.428  -77.936  44.421  1
224256  102.450  -77.940  44.407  1
224257  102.471  -77.943  44.392  1
224258  102.493  -77.947  44.377  1
224259  102.515  -77.951  44.362  1
224260  102.537  -77.955  44.346  1
224261  102.558  -77.959  44.331  1
224262  102.580  -77.962  44.316  1
224263  102.602  -77.966  44.301  1
224264  102.624  -77.969  44.286  1
224265  102.647  -77.972  44.272  1
224266  102.674  -77.979  44.257  1
224267  102.703  -77.986  44.242  1
224268  102.734  -77.997  44.227  1
224269  102.764  -78.009  44.210  1
224270  102.802  -78.021  44.193  1
224271  102.842  -78.032  44.177  1
224272  102.882  -78.044  44.160  1
224273  102.922  -78.055  44.143  1
224274  102.962  -78.065  44.126  1
224275  103.001  -78.077  44.110  1
224276  103.042  -78.088  44.094  1
224277  103.082  -78.100  44.078  1
224278  103.121  -78.110  44.061  1
224279  103.161  -78.122  44.045  1
224280  103.201  -78.133  44.028  1
224281  103.241  -78.144  44.011  1
224522  92.166  -75.205  54.230  1
224523  92.189  -75.217  54.237  1
224524  92.212  -75.227  54.244  1
224525  92.235  -75.239  54.251  1
224526  92.258  -75.250  54.261  1
224527  92.281  -75.261  54.272  1
224528  92.304  -75.272  54.283  1
224529  92.327  -75.283  54.291  1
224530  92.350  -75.294  54.299  1
224531  92.373  -75.305  54.304  1
224532  92.397  -75.316  54.309  1
224533  92.415  -75.327  54.315  1
224534  92.432  -75.323  54.318  1
224535  92.452  -75.315  54.320  1
224536  92.472  -75.312  54.319  1
224537  92.496  -75.309  54.314  1
224538  92.526  -75.305  54.307  1
224539  92.557  -75.301  54.300  1
224540  92.588  -75.296  54.294  1
224541  92.619  -75.292  54.287  1
224542  92.650  -75.288  54.278  1
224543  92.681  -75.284  54.269  1
224544  92.712  -75.279  54.256  1
224545  92.742  -75.276  54.244  1
224546  92.773  -75.271  54.232  1
224547  92.804  -75.267  54.220  1
224548  92.835  -75.263  54.208  1
224549  92.866  -75.259  54.195  1
224550  92.897  -75.254  54.182  1
224551  92.917  -75.257  54.170  1
224552  92.935  -75.260  54.157  1
224553  92.953  -75.263  54.145  1
224554  92.972  -75.266  54.132  1
224555  92.990  -75.270  54.118  1
224556  93.010  -75.271  54.105  1
224557  93.033  -75.270  54.090  1
224558  93.056  -75.269  54.075  1
224559  93.080  -75.267  54.062  1
224560  93.103  -75.266  54.047  1
224568  93.289  -75.256  53.965  1
224569  93.313  -75.255  53.963  1
224570  93.336  -75.254  53.963  1
224571  93.359  -75.252  53.967  1
224572  93.383  -75.251  53.976  1
224573  93.406  -75.250  53.986  1
224574  93.429  -75.248  53.997  1
224575  93.452  -75.248  54.013  1
224576  93.476  -75.246  54.032  1
224577  93.499  -75.245  54.057  1
224578  93.522  -75.244  54.086  1
224579  93.559  -75.242  54.120  1
224580  93.598  -75.240  54.159  1
224581  93.637  -75.239  54.201  1
224582  93.675  -75.236  54.247  1
224583  93.707  -75.236  54.286  1
224584  93.738  -75.234  54.316  1
224585  93.766  -75.231  54.340  1
224586  93.792  -75.227  54.358  1
224587  93.819  -75.224  54.368  1
224588  93.845  -75.220  54.378  1
224589  93.871  -75.217  54.388  1
224590  93.898  -75.214  54.397  1
224591  93.924  -75.210  54.404  1
224592  93.947  -75.201  54.410  1
224593  93.970  -75.192  54.413  1
224594  93.992  -75.183  54.415  1
224595  94.015  -75.175  54.419  1
224596  94.040  -75.175  54.422  1
224597  94.066  -75.177  54.425  1
224598  94.092  -75.179  54.429  1
224599  94.118  -75.182  54.438  1
224600  94.143  -75.182  54.445  1
224601  94.167  -75.180  54.450  1
224602  94.190  -75.178  54.455  1
224603  94.214  -75.176  54.457  1
224604  94.237  -75.173  54.455  1
224605  94.262  -75.175  54.448  1
224606  94.289  -75.185  54.442  1
224607  94.316  -75.193  54.427  1
224608  94.340  -75.192  54.407  1
224609  94.365  -75.192  54.388  1
224610  94.389  -75.192  54.366  1
224611  94.414  -75.191  54.342  1
224612  94.438  -75.190  54.320  1
224613  94.463  -75.189  54.307  1
224614  94.487  -75.189  54.285  1
224615  94.510  -75.189  54.259  1
224616  94.525  -75.191  54.229  1
224617  94.538  -75.192  54.196  1
224618  94.553  -75.192  54.162  1
224619  94.567  -75.192  54.126  1
224620  94.581  -75.192  54.088  1
224621  94.595  -75.192  54.047  1
224622  94.609  -75.193  54.007  1
224623  94.623  -75.193  53.968  1
224624  94.637  -75.193  53.931  1
224625  94.652  -75.193  53.893  1
224626  94.672  -75.194  53.856  1
224627  94.691  -75.194  53.818  1
224628  94.716  -75.197  53.777  1
224629  94.741  -75.200  53.733  1
224630  94.758  -75.204  53.689  1
224631  94.751  -75.209  53.644  1
224632  94.745  -75.214  53.598  1
224633  94.738  -75.220  53.552  1
224634  94.731  -75.226  53.505  1
224635  94.724  -75.231  53.457  1
224636  94.718  -75.236  53.410  1
224637  94.711  -75.242  53.362  1
224638  94.726  -75.245  53.313  1
224639  94.744  -75.248  53.265  1
224640  94.762  -75.251  53.217  1
224641  94.780  -75.253  53.168  1
224642  94.797  -75.256  53.120  1
224643  94.815  -75.259  53.072  1
224644  94.833  -75.261  53.023  1
224645  94.851  -75.264  52.975  1
224646  94.875  -75.269  52.927  1
224647  94.905  -75.275  52.876  1
224648  94.934  -75.280  52.825  1
224649  94.960  -75.284  52.772  1
224650  94.985  -75.287  52.720  1
224651  95.011  -75.290  52.668  1
224652  95.037  -75.294  52.617  1
224653  95.062  -75.297  52.566  1
224654  95.088  -75.301  52.515  1
224655  95.114  -75.304  52.465  1
224656  95.139  -75.308  52.415  1
224657  95.166  -75.311  52.366  1
224658  95.199  -75.321  52.319  1
224659  95.233  -75.332  52.274  1
224660  95.267  -75.342  52.230  1
224661  95.300  -75.354  52.186  1
224662  95.320  -75.367  52.144  1
224663  95.341  -75.381  52.103  1
224664  95.362  -75.395  52.062  1
224665  95.383  -75.408  52.023  1
224666  95.407  -75.419  51.985  1
224667  95.431  -75.430  51.948  1
224668  95.455  -75.440  51.914  1
224669  95.479  -75.451  51.881  1
224670  95.503  -75.461  51.848  1
224671  95.528  -75.472  51.817  1
224672  95.552  -75.483  51.784  1
224673  95.580  -75.477  51.751  1
224674  95.609  -75.470  51.720  1
224675  95.637  -75.463  51.691  1
224676  95.666  -75.456  51.662  1
224677  95.694  -75.449  51.633  1
224678  95.723  -75.442  51.603  1
224679  95.754  -75.436  51.571  1
224680  95.790  -75.432  51.540  1
224681  95.825  -75.428  51.509  1
224682  95.861  -75.424  51.478  1
224683  95.896  -75.420  51.446  1
224684  95.933  -75.420  51.413  1
224685  95.970  -75.420  51.381  1
224686  96.008  -75.420  51.350  1
224687  96.045  -75.421  51.318  1
224688  96.082  -75.421  51.289  1
224689  96.119  -75.422  51.260  1
224690  96.161  -75.429  51.232  1
224691  96.198  -75.436  51.203  1
224692  96.235  -75.449  51.177  1
224693  96.271  -75.462  51.151  1
224694  96.307  -75.475  51.123  1
224695  96.335  -75.486  51.098  1
224696  96.356  -75.494  51.072  1
224697  96.376  -75.503  51.045  1
224698  96.396  -75.511  51.018  1
224699  96.416  -75.523  50.992  1
224700  96.436  -75.536  50.967  1
224701  96.456  -75.547  50.943  1
224702  96.475  -75.550  50.920  1
224703  96.495  -75.553  50.896  1
224704  96.514  -75.556  50.872  1
224705  96.533  -75.561  50.849  1
224706  96.551  -75.569  50.825  1
224707  96.570  -75.577  50.802  1
224708  96.588  -75.585  50.780  1
224709  96.607  -75.593  50.758  1
224710  96.625  -75.601  50.736  1
224711  96.641  -75.612  50.712  1
224712  96.651  -75.631  50.688  1
224713  96.661  -75.649  50.664  1
224714  96.671  -75.669  50.639  1
224715  96.682  -75.689  50.615  1
224716  96.693  -75.709  50.592  1
224717  96.703  -75.728  50.569  1
224718  96.714  -75.747  50.544  1
224719  96.725  -75.767  50.518  1
224720  96.738  -75.786  50.489  1
224721  96.760  -75.801  50.458  1
224722  96.783  -75.816  50.424  1
224723  96.805  -75.831  50.389  1
224724  96.868  -75.836  50.352  1
224725  96.933  -75.840  50.316  1
224726  96.993  -75.845  50.280  1
224727  97.017  -75.851  50.244  1
224728  97.041  -75.856  50.208  1
224729  97.066  -75.862  50.172  1
224730  97.090  -75.869  50.135  1
224731  97.114  -75.875  50.099  1
224732  97.138  -75.881  50.063  1
224733  97.162  -75.887  50.028  1
224734  97.185  -75.893  49.994  1
224735  97.207  -75.900  49.959  1
224736  97.228  -75.906  49.924  1
224737  97.249  -75.914  49.890  1
224738  97.271  -75.921  49.856  1
224739  97.292  -75.928  49.822  1
224740  97.314  -75.934  49.787  1
224741  97.335  -75.941  49.753  1
224742  97.359  -75.953  49.721  1
224743  97.383  -75.968  49.689  1
224744  97.413  -75.978  49.659  1
224745  97.456  -75.977  49.630  1
224746  97.499  -75.975  49.603  1
224747  97.541  -75.974  49.576  1
224748  97.584  -75.972  49.550  1
224749  97.594  -75.973  49.525  1
224750  97.602  -75.974  49.500  1
224751  97.628  -75.979  49.476  1
224752  97.638  -75.990  49.452  1
224753  97.649  -76.003  49.427  1
224754  97.660  -76.018  49.401  1
224755  97.672  -76.032  49.373  1
224756  97.649  -76.029  49.341  1
224757  97.643  -76.038  49.304  1
224758  97.660  -76.063  49.267  1
224759  97.678  -76.088  49.230  1
224760  97.706  -76.100  49.191  1
224761  97.734  -76.113  49.152  1
224762  97.761  -76.126  49.111  1
224763  97.789  -76.138  49.070  1
224764  97.817  -76.150  49.029  1
224765  97.845  -76.162  48.988  1
224766  97.887  -76.175  48.949  1
224767  97.933  -76.188  48.909  1
224768  97.979  -76.201  48.871  1
224769  98.024  -76.213  48.830  1
224770  98.070  -76.226  48.789  1
224771  98.119  -76.248  48.748  1
224772  98.174  -76.281  48.708  1
224773  98.229  -76.315  48.666  1
224774  98.215  -76.370  48.625  1
224775  98.255  -76.385  48.584  1
224776  98.281  -76.393  48.543  1
224777  98.304  -76.399  48.504  1
224778  98.326  -76.401  48.466  1
224779  98.348  -76.404  48.430  1
224780  98.370  -76.406  48.395  1
224781  98.392  -76.408  48.362  1
224782  98.415  -76.410  48.330  1
224783  98.442  -76.411  48.297  1
224784  98.469  -76.411  48.267  1
224785  98.499  -76.414  48.236  1
224786  98.531  -76.422  48.205  1
224787  98.564  -76.430  48.173  1
224788  98.596  -76.436  48.143  1
224789  98.629  -76.444  48.113  1
224790  98.661  -76.451  48.084  1
224791  98.694  -76.458  48.056  1
224792  98.726  -76.466  48.031  1
224793  98.758  -76.473  48.006  1
224794  98.781  -76.477  47.982  1
224795  98.798  -76.477  47.959  1
224796  98.816  -76.479  47.936  1
224797  98.833  -76.480  47.914  1
224798  98.851  -76.480  47.893  1
224799  98.868  -76.481  47.871  1
224800  98.885  -76.482  47.848  1
224801  98.903  -76.483  47.825  1
224802  98.920  -76.484  47.801  1
224803  98.937  -76.485  47.778  1
224804  98.955  -76.486  47.756  1
224805  98.972  -76.486  47.732  1
224806  98.996  -76.489  47.709  1
224807  99.013  -76.489  47.683  1
224808  99.033  -76.489  47.655  1
224809  99.053  -76.489  47.627  1
224810  99.072  -76.489  47.597  1
224811  99.092  -76.490  47.567  1
224812  99.112  -76.491  47.536  1
224813  99.132  -76.491  47.504  1
224814  99.151  -76.492  47.471  1
224815  99.171  -76.492  47.437  1
224816  99.190  -76.499  47.403  1
224817  99.218  -76.503  47.369  1
224818  99.249  -76.514  47.333  1
224819  99.278  -76.525  47.297  1
224820  99.308  -76.536  47.260  1
224821  99.339  -76.547  47.222  1
224822  99.368  -76.558  47.183  1
224823  99.398  -76.571  47.147  1
224824  99.427  -76.583  47.111  1
224825  99.456  -76.595  47.073  1
224826  99.486  -76.607  47.035  1
224827  99.515  -76.620  46.998  1
224828  99.546  -76.633  46.961  1
224829  99.579  -76.646  46.924  1
224830  99.614  -76.658  46.888  1
224831  99.649  -76.671  46.852  1
224832  99.678  -76.680  46.817  1
224833  99.690  -76.682  46.782  1
224834  99.701  -76.683  46.748  1
224835  99.713  -76.686  46.715  1
224836  99.724  -76.687  46.683  1
224837  99.736  -76.689  46.653  1
224838  99.751  -76.690  46.624  1
224839  99.767  -76.690  46.595  1
224840  99.783  -76.690  46.567  1
224841  99.799  -76.691  46.538  1
224842  99.816  -76.692  46.510  1
224843  99.832  -76.692  46.482  1
224844  99.848  -76.693  46.454  1
224845  99.865  -76.693  46.426  1
224846  99.887  -76.696  46.397  1
224847  99.908  -76.699  46.368  1
224848  99.930  -76.702  46.338  1
224849  99.951  -76.705  46.308  1
224850  99.973  -76.707  46.278  1
224851  99.994  -76.710  46.248  1
224852  100.016  -76.712  46.217  1
224853  100.037  -76.715  46.186  1
224854  100.062  -76.719  46.155  1
224855  100.093  -76.727  46.124  1
224856  100.125  -76.734  46.093  1
224857  100.156  -76.740  46.064  1
224858  100.188  -76.747  46.034  1
224859  100.217  -76.752  46.006  1
224860  100.231  -76.736  45.978  1
224861  100.246  -76.720  45.951  1
224862  100.260  -76.704  45.925  1
224863  100.274  -76.688  45.901  1
224864  100.288  -76.672  45.877  1
224865  100.303  -76.656  45.855  1
224866  100.317  -76.640  45.833  1
224867  100.338  -76.638  45.813  1
224868  100.372  -76.668  45.793  1
224869  100.401  -76.702  45.775  1
224870  100.428  -76.737  45.758  1
224871  100.455  -76.772  45.741  1
224872  100.482  -76.807  45.724  1
224873  100.508  -76.842  45.708  1
224874  100.535  -76.877  45.691  1
224875  100.558  -76.897  45.674  1
224876  100.580  -76.915  45.657  1
224877  100.603  -76.933  45.641  1
224878  100.625  -76.951  45.624  1
224879  100.647  -76.969  45.606  1
224880  100.670  -76.987  45.589  1
224881  100.692  -77.006  45.573  1
224882  100.713  -77.025  45.557  1
224883  100.731  -77.044  45.542  1
224884  100.758  -77.079  45.527  1
224885  100.789  -77.039  45.513  1
224886  100.816  -77.053  45.499  1
224887  100.843  -77.066  45.486  1
224888  100.870  -77.080  45.474  1
224889  100.898  -77.094  45.462  1
224890  100.925  -77.107  45.450  1
224891  100.953  -77.121  45.438  1
224892  100.980  -77.135  45.426  1
224893  101.007  -77.148  45.414  1
224894  101.034  -77.162  45.402  1
224895  101.061  -77.175  45.392  1
224896  101.089  -77.189  45.381  1
224897  101.116  -77.204  45.370  1
224898  101.143  -77.217  45.359  1
224899  101.171  -77.229  45.347  1
224900  101.198  -77.239  45.333  1
224901  101.217  -77.254  45.319  1
224902  101.229  -77.279  45.304  1
224903  101.239  -77.304  45.288  1
224904  101.250  -77.329  45.273  1
224905  101.261  -77.354  45.257  1
224906  101.271  -77.379  45.241  1
224907  101.282  -77.404  45.223  1
224908  101.293  -77.429  45.205  1
224909  101.296  -77.444  45.187  1
224910  101.297  -77.457  45.167  1
224911  101.311  -77.461  45.149  1
224912  101.329  -77.464  45.130  1
224913  101.346  -77.466  45.111  1
224914  101.364  -77.468  45.092  1
224915  101.382  -77.470  45.073  1
224916  101.399  -77.473  45.054  1
224917  101.417  -77.475  45.036  1
224918  101.434  -77.477  45.017  1
224919  101.450  -77.479  45.000  1
224920  101.466  -77.480  44.983  1
224921  101.481  -77.482  44.965  1
224922  101.496  -77.483  44.947  1
224923  101.512  -77.485  44.929  1
224924  101.527  -77.486  44.913  1
224925  101.505  -77.539  44.898  1
224926  101.530  -77.556  44.881  1
224927  101.566  -77.568  44.865  1
224928  101.603  -77.580  44.848  1
224929  101.639  -77.592  44.832  1
224930  101.675  -77.603  44.814  1
224931  101.711  -77.615  44.798  1
224932  101.748  -77.627  44.782  1
224933  101.784  -77.639  44.767  1
224934  101.820  -77.651  44.751  1
224935  101.856  -77.662  44.735  1
224936  101.893  -77.674  44.719  1
224937  101.923  -77.688  44.703  1
224938  101.937  -77.710  44.688  1
224939  101.958  -77.727  44.672  1
224940  102.001  -77.733  44.657  1
224941  102.034  -77.745  44.641  1
224942  102.066  -77.757  44.624  1
224943  102.097  -77.768  44.608  1
224944  102.125  -77.779  44.592  1
224945  102.154  -77.790  44.577  1
224946  102.183  -77.794  44.562  1
224947  102.211  -77.796  44.547  1
224948  102.239  -77.802  44.531  1
224949  102.262  -77.818  44.516  1
224950  102.286  -77.832  44.500  1
224951  102.309  -77.847  44.486  1
224952  102.332  -77.862  44.473  1
224953  102.356  -77.877  44.458  1
224954  102.379  -77.891  44.443  1
224955  102.411  -77.911  44.428  1
224956  102.439  -77.921  44.411  1
224957  102.461  -77.924  44.397  1
224958  102.482  -77.928  44.382  1
224959  102.504  -77.932  44.367  1
224960  102.526  -77.936  44.353  1
224961  102.548  -77.940  44.337  1
224962  102.571  -77.943  44.321  1
224963  102.595  -77.944  44.305  1
224964  102.619  -77.946  44.290  1
224965  102.641  -77.950  44.275  1
224966  102.660  -77.956  44.261  1
224967  102.689  -77.963  44.246  1
224968  102.718  -77.970  44.230  1
224969  102.747  -77.977  44.215  1
224970  102.779  -77.983  44.198  1
224971  102.816  -77.987  44.181  1
224972  102.854  -77.996  44.164  1
224973  102.894  -78.007  44.147  1
224974  102.934  -78.018  44.131  1
224975  102.974  -78.029  44.114  1
224976  103.014  -78.040  44.098  1
224977  103.053  -78.051  44.082  1
224978  103.093  -78.062  44.066  1
224979  103.134  -78.074  44.049  1
224980  103.173  -78.085  44.033  1
224981  103.213  -78.096  44.016  1
224982  103.253  -78.107  43.999  1
225223  92.153  -75.176  54.237  1
225224  92.176  -75.187  54.244  1
225225  92.199  -75.198  54.251  1
225226  92.222  -75.209  54.259  1
225227  92.245  -75.220  54.268  1
225228  92.269  -75.232  54.279  1
225229  92.292  -75.242  54.290  1
225230  92.314  -75.254  54.299  1
225231  92.338  -75.265  54.308  1
225232  92.361  -75.276  54.315  1
225233  92.384  -75.287  54.319  1
225234  92.407  -75.298  54.326  1
225235  92.422  -75.299  54.331  1
225236  92.442  -75.292  54.333  1
225237  92.461  -75.289  54.333  1
225238  92.489  -75.285  54.329  1
225239  92.519  -75.281  54.322  1
225240  92.550  -75.276  54.315  1
225241  92.581  -75.273  54.310  1
225242  92.612  -75.268  54.302  1
225243  92.643  -75.264  54.293  1
225244  92.673  -75.260  54.283  1
225245  92.704  -75.256  54.270  1
225246  92.735  -75.251  54.258  1
225247  92.766  -75.248  54.245  1
225248  92.797  -75.243  54.233  1
225249  92.828  -75.239  54.222  1
225250  92.859  -75.235  54.209  1
225251  92.889  -75.231  54.196  1
225252  92.908  -75.233  54.184  1
225253  92.927  -75.236  54.171  1
225254  92.945  -75.239  54.158  1
225255  92.964  -75.243  54.145  1
225256  92.985  -75.243  54.132  1
225257  93.008  -75.242  54.119  1
225258  93.032  -75.240  54.105  1
225259  93.055  -75.239  54.090  1
225260  93.078  -75.238  54.077  1
225261  93.102  -75.236  54.062  1
225262  93.125  -75.236  54.047  1
225269  93.288  -75.226  53.975  1
225270  93.311  -75.226  53.972  1
225271  93.335  -75.224  53.972  1
225272  93.358  -75.223  53.975  1
225273  93.381  -75.222  53.983  1
225274  93.405  -75.220  53.992  1
225275  93.428  -75.219  54.003  1
225276  93.451  -75.218  54.018  1
225277  93.475  -75.217  54.038  1
225278  93.498  -75.216  54.062  1
225279  93.521  -75.214  54.091  1
225280  93.558  -75.213  54.128  1
225281  93.597  -75.210  54.168  1
225282  93.636  -75.209  54.212  1
225283  93.669  -75.207  54.260  1
225284  93.700  -75.206  54.299  1
225285  93.731  -75.204  54.333  1
225286  93.763  -75.203  54.360  1
225287  93.789  -75.200  54.379  1
225288  93.816  -75.196  54.390  1
225289  93.842  -75.193  54.398  1
225290  93.868  -75.189  54.406  1
225291  93.895  -75.186  54.414  1
225292  93.921  -75.183  54.420  1
225293  93.947  -75.180  54.424  1
225294  93.971  -75.174  54.425  1
225295  93.994  -75.165  54.424  1
225296  94.016  -75.157  54.426  1
225297  94.039  -75.148  54.428  1
225298  94.065  -75.151  54.430  1
225299  94.091  -75.153  54.434  1
225300  94.117  -75.156  54.441  1
225301  94.142  -75.156  54.446  1
225302  94.166  -75.154  54.448  1
225303  94.189  -75.151  54.454  1
225304  94.212  -75.149  54.459  1
225305  94.236  -75.146  54.461  1
225306  94.260  -75.144  54.460  1
225307  94.284  -75.145  54.457  1
225308  94.312  -75.155  54.446  1
225309  94.336  -75.154  54.430  1
225310  94.360  -75.154  54.409  1
225311  94.385  -75.154  54.387  1
225312  94.409  -75.153  54.363  1
225313  94.435  -75.153  54.340  1
225314  94.461  -75.152  54.323  1
225315  94.486  -75.152  54.301  1
225316  94.509  -75.152  54.274  1
225317  94.524  -75.154  54.243  1
225318  94.538  -75.155  54.209  1
225319  94.552  -75.157  54.174  1
225320  94.565  -75.159  54.139  1
225321  94.579  -75.160  54.103  1
225322  94.594  -75.162  54.063  1
225323  94.608  -75.163  54.025  1
225324  94.622  -75.165  53.988  1
225325  94.636  -75.167  53.951  1
225326  94.650  -75.167  53.914  1
225327  94.664  -75.167  53.877  1
225328  94.686  -75.169  53.838  1
225329  94.710  -75.172  53.796  1
225330  94.735  -75.175  53.751  1
225331  94.760  -75.178  53.706  1
225332  94.761  -75.183  53.660  1
225333  94.755  -75.189  53.611  1
225334  94.748  -75.194  53.566  1
225335  94.741  -75.199  53.520  1
225336  94.735  -75.204  53.473  1
225337  94.728  -75.210  53.428  1
225338  94.726  -75.215  53.381  1
225339  94.745  -75.217  53.332  1
225340  94.762  -75.220  53.281  1
225341  94.780  -75.223  53.231  1
225342  94.798  -75.226  53.182  1
225343  94.816  -75.229  53.133  1
225344  94.834  -75.232  53.085  1
225345  94.851  -75.235  53.035  1
225346  94.870  -75.237  52.986  1
225347  94.887  -75.240  52.936  1
225348  94.913  -75.245  52.886  1
225349  94.941  -75.250  52.834  1
225350  94.967  -75.253  52.780  1
225351  94.992  -75.256  52.726  1
225352  95.018  -75.260  52.673  1
225353  95.044  -75.263  52.620  1
225354  95.069  -75.267  52.567  1
225355  95.095  -75.270  52.515  1
225356  95.121  -75.273  52.465  1
225357  95.146  -75.276  52.414  1
225358  95.172  -75.280  52.365  1
225359  95.204  -75.289  52.318  1
225360  95.238  -75.300  52.272  1
225361  95.272  -75.311  52.227  1
225362  95.294  -75.324  52.184  1
225363  95.315  -75.338  52.141  1
225364  95.336  -75.352  52.100  1
225365  95.359  -75.362  52.058  1
225366  95.384  -75.373  52.019  1
225367  95.408  -75.383  51.981  1
225368  95.432  -75.394  51.944  1
225369  95.456  -75.405  51.910  1
225370  95.480  -75.415  51.877  1
225371  95.505  -75.426  51.844  1
225372  95.529  -75.436  51.812  1
225373  95.553  -75.446  51.779  1
225374  95.582  -75.439  51.747  1
225375  95.610  -75.433  51.715  1
225376  95.639  -75.426  51.686  1
225377  95.667  -75.419  51.658  1
225378  95.696  -75.412  51.629  1
225379  95.725  -75.405  51.600  1
225380  95.753  -75.398  51.569  1
225381  95.781  -75.392  51.538  1
225382  95.815  -75.386  51.508  1
225383  95.850  -75.383  51.478  1
225384  95.886  -75.379  51.447  1
225385  95.923  -75.380  51.414  1
225386  95.961  -75.380  51.383  1
225387  95.998  -75.380  51.352  1
225388  96.039  -75.386  51.320  1
225389  96.081  -75.394  51.291  1
225390  96.122  -75.402  51.263  1
225391  96.165  -75.409  51.235  1
225392  96.203  -75.414  51.207  1
225393  96.240  -75.417  51.181  1
225394  96.277  -75.428  51.155  1
225395  96.313  -75.441  51.127  1
225396  96.343  -75.452  51.102  1
225397  96.364  -75.461  51.076  1
225398  96.384  -75.469  51.050  1
225399  96.404  -75.482  51.022  1
225400  96.424  -75.494  50.997  1
225401  96.444  -75.507  50.973  1
225402  96.464  -75.520  50.949  1
225403  96.483  -75.528  50.926  1
225404  96.503  -75.531  50.903  1
225405  96.522  -75.533  50.880  1
225406  96.541  -75.538  50.857  1
225407  96.559  -75.546  50.833  1
225408  96.578  -75.554  50.809  1
225409  96.596  -75.562  50.786  1
225410  96.615  -75.570  50.764  1
225411  96.635  -75.576  50.742  1
225412  96.651  -75.587  50.718  1
225413  96.661  -75.605  50.694  1
225414  96.671  -75.624  50.669  1
225415  96.681  -75.643  50.644  1
225416  96.691  -75.662  50.620  1
225417  96.701  -75.680  50.597  1
225418  96.711  -75.699  50.572  1
225419  96.722  -75.718  50.546  1
225420  96.733  -75.738  50.519  1
225421  96.743  -75.758  50.490  1
225422  96.758  -75.776  50.458  1
225423  96.781  -75.791  50.425  1
225424  96.817  -75.803  50.391  1
225425  96.881  -75.807  50.356  1
225426  96.946  -75.811  50.322  1
225427  97.010  -75.815  50.287  1
225428  97.040  -75.822  50.252  1
225429  97.064  -75.828  50.218  1
225430  97.088  -75.834  50.182  1
225431  97.112  -75.839  50.146  1
225432  97.137  -75.845  50.110  1
225433  97.158  -75.852  50.075  1
225434  97.180  -75.859  50.042  1
225435  97.202  -75.866  50.008  1
225436  97.223  -75.873  49.973  1
225437  97.244  -75.880  49.938  1
225438  97.266  -75.887  49.904  1
225439  97.287  -75.894  49.870  1
225440  97.309  -75.900  49.836  1
225441  97.330  -75.908  49.801  1
225442  97.352  -75.915  49.766  1
225443  97.376  -75.929  49.733  1
225444  97.401  -75.944  49.701  1
225445  97.428  -75.957  49.670  1
225446  97.470  -75.956  49.641  1
225447  97.513  -75.955  49.613  1
225448  97.556  -75.953  49.587  1
225449  97.598  -75.952  49.562  1
225450  97.641  -75.950  49.537  1
225451  97.661  -75.950  49.512  1
225452  97.677  -75.959  49.487  1
225453  97.686  -75.969  49.462  1
225454  97.696  -75.980  49.435  1
225455  97.706  -75.992  49.409  1
225456  97.710  -76.003  49.380  1
225457  97.682  -75.998  49.346  1
225458  97.669  -76.003  49.308  1
225459  97.687  -76.027  49.270  1
225460  97.705  -76.052  49.231  1
225461  97.723  -76.077  49.192  1
225462  97.750  -76.089  49.152  1
225463  97.778  -76.101  49.110  1
225464  97.806  -76.113  49.068  1
225465  97.834  -76.126  49.026  1
225466  97.862  -76.138  48.984  1
225467  97.903  -76.151  48.944  1
225468  97.949  -76.163  48.904  1
225469  97.995  -76.176  48.864  1
225470  98.040  -76.189  48.823  1
225471  98.089  -76.207  48.782  1
225472  98.144  -76.241  48.741  1
225473  98.199  -76.275  48.700  1
225474  98.253  -76.308  48.659  1
225475  98.308  -76.342  48.618  1
225476  98.286  -76.376  48.576  1
225477  98.292  -76.386  48.536  1
225478  98.314  -76.389  48.496  1
225479  98.336  -76.391  48.459  1
225480  98.358  -76.393  48.422  1
225481  98.380  -76.395  48.387  1
225482  98.402  -76.398  48.354  1
225483  98.424  -76.400  48.322  1
225484  98.450  -76.401  48.290  1
225485  98.478  -76.401  48.260  1
225486  98.505  -76.401  48.229  1
225487  98.532  -76.401  48.198  1
225488  98.560  -76.403  48.166  1
225489  98.593  -76.410  48.136  1
225490  98.625  -76.417  48.107  1
225491  98.657  -76.425  48.078  1
225492  98.690  -76.433  48.051  1
225493  98.722  -76.439  48.026  1
225494  98.755  -76.447  48.001  1
225495  98.778  -76.451  47.976  1
225496  98.795  -76.451  47.954  1
225497  98.812  -76.452  47.931  1
225498  98.830  -76.453  47.909  1
225499  98.847  -76.454  47.888  1
225500  98.865  -76.455  47.867  1
225501  98.882  -76.456  47.845  1
225502  98.900  -76.457  47.822  1
225503  98.917  -76.458  47.799  1
225504  98.941  -76.460  47.776  1
225505  98.967  -76.462  47.753  1
225506  98.993  -76.464  47.729  1
225507  99.017  -76.472  47.708  1
225508  99.031  -76.474  47.680  1
225509  99.044  -76.472  47.653  1
225510  99.064  -76.470  47.624  1
225511  99.084  -76.468  47.594  1
225512  99.105  -76.467  47.563  1
225513  99.125  -76.465  47.531  1
225514  99.145  -76.466  47.499  1
225515  99.164  -76.466  47.467  1
225516  99.184  -76.467  47.433  1
225517  99.204  -76.470  47.400  1
225518  99.232  -76.477  47.366  1
225519  99.262  -76.488  47.332  1
225520  99.292  -76.500  47.296  1
225521  99.322  -76.512  47.260  1
225522  99.351  -76.524  47.222  1
225523  99.380  -76.536  47.184  1
225524  99.409  -76.549  47.147  1
225525  99.438  -76.561  47.111  1
225526  99.468  -76.573  47.073  1
225527  99.497  -76.585  47.036  1
225528  99.528  -76.598  47.000  1
225529  99.559  -76.611  46.964  1
225530  99.592  -76.624  46.927  1
225531  99.628  -76.637  46.891  1
225532  99.663  -76.649  46.856  1
225533  99.698  -76.662  46.821  1
225534  99.726  -76.671  46.787  1
225535  99.737  -76.673  46.753  1
225536  99.749  -76.674  46.720  1
225537  99.760  -76.676  46.689  1
225538  99.772  -76.677  46.659  1
225539  99.787  -76.678  46.630  1
225540  99.803  -76.679  46.602  1
225541  99.819  -76.680  46.573  1
225542  99.835  -76.680  46.545  1
225543  99.852  -76.680  46.516  1
225544  99.868  -76.681  46.488  1
225545  99.884  -76.682  46.460  1
225546  99.900  -76.682  46.431  1
225547  99.917  -76.683  46.401  1
225548  99.933  -76.683  46.372  1
225549  99.955  -76.687  46.341  1
225550  99.977  -76.689  46.310  1
225551  99.998  -76.692  46.279  1
225552  100.019  -76.694  46.249  1
225553  100.041  -76.697  46.217  1
225554  100.062  -76.699  46.186  1
225555  100.088  -76.704  46.154  1
225556  100.120  -76.712  46.123  1
225557  100.151  -76.718  46.093  1
225558  100.182  -76.725  46.062  1
225559  100.205  -76.721  46.032  1
225560  100.220  -76.705  46.003  1
225561  100.234  -76.690  45.975  1
225562  100.248  -76.673  45.949  1
225563  100.263  -76.657  45.923  1
225564  100.277  -76.641  45.898  1
225565  100.291  -76.625  45.875  1
225566  100.305  -76.609  45.852  1
225567  100.320  -76.593  45.830  1
225568  100.344  -76.601  45.809  1
225569  100.374  -76.633  45.789  1
225570  100.401  -76.668  45.772  1
225571  100.428  -76.704  45.754  1
225572  100.455  -76.739  45.737  1
225573  100.481  -76.774  45.719  1
225574  100.508  -76.809  45.702  1
225575  100.535  -76.843  45.686  1
225576  100.561  -76.878  45.669  1
225577  100.583  -76.897  45.652  1
225578  100.606  -76.915  45.635  1
225579  100.628  -76.933  45.618  1
225580  100.651  -76.951  45.601  1
225581  100.673  -76.969  45.584  1
225582  100.696  -76.987  45.567  1
225583  100.718  -77.006  45.551  1
225584  100.749  -77.012  45.536  1
225585  100.784  -77.063  45.521  1
225586  100.818  -76.992  45.507  1
225587  100.845  -77.006  45.494  1
225588  100.872  -77.020  45.481  1
225589  100.899  -77.034  45.468  1
225590  100.926  -77.047  45.455  1
225591  100.954  -77.061  45.443  1
225592  100.981  -77.075  45.431  1
225593  101.008  -77.088  45.419  1
225594  101.036  -77.102  45.408  1
225595  101.063  -77.116  45.396  1
225596  101.090  -77.129  45.386  1
225597  101.118  -77.143  45.375  1
225598  101.132  -77.168  45.364  1
225599  101.153  -77.191  45.352  1
225600  101.182  -77.212  45.339  1
225601  101.211  -77.232  45.326  1
225602  101.229  -77.255  45.312  1
225603  101.241  -77.281  45.297  1
225604  101.253  -77.307  45.281  1
225605  101.265  -77.332  45.265  1
225606  101.277  -77.358  45.249  1
225607  101.287  -77.383  45.232  1
225608  101.298  -77.408  45.215  1
225609  101.309  -77.433  45.197  1
225610  101.314  -77.445  45.178  1
225611  101.332  -77.448  45.159  1
225612  101.350  -77.450  45.140  1
225613  101.366  -77.451  45.122  1
225614  101.382  -77.453  45.103  1
225615  101.397  -77.454  45.084  1
225616  101.412  -77.456  45.064  1
225617  101.428  -77.458  45.045  1
225618  101.443  -77.460  45.026  1
225619  101.459  -77.461  45.008  1
225620  101.474  -77.463  44.990  1
225621  101.489  -77.464  44.973  1
225622  101.505  -77.466  44.955  1
225623  101.520  -77.467  44.938  1
225624  101.536  -77.469  44.921  1
225625  101.551  -77.471  44.905  1
225626  101.533  -77.515  44.889  1
225627  101.553  -77.535  44.873  1
225628  101.572  -77.555  44.856  1
225629  101.606  -77.567  44.839  1
225630  101.642  -77.580  44.822  1
225631  101.679  -77.592  44.805  1
225632  101.715  -77.603  44.789  1
225633  101.751  -77.615  44.773  1
225634  101.787  -77.627  44.757  1
225635  101.823  -77.639  44.741  1
225636  101.859  -77.650  44.725  1
225637  101.896  -77.662  44.709  1
225638  101.925  -77.677  44.693  1
225639  101.939  -77.699  44.677  1
225640  101.971  -77.711  44.662  1
225641  102.014  -77.716  44.646  1
225642  102.048  -77.727  44.631  1
225643  102.081  -77.739  44.614  1
225644  102.113  -77.751  44.598  1
225645  102.145  -77.762  44.582  1
225646  102.173  -77.773  44.567  1
225647  102.201  -77.783  44.553  1
225648  102.231  -77.785  44.538  1
225649  102.257  -77.792  44.523  1
225650  102.280  -77.806  44.508  1
225651  102.304  -77.821  44.493  1
225652  102.327  -77.836  44.478  1
225653  102.350  -77.851  44.464  1
225654  102.374  -77.865  44.449  1
225655  102.397  -77.881  44.434  1
225656  102.424  -77.898  44.419  1
225657  102.450  -77.906  44.403  1
225658  102.472  -77.909  44.387  1
225659  102.493  -77.913  44.373  1
225660  102.517  -77.915  44.358  1
225661  102.541  -77.918  44.343  1
225662  102.566  -77.919  44.327  1
225663  102.590  -77.921  44.311  1
225664  102.615  -77.923  44.295  1
225665  102.635  -77.928  44.279  1
225666  102.653  -77.934  44.264  1
225667  102.675  -77.941  44.249  1
225668  102.704  -77.947  44.234  1
225669  102.733  -77.954  44.219  1
225670  102.763  -77.960  44.203  1
225671  102.801  -77.965  44.186  1
225672  102.837  -77.971  44.169  1
225673  102.874  -77.976  44.152  1
225674  102.911  -77.981  44.135  1
225675  102.948  -77.987  44.119  1
225676  102.986  -77.993  44.103  1
225677  103.026  -78.003  44.087  1
225678  103.066  -78.015  44.070  1
225679  103.105  -78.026  44.054  1
225680  103.145  -78.037  44.038  1
225681  103.185  -78.048  44.021  1
225682  103.225  -78.059  44.004  1
225683  103.265  -78.071  43.988  1
225924  92.141  -75.147  54.244  1
225925  92.164  -75.158  54.250  1
225926  92.187  -75.170  54.257  1
225927  92.210  -75.180  54.264  1
225928  92.233  -75.192  54.274  1
225929  92.256  -75.202  54.285  1
225930  92.279  -75.214  54.295  1
225931  92.302  -75.225  54.306  1
225932  92.325  -75.236  54.315  1
225933  92.348  -75.247  54.322  1
225934  92.371  -75.258  54.329  1
225935  92.394  -75.269  54.336  1
225936  92.411  -75.276  54.342  1
225937  92.431  -75.268  54.345  1
225938  92.451  -75.265  54.345  1
225939  92.482  -75.261  54.342  1
225940  92.512  -75.257  54.337  1
225941  92.543  -75.252  54.329  1
225942  92.574  -75.248  54.324  1
225943  92.605  -75.244  54.317  1
225944  92.636  -75.240  54.308  1
225945  92.666  -75.236  54.298  1
225946  92.697  -75.232  54.285  1
225947  92.728  -75.227  54.272  1
225948  92.759  -75.223  54.259  1
225949  92.790  -75.219  54.248  1
225950  92.820  -75.215  54.236  1
225951  92.851  -75.210  54.223  1
225952  92.882  -75.207  54.211  1
225953  92.900  -75.210  54.199  1
225954  92.919  -75.213  54.186  1
225955  92.937  -75.216  54.172  1
225956  92.960  -75.214  54.159  1
225957  92.984  -75.214  54.147  1
225958  93.007  -75.212  54.134  1
225959  93.030  -75.210  54.120  1
225960  93.054  -75.210  54.106  1
225961  93.077  -75.208  54.092  1
225962  93.100  -75.207  54.076  1
225963  93.124  -75.206  54.061  1
225964  93.147  -75.204  54.047  1
225970  93.287  -75.197  53.986  1
225971  93.310  -75.196  53.983  1
225972  93.334  -75.195  53.982  1
225973  93.357  -75.193  53.985  1
225974  93.380  -75.192  53.991  1
225975  93.404  -75.191  54.000  1
225976  93.427  -75.190  54.011  1
225977  93.450  -75.189  54.026  1
225978  93.474  -75.187  54.045  1
225979  93.497  -75.186  54.070  1
225980  93.520  -75.185  54.100  1
225981  93.557  -75.183  54.138  1
225982  93.595  -75.181  54.179  1
225983  93.630  -75.179  54.224  1
225984  93.661  -75.178  54.271  1
225985  93.693  -75.177  54.312  1
225986  93.724  -75.176  54.349  1
225987  93.756  -75.174  54.379  1
225988  93.786  -75.173  54.403  1
225989  93.813  -75.169  54.414  1
225990  93.839  -75.166  54.422  1
225991  93.865  -75.162  54.428  1
225992  93.892  -75.159  54.436  1
225993  93.917  -75.157  54.442  1
225994  93.943  -75.154  54.445  1
225995  93.969  -75.151  54.443  1
225996  93.995  -75.148  54.437  1
225997  94.017  -75.138  54.437  1
225998  94.040  -75.130  54.438  1
225999  94.064  -75.124  54.441  1
226000  94.090  -75.126  54.444  1
226001  94.116  -75.129  54.449  1
226002  94.140  -75.129  54.452  1
226003  94.164  -75.127  54.451  1
226004  94.188  -75.125  54.454  1
226005  94.211  -75.122  54.460  1
226006  94.235  -75.120  54.465  1
226007  94.259  -75.117  54.469  1
226008  94.282  -75.115  54.468  1
226009  94.307  -75.116  54.461  1
226010  94.332  -75.116  54.448  1
226011  94.357  -75.116  54.427  1
226012  94.383  -75.116  54.405  1
226013  94.408  -75.116  54.382  1
226014  94.434  -75.116  54.359  1
226015  94.460  -75.116  54.339  1
226016  94.486  -75.116  54.315  1
226017  94.508  -75.116  54.287  1
226018  94.523  -75.117  54.256  1
226019  94.537  -75.119  54.221  1
226020  94.551  -75.120  54.187  1
226021  94.565  -75.122  54.153  1
226022  94.578  -75.123  54.119  1
226023  94.593  -75.125  54.082  1
226024  94.607  -75.126  54.045  1
226025  94.621  -75.128  54.008  1
226026  94.635  -75.129  53.971  1
226027  94.649  -75.131  53.933  1
226028  94.660  -75.140  53.894  1
226029  94.681  -75.145  53.854  1
226030  94.704  -75.147  53.810  1
226031  94.729  -75.150  53.765  1
226032  94.754  -75.153  53.720  1
226033  94.771  -75.157  53.673  1
226034  94.765  -75.162  53.626  1
226035  94.758  -75.167  53.582  1
226036  94.752  -75.173  53.536  1
226037  94.745  -75.178  53.491  1
226038  94.738  -75.183  53.447  1
226039  94.745  -75.188  53.401  1
226040  94.763  -75.190  53.352  1
226041  94.781  -75.193  53.301  1
226042  94.799  -75.196  53.252  1
226043  94.816  -75.199  53.201  1
226044  94.834  -75.201  53.151  1
226045  94.852  -75.204  53.102  1
226046  94.870  -75.207  53.053  1
226047  94.888  -75.210  53.002  1
226048  94.906  -75.213  52.951  1
226049  94.923  -75.216  52.900  1
226050  94.948  -75.219  52.847  1
226051  94.973  -75.222  52.792  1
226052  94.999  -75.226  52.737  1
226053  95.025  -75.229  52.681  1
226054  95.051  -75.232  52.626  1
226055  95.076  -75.236  52.572  1
226056  95.102  -75.239  52.519  1
226057  95.128  -75.242  52.467  1
226058  95.154  -75.246  52.417  1
226059  95.179  -75.249  52.367  1
226060  95.209  -75.257  52.318  1
226061  95.244  -75.267  52.271  1
226062  95.268  -75.280  52.226  1
226063  95.288  -75.294  52.181  1
226064  95.312  -75.305  52.138  1
226065  95.336  -75.316  52.096  1
226066  95.360  -75.326  52.055  1
226067  95.385  -75.337  52.016  1
226068  95.409  -75.348  51.979  1
226069  95.433  -75.358  51.941  1
226070  95.457  -75.369  51.907  1
226071  95.481  -75.380  51.873  1
226072  95.506  -75.390  51.840  1
226073  95.530  -75.401  51.808  1
226074  95.554  -75.410  51.775  1
226075  95.583  -75.403  51.743  1
226076  95.611  -75.395  51.712  1
226077  95.640  -75.389  51.683  1
226078  95.669  -75.382  51.654  1
226079  95.697  -75.375  51.626  1
226080  95.726  -75.368  51.598  1
226081  95.754  -75.361  51.569  1
226082  95.783  -75.355  51.538  1
226083  95.812  -75.348  51.508  1
226084  95.841  -75.341  51.479  1
226085  95.877  -75.339  51.447  1
226086  95.917  -75.343  51.416  1
226087  95.959  -75.352  51.384  1
226088  96.001  -75.359  51.353  1
226089  96.043  -75.367  51.324  1
226090  96.085  -75.374  51.295  1
226091  96.126  -75.383  51.266  1
226092  96.168  -75.390  51.239  1
226093  96.207  -75.395  51.212  1
226094  96.245  -75.398  51.186  1
226095  96.282  -75.402  51.160  1
226096  96.319  -75.407  51.132  1
226097  96.352  -75.418  51.107  1
226098  96.372  -75.428  51.082  1
226099  96.392  -75.441  51.055  1
226100  96.412  -75.453  51.028  1
226101  96.432  -75.466  51.003  1
226102  96.452  -75.479  50.979  1
226103  96.471  -75.491  50.955  1
226104  96.491  -75.504  50.933  1
226105  96.511  -75.508  50.911  1
226106  96.530  -75.511  50.888  1
226107  96.549  -75.515  50.865  1
226108  96.568  -75.523  50.841  1
226109  96.586  -75.531  50.817  1
226110  96.605  -75.539  50.793  1
226111  96.623  -75.546  50.770  1
226112  96.645  -75.551  50.747  1
226113  96.661  -75.561  50.724  1
226114  96.671  -75.580  50.699  1
226115  96.681  -75.599  50.674  1
226116  96.691  -75.617  50.649  1
226117  96.701  -75.636  50.625  1
226118  96.711  -75.654  50.601  1
226119  96.721  -75.673  50.576  1
226120  96.731  -75.692  50.549  1
226121  96.741  -75.710  50.521  1
226122  96.751  -75.729  50.492  1
226123  96.761  -75.749  50.460  1
226124  96.778  -75.766  50.428  1
226125  96.830  -75.774  50.395  1
226126  96.894  -75.778  50.361  1
226127  96.959  -75.782  50.329  1
226128  97.023  -75.787  50.295  1
226129  97.063  -75.792  50.262  1
226130  97.087  -75.798  50.228  1
226131  97.110  -75.804  50.193  1
226132  97.132  -75.811  50.158  1
226133  97.154  -75.818  50.123  1
226134  97.175  -75.825  50.088  1
226135  97.196  -75.832  50.056  1
226136  97.218  -75.839  50.021  1
226137  97.239  -75.846  49.987  1
226138  97.261  -75.853  49.953  1
226139  97.282  -75.860  49.919  1
226140  97.304  -75.867  49.885  1
226141  97.325  -75.874  49.850  1
226142  97.347  -75.881  49.815  1
226143  97.369  -75.891  49.780  1
226144  97.394  -75.906  49.746  1
226145  97.419  -75.920  49.714  1
226146  97.444  -75.935  49.682  1
226147  97.485  -75.935  49.652  1
226148  97.527  -75.934  49.624  1
226149  97.570  -75.932  49.599  1
226150  97.613  -75.931  49.575  1
226151  97.656  -75.930  49.549  1
226152  97.696  -75.928  49.524  1
226153  97.712  -75.935  49.498  1
226154  97.723  -75.947  49.470  1
226155  97.734  -75.957  49.443  1
226156  97.745  -75.969  49.415  1
226157  97.743  -75.971  49.384  1
226158  97.716  -75.966  49.348  1
226159  97.696  -75.966  49.311  1
226160  97.713  -75.991  49.271  1
226161  97.731  -76.016  49.232  1
226162  97.749  -76.041  49.192  1
226163  97.767  -76.065  49.152  1
226164  97.795  -76.078  49.110  1
226165  97.823  -76.090  49.067  1
226166  97.851  -76.102  49.024  1
226167  97.878  -76.114  48.982  1
226168  97.920  -76.127  48.941  1
226169  97.966  -76.140  48.900  1
226170  98.012  -76.153  48.859  1
226171  98.058  -76.166  48.818  1
226172  98.113  -76.201  48.777  1
226173  98.168  -76.235  48.736  1
226174  98.223  -76.268  48.694  1
226175  98.273  -76.294  48.653  1
226176  98.318  -76.312  48.612  1
226177  98.344  -76.329  48.570  1
226178  98.355  -76.347  48.530  1
226179  98.323  -76.378  48.491  1
226180  98.346  -76.380  48.453  1
226181  98.367  -76.383  48.415  1
226182  98.389  -76.385  48.381  1
226183  98.412  -76.387  48.347  1
226184  98.434  -76.389  48.315  1
226185  98.458  -76.391  48.283  1
226186  98.486  -76.391  48.251  1
226187  98.513  -76.391  48.221  1
226188  98.540  -76.391  48.191  1
226189  98.567  -76.391  48.161  1
226190  98.594  -76.392  48.131  1
226191  98.622  -76.392  48.102  1
226192  98.654  -76.398  48.073  1
226193  98.686  -76.406  48.046  1
226194  98.719  -76.414  48.021  1
226195  98.751  -76.420  47.996  1
226196  98.774  -76.424  47.972  1
226197  98.792  -76.425  47.950  1
226198  98.809  -76.426  47.927  1
226199  98.827  -76.426  47.906  1
226200  98.844  -76.428  47.885  1
226201  98.861  -76.429  47.864  1
226202  98.885  -76.431  47.842  1
226203  98.912  -76.433  47.819  1
226204  98.937  -76.436  47.796  1
226205  98.963  -76.438  47.774  1
226206  98.990  -76.440  47.751  1
226207  99.015  -76.443  47.727  1
226208  99.040  -76.455  47.703  1
226209  99.059  -76.461  47.676  1
226210  99.067  -76.458  47.649  1
226211  99.075  -76.455  47.620  1
226212  99.095  -76.454  47.590  1
226213  99.116  -76.451  47.559  1
226214  99.136  -76.450  47.527  1
226215  99.156  -76.448  47.495  1
226216  99.177  -76.447  47.463  1
226217  99.197  -76.445  47.429  1
226218  99.217  -76.444  47.396  1
226219  99.245  -76.453  47.364  1
226220  99.274  -76.465  47.330  1
226221  99.304  -76.477  47.295  1
226222  99.333  -76.489  47.258  1
226223  99.362  -76.502  47.222  1
226224  99.392  -76.514  47.184  1
226225  99.421  -76.527  47.148  1
226226  99.450  -76.539  47.111  1
226227  99.480  -76.551  47.074  1
226228  99.510  -76.564  47.038  1
226229  99.541  -76.577  47.002  1
226230  99.572  -76.589  46.966  1
226231  99.607  -76.602  46.930  1
226232  99.641  -76.615  46.895  1
226233  99.677  -76.628  46.859  1
226234  99.712  -76.641  46.825  1
226235  99.747  -76.653  46.791  1
226236  99.773  -76.662  46.758  1
226237  99.785  -76.664  46.726  1
226238  99.796  -76.665  46.695  1
226239  99.808  -76.667  46.664  1
226240  99.823  -76.668  46.637  1
226241  99.839  -76.668  46.608  1
226242  99.855  -76.668  46.580  1
226243  99.871  -76.669  46.552  1
226244  99.888  -76.670  46.521  1
226245  99.904  -76.670  46.493  1
226246  99.920  -76.671  46.465  1
226247  99.936  -76.671  46.436  1
226248  99.952  -76.672  46.407  1
226249  99.969  -76.672  46.376  1
226250  99.985  -76.673  46.344  1
226251  100.002  -76.674  46.311  1
226252  100.023  -76.676  46.280  1
226253  100.045  -76.679  46.249  1
226254  100.066  -76.682  46.216  1
226255  100.087  -76.684  46.184  1
226256  100.114  -76.690  46.154  1
226257  100.146  -76.696  46.123  1
226258  100.177  -76.703  46.091  1
226259  100.194  -76.690  46.061  1
226260  100.208  -76.674  46.031  1
226261  100.222  -76.658  46.002  1
226262  100.237  -76.643  45.974  1
226263  100.251  -76.627  45.947  1
226264  100.265  -76.611  45.920  1
226265  100.279  -76.595  45.895  1
226266  100.293  -76.578  45.872  1
226267  100.308  -76.562  45.849  1
226268  100.322  -76.546  45.827  1
226269  100.347  -76.565  45.806  1
226270  100.373  -76.600  45.787  1
226271  100.401  -76.635  45.768  1
226272  100.427  -76.670  45.750  1
226273  100.454  -76.705  45.732  1
226274  100.481  -76.740  45.714  1
226275  100.507  -76.775  45.697  1
226276  100.534  -76.810  45.680  1
226277  100.561  -76.845  45.664  1
226278  100.587  -76.878  45.647  1
226279  100.609  -76.896  45.629  1
226280  100.632  -76.914  45.612  1
226281  100.654  -76.932  45.595  1
226282  100.677  -76.950  45.578  1
226283  100.699  -76.969  45.561  1
226284  100.728  -76.976  45.545  1
226285  100.770  -76.967  45.530  1
226286  100.811  -76.957  45.515  1
226287  100.846  -76.946  45.502  1
226288  100.874  -76.959  45.488  1
226289  100.901  -76.973  45.475  1
226290  100.928  -76.987  45.462  1
226291  100.956  -77.000  45.448  1
226292  100.983  -77.014  45.435  1
226293  101.008  -77.029  45.423  1
226294  101.019  -77.058  45.412  1
226295  101.030  -77.086  45.401  1
226296  101.047  -77.111  45.389  1
226297  101.076  -77.132  45.379  1
226298  101.105  -77.151  45.369  1
226299  101.134  -77.172  45.357  1
226300  101.164  -77.191  45.345  1
226301  101.193  -77.211  45.332  1
226302  101.222  -77.232  45.318  1
226303  101.238  -77.256  45.304  1
226304  101.250  -77.282  45.289  1
226305  101.262  -77.307  45.273  1
226306  101.274  -77.332  45.257  1
226307  101.286  -77.358  45.240  1
226308  101.298  -77.384  45.224  1
226309  101.310  -77.409  45.206  1
226310  101.324  -77.425  45.188  1
226311  101.343  -77.430  45.169  1
226312  101.359  -77.432  45.150  1
226313  101.375  -77.434  45.132  1
226314  101.390  -77.436  45.113  1
226315  101.406  -77.437  45.094  1
226316  101.421  -77.439  45.075  1
226317  101.437  -77.441  45.055  1
226318  101.452  -77.442  45.035  1
226319  101.467  -77.444  45.017  1
226320  101.483  -77.445  44.999  1
226321  101.498  -77.447  44.981  1
226322  101.513  -77.448  44.963  1
226323  101.529  -77.450  44.946  1
226324  101.544  -77.451  44.929  1
226325  101.560  -77.454  44.913  1
226326  101.575  -77.455  44.896  1
226327  101.560  -77.492  44.880  1
226328  101.580  -77.511  44.865  1
226329  101.600  -77.531  44.847  1
226330  101.620  -77.551  44.830  1
226331  101.645  -77.567  44.813  1
226332  101.682  -77.580  44.796  1
226333  101.718  -77.591  44.780  1
226334  101.754  -77.603  44.764  1
226335  101.790  -77.615  44.749  1
226336  101.827  -77.627  44.733  1
226337  101.863  -77.639  44.716  1
226338  101.899  -77.650  44.700  1
226339  101.927  -77.666  44.685  1
226340  101.941  -77.687  44.669  1
226341  101.983  -77.694  44.653  1
226342  102.027  -77.699  44.636  1
226343  102.062  -77.709  44.620  1
226344  102.095  -77.721  44.605  1
226345  102.127  -77.733  44.589  1
226346  102.160  -77.745  44.573  1
226347  102.192  -77.756  44.558  1
226348  102.221  -77.767  44.544  1
226349  102.249  -77.773  44.529  1
226350  102.276  -77.780  44.514  1
226351  102.299  -77.796  44.500  1
226352  102.323  -77.810  44.485  1
226353  102.346  -77.825  44.470  1
226354  102.369  -77.840  44.456  1
226355  102.393  -77.855  44.441  1
226356  102.416  -77.870  44.426  1
226357  102.439  -77.884  44.411  1
226358  102.464  -77.889  44.395  1
226359  102.488  -77.890  44.378  1
226360  102.512  -77.893  44.363  1
226361  102.537  -77.894  44.349  1
226362  102.561  -77.896  44.333  1
226363  102.586  -77.898  44.317  1
226364  102.610  -77.900  44.301  1
226365  102.629  -77.906  44.285  1
226366  102.647  -77.912  44.269  1
226367  102.665  -77.918  44.254  1
226368  102.690  -77.925  44.238  1
226369  102.719  -77.932  44.223  1
226370  102.748  -77.938  44.208  1
226371  102.785  -77.943  44.191  1
226372  102.822  -77.949  44.174  1
226373  102.859  -77.954  44.158  1
226374  102.896  -77.959  44.141  1
226375  102.933  -77.965  44.124  1
226376  102.970  -77.969  44.108  1
226377  103.007  -77.975  44.092  1
226378  103.044  -77.980  44.075  1
226379  103.081  -77.985  44.059  1
226380  103.118  -77.990  44.043  1
226381  103.157  -78.000  44.025  1
226382  103.197  -78.012  44.009  1
226383  103.237  -78.023  43.993  1
226625  92.128  -75.118  54.251  1
226626  92.151  -75.129  54.257  1
226627  92.174  -75.140  54.263  1
226628  92.197  -75.151  54.269  1
226629  92.220  -75.162  54.279  1
226630  92.243  -75.173  54.290  1
226631  92.267  -75.185  54.300  1
226632  92.289  -75.195  54.311  1
226633  92.312  -75.207  54.321  1
226634  92.336  -75.217  54.329  1
226635  92.359  -75.229  54.337  1
226636  92.382  -75.240  54.345  1
226637  92.402  -75.251  54.352  1
226638  92.421  -75.245  54.357  1
226639  92.443  -75.241  54.359  1
226640  92.475  -75.237  54.356  1
226641  92.505  -75.232  54.351  1
226642  92.536  -75.229  54.344  1
226643  92.567  -75.224  54.339  1
226644  92.597  -75.220  54.332  1
226645  92.629  -75.216  54.323  1
226646  92.659  -75.212  54.313  1
226647  92.690  -75.207  54.300  1
226648  92.721  -75.204  54.287  1
226649  92.752  -75.199  54.274  1
226650  92.783  -75.195  54.262  1
226651  92.813  -75.191  54.249  1
226652  92.844  -75.187  54.237  1
226653  92.874  -75.183  54.226  1
226654  92.892  -75.186  54.215  1
226655  92.913  -75.188  54.201  1
226656  92.936  -75.186  54.188  1
226657  92.959  -75.185  54.175  1
226658  92.983  -75.184  54.162  1
226659  93.006  -75.182  54.149  1
226660  93.029  -75.182  54.135  1
226661  93.053  -75.180  54.121  1
226662  93.076  -75.179  54.107  1
226663  93.099  -75.178  54.091  1
226664  93.123  -75.176  54.076  1
226665  93.146  -75.175  54.062  1
226670  93.263  -75.169  54.005  1
226671  93.286  -75.167  53.999  1
226672  93.309  -75.167  53.995  1
226673  93.333  -75.165  53.993  1
226674  93.356  -75.164  53.996  1
226675  93.379  -75.163  54.001  1
226676  93.403  -75.161  54.009  1
226677  93.426  -75.160  54.020  1
226678  93.449  -75.159  54.035  1
226679  93.473  -75.157  54.055  1
226680  93.496  -75.157  54.079  1
226681  93.519  -75.155  54.110  1
226682  93.556  -75.154  54.149  1
226683  93.592  -75.152  54.191  1
226684  93.623  -75.151  54.235  1
226685  93.654  -75.149  54.283  1
226686  93.686  -75.148  54.325  1
226687  93.717  -75.146  54.363  1
226688  93.749  -75.145  54.395  1
226689  93.780  -75.143  54.420  1
226690  93.810  -75.142  54.434  1
226691  93.836  -75.138  54.443  1
226692  93.862  -75.135  54.449  1
226693  93.888  -75.132  54.454  1
226694  93.914  -75.129  54.459  1
226695  93.940  -75.126  54.460  1
226696  93.966  -75.123  54.457  1
226697  93.992  -75.121  54.449  1
226698  94.017  -75.118  54.448  1
226699  94.042  -75.112  54.452  1
226700  94.064  -75.103  54.458  1
226701  94.088  -75.100  54.463  1
226702  94.115  -75.102  54.467  1
226703  94.139  -75.103  54.467  1
226704  94.163  -75.101  54.464  1
226705  94.187  -75.098  54.463  1
226706  94.210  -75.095  54.464  1
226707  94.234  -75.093  54.468  1
226708  94.258  -75.091  54.474  1
226709  94.281  -75.088  54.475  1
226710  94.307  -75.085  54.470  1
226711  94.331  -75.080  54.458  1
226712  94.356  -75.080  54.439  1
226713  94.382  -75.079  54.420  1
226714  94.408  -75.079  54.398  1
226715  94.433  -75.079  54.376  1
226716  94.459  -75.079  54.355  1
226717  94.485  -75.079  54.329  1
226718  94.507  -75.079  54.301  1
226719  94.522  -75.081  54.269  1
226720  94.536  -75.082  54.234  1
226721  94.550  -75.084  54.201  1
226722  94.564  -75.085  54.169  1
226723  94.578  -75.087  54.136  1
226724  94.592  -75.088  54.101  1
226725  94.606  -75.090  54.065  1
226726  94.620  -75.091  54.028  1
226727  94.631  -75.100  53.989  1
226728  94.641  -75.109  53.950  1
226729  94.659  -75.116  53.910  1
226730  94.680  -75.123  53.867  1
226731  94.700  -75.123  53.822  1
226732  94.723  -75.125  53.776  1
226733  94.748  -75.128  53.731  1
226734  94.772  -75.131  53.686  1
226735  94.775  -75.135  53.640  1
226736  94.768  -75.141  53.596  1
226737  94.762  -75.146  53.551  1
226738  94.755  -75.152  53.506  1
226739  94.748  -75.157  53.462  1
226740  94.763  -75.160  53.416  1
226741  94.781  -75.163  53.368  1
226742  94.799  -75.166  53.318  1
226743  94.817  -75.169  53.270  1
226744  94.835  -75.172  53.219  1
226745  94.852  -75.174  53.168  1
226746  94.871  -75.177  53.119  1
226747  94.888  -75.180  53.070  1
226748  94.906  -75.182  53.019  1
226749  94.922  -75.188  52.967  1
226750  94.930  -75.189  52.916  1
226751  94.957  -75.192  52.862  1
226752  94.982  -75.195  52.805  1
226753  95.007  -75.198  52.748  1
226754  95.033  -75.200  52.691  1
226755  95.058  -75.203  52.634  1
226756  95.084  -75.205  52.579  1
226757  95.109  -75.208  52.525  1
226758  95.135  -75.212  52.470  1
226759  95.161  -75.215  52.420  1
226760  95.186  -75.219  52.369  1
226761  95.215  -75.224  52.320  1
226762  95.242  -75.237  52.272  1
226763  95.265  -75.248  52.225  1
226764  95.289  -75.259  52.181  1
226765  95.313  -75.270  52.137  1
226766  95.337  -75.280  52.095  1
226767  95.361  -75.291  52.054  1
226768  95.386  -75.301  52.015  1
226769  95.410  -75.312  51.976  1
226770  95.434  -75.323  51.938  1
226771  95.458  -75.333  51.905  1
226772  95.482  -75.344  51.871  1
226773  95.507  -75.355  51.837  1
226774  95.531  -75.365  51.804  1
226775  95.555  -75.373  51.772  1
226776  95.584  -75.366  51.740  1
226777  95.613  -75.359  51.709  1
226778  95.641  -75.352  51.681  1
226779  95.670  -75.345  51.652  1
226780  95.698  -75.338  51.623  1
226781  95.727  -75.331  51.595  1
226782  95.756  -75.324  51.567  1
226783  95.784  -75.317  51.537  1
226784  95.813  -75.311  51.508  1
226785  95.845  -75.308  51.478  1
226786  95.883  -75.315  51.448  1
226787  95.921  -75.323  51.417  1
226788  95.963  -75.332  51.387  1
226789  96.005  -75.340  51.357  1
226790  96.046  -75.348  51.327  1
226791  96.089  -75.355  51.298  1
226792  96.130  -75.363  51.270  1
226793  96.172  -75.371  51.243  1
226794  96.211  -75.376  51.218  1
226795  96.249  -75.379  51.192  1
226796  96.286  -75.383  51.165  1
226797  96.324  -75.386  51.138  1
226798  96.360  -75.387  51.113  1
226799  96.380  -75.400  51.088  1
226800  96.400  -75.412  51.062  1
226801  96.419  -75.425  51.036  1
226802  96.439  -75.437  51.011  1
226803  96.459  -75.450  50.987  1
226804  96.479  -75.463  50.963  1
226805  96.499  -75.475  50.942  1
226806  96.519  -75.486  50.919  1
226807  96.538  -75.489  50.897  1
226808  96.557  -75.493  50.874  1
226809  96.576  -75.500  50.850  1
226810  96.594  -75.508  50.824  1
226811  96.613  -75.516  50.799  1
226812  96.633  -75.521  50.776  1
226813  96.654  -75.526  50.752  1
226814  96.671  -75.536  50.728  1
226815  96.681  -75.554  50.704  1
226816  96.691  -75.573  50.679  1
226817  96.701  -75.592  50.655  1
226818  96.711  -75.610  50.631  1
226819  96.721  -75.629  50.606  1
226820  96.731  -75.647  50.581  1
226821  96.741  -75.666  50.553  1
226822  96.751  -75.684  50.524  1
226823  96.760  -75.703  50.494  1
226824  96.770  -75.722  50.465  1
226825  96.784  -75.740  50.434  1
226826  96.842  -75.746  50.402  1
226827  96.907  -75.750  50.369  1
226828  96.971  -75.754  50.336  1
226829  97.036  -75.759  50.304  1
226830  97.084  -75.763  50.271  1
226831  97.106  -75.771  50.237  1
226832  97.127  -75.778  50.202  1
226833  97.149  -75.784  50.168  1
226834  97.170  -75.791  50.135  1
226835  97.191  -75.798  50.102  1
226836  97.213  -75.805  50.069  1
226837  97.234  -75.812  50.036  1
226838  97.256  -75.819  50.002  1
226839  97.277  -75.826  49.968  1
226840  97.299  -75.833  49.934  1
226841  97.320  -75.840  49.900  1
226842  97.342  -75.847  49.865  1
226843  97.363  -75.854  49.830  1
226844  97.387  -75.867  49.796  1
226845  97.412  -75.882  49.761  1
226846  97.437  -75.897  49.727  1
226847  97.461  -75.911  49.693  1
226848  97.499  -75.915  49.663  1
226849  97.542  -75.913  49.635  1
226850  97.585  -75.912  49.609  1
226851  97.628  -75.910  49.584  1
226852  97.668  -75.909  49.559  1
226853  97.699  -75.906  49.533  1
226854  97.723  -75.909  49.506  1
226855  97.734  -75.919  49.477  1
226856  97.745  -75.931  49.448  1
226857  97.756  -75.941  49.419  1
226858  97.759  -75.939  49.387  1
226859  97.749  -75.935  49.350  1
226860  97.722  -75.930  49.311  1
226861  97.740  -75.955  49.271  1
226862  97.757  -75.980  49.231  1
226863  97.776  -76.005  49.191  1
226864  97.793  -76.030  49.149  1
226865  97.812  -76.053  49.107  1
226866  97.840  -76.066  49.064  1
226867  97.867  -76.078  49.022  1
226868  97.895  -76.091  48.980  1
226869  97.937  -76.103  48.938  1
226870  97.983  -76.116  48.897  1
226871  98.028  -76.129  48.856  1
226872  98.082  -76.160  48.814  1
226873  98.137  -76.194  48.772  1
226874  98.191  -76.226  48.730  1
226875  98.236  -76.244  48.688  1
226876  98.282  -76.262  48.647  1
226877  98.326  -76.280  48.607  1
226878  98.359  -76.296  48.565  1
226879  98.371  -76.314  48.524  1
226880  98.383  -76.332  48.485  1
226881  98.394  -76.350  48.446  1
226882  98.377  -76.372  48.408  1
226883  98.400  -76.374  48.373  1
226884  98.421  -76.376  48.339  1
226885  98.443  -76.379  48.306  1
226886  98.467  -76.381  48.274  1
226887  98.494  -76.381  48.242  1
226888  98.521  -76.381  48.212  1
226889  98.549  -76.381  48.182  1
226890  98.576  -76.382  48.152  1
226891  98.603  -76.382  48.123  1
226892  98.630  -76.382  48.094  1
226893  98.657  -76.382  48.067  1
226894  98.685  -76.382  48.040  1
226895  98.715  -76.387  48.015  1
226896  98.747  -76.394  47.991  1
226897  98.771  -76.398  47.967  1
226898  98.788  -76.398  47.945  1
226899  98.806  -76.400  47.923  1
226900  98.830  -76.401  47.901  1
226901  98.856  -76.404  47.880  1
226902  98.882  -76.406  47.859  1
226903  98.908  -76.408  47.838  1
226904  98.934  -76.411  47.816  1
226905  98.960  -76.414  47.794  1
226906  98.987  -76.416  47.771  1
226907  99.012  -76.418  47.748  1
226908  99.038  -76.426  47.724  1
226909  99.062  -76.436  47.698  1
226910  99.085  -76.448  47.672  1
226911  99.094  -76.445  47.644  1
226912  99.102  -76.442  47.615  1
226913  99.110  -76.439  47.585  1
226914  99.126  -76.437  47.554  1
226915  99.146  -76.435  47.522  1
226916  99.167  -76.433  47.490  1
226917  99.187  -76.432  47.458  1
226918  99.207  -76.430  47.425  1
226919  99.227  -76.429  47.393  1
226920  99.257  -76.431  47.360  1
226921  99.286  -76.443  47.327  1
226922  99.315  -76.455  47.292  1
226923  99.345  -76.467  47.256  1
226924  99.374  -76.480  47.220  1
226925  99.403  -76.492  47.184  1
226926  99.432  -76.504  47.148  1
226927  99.462  -76.516  47.111  1
226928  99.492  -76.529  47.075  1
226929  99.523  -76.542  47.040  1
226930  99.554  -76.555  47.004  1
226931  99.585  -76.568  46.968  1
226932  99.620  -76.581  46.932  1
226933  99.655  -76.594  46.897  1
226934  99.691  -76.606  46.863  1
226935  99.725  -76.619  46.829  1
226936  99.761  -76.632  46.795  1
226937  99.796  -76.645  46.763  1
226938  99.821  -76.652  46.732  1
226939  99.833  -76.654  46.701  1
226940  99.844  -76.655  46.672  1
226941  99.859  -76.657  46.643  1
226942  99.875  -76.657  46.615  1
226943  99.891  -76.658  46.587  1
226944  99.908  -76.658  46.557  1
226945  99.924  -76.658  46.528  1
226946  99.940  -76.659  46.499  1
226947  99.956  -76.660  46.470  1
226948  99.973  -76.661  46.440  1
226949  99.989  -76.661  46.409  1
226950  100.005  -76.661  46.378  1
226951  100.021  -76.662  46.345  1
226952  100.037  -76.662  46.312  1
226953  100.054  -76.663  46.281  1
226954  100.070  -76.664  46.249  1
226955  100.091  -76.666  46.216  1
226956  100.113  -76.669  46.184  1
226957  100.140  -76.674  46.153  1
226958  100.168  -76.675  46.121  1
226959  100.182  -76.659  46.090  1
226960  100.196  -76.643  46.060  1
226961  100.210  -76.627  46.030  1
226962  100.225  -76.611  46.001  1
226963  100.239  -76.596  45.972  1
226964  100.253  -76.580  45.945  1
226965  100.270  -76.573  45.918  1
226966  100.287  -76.567  45.893  1
226967  100.304  -76.563  45.870  1
226968  100.322  -76.558  45.847  1
226969  100.339  -76.553  45.825  1
226970  100.359  -76.561  45.804  1
226971  100.380  -76.583  45.785  1
226972  100.402  -76.605  45.765  1
226973  100.427  -76.636  45.746  1
226974  100.454  -76.671  45.728  1
226975  100.480  -76.706  45.709  1
226976  100.507  -76.741  45.692  1
226977  100.534  -76.776  45.675  1
226978  100.560  -76.811  45.658  1
226979  100.587  -76.846  45.642  1
226980  100.613  -76.878  45.624  1
226981  100.635  -76.896  45.606  1
226982  100.657  -76.914  45.589  1
226983  100.680  -76.932  45.572  1
226984  100.709  -76.940  45.555  1
226985  100.750  -76.931  45.539  1
226986  100.791  -76.922  45.523  1
226987  100.833  -76.912  45.509  1
226988  100.874  -76.902  45.495  1
226989  100.896  -76.919  45.482  1
226990  100.906  -76.947  45.470  1
226991  100.917  -76.975  45.457  1
226992  100.928  -77.003  45.443  1
226993  100.941  -77.031  45.429  1
226994  100.970  -77.051  45.417  1
226995  100.999  -77.071  45.405  1
226996  101.029  -77.091  45.393  1
226997  101.057  -77.111  45.381  1
226998  101.087  -77.131  45.370  1
226999  101.116  -77.151  45.360  1
227000  101.145  -77.171  45.348  1
227001  101.174  -77.191  45.336  1
227002  101.203  -77.211  45.324  1
227003  101.232  -77.232  45.309  1
227004  101.247  -77.256  45.295  1
227005  101.259  -77.282  45.280  1
227006  101.271  -77.307  45.263  1
227007  101.283  -77.332  45.247  1
227008  101.295  -77.358  45.231  1
227009  101.308  -77.378  45.213  1
227010  101.323  -77.390  45.196  1
227011  101.340  -77.399  45.178  1
227012  101.360  -77.403  45.160  1
227013  101.379  -77.410  45.141  1
227014  101.398  -77.417  45.123  1
227015  101.414  -77.420  45.104  1
227016  101.429  -77.421  45.085  1
227017  101.445  -77.423  45.066  1
227018  101.460  -77.425  45.046  1
227019  101.476  -77.426  45.027  1
227020  101.491  -77.428  45.008  1
227021  101.506  -77.429  44.990  1
227022  101.522  -77.431  44.972  1
227023  101.538  -77.432  44.954  1
227024  101.553  -77.434  44.937  1
227025  101.568  -77.436  44.920  1
227026  101.584  -77.438  44.904  1
227027  101.599  -77.439  44.888  1
227028  101.615  -77.441  44.872  1
227029  101.607  -77.488  44.857  1
227030  101.627  -77.508  44.840  1
227031  101.647  -77.527  44.823  1
227032  101.667  -77.547  44.805  1
227033  101.687  -77.567  44.788  1
227034  101.722  -77.580  44.771  1
227035  101.758  -77.591  44.755  1
227036  101.794  -77.603  44.740  1
227037  101.830  -77.614  44.724  1
227038  101.867  -77.627  44.708  1
227039  101.903  -77.638  44.692  1
227040  101.928  -77.655  44.675  1
227041  101.952  -77.671  44.661  1
227042  101.995  -77.677  44.644  1
227043  102.039  -77.683  44.628  1
227044  102.076  -77.692  44.612  1
227045  102.109  -77.703  44.597  1
227046  102.141  -77.715  44.581  1
227047  102.174  -77.727  44.565  1
227048  102.206  -77.739  44.550  1
227049  102.239  -77.750  44.536  1
227050  102.268  -77.761  44.521  1
227051  102.295  -77.770  44.506  1
227052  102.318  -77.784  44.491  1
227053  102.341  -77.799  44.477  1
227054  102.364  -77.815  44.462  1
227055  102.383  -77.830  44.448  1
227056  102.402  -77.846  44.432  1
227057  102.420  -77.862  44.417  1
227058  102.448  -77.866  44.402  1
227059  102.476  -77.868  44.387  1
227060  102.505  -77.870  44.370  1
227061  102.532  -77.871  44.354  1
227062  102.556  -77.873  44.339  1
227063  102.581  -77.875  44.323  1
227064  102.605  -77.877  44.308  1
227065  102.623  -77.884  44.292  1
227066  102.641  -77.890  44.275  1
227067  102.658  -77.896  44.258  1
227068  102.676  -77.903  44.243  1
227069  102.704  -77.909  44.227  1
227070  102.734  -77.916  44.211  1
227071  102.770  -77.921  44.196  1
227072  102.807  -77.927  44.179  1
227073  102.843  -77.932  44.163  1
227074  102.881  -77.937  44.147  1
227075  102.917  -77.943  44.130  1
227076  102.955  -77.947  44.113  1
227077  102.992  -77.953  44.096  1
227078  103.028  -77.958  44.080  1
227079  103.066  -77.963  44.064  1
227080  103.102  -77.968  44.048  1
227081  103.140  -77.974  44.031  1
227082  103.176  -77.978  44.014  1
227083  103.213  -77.984  43.998  1
227084  103.250  -77.989  43.982  1
227327  92.139  -75.100  54.262  1
227328  92.161  -75.111  54.268  1
227329  92.184  -75.122  54.274  1
227330  92.208  -75.133  54.283  1
227331  92.231  -75.145  54.294  1
227332  92.254  -75.155  54.306  1
227333  92.277  -75.167  54.316  1
227334  92.300  -75.177  54.326  1
227335  92.323  -75.189  54.335  1
227336  92.346  -75.200  54.344  1
227337  92.369  -75.210  54.353  1
227338  92.392  -75.222  54.361  1
227339  92.411  -75.220  54.368  1
227340  92.436  -75.217  54.372  1
227341  92.467  -75.213  54.370  1
227342  92.498  -75.208  54.365  1
227343  92.529  -75.204  54.359  1
227344  92.560  -75.200  54.355  1
227345  92.590  -75.196  54.347  1
227346  92.622  -75.192  54.338  1
227347  92.652  -75.188  54.327  1
227348  92.683  -75.183  54.315  1
227349  92.714  -75.179  54.302  1
227350  92.745  -75.176  54.288  1
227351  92.776  -75.171  54.276  1
227352  92.806  -75.167  54.263  1
227353  92.837  -75.163  54.252  1
227354  92.866  -75.160  54.242  1
227355  92.888  -75.159  54.230  1
227356  92.912  -75.158  54.217  1
227357  92.935  -75.157  54.203  1
227358  92.958  -75.156  54.191  1
227359  92.982  -75.154  54.177  1
227360  93.005  -75.153  54.164  1
227361  93.028  -75.152  54.150  1
227362  93.052  -75.151  54.136  1
227363  93.075  -75.149  54.121  1
227364  93.098  -75.148  54.106  1
227365  93.122  -75.147  54.092  1
227366  93.145  -75.145  54.077  1
227367  93.168  -75.145  54.064  1
227370  93.238  -75.141  54.030  1
227371  93.262  -75.139  54.020  1
227372  93.285  -75.138  54.012  1
227373  93.308  -75.137  54.007  1
227374  93.331  -75.135  54.005  1
227375  93.355  -75.135  54.008  1
227376  93.378  -75.133  54.013  1
227377  93.401  -75.132  54.020  1
227378  93.425  -75.131  54.029  1
227379  93.448  -75.129  54.046  1
227380  93.471  -75.128  54.067  1
227381  93.495  -75.127  54.091  1
227382  93.518  -75.126  54.121  1
227383  93.554  -75.124  54.161  1
227384  93.585  -75.123  54.203  1
227385  93.616  -75.121  54.247  1
227386  93.648  -75.120  54.294  1
227387  93.679  -75.118  54.337  1
227388  93.711  -75.117  54.375  1
227389  93.743  -75.116  54.409  1
227390  93.775  -75.114  54.435  1
227391  93.807  -75.113  54.451  1
227392  93.833  -75.110  54.460  1
227393  93.858  -75.107  54.466  1
227394  93.885  -75.105  54.470  1
227395  93.910  -75.103  54.472  1
227396  93.936  -75.100  54.472  1
227397  93.962  -75.097  54.468  1
227398  93.988  -75.094  54.461  1
227399  94.014  -75.091  54.461  1
227400  94.040  -75.088  54.466  1
227401  94.066  -75.085  54.475  1
227402  94.088  -75.076  54.483  1
227403  94.114  -75.076  54.488  1
227404  94.138  -75.076  54.488  1
227405  94.162  -75.074  54.482  1
227406  94.186  -75.072  54.476  1
227407  94.209  -75.069  54.473  1
227408  94.234  -75.066  54.473  1
227409  94.259  -75.062  54.476  1
227410  94.284  -75.057  54.478  1
227411  94.306  -75.057  54.472  1
227412  94.330  -75.051  54.461  1
227413  94.356  -75.045  54.445  1
227414  94.382  -75.043  54.425  1
227415  94.407  -75.043  54.405  1
227416  94.433  -75.042  54.385  1
227417  94.459  -75.042  54.365  1
227418  94.484  -75.042  54.340  1
227419  94.506  -75.042  54.312  1
227420  94.521  -75.044  54.281  1
227421  94.535  -75.045  54.248  1
227422  94.549  -75.047  54.217  1
227423  94.563  -75.048  54.186  1
227424  94.577  -75.050  54.155  1
227425  94.591  -75.052  54.120  1
227426  94.603  -75.059  54.084  1
227427  94.613  -75.068  54.045  1
227428  94.623  -75.077  54.004  1
227429  94.636  -75.086  53.963  1
227430  94.657  -75.092  53.922  1
227431  94.678  -75.098  53.879  1
227432  94.699  -75.102  53.831  1
227433  94.718  -75.101  53.785  1
227434  94.742  -75.103  53.741  1
227435  94.767  -75.106  53.696  1
227436  94.785  -75.109  53.652  1
227437  94.778  -75.115  53.608  1
227438  94.772  -75.120  53.563  1
227439  94.765  -75.126  53.518  1
227440  94.764  -75.130  53.473  1
227441  94.782  -75.133  53.426  1
227442  94.800  -75.136  53.379  1
227443  94.818  -75.138  53.332  1
227444  94.835  -75.142  53.285  1
227445  94.853  -75.145  53.235  1
227446  94.871  -75.147  53.185  1
227447  94.889  -75.150  53.136  1
227448  94.905  -75.155  53.086  1
227449  94.920  -75.160  53.035  1
227450  94.936  -75.166  52.984  1
227451  94.935  -75.160  52.932  1
227452  94.964  -75.165  52.878  1
227453  94.992  -75.170  52.819  1
227454  95.018  -75.172  52.759  1
227455  95.043  -75.174  52.701  1
227456  95.068  -75.177  52.643  1
227457  95.093  -75.179  52.587  1
227458  95.118  -75.182  52.531  1
227459  95.143  -75.185  52.475  1
227460  95.169  -75.187  52.424  1
227461  95.194  -75.189  52.373  1
227462  95.218  -75.193  52.322  1
227463  95.242  -75.202  52.273  1
227464  95.266  -75.213  52.225  1
227465  95.290  -75.223  52.180  1
227466  95.314  -75.234  52.137  1
227467  95.338  -75.245  52.094  1
227468  95.362  -75.255  52.054  1
227469  95.387  -75.266  52.014  1
227470  95.411  -75.276  51.974  1
227471  95.435  -75.287  51.937  1
227472  95.459  -75.298  51.902  1
227473  95.483  -75.308  51.868  1
227474  95.508  -75.319  51.834  1
227475  95.532  -75.330  51.801  1
227476  95.557  -75.336  51.770  1
227477  95.586  -75.329  51.738  1
227478  95.614  -75.322  51.707  1
227479  95.642  -75.315  51.678  1
227480  95.671  -75.308  51.650  1
227481  95.700  -75.301  51.621  1
227482  95.728  -75.294  51.593  1
227483  95.757  -75.287  51.565  1
227484  95.785  -75.280  51.536  1
227485  95.819  -75.279  51.507  1
227486  95.860  -75.285  51.478  1
227487  95.897  -75.293  51.449  1
227488  95.933  -75.301  51.419  1
227489  95.970  -75.310  51.389  1
227490  96.011  -75.319  51.360  1
227491  96.051  -75.328  51.330  1
227492  96.092  -75.336  51.302  1
227493  96.134  -75.344  51.275  1
227494  96.176  -75.352  51.248  1
227495  96.215  -75.357  51.223  1
227496  96.253  -75.360  51.197  1
227497  96.292  -75.362  51.171  1
227498  96.331  -75.364  51.144  1
227499  96.362  -75.364  51.120  1
227500  96.387  -75.372  51.095  1
227501  96.407  -75.384  51.069  1
227502  96.427  -75.396  51.043  1
227503  96.447  -75.409  51.019  1
227504  96.467  -75.422  50.995  1
227505  96.486  -75.434  50.972  1
227506  96.507  -75.447  50.950  1
227507  96.526  -75.459  50.928  1
227508  96.546  -75.467  50.905  1
227509  96.565  -75.470  50.881  1
227510  96.584  -75.477  50.856  1
227511  96.602  -75.485  50.830  1
227512  96.621  -75.492  50.805  1
227513  96.642  -75.496  50.781  1
227514  96.663  -75.501  50.757  1
227515  96.681  -75.510  50.733  1
227516  96.691  -75.529  50.709  1
227517  96.701  -75.547  50.685  1
227518  96.711  -75.566  50.661  1
227519  96.721  -75.584  50.637  1
227520  96.731  -75.603  50.613  1
227521  96.741  -75.622  50.587  1
227522  96.751  -75.640  50.559  1
227523  96.760  -75.659  50.529  1
227524  96.770  -75.677  50.499  1
227525  96.784  -75.699  50.469  1
227526  96.805  -75.714  50.440  1
227527  96.853  -75.721  50.408  1
227528  96.917  -75.725  50.376  1
227529  96.981  -75.730  50.344  1
227530  97.046  -75.734  50.313  1
227531  97.095  -75.739  50.281  1
227532  97.119  -75.745  50.247  1
227533  97.143  -75.750  50.213  1
227534  97.165  -75.757  50.180  1
227535  97.186  -75.765  50.147  1
227536  97.208  -75.771  50.114  1
227537  97.229  -75.778  50.082  1
227538  97.251  -75.785  50.049  1
227539  97.273  -75.792  50.016  1
227540  97.294  -75.799  49.982  1
227541  97.315  -75.806  49.948  1
227542  97.336  -75.813  49.914  1
227543  97.358  -75.820  49.879  1
227544  97.380  -75.828  49.844  1
227545  97.405  -75.844  49.809  1
227546  97.430  -75.858  49.774  1
227547  97.455  -75.873  49.739  1
227548  97.479  -75.887  49.705  1
227549  97.514  -75.894  49.673  1
227550  97.557  -75.892  49.645  1
227551  97.599  -75.891  49.617  1
227552  97.640  -75.890  49.591  1
227553  97.671  -75.887  49.566  1
227554  97.703  -75.884  49.540  1
227555  97.734  -75.882  49.512  1
227556  97.745  -75.893  49.482  1
227557  97.756  -75.904  49.452  1
227558  97.764  -75.909  49.421  1
227559  97.767  -75.906  49.388  1
227560  97.770  -75.903  49.350  1
227561  97.755  -75.899  49.311  1
227562  97.766  -75.919  49.270  1
227563  97.784  -75.944  49.229  1
227564  97.802  -75.969  49.187  1
227565  97.819  -75.994  49.145  1
227566  97.838  -76.019  49.103  1
227567  97.856  -76.042  49.061  1
227568  97.884  -76.054  49.020  1
227569  97.912  -76.066  48.977  1
227570  97.953  -76.079  48.935  1
227571  97.999  -76.092  48.894  1
227572  98.052  -76.120  48.852  1
227573  98.106  -76.154  48.810  1
227574  98.154  -76.176  48.767  1
227575  98.200  -76.194  48.725  1
227576  98.246  -76.213  48.683  1
227577  98.292  -76.231  48.642  1
227578  98.335  -76.248  48.602  1
227579  98.375  -76.264  48.560  1
227580  98.387  -76.282  48.519  1
227581  98.398  -76.300  48.479  1
227582  98.410  -76.317  48.440  1
227583  98.422  -76.336  48.402  1
227584  98.423  -76.357  48.365  1
227585  98.431  -76.367  48.331  1
227586  98.453  -76.369  48.298  1
227587  98.475  -76.371  48.265  1
227588  98.502  -76.371  48.233  1
227589  98.529  -76.371  48.203  1
227590  98.557  -76.371  48.172  1
227591  98.584  -76.372  48.141  1
227592  98.611  -76.372  48.113  1
227593  98.638  -76.372  48.085  1
227594  98.665  -76.372  48.058  1
227595  98.693  -76.372  48.031  1
227596  98.720  -76.373  48.008  1
227597  98.747  -76.373  47.984  1
227598  98.775  -76.373  47.961  1
227599  98.801  -76.375  47.939  1
227600  98.827  -76.377  47.917  1
227601  98.853  -76.379  47.895  1
227602  98.879  -76.382  47.874  1
227603  98.905  -76.384  47.853  1
227604  98.931  -76.386  47.833  1
227605  98.957  -76.389  47.813  1
227606  98.983  -76.392  47.790  1
227607  99.009  -76.394  47.767  1
227608  99.035  -76.397  47.744  1
227609  99.059  -76.408  47.719  1
227610  99.083  -76.419  47.693  1
227611  99.108  -76.430  47.667  1
227612  99.121  -76.431  47.639  1
227613  99.129  -76.428  47.610  1
227614  99.137  -76.426  47.581  1
227615  99.145  -76.423  47.548  1
227616  99.157  -76.420  47.516  1
227617  99.178  -76.418  47.484  1
227618  99.198  -76.417  47.452  1
227619  99.218  -76.415  47.420  1
227620  99.238  -76.414  47.388  1
227621  99.268  -76.414  47.356  1
227622  99.298  -76.420  47.322  1
227623  99.327  -76.433  47.287  1
227624  99.356  -76.445  47.253  1
227625  99.385  -76.458  47.218  1
227626  99.415  -76.470  47.182  1
227627  99.444  -76.482  47.146  1
227628  99.474  -76.494  47.111  1
227629  99.505  -76.508  47.076  1
227630  99.536  -76.520  47.040  1
227631  99.567  -76.533  47.005  1
227632  99.598  -76.547  46.970  1
227633  99.634  -76.559  46.934  1
227634  99.669  -76.572  46.900  1
227635  99.704  -76.585  46.866  1
227636  99.739  -76.598  46.833  1
227637  99.775  -76.611  46.800  1
227638  99.809  -76.623  46.768  1
227639  99.845  -76.636  46.736  1
227640  99.869  -76.643  46.706  1
227641  99.880  -76.645  46.678  1
227642  99.895  -76.646  46.649  1
227643  99.911  -76.646  46.621  1
227644  99.927  -76.647  46.592  1
227645  99.943  -76.647  46.562  1
227646  99.960  -76.648  46.533  1
227647  99.976  -76.649  46.504  1
227648  99.992  -76.649  46.474  1
227649  100.008  -76.649  46.443  1
227650  100.025  -76.650  46.411  1
227651  100.041  -76.651  46.379  1
227652  100.057  -76.651  46.347  1
227653  100.073  -76.652  46.313  1
227654  100.089  -76.652  46.280  1
227655  100.106  -76.652  46.248  1
227656  100.122  -76.653  46.215  1
227657  100.138  -76.654  46.183  1
227658  100.156  -76.646  46.151  1
227659  100.174  -76.642  46.120  1
227660  100.191  -76.637  46.088  1
227661  100.208  -76.632  46.058  1
227662  100.226  -76.627  46.029  1
227663  100.243  -76.623  46.000  1
227664  100.261  -76.618  45.971  1
227665  100.278  -76.613  45.943  1
227666  100.295  -76.608  45.916  1
227667  100.313  -76.604  45.891  1
227668  100.330  -76.599  45.868  1
227669  100.347  -76.594  45.845  1
227670  100.364  -76.589  45.823  1
227671  100.382  -76.586  45.802  1
227672  100.404  -76.608  45.782  1
227673  100.425  -76.630  45.763  1
227674  100.446  -76.652  45.744  1
227675  100.468  -76.674  45.725  1
227676  100.489  -76.696  45.706  1
227677  100.510  -76.718  45.689  1
227678  100.533  -76.743  45.671  1
227679  100.560  -76.777  45.654  1
227680  100.586  -76.812  45.638  1
227681  100.613  -76.847  45.620  1
227682  100.638  -76.877  45.602  1
227683  100.661  -76.895  45.584  1
227684  100.689  -76.905  45.566  1
227685  100.730  -76.896  45.549  1
227686  100.772  -76.886  45.533  1
227687  100.796  -76.896  45.517  1
227688  100.817  -76.911  45.502  1
227689  100.838  -76.925  45.488  1
227690  100.837  -76.950  45.474  1
227691  100.864  -76.971  45.462  1
227692  100.893  -76.990  45.449  1
227693  100.922  -77.010  45.435  1
227694  100.952  -77.031  45.422  1
227695  100.980  -77.050  45.409  1
227696  101.009  -77.071  45.396  1
227697  101.039  -77.091  45.385  1
227698  101.068  -77.111  45.373  1
227699  101.097  -77.131  45.362  1
227700  101.126  -77.151  45.351  1
227701  101.155  -77.171  45.340  1
227702  101.184  -77.191  45.327  1
227703  101.213  -77.211  45.315  1
227704  101.243  -77.231  45.300  1
227705  101.257  -77.256  45.286  1
227706  101.268  -77.282  45.271  1
227707  101.280  -77.307  45.253  1
227708  101.293  -77.331  45.237  1
227709  101.308  -77.343  45.220  1
227710  101.322  -77.355  45.202  1
227711  101.337  -77.368  45.186  1
227712  101.356  -77.374  45.168  1
227713  101.378  -77.376  45.150  1
227714  101.396  -77.383  45.131  1
227715  101.414  -77.389  45.112  1
227716  101.433  -77.396  45.093  1
227717  101.452  -77.403  45.075  1
227718  101.469  -77.407  45.056  1
227719  101.484  -77.409  45.037  1
227720  101.500  -77.410  45.018  1
227721  101.515  -77.412  44.999  1
227722  101.531  -77.414  44.981  1
227723  101.546  -77.415  44.963  1
227724  101.561  -77.417  44.945  1
227725  101.577  -77.419  44.928  1
227726  101.592  -77.420  44.912  1
227727  101.608  -77.422  44.895  1
227728  101.623  -77.423  44.879  1
227729  101.638  -77.425  44.863  1
227730  101.634  -77.464  44.848  1
227731  101.654  -77.484  44.832  1
227732  101.674  -77.504  44.815  1
227733  101.694  -77.523  44.798  1
227734  101.714  -77.543  44.780  1
227735  101.734  -77.563  44.763  1
227736  101.761  -77.579  44.747  1
227737  101.798  -77.591  44.731  1
227738  101.834  -77.603  44.715  1
227739  101.870  -77.614  44.699  1
227740  101.906  -77.627  44.683  1
227741  101.930  -77.643  44.667  1
227742  101.964  -77.655  44.652  1
227743  102.007  -77.660  44.636  1
227744  102.051  -77.666  44.620  1
227745  102.089  -77.674  44.604  1
227746  102.121  -77.686  44.588  1
227747  102.154  -77.698  44.573  1
227748  102.186  -77.710  44.558  1
227749  102.219  -77.721  44.543  1
227750  102.251  -77.733  44.529  1
227751  102.284  -77.745  44.514  1
227752  102.307  -77.760  44.499  1
227753  102.326  -77.776  44.483  1
227754  102.345  -77.792  44.468  1
227755  102.364  -77.808  44.454  1
227756  102.383  -77.824  44.439  1
227757  102.402  -77.840  44.424  1
227758  102.429  -77.844  44.409  1
227759  102.458  -77.846  44.393  1
227760  102.486  -77.847  44.377  1
227761  102.515  -77.849  44.361  1
227762  102.544  -77.851  44.345  1
227763  102.573  -77.852  44.329  1
227764  102.599  -77.855  44.314  1
227765  102.616  -77.862  44.298  1
227766  102.634  -77.868  44.282  1
227767  102.652  -77.874  44.265  1
227768  102.670  -77.881  44.248  1
227769  102.691  -77.887  44.232  1
227770  102.720  -77.894  44.216  1
227771  102.754  -77.899  44.200  1
227772  102.791  -77.905  44.184  1
227773  102.828  -77.910  44.167  1
227774  102.865  -77.915  44.152  1
227775  102.902  -77.920  44.136  1
227776  102.939  -77.925  44.119  1
227777  102.976  -77.931  44.101  1
227778  103.013  -77.936  44.084  1
227779  103.050  -77.941  44.068  1
227780  103.087  -77.946  44.052  1
227781  103.124  -77.951  44.036  1
227782  103.161  -77.956  44.020  1
227783  103.198  -77.962  44.003  1
227784  103.235  -77.967  43.987  1
228028  92.126  -75.071  54.266  1
228029  92.149  -75.082  54.273  1
228030  92.172  -75.093  54.278  1
228031  92.195  -75.104  54.286  1
228032  92.218  -75.115  54.297  1
228033  92.241  -75.126  54.309  1
228034  92.264  -75.137  54.319  1
228035  92.287  -75.148  54.330  1
228036  92.310  -75.160  54.341  1
228037  92.334  -75.170  54.349  1
228038  92.357  -75.182  54.360  1
228039  92.379  -75.193  54.370  1
228040  92.400  -75.197  54.379  1
228041  92.429  -75.193  54.384  1
228042  92.460  -75.189  54.384  1
228043  92.491  -75.185  54.380  1
228044  92.522  -75.180  54.374  1
228045  92.553  -75.176  54.370  1
228046  92.583  -75.172  54.363  1
228047  92.614  -75.168  54.353  1
228048  92.645  -75.163  54.343  1
228049  92.676  -75.160  54.329  1
228050  92.708  -75.156  54.315  1
228051  92.739  -75.151  54.302  1
228052  92.771  -75.148  54.290  1
228053  92.802  -75.142  54.278  1
228054  92.834  -75.136  54.267  1
228055  92.863  -75.136  54.257  1
228056  92.888  -75.128  54.246  1
228057  92.912  -75.126  54.233  1
228058  92.935  -75.126  54.220  1
228059  92.958  -75.124  54.206  1
228060  92.982  -75.123  54.193  1
228061  93.005  -75.122  54.180  1
228062  93.028  -75.120  54.166  1
228063  93.051  -75.120  54.152  1
228064  93.074  -75.118  54.137  1
228065  93.098  -75.117  54.123  1
228066  93.121  -75.116  54.108  1
228067  93.144  -75.115  54.093  1
228068  93.167  -75.113  54.079  1
228071  93.237  -75.110  54.046  1
228072  93.261  -75.109  54.036  1
228073  93.284  -75.107  54.029  1
228074  93.307  -75.107  54.023  1
228075  93.331  -75.105  54.021  1
228076  93.354  -75.104  54.023  1
228077  93.377  -75.103  54.028  1
228078  93.401  -75.102  54.035  1
228079  93.424  -75.101  54.045  1
228080  93.447  -75.099  54.060  1
228081  93.470  -75.098  54.080  1
228082  93.494  -75.097  54.105  1
228083  93.517  -75.096  54.135  1
228084  93.548  -75.095  54.174  1
228085  93.580  -75.093  54.215  1
228086  93.612  -75.091  54.258  1
228087  93.644  -75.090  54.303  1
228088  93.677  -75.088  54.344  1
228089  93.709  -75.088  54.382  1
228090  93.741  -75.086  54.417  1
228091  93.773  -75.085  54.448  1
228092  93.805  -75.083  54.464  1
228093  93.831  -75.081  54.473  1
228094  93.856  -75.078  54.478  1
228095  93.882  -75.076  54.481  1
228096  93.908  -75.073  54.482  1
228097  93.933  -75.071  54.480  1
228098  93.959  -75.069  54.477  1
228099  93.985  -75.066  54.471  1
228100  94.010  -75.064  54.473  1
228101  94.037  -75.061  54.481  1
228102  94.062  -75.058  54.491  1
228103  94.088  -75.056  54.501  1
228104  94.113  -75.050  54.508  1
228105  94.137  -75.050  54.510  1
228106  94.161  -75.048  54.502  1
228107  94.186  -75.044  54.492  1
228108  94.211  -75.039  54.484  1
228109  94.237  -75.035  54.479  1
228110  94.262  -75.031  54.477  1
228111  94.287  -75.027  54.477  1
228112  94.305  -75.029  54.471  1
228113  94.330  -75.023  54.460  1
228114  94.355  -75.017  54.446  1
228115  94.381  -75.011  54.426  1
228116  94.407  -75.006  54.408  1
228117  94.432  -75.006  54.390  1
228118  94.458  -75.006  54.372  1
228119  94.484  -75.005  54.348  1
228120  94.506  -75.006  54.321  1
228121  94.520  -75.007  54.292  1
228122  94.534  -75.009  54.262  1
228123  94.548  -75.010  54.232  1
228124  94.562  -75.012  54.202  1
228125  94.574  -75.018  54.172  1
228126  94.584  -75.027  54.136  1
228127  94.595  -75.036  54.098  1
228128  94.605  -75.046  54.057  1
228129  94.616  -75.055  54.015  1
228130  94.634  -75.062  53.973  1
228131  94.655  -75.068  53.932  1
228132  94.677  -75.075  53.889  1
228133  94.698  -75.081  53.843  1
228134  94.718  -75.080  53.797  1
228135  94.738  -75.079  53.752  1
228136  94.761  -75.081  53.708  1
228137  94.785  -75.084  53.664  1
228138  94.788  -75.088  53.618  1
228139  94.782  -75.094  53.573  1
228140  94.775  -75.099  53.527  1
228141  94.782  -75.103  53.483  1
228142  94.800  -75.106  53.437  1
228143  94.818  -75.109  53.392  1
228144  94.836  -75.111  53.346  1
228145  94.853  -75.114  53.299  1
228146  94.872  -75.117  53.251  1
228147  94.888  -75.122  53.203  1
228148  94.903  -75.127  53.156  1
228149  94.919  -75.133  53.106  1
228150  94.934  -75.138  53.056  1
228151  94.946  -75.141  53.004  1
228152  94.939  -75.131  52.951  1
228153  94.970  -75.137  52.894  1
228154  95.002  -75.144  52.834  1
228155  95.027  -75.146  52.773  1
228156  95.052  -75.148  52.713  1
228157  95.077  -75.151  52.653  1
228158  95.103  -75.154  52.595  1
228159  95.128  -75.156  52.537  1
228160  95.154  -75.159  52.481  1
228161  95.179  -75.161  52.428  1
228162  95.204  -75.163  52.376  1
228163  95.230  -75.170  52.325  1
228164  95.249  -75.174  52.274  1
228165  95.266  -75.177  52.226  1
228166  95.290  -75.188  52.181  1
228167  95.315  -75.198  52.137  1
228168  95.339  -75.209  52.095  1
228169  95.364  -75.220  52.053  1
228170  95.388  -75.230  52.013  1
228171  95.412  -75.241  51.974  1
228172  95.436  -75.251  51.936  1
228173  95.460  -75.262  51.900  1
228174  95.484  -75.273  51.865  1
228175  95.509  -75.283  51.832  1
228176  95.533  -75.294  51.799  1
228177  95.558  -75.298  51.768  1
228178  95.587  -75.292  51.737  1
228179  95.615  -75.285  51.706  1
228180  95.644  -75.278  51.676  1
228181  95.673  -75.271  51.647  1
228182  95.701  -75.264  51.619  1
228183  95.730  -75.258  51.591  1
228184  95.758  -75.251  51.563  1
228185  95.794  -75.251  51.534  1
228186  95.835  -75.257  51.506  1
228187  95.876  -75.262  51.479  1
228188  95.911  -75.270  51.450  1
228189  95.947  -75.279  51.421  1
228190  95.982  -75.287  51.392  1
228191  96.019  -75.296  51.363  1
228192  96.059  -75.305  51.334  1
228193  96.100  -75.314  51.306  1
228194  96.140  -75.323  51.280  1
228195  96.180  -75.332  51.254  1
228196  96.220  -75.337  51.228  1
228197  96.260  -75.338  51.202  1
228198  96.300  -75.339  51.177  1
228199  96.333  -75.340  51.150  1
228200  96.364  -75.341  51.126  1
228201  96.394  -75.343  51.101  1
228202  96.414  -75.356  51.076  1
228203  96.434  -75.368  51.051  1
228204  96.454  -75.381  51.027  1
228205  96.474  -75.393  51.003  1
228206  96.494  -75.406  50.980  1
228207  96.514  -75.418  50.958  1
228208  96.534  -75.431  50.936  1
228209  96.553  -75.443  50.912  1
228210  96.573  -75.448  50.888  1
228211  96.592  -75.454  50.862  1
228212  96.610  -75.461  50.836  1
228213  96.630  -75.467  50.811  1
228214  96.652  -75.471  50.787  1
228215  96.673  -75.476  50.763  1
228216  96.691  -75.484  50.738  1
228217  96.701  -75.503  50.714  1
228218  96.711  -75.521  50.691  1
228219  96.721  -75.540  50.667  1
228220  96.731  -75.559  50.644  1
228221  96.741  -75.577  50.619  1
228222  96.751  -75.596  50.593  1
228223  96.760  -75.615  50.565  1
228224  96.772  -75.634  50.536  1
228225  96.786  -75.656  50.506  1
228226  96.802  -75.674  50.475  1
228227  96.826  -75.687  50.446  1
228228  96.862  -75.697  50.415  1
228229  96.927  -75.701  50.384  1
228230  96.992  -75.706  50.353  1
228231  97.056  -75.709  50.322  1
228232  97.105  -75.715  50.290  1
228233  97.129  -75.720  50.258  1
228234  97.153  -75.726  50.225  1
228235  97.177  -75.732  50.193  1
228236  97.202  -75.738  50.160  1
228237  97.225  -75.744  50.127  1
228238  97.246  -75.751  50.095  1
228239  97.267  -75.759  50.062  1
228240  97.289  -75.765  50.028  1
228241  97.310  -75.772  49.995  1
228242  97.332  -75.779  49.961  1
228243  97.353  -75.786  49.927  1
228244  97.375  -75.793  49.893  1
228245  97.398  -75.805  49.857  1
228246  97.423  -75.819  49.822  1
228247  97.448  -75.834  49.787  1
228248  97.472  -75.849  49.752  1
228249  97.497  -75.864  49.717  1
228250  97.528  -75.873  49.683  1
228251  97.571  -75.872  49.654  1
228252  97.613  -75.870  49.625  1
228253  97.644  -75.868  49.598  1
228254  97.675  -75.865  49.572  1
228255  97.706  -75.862  49.544  1
228256  97.737  -75.860  49.516  1
228257  97.756  -75.866  49.485  1
228258  97.767  -75.877  49.454  1
228259  97.771  -75.875  49.422  1
228260  97.775  -75.873  49.387  1
228261  97.778  -75.870  49.349  1
228262  97.781  -75.867  49.309  1
228263  97.793  -75.883  49.268  1
228264  97.810  -75.908  49.225  1
228265  97.828  -75.933  49.182  1
228266  97.846  -75.957  49.141  1
228267  97.864  -75.982  49.099  1
228268  97.882  -76.007  49.057  1
228269  97.901  -76.030  49.017  1
228270  97.929  -76.043  48.974  1
228271  97.970  -76.055  48.932  1
228272  98.021  -76.079  48.890  1
228273  98.072  -76.107  48.847  1
228274  98.118  -76.126  48.805  1
228275  98.164  -76.144  48.762  1
228276  98.210  -76.163  48.719  1
228277  98.256  -76.181  48.678  1
228278  98.302  -76.200  48.638  1
228279  98.343  -76.216  48.597  1
228280  98.383  -76.232  48.555  1
228281  98.403  -76.249  48.514  1
228282  98.414  -76.267  48.473  1
228283  98.426  -76.285  48.434  1
228284  98.438  -76.303  48.395  1
228285  98.449  -76.321  48.358  1
228286  98.461  -76.339  48.323  1
228287  98.463  -76.358  48.289  1
228288  98.485  -76.361  48.256  1
228289  98.510  -76.361  48.223  1
228290  98.537  -76.361  48.192  1
228291  98.565  -76.361  48.162  1
228292  98.592  -76.362  48.132  1
228293  98.619  -76.362  48.102  1
228294  98.649  -76.361  48.073  1
228295  98.681  -76.358  48.045  1
228296  98.713  -76.355  48.019  1
228297  98.744  -76.353  47.996  1
228298  98.772  -76.351  47.974  1
228299  98.798  -76.351  47.952  1
228300  98.824  -76.353  47.930  1
228301  98.850  -76.355  47.908  1
228302  98.876  -76.357  47.887  1
228303  98.902  -76.360  47.866  1
228304  98.928  -76.362  47.845  1
228305  98.954  -76.364  47.826  1
228306  98.980  -76.367  47.806  1
228307  99.006  -76.369  47.784  1
228308  99.032  -76.372  47.761  1
228309  99.057  -76.379  47.737  1
228310  99.081  -76.390  47.712  1
228311  99.106  -76.401  47.687  1
228312  99.130  -76.412  47.660  1
228313  99.148  -76.417  47.631  1
228314  99.156  -76.415  47.602  1
228315  99.164  -76.412  47.573  1
228316  99.172  -76.409  47.541  1
228317  99.181  -76.406  47.509  1
228318  99.189  -76.404  47.477  1
228319  99.208  -76.401  47.445  1
228320  99.229  -76.400  47.413  1
228321  99.249  -76.398  47.382  1
228322  99.279  -76.398  47.350  1
228323  99.309  -76.398  47.316  1
228324  99.339  -76.411  47.282  1
228325  99.368  -76.423  47.248  1
228326  99.397  -76.435  47.214  1
228327  99.427  -76.447  47.180  1
228328  99.456  -76.459  47.144  1
228329  99.487  -76.473  47.110  1
228330  99.518  -76.486  47.075  1
228331  99.549  -76.499  47.040  1
228332  99.579  -76.512  47.006  1
228333  99.612  -76.525  46.971  1
228334  99.647  -76.538  46.936  1
228335  99.683  -76.551  46.902  1
228336  99.718  -76.564  46.869  1
228337  99.753  -76.576  46.837  1
228338  99.788  -76.589  46.804  1
228339  99.824  -76.602  46.772  1
228340  99.859  -76.614  46.741  1
228341  99.894  -76.627  46.712  1
228342  99.917  -76.634  46.684  1
228343  99.931  -76.635  46.655  1
228344  99.947  -76.636  46.625  1
228345  99.963  -76.636  46.596  1
228346  99.980  -76.636  46.566  1
228347  99.996  -76.637  46.537  1
228348  100.012  -76.637  46.507  1
228349  100.028  -76.638  46.477  1
228350  100.045  -76.639  46.446  1
228351  100.061  -76.639  46.413  1
228352  100.074  -76.642  46.381  1
228353  100.088  -76.645  46.347  1
228354  100.102  -76.648  46.313  1
228355  100.115  -76.651  46.280  1
228356  100.129  -76.654  46.247  1
228357  100.142  -76.657  46.215  1
228358  100.157  -76.657  46.182  1
228359  100.176  -76.651  46.149  1
228360  100.196  -76.658  46.118  1
228361  100.215  -76.666  46.086  1
228362  100.233  -76.668  46.056  1
228363  100.251  -76.664  46.026  1
228364  100.268  -76.658  45.997  1
228365  100.286  -76.654  45.969  1
228366  100.303  -76.649  45.941  1
228367  100.321  -76.644  45.915  1
228368  100.338  -76.640  45.890  1
228369  100.355  -76.635  45.866  1
228370  100.372  -76.630  45.843  1
228371  100.390  -76.625  45.820  1
228372  100.407  -76.621  45.799  1
228373  100.427  -76.633  45.779  1
228374  100.449  -76.654  45.759  1
228375  100.470  -76.676  45.740  1
228376  100.491  -76.698  45.721  1
228377  100.512  -76.720  45.703  1
228378  100.534  -76.742  45.685  1
228379  100.555  -76.764  45.667  1
228380  100.576  -76.786  45.649  1
228381  100.598  -76.808  45.632  1
228382  100.619  -76.830  45.615  1
228383  100.641  -76.852  45.597  1
228384  100.668  -76.870  45.578  1
228385  100.691  -76.884  45.560  1
228386  100.719  -76.894  45.543  1
228387  100.747  -76.905  45.526  1
228388  100.775  -76.915  45.510  1
228389  100.804  -76.926  45.495  1
228390  100.831  -76.937  45.480  1
228391  100.849  -76.949  45.466  1
228392  100.878  -76.971  45.453  1
228393  100.907  -76.994  45.440  1
228394  100.935  -77.016  45.427  1
228395  100.964  -77.035  45.413  1
228396  100.991  -77.050  45.400  1
228397  101.020  -77.071  45.388  1
228398  101.049  -77.091  45.376  1
228399  101.078  -77.110  45.365  1
228400  101.107  -77.131  45.354  1
228401  101.136  -77.150  45.344  1
228402  101.165  -77.171  45.332  1
228403  101.195  -77.191  45.319  1
228404  101.224  -77.211  45.306  1
228405  101.253  -77.231  45.291  1
228406  101.266  -77.257  45.276  1
228407  101.277  -77.282  45.261  1
228408  101.292  -77.296  45.244  1
228409  101.307  -77.308  45.227  1
228410  101.322  -77.321  45.211  1
228411  101.337  -77.333  45.194  1
228412  101.351  -77.346  45.177  1
228413  101.373  -77.348  45.159  1
228414  101.395  -77.350  45.140  1
228415  101.413  -77.357  45.122  1
228416  101.431  -77.363  45.103  1
228417  101.450  -77.370  45.084  1
228418  101.469  -77.376  45.066  1
228419  101.487  -77.382  45.048  1
228420  101.506  -77.389  45.029  1
228421  101.524  -77.395  45.010  1
228422  101.539  -77.396  44.991  1
228423  101.555  -77.398  44.972  1
228424  101.570  -77.399  44.953  1
228425  101.586  -77.401  44.936  1
228426  101.601  -77.403  44.919  1
228427  101.616  -77.404  44.903  1
228428  101.632  -77.406  44.886  1
228429  101.647  -77.407  44.870  1
228430  101.663  -77.409  44.854  1
228431  101.662  -77.441  44.838  1
228432  101.681  -77.461  44.823  1
228433  101.701  -77.480  44.807  1
228434  101.722  -77.500  44.790  1
228435  101.741  -77.520  44.772  1
228436  101.761  -77.539  44.757  1
228437  101.781  -77.559  44.740  1
228438  101.801  -77.579  44.723  1
228439  101.837  -77.591  44.707  1
228440  101.874  -77.602  44.692  1
228441  101.910  -77.614  44.676  1
228442  101.933  -77.632  44.659  1
228443  101.976  -77.638  44.643  1
228444  102.020  -77.643  44.628  1
228445  102.077  -77.652  44.612  1
228446  102.097  -77.661  44.596  1
228447  102.129  -77.672  44.580  1
228448  102.162  -77.683  44.564  1
228449  102.194  -77.696  44.549  1
228450  102.227  -77.707  44.535  1
228451  102.259  -77.719  44.521  1
228452  102.292  -77.730  44.506  1
228453  102.313  -77.748  44.491  1
228454  102.328  -77.768  44.476  1
228455  102.345  -77.786  44.461  1
228456  102.365  -77.802  44.446  1
228457  102.383  -77.818  44.431  1
228458  102.410  -77.822  44.415  1
228459  102.439  -77.824  44.400  1
228460  102.468  -77.825  44.384  1
228461  102.496  -77.827  44.367  1
228462  102.522  -77.831  44.352  1
228463  102.548  -77.835  44.336  1
228464  102.575  -77.839  44.320  1
228465  102.601  -77.843  44.304  1
228466  102.627  -77.846  44.288  1
228467  102.646  -77.852  44.271  1
228468  102.664  -77.859  44.255  1
228469  102.681  -77.865  44.239  1
228470  102.705  -77.871  44.222  1
228471  102.739  -77.877  44.206  1
228472  102.776  -77.883  44.190  1
228473  102.813  -77.888  44.173  1
228474  102.850  -77.893  44.156  1
228475  102.887  -77.898  44.140  1
228476  102.924  -77.903  44.124  1
228477  102.961  -77.909  44.107  1
228478  102.998  -77.914  44.090  1
228479  103.035  -77.919  44.074  1
228480  103.072  -77.924  44.058  1
228481  103.109  -77.929  44.042  1
228482  103.146  -77.934  44.026  1
228483  103.182  -77.940  44.009  1
228484  103.220  -77.945  43.993  1
228729  92.113  -75.041  54.271  1
228730  92.136  -75.053  54.277  1
228731  92.159  -75.064  54.282  1
228732  92.182  -75.075  54.290  1
228733  92.206  -75.086  54.301  1
228734  92.229  -75.097  54.311  1
228735  92.251  -75.108  54.322  1
228736  92.275  -75.120  54.334  1
228737  92.298  -75.130  54.345  1
228738  92.321  -75.142  54.354  1
228739  92.344  -75.153  54.366  1
228740  92.367  -75.163  54.378  1
228741  92.391  -75.173  54.389  1
228742  92.423  -75.169  54.396  1
228743  92.454  -75.165  54.398  1
228744  92.486  -75.161  54.395  1
228745  92.517  -75.157  54.391  1
228746  92.549  -75.153  54.388  1
228747  92.580  -75.149  54.382  1
228748  92.611  -75.145  54.373  1
228749  92.643  -75.141  54.364  1
228750  92.674  -75.137  54.348  1
228751  92.706  -75.132  54.332  1
228752  92.738  -75.124  54.317  1
228753  92.770  -75.116  54.304  1
228754  92.802  -75.113  54.292  1
228755  92.831  -75.123  54.281  1
228756  92.859  -75.123  54.272  1
228757  92.888  -75.095  54.263  1
228758  92.912  -75.094  54.251  1
228759  92.935  -75.093  54.238  1
228760  92.958  -75.091  54.224  1
228761  92.982  -75.091  54.209  1
228762  93.005  -75.089  54.196  1
228763  93.028  -75.088  54.182  1
228764  93.052  -75.087  54.169  1
228765  93.075  -75.085  54.153  1
228766  93.098  -75.085  54.140  1
228767  93.122  -75.083  54.125  1
228768  93.145  -75.082  54.110  1
228769  93.168  -75.081  54.096  1
228770  93.191  -75.080  54.083  1
228771  93.215  -75.079  54.072  1
228772  93.238  -75.078  54.063  1
228773  93.261  -75.076  54.053  1
228774  93.284  -75.075  54.046  1
228775  93.308  -75.074  54.041  1
228776  93.331  -75.073  54.038  1
228777  93.354  -75.072  54.040  1
228778  93.377  -75.070  54.044  1
228779  93.401  -75.069  54.052  1
228780  93.425  -75.069  54.061  1
228781  93.450  -75.071  54.076  1
228782  93.477  -75.073  54.095  1
228783  93.499  -75.066  54.119  1
228784  93.522  -75.059  54.149  1
228785  93.551  -75.060  54.187  1
228786  93.579  -75.063  54.227  1
228787  93.610  -75.062  54.268  1
228788  93.642  -75.060  54.310  1
228789  93.675  -75.060  54.350  1
228790  93.707  -75.058  54.387  1
228791  93.739  -75.057  54.422  1
228792  93.771  -75.055  54.452  1
228793  93.802  -75.054  54.471  1
228794  93.828  -75.051  54.482  1
228795  93.854  -75.048  54.488  1
228796  93.880  -75.046  54.489  1
228797  93.905  -75.044  54.489  1
228798  93.931  -75.041  54.487  1
228799  93.957  -75.039  54.484  1
228800  93.982  -75.037  54.480  1
228801  94.008  -75.035  54.485  1
228802  94.034  -75.032  54.494  1
228803  94.060  -75.029  54.505  1
228804  94.085  -75.027  54.515  1
228805  94.111  -75.025  54.522  1
228806  94.138  -75.021  54.523  1
228807  94.164  -75.017  54.518  1
228808  94.189  -75.013  54.507  1
228809  94.214  -75.009  54.495  1
228810  94.240  -75.004  54.484  1
228811  94.265  -75.001  54.476  1
228812  94.288  -74.998  54.473  1
228813  94.305  -75.001  54.465  1
228814  94.330  -74.995  54.452  1
228815  94.355  -74.989  54.438  1
228816  94.381  -74.983  54.422  1
228817  94.406  -74.977  54.407  1
228818  94.432  -74.971  54.392  1
228819  94.458  -74.969  54.375  1
228820  94.483  -74.969  54.353  1
228821  94.505  -74.969  54.329  1
228822  94.519  -74.971  54.302  1
228823  94.533  -74.972  54.274  1
228824  94.545  -74.977  54.246  1
228825  94.556  -74.986  54.218  1
228826  94.566  -74.996  54.188  1
228827  94.577  -75.005  54.151  1
228828  94.588  -75.014  54.110  1
228829  94.598  -75.023  54.068  1
228830  94.612  -75.032  54.025  1
228831  94.633  -75.038  53.984  1
228832  94.654  -75.044  53.944  1
228833  94.676  -75.051  53.903  1
228834  94.697  -75.057  53.860  1
228835  94.717  -75.060  53.814  1
228836  94.737  -75.058  53.769  1
228837  94.757  -75.057  53.725  1
228838  94.779  -75.058  53.680  1
228839  94.799  -75.062  53.634  1
228840  94.792  -75.067  53.588  1
228841  94.785  -75.073  53.543  1
228842  94.801  -75.076  53.498  1
228843  94.819  -75.079  53.454  1
228844  94.836  -75.082  53.409  1
228845  94.854  -75.085  53.364  1
228846  94.871  -75.088  53.317  1
228847  94.886  -75.095  53.270  1
228848  94.901  -75.100  53.223  1
228849  94.917  -75.105  53.177  1
228850  94.932  -75.111  53.128  1
228851  94.948  -75.116  53.077  1
228852  94.950  -75.113  53.024  1
228853  94.944  -75.102  52.969  1
228854  94.976  -75.109  52.911  1
228855  95.007  -75.116  52.850  1
228856  95.037  -75.120  52.788  1
228857  95.062  -75.123  52.725  1
228858  95.088  -75.126  52.665  1
228859  95.113  -75.128  52.605  1
228860  95.138  -75.131  52.546  1
228861  95.163  -75.133  52.490  1
228862  95.188  -75.135  52.435  1
228863  95.213  -75.138  52.382  1
228864  95.241  -75.147  52.330  1
228865  95.265  -75.156  52.279  1
228866  95.280  -75.155  52.229  1
228867  95.294  -75.155  52.183  1
228868  95.316  -75.163  52.139  1
228869  95.340  -75.173  52.096  1
228870  95.364  -75.184  52.055  1
228871  95.388  -75.195  52.014  1
228872  95.412  -75.205  51.974  1
228873  95.437  -75.216  51.936  1
228874  95.461  -75.226  51.899  1
228875  95.485  -75.237  51.864  1
228876  95.509  -75.248  51.830  1
228877  95.533  -75.258  51.797  1
228878  95.559  -75.262  51.766  1
228879  95.588  -75.255  51.735  1
228880  95.617  -75.248  51.704  1
228881  95.645  -75.241  51.675  1
228882  95.674  -75.234  51.646  1
228883  95.702  -75.227  51.619  1
228884  95.731  -75.220  51.592  1
228885  95.768  -75.223  51.564  1
228886  95.809  -75.228  51.536  1
228887  95.850  -75.234  51.508  1
228888  95.890  -75.240  51.480  1
228889  95.925  -75.248  51.452  1
228890  95.961  -75.257  51.424  1
228891  95.997  -75.265  51.395  1
228892  96.033  -75.273  51.367  1
228893  96.068  -75.282  51.338  1
228894  96.108  -75.291  51.312  1
228895  96.149  -75.300  51.286  1
228896  96.189  -75.309  51.260  1
228897  96.229  -75.314  51.234  1
228898  96.269  -75.315  51.209  1
228899  96.304  -75.316  51.184  1
228900  96.335  -75.317  51.159  1
228901  96.366  -75.318  51.134  1
228902  96.397  -75.319  51.109  1
228903  96.421  -75.328  51.084  1
228904  96.441  -75.340  51.059  1
228905  96.461  -75.353  51.035  1
228906  96.481  -75.365  51.011  1
228907  96.502  -75.377  50.988  1
228908  96.522  -75.390  50.966  1
228909  96.541  -75.402  50.943  1
228910  96.561  -75.415  50.919  1
228911  96.581  -75.426  50.895  1
228912  96.600  -75.430  50.869  1
228913  96.619  -75.438  50.843  1
228914  96.640  -75.442  50.818  1
228915  96.661  -75.446  50.794  1
228916  96.682  -75.451  50.770  1
228917  96.701  -75.459  50.746  1
228918  96.711  -75.477  50.722  1
228919  96.721  -75.496  50.698  1
228920  96.731  -75.514  50.674  1
228921  96.741  -75.533  50.651  1
228922  96.751  -75.552  50.627  1
228923  96.760  -75.571  50.601  1
228924  96.774  -75.591  50.573  1
228925  96.788  -75.612  50.543  1
228926  96.801  -75.633  50.512  1
228927  96.823  -75.647  50.482  1
228928  96.848  -75.660  50.453  1
228929  96.872  -75.672  50.424  1
228930  96.937  -75.677  50.393  1
228931  97.001  -75.681  50.363  1
228932  97.066  -75.685  50.332  1
228933  97.115  -75.690  50.301  1
228934  97.139  -75.696  50.270  1
228935  97.163  -75.702  50.237  1
228936  97.187  -75.708  50.205  1
228937  97.212  -75.713  50.173  1
228938  97.236  -75.719  50.141  1
228939  97.260  -75.725  50.108  1
228940  97.284  -75.731  50.074  1
228941  97.305  -75.738  50.041  1
228942  97.327  -75.745  50.008  1
228943  97.348  -75.752  49.974  1
228944  97.370  -75.759  49.940  1
228945  97.391  -75.766  49.904  1
228946  97.416  -75.781  49.868  1
228947  97.441  -75.796  49.832  1
228948  97.465  -75.810  49.797  1
228949  97.490  -75.825  49.763  1
228950  97.515  -75.840  49.728  1
228951  97.543  -75.852  49.695  1
228952  97.585  -75.850  49.663  1
228953  97.616  -75.848  49.634  1
228954  97.648  -75.846  49.606  1
228955  97.679  -75.844  49.577  1
228956  97.710  -75.840  49.548  1
228957  97.741  -75.838  49.518  1
228958  97.767  -75.839  49.486  1
228959  97.776  -75.846  49.454  1
228960  97.779  -75.843  49.420  1
228961  97.782  -75.840  49.385  1
228962  97.793  -75.844  49.346  1
228963  97.803  -75.849  49.305  1
228964  97.816  -75.862  49.263  1
228965  97.835  -75.883  49.220  1
228966  97.853  -75.905  49.178  1
228967  97.872  -75.927  49.137  1
228968  97.890  -75.948  49.096  1
228969  97.908  -75.971  49.055  1
228970  97.926  -75.996  49.014  1
228971  97.946  -76.019  48.972  1
228972  97.990  -76.039  48.929  1
228973  98.036  -76.057  48.887  1
228974  98.082  -76.076  48.844  1
228975  98.128  -76.094  48.801  1
228976  98.174  -76.113  48.757  1
228977  98.220  -76.132  48.714  1
228978  98.266  -76.150  48.673  1
228979  98.311  -76.169  48.632  1
228980  98.352  -76.185  48.590  1
228981  98.392  -76.200  48.549  1
228982  98.418  -76.217  48.507  1
228983  98.430  -76.235  48.466  1
228984  98.442  -76.253  48.427  1
228985  98.453  -76.270  48.389  1
228986  98.465  -76.289  48.351  1
228987  98.477  -76.307  48.316  1
228988  98.489  -76.324  48.281  1
228989  98.500  -76.342  48.246  1
228990  98.519  -76.351  48.214  1
228991  98.551  -76.348  48.183  1
228992  98.583  -76.346  48.152  1
228993  98.615  -76.344  48.121  1
228994  98.647  -76.341  48.091  1
228995  98.678  -76.339  48.062  1
228996  98.710  -76.336  48.033  1
228997  98.742  -76.333  48.007  1
228998  98.770  -76.332  47.984  1
228999  98.795  -76.331  47.962  1
229000  98.821  -76.330  47.941  1
229001  98.847  -76.331  47.920  1
229002  98.873  -76.333  47.899  1
229003  98.899  -76.336  47.878  1
229004  98.925  -76.338  47.857  1
229005  98.951  -76.340  47.837  1
229006  98.977  -76.342  47.818  1
229007  99.003  -76.345  47.798  1
229008  99.029  -76.347  47.777  1
229009  99.055  -76.351  47.754  1
229010  99.079  -76.361  47.730  1
229011  99.103  -76.373  47.705  1
229012  99.128  -76.383  47.680  1
229013  99.152  -76.394  47.652  1
229014  99.175  -76.404  47.623  1
229015  99.183  -76.401  47.594  1
229016  99.191  -76.398  47.564  1
229017  99.200  -76.395  47.533  1
229018  99.208  -76.393  47.501  1
229019  99.216  -76.390  47.470  1
229020  99.224  -76.387  47.438  1
229021  99.239  -76.385  47.407  1
229022  99.261  -76.383  47.376  1
229023  99.290  -76.383  47.344  1
229024  99.321  -76.383  47.311  1
229025  99.350  -76.389  47.277  1
229026  99.379  -76.401  47.244  1
229027  99.409  -76.413  47.210  1
229028  99.438  -76.425  47.176  1
229029  99.469  -76.438  47.142  1
229030  99.500  -76.451  47.108  1
229031  99.531  -76.464  47.074  1
229032  99.561  -76.477  47.039  1
229033  99.592  -76.491  47.006  1
229034  99.626  -76.504  46.972  1
229035  99.661  -76.517  46.938  1
229036  99.696  -76.529  46.905  1
229037  99.731  -76.542  46.872  1
229038  99.767  -76.555  46.840  1
229039  99.802  -76.567  46.807  1
229040  99.837  -76.580  46.775  1
229041  99.872  -76.592  46.746  1
229042  99.908  -76.605  46.716  1
229043  99.942  -76.618  46.688  1
229044  99.967  -76.624  46.659  1
229045  99.981  -76.627  46.630  1
229046  99.994  -76.630  46.600  1
229047  100.008  -76.633  46.570  1
229048  100.021  -76.636  46.540  1
229049  100.035  -76.639  46.509  1
229050  100.049  -76.642  46.478  1
229051  100.062  -76.645  46.447  1
229052  100.076  -76.648  46.413  1
229053  100.089  -76.650  46.379  1
229054  100.103  -76.653  46.345  1
229055  100.117  -76.656  46.311  1
229056  100.130  -76.659  46.278  1
229057  100.143  -76.662  46.245  1
229058  100.157  -76.665  46.212  1
229059  100.174  -76.658  46.179  1
229060  100.194  -76.646  46.147  1
229061  100.213  -76.650  46.115  1
229062  100.232  -76.658  46.084  1
229063  100.252  -76.665  46.053  1
229064  100.272  -76.674  46.024  1
229065  100.291  -76.681  45.995  1
229066  100.311  -76.690  45.966  1
229067  100.328  -76.685  45.939  1
229068  100.345  -76.680  45.913  1
229069  100.363  -76.676  45.887  1
229070  100.380  -76.671  45.863  1
229071  100.398  -76.666  45.840  1
229072  100.415  -76.661  45.818  1
229073  100.432  -76.656  45.796  1
229074  100.451  -76.657  45.775  1
229075  100.472  -76.679  45.755  1
229076  100.493  -76.701  45.736  1
229077  100.514  -76.723  45.718  1
229078  100.536  -76.745  45.699  1
229079  100.557  -76.767  45.681  1
229080  100.578  -76.789  45.662  1
229081  100.600  -76.811  45.644  1
229082  100.621  -76.832  45.627  1
229083  100.645  -76.843  45.609  1
229084  100.669  -76.852  45.591  1
229085  100.694  -76.861  45.572  1
229086  100.722  -76.871  45.554  1
229087  100.750  -76.882  45.537  1
229088  100.778  -76.893  45.520  1
229089  100.806  -76.903  45.503  1
229090  100.834  -76.914  45.487  1
229091  100.862  -76.925  45.472  1
229092  100.876  -76.937  45.458  1
229093  100.891  -76.948  45.444  1
229094  100.917  -76.969  45.430  1
229095  100.946  -76.990  45.417  1
229096  100.974  -77.013  45.404  1
229097  101.003  -77.035  45.391  1
229098  101.032  -77.058  45.378  1
229099  101.061  -77.080  45.367  1
229100  101.090  -77.103  45.356  1
229101  101.119  -77.125  45.345  1
229102  101.148  -77.147  45.333  1
229103  101.177  -77.170  45.321  1
229104  101.205  -77.191  45.308  1
229105  101.234  -77.211  45.295  1
229106  101.263  -77.231  45.281  1
229107  101.277  -77.248  45.266  1
229108  101.291  -77.261  45.251  1
229109  101.307  -77.273  45.235  1
229110  101.321  -77.286  45.218  1
229111  101.336  -77.298  45.201  1
229112  101.351  -77.311  45.184  1
229113  101.366  -77.323  45.168  1
229114  101.389  -77.323  45.149  1
229115  101.411  -77.323  45.131  1
229116  101.430  -77.329  45.113  1
229117  101.449  -77.336  45.095  1
229118  101.467  -77.342  45.076  1
229119  101.486  -77.349  45.058  1
229120  101.504  -77.356  45.039  1
229121  101.523  -77.362  45.021  1
229122  101.541  -77.369  45.001  1
229123  101.560  -77.376  44.982  1
229124  101.579  -77.382  44.963  1
229125  101.594  -77.384  44.944  1
229126  101.610  -77.385  44.927  1
229127  101.625  -77.387  44.910  1
229128  101.640  -77.389  44.893  1
229129  101.656  -77.390  44.877  1
229130  101.671  -77.392  44.861  1
229131  101.687  -77.393  44.846  1
229132  101.689  -77.417  44.830  1
229133  101.708  -77.437  44.815  1
229134  101.729  -77.457  44.799  1
229135  101.749  -77.476  44.782  1
229136  101.768  -77.496  44.764  1
229137  101.788  -77.516  44.748  1
229138  101.809  -77.536  44.732  1
229139  101.829  -77.555  44.715  1
229140  101.848  -77.575  44.699  1
229141  101.877  -77.591  44.683  1
229142  101.913  -77.602  44.667  1
229143  101.945  -77.615  44.651  1
229144  101.992  -77.621  44.636  1
229145  102.049  -77.630  44.620  1
229146  102.089  -77.639  44.604  1
229147  102.109  -77.647  44.588  1
229148  102.137  -77.658  44.572  1
229149  102.169  -77.669  44.556  1
229150  102.202  -77.681  44.541  1
229151  102.234  -77.692  44.527  1
229152  102.267  -77.705  44.513  1
229153  102.299  -77.716  44.498  1
229154  102.320  -77.733  44.483  1
229155  102.335  -77.755  44.469  1
229156  102.349  -77.775  44.453  1
229157  102.365  -77.795  44.438  1
229158  102.390  -77.801  44.423  1
229159  102.416  -77.805  44.406  1
229160  102.443  -77.808  44.391  1
229161  102.469  -77.812  44.375  1
229162  102.495  -77.815  44.359  1
229163  102.522  -77.819  44.342  1
229164  102.548  -77.823  44.326  1
229165  102.574  -77.827  44.311  1
229166  102.600  -77.830  44.295  1
229167  102.626  -77.834  44.278  1
229168  102.653  -77.838  44.262  1
229169  102.675  -77.843  44.245  1
229170  102.693  -77.849  44.229  1
229171  102.724  -77.855  44.212  1
229172  102.760  -77.861  44.196  1
229173  102.798  -77.866  44.179  1
229174  102.834  -77.871  44.162  1
229175  102.872  -77.876  44.146  1
229176  102.908  -77.881  44.130  1
229177  102.945  -77.887  44.114  1
229178  102.982  -77.892  44.097  1
229179  103.019  -77.897  44.080  1
229180  103.056  -77.902  44.064  1
229181  103.093  -77.907  44.048  1
229182  103.130  -77.912  44.031  1
229183  103.167  -77.918  44.015  1
229184  103.204  -77.923  43.999  1
229185  103.241  -77.928  43.982  1
229430  92.101  -75.013  54.276  1
229431  92.125  -75.023  54.281  1
229432  92.149  -75.034  54.286  1
229433  92.173  -75.045  54.293  1
229434  92.198  -75.056  54.303  1
229435  92.222  -75.066  54.314  1
229436  92.246  -75.077  54.325  1
229437  92.271  -75.088  54.336  1
229438  92.295  -75.099  54.348  1
229439  92.320  -75.110  54.358  1
229440  92.344  -75.120  54.371  1
229441  92.368  -75.131  54.384  1
229442  92.393  -75.142  54.397  1
229443  92.419  -75.136  54.407  1
229444  92.451  -75.133  54.411  1
229445  92.482  -75.130  54.410  1
229446  92.514  -75.127  54.408  1
229447  92.545  -75.124  54.407  1
229448  92.577  -75.121  54.402  1
229449  92.608  -75.118  54.395  1
229450  92.641  -75.114  54.386  1
229451  92.673  -75.107  54.369  1
229452  92.706  -75.099  54.351  1
229453  92.738  -75.091  54.334  1
229454  92.769  -75.091  54.320  1
229455  92.798  -75.099  54.308  1
229456  92.827  -75.108  54.297  1
229457  92.856  -75.109  54.287  1
229458  92.886  -75.076  54.278  1
229459  92.912  -75.062  54.266  1
229460  92.936  -75.060  54.253  1
229461  92.959  -75.059  54.240  1
229462  92.982  -75.058  54.226  1
229463  93.005  -75.057  54.213  1
229464  93.029  -75.056  54.199  1
229465  93.052  -75.054  54.185  1
229466  93.075  -75.054  54.171  1
229467  93.098  -75.052  54.157  1
229468  93.122  -75.051  54.142  1
229469  93.145  -75.050  54.128  1
229470  93.168  -75.048  54.115  1
229471  93.192  -75.048  54.102  1
229472  93.215  -75.046  54.090  1
229473  93.238  -75.045  54.081  1
229474  93.262  -75.044  54.072  1
229475  93.285  -75.043  54.064  1
229476  93.308  -75.041  54.058  1
229477  93.332  -75.041  54.056  1
229478  93.358  -75.043  54.058  1
229479  93.383  -75.045  54.063  1
229480  93.410  -75.048  54.069  1
229481  93.435  -75.049  54.078  1
229482  93.459  -75.043  54.092  1
229483  93.482  -75.036  54.110  1
229484  93.504  -75.029  54.133  1
229485  93.528  -75.022  54.164  1
229486  93.555  -75.023  54.200  1
229487  93.584  -75.026  54.239  1
229488  93.613  -75.028  54.278  1
229489  93.642  -75.030  54.317  1
229490  93.673  -75.030  54.356  1
229491  93.705  -75.029  54.393  1
229492  93.737  -75.027  54.428  1
229493  93.769  -75.026  54.457  1
229494  93.800  -75.023  54.476  1
229495  93.826  -75.021  54.489  1
229496  93.851  -75.019  54.495  1
229497  93.877  -75.016  54.495  1
229498  93.903  -75.014  54.494  1
229499  93.928  -75.012  54.493  1
229500  93.954  -75.010  54.492  1
229501  93.980  -75.007  54.491  1
229502  94.006  -75.005  54.496  1
229503  94.032  -75.004  54.505  1
229504  94.058  -75.002  54.516  1
229505  94.084  -75.001  54.525  1
229506  94.110  -74.998  54.531  1
229507  94.139  -74.992  54.533  1
229508  94.167  -74.986  54.527  1
229509  94.192  -74.982  54.515  1
229510  94.217  -74.978  54.502  1
229511  94.243  -74.974  54.489  1
229512  94.268  -74.969  54.476  1
229513  94.287  -74.971  54.467  1
229514  94.304  -74.972  54.455  1
229515  94.330  -74.967  54.442  1
229516  94.355  -74.961  54.428  1
229517  94.381  -74.955  54.413  1
229518  94.406  -74.949  54.400  1
229519  94.431  -74.943  54.388  1
229520  94.457  -74.937  54.374  1
229521  94.482  -74.932  54.355  1
229522  94.504  -74.932  54.333  1
229523  94.517  -74.936  54.310  1
229524  94.528  -74.945  54.284  1
229525  94.538  -74.955  54.258  1
229526  94.548  -74.964  54.231  1
229527  94.559  -74.973  54.202  1
229528  94.569  -74.983  54.163  1
229529  94.579  -74.992  54.122  1
229530  94.590  -75.001  54.080  1
229531  94.611  -75.008  54.038  1
229532  94.632  -75.014  53.997  1
229533  94.653  -75.020  53.959  1
229534  94.674  -75.026  53.921  1
229535  94.695  -75.032  53.882  1
229536  94.716  -75.038  53.839  1
229537  94.736  -75.038  53.794  1
229538  94.756  -75.036  53.748  1
229539  94.776  -75.035  53.703  1
229540  94.799  -75.036  53.657  1
229541  94.802  -75.041  53.611  1
229542  94.801  -75.046  53.565  1
229543  94.819  -75.048  53.519  1
229544  94.837  -75.051  53.476  1
229545  94.853  -75.056  53.431  1
229546  94.869  -75.061  53.385  1
229547  94.884  -75.066  53.337  1
229548  94.900  -75.073  53.290  1
229549  94.915  -75.078  53.244  1
229550  94.931  -75.083  53.198  1
229551  94.946  -75.089  53.152  1
229552  94.961  -75.094  53.099  1
229553  94.955  -75.084  53.044  1
229554  94.949  -75.074  52.987  1
229555  94.981  -75.081  52.927  1
229556  95.013  -75.087  52.865  1
229557  95.045  -75.094  52.803  1
229558  95.072  -75.098  52.738  1
229559  95.097  -75.100  52.677  1
229560  95.122  -75.102  52.616  1
229561  95.148  -75.105  52.556  1
229562  95.173  -75.107  52.499  1
229563  95.198  -75.110  52.443  1
229564  95.224  -75.113  52.389  1
229565  95.251  -75.123  52.336  1
229566  95.278  -75.135  52.285  1
229567  95.296  -75.137  52.233  1
229568  95.311  -75.137  52.186  1
229569  95.325  -75.136  52.141  1
229570  95.341  -75.138  52.098  1
229571  95.365  -75.148  52.057  1
229572  95.389  -75.159  52.016  1
229573  95.413  -75.170  51.975  1
229574  95.438  -75.180  51.936  1
229575  95.462  -75.191  51.899  1
229576  95.486  -75.201  51.863  1
229577  95.510  -75.212  51.829  1
229578  95.534  -75.223  51.795  1
229579  95.561  -75.225  51.764  1
229580  95.589  -75.218  51.733  1
229581  95.618  -75.211  51.703  1
229582  95.647  -75.204  51.674  1
229583  95.675  -75.197  51.646  1
229584  95.703  -75.190  51.618  1
229585  95.743  -75.194  51.591  1
229586  95.783  -75.200  51.565  1
229587  95.824  -75.206  51.537  1
229588  95.865  -75.211  51.510  1
229589  95.904  -75.218  51.482  1
229590  95.940  -75.226  51.454  1
229591  95.976  -75.235  51.426  1
229592  96.012  -75.243  51.398  1
229593  96.047  -75.251  51.371  1
229594  96.083  -75.260  51.343  1
229595  96.118  -75.268  51.317  1
229596  96.157  -75.277  51.293  1
229597  96.197  -75.286  51.267  1
229598  96.237  -75.291  51.242  1
229599  96.274  -75.292  51.217  1
229600  96.306  -75.293  51.192  1
229601  96.337  -75.294  51.168  1
229602  96.369  -75.295  51.143  1
229603  96.400  -75.295  51.118  1
229604  96.428  -75.300  51.093  1
229605  96.448  -75.312  51.068  1
229606  96.468  -75.324  51.043  1
229607  96.488  -75.337  51.018  1
229608  96.509  -75.349  50.995  1
229609  96.529  -75.362  50.973  1
229610  96.549  -75.374  50.950  1
229611  96.569  -75.386  50.926  1
229612  96.589  -75.399  50.902  1
229613  96.608  -75.408  50.876  1
229614  96.628  -75.413  50.851  1
229615  96.650  -75.417  50.826  1
229616  96.671  -75.421  50.802  1
229617  96.692  -75.426  50.779  1
229618  96.711  -75.433  50.755  1
229619  96.721  -75.452  50.731  1
229620  96.731  -75.471  50.707  1
229621  96.741  -75.489  50.684  1
229622  96.751  -75.508  50.660  1
229623  96.762  -75.527  50.635  1
229624  96.776  -75.549  50.609  1
229625  96.789  -75.569  50.580  1
229626  96.803  -75.590  50.550  1
229627  96.820  -75.608  50.520  1
229628  96.844  -75.620  50.491  1
229629  96.869  -75.633  50.462  1
229630  96.892  -75.646  50.433  1
229631  96.947  -75.652  50.403  1
229632  97.011  -75.656  50.373  1
229633  97.076  -75.661  50.342  1
229634  97.124  -75.665  50.312  1
229635  97.149  -75.671  50.282  1
229636  97.173  -75.677  50.250  1
229637  97.197  -75.683  50.218  1
229638  97.222  -75.689  50.186  1
229639  97.246  -75.695  50.154  1
229640  97.271  -75.701  50.120  1
229641  97.295  -75.706  50.087  1
229642  97.319  -75.712  50.053  1
229643  97.343  -75.718  50.020  1
229644  97.365  -75.725  49.986  1
229645  97.386  -75.732  49.951  1
229646  97.409  -75.743  49.915  1
229647  97.434  -75.757  49.879  1
229648  97.459  -75.772  49.843  1
229649  97.484  -75.787  49.808  1
229650  97.508  -75.802  49.773  1
229651  97.533  -75.816  49.739  1
229652  97.558  -75.831  49.706  1
229653  97.589  -75.829  49.673  1
229654  97.620  -75.826  49.643  1
229655  97.651  -75.824  49.614  1
229656  97.682  -75.822  49.583  1
229657  97.714  -75.818  49.552  1
229658  97.745  -75.816  49.520  1
229659  97.776  -75.814  49.487  1
229660  97.786  -75.816  49.453  1
229661  97.797  -75.820  49.418  1
229662  97.808  -75.825  49.382  1
229663  97.819  -75.829  49.342  1
229664  97.829  -75.837  49.301  1
229665  97.840  -75.844  49.259  1
229666  97.858  -75.865  49.216  1
229667  97.877  -75.887  49.174  1
229668  97.895  -75.909  49.133  1
229669  97.914  -75.931  49.093  1
229670  97.932  -75.953  49.051  1
229671  97.950  -75.974  49.010  1
229672  97.968  -75.991  48.968  1
229673  98.000  -76.008  48.925  1
229674  98.045  -76.026  48.883  1
229675  98.092  -76.044  48.840  1
229676  98.138  -76.063  48.796  1
229677  98.183  -76.082  48.752  1
229678  98.229  -76.100  48.709  1
229679  98.275  -76.119  48.668  1
229680  98.320  -76.137  48.626  1
229681  98.360  -76.153  48.584  1
229682  98.400  -76.168  48.543  1
229683  98.434  -76.185  48.501  1
229684  98.446  -76.202  48.460  1
229685  98.457  -76.220  48.420  1
229686  98.469  -76.238  48.382  1
229687  98.481  -76.256  48.345  1
229688  98.493  -76.274  48.309  1
229689  98.504  -76.292  48.273  1
229690  98.516  -76.310  48.238  1
229691  98.549  -76.329  48.205  1
229692  98.580  -76.326  48.173  1
229693  98.612  -76.324  48.142  1
229694  98.644  -76.322  48.111  1
229695  98.676  -76.319  48.081  1
229696  98.708  -76.317  48.051  1
229697  98.739  -76.314  48.022  1
229698  98.767  -76.313  47.996  1
229699  98.793  -76.311  47.972  1
229700  98.818  -76.310  47.950  1
229701  98.844  -76.310  47.929  1
229702  98.870  -76.309  47.909  1
229703  98.896  -76.311  47.889  1
229704  98.922  -76.314  47.869  1
229705  98.948  -76.316  47.849  1
229706  98.974  -76.318  47.830  1
229707  99.000  -76.320  47.809  1
229708  99.026  -76.323  47.789  1
229709  99.052  -76.325  47.768  1
229710  99.077  -76.332  47.746  1
229711  99.101  -76.344  47.722  1
229712  99.125  -76.354  47.697  1
229713  99.149  -76.366  47.672  1
229714  99.173  -76.376  47.645  1
229715  99.198  -76.387  47.615  1
229716  99.210  -76.388  47.586  1
229717  99.218  -76.385  47.555  1
229718  99.226  -76.383  47.525  1
229719  99.235  -76.379  47.494  1
229720  99.243  -76.376  47.462  1
229721  99.251  -76.373  47.431  1
229722  99.259  -76.371  47.401  1
229723  99.272  -76.369  47.369  1
229724  99.302  -76.368  47.337  1
229725  99.332  -76.368  47.305  1
229726  99.362  -76.368  47.272  1
229727  99.392  -76.379  47.239  1
229728  99.421  -76.391  47.206  1
229729  99.451  -76.403  47.172  1
229730  99.482  -76.417  47.140  1
229731  99.512  -76.430  47.106  1
229732  99.544  -76.443  47.073  1
229733  99.574  -76.456  47.040  1
229734  99.605  -76.469  47.007  1
229735  99.639  -76.482  46.974  1
229736  99.675  -76.495  46.940  1
229737  99.710  -76.508  46.907  1
229738  99.745  -76.520  46.875  1
229739  99.780  -76.533  46.843  1
229740  99.816  -76.546  46.810  1
229741  99.851  -76.558  46.779  1
229742  99.886  -76.571  46.749  1
229743  99.920  -76.585  46.719  1
229744  99.952  -76.602  46.691  1
229745  99.972  -76.610  46.662  1
229746  99.990  -76.624  46.633  1
229747  100.009  -76.636  46.603  1
229748  100.023  -76.641  46.573  1
229749  100.037  -76.644  46.542  1
229750  100.050  -76.647  46.510  1
229751  100.064  -76.650  46.479  1
229752  100.077  -76.653  46.447  1
229753  100.091  -76.656  46.413  1
229754  100.105  -76.659  46.379  1
229755  100.118  -76.662  46.344  1
229756  100.131  -76.665  46.310  1
229757  100.145  -76.668  46.277  1
229758  100.158  -76.671  46.244  1
229759  100.173  -76.671  46.210  1
229760  100.192  -76.658  46.177  1
229761  100.211  -76.646  46.144  1
229762  100.230  -76.641  46.112  1
229763  100.250  -76.649  46.081  1
229764  100.270  -76.657  46.051  1
229765  100.289  -76.665  46.022  1
229766  100.309  -76.673  45.993  1
229767  100.328  -76.680  45.964  1
229768  100.348  -76.688  45.936  1
229769  100.367  -76.696  45.910  1
229770  100.387  -76.704  45.885  1
229771  100.405  -76.707  45.861  1
229772  100.423  -76.702  45.837  1
229773  100.440  -76.697  45.815  1
229774  100.458  -76.693  45.793  1
229775  100.475  -76.687  45.772  1
229776  100.495  -76.703  45.751  1
229777  100.516  -76.725  45.732  1
229778  100.538  -76.747  45.713  1
229779  100.559  -76.769  45.695  1
229780  100.581  -76.791  45.676  1
229781  100.604  -76.802  45.658  1
229782  100.628  -76.812  45.640  1
229783  100.652  -76.821  45.622  1
229784  100.676  -76.830  45.604  1
229785  100.700  -76.840  45.585  1
229786  100.725  -76.849  45.567  1
229787  100.753  -76.859  45.549  1
229788  100.781  -76.870  45.530  1
229789  100.809  -76.881  45.513  1
229790  100.837  -76.891  45.497  1
229791  100.865  -76.902  45.480  1
229792  100.890  -76.912  45.464  1
229793  100.905  -76.925  45.449  1
229794  100.920  -76.937  45.435  1
229795  100.934  -76.949  45.422  1
229796  100.956  -76.965  45.408  1
229797  100.984  -76.987  45.395  1
229798  101.013  -77.010  45.382  1
229799  101.042  -77.032  45.370  1
229800  101.071  -77.055  45.359  1
229801  101.100  -77.078  45.347  1
229802  101.129  -77.100  45.336  1
229803  101.158  -77.122  45.324  1
229804  101.187  -77.144  45.311  1
229805  101.215  -77.167  45.298  1
229806  101.244  -77.189  45.285  1
229807  101.273  -77.212  45.271  1
229808  101.291  -77.226  45.256  1
229809  101.305  -77.238  45.241  1
229810  101.321  -77.251  45.226  1
229811  101.335  -77.263  45.208  1
229812  101.350  -77.276  45.191  1
229813  101.365  -77.288  45.175  1
229814  101.382  -77.298  45.158  1
229815  101.405  -77.298  45.140  1
229816  101.428  -77.298  45.122  1
229817  101.447  -77.303  45.105  1
229818  101.466  -77.310  45.087  1
229819  101.484  -77.316  45.068  1
229820  101.503  -77.323  45.050  1
229821  101.522  -77.329  45.032  1
229822  101.540  -77.335  45.013  1
229823  101.558  -77.342  44.993  1
229824  101.577  -77.348  44.974  1
229825  101.596  -77.355  44.955  1
229826  101.614  -77.362  44.937  1
229827  101.633  -77.368  44.920  1
229828  101.649  -77.371  44.903  1
229829  101.664  -77.373  44.886  1
229830  101.680  -77.374  44.869  1
229831  101.695  -77.376  44.854  1
229832  101.710  -77.377  44.838  1
229833  101.716  -77.394  44.823  1
229834  101.736  -77.414  44.807  1
229835  101.756  -77.433  44.791  1
229836  101.776  -77.453  44.775  1
229837  101.796  -77.473  44.757  1
229838  101.816  -77.492  44.741  1
229839  101.836  -77.512  44.725  1
229840  101.856  -77.532  44.708  1
229841  101.876  -77.551  44.692  1
229842  101.896  -77.571  44.676  1
229843  101.917  -77.591  44.659  1
229844  101.965  -77.600  44.643  1
229845  102.022  -77.608  44.628  1
229846  102.079  -77.617  44.612  1
229847  102.102  -77.625  44.596  1
229848  102.122  -77.634  44.581  1
229849  102.144  -77.643  44.564  1
229850  102.177  -77.655  44.549  1
229851  102.209  -77.667  44.534  1
229852  102.242  -77.678  44.520  1
229853  102.274  -77.690  44.505  1
229854  102.307  -77.702  44.491  1
229855  102.327  -77.720  44.476  1
229856  102.342  -77.740  44.461  1
229857  102.357  -77.761  44.445  1
229858  102.373  -77.779  44.430  1
229859  102.399  -77.783  44.414  1
229860  102.424  -77.787  44.398  1
229861  102.450  -77.791  44.382  1
229862  102.475  -77.796  44.366  1
229863  102.501  -77.799  44.350  1
229864  102.527  -77.804  44.333  1
229865  102.552  -77.808  44.318  1
229866  102.578  -77.812  44.302  1
229867  102.603  -77.816  44.285  1
229868  102.629  -77.821  44.268  1
229869  102.655  -77.824  44.252  1
229870  102.680  -77.829  44.235  1
229871  102.709  -77.834  44.218  1
229872  102.745  -77.839  44.202  1
229873  102.782  -77.844  44.186  1
229874  102.819  -77.849  44.169  1
229875  102.856  -77.854  44.152  1
229876  102.893  -77.859  44.136  1
229877  102.930  -77.865  44.120  1
229878  102.967  -77.870  44.104  1
229879  103.004  -77.875  44.087  1
229880  103.041  -77.880  44.070  1
229881  103.078  -77.885  44.053  1
229882  103.115  -77.890  44.037  1
229883  103.152  -77.896  44.021  1
229884  103.189  -77.901  44.005  1
229885  103.226  -77.906  43.989  1
230132  92.127  -74.991  54.284  1
230133  92.151  -75.002  54.288  1
230134  92.175  -75.013  54.295  1
230135  92.200  -75.023  54.305  1
230136  92.224  -75.034  54.316  1
230137  92.248  -75.045  54.327  1
230138  92.273  -75.056  54.339  1
230139  92.297  -75.066  54.350  1
230140  92.321  -75.077  54.361  1
230141  92.346  -75.088  54.374  1
230142  92.370  -75.099  54.387  1
230143  92.394  -75.110  54.401  1
230144  92.416  -75.104  54.413  1
230145  92.447  -75.101  54.420  1
230146  92.479  -75.097  54.424  1
230147  92.510  -75.094  54.425  1
230148  92.542  -75.091  54.424  1
230149  92.573  -75.088  54.422  1
230150  92.606  -75.084  54.416  1
230151  92.641  -75.080  54.409  1
230152  92.674  -75.073  54.392  1
230153  92.706  -75.066  54.372  1
230154  92.736  -75.068  54.352  1
230155  92.765  -75.076  54.337  1
230156  92.794  -75.085  54.324  1
230157  92.823  -75.095  54.313  1
230158  92.852  -75.096  54.303  1
230159  92.882  -75.063  54.294  1
230160  92.913  -75.029  54.282  1
230161  92.936  -75.028  54.269  1
230162  92.959  -75.027  54.256  1
230163  92.983  -75.026  54.243  1
230164  93.006  -75.025  54.230  1
230165  93.029  -75.023  54.217  1
230166  93.052  -75.022  54.202  1
230167  93.076  -75.021  54.189  1
230168  93.099  -75.019  54.175  1
230169  93.122  -75.019  54.160  1
230170  93.145  -75.017  54.147  1
230171  93.169  -75.016  54.134  1
230172  93.192  -75.015  54.121  1
230173  93.215  -75.014  54.110  1
230174  93.239  -75.013  54.099  1
230175  93.265  -75.016  54.091  1
230176  93.291  -75.017  54.084  1
230177  93.317  -75.019  54.079  1
230178  93.343  -75.022  54.076  1
230179  93.368  -75.023  54.078  1
230180  93.394  -75.026  54.083  1
230181  93.418  -75.020  54.089  1
230182  93.441  -75.013  54.097  1
230183  93.464  -75.007  54.111  1
230184  93.487  -74.999  54.129  1
230185  93.509  -74.992  54.151  1
230186  93.533  -74.985  54.180  1
230187  93.560  -74.986  54.215  1
230188  93.589  -74.988  54.252  1
230189  93.618  -74.991  54.289  1
230190  93.647  -74.993  54.326  1
230191  93.676  -74.995  54.363  1
230192  93.704  -74.997  54.400  1
230193  93.735  -74.997  54.435  1
230194  93.768  -74.996  54.465  1
230195  93.797  -74.994  54.482  1
230196  93.823  -74.991  54.493  1
230197  93.849  -74.989  54.499  1
230198  93.874  -74.987  54.499  1
230199  93.901  -74.985  54.498  1
230200  93.926  -74.983  54.498  1
230201  93.953  -74.982  54.499  1
230202  93.979  -74.980  54.502  1
230203  94.004  -74.979  54.507  1
230204  94.031  -74.977  54.514  1
230205  94.057  -74.975  54.525  1
230206  94.082  -74.974  54.533  1
230207  94.110  -74.969  54.539  1
230208  94.139  -74.963  54.540  1
230209  94.167  -74.957  54.534  1
230210  94.195  -74.951  54.522  1
230211  94.220  -74.947  54.509  1
230212  94.246  -74.943  54.494  1
230213  94.270  -74.939  54.477  1
230214  94.286  -74.943  54.462  1
230215  94.304  -74.944  54.446  1
230216  94.329  -74.938  54.431  1
230217  94.355  -74.932  54.416  1
230218  94.380  -74.926  54.404  1
230219  94.406  -74.920  54.393  1
230220  94.431  -74.914  54.383  1
230221  94.457  -74.908  54.372  1
230222  94.482  -74.903  54.355  1
230223  94.498  -74.905  54.335  1
230224  94.509  -74.914  54.313  1
230225  94.520  -74.923  54.290  1
230226  94.530  -74.932  54.265  1
230227  94.541  -74.942  54.240  1
230228  94.551  -74.951  54.212  1
230229  94.562  -74.960  54.174  1
230230  94.572  -74.970  54.135  1
230231  94.588  -74.978  54.095  1
230232  94.609  -74.984  54.055  1
230233  94.630  -74.990  54.018  1
230234  94.651  -74.996  53.983  1
230235  94.673  -75.003  53.947  1
230236  94.694  -75.007  53.908  1
230237  94.713  -75.010  53.867  1
230238  94.734  -75.011  53.823  1
230239  94.755  -75.013  53.778  1
230240  94.775  -75.014  53.733  1
230241  94.795  -75.013  53.687  1
230242  94.812  -75.015  53.641  1
230243  94.820  -75.019  53.595  1
230244  94.836  -75.022  53.548  1
230245  94.852  -75.029  53.502  1
230246  94.867  -75.034  53.456  1
230247  94.883  -75.039  53.409  1
230248  94.898  -75.044  53.362  1
230249  94.914  -75.051  53.313  1
230250  94.929  -75.056  53.264  1
230251  94.945  -75.061  53.217  1
230252  94.960  -75.066  53.170  1
230253  94.965  -75.065  53.119  1
230254  94.959  -75.055  53.064  1
230255  94.955  -75.046  53.005  1
230256  94.987  -75.052  52.943  1
230257  95.019  -75.059  52.880  1
230258  95.051  -75.066  52.816  1
230259  95.082  -75.072  52.752  1
230260  95.107  -75.074  52.690  1
230261  95.132  -75.076  52.629  1
230262  95.158  -75.079  52.569  1
230263  95.183  -75.082  52.509  1
230264  95.208  -75.084  52.452  1
230265  95.234  -75.089  52.397  1
230266  95.261  -75.100  52.343  1
230267  95.289  -75.111  52.290  1
230268  95.313  -75.119  52.239  1
230269  95.327  -75.119  52.191  1
230270  95.341  -75.118  52.145  1
230271  95.355  -75.117  52.101  1
230272  95.370  -75.117  52.059  1
230273  95.390  -75.123  52.018  1
230274  95.414  -75.134  51.977  1
230275  95.439  -75.145  51.938  1
230276  95.463  -75.155  51.900  1
230277  95.487  -75.166  51.864  1
230278  95.511  -75.176  51.828  1
230279  95.535  -75.187  51.794  1
230280  95.562  -75.188  51.762  1
230281  95.591  -75.181  51.731  1
230282  95.619  -75.174  51.701  1
230283  95.648  -75.167  51.672  1
230284  95.676  -75.160  51.645  1
230285  95.717  -75.166  51.618  1
230286  95.758  -75.172  51.590  1
230287  95.799  -75.177  51.565  1
230288  95.839  -75.183  51.539  1
230289  95.881  -75.189  51.512  1
230290  95.918  -75.196  51.484  1
230291  95.954  -75.204  51.456  1
230292  95.990  -75.213  51.428  1
230293  96.026  -75.221  51.401  1
230294  96.061  -75.229  51.375  1
230295  96.097  -75.238  51.348  1
230296  96.133  -75.246  51.323  1
230297  96.169  -75.254  51.299  1
230298  96.206  -75.263  51.274  1
230299  96.245  -75.268  51.250  1
230300  96.276  -75.269  51.226  1
230301  96.308  -75.270  51.201  1
230302  96.339  -75.270  51.177  1
230303  96.371  -75.272  51.153  1
230304  96.402  -75.273  51.128  1
230305  96.433  -75.273  51.103  1
230306  96.455  -75.284  51.077  1
230307  96.475  -75.296  51.051  1
230308  96.496  -75.309  51.026  1
230309  96.515  -75.321  51.002  1
230310  96.535  -75.334  50.980  1
230311  96.555  -75.346  50.957  1
230312  96.576  -75.358  50.933  1
230313  96.596  -75.371  50.908  1
230314  96.616  -75.383  50.883  1
230315  96.638  -75.388  50.858  1
230316  96.659  -75.392  50.834  1
230317  96.680  -75.396  50.811  1
230318  96.701  -75.401  50.788  1
230319  96.721  -75.408  50.765  1
230320  96.731  -75.427  50.741  1
230321  96.741  -75.445  50.718  1
230322  96.751  -75.464  50.694  1
230323  96.764  -75.484  50.669  1
230324  96.778  -75.505  50.644  1
230325  96.791  -75.526  50.618  1
230326  96.804  -75.547  50.588  1
230327  96.818  -75.568  50.558  1
230328  96.842  -75.580  50.529  1
230329  96.866  -75.593  50.501  1
230330  96.890  -75.606  50.471  1
230331  96.914  -75.619  50.443  1
230332  96.957  -75.628  50.414  1
230333  97.021  -75.632  50.384  1
230334  97.086  -75.637  50.354  1
230335  97.135  -75.641  50.324  1
230336  97.159  -75.647  50.294  1
230337  97.183  -75.653  50.263  1
230338  97.208  -75.659  50.231  1
230339  97.232  -75.665  50.198  1
230340  97.256  -75.671  50.166  1
230341  97.281  -75.676  50.133  1
230342  97.305  -75.682  50.099  1
230343  97.329  -75.688  50.065  1
230344  97.353  -75.694  50.031  1
230345  97.378  -75.699  49.996  1
230346  97.402  -75.706  49.961  1
230347  97.425  -75.720  49.925  1
230348  97.447  -75.735  49.889  1
230349  97.470  -75.750  49.854  1
230350  97.493  -75.766  49.819  1
230351  97.516  -75.781  49.784  1
230352  97.538  -75.796  49.750  1
230353  97.569  -75.803  49.716  1
230354  97.600  -75.805  49.683  1
230355  97.632  -75.804  49.652  1
230356  97.663  -75.802  49.622  1
230357  97.693  -75.800  49.590  1
230358  97.725  -75.796  49.557  1
230359  97.755  -75.794  49.524  1
230360  97.787  -75.792  49.489  1
230361  97.813  -75.801  49.452  1
230362  97.824  -75.806  49.416  1
230363  97.835  -75.810  49.379  1
230364  97.846  -75.815  49.338  1
230365  97.854  -75.825  49.296  1
230366  97.865  -75.834  49.255  1
230367  97.882  -75.848  49.213  1
230368  97.900  -75.870  49.171  1
230369  97.919  -75.891  49.130  1
230370  97.937  -75.913  49.089  1
230371  97.955  -75.934  49.047  1
230372  97.973  -75.949  49.005  1
230373  97.992  -75.963  48.963  1
230374  98.010  -75.977  48.920  1
230375  98.056  -75.995  48.877  1
230376  98.101  -76.013  48.835  1
230377  98.147  -76.032  48.791  1
230378  98.193  -76.050  48.747  1
230379  98.239  -76.069  48.703  1
230380  98.285  -76.088  48.662  1
230381  98.329  -76.105  48.620  1
230382  98.368  -76.120  48.579  1
230383  98.409  -76.136  48.537  1
230384  98.448  -76.152  48.496  1
230385  98.461  -76.170  48.454  1
230386  98.473  -76.188  48.414  1
230387  98.485  -76.206  48.376  1
230388  98.497  -76.223  48.339  1
230389  98.508  -76.242  48.302  1
230390  98.520  -76.260  48.266  1
230391  98.544  -76.294  48.231  1
230392  98.578  -76.307  48.198  1
230393  98.609  -76.304  48.165  1
230394  98.642  -76.302  48.133  1
230395  98.673  -76.300  48.102  1
230396  98.705  -76.297  48.072  1
230397  98.737  -76.295  48.042  1
230398  98.765  -76.293  48.013  1
230399  98.790  -76.292  47.985  1
230400  98.816  -76.291  47.961  1
230401  98.842  -76.290  47.937  1
230402  98.867  -76.289  47.915  1
230403  98.893  -76.288  47.895  1
230404  98.919  -76.289  47.877  1
230405  98.945  -76.292  47.858  1
230406  98.971  -76.294  47.840  1
230407  98.997  -76.296  47.821  1
230408  99.023  -76.298  47.800  1
230409  99.049  -76.301  47.780  1
230410  99.075  -76.304  47.759  1
230411  99.099  -76.315  47.736  1
230412  99.123  -76.326  47.713  1
230413  99.147  -76.337  47.688  1
230414  99.171  -76.348  47.663  1
230415  99.196  -76.359  47.635  1
230416  99.220  -76.370  47.607  1
230417  99.237  -76.375  47.578  1
230418  99.245  -76.372  47.549  1
230419  99.254  -76.369  47.518  1
230420  99.262  -76.366  47.486  1
230421  99.270  -76.363  47.455  1
230422  99.278  -76.361  47.424  1
230423  99.286  -76.357  47.394  1
230424  99.303  -76.356  47.363  1
230425  99.325  -76.354  47.332  1
230426  99.346  -76.354  47.300  1
230427  99.373  -76.354  47.267  1
230428  99.403  -76.356  47.235  1
230429  99.433  -76.369  47.202  1
230430  99.464  -76.382  47.168  1
230431  99.495  -76.395  47.136  1
230432  99.525  -76.408  47.104  1
230433  99.556  -76.421  47.072  1
230434  99.587  -76.435  47.041  1
230435  99.618  -76.448  47.008  1
230436  99.653  -76.461  46.975  1
230437  99.688  -76.473  46.942  1
230438  99.723  -76.486  46.909  1
230439  99.759  -76.499  46.877  1
230440  99.794  -76.511  46.845  1
230441  99.829  -76.524  46.814  1
230442  99.863  -76.539  46.783  1
230443  99.895  -76.555  46.752  1
230444  99.927  -76.571  46.723  1
230445  99.954  -76.583  46.694  1
230446  99.973  -76.589  46.665  1
230447  99.992  -76.602  46.636  1
230448  100.010  -76.615  46.605  1
230449  100.028  -76.629  46.574  1
230450  100.047  -76.642  46.542  1
230451  100.065  -76.655  46.510  1
230452  100.079  -76.658  46.478  1
230453  100.092  -76.661  46.446  1
230454  100.106  -76.665  46.413  1
230455  100.119  -76.668  46.378  1
230456  100.133  -76.671  46.343  1
230457  100.146  -76.674  46.309  1
230458  100.160  -76.677  46.275  1
230459  100.174  -76.680  46.242  1
230460  100.191  -76.671  46.208  1
230461  100.210  -76.659  46.174  1
230462  100.229  -76.647  46.142  1
230463  100.248  -76.634  46.110  1
230464  100.267  -76.640  46.078  1
230465  100.287  -76.648  46.048  1
230466  100.307  -76.656  46.018  1
230467  100.326  -76.664  45.989  1
230468  100.346  -76.671  45.960  1
230469  100.365  -76.680  45.933  1
230470  100.385  -76.687  45.907  1
230471  100.404  -76.696  45.882  1
230472  100.424  -76.703  45.858  1
230473  100.443  -76.711  45.834  1
230474  100.463  -76.719  45.811  1
230475  100.482  -76.727  45.790  1
230476  100.500  -76.724  45.769  1
230477  100.519  -76.728  45.748  1
230478  100.540  -76.750  45.728  1
230479  100.563  -76.763  45.709  1
230480  100.587  -76.772  45.691  1
230481  100.611  -76.781  45.672  1
230482  100.635  -76.790  45.653  1
230483  100.659  -76.799  45.635  1
230484  100.683  -76.809  45.616  1
230485  100.707  -76.818  45.598  1
230486  100.731  -76.828  45.579  1
230487  100.756  -76.837  45.560  1
230488  100.784  -76.847  45.542  1
230489  100.812  -76.858  45.523  1
230490  100.840  -76.868  45.506  1
230491  100.868  -76.879  45.489  1
230492  100.896  -76.890  45.472  1
230493  100.918  -76.901  45.456  1
230494  100.933  -76.912  45.441  1
230495  100.948  -76.925  45.427  1
230496  100.963  -76.937  45.414  1
230497  100.977  -76.949  45.400  1
230498  100.994  -76.962  45.387  1
230499  101.023  -76.984  45.374  1
230500  101.052  -77.007  45.362  1
230501  101.081  -77.030  45.350  1
230502  101.110  -77.052  45.338  1
230503  101.139  -77.075  45.326  1
230504  101.168  -77.097  45.315  1
230505  101.196  -77.119  45.303  1
230506  101.226  -77.141  45.290  1
230507  101.254  -77.164  45.276  1
230508  101.283  -77.186  45.261  1
230509  101.305  -77.204  45.246  1
230510  101.320  -77.216  45.231  1
230511  101.335  -77.229  45.215  1
230512  101.349  -77.241  45.198  1
230513  101.364  -77.254  45.182  1
230514  101.379  -77.266  45.166  1
230515  101.398  -77.272  45.148  1
230516  101.421  -77.273  45.131  1
230517  101.444  -77.273  45.114  1
230518  101.464  -77.276  45.096  1
230519  101.483  -77.282  45.078  1
230520  101.501  -77.289  45.059  1
230521  101.520  -77.296  45.041  1
230522  101.539  -77.302  45.023  1
230523  101.557  -77.309  45.004  1
230524  101.575  -77.315  44.984  1
230525  101.594  -77.322  44.966  1
230526  101.613  -77.329  44.948  1
230527  101.631  -77.335  44.930  1
230528  101.650  -77.341  44.914  1
230529  101.668  -77.348  44.897  1
230530  101.687  -77.354  44.880  1
230531  101.704  -77.358  44.863  1
230532  101.719  -77.360  44.847  1
230533  101.735  -77.362  44.831  1
230534  101.746  -77.367  44.816  1
230535  101.763  -77.390  44.800  1
230536  101.783  -77.410  44.784  1
230537  101.803  -77.429  44.767  1
230538  101.823  -77.449  44.750  1
230539  101.843  -77.469  44.735  1
230540  101.863  -77.489  44.718  1
230541  101.883  -77.508  44.702  1
230542  101.903  -77.531  44.687  1
230543  101.922  -77.554  44.669  1
230544  101.942  -77.577  44.652  1
230545  101.994  -77.586  44.635  1
230546  102.051  -77.595  44.620  1
230547  102.094  -77.603  44.604  1
230548  102.114  -77.612  44.588  1
230549  102.134  -77.620  44.572  1
230550  102.155  -77.630  44.557  1
230551  102.185  -77.641  44.541  1
230552  102.217  -77.652  44.527  1
230553  102.249  -77.664  44.512  1
230554  102.282  -77.676  44.498  1
230555  102.314  -77.687  44.484  1
230556  102.334  -77.705  44.469  1
230557  102.349  -77.727  44.454  1
230558  102.364  -77.747  44.437  1
230559  102.384  -77.760  44.421  1
230560  102.409  -77.764  44.406  1
230561  102.435  -77.768  44.390  1
230562  102.460  -77.772  44.373  1
230563  102.486  -77.777  44.357  1
230564  102.512  -77.780  44.341  1
230565  102.537  -77.785  44.325  1
230566  102.562  -77.789  44.308  1
230567  102.588  -77.793  44.292  1
230568  102.614  -77.797  44.276  1
230569  102.640  -77.802  44.259  1
230570  102.665  -77.805  44.242  1
230571  102.697  -77.811  44.225  1
230572  102.733  -77.816  44.208  1
230573  102.769  -77.821  44.192  1
230574  102.806  -77.827  44.176  1
230575  102.842  -77.832  44.159  1
230576  102.878  -77.837  44.142  1
230577  102.914  -77.843  44.126  1
230578  102.952  -77.848  44.110  1
230579  102.988  -77.853  44.093  1
230580  103.026  -77.858  44.077  1
230581  103.063  -77.863  44.060  1
230582  103.099  -77.868  44.044  1
230583  103.137  -77.874  44.028  1
230584  103.173  -77.879  44.012  1
230585  103.211  -77.884  43.996  1
230834  92.153  -74.969  54.291  1
230835  92.177  -74.980  54.298  1
230836  92.202  -74.991  54.307  1
230837  92.226  -75.002  54.318  1
230838  92.250  -75.013  54.329  1
230839  92.275  -75.023  54.341  1
230840  92.299  -75.034  54.352  1
230841  92.323  -75.044  54.364  1
230842  92.348  -75.056  54.377  1
230843  92.372  -75.066  54.391  1
230844  92.397  -75.077  54.405  1
230845  92.417  -75.076  54.417  1
230846  92.443  -75.067  54.427  1
230847  92.475  -75.064  54.434  1
230848  92.506  -75.061  54.437  1
230849  92.537  -75.058  54.438  1
230850  92.571  -75.054  54.437  1
230851  92.605  -75.050  54.433  1
230852  92.640  -75.046  54.427  1
230853  92.674  -75.041  54.412  1
230854  92.704  -75.044  54.392  1
230855  92.733  -75.054  54.370  1
230856  92.762  -75.063  54.355  1
230857  92.790  -75.072  54.342  1
230858  92.819  -75.081  54.331  1
230859  92.848  -75.082  54.321  1
230860  92.878  -75.049  54.311  1
230861  92.909  -75.016  54.299  1
230862  92.936  -74.995  54.287  1
230863  92.959  -74.994  54.274  1
230864  92.983  -74.993  54.261  1
230865  93.006  -74.992  54.248  1
230866  93.029  -74.991  54.234  1
230867  93.053  -74.990  54.220  1
230868  93.076  -74.988  54.207  1
230869  93.099  -74.988  54.193  1
230870  93.123  -74.986  54.179  1
230871  93.146  -74.985  54.165  1
230872  93.172  -74.988  54.153  1
230873  93.198  -74.990  54.141  1
230874  93.224  -74.991  54.130  1
230875  93.250  -74.994  54.119  1
230876  93.276  -74.996  54.111  1
230877  93.301  -74.997  54.105  1
230878  93.327  -75.000  54.100  1
230879  93.353  -75.002  54.098  1
230880  93.377  -74.997  54.099  1
230881  93.400  -74.990  54.103  1
230882  93.423  -74.983  54.110  1
230883  93.445  -74.976  54.118  1
230884  93.469  -74.969  54.131  1
230885  93.492  -74.963  54.148  1
230886  93.514  -74.956  54.170  1
230887  93.538  -74.948  54.198  1
230888  93.565  -74.949  54.234  1
230889  93.594  -74.951  54.270  1
230890  93.623  -74.954  54.305  1
230891  93.652  -74.956  54.338  1
230892  93.681  -74.958  54.373  1
230893  93.709  -74.960  54.408  1
230894  93.738  -74.963  54.443  1
230895  93.767  -74.965  54.471  1
230896  93.795  -74.964  54.488  1
230897  93.821  -74.963  54.498  1
230898  93.847  -74.961  54.503  1
230899  93.873  -74.960  54.502  1
230900  93.899  -74.958  54.502  1
230901  93.925  -74.957  54.504  1
230902  93.952  -74.955  54.509  1
230903  93.977  -74.954  54.513  1
230904  94.003  -74.952  54.519  1
230905  94.030  -74.950  54.526  1
230906  94.055  -74.949  54.533  1
230907  94.082  -74.947  54.541  1
230908  94.110  -74.941  54.545  1
230909  94.139  -74.935  54.545  1
230910  94.168  -74.928  54.539  1
230911  94.196  -74.922  54.528  1
230912  94.223  -74.916  54.514  1
230913  94.249  -74.912  54.498  1
230914  94.269  -74.912  54.477  1
230915  94.285  -74.916  54.458  1
230916  94.303  -74.916  54.438  1
230917  94.329  -74.910  54.419  1
230918  94.354  -74.904  54.405  1
230919  94.380  -74.898  54.395  1
230920  94.405  -74.892  54.385  1
230921  94.431  -74.886  54.377  1
230922  94.454  -74.884  54.368  1
230923  94.474  -74.883  54.353  1
230924  94.487  -74.888  54.334  1
230925  94.500  -74.894  54.313  1
230926  94.512  -74.901  54.291  1
230927  94.523  -74.910  54.268  1
230928  94.533  -74.919  54.244  1
230929  94.544  -74.929  54.219  1
230930  94.554  -74.938  54.185  1
230931  94.565  -74.947  54.148  1
230932  94.586  -74.954  54.110  1
230933  94.608  -74.960  54.073  1
230934  94.629  -74.966  54.041  1
230935  94.650  -74.971  54.008  1
230936  94.670  -74.972  53.973  1
230937  94.690  -74.974  53.935  1
230938  94.710  -74.976  53.895  1
230939  94.731  -74.979  53.852  1
230940  94.751  -74.981  53.807  1
230941  94.772  -74.982  53.762  1
230942  94.792  -74.985  53.717  1
230943  94.815  -74.988  53.671  1
230944  94.834  -74.995  53.625  1
230945  94.850  -75.001  53.576  1
230946  94.865  -75.006  53.528  1
230947  94.881  -75.012  53.481  1
230948  94.897  -75.017  53.435  1
230949  94.912  -75.022  53.387  1
230950  94.927  -75.029  53.336  1
230951  94.943  -75.034  53.286  1
230952  94.959  -75.039  53.238  1
230953  94.974  -75.044  53.189  1
230954  94.970  -75.036  53.137  1
230955  94.964  -75.026  53.082  1
230956  94.961  -75.017  53.023  1
230957  94.992  -75.024  52.960  1
230958  95.025  -75.031  52.896  1
230959  95.056  -75.038  52.832  1
230960  95.089  -75.044  52.767  1
230961  95.117  -75.048  52.704  1
230962  95.142  -75.051  52.642  1
230963  95.167  -75.054  52.581  1
230964  95.193  -75.056  52.520  1
230965  95.218  -75.058  52.462  1
230966  95.244  -75.066  52.405  1
230967  95.272  -75.076  52.351  1
230968  95.299  -75.088  52.298  1
230969  95.327  -75.099  52.247  1
230970  95.343  -75.100  52.198  1
230971  95.357  -75.100  52.151  1
230972  95.372  -75.099  52.106  1
230973  95.386  -75.098  52.063  1
230974  95.400  -75.098  52.021  1
230975  95.415  -75.098  51.980  1
230976  95.440  -75.109  51.940  1
230977  95.464  -75.120  51.902  1
230978  95.488  -75.130  51.865  1
230979  95.512  -75.141  51.829  1
230980  95.536  -75.151  51.795  1
230981  95.563  -75.151  51.762  1
230982  95.592  -75.144  51.730  1
230983  95.620  -75.137  51.700  1
230984  95.651  -75.132  51.672  1
230985  95.691  -75.138  51.645  1
230986  95.732  -75.143  51.618  1
230987  95.773  -75.149  51.591  1
230988  95.814  -75.155  51.566  1
230989  95.855  -75.160  51.540  1
230990  95.896  -75.167  51.513  1
230991  95.933  -75.174  51.486  1
230992  95.969  -75.182  51.459  1
230993  96.005  -75.191  51.431  1
230994  96.040  -75.199  51.405  1
230995  96.076  -75.207  51.380  1
230996  96.112  -75.216  51.354  1
230997  96.147  -75.224  51.329  1
230998  96.183  -75.232  51.306  1
230999  96.219  -75.241  51.283  1
231000  96.249  -75.244  51.258  1
231001  96.279  -75.245  51.234  1
231002  96.310  -75.247  51.210  1
231003  96.341  -75.248  51.187  1
231004  96.373  -75.248  51.163  1
231005  96.404  -75.249  51.139  1
231006  96.435  -75.250  51.114  1
231007  96.462  -75.256  51.087  1
231008  96.482  -75.268  51.060  1
231009  96.502  -75.281  51.034  1
231010  96.522  -75.293  51.009  1
231011  96.542  -75.305  50.986  1
231012  96.562  -75.318  50.962  1
231013  96.581  -75.333  50.939  1
231014  96.599  -75.350  50.915  1
231015  96.622  -75.356  50.891  1
231016  96.645  -75.361  50.867  1
231017  96.668  -75.367  50.844  1
231018  96.690  -75.371  50.821  1
231019  96.711  -75.376  50.798  1
231020  96.731  -75.382  50.775  1
231021  96.741  -75.401  50.752  1
231022  96.752  -75.420  50.728  1
231023  96.766  -75.441  50.703  1
231024  96.779  -75.462  50.678  1
231025  96.793  -75.483  50.653  1
231026  96.806  -75.504  50.626  1
231027  96.819  -75.524  50.598  1
231028  96.839  -75.541  50.569  1
231029  96.863  -75.554  50.540  1
231030  96.887  -75.567  50.512  1
231031  96.911  -75.580  50.483  1
231032  96.935  -75.593  50.455  1
231033  96.966  -75.603  50.426  1
231034  97.031  -75.608  50.396  1
231035  97.096  -75.612  50.366  1
231036  97.145  -75.617  50.336  1
231037  97.169  -75.623  50.305  1
231038  97.193  -75.628  50.274  1
231039  97.218  -75.634  50.242  1
231040  97.242  -75.640  50.210  1
231041  97.266  -75.646  50.177  1
231042  97.291  -75.652  50.143  1
231043  97.315  -75.658  50.109  1
231044  97.339  -75.664  50.075  1
231045  97.363  -75.669  50.040  1
231046  97.388  -75.675  50.005  1
231047  97.405  -75.687  49.970  1
231048  97.428  -75.701  49.935  1
231049  97.450  -75.717  49.900  1
231050  97.473  -75.732  49.864  1
231051  97.496  -75.747  49.829  1
231052  97.519  -75.763  49.794  1
231053  97.547  -75.770  49.760  1
231054  97.580  -75.773  49.727  1
231055  97.611  -75.776  49.694  1
231056  97.643  -75.779  49.663  1
231057  97.675  -75.780  49.632  1
231058  97.706  -75.777  49.599  1
231059  97.737  -75.775  49.565  1
231060  97.768  -75.772  49.530  1
231061  97.799  -75.770  49.493  1
231062  97.837  -75.785  49.455  1
231063  97.851  -75.791  49.418  1
231064  97.862  -75.796  49.379  1
231065  97.872  -75.803  49.337  1
231066  97.879  -75.813  49.295  1
231067  97.889  -75.822  49.253  1
231068  97.905  -75.831  49.211  1
231069  97.924  -75.852  49.170  1
231070  97.942  -75.874  49.128  1
231071  97.960  -75.892  49.086  1
231072  97.979  -75.906  49.044  1
231073  97.997  -75.920  49.001  1
231074  98.015  -75.934  48.959  1
231075  98.033  -75.947  48.916  1
231076  98.065  -75.963  48.873  1
231077  98.111  -75.982  48.830  1
231078  98.157  -76.000  48.787  1
231079  98.203  -76.019  48.743  1
231080  98.249  -76.038  48.700  1
231081  98.295  -76.056  48.658  1
231082  98.337  -76.073  48.616  1
231083  98.377  -76.088  48.575  1
231084  98.417  -76.104  48.534  1
231085  98.457  -76.120  48.491  1
231086  98.477  -76.138  48.449  1
231087  98.489  -76.156  48.409  1
231088  98.501  -76.173  48.371  1
231089  98.512  -76.191  48.332  1
231090  98.524  -76.209  48.296  1
231091  98.536  -76.227  48.261  1
231092  98.575  -76.282  48.225  1
231093  98.607  -76.285  48.192  1
231094  98.639  -76.282  48.158  1
231095  98.671  -76.280  48.125  1
231096  98.703  -76.278  48.094  1
231097  98.734  -76.275  48.063  1
231098  98.762  -76.273  48.032  1
231099  98.788  -76.273  48.003  1
231100  98.813  -76.271  47.975  1
231101  98.839  -76.270  47.950  1
231102  98.865  -76.270  47.926  1
231103  98.890  -76.269  47.903  1
231104  98.916  -76.267  47.883  1
231105  98.942  -76.267  47.865  1
231106  98.968  -76.270  47.847  1
231107  98.994  -76.272  47.830  1
231108  99.020  -76.274  47.811  1
231109  99.046  -76.276  47.790  1
231110  99.072  -76.279  47.769  1
231111  99.097  -76.286  47.748  1
231112  99.121  -76.298  47.725  1
231113  99.145  -76.308  47.703  1
231114  99.169  -76.319  47.679  1
231115  99.194  -76.330  47.653  1
231116  99.218  -76.341  47.627  1
231117  99.242  -76.351  47.599  1
231118  99.264  -76.361  47.570  1
231119  99.272  -76.358  47.541  1
231120  99.281  -76.355  47.511  1
231121  99.289  -76.353  47.479  1
231122  99.297  -76.350  47.448  1
231123  99.305  -76.347  47.418  1
231124  99.314  -76.344  47.387  1
231125  99.337  -76.343  47.357  1
231126  99.358  -76.342  47.326  1
231127  99.380  -76.342  47.295  1
231128  99.402  -76.340  47.262  1
231129  99.422  -76.340  47.230  1
231130  99.446  -76.347  47.197  1
231131  99.477  -76.361  47.164  1
231132  99.507  -76.373  47.132  1
231133  99.539  -76.387  47.101  1
231134  99.569  -76.400  47.071  1
231135  99.600  -76.413  47.042  1
231136  99.632  -76.426  47.009  1
231137  99.667  -76.439  46.976  1
231138  99.702  -76.451  46.943  1
231139  99.737  -76.464  46.911  1
231140  99.772  -76.477  46.879  1
231141  99.805  -76.492  46.847  1
231142  99.838  -76.508  46.817  1
231143  99.869  -76.525  46.786  1
231144  99.902  -76.541  46.756  1
231145  99.933  -76.558  46.726  1
231146  99.955  -76.562  46.698  1
231147  99.975  -76.568  46.668  1
231148  99.993  -76.582  46.638  1
231149  100.011  -76.595  46.607  1
231150  100.030  -76.608  46.575  1
231151  100.048  -76.621  46.542  1
231152  100.066  -76.634  46.510  1
231153  100.084  -76.647  46.478  1
231154  100.103  -76.661  46.446  1
231155  100.121  -76.673  46.412  1
231156  100.134  -76.676  46.376  1
231157  100.148  -76.679  46.341  1
231158  100.161  -76.682  46.306  1
231159  100.175  -76.685  46.272  1
231160  100.190  -76.685  46.238  1
231161  100.209  -76.672  46.205  1
231162  100.227  -76.660  46.171  1
231163  100.247  -76.648  46.139  1
231164  100.266  -76.635  46.107  1
231165  100.285  -76.631  46.075  1
231166  100.304  -76.640  46.044  1
231167  100.324  -76.647  46.015  1
231168  100.344  -76.655  45.986  1
231169  100.363  -76.663  45.957  1
231170  100.382  -76.671  45.930  1
231171  100.402  -76.679  45.904  1
231172  100.422  -76.687  45.878  1
231173  100.441  -76.694  45.854  1
231174  100.461  -76.702  45.830  1
231175  100.480  -76.710  45.808  1
231176  100.500  -76.718  45.786  1
231177  100.519  -76.726  45.765  1
231178  100.546  -76.732  45.744  1
231179  100.570  -76.742  45.724  1
231180  100.594  -76.751  45.705  1
231181  100.618  -76.760  45.686  1
231182  100.642  -76.769  45.667  1
231183  100.666  -76.778  45.648  1
231184  100.690  -76.787  45.629  1
231185  100.714  -76.796  45.610  1
231186  100.738  -76.806  45.592  1
231187  100.762  -76.815  45.572  1
231188  100.787  -76.824  45.553  1
231189  100.815  -76.835  45.535  1
231190  100.843  -76.846  45.516  1
231191  100.871  -76.856  45.498  1
231192  100.899  -76.867  45.481  1
231193  100.927  -76.878  45.464  1
231194  100.947  -76.889  45.448  1
231195  100.962  -76.901  45.432  1
231196  100.976  -76.913  45.418  1
231197  100.991  -76.925  45.405  1
231198  101.006  -76.937  45.392  1
231199  101.021  -76.949  45.379  1
231200  101.035  -76.961  45.366  1
231201  101.062  -76.982  45.353  1
231202  101.091  -77.004  45.342  1
231203  101.120  -77.027  45.330  1
231204  101.148  -77.049  45.319  1
231205  101.178  -77.072  45.306  1
231206  101.206  -77.094  45.294  1
231207  101.236  -77.116  45.280  1
231208  101.264  -77.139  45.266  1
231209  101.293  -77.161  45.251  1
231210  101.319  -77.182  45.237  1
231211  101.334  -77.194  45.221  1
231212  101.349  -77.207  45.205  1
231213  101.364  -77.219  45.189  1
231214  101.379  -77.232  45.173  1
231215  101.394  -77.244  45.157  1
231216  101.415  -77.247  45.139  1
231217  101.438  -77.247  45.123  1
231218  101.460  -77.247  45.105  1
231219  101.481  -77.249  45.087  1
231220  101.500  -77.256  45.069  1
231221  101.519  -77.263  45.050  1
231222  101.537  -77.269  45.032  1
231223  101.556  -77.276  45.013  1
231224  101.574  -77.282  44.995  1
231225  101.593  -77.288  44.976  1
231226  101.611  -77.295  44.958  1
231227  101.630  -77.301  44.940  1
231228  101.649  -77.308  44.923  1
231229  101.667  -77.315  44.907  1
231230  101.685  -77.321  44.891  1
231231  101.704  -77.328  44.874  1
231232  101.723  -77.335  44.857  1
231233  101.741  -77.341  44.841  1
231234  101.759  -77.346  44.824  1
231235  101.774  -77.348  44.808  1
231236  101.790  -77.367  44.792  1
231237  101.810  -77.386  44.776  1
231238  101.830  -77.406  44.759  1
231239  101.850  -77.429  44.742  1
231240  101.870  -77.451  44.727  1
231241  101.889  -77.473  44.711  1
231242  101.909  -77.496  44.694  1
231243  101.928  -77.519  44.678  1
231244  101.948  -77.542  44.661  1
231245  101.968  -77.564  44.644  1
231246  102.024  -77.573  44.628  1
231247  102.081  -77.581  44.612  1
231248  102.106  -77.590  44.597  1
231249  102.126  -77.599  44.580  1
231250  102.147  -77.608  44.565  1
231251  102.167  -77.617  44.550  1
231252  102.192  -77.627  44.534  1
231253  102.225  -77.638  44.519  1
231254  102.257  -77.650  44.505  1
231255  102.290  -77.661  44.491  1
231256  102.322  -77.673  44.476  1
231257  102.341  -77.692  44.461  1
231258  102.356  -77.712  44.446  1
231259  102.371  -77.733  44.429  1
231260  102.394  -77.740  44.413  1
231261  102.419  -77.745  44.397  1
231262  102.445  -77.749  44.381  1
231263  102.471  -77.753  44.364  1
231264  102.496  -77.757  44.347  1
231265  102.522  -77.761  44.332  1
231266  102.547  -77.765  44.316  1
231267  102.573  -77.770  44.298  1
231268  102.599  -77.774  44.282  1
231269  102.624  -77.778  44.265  1
231270  102.650  -77.782  44.249  1
231271  102.685  -77.787  44.232  1
231272  102.721  -77.793  44.216  1
231273  102.757  -77.798  44.199  1
231274  102.794  -77.803  44.182  1
231275  102.830  -77.809  44.166  1
231276  102.867  -77.815  44.149  1
231277  102.903  -77.820  44.133  1
231278  102.939  -77.825  44.116  1
231279  102.975  -77.830  44.100  1
231280  103.012  -77.836  44.084  1
231281  103.048  -77.841  44.067  1
231282  103.085  -77.846  44.050  1
231283  103.121  -77.852  44.034  1
231284  103.158  -77.857  44.019  1
231285  103.195  -77.862  44.003  1
231535  92.155  -74.937  54.296  1
231536  92.179  -74.947  54.301  1
231537  92.204  -74.959  54.310  1
231538  92.228  -74.969  54.320  1
231539  92.252  -74.980  54.331  1
231540  92.277  -74.991  54.343  1
231541  92.301  -75.001  54.355  1
231542  92.325  -75.013  54.366  1
231543  92.350  -75.023  54.380  1
231544  92.374  -75.034  54.394  1
231545  92.399  -75.044  54.408  1
231546  92.422  -75.052  54.420  1
231547  92.439  -75.034  54.432  1
231548  92.471  -75.031  54.442  1
231549  92.502  -75.028  54.447  1
231550  92.535  -75.024  54.450  1
231551  92.570  -75.020  54.451  1
231552  92.605  -75.016  54.448  1
231553  92.639  -75.013  54.442  1
231554  92.672  -75.009  54.428  1
231555  92.701  -75.019  54.410  1
231556  92.729  -75.035  54.388  1
231557  92.758  -75.049  54.373  1
231558  92.786  -75.058  54.361  1
231559  92.815  -75.067  54.351  1
231560  92.844  -75.069  54.342  1
231561  92.874  -75.035  54.332  1
231562  92.905  -75.002  54.320  1
231563  92.935  -74.969  54.307  1
231564  92.960  -74.962  54.293  1
231565  92.983  -74.961  54.279  1
231566  93.007  -74.960  54.266  1
231567  93.030  -74.958  54.252  1
231568  93.054  -74.958  54.238  1
231569  93.079  -74.960  54.226  1
231570  93.106  -74.962  54.212  1
231571  93.131  -74.964  54.198  1
231572  93.157  -74.966  54.185  1
231573  93.183  -74.968  54.173  1
231574  93.209  -74.970  54.161  1
231575  93.234  -74.972  54.150  1
231576  93.261  -74.974  54.141  1
231577  93.286  -74.976  54.133  1
231578  93.312  -74.978  54.126  1
231579  93.336  -74.974  54.121  1
231580  93.359  -74.967  54.120  1
231581  93.382  -74.960  54.120  1
231582  93.405  -74.954  54.125  1
231583  93.428  -74.947  54.132  1
231584  93.450  -74.939  54.139  1
231585  93.474  -74.932  54.151  1
231586  93.496  -74.925  54.168  1
231587  93.519  -74.919  54.189  1
231588  93.543  -74.912  54.218  1
231589  93.570  -74.913  54.254  1
231590  93.599  -74.915  54.289  1
231591  93.628  -74.917  54.322  1
231592  93.657  -74.919  54.353  1
231593  93.686  -74.921  54.385  1
231594  93.714  -74.923  54.418  1
231595  93.743  -74.925  54.451  1
231596  93.773  -74.930  54.477  1
231597  93.803  -74.940  54.494  1
231598  93.821  -74.937  54.504  1
231599  93.846  -74.935  54.508  1
231600  93.872  -74.934  54.507  1
231601  93.898  -74.932  54.508  1
231602  93.924  -74.931  54.512  1
231603  93.950  -74.929  54.520  1
231604  93.976  -74.928  54.524  1
231605  94.002  -74.926  54.531  1
231606  94.028  -74.925  54.538  1
231607  94.054  -74.923  54.544  1
231608  94.082  -74.918  54.551  1
231609  94.111  -74.912  54.554  1
231610  94.139  -74.906  54.554  1
231611  94.168  -74.900  54.547  1
231612  94.196  -74.893  54.535  1
231613  94.224  -74.887  54.520  1
231614  94.252  -74.881  54.501  1
231615  94.268  -74.885  54.478  1
231616  94.284  -74.888  54.456  1
231617  94.303  -74.888  54.434  1
231618  94.329  -74.882  54.412  1
231619  94.354  -74.876  54.396  1
231620  94.380  -74.870  54.385  1
231621  94.403  -74.866  54.376  1
231622  94.425  -74.865  54.368  1
231623  94.447  -74.863  54.360  1
231624  94.463  -74.866  54.345  1
231625  94.476  -74.872  54.327  1
231626  94.489  -74.878  54.308  1
231627  94.501  -74.883  54.287  1
231628  94.514  -74.889  54.266  1
231629  94.526  -74.897  54.244  1
231630  94.536  -74.907  54.221  1
231631  94.547  -74.916  54.191  1
231632  94.564  -74.923  54.158  1
231633  94.585  -74.929  54.124  1
231634  94.606  -74.934  54.092  1
231635  94.626  -74.935  54.061  1
231636  94.646  -74.938  54.031  1
231637  94.666  -74.939  54.000  1
231638  94.686  -74.941  53.962  1
231639  94.706  -74.943  53.923  1
231640  94.727  -74.945  53.882  1
231641  94.747  -74.947  53.838  1
231642  94.768  -74.950  53.790  1
231643  94.794  -74.957  53.746  1
231644  94.822  -74.965  53.701  1
231645  94.848  -74.973  53.653  1
231646  94.864  -74.979  53.604  1
231647  94.879  -74.984  53.555  1
231648  94.895  -74.990  53.507  1
231649  94.910  -74.995  53.460  1
231650  94.926  -75.001  53.411  1
231651  94.941  -75.007  53.360  1
231652  94.957  -75.012  53.309  1
231653  94.972  -75.017  53.259  1
231654  94.980  -75.017  53.208  1
231655  94.974  -75.007  53.156  1
231656  94.968  -74.997  53.100  1
231657  94.966  -74.989  53.041  1
231658  94.998  -74.996  52.978  1
231659  95.030  -75.003  52.912  1
231660  95.062  -75.009  52.847  1
231661  95.094  -75.016  52.782  1
231662  95.126  -75.022  52.718  1
231663  95.152  -75.025  52.655  1
231664  95.177  -75.028  52.593  1
231665  95.202  -75.030  52.532  1
231666  95.228  -75.032  52.472  1
231667  95.255  -75.042  52.415  1
231668  95.282  -75.053  52.359  1
231669  95.310  -75.064  52.305  1
231670  95.337  -75.076  52.255  1
231671  95.359  -75.082  52.206  1
231672  95.374  -75.082  52.158  1
231673  95.388  -75.081  52.112  1
231674  95.402  -75.080  52.067  1
231675  95.417  -75.080  52.024  1
231676  95.431  -75.079  51.983  1
231677  95.446  -75.079  51.942  1
231678  95.465  -75.084  51.903  1
231679  95.489  -75.095  51.866  1
231680  95.513  -75.105  51.831  1
231681  95.537  -75.116  51.797  1
231682  95.564  -75.114  51.764  1
231683  95.593  -75.107  51.731  1
231684  95.625  -75.104  51.700  1
231685  95.666  -75.109  51.672  1
231686  95.706  -75.115  51.644  1
231687  95.748  -75.121  51.617  1
231688  95.789  -75.126  51.591  1
231689  95.829  -75.132  51.565  1
231690  95.870  -75.138  51.539  1
231691  95.911  -75.144  51.512  1
231692  95.948  -75.152  51.486  1
231693  95.983  -75.160  51.459  1
231694  96.019  -75.169  51.434  1
231695  96.054  -75.177  51.409  1
231696  96.090  -75.185  51.384  1
231697  96.126  -75.194  51.359  1
231698  96.162  -75.202  51.335  1
231699  96.197  -75.210  51.313  1
231700  96.229  -75.213  51.291  1
231701  96.260  -75.215  51.267  1
231702  96.290  -75.217  51.243  1
231703  96.317  -75.220  51.220  1
231704  96.345  -75.223  51.195  1
231705  96.375  -75.225  51.172  1
231706  96.406  -75.226  51.148  1
231707  96.437  -75.227  51.123  1
231708  96.469  -75.228  51.097  1
231709  96.489  -75.240  51.070  1
231710  96.509  -75.253  51.043  1
231711  96.529  -75.265  51.017  1
231712  96.548  -75.279  50.993  1
231713  96.566  -75.297  50.969  1
231714  96.584  -75.314  50.945  1
231715  96.604  -75.324  50.923  1
231716  96.627  -75.330  50.900  1
231717  96.650  -75.335  50.877  1
231718  96.673  -75.340  50.853  1
231719  96.696  -75.345  50.830  1
231720  96.719  -75.350  50.808  1
231721  96.741  -75.357  50.785  1
231722  96.754  -75.377  50.762  1
231723  96.767  -75.399  50.737  1
231724  96.781  -75.419  50.712  1
231725  96.795  -75.439  50.688  1
231726  96.808  -75.461  50.664  1
231727  96.821  -75.481  50.638  1
231728  96.836  -75.501  50.610  1
231729  96.860  -75.514  50.582  1
231730  96.884  -75.527  50.553  1
231731  96.908  -75.540  50.525  1
231732  96.932  -75.552  50.497  1
231733  96.956  -75.565  50.468  1
231734  96.980  -75.578  50.439  1
231735  97.041  -75.583  50.409  1
231736  97.105  -75.587  50.378  1
231737  97.155  -75.593  50.348  1
231738  97.179  -75.598  50.317  1
231739  97.204  -75.604  50.285  1
231740  97.228  -75.610  50.252  1
231741  97.252  -75.615  50.219  1
231742  97.276  -75.621  50.186  1
231743  97.301  -75.627  50.153  1
231744  97.325  -75.634  50.118  1
231745  97.349  -75.639  50.084  1
231746  97.373  -75.645  50.049  1
231747  97.391  -75.656  50.014  1
231748  97.408  -75.668  49.979  1
231749  97.431  -75.683  49.944  1
231750  97.453  -75.698  49.910  1
231751  97.476  -75.714  49.875  1
231752  97.499  -75.729  49.840  1
231753  97.527  -75.737  49.806  1
231754  97.559  -75.740  49.772  1
231755  97.590  -75.743  49.739  1
231756  97.623  -75.746  49.707  1
231757  97.654  -75.749  49.675  1
231758  97.686  -75.753  49.644  1
231759  97.718  -75.755  49.609  1
231760  97.749  -75.753  49.574  1
231761  97.780  -75.749  49.538  1
231762  97.811  -75.749  49.500  1
231763  97.849  -75.765  49.460  1
231764  97.878  -75.777  49.421  1
231765  97.889  -75.781  49.381  1
231766  97.897  -75.791  49.338  1
231767  97.905  -75.801  49.296  1
231768  97.913  -75.811  49.254  1
231769  97.929  -75.815  49.212  1
231770  97.947  -75.834  49.171  1
231771  97.965  -75.849  49.128  1
231772  97.984  -75.863  49.085  1
231773  98.002  -75.877  49.042  1
231774  98.020  -75.891  48.998  1
231775  98.038  -75.905  48.956  1
231776  98.057  -75.919  48.913  1
231777  98.075  -75.932  48.870  1
231778  98.121  -75.951  48.826  1
231779  98.167  -75.969  48.783  1
231780  98.213  -75.988  48.740  1
231781  98.258  -76.007  48.697  1
231782  98.304  -76.025  48.655  1
231783  98.345  -76.041  48.613  1
231784  98.385  -76.057  48.572  1
231785  98.425  -76.072  48.530  1
231786  98.465  -76.088  48.486  1
231787  98.493  -76.105  48.444  1
231788  98.505  -76.123  48.404  1
231789  98.516  -76.141  48.365  1
231790  98.528  -76.159  48.327  1
231791  98.540  -76.177  48.291  1
231792  98.565  -76.213  48.256  1
231793  98.604  -76.266  48.220  1
231794  98.637  -76.263  48.186  1
231795  98.668  -76.260  48.152  1
231796  98.700  -76.258  48.119  1
231797  98.732  -76.255  48.086  1
231798  98.760  -76.254  48.054  1
231799  98.785  -76.253  48.023  1
231800  98.811  -76.252  47.994  1
231801  98.837  -76.251  47.966  1
231802  98.862  -76.250  47.941  1
231803  98.888  -76.249  47.916  1
231804  98.914  -76.248  47.893  1
231805  98.939  -76.247  47.872  1
231806  98.964  -76.246  47.853  1
231807  98.991  -76.248  47.836  1
231808  99.017  -76.250  47.819  1
231809  99.043  -76.252  47.800  1
231810  99.069  -76.254  47.779  1
231811  99.094  -76.258  47.757  1
231812  99.119  -76.269  47.736  1
231813  99.143  -76.279  47.713  1
231814  99.167  -76.291  47.691  1
231815  99.191  -76.301  47.668  1
231816  99.215  -76.312  47.644  1
231817  99.239  -76.323  47.619  1
231818  99.264  -76.334  47.590  1
231819  99.288  -76.345  47.562  1
231820  99.299  -76.345  47.533  1
231821  99.307  -76.342  47.503  1
231822  99.316  -76.339  47.472  1
231823  99.324  -76.336  47.442  1
231824  99.332  -76.333  47.412  1
231825  99.348  -76.332  47.382  1
231826  99.370  -76.331  47.351  1
231827  99.392  -76.329  47.321  1
231828  99.414  -76.329  47.289  1
231829  99.433  -76.329  47.257  1
231830  99.448  -76.332  47.225  1
231831  99.464  -76.333  47.193  1
231832  99.492  -76.343  47.160  1
231833  99.521  -76.353  47.130  1
231834  99.551  -76.365  47.100  1
231835  99.582  -76.379  47.070  1
231836  99.613  -76.392  47.040  1
231837  99.645  -76.404  47.008  1
231838  99.681  -76.417  46.976  1
231839  99.716  -76.430  46.944  1
231840  99.749  -76.445  46.912  1
231841  99.780  -76.462  46.880  1
231842  99.812  -76.478  46.849  1
231843  99.844  -76.495  46.818  1
231844  99.876  -76.511  46.789  1
231845  99.909  -76.527  46.757  1
231846  99.936  -76.539  46.728  1
231847  99.956  -76.542  46.699  1
231848  99.976  -76.548  46.670  1
231849  99.994  -76.561  46.640  1
231850  100.012  -76.574  46.608  1
231851  100.031  -76.587  46.575  1
231852  100.049  -76.600  46.542  1
231853  100.067  -76.613  46.510  1
231854  100.085  -76.627  46.478  1
231855  100.104  -76.640  46.444  1
231856  100.122  -76.652  46.410  1
231857  100.140  -76.666  46.374  1
231858  100.159  -76.679  46.339  1
231859  100.176  -76.690  46.303  1
231860  100.190  -76.693  46.269  1
231861  100.207  -76.686  46.235  1
231862  100.226  -76.673  46.202  1
231863  100.246  -76.661  46.169  1
231864  100.264  -76.649  46.136  1
231865  100.283  -76.636  46.103  1
231866  100.302  -76.624  46.072  1
231867  100.322  -76.630  46.041  1
231868  100.341  -76.639  46.011  1
231869  100.361  -76.646  45.982  1
231870  100.381  -76.654  45.954  1
231871  100.400  -76.662  45.927  1
231872  100.420  -76.670  45.900  1
231873  100.439  -76.678  45.874  1
231874  100.459  -76.686  45.850  1
231875  100.478  -76.693  45.826  1
231876  100.498  -76.702  45.804  1
231877  100.517  -76.709  45.782  1
231878  100.537  -76.721  45.760  1
231879  100.572  -76.724  45.739  1
231880  100.601  -76.729  45.719  1
231881  100.625  -76.739  45.700  1
231882  100.649  -76.748  45.682  1
231883  100.673  -76.757  45.662  1
231884  100.697  -76.766  45.643  1
231885  100.720  -76.775  45.623  1
231886  100.745  -76.784  45.604  1
231887  100.768  -76.793  45.585  1
231888  100.792  -76.803  45.566  1
231889  100.818  -76.813  45.546  1
231890  100.846  -76.823  45.527  1
231891  100.874  -76.834  45.508  1
231892  100.902  -76.844  45.489  1
231893  100.930  -76.855  45.472  1
231894  100.958  -76.865  45.454  1
231895  100.975  -76.877  45.438  1
231896  100.990  -76.889  45.422  1
231897  101.004  -76.901  45.407  1
231898  101.019  -76.913  45.394  1
231899  101.034  -76.925  45.381  1
231900  101.049  -76.937  45.368  1
231901  101.063  -76.950  45.356  1
231902  101.078  -76.961  45.345  1
231903  101.101  -76.979  45.333  1
231904  101.130  -77.001  45.322  1
231905  101.159  -77.024  45.310  1
231906  101.188  -77.047  45.298  1
231907  101.216  -77.069  45.284  1
231908  101.245  -77.091  45.271  1
231909  101.274  -77.113  45.256  1
231910  101.303  -77.136  45.242  1
231911  101.332  -77.158  45.227  1
231912  101.348  -77.172  45.212  1
231913  101.363  -77.185  45.196  1
231914  101.378  -77.197  45.180  1
231915  101.393  -77.210  45.164  1
231916  101.408  -77.221  45.148  1
231917  101.431  -77.221  45.131  1
231918  101.454  -77.222  45.115  1
231919  101.476  -77.222  45.097  1
231920  101.498  -77.222  45.078  1
231921  101.517  -77.229  45.060  1
231922  101.536  -77.235  45.041  1
231923  101.554  -77.242  45.023  1
231924  101.572  -77.249  45.005  1
231925  101.591  -77.255  44.986  1
231926  101.610  -77.262  44.968  1
231927  101.628  -77.269  44.950  1
231928  101.647  -77.275  44.933  1
231929  101.666  -77.282  44.916  1
231930  101.684  -77.288  44.900  1
231931  101.702  -77.294  44.885  1
231932  101.721  -77.301  44.868  1
231933  101.740  -77.307  44.851  1
231934  101.758  -77.314  44.835  1
231935  101.777  -77.321  44.818  1
231936  101.796  -77.328  44.801  1
231937  101.817  -77.348  44.785  1
231938  101.836  -77.371  44.768  1
231939  101.856  -77.394  44.752  1
231940  101.876  -77.417  44.735  1
231941  101.895  -77.439  44.720  1
231942  101.915  -77.461  44.704  1
231943  101.935  -77.484  44.687  1
231944  101.954  -77.507  44.671  1
231945  101.974  -77.530  44.654  1
231946  101.996  -77.551  44.637  1
231947  102.053  -77.559  44.621  1
231948  102.098  -77.568  44.605  1
231949  102.119  -77.577  44.589  1
231950  102.139  -77.586  44.573  1
231951  102.159  -77.595  44.557  1
231952  102.180  -77.603  44.543  1
231953  102.200  -77.612  44.526  1
231954  102.232  -77.624  44.511  1
231955  102.265  -77.636  44.497  1
231956  102.297  -77.647  44.483  1
231957  102.330  -77.658  44.468  1
231958  102.348  -77.677  44.453  1
231959  102.363  -77.699  44.438  1
231960  102.379  -77.718  44.421  1
231961  102.404  -77.721  44.405  1
231962  102.430  -77.726  44.389  1
231963  102.455  -77.730  44.372  1
231964  102.481  -77.734  44.355  1
231965  102.507  -77.738  44.338  1
231966  102.532  -77.743  44.322  1
231967  102.558  -77.746  44.305  1
231968  102.583  -77.751  44.289  1
231969  102.609  -77.755  44.272  1
231970  102.637  -77.759  44.256  1
231971  102.673  -77.765  44.239  1
231972  102.710  -77.770  44.222  1
231973  102.746  -77.775  44.206  1
231974  102.782  -77.780  44.189  1
231975  102.818  -77.786  44.172  1
231976  102.855  -77.791  44.156  1
231977  102.891  -77.796  44.139  1
231978  102.927  -77.802  44.123  1
231979  102.964  -77.807  44.106  1
231980  103.000  -77.812  44.090  1
231981  103.036  -77.818  44.074  1
231982  103.073  -77.824  44.058  1
231983  103.109  -77.829  44.041  1
231984  103.146  -77.834  44.025  1
231985  103.182  -77.840  44.009  1
232237  92.181  -74.916  54.305  1
232238  92.205  -74.926  54.314  1
232239  92.230  -74.937  54.323  1
232240  92.254  -74.947  54.334  1
232241  92.278  -74.958  54.345  1
232242  92.303  -74.969  54.356  1
232243  92.327  -74.980  54.368  1
232244  92.352  -74.991  54.381  1
232245  92.376  -75.001  54.396  1
232246  92.400  -75.013  54.410  1
232247  92.425  -75.023  54.423  1
232248  92.439  -75.005  54.435  1
232249  92.467  -74.998  54.446  1
232250  92.500  -74.994  54.453  1
232251  92.535  -74.991  54.459  1
232252  92.568  -74.987  54.461  1
232253  92.601  -74.983  54.459  1
232254  92.634  -74.980  54.453  1
232255  92.667  -74.976  54.442  1
232256  92.699  -74.973  54.425  1
232257  92.728  -74.987  54.405  1
232258  92.756  -75.001  54.392  1
232259  92.784  -75.016  54.381  1
232260  92.813  -75.030  54.372  1
232261  92.842  -75.032  54.365  1
232262  92.872  -75.005  54.356  1
232263  92.902  -74.978  54.343  1
232264  92.932  -74.951  54.328  1
232265  92.961  -74.930  54.313  1
232266  92.987  -74.932  54.298  1
232267  93.013  -74.935  54.284  1
232268  93.039  -74.936  54.271  1
232269  93.064  -74.938  54.257  1
232270  93.090  -74.940  54.245  1
232271  93.116  -74.942  54.232  1
232272  93.142  -74.944  54.218  1
232273  93.167  -74.946  54.205  1
232274  93.194  -74.948  54.193  1
232275  93.219  -74.950  54.182  1
232276  93.245  -74.952  54.172  1
232277  93.271  -74.954  54.163  1
232278  93.295  -74.951  54.155  1
232279  93.318  -74.944  54.148  1
232280  93.341  -74.938  54.143  1
232281  93.364  -74.931  54.142  1
232282  93.387  -74.923  54.143  1
232283  93.410  -74.916  54.147  1
232284  93.433  -74.910  54.154  1
232285  93.455  -74.903  54.161  1
232286  93.479  -74.896  54.173  1
232287  93.501  -74.888  54.188  1
232288  93.524  -74.881  54.209  1
232289  93.547  -74.875  54.237  1
232290  93.575  -74.875  54.271  1
232291  93.604  -74.878  54.306  1
232292  93.633  -74.880  54.340  1
232293  93.662  -74.882  54.371  1
232294  93.691  -74.885  54.400  1
232295  93.719  -74.886  54.428  1
232296  93.748  -74.889  54.459  1
232297  93.781  -74.901  54.485  1
232298  93.814  -74.914  54.502  1
232299  93.834  -74.913  54.511  1
232300  93.852  -74.910  54.515  1
232301  93.871  -74.907  54.514  1
232302  93.897  -74.906  54.516  1
232303  93.923  -74.904  54.521  1
232304  93.949  -74.903  54.531  1
232305  93.975  -74.901  54.536  1
232306  94.001  -74.900  54.543  1
232307  94.027  -74.898  54.550  1
232308  94.054  -74.896  54.556  1
232309  94.082  -74.889  54.562  1
232310  94.111  -74.883  54.565  1
232311  94.139  -74.877  54.564  1
232312  94.168  -74.871  54.556  1
232313  94.196  -74.864  54.543  1
232314  94.223  -74.857  54.526  1
232315  94.247  -74.855  54.505  1
232316  94.267  -74.857  54.481  1
232317  94.283  -74.861  54.456  1
232318  94.303  -74.860  54.432  1
232319  94.329  -74.854  54.408  1
232320  94.353  -74.849  54.389  1
232321  94.374  -74.847  54.376  1
232322  94.396  -74.846  54.367  1
232323  94.418  -74.844  54.359  1
232324  94.439  -74.844  54.351  1
232325  94.452  -74.850  54.337  1
232326  94.465  -74.855  54.319  1
232327  94.477  -74.861  54.300  1
232328  94.490  -74.866  54.280  1
232329  94.503  -74.872  54.260  1
232330  94.516  -74.878  54.240  1
232331  94.529  -74.885  54.218  1
232332  94.542  -74.893  54.191  1
232333  94.562  -74.897  54.160  1
232334  94.582  -74.899  54.130  1
232335  94.602  -74.900  54.102  1
232336  94.622  -74.903  54.075  1
232337  94.642  -74.904  54.048  1
232338  94.662  -74.907  54.019  1
232339  94.682  -74.908  53.985  1
232340  94.702  -74.910  53.946  1
232341  94.723  -74.913  53.904  1
232342  94.745  -74.916  53.860  1
232343  94.773  -74.924  53.815  1
232344  94.801  -74.933  53.771  1
232345  94.829  -74.941  53.725  1
232346  94.857  -74.950  53.676  1
232347  94.878  -74.957  53.626  1
232348  94.893  -74.962  53.577  1
232349  94.909  -74.968  53.529  1
232350  94.924  -74.973  53.480  1
232351  94.939  -74.979  53.431  1
232352  94.955  -74.984  53.381  1
232353  94.971  -74.990  53.330  1
232354  94.986  -74.995  53.279  1
232355  94.985  -74.988  53.227  1
232356  94.979  -74.979  53.173  1
232357  94.973  -74.969  53.117  1
232358  94.972  -74.961  53.059  1
232359  95.004  -74.968  52.993  1
232360  95.036  -74.974  52.927  1
232361  95.068  -74.981  52.861  1
232362  95.100  -74.988  52.795  1
232363  95.132  -74.994  52.731  1
232364  95.162  -75.000  52.667  1
232365  95.187  -75.002  52.605  1
232366  95.212  -75.004  52.544  1
232367  95.238  -75.007  52.483  1
232368  95.265  -75.018  52.425  1
232369  95.293  -75.029  52.368  1
232370  95.320  -75.041  52.314  1
232371  95.347  -75.051  52.263  1
232372  95.375  -75.063  52.214  1
232373  95.390  -75.063  52.165  1
232374  95.404  -75.063  52.116  1
232375  95.419  -75.062  52.071  1
232376  95.433  -75.062  52.027  1
232377  95.448  -75.061  51.985  1
232378  95.462  -75.060  51.944  1
232379  95.476  -75.060  51.905  1
232380  95.490  -75.060  51.868  1
232381  95.514  -75.069  51.833  1
232382  95.538  -75.080  51.800  1
232383  95.566  -75.077  51.765  1
232384  95.599  -75.075  51.732  1
232385  95.640  -75.081  51.701  1
232386  95.681  -75.087  51.672  1
232387  95.722  -75.092  51.643  1
232388  95.763  -75.098  51.616  1
232389  95.804  -75.104  51.589  1
232390  95.844  -75.110  51.563  1
232391  95.885  -75.116  51.536  1
232392  95.926  -75.122  51.510  1
232393  95.962  -75.130  51.484  1
232394  95.997  -75.138  51.459  1
232395  96.033  -75.147  51.435  1
232396  96.069  -75.155  51.412  1
232397  96.105  -75.163  51.387  1
232398  96.141  -75.172  51.363  1
232399  96.176  -75.180  51.341  1
232400  96.207  -75.182  51.320  1
232401  96.239  -75.184  51.298  1
232402  96.270  -75.186  51.274  1
232403  96.302  -75.189  51.252  1
232404  96.330  -75.192  51.229  1
232405  96.358  -75.195  51.204  1
232406  96.385  -75.198  51.180  1
232407  96.413  -75.201  51.157  1
232408  96.440  -75.204  51.132  1
232409  96.471  -75.205  51.106  1
232410  96.496  -75.212  51.079  1
232411  96.515  -75.226  51.052  1
232412  96.533  -75.243  51.025  1
232413  96.551  -75.260  51.001  1
232414  96.569  -75.277  50.976  1
232415  96.587  -75.292  50.953  1
232416  96.610  -75.298  50.931  1
232417  96.633  -75.303  50.908  1
232418  96.656  -75.308  50.886  1
232419  96.679  -75.313  50.863  1
232420  96.702  -75.318  50.840  1
232421  96.726  -75.327  50.818  1
232422  96.751  -75.338  50.795  1
232423  96.769  -75.355  50.771  1
232424  96.783  -75.376  50.747  1
232425  96.796  -75.397  50.723  1
232426  96.810  -75.417  50.699  1
232427  96.823  -75.439  50.676  1
232428  96.836  -75.459  50.651  1
232429  96.857  -75.474  50.623  1
232430  96.881  -75.487  50.595  1
232431  96.905  -75.500  50.567  1
232432  96.930  -75.513  50.539  1
232433  96.953  -75.526  50.511  1
232434  96.977  -75.539  50.482  1
232435  97.002  -75.552  50.452  1
232436  97.051  -75.558  50.421  1
232437  97.115  -75.563  50.391  1
232438  97.165  -75.568  50.360  1
232439  97.189  -75.574  50.328  1
232440  97.214  -75.580  50.296  1
232441  97.238  -75.586  50.263  1
232442  97.262  -75.591  50.229  1
232443  97.286  -75.597  50.195  1
232444  97.311  -75.603  50.162  1
232445  97.335  -75.609  50.128  1
232446  97.359  -75.615  50.094  1
232447  97.377  -75.626  50.059  1
232448  97.394  -75.637  50.024  1
232449  97.412  -75.649  49.989  1
232450  97.434  -75.665  49.954  1
232451  97.456  -75.680  49.920  1
232452  97.479  -75.696  49.886  1
232453  97.506  -75.706  49.852  1
232454  97.538  -75.709  49.818  1
232455  97.570  -75.712  49.784  1
232456  97.601  -75.715  49.753  1
232457  97.633  -75.718  49.721  1
232458  97.665  -75.721  49.688  1
232459  97.697  -75.724  49.656  1
232460  97.729  -75.727  49.621  1
232461  97.760  -75.730  49.585  1
232462  97.792  -75.728  49.547  1
232463  97.824  -75.728  49.507  1
232464  97.862  -75.744  49.467  1
232465  97.899  -75.760  49.426  1
232466  97.915  -75.768  49.384  1
232467  97.923  -75.779  49.341  1
232468  97.930  -75.789  49.298  1
232469  97.935  -75.797  49.255  1
232470  97.947  -75.799  49.213  1
232471  97.969  -75.806  49.172  1
232472  97.989  -75.820  49.129  1
232473  98.007  -75.834  49.085  1
232474  98.025  -75.848  49.041  1
232475  98.043  -75.862  48.996  1
232476  98.062  -75.875  48.954  1
232477  98.080  -75.890  48.911  1
232478  98.099  -75.903  48.868  1
232479  98.131  -75.919  48.824  1
232480  98.176  -75.938  48.781  1
232481  98.222  -75.956  48.738  1
232482  98.268  -75.975  48.695  1
232483  98.313  -75.993  48.652  1
232484  98.353  -76.009  48.611  1
232485  98.393  -76.025  48.568  1
232486  98.434  -76.041  48.524  1
232487  98.474  -76.057  48.481  1
232488  98.509  -76.072  48.440  1
232489  98.520  -76.091  48.399  1
232490  98.532  -76.109  48.360  1
232491  98.544  -76.126  48.322  1
232492  98.556  -76.144  48.286  1
232493  98.596  -76.201  48.251  1
232494  98.634  -76.244  48.216  1
232495  98.666  -76.241  48.182  1
232496  98.698  -76.238  48.147  1
232497  98.729  -76.236  48.113  1
232498  98.757  -76.235  48.081  1
232499  98.783  -76.233  48.047  1
232500  98.808  -76.232  48.015  1
232501  98.834  -76.232  47.985  1
232502  98.860  -76.230  47.958  1
232503  98.885  -76.229  47.931  1
232504  98.911  -76.229  47.906  1
232505  98.937  -76.227  47.883  1
232506  98.962  -76.226  47.862  1
232507  98.988  -76.226  47.842  1
232508  99.014  -76.226  47.824  1
232509  99.040  -76.228  47.807  1
232510  99.066  -76.230  47.789  1
232511  99.092  -76.232  47.768  1
232512  99.117  -76.240  47.747  1
232513  99.141  -76.251  47.725  1
232514  99.165  -76.262  47.702  1
232515  99.189  -76.273  47.680  1
232516  99.213  -76.284  47.657  1
232517  99.237  -76.295  47.633  1
232518  99.262  -76.305  47.608  1
232519  99.286  -76.317  47.581  1
232520  99.310  -76.327  47.554  1
232521  99.327  -76.332  47.526  1
232522  99.335  -76.329  47.496  1
232523  99.343  -76.326  47.466  1
232524  99.351  -76.323  47.435  1
232525  99.360  -76.320  47.405  1
232526  99.382  -76.320  47.376  1
232527  99.404  -76.318  47.346  1
232528  99.426  -76.317  47.315  1
232529  99.444  -76.318  47.284  1
232530  99.459  -76.320  47.252  1
232531  99.475  -76.323  47.221  1
232532  99.490  -76.325  47.189  1
232533  99.509  -76.329  47.157  1
232534  99.538  -76.339  47.127  1
232535  99.567  -76.349  47.098  1
232536  99.596  -76.359  47.068  1
232537  99.626  -76.370  47.039  1
232538  99.659  -76.383  47.007  1
232539  99.691  -76.399  46.975  1
232540  99.723  -76.415  46.943  1
232541  99.756  -76.432  46.912  1
232542  99.787  -76.448  46.881  1
232543  99.820  -76.464  46.850  1
232544  99.851  -76.480  46.819  1
232545  99.884  -76.497  46.790  1
232546  99.915  -76.513  46.758  1
232547  99.937  -76.518  46.729  1
232548  99.957  -76.522  46.700  1
232549  99.977  -76.527  46.671  1
232550  99.995  -76.540  46.640  1
232551  100.013  -76.553  46.608  1
232552  100.031  -76.566  46.575  1
232553  100.050  -76.580  46.542  1
232554  100.068  -76.592  46.510  1
232555  100.087  -76.605  46.477  1
232556  100.105  -76.619  46.441  1
232557  100.123  -76.632  46.407  1
232558  100.142  -76.645  46.372  1
232559  100.160  -76.658  46.336  1
232560  100.178  -76.671  46.301  1
232561  100.207  -76.680  46.266  1
232562  100.225  -76.687  46.232  1
232563  100.244  -76.674  46.199  1
232564  100.263  -76.661  46.166  1
232565  100.282  -76.649  46.132  1
232566  100.301  -76.636  46.100  1
232567  100.320  -76.624  46.067  1
232568  100.339  -76.622  46.036  1
232569  100.359  -76.630  46.006  1
232570  100.379  -76.637  45.977  1
232571  100.398  -76.646  45.949  1
232572  100.418  -76.653  45.921  1
232573  100.437  -76.661  45.894  1
232574  100.457  -76.669  45.869  1
232575  100.476  -76.677  45.844  1
232576  100.496  -76.685  45.821  1
232577  100.515  -76.693  45.798  1
232578  100.535  -76.702  45.776  1
232579  100.554  -76.720  45.755  1
232580  100.598  -76.715  45.734  1
232581  100.632  -76.717  45.714  1
232582  100.656  -76.727  45.694  1
232583  100.680  -76.736  45.675  1
232584  100.704  -76.745  45.656  1
232585  100.727  -76.754  45.637  1
232586  100.752  -76.763  45.617  1
232587  100.775  -76.772  45.597  1
232588  100.799  -76.781  45.578  1
232589  100.823  -76.791  45.558  1
232590  100.849  -76.801  45.539  1
232591  100.877  -76.811  45.519  1
232592  100.905  -76.821  45.500  1
232593  100.933  -76.832  45.481  1
232594  100.961  -76.843  45.462  1
232595  100.989  -76.853  45.445  1
232596  101.003  -76.865  45.428  1
232597  101.018  -76.878  45.412  1
232598  101.033  -76.890  45.397  1
232599  101.048  -76.901  45.383  1
232600  101.062  -76.913  45.370  1
232601  101.077  -76.925  45.358  1
232602  101.092  -76.937  45.347  1
232603  101.107  -76.950  45.336  1
232604  101.121  -76.962  45.325  1
232605  101.140  -76.976  45.313  1
232606  101.169  -76.999  45.301  1
232607  101.197  -77.021  45.288  1
232608  101.227  -77.044  45.275  1
232609  101.255  -77.066  45.261  1
232610  101.284  -77.088  45.247  1
232611  101.313  -77.110  45.232  1
232612  101.342  -77.133  45.219  1
232613  101.362  -77.150  45.204  1
232614  101.378  -77.162  45.188  1
232615  101.392  -77.175  45.172  1
232616  101.407  -77.187  45.156  1
232617  101.424  -77.196  45.140  1
232618  101.447  -77.196  45.124  1
232619  101.470  -77.196  45.107  1
232620  101.492  -77.196  45.089  1
232621  101.516  -77.196  45.070  1
232622  101.534  -77.203  45.052  1
232623  101.553  -77.209  45.034  1
232624  101.571  -77.216  45.016  1
232625  101.590  -77.222  44.998  1
232626  101.608  -77.229  44.979  1
232627  101.627  -77.235  44.961  1
232628  101.645  -77.241  44.943  1
232629  101.664  -77.248  44.926  1
232630  101.682  -77.255  44.910  1
232631  101.701  -77.261  44.894  1
232632  101.720  -77.268  44.878  1
232633  101.738  -77.274  44.862  1
232634  101.757  -77.281  44.845  1
232635  101.775  -77.288  44.829  1
232636  101.795  -77.298  44.812  1
232637  101.814  -77.312  44.795  1
232638  101.837  -77.335  44.778  1
232639  101.860  -77.358  44.762  1
232640  101.882  -77.382  44.745  1
232641  101.902  -77.404  44.728  1
232642  101.921  -77.427  44.713  1
232643  101.941  -77.449  44.697  1
232644  101.961  -77.472  44.680  1
232645  101.980  -77.495  44.663  1
232646  102.000  -77.517  44.646  1
232647  102.026  -77.538  44.629  1
232648  102.083  -77.546  44.613  1
232649  102.111  -77.555  44.597  1
232650  102.131  -77.564  44.582  1
232651  102.152  -77.572  44.566  1
232652  102.172  -77.581  44.551  1
232653  102.192  -77.590  44.536  1
232654  102.212  -77.599  44.519  1
232655  102.240  -77.609  44.504  1
232656  102.272  -77.621  44.490  1
232657  102.305  -77.633  44.475  1
232658  102.337  -77.645  44.460  1
232659  102.355  -77.664  44.445  1
232660  102.370  -77.684  44.429  1
232661  102.389  -77.698  44.412  1
232662  102.414  -77.702  44.396  1
232663  102.440  -77.706  44.380  1
232664  102.466  -77.711  44.364  1
232665  102.491  -77.714  44.347  1
232666  102.517  -77.719  44.330  1
232667  102.542  -77.723  44.313  1
232668  102.568  -77.727  44.296  1
232669  102.594  -77.731  44.279  1
232670  102.625  -77.736  44.263  1
232671  102.662  -77.742  44.246  1
232672  102.698  -77.747  44.229  1
232673  102.734  -77.752  44.212  1
232674  102.770  -77.758  44.196  1
232675  102.807  -77.763  44.179  1
232676  102.843  -77.768  44.163  1
232677  102.879  -77.774  44.146  1
232678  102.915  -77.779  44.130  1
232679  102.952  -77.784  44.113  1
232680  102.988  -77.790  44.096  1
232681  103.025  -77.795  44.081  1
232682  103.061  -77.800  44.064  1
232683  103.097  -77.805  44.048  1
232684  103.134  -77.811  44.033  1
232685  103.170  -77.816  44.016  1
232686  103.206  -77.822  44.000  1
232938  92.182  -74.883  54.309  1
232939  92.207  -74.894  54.317  1
232940  92.231  -74.904  54.326  1
232941  92.256  -74.916  54.336  1
232942  92.280  -74.926  54.347  1
232943  92.304  -74.937  54.358  1
232944  92.329  -74.947  54.369  1
232945  92.353  -74.958  54.383  1
232946  92.378  -74.969  54.397  1
232947  92.402  -74.980  54.412  1
232948  92.427  -74.991  54.425  1
232949  92.444  -74.981  54.437  1
232950  92.464  -74.965  54.447  1
232951  92.497  -74.961  54.456  1
232952  92.530  -74.957  54.463  1
232953  92.564  -74.954  54.466  1
232954  92.596  -74.950  54.467  1
232955  92.630  -74.947  54.461  1
232956  92.662  -74.944  54.451  1
232957  92.695  -74.941  54.437  1
232958  92.726  -74.939  54.421  1
232959  92.755  -74.954  54.411  1
232960  92.783  -74.968  54.402  1
232961  92.811  -74.982  54.395  1
232962  92.841  -74.975  54.388  1
232963  92.871  -74.948  54.380  1
232964  92.901  -74.922  54.367  1
232965  92.932  -74.907  54.351  1
232966  92.966  -74.910  54.335  1
232967  92.997  -74.913  54.318  1
232968  93.023  -74.914  54.303  1
232969  93.049  -74.916  54.289  1
232970  93.075  -74.919  54.277  1
232971  93.100  -74.920  54.265  1
232972  93.127  -74.922  54.252  1
232973  93.152  -74.925  54.239  1
232974  93.178  -74.926  54.226  1
232975  93.204  -74.928  54.214  1
232976  93.230  -74.931  54.203  1
232977  93.255  -74.928  54.194  1
232978  93.277  -74.922  54.185  1
232979  93.300  -74.914  54.178  1
232980  93.323  -74.907  54.171  1
232981  93.346  -74.900  54.167  1
232982  93.369  -74.894  54.165  1
232983  93.392  -74.887  54.167  1
232984  93.415  -74.879  54.171  1
232985  93.438  -74.872  54.178  1
232986  93.461  -74.866  54.184  1
232987  93.484  -74.859  54.195  1
232988  93.506  -74.852  54.210  1
232989  93.530  -74.844  54.228  1
232990  93.552  -74.838  54.255  1
232991  93.580  -74.838  54.286  1
232992  93.609  -74.841  54.319  1
232993  93.638  -74.843  54.353  1
232994  93.666  -74.845  54.385  1
232995  93.696  -74.847  54.414  1
232996  93.724  -74.850  54.442  1
232997  93.757  -74.860  54.470  1
232998  93.790  -74.873  54.496  1
232999  93.823  -74.886  54.512  1
233000  93.847  -74.890  54.520  1
233001  93.865  -74.887  54.523  1
233002  93.883  -74.883  54.524  1
233003  93.900  -74.880  54.526  1
233004  93.922  -74.878  54.532  1
233005  93.947  -74.876  54.542  1
233006  93.974  -74.875  54.550  1
233007  94.000  -74.873  54.556  1
233008  94.026  -74.872  54.562  1
233009  94.054  -74.867  54.569  1
233010  94.082  -74.860  54.574  1
233011  94.111  -74.854  54.576  1
233012  94.139  -74.848  54.576  1
233013  94.166  -74.841  54.565  1
233014  94.193  -74.833  54.550  1
233015  94.218  -74.828  54.532  1
233016  94.240  -74.831  54.511  1
233017  94.261  -74.831  54.485  1
233018  94.282  -74.833  54.459  1
233019  94.303  -74.831  54.433  1
233020  94.325  -74.830  54.407  1
233021  94.346  -74.828  54.385  1
233022  94.368  -74.827  54.369  1
233023  94.390  -74.825  54.357  1
233024  94.411  -74.824  54.348  1
233025  94.427  -74.827  54.341  1
233026  94.440  -74.833  54.327  1
233027  94.453  -74.838  54.309  1
233028  94.466  -74.844  54.291  1
233029  94.479  -74.850  54.270  1
233030  94.492  -74.856  54.252  1
233031  94.505  -74.861  54.233  1
233032  94.522  -74.865  54.212  1
233033  94.541  -74.866  54.187  1
233034  94.560  -74.866  54.159  1
233035  94.579  -74.867  54.131  1
233036  94.598  -74.868  54.106  1
233037  94.618  -74.869  54.083  1
233038  94.638  -74.871  54.059  1
233039  94.659  -74.873  54.034  1
233040  94.678  -74.875  54.003  1
233041  94.699  -74.877  53.965  1
233042  94.724  -74.884  53.924  1
233043  94.753  -74.892  53.881  1
233044  94.780  -74.900  53.837  1
233045  94.809  -74.910  53.792  1
233046  94.836  -74.918  53.745  1
233047  94.864  -74.926  53.695  1
233048  94.892  -74.935  53.645  1
233049  94.907  -74.940  53.596  1
233050  94.922  -74.946  53.547  1
233051  94.938  -74.951  53.497  1
233052  94.954  -74.957  53.448  1
233053  94.969  -74.962  53.399  1
233054  94.984  -74.968  53.349  1
233055  94.995  -74.970  53.298  1
233056  94.989  -74.960  53.245  1
233057  94.983  -74.950  53.190  1
233058  94.978  -74.940  53.133  1
233059  94.978  -74.933  53.073  1
233060  95.010  -74.939  53.006  1
233061  95.042  -74.946  52.939  1
233062  95.073  -74.953  52.872  1
233063  95.106  -74.960  52.807  1
233064  95.137  -74.966  52.742  1
233065  95.169  -74.972  52.679  1
233066  95.197  -74.976  52.617  1
233067  95.222  -74.979  52.555  1
233068  95.248  -74.984  52.495  1
233069  95.275  -74.994  52.436  1
233070  95.303  -75.006  52.378  1
233071  95.330  -75.017  52.323  1
233072  95.358  -75.028  52.270  1
233073  95.385  -75.039  52.220  1
233074  95.406  -75.044  52.171  1
233075  95.421  -75.044  52.121  1
233076  95.435  -75.044  52.075  1
233077  95.450  -75.043  52.030  1
233078  95.464  -75.043  51.987  1
233079  95.478  -75.042  51.946  1
233080  95.492  -75.041  51.907  1
233081  95.507  -75.041  51.870  1
233082  95.521  -75.041  51.835  1
233083  95.539  -75.044  51.801  1
233084  95.574  -75.047  51.767  1
233085  95.615  -75.053  51.734  1
233086  95.656  -75.058  51.702  1
233087  95.696  -75.064  51.672  1
233088  95.737  -75.070  51.643  1
233089  95.778  -75.076  51.615  1
233090  95.819  -75.082  51.587  1
233091  95.860  -75.088  51.560  1
233092  95.901  -75.093  51.533  1
233093  95.941  -75.100  51.508  1
233094  95.976  -75.108  51.483  1
233095  96.012  -75.116  51.459  1
233096  96.048  -75.125  51.435  1
233097  96.083  -75.133  51.412  1
233098  96.119  -75.142  51.390  1
233099  96.155  -75.149  51.367  1
233100  96.186  -75.151  51.346  1
233101  96.218  -75.154  51.325  1
233102  96.249  -75.156  51.303  1
233103  96.281  -75.158  51.281  1
233104  96.312  -75.160  51.259  1
233105  96.343  -75.163  51.235  1
233106  96.371  -75.166  51.211  1
233107  96.398  -75.168  51.188  1
233108  96.426  -75.171  51.165  1
233109  96.453  -75.174  51.140  1
233110  96.480  -75.177  51.114  1
233111  96.500  -75.189  51.088  1
233112  96.518  -75.207  51.062  1
233113  96.536  -75.223  51.034  1
233114  96.553  -75.240  51.010  1
233115  96.571  -75.258  50.985  1
233116  96.593  -75.266  50.962  1
233117  96.616  -75.271  50.939  1
233118  96.639  -75.276  50.917  1
233119  96.662  -75.281  50.895  1
233120  96.685  -75.288  50.873  1
233121  96.710  -75.298  50.850  1
233122  96.735  -75.310  50.829  1
233123  96.760  -75.320  50.805  1
233124  96.785  -75.333  50.781  1
233125  96.798  -75.354  50.757  1
233126  96.811  -75.374  50.735  1
233127  96.825  -75.395  50.712  1
233128  96.838  -75.416  50.689  1
233129  96.855  -75.435  50.664  1
233130  96.879  -75.448  50.637  1
233131  96.902  -75.461  50.609  1
233132  96.927  -75.474  50.580  1
233133  96.951  -75.486  50.552  1
233134  96.974  -75.499  50.525  1
233135  96.999  -75.511  50.495  1
233136  97.023  -75.524  50.464  1
233137  97.061  -75.534  50.433  1
233138  97.125  -75.539  50.402  1
233139  97.175  -75.543  50.371  1
233140  97.199  -75.549  50.340  1
233141  97.224  -75.555  50.307  1
233142  97.248  -75.561  50.274  1
233143  97.272  -75.567  50.240  1
233144  97.296  -75.573  50.206  1
233145  97.321  -75.578  50.172  1
233146  97.345  -75.584  50.138  1
233147  97.363  -75.596  50.104  1
233148  97.380  -75.608  50.071  1
233149  97.397  -75.619  50.036  1
233150  97.414  -75.630  50.002  1
233151  97.437  -75.646  49.968  1
233152  97.459  -75.662  49.934  1
233153  97.485  -75.673  49.900  1
233154  97.517  -75.676  49.865  1
233155  97.548  -75.679  49.832  1
233156  97.581  -75.682  49.799  1
233157  97.612  -75.685  49.767  1
233158  97.644  -75.688  49.734  1
233159  97.676  -75.691  49.702  1
233160  97.708  -75.694  49.669  1
233161  97.740  -75.697  49.633  1
233162  97.772  -75.700  49.595  1
233163  97.804  -75.703  49.556  1
233164  97.837  -75.708  49.516  1
233165  97.870  -75.722  49.476  1
233166  97.899  -75.736  49.433  1
233167  97.902  -75.743  49.390  1
233168  97.907  -75.752  49.346  1
233169  97.926  -75.762  49.302  1
233170  97.945  -75.773  49.258  1
233171  97.959  -75.775  49.215  1
233172  97.991  -75.784  49.173  1
233173  98.009  -75.794  49.129  1
233174  98.030  -75.805  49.085  1
233175  98.049  -75.818  49.041  1
233176  98.067  -75.833  48.997  1
233177  98.085  -75.847  48.954  1
233178  98.104  -75.860  48.911  1
233179  98.122  -75.875  48.867  1
233180  98.141  -75.888  48.824  1
233181  98.186  -75.907  48.780  1
233182  98.232  -75.925  48.736  1
233183  98.278  -75.944  48.692  1
233184  98.322  -75.961  48.651  1
233185  98.362  -75.977  48.608  1
233186  98.402  -75.993  48.565  1
233187  98.442  -76.009  48.522  1
233188  98.482  -76.025  48.479  1
233189  98.522  -76.041  48.437  1
233190  98.536  -76.058  48.396  1
233191  98.548  -76.076  48.357  1
233192  98.560  -76.094  48.319  1
233193  98.586  -76.132  48.283  1
233194  98.627  -76.189  48.246  1
233195  98.663  -76.222  48.210  1
233196  98.695  -76.219  48.176  1
233197  98.727  -76.216  48.142  1
233198  98.755  -76.215  48.108  1
233199  98.780  -76.214  48.074  1
233200  98.806  -76.213  48.040  1
233201  98.832  -76.212  48.007  1
233202  98.857  -76.211  47.977  1
233203  98.883  -76.210  47.949  1
233204  98.909  -76.209  47.923  1
233205  98.934  -76.208  47.898  1
233206  98.959  -76.207  47.874  1
233207  98.985  -76.206  47.851  1
233208  99.011  -76.205  47.831  1
233209  99.037  -76.204  47.812  1
233210  99.063  -76.206  47.794  1
233211  99.088  -76.208  47.777  1
233212  99.115  -76.211  47.757  1
233213  99.139  -76.223  47.736  1
233214  99.163  -76.233  47.714  1
233215  99.187  -76.244  47.691  1
233216  99.211  -76.255  47.668  1
233217  99.235  -76.266  47.645  1
233218  99.260  -76.277  47.621  1
233219  99.284  -76.288  47.596  1
233220  99.308  -76.298  47.570  1
233221  99.332  -76.310  47.544  1
233222  99.354  -76.318  47.517  1
233223  99.362  -76.315  47.488  1
233224  99.370  -76.312  47.459  1
233225  99.378  -76.310  47.429  1
233226  99.394  -76.307  47.398  1
233227  99.416  -76.307  47.369  1
233228  99.438  -76.306  47.340  1
233229  99.455  -76.307  47.310  1
233230  99.470  -76.309  47.279  1
233231  99.485  -76.311  47.248  1
233232  99.500  -76.314  47.216  1
233233  99.516  -76.316  47.185  1
233234  99.531  -76.318  47.154  1
233235  99.555  -76.326  47.124  1
233236  99.584  -76.336  47.095  1
233237  99.614  -76.345  47.066  1
233238  99.642  -76.355  47.037  1
233239  99.666  -76.369  47.005  1
233240  99.698  -76.385  46.973  1
233241  99.730  -76.401  46.941  1
233242  99.762  -76.417  46.911  1
233243  99.794  -76.434  46.880  1
233244  99.826  -76.450  46.850  1
233245  99.858  -76.467  46.819  1
233246  99.890  -76.483  46.790  1
233247  99.918  -76.495  46.758  1
233248  99.938  -76.498  46.729  1
233249  99.958  -76.502  46.700  1
233250  99.978  -76.506  46.670  1
233251  99.996  -76.519  46.639  1
233252  100.014  -76.533  46.606  1
233253  100.033  -76.546  46.574  1
233254  100.051  -76.558  46.540  1
233255  100.069  -76.572  46.507  1
233256  100.088  -76.585  46.474  1
233257  100.106  -76.598  46.439  1
233258  100.125  -76.611  46.404  1
233259  100.143  -76.624  46.369  1
233260  100.161  -76.637  46.333  1
233261  100.198  -76.643  46.297  1
233262  100.227  -76.652  46.263  1
233263  100.245  -76.665  46.229  1
233264  100.262  -76.674  46.195  1
233265  100.281  -76.662  46.161  1
233266  100.300  -76.650  46.128  1
233267  100.319  -76.637  46.095  1
233268  100.338  -76.625  46.062  1
233269  100.357  -76.613  46.031  1
233270  100.376  -76.621  46.001  1
233271  100.396  -76.629  45.971  1
233272  100.415  -76.636  45.943  1
233273  100.435  -76.645  45.915  1
233274  100.455  -76.652  45.888  1
233275  100.474  -76.660  45.862  1
233276  100.494  -76.668  45.838  1
233277  100.513  -76.676  45.815  1
233278  100.533  -76.684  45.792  1
233279  100.552  -76.701  45.770  1
233280  100.578  -76.712  45.749  1
233281  100.623  -76.707  45.728  1
233282  100.662  -76.705  45.708  1
233283  100.687  -76.715  45.688  1
233284  100.710  -76.724  45.669  1
233285  100.735  -76.733  45.650  1
233286  100.758  -76.742  45.630  1
233287  100.782  -76.751  45.610  1
233288  100.806  -76.760  45.590  1
233289  100.830  -76.769  45.571  1
233290  100.854  -76.778  45.551  1
233291  100.880  -76.789  45.531  1
233292  100.908  -76.799  45.510  1
233293  100.936  -76.809  45.491  1
233294  100.964  -76.820  45.472  1
233295  100.992  -76.831  45.454  1
233296  101.017  -76.841  45.435  1
233297  101.032  -76.853  45.419  1
233298  101.047  -76.865  45.402  1
233299  101.061  -76.878  45.387  1
233300  101.076  -76.890  45.373  1
233301  101.091  -76.902  45.360  1
233302  101.106  -76.913  45.349  1
233303  101.120  -76.925  45.338  1
233304  101.135  -76.937  45.326  1
233305  101.149  -76.950  45.315  1
233306  101.165  -76.962  45.303  1
233307  101.179  -76.974  45.291  1
233308  101.207  -76.996  45.279  1
233309  101.236  -77.018  45.265  1
233310  101.265  -77.041  45.252  1
233311  101.294  -77.063  45.238  1
233312  101.323  -77.085  45.224  1
233313  101.352  -77.108  45.210  1
233314  101.376  -77.127  45.195  1
233315  101.392  -77.140  45.179  1
233316  101.406  -77.152  45.164  1
233317  101.421  -77.165  45.148  1
233318  101.441  -77.170  45.132  1
233319  101.463  -77.170  45.116  1
233320  101.486  -77.171  45.099  1
233321  101.509  -77.171  45.080  1
233322  101.532  -77.171  45.062  1
233323  101.551  -77.175  45.044  1
233324  101.570  -77.182  45.027  1
233325  101.588  -77.189  45.008  1
233326  101.607  -77.195  44.990  1
233327  101.625  -77.202  44.972  1
233328  101.644  -77.208  44.953  1
233329  101.663  -77.215  44.936  1
233330  101.681  -77.222  44.919  1
233331  101.699  -77.228  44.903  1
233332  101.718  -77.235  44.887  1
233333  101.737  -77.241  44.871  1
233334  101.755  -77.248  44.855  1
233335  101.774  -77.255  44.840  1
233336  101.793  -77.269  44.823  1
233337  101.813  -77.282  44.806  1
233338  101.833  -77.297  44.789  1
233339  101.856  -77.320  44.772  1
233340  101.880  -77.344  44.755  1
233341  101.903  -77.368  44.738  1
233342  101.926  -77.392  44.721  1
233343  101.947  -77.415  44.705  1
233344  101.967  -77.437  44.689  1
233345  101.986  -77.460  44.673  1
233346  102.006  -77.483  44.658  1
233347  102.026  -77.505  44.640  1
233348  102.055  -77.524  44.623  1
233349  102.103  -77.533  44.607  1
233350  102.123  -77.542  44.592  1
233351  102.144  -77.550  44.575  1
233352  102.164  -77.559  44.560  1
233353  102.184  -77.568  44.544  1
233354  102.204  -77.577  44.529  1
233355  102.225  -77.586  44.512  1
233356  102.248  -77.595  44.497  1
233357  102.280  -77.607  44.482  1
233358  102.313  -77.618  44.468  1
233359  102.345  -77.630  44.452  1
233360  102.362  -77.649  44.436  1
233361  102.377  -77.671  44.420  1
233362  102.399  -77.679  44.403  1
233363  102.425  -77.683  44.388  1
233364  102.451  -77.687  44.372  1
233365  102.476  -77.692  44.356  1
233366  102.501  -77.696  44.339  1
233367  102.527  -77.700  44.321  1
233368  102.553  -77.704  44.304  1
233369  102.579  -77.708  44.287  1
233370  102.613  -77.713  44.271  1
233371  102.650  -77.719  44.254  1
233372  102.686  -77.724  44.237  1
233373  102.722  -77.730  44.219  1
233374  102.759  -77.735  44.203  1
233375  102.795  -77.740  44.186  1
233376  102.831  -77.746  44.170  1
233377  102.868  -77.751  44.153  1
233378  102.904  -77.756  44.136  1
233379  102.940  -77.761  44.121  1
233380  102.976  -77.767  44.104  1
233381  103.013  -77.772  44.087  1
233382  103.049  -77.777  44.072  1
233383  103.086  -77.783  44.055  1
233384  103.122  -77.788  44.039  1
233385  103.158  -77.793  44.023  1
233386  103.194  -77.799  44.007  1
233640  92.209  -74.861  54.321  1
233641  92.233  -74.872  54.329  1
233642  92.258  -74.883  54.338  1
233643  92.282  -74.894  54.349  1
233644  92.306  -74.904  54.359  1
233645  92.331  -74.915  54.371  1
233646  92.355  -74.926  54.384  1
233647  92.379  -74.937  54.399  1
233648  92.404  -74.947  54.413  1
233649  92.428  -74.958  54.426  1
233650  92.449  -74.957  54.438  1
233651  92.463  -74.936  54.448  1
233652  92.493  -74.928  54.456  1
233653  92.525  -74.925  54.464  1
233654  92.559  -74.922  54.469  1
233655  92.592  -74.918  54.472  1
233656  92.625  -74.914  54.468  1
233657  92.658  -74.911  54.460  1
233658  92.690  -74.909  54.449  1
233659  92.722  -74.906  54.438  1
233660  92.754  -74.906  54.429  1
233661  92.782  -74.920  54.424  1
233662  92.810  -74.935  54.418  1
233663  92.840  -74.919  54.410  1
233664  92.870  -74.892  54.401  1
233665  92.902  -74.882  54.387  1
233666  92.935  -74.885  54.369  1
233667  92.969  -74.888  54.352  1
233668  93.003  -74.892  54.336  1
233669  93.034  -74.894  54.321  1
233670  93.060  -74.897  54.308  1
233671  93.085  -74.899  54.295  1
233672  93.111  -74.900  54.284  1
233673  93.137  -74.903  54.272  1
233674  93.163  -74.905  54.259  1
233675  93.189  -74.907  54.247  1
233676  93.213  -74.906  54.236  1
233677  93.236  -74.898  54.226  1
233678  93.259  -74.891  54.216  1
233679  93.282  -74.885  54.209  1
233680  93.305  -74.878  54.201  1
233681  93.328  -74.871  54.195  1
233682  93.351  -74.863  54.192  1
233683  93.374  -74.856  54.191  1
233684  93.397  -74.850  54.192  1
233685  93.420  -74.843  54.196  1
233686  93.443  -74.836  54.201  1
233687  93.466  -74.828  54.208  1
233688  93.489  -74.822  54.218  1
233689  93.511  -74.815  54.232  1
233690  93.535  -74.808  54.249  1
233691  93.557  -74.801  54.272  1
233692  93.585  -74.801  54.300  1
233693  93.614  -74.803  54.330  1
233694  93.643  -74.806  54.362  1
233695  93.672  -74.808  54.395  1
233696  93.700  -74.810  54.426  1
233697  93.732  -74.819  54.455  1
233698  93.765  -74.832  54.482  1
233699  93.798  -74.845  54.507  1
233700  93.831  -74.858  54.523  1
233701  93.860  -74.866  54.531  1
233702  93.877  -74.863  54.533  1
233703  93.895  -74.859  54.533  1
233704  93.913  -74.856  54.536  1
233705  93.931  -74.853  54.542  1
233706  93.948  -74.850  54.553  1
233707  93.973  -74.849  54.561  1
233708  93.998  -74.847  54.568  1
233709  94.025  -74.844  54.575  1
233710  94.054  -74.838  54.581  1
233711  94.081  -74.831  54.585  1
233712  94.109  -74.824  54.588  1
233713  94.135  -74.816  54.586  1
233714  94.162  -74.809  54.576  1
233715  94.189  -74.802  54.561  1
233716  94.210  -74.803  54.542  1
233717  94.232  -74.806  54.521  1
233718  94.253  -74.807  54.495  1
233719  94.274  -74.809  54.468  1
233720  94.296  -74.810  54.440  1
233721  94.318  -74.809  54.410  1
233722  94.339  -74.808  54.386  1
233723  94.361  -74.806  54.367  1
233724  94.383  -74.805  54.351  1
233725  94.403  -74.804  54.338  1
233726  94.416  -74.810  54.329  1
233727  94.429  -74.816  54.315  1
233728  94.442  -74.822  54.298  1
233729  94.455  -74.828  54.278  1
233730  94.469  -74.832  54.259  1
233731  94.486  -74.836  54.241  1
233732  94.503  -74.839  54.222  1
233733  94.521  -74.842  54.202  1
233734  94.542  -74.844  54.178  1
233735  94.561  -74.844  54.152  1
233736  94.580  -74.844  54.126  1
233737  94.600  -74.844  54.102  1
233738  94.619  -74.844  54.083  1
233739  94.638  -74.844  54.064  1
233740  94.657  -74.844  54.042  1
233741  94.676  -74.844  54.013  1
233742  94.704  -74.852  53.980  1
233743  94.732  -74.860  53.941  1
233744  94.760  -74.869  53.898  1
233745  94.788  -74.877  53.853  1
233746  94.816  -74.885  53.808  1
233747  94.844  -74.894  53.760  1
233748  94.872  -74.903  53.710  1
233749  94.900  -74.911  53.661  1
233750  94.921  -74.918  53.611  1
233751  94.936  -74.923  53.561  1
233752  94.952  -74.929  53.512  1
233753  94.967  -74.935  53.463  1
233754  94.983  -74.940  53.415  1
233755  94.998  -74.946  53.366  1
233756  95.000  -74.941  53.316  1
233757  94.994  -74.932  53.262  1
233758  94.988  -74.922  53.206  1
233759  94.982  -74.911  53.146  1
233760  94.983  -74.904  53.084  1
233761  95.015  -74.911  53.016  1
233762  95.047  -74.918  52.949  1
233763  95.079  -74.925  52.882  1
233764  95.111  -74.931  52.817  1
233765  95.143  -74.938  52.753  1
233766  95.175  -74.944  52.690  1
233767  95.206  -74.950  52.627  1
233768  95.232  -74.953  52.566  1
233769  95.258  -74.960  52.506  1
233770  95.285  -74.971  52.447  1
233771  95.313  -74.982  52.389  1
233772  95.341  -74.994  52.332  1
233773  95.368  -75.004  52.278  1
233774  95.396  -75.016  52.226  1
233775  95.423  -75.026  52.176  1
233776  95.437  -75.026  52.126  1
233777  95.451  -75.026  52.079  1
233778  95.466  -75.025  52.034  1
233779  95.480  -75.025  51.989  1
233780  95.494  -75.024  51.947  1
233781  95.509  -75.023  51.909  1
233782  95.523  -75.023  51.872  1
233783  95.540  -75.019  51.836  1
233784  95.557  -75.012  51.802  1
233785  95.589  -75.024  51.768  1
233786  95.630  -75.030  51.735  1
233787  95.671  -75.036  51.703  1
233788  95.711  -75.041  51.673  1
233789  95.752  -75.048  51.644  1
233790  95.794  -75.054  51.615  1
233791  95.834  -75.059  51.587  1
233792  95.875  -75.065  51.559  1
233793  95.916  -75.071  51.532  1
233794  95.955  -75.077  51.507  1
233795  95.990  -75.085  51.483  1
233796  96.026  -75.094  51.458  1
233797  96.062  -75.102  51.435  1
233798  96.098  -75.110  51.413  1
233799  96.133  -75.119  51.391  1
233800  96.165  -75.121  51.370  1
233801  96.196  -75.123  51.349  1
233802  96.228  -75.125  51.329  1
233803  96.259  -75.127  51.307  1
233804  96.291  -75.129  51.286  1
233805  96.322  -75.132  51.264  1
233806  96.354  -75.134  51.241  1
233807  96.383  -75.136  51.218  1
233808  96.411  -75.139  51.196  1
233809  96.438  -75.142  51.173  1
233810  96.466  -75.145  51.148  1
233811  96.488  -75.154  51.122  1
233812  96.503  -75.170  51.096  1
233813  96.520  -75.187  51.070  1
233814  96.538  -75.204  51.043  1
233815  96.556  -75.220  51.019  1
233816  96.576  -75.234  50.995  1
233817  96.598  -75.239  50.971  1
233818  96.621  -75.244  50.949  1
233819  96.644  -75.249  50.927  1
233820  96.669  -75.259  50.905  1
233821  96.694  -75.270  50.883  1
233822  96.719  -75.281  50.861  1
233823  96.744  -75.292  50.839  1
233824  96.769  -75.303  50.816  1
233825  96.795  -75.314  50.793  1
233826  96.813  -75.331  50.770  1
233827  96.826  -75.352  50.748  1
233828  96.840  -75.373  50.726  1
233829  96.854  -75.394  50.703  1
233830  96.876  -75.408  50.678  1
233831  96.900  -75.420  50.651  1
233832  96.924  -75.433  50.623  1
233833  96.948  -75.446  50.595  1
233834  96.972  -75.459  50.566  1
233835  96.996  -75.472  50.537  1
233836  97.020  -75.485  50.507  1
233837  97.044  -75.498  50.476  1
233838  97.071  -75.510  50.445  1
233839  97.136  -75.514  50.414  1
233840  97.185  -75.519  50.383  1
233841  97.209  -75.525  50.351  1
233842  97.234  -75.530  50.318  1
233843  97.258  -75.536  50.285  1
233844  97.282  -75.543  50.251  1
233845  97.306  -75.549  50.217  1
233846  97.331  -75.554  50.183  1
233847  97.348  -75.566  50.151  1
233848  97.365  -75.577  50.118  1
233849  97.383  -75.589  50.085  1
233850  97.400  -75.601  50.052  1
233851  97.417  -75.612  50.018  1
233852  97.440  -75.627  49.984  1
233853  97.464  -75.641  49.949  1
233854  97.496  -75.644  49.916  1
233855  97.528  -75.647  49.881  1
233856  97.560  -75.650  49.847  1
233857  97.591  -75.653  49.815  1
233858  97.624  -75.656  49.782  1
233859  97.655  -75.659  49.749  1
233860  97.687  -75.662  49.716  1
233861  97.719  -75.665  49.683  1
233862  97.743  -75.669  49.646  1
233863  97.768  -75.673  49.608  1
233864  97.793  -75.677  49.568  1
233865  97.819  -75.683  49.527  1
233866  97.852  -75.695  49.486  1
233867  97.878  -75.706  49.442  1
233868  97.897  -75.717  49.398  1
233869  97.917  -75.728  49.352  1
233870  97.936  -75.739  49.308  1
233871  97.954  -75.748  49.263  1
233872  97.978  -75.752  49.219  1
233873  98.013  -75.761  49.176  1
233874  98.030  -75.771  49.132  1
233875  98.049  -75.782  49.088  1
233876  98.070  -75.792  49.043  1
233877  98.090  -75.803  48.999  1
233878  98.109  -75.818  48.956  1
233879  98.127  -75.831  48.913  1
233880  98.146  -75.846  48.869  1
233881  98.164  -75.859  48.825  1
233882  98.196  -75.875  48.781  1
233883  98.242  -75.894  48.737  1
233884  98.288  -75.912  48.693  1
233885  98.330  -75.929  48.650  1
233886  98.370  -75.945  48.607  1
233887  98.410  -75.961  48.564  1
233888  98.450  -75.977  48.521  1
233889  98.490  -75.993  48.479  1
233890  98.530  -76.009  48.436  1
233891  98.552  -76.026  48.395  1
233892  98.564  -76.044  48.355  1
233893  98.577  -76.063  48.316  1
233894  98.617  -76.120  48.279  1
233895  98.657  -76.178  48.242  1
233896  98.693  -76.200  48.206  1
233897  98.724  -76.197  48.171  1
233898  98.752  -76.195  48.136  1
233899  98.778  -76.195  48.102  1
233900  98.803  -76.194  48.068  1
233901  98.829  -76.192  48.034  1
233902  98.855  -76.191  48.001  1
233903  98.880  -76.191  47.970  1
233904  98.906  -76.189  47.941  1
233905  98.932  -76.188  47.915  1
233906  98.957  -76.188  47.889  1
233907  98.983  -76.186  47.865  1
233908  99.008  -76.185  47.841  1
233909  99.034  -76.185  47.821  1
233910  99.060  -76.183  47.801  1
233911  99.085  -76.184  47.782  1
233912  99.112  -76.186  47.764  1
233913  99.136  -76.194  47.745  1
233914  99.160  -76.204  47.725  1
233915  99.185  -76.216  47.703  1
233916  99.209  -76.226  47.681  1
233917  99.233  -76.237  47.657  1
233918  99.257  -76.248  47.633  1
233919  99.281  -76.259  47.609  1
233920  99.305  -76.270  47.584  1
233921  99.330  -76.281  47.557  1
233922  99.354  -76.292  47.531  1
233923  99.378  -76.303  47.505  1
233924  99.389  -76.302  47.479  1
233925  99.397  -76.299  47.450  1
233926  99.406  -76.296  47.421  1
233927  99.428  -76.295  47.391  1
233928  99.450  -76.295  47.362  1
233929  99.466  -76.296  47.334  1
233930  99.481  -76.298  47.304  1
233931  99.496  -76.301  47.274  1
233932  99.511  -76.303  47.243  1
233933  99.526  -76.305  47.212  1
233934  99.542  -76.307  47.181  1
233935  99.557  -76.310  47.150  1
233936  99.572  -76.312  47.121  1
233937  99.602  -76.322  47.091  1
233938  99.631  -76.332  47.062  1
233939  99.659  -76.342  47.032  1
233940  99.679  -76.355  47.000  1
233941  99.705  -76.371  46.969  1
233942  99.737  -76.387  46.938  1
233943  99.769  -76.404  46.907  1
233944  99.801  -76.420  46.877  1
233945  99.833  -76.436  46.846  1
233946  99.865  -76.453  46.816  1
233947  99.897  -76.469  46.786  1
233948  99.919  -76.474  46.755  1
233949  99.939  -76.478  46.726  1
233950  99.959  -76.481  46.697  1
233951  99.979  -76.486  46.667  1
233952  99.997  -76.499  46.636  1
233953  100.016  -76.511  46.603  1
233954  100.034  -76.525  46.570  1
233955  100.052  -76.538  46.537  1
233956  100.071  -76.551  46.503  1
233957  100.089  -76.564  46.469  1
233958  100.108  -76.577  46.436  1
233959  100.126  -76.590  46.401  1
233960  100.149  -76.602  46.365  1
233961  100.187  -76.607  46.329  1
233962  100.225  -76.612  46.293  1
233963  100.247  -76.624  46.259  1
233964  100.264  -76.636  46.224  1
233965  100.281  -76.649  46.190  1
233966  100.298  -76.661  46.156  1
233967  100.318  -76.651  46.122  1
233968  100.337  -76.638  46.089  1
233969  100.355  -76.626  46.056  1
233970  100.374  -76.614  46.025  1
233971  100.394  -76.612  45.994  1
233972  100.413  -76.620  45.965  1
233973  100.433  -76.628  45.936  1
233974  100.453  -76.636  45.908  1
233975  100.472  -76.644  45.881  1
233976  100.491  -76.652  45.855  1
233977  100.511  -76.659  45.830  1
233978  100.531  -76.668  45.807  1
233979  100.550  -76.682  45.784  1
233980  100.569  -76.701  45.763  1
233981  100.604  -76.704  45.742  1
233982  100.649  -76.699  45.721  1
233983  100.694  -76.693  45.702  1
233984  100.717  -76.702  45.682  1
233985  100.741  -76.712  45.663  1
233986  100.765  -76.721  45.644  1
233987  100.789  -76.730  45.623  1
233988  100.813  -76.739  45.603  1
233989  100.837  -76.748  45.583  1
233990  100.861  -76.757  45.563  1
233991  100.885  -76.766  45.543  1
233992  100.911  -76.777  45.523  1
233993  100.939  -76.787  45.502  1
233994  100.967  -76.797  45.483  1
233995  100.995  -76.808  45.464  1
233996  101.022  -76.818  45.445  1
233997  101.045  -76.830  45.426  1
233998  101.060  -76.842  45.409  1
233999  101.075  -76.853  45.393  1
234000  101.090  -76.865  45.378  1
234001  101.104  -76.878  45.364  1
234002  101.119  -76.890  45.351  1
234003  101.134  -76.902  45.340  1
234004  101.148  -76.914  45.329  1
234005  101.163  -76.926  45.317  1
234006  101.178  -76.937  45.306  1
234007  101.193  -76.950  45.294  1
234008  101.207  -76.962  45.282  1
234009  101.222  -76.974  45.269  1
234010  101.246  -76.993  45.256  1
234011  101.275  -77.016  45.242  1
234012  101.304  -77.038  45.229  1
234013  101.333  -77.060  45.215  1
234014  101.362  -77.082  45.201  1
234015  101.391  -77.105  45.186  1
234016  101.406  -77.117  45.171  1
234017  101.421  -77.130  45.156  1
234018  101.435  -77.142  45.141  1
234019  101.457  -77.145  45.125  1
234020  101.479  -77.145  45.109  1
234021  101.502  -77.145  45.091  1
234022  101.525  -77.145  45.072  1
234023  101.548  -77.145  45.054  1
234024  101.568  -77.149  45.037  1
234025  101.587  -77.156  45.019  1
234026  101.605  -77.162  45.000  1
234027  101.624  -77.169  44.981  1
234028  101.642  -77.175  44.964  1
234029  101.661  -77.182  44.946  1
234030  101.680  -77.188  44.930  1
234031  101.698  -77.194  44.913  1
234032  101.716  -77.201  44.897  1
234033  101.735  -77.208  44.881  1
234034  101.754  -77.214  44.866  1
234035  101.773  -77.226  44.850  1
234036  101.793  -77.240  44.834  1
234037  101.813  -77.254  44.817  1
234038  101.832  -77.267  44.800  1
234039  101.852  -77.282  44.783  1
234040  101.876  -77.306  44.767  1
234041  101.899  -77.330  44.750  1
234042  101.922  -77.354  44.732  1
234043  101.945  -77.377  44.715  1
234044  101.969  -77.401  44.699  1
234045  101.992  -77.425  44.683  1
234046  102.013  -77.448  44.667  1
234047  102.032  -77.470  44.652  1
234048  102.052  -77.493  44.635  1
234049  102.085  -77.511  44.618  1
234050  102.115  -77.520  44.602  1
234051  102.135  -77.528  44.586  1
234052  102.156  -77.537  44.569  1
234053  102.176  -77.546  44.553  1
234054  102.196  -77.555  44.538  1
234055  102.217  -77.564  44.522  1
234056  102.237  -77.573  44.506  1
234057  102.257  -77.581  44.490  1
234058  102.287  -77.592  44.475  1
234059  102.320  -77.604  44.460  1
234060  102.352  -77.616  44.444  1
234061  102.369  -77.636  44.428  1
234062  102.384  -77.655  44.411  1
234063  102.410  -77.660  44.395  1
234064  102.436  -77.664  44.379  1
234065  102.461  -77.668  44.364  1
234066  102.486  -77.672  44.347  1
234067  102.512  -77.677  44.330  1
234068  102.538  -77.680  44.312  1
234069  102.565  -77.685  44.294  1
234070  102.602  -77.690  44.277  1
234071  102.638  -77.696  44.260  1
234072  102.674  -77.701  44.244  1
234073  102.711  -77.706  44.227  1
234074  102.747  -77.711  44.210  1
234075  102.783  -77.717  44.193  1
234076  102.820  -77.722  44.177  1
234077  102.856  -77.728  44.161  1
234078  102.892  -77.733  44.145  1
234079  102.929  -77.739  44.128  1
234080  102.965  -77.744  44.112  1
234081  103.001  -77.749  44.095  1
234082  103.037  -77.755  44.078  1
234083  103.074  -77.760  44.063  1
234084  103.110  -77.765  44.047  1
234085  103.147  -77.771  44.031  1
234086  103.183  -77.776  44.014  1
234341  92.211  -74.829  54.325  1
234342  92.235  -74.840  54.333  1
234343  92.260  -74.850  54.342  1
234344  92.284  -74.861  54.351  1
234345  92.308  -74.872  54.362  1
234346  92.333  -74.883  54.372  1
234347  92.357  -74.894  54.385  1
234348  92.381  -74.904  54.399  1
234349  92.406  -74.915  54.413  1
234350  92.430  -74.925  54.426  1
234351  92.453  -74.933  54.438  1
234352  92.466  -74.910  54.448  1
234353  92.492  -74.900  54.455  1
234354  92.521  -74.892  54.463  1
234355  92.554  -74.889  54.470  1
234356  92.587  -74.885  54.474  1
234357  92.621  -74.881  54.473  1
234358  92.653  -74.878  54.469  1
234359  92.685  -74.876  54.462  1
234360  92.717  -74.873  54.454  1
234361  92.749  -74.870  54.448  1
234362  92.780  -74.873  54.444  1
234363  92.808  -74.888  54.440  1
234364  92.839  -74.863  54.431  1
234365  92.871  -74.858  54.420  1
234366  92.905  -74.861  54.404  1
234367  92.939  -74.864  54.386  1
234368  92.972  -74.868  54.369  1
234369  93.006  -74.871  54.354  1
234370  93.040  -74.874  54.341  1
234371  93.070  -74.877  54.328  1
234372  93.096  -74.879  54.316  1
234373  93.122  -74.881  54.304  1
234374  93.148  -74.883  54.293  1
234375  93.172  -74.882  54.281  1
234376  93.196  -74.875  54.269  1
234377  93.218  -74.869  54.258  1
234378  93.241  -74.862  54.249  1
234379  93.264  -74.854  54.239  1
234380  93.287  -74.847  54.233  1
234381  93.310  -74.841  54.226  1
234382  93.333  -74.834  54.221  1
234383  93.356  -74.827  54.218  1
234384  93.379  -74.819  54.216  1
234385  93.402  -74.812  54.218  1
234386  93.425  -74.806  54.222  1
234387  93.448  -74.799  54.228  1
234388  93.471  -74.792  54.233  1
234389  93.494  -74.784  54.243  1
234390  93.516  -74.778  54.255  1
234391  93.540  -74.771  54.270  1
234392  93.562  -74.764  54.290  1
234393  93.590  -74.765  54.314  1
234394  93.619  -74.767  54.341  1
234395  93.648  -74.769  54.368  1
234396  93.677  -74.771  54.401  1
234397  93.708  -74.778  54.433  1
234398  93.741  -74.791  54.465  1
234399  93.774  -74.804  54.495  1
234400  93.806  -74.817  54.518  1
234401  93.839  -74.829  54.535  1
234402  93.872  -74.842  54.544  1
234403  93.891  -74.839  54.545  1
234404  93.908  -74.836  54.543  1
234405  93.926  -74.833  54.546  1
234406  93.944  -74.830  54.553  1
234407  93.962  -74.827  54.563  1
234408  93.979  -74.824  54.571  1
234409  93.997  -74.821  54.579  1
234410  94.024  -74.815  54.586  1
234411  94.051  -74.807  54.591  1
234412  94.078  -74.800  54.597  1
234413  94.105  -74.792  54.599  1
234414  94.131  -74.784  54.598  1
234415  94.158  -74.777  54.588  1
234416  94.181  -74.777  54.573  1
234417  94.203  -74.779  54.555  1
234418  94.224  -74.781  54.534  1
234419  94.246  -74.783  54.507  1
234420  94.267  -74.784  54.479  1
234421  94.289  -74.786  54.449  1
234422  94.311  -74.787  54.417  1
234423  94.333  -74.787  54.391  1
234424  94.354  -74.786  54.369  1
234425  94.376  -74.784  54.349  1
234426  94.392  -74.787  54.332  1
234427  94.405  -74.794  54.319  1
234428  94.418  -74.799  54.303  1
234429  94.433  -74.803  54.285  1
234430  94.451  -74.806  54.265  1
234431  94.468  -74.809  54.246  1
234432  94.485  -74.812  54.227  1
234433  94.503  -74.816  54.209  1
234434  94.522  -74.819  54.190  1
234435  94.543  -74.821  54.166  1
234436  94.563  -74.822  54.141  1
234437  94.582  -74.822  54.116  1
234438  94.601  -74.822  54.094  1
234439  94.620  -74.822  54.077  1
234440  94.639  -74.822  54.061  1
234441  94.659  -74.822  54.042  1
234442  94.683  -74.825  54.016  1
234443  94.711  -74.831  53.985  1
234444  94.739  -74.838  53.948  1
234445  94.767  -74.845  53.908  1
234446  94.795  -74.853  53.864  1
234447  94.823  -74.862  53.819  1
234448  94.851  -74.871  53.771  1
234449  94.879  -74.879  53.722  1
234450  94.907  -74.888  53.672  1
234451  94.934  -74.896  53.622  1
234452  94.950  -74.901  53.573  1
234453  94.966  -74.907  53.524  1
234454  94.981  -74.913  53.475  1
234455  94.996  -74.918  53.428  1
234456  95.011  -74.922  53.380  1
234457  95.004  -74.913  53.329  1
234458  94.998  -74.903  53.275  1
234459  94.993  -74.893  53.218  1
234460  94.987  -74.883  53.157  1
234461  94.989  -74.876  53.093  1
234462  95.021  -74.883  53.024  1
234463  95.053  -74.890  52.956  1
234464  95.085  -74.896  52.889  1
234465  95.117  -74.903  52.824  1
234466  95.148  -74.910  52.761  1
234467  95.181  -74.916  52.699  1
234468  95.212  -74.922  52.637  1
234469  95.242  -74.927  52.577  1
234470  95.268  -74.937  52.518  1
234471  95.296  -74.947  52.459  1
234472  95.324  -74.959  52.400  1
234473  95.351  -74.970  52.341  1
234474  95.379  -74.981  52.285  1
234475  95.406  -74.992  52.232  1
234476  95.433  -75.004  52.182  1
234477  95.453  -75.007  52.132  1
234478  95.468  -75.007  52.084  1
234479  95.482  -75.007  52.038  1
234480  95.496  -75.006  51.992  1
234481  95.512  -75.004  51.950  1
234482  95.529  -74.997  51.911  1
234483  95.547  -74.991  51.873  1
234484  95.565  -74.985  51.837  1
234485  95.583  -74.978  51.803  1
234486  95.605  -74.977  51.769  1
234487  95.645  -75.003  51.736  1
234488  95.686  -75.013  51.704  1
234489  95.727  -75.019  51.675  1
234490  95.768  -75.025  51.645  1
234491  95.809  -75.031  51.616  1
234492  95.849  -75.037  51.588  1
234493  95.890  -75.042  51.560  1
234494  95.931  -75.048  51.532  1
234495  95.969  -75.055  51.507  1
234496  96.005  -75.063  51.483  1
234497  96.041  -75.072  51.458  1
234498  96.077  -75.080  51.435  1
234499  96.112  -75.088  51.413  1
234500  96.143  -75.090  51.392  1
234501  96.175  -75.092  51.371  1
234502  96.206  -75.095  51.351  1
234503  96.238  -75.097  51.332  1
234504  96.269  -75.099  51.312  1
234505  96.301  -75.101  51.290  1
234506  96.332  -75.103  51.268  1
234507  96.364  -75.105  51.247  1
234508  96.395  -75.107  51.225  1
234509  96.424  -75.110  51.204  1
234510  96.451  -75.113  51.181  1
234511  96.476  -75.119  51.156  1
234512  96.491  -75.135  51.131  1
234513  96.507  -75.151  51.104  1
234514  96.523  -75.167  51.077  1
234515  96.541  -75.184  51.052  1
234516  96.558  -75.201  51.028  1
234517  96.581  -75.207  51.004  1
234518  96.604  -75.212  50.982  1
234519  96.627  -75.220  50.960  1
234520  96.653  -75.231  50.938  1
234521  96.678  -75.242  50.916  1
234522  96.703  -75.253  50.894  1
234523  96.729  -75.264  50.871  1
234524  96.754  -75.275  50.850  1
234525  96.779  -75.286  50.828  1
234526  96.804  -75.297  50.806  1
234527  96.828  -75.309  50.784  1
234528  96.841  -75.330  50.762  1
234529  96.855  -75.351  50.741  1
234530  96.873  -75.368  50.718  1
234531  96.897  -75.381  50.693  1
234532  96.921  -75.394  50.665  1
234533  96.945  -75.407  50.638  1
234534  96.969  -75.420  50.610  1
234535  96.993  -75.433  50.581  1
234536  97.017  -75.446  50.550  1
234537  97.041  -75.458  50.520  1
234538  97.065  -75.471  50.489  1
234539  97.089  -75.483  50.459  1
234540  97.145  -75.489  50.427  1
234541  97.195  -75.495  50.395  1
234542  97.219  -75.500  50.363  1
234543  97.244  -75.506  50.330  1
234544  97.268  -75.512  50.296  1
234545  97.292  -75.518  50.263  1
234546  97.316  -75.524  50.230  1
234547  97.333  -75.536  50.197  1
234548  97.351  -75.547  50.165  1
234549  97.368  -75.559  50.133  1
234550  97.385  -75.571  50.101  1
234551  97.403  -75.582  50.069  1
234552  97.420  -75.594  50.035  1
234553  97.443  -75.609  50.001  1
234554  97.475  -75.612  49.967  1
234555  97.507  -75.615  49.932  1
234556  97.539  -75.618  49.898  1
234557  97.571  -75.621  49.864  1
234558  97.597  -75.624  49.830  1
234559  97.621  -75.628  49.797  1
234560  97.646  -75.632  49.764  1
234561  97.671  -75.637  49.731  1
234562  97.696  -75.640  49.696  1
234563  97.720  -75.644  49.660  1
234564  97.745  -75.648  49.621  1
234565  97.770  -75.652  49.580  1
234566  97.796  -75.658  49.539  1
234567  97.828  -75.670  49.497  1
234568  97.886  -75.675  49.453  1
234569  97.908  -75.693  49.408  1
234570  97.927  -75.705  49.360  1
234571  97.947  -75.715  49.315  1
234572  97.963  -75.724  49.270  1
234573  97.996  -75.729  49.226  1
234574  98.035  -75.738  49.182  1
234575  98.053  -75.749  49.137  1
234576  98.070  -75.759  49.092  1
234577  98.088  -75.769  49.047  1
234578  98.110  -75.780  49.004  1
234579  98.131  -75.790  48.960  1
234580  98.151  -75.803  48.916  1
234581  98.169  -75.816  48.873  1
234582  98.187  -75.831  48.829  1
234583  98.206  -75.844  48.784  1
234584  98.251  -75.862  48.739  1
234585  98.297  -75.881  48.695  1
234586  98.339  -75.897  48.650  1
234587  98.378  -75.913  48.607  1
234588  98.419  -75.929  48.564  1
234589  98.458  -75.945  48.522  1
234590  98.499  -75.961  48.479  1
234591  98.538  -75.977  48.436  1
234592  98.568  -75.994  48.395  1
234593  98.579  -76.011  48.354  1
234594  98.607  -76.051  48.314  1
234595  98.648  -76.109  48.277  1
234596  98.688  -76.166  48.240  1
234597  98.722  -76.177  48.203  1
234598  98.749  -76.176  48.167  1
234599  98.775  -76.175  48.132  1
234600  98.801  -76.174  48.097  1
234601  98.827  -76.173  48.064  1
234602  98.852  -76.172  48.030  1
234603  98.878  -76.171  47.996  1
234604  98.904  -76.170  47.964  1
234605  98.929  -76.169  47.935  1
234606  98.954  -76.168  47.908  1
234607  98.980  -76.167  47.881  1
234608  99.006  -76.166  47.857  1
234609  99.031  -76.165  47.834  1
234610  99.057  -76.164  47.812  1
234611  99.083  -76.163  47.792  1
234612  99.109  -76.162  47.771  1
234613  99.134  -76.165  47.751  1
234614  99.158  -76.176  47.731  1
234615  99.183  -76.187  47.711  1
234616  99.207  -76.198  47.690  1
234617  99.231  -76.209  47.668  1
234618  99.255  -76.220  47.645  1
234619  99.279  -76.230  47.622  1
234620  99.303  -76.242  47.598  1
234621  99.328  -76.252  47.574  1
234622  99.352  -76.263  47.547  1
234623  99.376  -76.274  47.520  1
234624  99.400  -76.285  47.495  1
234625  99.416  -76.289  47.469  1
234626  99.424  -76.285  47.441  1
234627  99.440  -76.284  47.412  1
234628  99.462  -76.282  47.383  1
234629  99.477  -76.285  47.355  1
234630  99.492  -76.287  47.327  1
234631  99.507  -76.289  47.298  1
234632  99.522  -76.292  47.268  1
234633  99.538  -76.294  47.237  1
234634  99.553  -76.296  47.207  1
234635  99.568  -76.298  47.176  1
234636  99.583  -76.301  47.145  1
234637  99.598  -76.303  47.116  1
234638  99.619  -76.308  47.087  1
234639  99.648  -76.318  47.057  1
234640  99.676  -76.328  47.027  1
234641  99.693  -76.342  46.995  1
234642  99.712  -76.357  46.964  1
234643  99.744  -76.373  46.932  1
234644  99.776  -76.390  46.902  1
234645  99.808  -76.406  46.872  1
234646  99.840  -76.423  46.842  1
234647  99.872  -76.439  46.812  1
234648  99.900  -76.451  46.781  1
234649  99.920  -76.454  46.751  1
234650  99.940  -76.458  46.722  1
234651  99.960  -76.461  46.693  1
234652  99.980  -76.464  46.663  1
234653  99.999  -76.478  46.631  1
234654  100.017  -76.491  46.599  1
234655  100.035  -76.504  46.566  1
234656  100.054  -76.517  46.533  1
234657  100.072  -76.530  46.499  1
234658  100.090  -76.543  46.465  1
234659  100.109  -76.556  46.432  1
234660  100.138  -76.565  46.397  1
234661  100.176  -76.571  46.360  1
234662  100.213  -76.577  46.324  1
234663  100.250  -76.582  46.289  1
234664  100.267  -76.595  46.254  1
234665  100.284  -76.608  46.219  1
234666  100.301  -76.621  46.184  1
234667  100.319  -76.633  46.149  1
234668  100.336  -76.646  46.115  1
234669  100.354  -76.639  46.081  1
234670  100.373  -76.627  46.049  1
234671  100.392  -76.614  46.018  1
234672  100.411  -76.603  45.986  1
234673  100.431  -76.611  45.957  1
234674  100.451  -76.619  45.928  1
234675  100.470  -76.627  45.900  1
234676  100.489  -76.635  45.872  1
234677  100.509  -76.643  45.847  1
234678  100.528  -76.651  45.823  1
234679  100.548  -76.663  45.799  1
234680  100.567  -76.682  45.777  1
234681  100.586  -76.700  45.756  1
234682  100.630  -76.696  45.736  1
234683  100.675  -76.690  45.716  1
234684  100.719  -76.684  45.696  1
234685  100.748  -76.690  45.677  1
234686  100.772  -76.699  45.657  1
234687  100.796  -76.708  45.637  1
234688  100.820  -76.718  45.616  1
234689  100.844  -76.727  45.596  1
234690  100.868  -76.736  45.575  1
234691  100.892  -76.745  45.556  1
234692  100.916  -76.754  45.535  1
234693  100.942  -76.765  45.515  1
234694  100.970  -76.774  45.494  1
234695  100.998  -76.785  45.474  1
234696  101.025  -76.796  45.455  1
234697  101.054  -76.806  45.436  1
234698  101.073  -76.818  45.417  1
234699  101.089  -76.830  45.400  1
234700  101.103  -76.842  45.385  1
234701  101.118  -76.854  45.369  1
234702  101.133  -76.866  45.355  1
234703  101.147  -76.878  45.342  1
234704  101.162  -76.890  45.331  1
234705  101.177  -76.902  45.320  1
234706  101.192  -76.914  45.308  1
234707  101.206  -76.926  45.297  1
234708  101.221  -76.938  45.285  1
234709  101.236  -76.950  45.273  1
234710  101.251  -76.962  45.259  1
234711  101.265  -76.974  45.246  1
234712  101.285  -76.990  45.233  1
234713  101.314  -77.012  45.220  1
234714  101.343  -77.034  45.205  1
234715  101.372  -77.057  45.191  1
234716  101.401  -77.079  45.177  1
234717  101.420  -77.095  45.162  1
234718  101.435  -77.108  45.148  1
234719  101.450  -77.119  45.132  1
234720  101.473  -77.119  45.116  1
234721  101.496  -77.119  45.100  1
234722  101.519  -77.120  45.082  1
234723  101.541  -77.120  45.064  1
234724  101.564  -77.120  45.046  1
234725  101.586  -77.122  45.029  1
234726  101.604  -77.128  45.011  1
234727  101.622  -77.135  44.992  1
234728  101.641  -77.142  44.974  1
234729  101.659  -77.148  44.956  1
234730  101.678  -77.155  44.938  1
234731  101.697  -77.162  44.922  1
234732  101.715  -77.168  44.906  1
234733  101.734  -77.175  44.889  1
234734  101.753  -77.183  44.875  1
234735  101.772  -77.197  44.859  1
234736  101.792  -77.210  44.843  1
234737  101.812  -77.224  44.826  1
234738  101.831  -77.238  44.810  1
234739  101.851  -77.251  44.793  1
234740  101.872  -77.268  44.777  1
234741  101.895  -77.292  44.761  1
234742  101.918  -77.316  44.743  1
234743  101.942  -77.339  44.726  1
234744  101.965  -77.363  44.710  1
234745  101.988  -77.387  44.694  1
234746  102.011  -77.410  44.678  1
234747  102.034  -77.435  44.661  1
234748  102.057  -77.458  44.645  1
234749  102.078  -77.481  44.630  1
234750  102.108  -77.498  44.612  1
234751  102.128  -77.506  44.596  1
234752  102.148  -77.515  44.580  1
234753  102.168  -77.523  44.563  1
234754  102.189  -77.533  44.547  1
234755  102.209  -77.542  44.531  1
234756  102.229  -77.550  44.516  1
234757  102.250  -77.559  44.499  1
234758  102.270  -77.568  44.483  1
234759  102.296  -77.578  44.468  1
234760  102.328  -77.589  44.453  1
234761  102.361  -77.602  44.436  1
234762  102.376  -77.621  44.420  1
234763  102.395  -77.636  44.404  1
234764  102.420  -77.641  44.387  1
234765  102.446  -77.645  44.371  1
234766  102.471  -77.649  44.355  1
234767  102.497  -77.653  44.338  1
234768  102.523  -77.658  44.320  1
234769  102.553  -77.662  44.302  1
234770  102.590  -77.667  44.285  1
234771  102.626  -77.673  44.267  1
234772  102.663  -77.678  44.250  1
234773  102.699  -77.683  44.234  1
234774  102.735  -77.689  44.218  1
234775  102.771  -77.694  44.201  1
234776  102.808  -77.699  44.184  1
234777  102.844  -77.705  44.168  1
234778  102.880  -77.710  44.152  1
234779  102.917  -77.715  44.137  1
234780  102.953  -77.721  44.119  1
234781  102.989  -77.726  44.102  1
234782  103.026  -77.732  44.085  1
234783  103.062  -77.737  44.070  1
234784  103.098  -77.743  44.054  1
234785  103.135  -77.748  44.038  1
234786  103.171  -77.753  44.022  1
235043  92.237  -74.807  54.336  1
235044  92.262  -74.818  54.345  1
235045  92.286  -74.828  54.354  1
235046  92.310  -74.840  54.364  1
235047  92.335  -74.850  54.374  1
235048  92.359  -74.861  54.386  1
235049  92.383  -74.872  54.400  1
235050  92.408  -74.883  54.413  1
235051  92.432  -74.894  54.426  1
235052  92.456  -74.904  54.437  1
235053  92.471  -74.886  54.447  1
235054  92.494  -74.872  54.454  1
235055  92.520  -74.863  54.462  1
235056  92.550  -74.856  54.469  1
235057  92.583  -74.853  54.475  1
235058  92.616  -74.849  54.476  1
235059  92.648  -74.846  54.476  1
235060  92.681  -74.844  54.473  1
235061  92.712  -74.841  54.469  1
235062  92.744  -74.838  54.465  1
235063  92.777  -74.834  54.462  1
235064  92.807  -74.832  54.458  1
235065  92.841  -74.834  54.448  1
235066  92.874  -74.837  54.436  1
235067  92.908  -74.840  54.420  1
235068  92.942  -74.844  54.403  1
235069  92.976  -74.847  54.389  1
235070  93.009  -74.850  54.374  1
235071  93.043  -74.853  54.360  1
235072  93.076  -74.856  54.348  1
235073  93.107  -74.859  54.337  1
235074  93.132  -74.859  54.326  1
235075  93.155  -74.853  54.314  1
235076  93.178  -74.846  54.303  1
235077  93.201  -74.838  54.291  1
235078  93.223  -74.831  54.281  1
235079  93.247  -74.825  54.272  1
235080  93.269  -74.818  54.264  1
235081  93.292  -74.811  54.257  1
235082  93.315  -74.803  54.251  1
235083  93.338  -74.797  54.247  1
235084  93.361  -74.790  54.244  1
235085  93.384  -74.783  54.243  1
235086  93.407  -74.776  54.245  1
235087  93.430  -74.769  54.249  1
235088  93.453  -74.762  54.255  1
235089  93.476  -74.755  54.260  1
235090  93.499  -74.748  54.269  1
235091  93.521  -74.741  54.280  1
235092  93.545  -74.734  54.293  1
235093  93.567  -74.727  54.311  1
235094  93.595  -74.728  54.332  1
235095  93.624  -74.730  54.355  1
235096  93.653  -74.732  54.378  1
235097  93.683  -74.737  54.407  1
235098  93.716  -74.750  54.439  1
235099  93.749  -74.763  54.472  1
235100  93.782  -74.776  54.502  1
235101  93.815  -74.788  54.526  1
235102  93.848  -74.801  54.542  1
235103  93.881  -74.814  54.551  1
235104  93.903  -74.816  54.552  1
235105  93.921  -74.812  54.552  1
235106  93.939  -74.809  54.555  1
235107  93.957  -74.806  54.561  1
235108  93.975  -74.803  54.572  1
235109  93.992  -74.800  54.580  1
235110  94.009  -74.791  54.588  1
235111  94.027  -74.784  54.595  1
235112  94.047  -74.775  54.602  1
235113  94.074  -74.768  54.607  1
235114  94.101  -74.760  54.610  1
235115  94.127  -74.753  54.611  1
235116  94.152  -74.750  54.601  1
235117  94.174  -74.753  54.587  1
235118  94.195  -74.755  54.570  1
235119  94.217  -74.756  54.550  1
235120  94.238  -74.758  54.522  1
235121  94.260  -74.759  54.491  1
235122  94.282  -74.762  54.460  1
235123  94.303  -74.763  54.428  1
235124  94.326  -74.765  54.399  1
235125  94.347  -74.766  54.375  1
235126  94.368  -74.766  54.352  1
235127  94.381  -74.771  54.329  1
235128  94.398  -74.774  54.311  1
235129  94.415  -74.777  54.292  1
235130  94.433  -74.781  54.271  1
235131  94.450  -74.784  54.251  1
235132  94.468  -74.787  54.232  1
235133  94.485  -74.790  54.213  1
235134  94.502  -74.793  54.195  1
235135  94.523  -74.795  54.176  1
235136  94.544  -74.797  54.153  1
235137  94.564  -74.799  54.129  1
235138  94.583  -74.799  54.105  1
235139  94.603  -74.799  54.083  1
235140  94.622  -74.799  54.068  1
235141  94.641  -74.799  54.054  1
235142  94.662  -74.800  54.038  1
235143  94.690  -74.806  54.014  1
235144  94.718  -74.812  53.985  1
235145  94.746  -74.818  53.951  1
235146  94.774  -74.824  53.913  1
235147  94.802  -74.830  53.871  1
235148  94.830  -74.838  53.827  1
235149  94.858  -74.847  53.780  1
235150  94.886  -74.856  53.732  1
235151  94.914  -74.864  53.683  1
235152  94.942  -74.872  53.634  1
235153  94.964  -74.879  53.584  1
235154  94.979  -74.885  53.534  1
235155  94.995  -74.891  53.484  1
235156  95.011  -74.896  53.436  1
235157  95.015  -74.894  53.387  1
235158  95.009  -74.884  53.336  1
235159  95.003  -74.874  53.281  1
235160  94.997  -74.864  53.224  1
235161  94.991  -74.854  53.162  1
235162  94.994  -74.848  53.098  1
235163  95.027  -74.855  53.029  1
235164  95.058  -74.861  52.960  1
235165  95.091  -74.868  52.894  1
235166  95.122  -74.875  52.829  1
235167  95.155  -74.881  52.768  1
235168  95.186  -74.888  52.707  1
235169  95.218  -74.894  52.647  1
235170  95.251  -74.903  52.588  1
235171  95.278  -74.914  52.528  1
235172  95.306  -74.925  52.468  1
235173  95.334  -74.935  52.408  1
235174  95.361  -74.947  52.349  1
235175  95.389  -74.957  52.294  1
235176  95.416  -74.969  52.240  1
235177  95.444  -74.980  52.188  1
235178  95.470  -74.989  52.138  1
235179  95.484  -74.989  52.089  1
235180  95.501  -74.984  52.042  1
235181  95.519  -74.977  51.998  1
235182  95.536  -74.970  51.955  1
235183  95.554  -74.963  51.914  1
235184  95.572  -74.957  51.876  1
235185  95.590  -74.950  51.840  1
235186  95.608  -74.944  51.805  1
235187  95.625  -74.937  51.770  1
235188  95.661  -74.956  51.737  1
235189  95.701  -74.982  51.705  1
235190  95.742  -74.997  51.675  1
235191  95.783  -75.003  51.646  1
235192  95.824  -75.008  51.617  1
235193  95.865  -75.014  51.589  1
235194  95.905  -75.020  51.561  1
235195  95.947  -75.026  51.534  1
235196  95.984  -75.033  51.508  1
235197  96.019  -75.041  51.482  1
235198  96.055  -75.050  51.458  1
235199  96.090  -75.057  51.435  1
235200  96.122  -75.060  51.413  1
235201  96.153  -75.062  51.392  1
235202  96.185  -75.064  51.372  1
235203  96.216  -75.066  51.353  1
235204  96.248  -75.068  51.333  1
235205  96.279  -75.070  51.314  1
235206  96.311  -75.073  51.294  1
235207  96.342  -75.075  51.275  1
235208  96.374  -75.077  51.255  1
235209  96.405  -75.079  51.233  1
235210  96.437  -75.081  51.213  1
235211  96.464  -75.084  51.191  1
235212  96.480  -75.099  51.166  1
235213  96.495  -75.115  51.140  1
235214  96.510  -75.131  51.112  1
235215  96.526  -75.148  51.085  1
235216  96.543  -75.164  51.060  1
235217  96.564  -75.176  51.037  1
235218  96.587  -75.180  51.014  1
235219  96.612  -75.191  50.992  1
235220  96.637  -75.202  50.972  1
235221  96.662  -75.214  50.950  1
235222  96.687  -75.224  50.928  1
235223  96.713  -75.236  50.906  1
235224  96.738  -75.246  50.884  1
235225  96.763  -75.258  50.862  1
235226  96.788  -75.269  50.841  1
235227  96.813  -75.279  50.820  1
235228  96.838  -75.291  50.799  1
235229  96.857  -75.308  50.777  1
235230  96.870  -75.329  50.755  1
235231  96.894  -75.342  50.732  1
235232  96.918  -75.355  50.707  1
235233  96.942  -75.367  50.681  1
235234  96.966  -75.380  50.653  1
235235  96.990  -75.392  50.624  1
235236  97.014  -75.405  50.595  1
235237  97.038  -75.418  50.564  1
235238  97.062  -75.431  50.534  1
235239  97.086  -75.444  50.503  1
235240  97.110  -75.457  50.473  1
235241  97.155  -75.465  50.441  1
235242  97.205  -75.470  50.409  1
235243  97.229  -75.476  50.377  1
235244  97.254  -75.482  50.343  1
235245  97.278  -75.488  50.310  1
235246  97.302  -75.494  50.277  1
235247  97.319  -75.505  50.245  1
235248  97.336  -75.517  50.213  1
235249  97.354  -75.529  50.183  1
235250  97.371  -75.540  50.151  1
235251  97.388  -75.552  50.119  1
235252  97.405  -75.564  50.087  1
235253  97.423  -75.575  50.053  1
235254  97.450  -75.580  50.019  1
235255  97.475  -75.583  49.985  1
235256  97.500  -75.588  49.951  1
235257  97.524  -75.592  49.916  1
235258  97.549  -75.596  49.881  1
235259  97.574  -75.599  49.847  1
235260  97.598  -75.603  49.813  1
235261  97.623  -75.608  49.780  1
235262  97.648  -75.612  49.746  1
235263  97.672  -75.615  49.710  1
235264  97.697  -75.619  49.673  1
235265  97.722  -75.623  49.634  1
235266  97.746  -75.627  49.594  1
235267  97.773  -75.633  49.552  1
235268  97.830  -75.634  49.509  1
235269  97.891  -75.637  49.465  1
235270  97.918  -75.669  49.419  1
235271  97.938  -75.681  49.371  1
235272  97.957  -75.692  49.324  1
235273  97.973  -75.699  49.278  1
235274  98.015  -75.706  49.233  1
235275  98.057  -75.715  49.189  1
235276  98.075  -75.726  49.145  1
235277  98.092  -75.736  49.100  1
235278  98.109  -75.746  49.055  1
235279  98.128  -75.757  49.011  1
235280  98.149  -75.767  48.967  1
235281  98.171  -75.778  48.924  1
235282  98.192  -75.788  48.880  1
235283  98.211  -75.801  48.836  1
235284  98.229  -75.815  48.790  1
235285  98.262  -75.831  48.744  1
235286  98.307  -75.850  48.699  1
235287  98.347  -75.865  48.653  1
235288  98.387  -75.881  48.610  1
235289  98.427  -75.897  48.567  1
235290  98.467  -75.913  48.524  1
235291  98.507  -75.929  48.481  1
235292  98.547  -75.945  48.438  1
235293  98.583  -75.961  48.397  1
235294  98.598  -75.982  48.357  1
235295  98.638  -76.040  48.315  1
235296  98.678  -76.097  48.277  1
235297  98.719  -76.154  48.239  1
235298  98.747  -76.157  48.200  1
235299  98.773  -76.155  48.164  1
235300  98.798  -76.154  48.128  1
235301  98.824  -76.154  48.093  1
235302  98.850  -76.152  48.059  1
235303  98.875  -76.151  48.026  1
235304  98.901  -76.151  47.992  1
235305  98.927  -76.149  47.959  1
235306  98.952  -76.148  47.930  1
235307  98.978  -76.148  47.902  1
235308  99.003  -76.146  47.875  1
235309  99.029  -76.145  47.850  1
235310  99.055  -76.144  47.826  1
235311  99.080  -76.141  47.804  1
235312  99.105  -76.140  47.782  1
235313  99.130  -76.138  47.761  1
235314  99.155  -76.147  47.740  1
235315  99.181  -76.158  47.720  1
235316  99.205  -76.169  47.698  1
235317  99.229  -76.180  47.677  1
235318  99.253  -76.191  47.656  1
235319  99.277  -76.202  47.633  1
235320  99.301  -76.213  47.611  1
235321  99.326  -76.223  47.587  1
235322  99.350  -76.235  47.563  1
235323  99.374  -76.245  47.536  1
235324  99.398  -76.256  47.510  1
235325  99.422  -76.267  47.485  1
235326  99.443  -76.275  47.459  1
235327  99.452  -76.273  47.431  1
235328  99.473  -76.272  47.403  1
235329  99.488  -76.274  47.375  1
235330  99.503  -76.276  47.347  1
235331  99.518  -76.279  47.320  1
235332  99.534  -76.281  47.291  1
235333  99.549  -76.283  47.262  1
235334  99.564  -76.285  47.231  1
235335  99.579  -76.288  47.201  1
235336  99.594  -76.290  47.170  1
235337  99.610  -76.292  47.140  1
235338  99.625  -76.295  47.111  1
235339  99.640  -76.296  47.082  1
235340  99.665  -76.304  47.052  1
235341  99.691  -76.315  47.022  1
235342  99.708  -76.329  46.990  1
235343  99.725  -76.344  46.958  1
235344  99.751  -76.360  46.926  1
235345  99.783  -76.376  46.896  1
235346  99.815  -76.392  46.866  1
235347  99.847  -76.408  46.836  1
235348  99.879  -76.425  46.806  1
235349  99.901  -76.430  46.776  1
235350  99.921  -76.434  46.746  1
235351  99.941  -76.437  46.717  1
235352  99.961  -76.441  46.688  1
235353  99.981  -76.445  46.659  1
235354  100.000  -76.457  46.626  1
235355  100.018  -76.470  46.594  1
235356  100.037  -76.483  46.562  1
235357  100.055  -76.496  46.528  1
235358  100.073  -76.509  46.495  1
235359  100.091  -76.523  46.461  1
235360  100.126  -76.529  46.426  1
235361  100.164  -76.535  46.393  1
235362  100.202  -76.540  46.357  1
235363  100.240  -76.546  46.320  1
235364  100.270  -76.554  46.284  1
235365  100.287  -76.567  46.249  1
235366  100.304  -76.580  46.214  1
235367  100.321  -76.592  46.179  1
235368  100.338  -76.605  46.143  1
235369  100.355  -76.618  46.108  1
235370  100.372  -76.630  46.075  1
235371  100.391  -76.627  46.042  1
235372  100.410  -76.615  46.010  1
235373  100.429  -76.602  45.978  1
235374  100.449  -76.602  45.949  1
235375  100.468  -76.611  45.920  1
235376  100.487  -76.618  45.892  1
235377  100.507  -76.626  45.865  1
235378  100.527  -76.634  45.840  1
235379  100.546  -76.644  45.816  1
235380  100.565  -76.663  45.793  1
235381  100.584  -76.681  45.771  1
235382  100.611  -76.693  45.750  1
235383  100.655  -76.687  45.730  1
235384  100.700  -76.682  45.710  1
235385  100.745  -76.676  45.690  1
235386  100.779  -76.677  45.671  1
235387  100.803  -76.687  45.651  1
235388  100.827  -76.696  45.630  1
235389  100.851  -76.705  45.609  1
235390  100.875  -76.715  45.588  1
235391  100.899  -76.724  45.568  1
235392  100.922  -76.733  45.548  1
235393  100.947  -76.742  45.527  1
235394  100.973  -76.752  45.507  1
235395  101.001  -76.762  45.486  1
235396  101.029  -76.773  45.466  1
235397  101.057  -76.784  45.446  1
235398  101.085  -76.794  45.427  1
235399  101.102  -76.806  45.409  1
235400  101.117  -76.818  45.392  1
235401  101.131  -76.830  45.375  1
235402  101.146  -76.842  45.361  1
235403  101.161  -76.854  45.348  1
235404  101.176  -76.866  45.335  1
235405  101.190  -76.878  45.323  1
235406  101.205  -76.890  45.312  1
235407  101.220  -76.902  45.301  1
235408  101.235  -76.914  45.290  1
235409  101.249  -76.926  45.277  1
235410  101.264  -76.938  45.263  1
235411  101.279  -76.950  45.249  1
235412  101.293  -76.962  45.238  1
235413  101.308  -76.975  45.225  1
235414  101.324  -76.987  45.212  1
235415  101.353  -77.009  45.198  1
235416  101.382  -77.031  45.184  1
235417  101.411  -77.054  45.170  1
235418  101.434  -77.073  45.154  1
235419  101.449  -77.085  45.139  1
235420  101.466  -77.094  45.124  1
235421  101.489  -77.094  45.107  1
235422  101.512  -77.094  45.090  1
235423  101.535  -77.094  45.073  1
235424  101.557  -77.094  45.055  1
235425  101.580  -77.094  45.038  1
235426  101.603  -77.096  45.021  1
235427  101.621  -77.102  45.002  1
235428  101.639  -77.109  44.984  1
235429  101.658  -77.115  44.967  1
235430  101.677  -77.122  44.949  1
235431  101.695  -77.128  44.930  1
235432  101.713  -77.135  44.914  1
235433  101.732  -77.141  44.898  1
235434  101.752  -77.153  44.882  1
235435  101.771  -77.167  44.868  1
235436  101.791  -77.181  44.852  1
235437  101.811  -77.194  44.835  1
235438  101.831  -77.208  44.818  1
235439  101.850  -77.222  44.803  1
235440  101.870  -77.235  44.785  1
235441  101.891  -77.254  44.768  1
235442  101.914  -77.278  44.752  1
235443  101.938  -77.301  44.736  1
235444  101.961  -77.326  44.719  1
235445  101.984  -77.349  44.704  1
235446  102.007  -77.373  44.689  1
235447  102.031  -77.397  44.673  1
235448  102.054  -77.420  44.656  1
235449  102.077  -77.444  44.640  1
235450  102.100  -77.468  44.625  1
235451  102.120  -77.484  44.607  1
235452  102.140  -77.493  44.590  1
235453  102.161  -77.501  44.574  1
235454  102.181  -77.511  44.557  1
235455  102.201  -77.520  44.541  1
235456  102.222  -77.528  44.525  1
235457  102.242  -77.537  44.510  1
235458  102.262  -77.546  44.492  1
235459  102.282  -77.555  44.477  1
235460  102.303  -77.564  44.461  1
235461  102.335  -77.575  44.446  1
235462  102.368  -77.587  44.429  1
235463  102.383  -77.608  44.412  1
235464  102.405  -77.617  44.396  1
235465  102.430  -77.621  44.379  1
235466  102.456  -77.626  44.363  1
235467  102.482  -77.630  44.346  1
235468  102.507  -77.634  44.328  1
235469  102.542  -77.639  44.310  1
235470  102.578  -77.645  44.293  1
235471  102.614  -77.650  44.275  1
235472  102.650  -77.655  44.257  1
235473  102.687  -77.661  44.242  1
235474  102.724  -77.666  44.225  1
235475  102.760  -77.671  44.209  1
235476  102.796  -77.677  44.192  1
235477  102.832  -77.682  44.175  1
235478  102.869  -77.687  44.159  1
235479  102.905  -77.692  44.144  1
235480  102.941  -77.698  44.128  1
235481  102.977  -77.703  44.110  1
235482  103.014  -77.708  44.094  1
235483  103.050  -77.714  44.078  1
235484  103.087  -77.719  44.062  1
235485  103.123  -77.724  44.046  1
235486  103.159  -77.730  44.030  1
235744  92.239  -74.775  54.340  1
235745  92.263  -74.785  54.347  1
235746  92.288  -74.797  54.356  1
235747  92.312  -74.807  54.366  1
235748  92.337  -74.818  54.376  1
235749  92.361  -74.828  54.387  1
235750  92.385  -74.840  54.401  1
235751  92.410  -74.850  54.413  1
235752  92.434  -74.861  54.425  1
235753  92.458  -74.872  54.436  1
235754  92.476  -74.862  54.445  1
235755  92.495  -74.846  54.453  1
235756  92.522  -74.836  54.461  1
235757  92.549  -74.827  54.469  1
235758  92.578  -74.820  54.475  1
235759  92.611  -74.816  54.478  1
235760  92.643  -74.813  54.480  1
235761  92.675  -74.811  54.480  1
235762  92.708  -74.808  54.478  1
235763  92.740  -74.805  54.476  1
235764  92.773  -74.802  54.474  1
235765  92.806  -74.800  54.470  1
235766  92.840  -74.804  54.461  1
235767  92.874  -74.807  54.449  1
235768  92.908  -74.811  54.434  1
235769  92.941  -74.815  54.419  1
235770  92.975  -74.818  54.406  1
235771  93.009  -74.822  54.393  1
235772  93.043  -74.825  54.381  1
235773  93.077  -74.828  54.370  1
235774  93.110  -74.834  54.360  1
235775  93.136  -74.828  54.349  1
235776  93.159  -74.819  54.338  1
235777  93.183  -74.809  54.326  1
235778  93.206  -74.802  54.316  1
235779  93.228  -74.794  54.306  1
235780  93.252  -74.787  54.297  1
235781  93.274  -74.781  54.289  1
235782  93.297  -74.774  54.283  1
235783  93.320  -74.767  54.277  1
235784  93.343  -74.759  54.273  1
235785  93.366  -74.753  54.270  1
235786  93.389  -74.746  54.270  1
235787  93.412  -74.739  54.272  1
235788  93.435  -74.732  54.276  1
235789  93.458  -74.725  54.282  1
235790  93.481  -74.718  54.288  1
235791  93.504  -74.711  54.295  1
235792  93.526  -74.704  54.305  1
235793  93.550  -74.697  54.317  1
235794  93.572  -74.690  54.333  1
235795  93.600  -74.690  54.351  1
235796  93.629  -74.693  54.371  1
235797  93.658  -74.697  54.390  1
235798  93.692  -74.709  54.416  1
235799  93.724  -74.722  54.445  1
235800  93.758  -74.735  54.476  1
235801  93.790  -74.747  54.507  1
235802  93.824  -74.760  54.530  1
235803  93.856  -74.773  54.546  1
235804  93.889  -74.785  54.556  1
235805  93.916  -74.792  54.558  1
235806  93.934  -74.789  54.560  1
235807  93.952  -74.786  54.564  1
235808  93.970  -74.783  54.571  1
235809  93.987  -74.777  54.582  1
235810  94.004  -74.769  54.590  1
235811  94.022  -74.761  54.598  1
235812  94.040  -74.753  54.605  1
235813  94.057  -74.745  54.612  1
235814  94.074  -74.737  54.616  1
235815  94.097  -74.729  54.619  1
235816  94.122  -74.724  54.621  1
235817  94.144  -74.725  54.611  1
235818  94.166  -74.728  54.599  1
235819  94.188  -74.730  54.584  1
235820  94.209  -74.732  54.566  1
235821  94.231  -74.734  54.537  1
235822  94.253  -74.735  54.506  1
235823  94.275  -74.737  54.473  1
235824  94.296  -74.738  54.440  1
235825  94.319  -74.740  54.410  1
235826  94.342  -74.743  54.383  1
235827  94.363  -74.745  54.358  1
235828  94.380  -74.748  54.332  1
235829  94.398  -74.751  54.309  1
235830  94.415  -74.754  54.285  1
235831  94.432  -74.757  54.262  1
235832  94.450  -74.760  54.240  1
235833  94.467  -74.764  54.219  1
235834  94.484  -74.767  54.199  1
235835  94.503  -74.770  54.180  1
235836  94.524  -74.772  54.161  1
235837  94.545  -74.774  54.138  1
235838  94.566  -74.776  54.114  1
235839  94.585  -74.776  54.091  1
235840  94.604  -74.776  54.070  1
235841  94.623  -74.776  54.056  1
235842  94.642  -74.776  54.044  1
235843  94.668  -74.781  54.030  1
235844  94.696  -74.787  54.007  1
235845  94.724  -74.793  53.981  1
235846  94.753  -74.799  53.951  1
235847  94.781  -74.805  53.916  1
235848  94.809  -74.811  53.875  1
235849  94.837  -74.817  53.832  1
235850  94.865  -74.823  53.788  1
235851  94.894  -74.831  53.741  1
235852  94.921  -74.841  53.694  1
235853  94.950  -74.849  53.644  1
235854  94.977  -74.857  53.594  1
235855  94.993  -74.863  53.543  1
235856  95.008  -74.869  53.492  1
235857  95.024  -74.874  53.441  1
235858  95.020  -74.865  53.390  1
235859  95.014  -74.855  53.337  1
235860  95.007  -74.845  53.283  1
235861  95.002  -74.835  53.225  1
235862  94.996  -74.825  53.165  1
235863  95.000  -74.820  53.101  1
235864  95.032  -74.826  53.031  1
235865  95.064  -74.833  52.964  1
235866  95.096  -74.840  52.897  1
235867  95.128  -74.846  52.833  1
235868  95.160  -74.853  52.773  1
235869  95.192  -74.859  52.714  1
235870  95.225  -74.872  52.655  1
235871  95.259  -74.888  52.596  1
235872  95.287  -74.899  52.536  1
235873  95.315  -74.910  52.476  1
235874  95.342  -74.920  52.416  1
235875  95.370  -74.931  52.357  1
235876  95.398  -74.941  52.302  1
235877  95.425  -74.951  52.247  1
235878  95.453  -74.962  52.194  1
235879  95.480  -74.970  52.144  1
235880  95.508  -74.957  52.094  1
235881  95.526  -74.950  52.047  1
235882  95.544  -74.943  52.002  1
235883  95.561  -74.936  51.959  1
235884  95.580  -74.929  51.918  1
235885  95.597  -74.922  51.879  1
235886  95.615  -74.916  51.842  1
235887  95.633  -74.910  51.807  1
235888  95.651  -74.903  51.772  1
235889  95.677  -74.908  51.739  1
235890  95.717  -74.934  51.706  1
235891  95.758  -74.960  51.676  1
235892  95.798  -74.980  51.647  1
235893  95.839  -74.986  51.618  1
235894  95.880  -74.991  51.589  1
235895  95.921  -74.997  51.562  1
235896  95.962  -75.004  51.535  1
235897  95.998  -75.011  51.509  1
235898  96.034  -75.019  51.483  1
235899  96.068  -75.027  51.459  1
235900  96.100  -75.029  51.436  1
235901  96.132  -75.031  51.414  1
235902  96.163  -75.033  51.393  1
235903  96.195  -75.035  51.372  1
235904  96.226  -75.038  51.353  1
235905  96.258  -75.040  51.335  1
235906  96.290  -75.041  51.316  1
235907  96.321  -75.044  51.298  1
235908  96.353  -75.046  51.279  1
235909  96.384  -75.048  51.261  1
235910  96.415  -75.051  51.241  1
235911  96.447  -75.054  51.221  1
235912  96.469  -75.065  51.199  1
235913  96.484  -75.079  51.174  1
235914  96.499  -75.096  51.148  1
235915  96.514  -75.112  51.121  1
235916  96.529  -75.128  51.095  1
235917  96.546  -75.144  51.070  1
235918  96.571  -75.151  51.048  1
235919  96.596  -75.163  51.025  1
235920  96.621  -75.173  51.004  1
235921  96.646  -75.185  50.984  1
235922  96.671  -75.196  50.963  1
235923  96.696  -75.207  50.941  1
235924  96.722  -75.218  50.919  1
235925  96.747  -75.229  50.896  1
235926  96.772  -75.240  50.875  1
235927  96.797  -75.251  50.854  1
235928  96.822  -75.262  50.834  1
235929  96.848  -75.273  50.814  1
235930  96.872  -75.286  50.792  1
235931  96.891  -75.301  50.770  1
235932  96.915  -75.314  50.746  1
235933  96.939  -75.327  50.722  1
235934  96.963  -75.340  50.695  1
235935  96.987  -75.353  50.667  1
235936  97.011  -75.366  50.638  1
235937  97.035  -75.379  50.608  1
235938  97.060  -75.392  50.578  1
235939  97.083  -75.405  50.548  1
235940  97.107  -75.417  50.519  1
235941  97.132  -75.430  50.488  1
235942  97.165  -75.441  50.456  1
235943  97.215  -75.446  50.424  1
235944  97.239  -75.452  50.392  1
235945  97.264  -75.458  50.358  1
235946  97.288  -75.464  50.326  1
235947  97.305  -75.475  50.294  1
235948  97.322  -75.487  50.263  1
235949  97.339  -75.499  50.233  1
235950  97.357  -75.510  50.202  1
235951  97.374  -75.522  50.171  1
235952  97.391  -75.532  50.139  1
235953  97.408  -75.540  50.106  1
235954  97.426  -75.548  50.073  1
235955  97.453  -75.554  50.039  1
235956  97.476  -75.558  50.005  1
235957  97.499  -75.562  49.970  1
235958  97.521  -75.566  49.935  1
235959  97.544  -75.570  49.899  1
235960  97.567  -75.574  49.865  1
235961  97.590  -75.578  49.831  1
235962  97.612  -75.582  49.798  1
235963  97.636  -75.586  49.763  1
235964  97.658  -75.590  49.727  1
235965  97.681  -75.594  49.689  1
235966  97.704  -75.598  49.649  1
235967  97.727  -75.602  49.608  1
235968  97.760  -75.603  49.566  1
235969  97.834  -75.596  49.521  1
235970  97.896  -75.599  49.476  1
235971  97.923  -75.631  49.430  1
235972  97.948  -75.658  49.382  1
235973  97.967  -75.668  49.335  1
235974  97.989  -75.676  49.288  1
235975  98.034  -75.684  49.243  1
235976  98.079  -75.693  49.199  1
235977  98.097  -75.702  49.155  1
235978  98.114  -75.713  49.110  1
235979  98.131  -75.724  49.066  1
235980  98.149  -75.734  49.021  1
235981  98.167  -75.744  48.977  1
235982  98.189  -75.755  48.933  1
235983  98.210  -75.765  48.889  1
235984  98.232  -75.775  48.844  1
235985  98.252  -75.787  48.797  1
235986  98.271  -75.800  48.751  1
235987  98.315  -75.818  48.706  1
235988  98.355  -75.834  48.660  1
235989  98.395  -75.850  48.615  1
235990  98.435  -75.865  48.571  1
235991  98.476  -75.881  48.528  1
235992  98.515  -75.897  48.485  1
235993  98.556  -75.913  48.442  1
235994  98.595  -75.929  48.400  1
235995  98.629  -75.971  48.359  1
235996  98.664  -76.020  48.317  1
235997  98.695  -76.062  48.278  1
235998  98.726  -76.104  48.238  1
235999  98.760  -76.107  48.199  1
236000  98.785  -76.105  48.162  1
236001  98.810  -76.103  48.125  1
236002  98.836  -76.100  48.090  1
236003  98.861  -76.099  48.055  1
236004  98.886  -76.097  48.022  1
236005  98.912  -76.094  47.988  1
236006  98.937  -76.092  47.956  1
236007  98.962  -76.090  47.926  1
236008  98.987  -76.088  47.896  1
236009  99.012  -76.086  47.869  1
236010  99.038  -76.084  47.843  1
236011  99.063  -76.082  47.819  1
236012  99.088  -76.079  47.796  1
236013  99.106  -76.094  47.773  1
236014  99.124  -76.110  47.752  1
236015  99.148  -76.122  47.730  1
236016  99.175  -76.135  47.709  1
236017  99.203  -76.146  47.687  1
236018  99.231  -76.158  47.665  1
236019  99.258  -76.169  47.644  1
236020  99.286  -76.181  47.621  1
236021  99.313  -76.193  47.599  1
236022  99.341  -76.204  47.576  1
236023  99.369  -76.216  47.551  1
236024  99.396  -76.228  47.527  1
236025  99.420  -76.238  47.501  1
236026  99.444  -76.249  47.475  1
236027  99.468  -76.260  47.449  1
236028  99.484  -76.260  47.420  1
236029  99.499  -76.263  47.393  1
236030  99.514  -76.265  47.366  1
236031  99.529  -76.267  47.339  1
236032  99.545  -76.270  47.312  1
236033  99.560  -76.272  47.284  1
236034  99.575  -76.274  47.256  1
236035  99.590  -76.276  47.225  1
236036  99.605  -76.279  47.195  1
236037  99.621  -76.281  47.164  1
236038  99.636  -76.283  47.134  1
236039  99.651  -76.285  47.106  1
236040  99.666  -76.288  47.076  1
236041  99.682  -76.291  47.046  1
236042  99.706  -76.302  47.015  1
236043  99.723  -76.317  46.984  1
236044  99.740  -76.331  46.952  1
236045  99.758  -76.345  46.920  1
236046  99.790  -76.362  46.889  1
236047  99.822  -76.378  46.860  1
236048  99.854  -76.395  46.830  1
236049  99.882  -76.407  46.800  1
236050  99.902  -76.410  46.770  1
236051  99.922  -76.414  46.740  1
236052  99.942  -76.417  46.711  1
236053  99.963  -76.420  46.682  1
236054  99.983  -76.424  46.652  1
236055  100.001  -76.436  46.620  1
236056  100.019  -76.449  46.588  1
236057  100.037  -76.462  46.556  1
236058  100.056  -76.476  46.522  1
236059  100.077  -76.487  46.489  1
236060  100.115  -76.493  46.456  1
236061  100.153  -76.499  46.422  1
236062  100.191  -76.504  46.388  1
236063  100.228  -76.509  46.352  1
236064  100.267  -76.515  46.316  1
236065  100.290  -76.526  46.280  1
236066  100.307  -76.538  46.244  1
236067  100.324  -76.551  46.209  1
236068  100.341  -76.564  46.174  1
236069  100.358  -76.577  46.138  1
236070  100.375  -76.589  46.102  1
236071  100.393  -76.602  46.068  1
236072  100.410  -76.614  46.034  1
236073  100.428  -76.616  46.002  1
236074  100.446  -76.603  45.970  1
236075  100.466  -76.594  45.941  1
236076  100.485  -76.602  45.912  1
236077  100.505  -76.610  45.884  1
236078  100.525  -76.618  45.858  1
236079  100.544  -76.625  45.833  1
236080  100.563  -76.643  45.809  1
236081  100.582  -76.662  45.787  1
236082  100.601  -76.681  45.765  1
236083  100.636  -76.684  45.744  1
236084  100.681  -76.679  45.724  1
236085  100.725  -76.673  45.704  1
236086  100.770  -76.668  45.684  1
236087  100.810  -76.665  45.664  1
236088  100.834  -76.675  45.643  1
236089  100.858  -76.684  45.623  1
236090  100.882  -76.693  45.602  1
236091  100.906  -76.702  45.581  1
236092  100.929  -76.712  45.561  1
236093  100.954  -76.721  45.540  1
236094  100.977  -76.730  45.519  1
236095  101.004  -76.740  45.499  1
236096  101.032  -76.750  45.479  1
236097  101.060  -76.761  45.458  1
236098  101.088  -76.771  45.438  1
236099  101.116  -76.782  45.419  1
236100  101.130  -76.794  45.401  1
236101  101.145  -76.806  45.384  1
236102  101.159  -76.818  45.368  1
236103  101.175  -76.831  45.353  1
236104  101.189  -76.842  45.340  1
236105  101.204  -76.854  45.327  1
236106  101.218  -76.866  45.315  1
236107  101.234  -76.878  45.304  1
236108  101.248  -76.890  45.292  1
236109  101.263  -76.903  45.281  1
236110  101.278  -76.915  45.268  1
236111  101.292  -76.926  45.255  1
236112  101.307  -76.938  45.242  1
236113  101.322  -76.950  45.230  1
236114  101.337  -76.962  45.218  1
236115  101.351  -76.975  45.204  1
236116  101.366  -76.987  45.190  1
236117  101.392  -77.006  45.176  1
236118  101.420  -77.029  45.161  1
236119  101.449  -77.050  45.146  1
236120  101.463  -77.063  45.130  1
236121  101.482  -77.069  45.114  1
236122  101.505  -77.069  45.098  1
236123  101.528  -77.069  45.081  1
236124  101.551  -77.069  45.064  1
236125  101.573  -77.069  45.047  1
236126  101.596  -77.069  45.030  1
236127  101.619  -77.069  45.013  1
236128  101.638  -77.075  44.994  1
236129  101.656  -77.082  44.976  1
236130  101.675  -77.088  44.958  1
236131  101.694  -77.095  44.940  1
236132  101.712  -77.101  44.923  1
236133  101.731  -77.110  44.906  1
236134  101.751  -77.124  44.890  1
236135  101.770  -77.138  44.874  1
236136  101.790  -77.151  44.859  1
236137  101.810  -77.165  44.843  1
236138  101.830  -77.179  44.826  1
236139  101.849  -77.192  44.810  1
236140  101.869  -77.206  44.793  1
236141  101.889  -77.219  44.776  1
236142  101.911  -77.240  44.759  1
236143  101.934  -77.263  44.742  1
236144  101.957  -77.288  44.727  1
236145  101.980  -77.311  44.711  1
236146  102.004  -77.335  44.696  1
236147  102.027  -77.359  44.682  1
236148  102.050  -77.382  44.667  1
236149  102.073  -77.406  44.651  1
236150  102.096  -77.429  44.635  1
236151  102.118  -77.449  44.618  1
236152  102.139  -77.467  44.600  1
236153  102.157  -77.477  44.584  1
236154  102.174  -77.488  44.568  1
236155  102.193  -77.498  44.551  1
236156  102.214  -77.506  44.535  1
236157  102.234  -77.515  44.519  1
236158  102.254  -77.524  44.503  1
236159  102.274  -77.533  44.486  1
236160  102.295  -77.542  44.471  1
236161  102.315  -77.551  44.454  1
236162  102.343  -77.561  44.438  1
236163  102.376  -77.573  44.422  1
236164  102.390  -77.593  44.405  1
236165  102.415  -77.599  44.388  1
236166  102.441  -77.602  44.370  1
236167  102.467  -77.607  44.354  1
236168  102.493  -77.611  44.337  1
236169  102.530  -77.616  44.319  1
236170  102.567  -77.621  44.301  1
236171  102.603  -77.627  44.283  1
236172  102.639  -77.632  44.265  1
236173  102.675  -77.638  44.248  1
236174  102.712  -77.643  44.231  1
236175  102.748  -77.649  44.216  1
236176  102.784  -77.654  44.200  1
236177  102.821  -77.659  44.183  1
236178  102.857  -77.664  44.166  1
236179  102.893  -77.670  44.150  1
236180  102.930  -77.675  44.135  1
236181  102.966  -77.680  44.119  1
236182  103.002  -77.686  44.102  1
236183  103.038  -77.691  44.085  1
236184  103.075  -77.696  44.070  1
236185  103.111  -77.702  44.055  1
236186  103.148  -77.707  44.038  1
236446  92.265  -74.753  54.352  1
236447  92.289  -74.764  54.359  1
236448  92.314  -74.775  54.369  1
236449  92.338  -74.785  54.378  1
236450  92.363  -74.797  54.389  1
236451  92.387  -74.807  54.401  1
236452  92.411  -74.818  54.414  1
236453  92.436  -74.828  54.425  1
236454  92.460  -74.839  54.435  1
236455  92.481  -74.838  54.444  1
236456  92.497  -74.819  54.453  1
236457  92.523  -74.809  54.461  1
236458  92.550  -74.800  54.469  1
236459  92.577  -74.791  54.474  1
236460  92.606  -74.784  54.479  1
236461  92.639  -74.781  54.483  1
236462  92.671  -74.778  54.485  1
236463  92.705  -74.775  54.485  1
236464  92.738  -74.772  54.484  1
236465  92.771  -74.769  54.483  1
236466  92.804  -74.768  54.479  1
236467  92.838  -74.771  54.472  1
236468  92.872  -74.775  54.460  1
236469  92.906  -74.778  54.448  1
236470  92.939  -74.781  54.436  1
236471  92.973  -74.785  54.425  1
236472  93.007  -74.788  54.413  1
236473  93.041  -74.793  54.402  1
236474  93.074  -74.799  54.392  1
236475  93.107  -74.804  54.383  1
236476  93.139  -74.808  54.373  1
236477  93.162  -74.798  54.362  1
236478  93.186  -74.787  54.351  1
236479  93.209  -74.778  54.342  1
236480  93.232  -74.768  54.333  1
236481  93.256  -74.758  54.324  1
236482  93.279  -74.748  54.315  1
236483  93.302  -74.738  54.310  1
236484  93.325  -74.730  54.305  1
236485  93.348  -74.723  54.301  1
236486  93.371  -74.716  54.299  1
236487  93.394  -74.709  54.300  1
236488  93.417  -74.702  54.303  1
236489  93.440  -74.695  54.307  1
236490  93.463  -74.688  54.312  1
236491  93.486  -74.681  54.318  1
236492  93.508  -74.674  54.325  1
236493  93.532  -74.667  54.333  1
236494  93.555  -74.660  54.344  1
236495  93.577  -74.653  54.357  1
236496  93.605  -74.653  54.372  1
236497  93.634  -74.656  54.389  1
236498  93.667  -74.668  54.405  1
236499  93.700  -74.681  54.426  1
236500  93.733  -74.694  54.451  1
236501  93.766  -74.706  54.479  1
236502  93.799  -74.719  54.508  1
236503  93.832  -74.732  54.531  1
236504  93.865  -74.745  54.547  1
236505  93.898  -74.757  54.558  1
236506  93.929  -74.769  54.563  1
236507  93.947  -74.766  54.567  1
236508  93.965  -74.762  54.573  1
236509  93.982  -74.754  54.582  1
236510  93.999  -74.747  54.593  1
236511  94.017  -74.738  54.602  1
236512  94.035  -74.730  54.609  1
236513  94.052  -74.722  54.617  1
236514  94.069  -74.715  54.622  1
236515  94.085  -74.710  54.626  1
236516  94.101  -74.705  54.628  1
236517  94.118  -74.701  54.629  1
236518  94.139  -74.703  54.619  1
236519  94.159  -74.704  54.609  1
236520  94.180  -74.706  54.595  1
236521  94.202  -74.708  54.577  1
236522  94.225  -74.710  54.550  1
236523  94.249  -74.712  54.519  1
236524  94.272  -74.714  54.487  1
236525  94.295  -74.716  54.453  1
236526  94.318  -74.718  54.422  1
236527  94.341  -74.721  54.392  1
236528  94.361  -74.723  54.364  1
236529  94.380  -74.725  54.338  1
236530  94.397  -74.728  54.312  1
236531  94.414  -74.731  54.286  1
236532  94.432  -74.734  54.261  1
236533  94.449  -74.737  54.238  1
236534  94.467  -74.740  54.215  1
236535  94.484  -74.744  54.193  1
236536  94.503  -74.747  54.170  1
236537  94.525  -74.749  54.150  1
236538  94.546  -74.750  54.125  1
236539  94.567  -74.753  54.100  1
236540  94.586  -74.753  54.076  1
236541  94.606  -74.753  54.055  1
236542  94.625  -74.753  54.040  1
236543  94.647  -74.756  54.028  1
236544  94.675  -74.762  54.015  1
236545  94.703  -74.768  53.996  1
236546  94.732  -74.774  53.972  1
236547  94.760  -74.780  53.944  1
236548  94.788  -74.786  53.912  1
236549  94.816  -74.792  53.875  1
236550  94.844  -74.798  53.835  1
236551  94.873  -74.804  53.793  1
236552  94.901  -74.810  53.747  1
236553  94.929  -74.817  53.699  1
236554  94.957  -74.825  53.650  1
236555  94.985  -74.834  53.600  1
236556  95.007  -74.841  53.549  1
236557  95.023  -74.847  53.497  1
236558  95.030  -74.847  53.443  1
236559  95.024  -74.836  53.389  1
236560  95.018  -74.826  53.334  1
236561  95.013  -74.816  53.278  1
236562  95.006  -74.806  53.221  1
236563  95.000  -74.797  53.162  1
236564  95.006  -74.791  53.099  1
236565  95.038  -74.798  53.032  1
236566  95.070  -74.805  52.965  1
236567  95.102  -74.812  52.899  1
236568  95.134  -74.818  52.836  1
236569  95.166  -74.826  52.777  1
236570  95.199  -74.842  52.719  1
236571  95.233  -74.857  52.662  1
236572  95.267  -74.873  52.603  1
236573  95.296  -74.885  52.542  1
236574  95.323  -74.894  52.483  1
236575  95.351  -74.905  52.424  1
236576  95.378  -74.916  52.365  1
236577  95.406  -74.926  52.309  1
236578  95.433  -74.936  52.253  1
236579  95.461  -74.947  52.199  1
236580  95.487  -74.950  52.149  1
236581  95.512  -74.950  52.100  1
236582  95.545  -74.923  52.053  1
236583  95.569  -74.909  52.007  1
236584  95.587  -74.902  51.963  1
236585  95.604  -74.895  51.922  1
236586  95.622  -74.888  51.882  1
236587  95.640  -74.881  51.844  1
236588  95.658  -74.875  51.808  1
236589  95.676  -74.869  51.774  1
236590  95.693  -74.862  51.741  1
236591  95.733  -74.886  51.708  1
236592  95.773  -74.912  51.677  1
236593  95.814  -74.938  51.647  1
236594  95.854  -74.963  51.618  1
236595  95.895  -74.969  51.589  1
236596  95.936  -74.975  51.562  1
236597  95.977  -74.981  51.535  1
236598  96.013  -74.989  51.509  1
236599  96.047  -74.996  51.484  1
236600  96.079  -74.998  51.460  1
236601  96.110  -75.001  51.436  1
236602  96.142  -75.003  51.414  1
236603  96.173  -75.005  51.392  1
236604  96.205  -75.007  51.372  1
236605  96.236  -75.009  51.354  1
236606  96.268  -75.011  51.337  1
236607  96.300  -75.014  51.318  1
236608  96.331  -75.021  51.301  1
236609  96.363  -75.027  51.283  1
236610  96.395  -75.033  51.265  1
236611  96.427  -75.040  51.247  1
236612  96.458  -75.046  51.228  1
236613  96.474  -75.060  51.206  1
236614  96.488  -75.073  51.181  1
236615  96.504  -75.088  51.155  1
236616  96.518  -75.101  51.130  1
236617  96.533  -75.115  51.105  1
236618  96.556  -75.127  51.080  1
236619  96.586  -75.134  51.058  1
236620  96.611  -75.145  51.036  1
236621  96.637  -75.156  51.015  1
236622  96.662  -75.167  50.995  1
236623  96.687  -75.178  50.975  1
236624  96.713  -75.189  50.953  1
236625  96.738  -75.201  50.930  1
236626  96.763  -75.211  50.908  1
236627  96.789  -75.223  50.887  1
236628  96.814  -75.233  50.867  1
236629  96.839  -75.245  50.848  1
236630  96.865  -75.256  50.828  1
236631  96.890  -75.267  50.808  1
236632  96.909  -75.290  50.784  1
236633  96.935  -75.293  50.760  1
236634  96.960  -75.301  50.735  1
236635  96.984  -75.314  50.708  1
236636  97.009  -75.326  50.680  1
236637  97.032  -75.339  50.651  1
236638  97.056  -75.352  50.622  1
236639  97.081  -75.364  50.593  1
236640  97.105  -75.377  50.563  1
236641  97.129  -75.390  50.534  1
236642  97.153  -75.403  50.504  1
236643  97.177  -75.416  50.472  1
236644  97.225  -75.421  50.440  1
236645  97.249  -75.427  50.408  1
236646  97.273  -75.433  50.375  1
236647  97.290  -75.446  50.343  1
236648  97.308  -75.457  50.312  1
236649  97.325  -75.468  50.282  1
236650  97.342  -75.479  50.252  1
236651  97.359  -75.487  50.222  1
236652  97.376  -75.496  50.191  1
236653  97.393  -75.503  50.159  1
236654  97.409  -75.511  50.126  1
236655  97.430  -75.519  50.093  1
236656  97.458  -75.526  50.059  1
236657  97.484  -75.532  50.024  1
236658  97.507  -75.536  49.989  1
236659  97.529  -75.540  49.954  1
236660  97.552  -75.544  49.918  1
236661  97.575  -75.548  49.883  1
236662  97.598  -75.552  49.849  1
236663  97.620  -75.556  49.816  1
236664  97.643  -75.560  49.781  1
236665  97.666  -75.564  49.744  1
236666  97.689  -75.568  49.705  1
236667  97.712  -75.572  49.665  1
236668  97.734  -75.576  49.623  1
236669  97.780  -75.572  49.580  1
236670  97.844  -75.561  49.534  1
236671  97.901  -75.561  49.488  1
236672  97.928  -75.593  49.441  1
236673  97.955  -75.626  49.393  1
236674  97.978  -75.645  49.346  1
236675  98.007  -75.653  49.299  1
236676  98.053  -75.662  49.254  1
236677  98.097  -75.670  49.210  1
236678  98.119  -75.680  49.167  1
236679  98.136  -75.690  49.122  1
236680  98.153  -75.701  49.077  1
236681  98.171  -75.711  49.033  1
236682  98.188  -75.721  48.988  1
236683  98.207  -75.732  48.944  1
236684  98.229  -75.742  48.899  1
236685  98.250  -75.753  48.854  1
236686  98.271  -75.763  48.806  1
236687  98.293  -75.773  48.760  1
236688  98.329  -75.792  48.714  1
236689  98.374  -75.813  48.668  1
236690  98.420  -75.834  48.622  1
236691  98.465  -75.856  48.577  1
236692  98.510  -75.878  48.533  1
236693  98.556  -75.899  48.490  1
236694  98.601  -75.920  48.446  1
236695  98.619  -75.909  48.403  1
236696  98.629  -75.911  48.360  1
236697  98.658  -75.950  48.319  1
236698  98.690  -75.993  48.279  1
236699  98.720  -76.035  48.239  1
236700  98.761  -76.050  48.199  1
236701  98.794  -76.043  48.160  1
236702  98.819  -76.041  48.123  1
236703  98.844  -76.038  48.087  1
236704  98.869  -76.037  48.051  1
236705  98.895  -76.035  48.018  1
236706  98.920  -76.032  47.984  1
236707  98.945  -76.030  47.952  1
236708  98.970  -76.028  47.921  1
236709  98.996  -76.026  47.891  1
236710  99.021  -76.024  47.864  1
236711  99.046  -76.022  47.837  1
236712  99.064  -76.037  47.812  1
236713  99.081  -76.053  47.789  1
236714  99.098  -76.069  47.766  1
236715  99.115  -76.086  47.744  1
236716  99.140  -76.098  47.722  1
236717  99.168  -76.110  47.699  1
236718  99.196  -76.122  47.677  1
236719  99.223  -76.133  47.656  1
236720  99.251  -76.145  47.634  1
236721  99.279  -76.157  47.611  1
236722  99.306  -76.169  47.588  1
236723  99.334  -76.180  47.565  1
236724  99.361  -76.191  47.540  1
236725  99.389  -76.204  47.516  1
236726  99.417  -76.215  47.491  1
236727  99.445  -76.229  47.466  1
236728  99.474  -76.239  47.438  1
236729  99.498  -76.244  47.410  1
236730  99.513  -76.246  47.382  1
236731  99.529  -76.248  47.356  1
236732  99.545  -76.251  47.329  1
236733  99.560  -76.254  47.303  1
236734  99.576  -76.257  47.276  1
236735  99.592  -76.259  47.249  1
236736  99.608  -76.261  47.219  1
236737  99.623  -76.264  47.189  1
236738  99.639  -76.267  47.158  1
236739  99.654  -76.270  47.128  1
236740  99.670  -76.272  47.099  1
236741  99.686  -76.275  47.069  1
236742  99.702  -76.277  47.038  1
236743  99.721  -76.289  47.007  1
236744  99.738  -76.304  46.975  1
236745  99.755  -76.318  46.944  1
236746  99.772  -76.332  46.912  1
236747  99.797  -76.348  46.882  1
236748  99.829  -76.364  46.852  1
236749  99.861  -76.381  46.822  1
236750  99.883  -76.386  46.792  1
236751  99.903  -76.390  46.762  1
236752  99.923  -76.393  46.733  1
236753  99.943  -76.397  46.704  1
236754  99.964  -76.401  46.675  1
236755  99.984  -76.404  46.645  1
236756  100.002  -76.415  46.613  1
236757  100.020  -76.429  46.582  1
236758  100.039  -76.442  46.549  1
236759  100.066  -76.451  46.516  1
236760  100.104  -76.457  46.483  1
236761  100.142  -76.462  46.451  1
236762  100.180  -76.467  46.418  1
236763  100.217  -76.473  46.383  1
236764  100.255  -76.479  46.348  1
236765  100.292  -76.484  46.312  1
236766  100.310  -76.497  46.276  1
236767  100.327  -76.510  46.239  1
236768  100.344  -76.523  46.204  1
236769  100.361  -76.536  46.169  1
236770  100.378  -76.548  46.132  1
236771  100.395  -76.561  46.096  1
236772  100.412  -76.574  46.061  1
236773  100.429  -76.586  46.027  1
236774  100.446  -76.599  45.994  1
236775  100.465  -76.604  45.964  1
236776  100.483  -76.592  45.934  1
236777  100.503  -76.593  45.905  1
236778  100.522  -76.601  45.878  1
236779  100.542  -76.608  45.852  1
236780  100.561  -76.624  45.827  1
236781  100.580  -76.643  45.803  1
236782  100.599  -76.662  45.781  1
236783  100.618  -76.680  45.759  1
236784  100.662  -76.676  45.738  1
236785  100.706  -76.671  45.718  1
236786  100.751  -76.665  45.698  1
236787  100.796  -76.659  45.678  1
236788  100.841  -76.654  45.658  1
236789  100.864  -76.663  45.637  1
236790  100.889  -76.672  45.617  1
236791  100.912  -76.681  45.596  1
236792  100.936  -76.690  45.575  1
236793  100.960  -76.699  45.554  1
236794  100.984  -76.708  45.533  1
236795  101.008  -76.718  45.512  1
236796  101.035  -76.728  45.492  1
236797  101.063  -76.739  45.471  1
236798  101.091  -76.749  45.450  1
236799  101.119  -76.759  45.431  1
236800  101.144  -76.771  45.412  1
236801  101.159  -76.782  45.394  1
236802  101.173  -76.794  45.376  1
236803  101.188  -76.806  45.361  1
236804  101.203  -76.818  45.346  1
236805  101.217  -76.831  45.332  1
236806  101.232  -76.843  45.320  1
236807  101.247  -76.855  45.308  1
236808  101.262  -76.866  45.296  1
236809  101.276  -76.878  45.284  1
236810  101.291  -76.890  45.272  1
236811  101.306  -76.903  45.259  1
236812  101.321  -76.915  45.247  1
236813  101.335  -76.927  45.235  1
236814  101.350  -76.939  45.223  1
236815  101.365  -76.950  45.210  1
236816  101.379  -76.962  45.196  1
236817  101.394  -76.975  45.182  1
236818  101.409  -76.987  45.167  1
236819  101.430  -77.003  45.153  1
236820  101.459  -77.026  45.137  1
236821  101.477  -77.041  45.121  1
236822  101.499  -77.044  45.105  1
236823  101.522  -77.044  45.088  1
236824  101.544  -77.044  45.071  1
236825  101.567  -77.044  45.055  1
236826  101.590  -77.044  45.038  1
236827  101.613  -77.044  45.022  1
236828  101.635  -77.044  45.005  1
236829  101.655  -77.049  44.987  1
236830  101.674  -77.055  44.967  1
236831  101.692  -77.062  44.948  1
236832  101.711  -77.069  44.930  1
236833  101.731  -77.081  44.913  1
236834  101.750  -77.094  44.896  1
236835  101.770  -77.108  44.880  1
236836  101.790  -77.122  44.865  1
236837  101.809  -77.136  44.849  1
236838  101.829  -77.150  44.833  1
236839  101.848  -77.163  44.817  1
236840  101.869  -77.177  44.800  1
236841  101.888  -77.191  44.783  1
236842  101.908  -77.204  44.766  1
236843  101.930  -77.226  44.750  1
236844  101.954  -77.249  44.733  1
236845  101.977  -77.273  44.718  1
236846  102.000  -77.297  44.703  1
236847  102.023  -77.321  44.689  1
236848  102.046  -77.345  44.675  1
236849  102.069  -77.368  44.660  1
236850  102.092  -77.390  44.645  1
236851  102.114  -77.410  44.629  1
236852  102.135  -77.429  44.612  1
236853  102.157  -77.448  44.594  1
236854  102.175  -77.460  44.577  1
236855  102.192  -77.470  44.561  1
236856  102.210  -77.481  44.545  1
236857  102.228  -77.492  44.528  1
236858  102.246  -77.501  44.512  1
236859  102.267  -77.511  44.495  1
236860  102.287  -77.520  44.479  1
236861  102.307  -77.528  44.464  1
236862  102.327  -77.537  44.447  1
236863  102.351  -77.547  44.430  1
236864  102.383  -77.559  44.414  1
236865  102.400  -77.575  44.396  1
236866  102.426  -77.579  44.378  1
236867  102.451  -77.583  44.360  1
236868  102.482  -77.588  44.344  1
236869  102.518  -77.593  44.326  1
236870  102.554  -77.599  44.308  1
236871  102.591  -77.604  44.290  1
236872  102.627  -77.609  44.273  1
236873  102.664  -77.614  44.255  1
236874  102.700  -77.620  44.239  1
236875  102.736  -77.625  44.222  1
236876  102.772  -77.630  44.206  1
236877  102.809  -77.636  44.190  1
236878  102.845  -77.642  44.174  1
236879  102.882  -77.647  44.157  1
236880  102.918  -77.652  44.141  1
236881  102.954  -77.658  44.125  1
236882  102.991  -77.663  44.110  1
236883  103.027  -77.668  44.094  1
236884  103.063  -77.674  44.078  1
236885  103.099  -77.679  44.062  1
236886  103.135  -77.684  44.046  1
237147  92.267  -74.721  54.357  1
237148  92.291  -74.731  54.364  1
237149  92.315  -74.742  54.372  1
237150  92.340  -74.753  54.381  1
237151  92.364  -74.764  54.390  1
237152  92.389  -74.775  54.402  1
237153  92.413  -74.785  54.414  1
237154  92.437  -74.796  54.425  1
237155  92.462  -74.807  54.434  1
237156  92.485  -74.814  54.444  1
237157  92.499  -74.791  54.452  1
237158  92.525  -74.782  54.461  1
237159  92.552  -74.773  54.469  1
237160  92.578  -74.763  54.474  1
237161  92.605  -74.754  54.480  1
237162  92.636  -74.748  54.485  1
237163  92.669  -74.745  54.488  1
237164  92.702  -74.741  54.489  1
237165  92.735  -74.738  54.489  1
237166  92.769  -74.735  54.488  1
237167  92.802  -74.734  54.485  1
237168  92.836  -74.738  54.479  1
237169  92.869  -74.741  54.471  1
237170  92.903  -74.745  54.463  1
237171  92.937  -74.749  54.454  1
237172  92.971  -74.752  54.444  1
237173  93.004  -74.757  54.434  1
237174  93.038  -74.763  54.424  1
237175  93.071  -74.769  54.414  1
237176  93.104  -74.775  54.405  1
237177  93.137  -74.781  54.396  1
237178  93.165  -74.777  54.387  1
237179  93.188  -74.767  54.378  1
237180  93.211  -74.757  54.368  1
237181  93.235  -74.747  54.360  1
237182  93.258  -74.737  54.352  1
237183  93.281  -74.728  54.344  1
237184  93.305  -74.718  54.339  1
237185  93.328  -74.707  54.334  1
237186  93.351  -74.697  54.331  1
237187  93.375  -74.687  54.330  1
237188  93.398  -74.678  54.331  1
237189  93.422  -74.668  54.335  1
237190  93.445  -74.658  54.340  1
237191  93.468  -74.651  54.345  1
237192  93.491  -74.644  54.351  1
237193  93.513  -74.637  54.357  1
237194  93.537  -74.630  54.364  1
237195  93.559  -74.623  54.373  1
237196  93.582  -74.616  54.383  1
237197  93.610  -74.617  54.396  1
237198  93.642  -74.628  54.411  1
237199  93.676  -74.640  54.425  1
237200  93.708  -74.653  54.442  1
237201  93.742  -74.665  54.463  1
237202  93.774  -74.678  54.487  1
237203  93.807  -74.691  54.512  1
237204  93.840  -74.704  54.532  1
237205  93.873  -74.716  54.548  1
237206  93.906  -74.729  54.559  1
237207  93.939  -74.742  54.566  1
237208  93.960  -74.740  54.574  1
237209  93.977  -74.732  54.583  1
237210  93.993  -74.727  54.595  1
237211  94.009  -74.722  54.609  1
237212  94.025  -74.716  54.618  1
237213  94.041  -74.712  54.625  1
237214  94.056  -74.706  54.631  1
237215  94.072  -74.701  54.634  1
237216  94.088  -74.696  54.635  1
237217  94.104  -74.690  54.636  1
237218  94.120  -74.686  54.636  1
237219  94.138  -74.684  54.626  1
237220  94.159  -74.686  54.616  1
237221  94.180  -74.687  54.602  1
237222  94.201  -74.687  54.581  1
237223  94.224  -74.688  54.560  1
237224  94.247  -74.690  54.531  1
237225  94.270  -74.692  54.499  1
237226  94.293  -74.694  54.466  1
237227  94.317  -74.697  54.433  1
237228  94.339  -74.699  54.402  1
237229  94.359  -74.701  54.372  1
237230  94.378  -74.703  54.345  1
237231  94.397  -74.705  54.319  1
237232  94.414  -74.709  54.294  1
237233  94.431  -74.712  54.268  1
237234  94.449  -74.715  54.243  1
237235  94.466  -74.718  54.217  1
237236  94.483  -74.721  54.191  1
237237  94.504  -74.723  54.166  1
237238  94.526  -74.725  54.144  1
237239  94.547  -74.728  54.117  1
237240  94.568  -74.730  54.091  1
237241  94.588  -74.731  54.065  1
237242  94.607  -74.731  54.042  1
237243  94.626  -74.731  54.025  1
237244  94.653  -74.736  54.011  1
237245  94.682  -74.742  54.000  1
237246  94.710  -74.748  53.983  1
237247  94.738  -74.754  53.961  1
237248  94.766  -74.760  53.935  1
237249  94.794  -74.766  53.906  1
237250  94.823  -74.772  53.873  1
237251  94.851  -74.778  53.835  1
237252  94.879  -74.784  53.794  1
237253  94.907  -74.791  53.750  1
237254  94.935  -74.797  53.702  1
237255  94.964  -74.803  53.654  1
237256  94.992  -74.810  53.605  1
237257  95.020  -74.819  53.554  1
237258  95.036  -74.825  53.501  1
237259  95.035  -74.818  53.445  1
237260  95.029  -74.808  53.389  1
237261  95.023  -74.797  53.333  1
237262  95.017  -74.787  53.276  1
237263  95.011  -74.778  53.219  1
237264  95.005  -74.768  53.159  1
237265  95.012  -74.763  53.097  1
237266  95.043  -74.770  53.031  1
237267  95.075  -74.777  52.965  1
237268  95.107  -74.783  52.900  1
237269  95.140  -74.796  52.838  1
237270  95.174  -74.811  52.779  1
237271  95.207  -74.827  52.722  1
237272  95.241  -74.842  52.665  1
237273  95.275  -74.858  52.607  1
237274  95.304  -74.869  52.548  1
237275  95.331  -74.880  52.489  1
237276  95.359  -74.890  52.430  1
237277  95.387  -74.900  52.371  1
237278  95.414  -74.911  52.314  1
237279  95.442  -74.922  52.258  1
237280  95.470  -74.932  52.203  1
237281  95.494  -74.931  52.152  1
237282  95.520  -74.930  52.103  1
237283  95.547  -74.919  52.057  1
237284  95.580  -74.893  52.011  1
237285  95.612  -74.868  51.967  1
237286  95.629  -74.861  51.926  1
237287  95.648  -74.854  51.886  1
237288  95.665  -74.847  51.847  1
237289  95.683  -74.841  51.811  1
237290  95.701  -74.834  51.776  1
237291  95.719  -74.828  51.742  1
237292  95.749  -74.838  51.709  1
237293  95.789  -74.864  51.678  1
237294  95.829  -74.890  51.647  1
237295  95.870  -74.916  51.617  1
237296  95.910  -74.942  51.588  1
237297  95.951  -74.953  51.561  1
237298  95.991  -74.959  51.534  1
237299  96.026  -74.966  51.508  1
237300  96.057  -74.968  51.483  1
237301  96.089  -74.969  51.459  1
237302  96.120  -74.972  51.435  1
237303  96.152  -74.975  51.411  1
237304  96.184  -74.981  51.390  1
237305  96.216  -74.987  51.371  1
237306  96.247  -74.994  51.353  1
237307  96.279  -75.000  51.336  1
237308  96.311  -75.007  51.318  1
237309  96.342  -75.013  51.302  1
237310  96.374  -75.019  51.285  1
237311  96.406  -75.026  51.268  1
237312  96.438  -75.032  51.250  1
237313  96.464  -75.041  51.230  1
237314  96.479  -75.054  51.209  1
237315  96.493  -75.069  51.186  1
237316  96.509  -75.082  51.161  1
237317  96.525  -75.096  51.137  1
237318  96.545  -75.110  51.113  1
237319  96.566  -75.125  51.090  1
237320  96.596  -75.132  51.069  1
237321  96.626  -75.137  51.047  1
237322  96.657  -75.142  51.025  1
237323  96.687  -75.149  51.006  1
237324  96.712  -75.160  50.986  1
237325  96.738  -75.171  50.963  1
237326  96.763  -75.182  50.940  1
237327  96.788  -75.193  50.919  1
237328  96.814  -75.204  50.898  1
237329  96.839  -75.215  50.879  1
237330  96.864  -75.226  50.860  1
237331  96.889  -75.237  50.841  1
237332  96.915  -75.248  50.822  1
237333  96.921  -75.309  50.798  1
237334  96.947  -75.311  50.773  1
237335  96.973  -75.314  50.748  1
237336  96.999  -75.317  50.719  1
237337  97.025  -75.320  50.692  1
237338  97.051  -75.323  50.664  1
237339  97.078  -75.326  50.635  1
237340  97.102  -75.338  50.608  1
237341  97.126  -75.351  50.579  1
237342  97.150  -75.364  50.549  1
237343  97.174  -75.377  50.520  1
237344  97.198  -75.389  50.490  1
237345  97.235  -75.397  50.459  1
237346  97.258  -75.403  50.426  1
237347  97.276  -75.415  50.394  1
237348  97.293  -75.427  50.360  1
237349  97.310  -75.435  50.329  1
237350  97.327  -75.442  50.299  1
237351  97.344  -75.451  50.270  1
237352  97.361  -75.459  50.240  1
237353  97.378  -75.467  50.210  1
237354  97.394  -75.475  50.178  1
237355  97.412  -75.483  50.146  1
237356  97.433  -75.491  50.113  1
237357  97.463  -75.497  50.079  1
237358  97.489  -75.504  50.044  1
237359  97.515  -75.510  50.008  1
237360  97.537  -75.514  49.973  1
237361  97.560  -75.518  49.937  1
237362  97.583  -75.522  49.902  1
237363  97.606  -75.526  49.868  1
237364  97.629  -75.530  49.834  1
237365  97.651  -75.534  49.799  1
237366  97.674  -75.538  49.762  1
237367  97.697  -75.542  49.722  1
237368  97.720  -75.546  49.681  1
237369  97.742  -75.550  49.637  1
237370  97.799  -75.542  49.592  1
237371  97.864  -75.531  49.547  1
237372  97.909  -75.540  49.501  1
237373  97.935  -75.566  49.454  1
237374  97.961  -75.592  49.405  1
237375  97.987  -75.620  49.358  1
237376  98.026  -75.630  49.311  1
237377  98.071  -75.639  49.266  1
237378  98.116  -75.647  49.222  1
237379  98.141  -75.657  49.179  1
237380  98.158  -75.668  49.134  1
237381  98.175  -75.677  49.089  1
237382  98.193  -75.688  49.045  1
237383  98.210  -75.699  49.000  1
237384  98.227  -75.709  48.955  1
237385  98.247  -75.719  48.910  1
237386  98.268  -75.730  48.864  1
237387  98.290  -75.740  48.816  1
237388  98.325  -75.751  48.770  1
237389  98.359  -75.766  48.724  1
237390  98.380  -75.805  48.678  1
237391  98.400  -75.844  48.632  1
237392  98.421  -75.882  48.586  1
237393  98.492  -75.908  48.541  1
237394  98.573  -75.931  48.495  1
237395  98.645  -75.922  48.451  1
237396  98.637  -75.884  48.407  1
237397  98.648  -75.890  48.364  1
237398  98.660  -75.894  48.322  1
237399  98.684  -75.924  48.281  1
237400  98.715  -75.966  48.240  1
237401  98.748  -76.003  48.199  1
237402  98.802  -75.981  48.160  1
237403  98.827  -75.978  48.123  1
237404  98.852  -75.976  48.086  1
237405  98.878  -75.975  48.049  1
237406  98.903  -75.972  48.015  1
237407  98.928  -75.970  47.982  1
237408  98.953  -75.968  47.949  1
237409  98.979  -75.966  47.918  1
237410  99.004  -75.964  47.887  1
237411  99.021  -75.981  47.859  1
237412  99.038  -75.997  47.832  1
237413  99.055  -76.013  47.806  1
237414  99.072  -76.029  47.782  1
237415  99.089  -76.046  47.759  1
237416  99.107  -76.062  47.736  1
237417  99.133  -76.074  47.713  1
237418  99.160  -76.086  47.691  1
237419  99.188  -76.097  47.668  1
237420  99.216  -76.109  47.646  1
237421  99.243  -76.121  47.624  1
237422  99.271  -76.132  47.601  1
237423  99.299  -76.144  47.578  1
237424  99.327  -76.156  47.554  1
237425  99.355  -76.170  47.529  1
237426  99.383  -76.185  47.504  1
237427  99.412  -76.199  47.480  1
237428  99.441  -76.210  47.455  1
237429  99.471  -76.215  47.427  1
237430  99.501  -76.220  47.399  1
237431  99.518  -76.223  47.371  1
237432  99.534  -76.225  47.345  1
237433  99.549  -76.228  47.318  1
237434  99.565  -76.230  47.293  1
237435  99.581  -76.232  47.267  1
237436  99.596  -76.235  47.240  1
237437  99.612  -76.238  47.212  1
237438  99.628  -76.241  47.182  1
237439  99.643  -76.243  47.151  1
237440  99.659  -76.246  47.120  1
237441  99.675  -76.248  47.091  1
237442  99.691  -76.251  47.061  1
237443  99.715  -76.255  47.030  1
237444  99.739  -76.267  46.999  1
237445  99.754  -76.286  46.966  1
237446  99.770  -76.305  46.934  1
237447  99.787  -76.320  46.904  1
237448  99.804  -76.334  46.875  1
237449  99.836  -76.351  46.844  1
237450  99.864  -76.363  46.814  1
237451  99.884  -76.367  46.784  1
237452  99.904  -76.370  46.754  1
237453  99.924  -76.373  46.725  1
237454  99.944  -76.376  46.697  1
237455  99.965  -76.380  46.667  1
237456  99.985  -76.384  46.636  1
237457  100.003  -76.395  46.607  1
237458  100.021  -76.408  46.576  1
237459  100.055  -76.415  46.543  1
237460  100.092  -76.420  46.510  1
237461  100.130  -76.426  46.479  1
237462  100.168  -76.432  46.446  1
237463  100.206  -76.437  46.413  1
237464  100.244  -76.442  46.378  1
237465  100.282  -76.448  46.343  1
237466  100.312  -76.456  46.307  1
237467  100.330  -76.469  46.271  1
237468  100.347  -76.482  46.236  1
237469  100.364  -76.494  46.200  1
237470  100.381  -76.507  46.164  1
237471  100.398  -76.520  46.127  1
237472  100.415  -76.533  46.090  1
237473  100.432  -76.545  46.055  1
237474  100.450  -76.558  46.022  1
237475  100.467  -76.571  45.989  1
237476  100.484  -76.583  45.958  1
237477  100.501  -76.592  45.928  1
237478  100.520  -76.584  45.899  1
237479  100.540  -76.592  45.871  1
237480  100.559  -76.605  45.846  1
237481  100.578  -76.624  45.821  1
237482  100.597  -76.643  45.797  1
237483  100.616  -76.661  45.774  1
237484  100.642  -76.674  45.753  1
237485  100.687  -76.668  45.732  1
237486  100.732  -76.662  45.711  1
237487  100.777  -76.656  45.692  1
237488  100.821  -76.651  45.673  1
237489  100.866  -76.645  45.652  1
237490  100.896  -76.651  45.632  1
237491  100.919  -76.660  45.611  1
237492  100.943  -76.669  45.590  1
237493  100.967  -76.678  45.568  1
237494  100.991  -76.687  45.547  1
237495  101.015  -76.696  45.527  1
237496  101.039  -76.705  45.506  1
237497  101.066  -76.716  45.485  1
237498  101.094  -76.727  45.464  1
237499  101.122  -76.737  45.442  1
237500  101.149  -76.747  45.423  1
237501  101.172  -76.759  45.405  1
237502  101.187  -76.771  45.387  1
237503  101.202  -76.783  45.370  1
237504  101.216  -76.795  45.354  1
237505  101.231  -76.806  45.338  1
237506  101.246  -76.818  45.324  1
237507  101.261  -76.831  45.312  1
237508  101.275  -76.843  45.300  1
237509  101.290  -76.855  45.288  1
237510  101.305  -76.867  45.276  1
237511  101.320  -76.879  45.264  1
237512  101.334  -76.890  45.251  1
237513  101.349  -76.903  45.239  1
237514  101.363  -76.915  45.227  1
237515  101.379  -76.927  45.214  1
237516  101.393  -76.939  45.202  1
237517  101.408  -76.951  45.188  1
237518  101.423  -76.963  45.173  1
237519  101.438  -76.975  45.158  1
237520  101.452  -76.987  45.143  1
237521  101.469  -77.000  45.127  1
237522  101.492  -77.018  45.111  1
237523  101.515  -77.018  45.095  1
237524  101.538  -77.018  45.078  1
237525  101.560  -77.018  45.061  1
237526  101.583  -77.019  45.046  1
237527  101.606  -77.019  45.029  1
237528  101.629  -77.019  45.013  1
237529  101.652  -77.019  44.995  1
237530  101.672  -77.022  44.978  1
237531  101.691  -77.028  44.958  1
237532  101.710  -77.038  44.938  1
237533  101.730  -77.052  44.919  1
237534  101.749  -77.066  44.902  1
237535  101.769  -77.079  44.886  1
237536  101.788  -77.093  44.870  1
237537  101.809  -77.106  44.854  1
237538  101.828  -77.120  44.838  1
237539  101.848  -77.134  44.823  1
237540  101.868  -77.147  44.806  1
237541  101.887  -77.161  44.789  1
237542  101.907  -77.175  44.773  1
237543  101.926  -77.188  44.757  1
237544  101.950  -77.211  44.740  1
237545  101.973  -77.235  44.725  1
237546  101.996  -77.259  44.710  1
237547  102.019  -77.283  44.695  1
237548  102.042  -77.307  44.680  1
237549  102.065  -77.330  44.667  1
237550  102.088  -77.351  44.652  1
237551  102.110  -77.370  44.637  1
237552  102.131  -77.390  44.622  1
237553  102.153  -77.410  44.606  1
237554  102.175  -77.429  44.588  1
237555  102.194  -77.442  44.571  1
237556  102.211  -77.453  44.555  1
237557  102.229  -77.464  44.539  1
237558  102.246  -77.474  44.522  1
237559  102.264  -77.486  44.505  1
237560  102.281  -77.496  44.489  1
237561  102.300  -77.506  44.472  1
237562  102.320  -77.515  44.456  1
237563  102.340  -77.524  44.440  1
237564  102.360  -77.533  44.422  1
237565  102.389  -77.545  44.405  1
237566  102.410  -77.556  44.387  1
237567  102.436  -77.560  44.369  1
237568  102.470  -77.565  44.351  1
237569  102.507  -77.570  44.333  1
237570  102.543  -77.576  44.315  1
237571  102.579  -77.581  44.297  1
237572  102.615  -77.586  44.279  1
237573  102.652  -77.592  44.262  1
237574  102.688  -77.597  44.245  1
237575  102.725  -77.602  44.229  1
237576  102.761  -77.608  44.213  1
237577  102.797  -77.613  44.196  1
237578  102.833  -77.618  44.181  1
237579  102.870  -77.624  44.165  1
237580  102.906  -77.629  44.148  1
237581  102.942  -77.634  44.133  1
237582  102.979  -77.639  44.117  1
237583  103.015  -77.645  44.101  1
237584  103.051  -77.651  44.084  1
237585  103.088  -77.656  44.069  1
237586  103.124  -77.661  44.053  1
237849  92.293  -74.699  54.369  1
237850  92.317  -74.710  54.377  1
237851  92.342  -74.721  54.384  1
237852  92.366  -74.731  54.393  1
237853  92.390  -74.742  54.404  1
237854  92.415  -74.753  54.415  1
237855  92.439  -74.764  54.425  1
237856  92.464  -74.775  54.435  1
237857  92.488  -74.785  54.444  1
237858  92.503  -74.767  54.453  1
237859  92.527  -74.755  54.461  1
237860  92.554  -74.746  54.469  1
237861  92.580  -74.737  54.475  1
237862  92.606  -74.727  54.482  1
237863  92.636  -74.718  54.487  1
237864  92.667  -74.712  54.490  1
237865  92.700  -74.709  54.493  1
237866  92.733  -74.706  54.495  1
237867  92.766  -74.702  54.494  1
237868  92.800  -74.702  54.492  1
237869  92.834  -74.705  54.488  1
237870  92.867  -74.709  54.483  1
237871  92.901  -74.712  54.479  1
237872  92.935  -74.715  54.474  1
237873  92.968  -74.722  54.466  1
237874  93.001  -74.728  54.456  1
237875  93.035  -74.734  54.446  1
237876  93.068  -74.739  54.436  1
237877  93.101  -74.745  54.429  1
237878  93.134  -74.751  54.420  1
237879  93.167  -74.756  54.412  1
237880  93.191  -74.747  54.403  1
237881  93.214  -74.737  54.395  1
237882  93.237  -74.727  54.387  1
237883  93.261  -74.717  54.380  1
237884  93.284  -74.706  54.374  1
237885  93.307  -74.697  54.369  1
237886  93.331  -74.687  54.365  1
237887  93.354  -74.677  54.362  1
237888  93.377  -74.667  54.362  1
237889  93.401  -74.657  54.364  1
237890  93.424  -74.647  54.369  1
237891  93.447  -74.637  54.375  1
237892  93.471  -74.627  54.379  1
237893  93.494  -74.617  54.385  1
237894  93.517  -74.607  54.391  1
237895  93.541  -74.597  54.397  1
237896  93.564  -74.587  54.404  1
237897  93.587  -74.579  54.412  1
237898  93.618  -74.587  54.422  1
237899  93.651  -74.599  54.434  1
237900  93.683  -74.612  54.446  1
237901  93.714  -74.624  54.461  1
237902  93.747  -74.637  54.478  1
237903  93.778  -74.650  54.498  1
237904  93.810  -74.662  54.519  1
237905  93.842  -74.675  54.537  1
237906  93.873  -74.687  54.552  1
237907  93.905  -74.700  54.563  1
237908  93.937  -74.712  54.572  1
237909  93.962  -74.717  54.582  1
237910  93.979  -74.715  54.594  1
237911  93.996  -74.712  54.609  1
237912  94.012  -74.708  54.624  1
237913  94.028  -74.703  54.634  1
237914  94.044  -74.697  54.642  1
237915  94.059  -74.692  54.646  1
237916  94.075  -74.687  54.648  1
237917  94.091  -74.682  54.647  1
237918  94.107  -74.677  54.646  1
237919  94.123  -74.671  54.643  1
237920  94.139  -74.666  54.632  1
237921  94.159  -74.667  54.620  1
237922  94.180  -74.668  54.606  1
237923  94.201  -74.668  54.587  1
237924  94.223  -74.666  54.563  1
237925  94.246  -74.668  54.537  1
237926  94.269  -74.670  54.507  1
237927  94.292  -74.672  54.475  1
237928  94.316  -74.675  54.442  1
237929  94.337  -74.677  54.411  1
237930  94.356  -74.679  54.381  1
237931  94.376  -74.681  54.355  1
237932  94.395  -74.683  54.332  1
237933  94.413  -74.685  54.308  1
237934  94.430  -74.689  54.282  1
237935  94.448  -74.692  54.254  1
237936  94.465  -74.695  54.225  1
237937  94.484  -74.697  54.197  1
237938  94.505  -74.700  54.171  1
237939  94.527  -74.702  54.146  1
237940  94.548  -74.704  54.118  1
237941  94.569  -74.706  54.090  1
237942  94.590  -74.708  54.061  1
237943  94.609  -74.708  54.033  1
237944  94.632  -74.711  54.011  1
237945  94.661  -74.717  53.995  1
237946  94.689  -74.723  53.983  1
237947  94.717  -74.729  53.967  1
237948  94.745  -74.735  53.947  1
237949  94.773  -74.741  53.923  1
237950  94.802  -74.747  53.897  1
237951  94.830  -74.753  53.867  1
237952  94.858  -74.759  53.831  1
237953  94.886  -74.766  53.791  1
237954  94.914  -74.772  53.748  1
237955  94.943  -74.778  53.702  1
237956  94.971  -74.784  53.656  1
237957  94.999  -74.790  53.608  1
237958  95.027  -74.796  53.557  1
237959  95.045  -74.799  53.503  1
237960  95.039  -74.789  53.447  1
237961  95.033  -74.779  53.389  1
237962  95.028  -74.769  53.332  1
237963  95.022  -74.759  53.276  1
237964  95.016  -74.749  53.217  1
237965  95.010  -74.739  53.157  1
237966  95.017  -74.735  53.096  1
237967  95.049  -74.742  53.030  1
237968  95.081  -74.749  52.965  1
237969  95.115  -74.765  52.901  1
237970  95.148  -74.780  52.840  1
237971  95.182  -74.796  52.781  1
237972  95.215  -74.811  52.724  1
237973  95.249  -74.827  52.667  1
237974  95.282  -74.842  52.610  1
237975  95.312  -74.854  52.551  1
237976  95.340  -74.865  52.493  1
237977  95.368  -74.875  52.434  1
237978  95.395  -74.885  52.375  1
237979  95.423  -74.896  52.318  1
237980  95.451  -74.907  52.262  1
237981  95.477  -74.912  52.207  1
237982  95.501  -74.911  52.155  1
237983  95.527  -74.910  52.107  1
237984  95.551  -74.909  52.060  1
237985  95.583  -74.888  52.015  1
237986  95.615  -74.862  51.971  1
237987  95.648  -74.836  51.929  1
237988  95.672  -74.820  51.889  1
237989  95.690  -74.813  51.850  1
237990  95.708  -74.807  51.813  1
237991  95.726  -74.800  51.777  1
237992  95.744  -74.794  51.743  1
237993  95.764  -74.791  51.709  1
237994  95.805  -74.817  51.678  1
237995  95.845  -74.843  51.647  1
237996  95.886  -74.869  51.616  1
237997  95.926  -74.894  51.587  1
237998  95.967  -74.920  51.559  1
237999  96.005  -74.935  51.532  1
238000  96.036  -74.941  51.505  1
238001  96.067  -74.947  51.480  1
238002  96.100  -74.954  51.456  1
238003  96.131  -74.960  51.432  1
238004  96.163  -74.966  51.408  1
238005  96.195  -74.973  51.387  1
238006  96.227  -74.979  51.368  1
238007  96.258  -74.985  51.350  1
238008  96.290  -74.992  51.334  1
238009  96.322  -74.998  51.318  1
238010  96.354  -75.005  51.302  1
238011  96.385  -75.011  51.285  1
238012  96.417  -75.018  51.268  1
238013  96.449  -75.024  51.250  1
238014  96.469  -75.035  51.231  1
238015  96.484  -75.049  51.211  1
238016  96.499  -75.063  51.189  1
238017  96.517  -75.077  51.166  1
238018  96.537  -75.091  51.144  1
238019  96.558  -75.106  51.121  1
238020  96.579  -75.120  51.098  1
238021  96.605  -75.130  51.077  1
238022  96.635  -75.136  51.056  1
238023  96.666  -75.142  51.035  1
238024  96.696  -75.147  51.015  1
238025  96.727  -75.153  50.994  1
238026  96.757  -75.158  50.972  1
238027  96.788  -75.163  50.949  1
238028  96.813  -75.175  50.927  1
238029  96.838  -75.185  50.907  1
238030  96.864  -75.197  50.889  1
238031  96.889  -75.208  50.871  1
238032  96.914  -75.219  50.852  1
238033  96.940  -75.230  50.832  1
238034  96.932  -75.327  50.809  1
238035  96.958  -75.330  50.784  1
238036  96.984  -75.333  50.758  1
238037  97.010  -75.336  50.731  1
238038  97.036  -75.339  50.704  1
238039  97.063  -75.342  50.677  1
238040  97.089  -75.345  50.651  1
238041  97.115  -75.348  50.623  1
238042  97.141  -75.351  50.596  1
238043  97.167  -75.354  50.568  1
238044  97.193  -75.357  50.540  1
238045  97.219  -75.362  50.509  1
238046  97.244  -75.373  50.477  1
238047  97.261  -75.382  50.445  1
238048  97.278  -75.390  50.411  1
238049  97.295  -75.398  50.378  1
238050  97.312  -75.406  50.346  1
238051  97.329  -75.414  50.316  1
238052  97.346  -75.423  50.287  1
238053  97.363  -75.430  50.258  1
238054  97.379  -75.439  50.229  1
238055  97.396  -75.447  50.198  1
238056  97.413  -75.455  50.167  1
238057  97.436  -75.462  50.134  1
238058  97.467  -75.469  50.100  1
238059  97.494  -75.475  50.065  1
238060  97.519  -75.481  50.029  1
238061  97.545  -75.488  49.992  1
238062  97.568  -75.492  49.956  1
238063  97.591  -75.496  49.921  1
238064  97.613  -75.500  49.886  1
238065  97.637  -75.504  49.852  1
238066  97.659  -75.508  49.817  1
238067  97.682  -75.512  49.779  1
238068  97.705  -75.516  49.739  1
238069  97.728  -75.520  49.696  1
238070  97.754  -75.523  49.652  1
238071  97.819  -75.511  49.606  1
238072  97.876  -75.508  49.560  1
238073  97.915  -75.524  49.514  1
238074  97.944  -75.548  49.466  1
238075  97.969  -75.574  49.418  1
238076  97.996  -75.599  49.370  1
238077  98.042  -75.608  49.324  1
238078  98.088  -75.616  49.280  1
238079  98.135  -75.624  49.235  1
238080  98.163  -75.634  49.191  1
238081  98.180  -75.645  49.146  1
238082  98.198  -75.655  49.101  1
238083  98.215  -75.665  49.056  1
238084  98.232  -75.676  49.010  1
238085  98.249  -75.686  48.965  1
238086  98.267  -75.696  48.919  1
238087  98.291  -75.707  48.873  1
238088  98.327  -75.718  48.826  1
238089  98.363  -75.730  48.780  1
238090  98.400  -75.741  48.734  1
238091  98.425  -75.772  48.688  1
238092  98.445  -75.811  48.641  1
238093  98.465  -75.850  48.595  1
238094  98.486  -75.888  48.549  1
238095  98.506  -75.927  48.503  1
238096  98.658  -75.887  48.458  1
238097  98.656  -75.862  48.413  1
238098  98.667  -75.868  48.370  1
238099  98.679  -75.873  48.327  1
238100  98.691  -75.878  48.284  1
238101  98.710  -75.897  48.242  1
238102  98.741  -75.939  48.200  1
238103  98.789  -75.933  48.161  1
238104  98.836  -75.916  48.123  1
238105  98.861  -75.914  48.085  1
238106  98.886  -75.912  48.048  1
238107  98.911  -75.910  48.013  1
238108  98.936  -75.908  47.979  1
238109  98.961  -75.908  47.946  1
238110  98.978  -75.924  47.914  1
238111  98.995  -75.941  47.883  1
238112  99.012  -75.956  47.855  1
238113  99.029  -75.973  47.827  1
238114  99.047  -75.989  47.801  1
238115  99.064  -76.006  47.776  1
238116  99.081  -76.022  47.752  1
238117  99.098  -76.038  47.728  1
238118  99.126  -76.050  47.705  1
238119  99.153  -76.062  47.683  1
238120  99.181  -76.073  47.659  1
238121  99.208  -76.085  47.636  1
238122  99.236  -76.097  47.614  1
238123  99.265  -76.112  47.592  1
238124  99.293  -76.126  47.568  1
238125  99.322  -76.141  47.543  1
238126  99.350  -76.155  47.518  1
238127  99.378  -76.170  47.492  1
238128  99.408  -76.180  47.466  1
238129  99.438  -76.185  47.441  1
238130  99.468  -76.190  47.415  1
238131  99.498  -76.195  47.387  1
238132  99.522  -76.199  47.359  1
238133  99.539  -76.201  47.332  1
238134  99.554  -76.204  47.306  1
238135  99.570  -76.207  47.282  1
238136  99.585  -76.209  47.257  1
238137  99.601  -76.212  47.231  1
238138  99.617  -76.214  47.202  1
238139  99.633  -76.217  47.174  1
238140  99.648  -76.220  47.143  1
238141  99.664  -76.222  47.112  1
238142  99.680  -76.225  47.082  1
238143  99.702  -76.229  47.051  1
238144  99.732  -76.233  47.021  1
238145  99.757  -76.242  46.990  1
238146  99.773  -76.263  46.957  1
238147  99.788  -76.282  46.924  1
238148  99.803  -76.303  46.894  1
238149  99.819  -76.321  46.865  1
238150  99.842  -76.336  46.835  1
238151  99.865  -76.342  46.805  1
238152  99.885  -76.346  46.775  1
238153  99.905  -76.349  46.746  1
238154  99.925  -76.353  46.716  1
238155  99.945  -76.357  46.688  1
238156  99.966  -76.360  46.659  1
238157  99.986  -76.364  46.629  1
238158  100.005  -76.373  46.599  1
238159  100.043  -76.379  46.569  1
238160  100.081  -76.384  46.537  1
238161  100.119  -76.390  46.504  1
238162  100.157  -76.395  46.472  1
238163  100.195  -76.401  46.440  1
238164  100.232  -76.406  46.407  1
238165  100.270  -76.412  46.373  1
238166  100.308  -76.417  46.338  1
238167  100.332  -76.428  46.303  1
238168  100.349  -76.440  46.266  1
238169  100.366  -76.453  46.232  1
238170  100.384  -76.466  46.195  1
238171  100.401  -76.479  46.158  1
238172  100.418  -76.491  46.122  1
238173  100.435  -76.504  46.085  1
238174  100.452  -76.517  46.050  1
238175  100.469  -76.530  46.016  1
238176  100.486  -76.542  45.984  1
238177  100.503  -76.555  45.952  1
238178  100.521  -76.567  45.922  1
238179  100.538  -76.580  45.893  1
238180  100.557  -76.586  45.865  1
238181  100.576  -76.605  45.839  1
238182  100.595  -76.624  45.814  1
238183  100.614  -76.643  45.790  1
238184  100.633  -76.661  45.768  1
238185  100.668  -76.665  45.746  1
238186  100.713  -76.659  45.725  1
238187  100.758  -76.654  45.705  1
238188  100.802  -76.648  45.686  1
238189  100.847  -76.643  45.667  1
238190  100.892  -76.636  45.647  1
238191  100.926  -76.638  45.626  1
238192  100.950  -76.648  45.604  1
238193  100.974  -76.657  45.583  1
238194  100.998  -76.666  45.562  1
238195  101.022  -76.675  45.541  1
238196  101.046  -76.684  45.519  1
238197  101.070  -76.693  45.499  1
238198  101.097  -76.704  45.478  1
238199  101.124  -76.715  45.457  1
238200  101.152  -76.724  45.436  1
238201  101.180  -76.735  45.417  1
238202  101.200  -76.746  45.398  1
238203  101.215  -76.759  45.380  1
238204  101.230  -76.771  45.362  1
238205  101.245  -76.783  45.347  1
238206  101.259  -76.795  45.332  1
238207  101.274  -76.807  45.318  1
238208  101.289  -76.819  45.305  1
238209  101.304  -76.831  45.293  1
238210  101.318  -76.843  45.281  1
238211  101.333  -76.855  45.268  1
238212  101.348  -76.867  45.256  1
238213  101.362  -76.879  45.243  1
238214  101.377  -76.891  45.231  1
238215  101.392  -76.903  45.218  1
238216  101.407  -76.915  45.206  1
238217  101.421  -76.927  45.193  1
238218  101.436  -76.939  45.179  1
238219  101.451  -76.951  45.164  1
238220  101.466  -76.963  45.149  1
238221  101.480  -76.975  45.133  1
238222  101.495  -76.987  45.117  1
238223  101.513  -76.993  45.101  1
238224  101.535  -76.993  45.084  1
238225  101.557  -76.993  45.067  1
238226  101.579  -76.993  45.051  1
238227  101.600  -76.993  45.035  1
238228  101.622  -76.993  45.019  1
238229  101.645  -76.993  45.003  1
238230  101.668  -76.994  44.986  1
238231  101.689  -76.995  44.967  1
238232  101.709  -77.009  44.948  1
238233  101.729  -77.022  44.928  1
238234  101.748  -77.036  44.908  1
238235  101.768  -77.050  44.891  1
238236  101.788  -77.063  44.875  1
238237  101.808  -77.077  44.859  1
238238  101.827  -77.091  44.842  1
238239  101.847  -77.104  44.826  1
238240  101.867  -77.118  44.811  1
238241  101.886  -77.132  44.795  1
238242  101.906  -77.145  44.779  1
238243  101.926  -77.159  44.763  1
238244  101.946  -77.173  44.748  1
238245  101.969  -77.197  44.731  1
238246  101.992  -77.221  44.715  1
238247  102.016  -77.244  44.701  1
238248  102.039  -77.269  44.686  1
238249  102.062  -77.292  44.672  1
238250  102.084  -77.312  44.658  1
238251  102.106  -77.332  44.643  1
238252  102.127  -77.351  44.629  1
238253  102.149  -77.370  44.614  1
238254  102.171  -77.390  44.599  1
238255  102.192  -77.409  44.581  1
238256  102.212  -77.425  44.564  1
238257  102.230  -77.436  44.547  1
238258  102.247  -77.446  44.531  1
238259  102.265  -77.457  44.515  1
238260  102.282  -77.467  44.499  1
238261  102.300  -77.479  44.482  1
238262  102.318  -77.489  44.464  1
238263  102.335  -77.500  44.448  1
238264  102.352  -77.511  44.432  1
238265  102.373  -77.520  44.414  1
238266  102.396  -77.531  44.396  1
238267  102.422  -77.536  44.378  1
238268  102.458  -77.542  44.359  1
238269  102.495  -77.548  44.340  1
238270  102.531  -77.553  44.321  1
238271  102.568  -77.558  44.304  1
238272  102.604  -77.564  44.286  1
238273  102.640  -77.569  44.269  1
238274  102.676  -77.574  44.251  1
238275  102.713  -77.580  44.235  1
238276  102.749  -77.585  44.219  1
238277  102.786  -77.590  44.203  1
238278  102.822  -77.595  44.188  1
238279  102.858  -77.601  44.171  1
238280  102.894  -77.606  44.155  1
238281  102.930  -77.611  44.139  1
238282  102.967  -77.617  44.124  1
238283  103.003  -77.622  44.108  1
238284  103.039  -77.627  44.091  1
238285  103.076  -77.633  44.075  1
238551  92.319  -74.678  54.381  1
238552  92.344  -74.688  54.388  1
238553  92.368  -74.699  54.396  1
238554  92.392  -74.709  54.408  1
238555  92.417  -74.721  54.418  1
238556  92.441  -74.731  54.428  1
238557  92.465  -74.742  54.437  1
238558  92.490  -74.753  54.445  1
238559  92.508  -74.744  54.453  1
238560  92.528  -74.728  54.461  1
238561  92.555  -74.718  54.469  1
238562  92.582  -74.709  54.477  1
238563  92.609  -74.700  54.484  1
238564  92.637  -74.692  54.489  1
238565  92.668  -74.684  54.494  1
238566  92.698  -74.675  54.497  1
238567  92.731  -74.672  54.499  1
238568  92.764  -74.669  54.500  1
238569  92.797  -74.668  54.498  1
238570  92.831  -74.672  54.496  1
238571  92.865  -74.675  54.494  1
238572  92.899  -74.681  54.493  1
238573  92.932  -74.686  54.491  1
238574  92.965  -74.692  54.485  1
238575  92.998  -74.698  54.477  1
238576  93.031  -74.704  54.468  1
238577  93.065  -74.709  54.459  1
238578  93.098  -74.715  54.452  1
238579  93.132  -74.722  54.444  1
238580  93.165  -74.727  54.437  1
238581  93.194  -74.726  54.429  1
238582  93.217  -74.716  54.422  1
238583  93.240  -74.706  54.415  1
238584  93.264  -74.696  54.409  1
238585  93.287  -74.686  54.405  1
238586  93.310  -74.676  54.401  1
238587  93.334  -74.666  54.397  1
238588  93.357  -74.656  54.394  1
238589  93.380  -74.646  54.395  1
238590  93.404  -74.637  54.399  1
238591  93.427  -74.626  54.405  1
238592  93.450  -74.616  54.412  1
238593  93.474  -74.606  54.418  1
238594  93.497  -74.596  54.422  1
238595  93.520  -74.587  54.427  1
238596  93.544  -74.577  54.434  1
238597  93.567  -74.567  54.440  1
238598  93.589  -74.559  54.445  1
238599  93.612  -74.556  54.452  1
238600  93.644  -74.568  54.460  1
238601  93.676  -74.581  54.470  1
238602  93.707  -74.593  54.482  1
238603  93.739  -74.606  54.496  1
238604  93.771  -74.618  54.513  1
238605  93.802  -74.631  54.531  1
238606  93.834  -74.643  54.546  1
238607  93.866  -74.656  54.558  1
238608  93.898  -74.668  54.569  1
238609  93.929  -74.681  54.581  1
238610  93.956  -74.688  54.593  1
238611  93.977  -74.689  54.606  1
238612  93.995  -74.687  54.622  1
238613  94.012  -74.685  54.638  1
238614  94.029  -74.683  54.649  1
238615  94.046  -74.680  54.657  1
238616  94.062  -74.678  54.661  1
238617  94.078  -74.673  54.661  1
238618  94.095  -74.668  54.659  1
238619  94.110  -74.663  54.656  1
238620  94.126  -74.658  54.651  1
238621  94.142  -74.653  54.638  1
238622  94.159  -74.649  54.625  1
238623  94.180  -74.650  54.611  1
238624  94.201  -74.648  54.591  1
238625  94.222  -74.646  54.567  1
238626  94.245  -74.646  54.542  1
238627  94.268  -74.649  54.515  1
238628  94.291  -74.650  54.484  1
238629  94.315  -74.653  54.452  1
238630  94.335  -74.655  54.422  1
238631  94.354  -74.657  54.393  1
238632  94.373  -74.659  54.367  1
238633  94.393  -74.661  54.346  1
238634  94.412  -74.663  54.324  1
238635  94.430  -74.665  54.298  1
238636  94.448  -74.668  54.269  1
238637  94.465  -74.672  54.238  1
238638  94.485  -74.675  54.208  1
238639  94.506  -74.676  54.177  1
238640  94.528  -74.678  54.150  1
238641  94.549  -74.681  54.120  1
238642  94.570  -74.683  54.089  1
238643  94.591  -74.685  54.059  1
238644  94.611  -74.686  54.028  1
238645  94.639  -74.692  54.003  1
238646  94.668  -74.698  53.983  1
238647  94.696  -74.704  53.967  1
238648  94.724  -74.710  53.952  1
238649  94.752  -74.716  53.933  1
238650  94.780  -74.722  53.911  1
238651  94.809  -74.728  53.886  1
238652  94.836  -74.734  53.855  1
238653  94.863  -74.740  53.820  1
238654  94.890  -74.747  53.781  1
238655  94.917  -74.753  53.738  1
238656  94.944  -74.759  53.695  1
238657  94.970  -74.766  53.650  1
238658  94.997  -74.772  53.605  1
238659  95.023  -74.778  53.556  1
238660  95.031  -74.773  53.503  1
238661  95.030  -74.762  53.447  1
238662  95.029  -74.751  53.390  1
238663  95.028  -74.740  53.331  1
238664  95.026  -74.731  53.275  1
238665  95.020  -74.720  53.217  1
238666  95.014  -74.710  53.157  1
238667  95.023  -74.707  53.096  1
238668  95.056  -74.718  53.030  1
238669  95.089  -74.734  52.965  1
238670  95.123  -74.750  52.900  1
238671  95.157  -74.765  52.841  1
238672  95.190  -74.781  52.782  1
238673  95.224  -74.796  52.724  1
238674  95.257  -74.812  52.668  1
238675  95.290  -74.827  52.610  1
238676  95.321  -74.840  52.552  1
238677  95.348  -74.850  52.494  1
238678  95.376  -74.860  52.436  1
238679  95.403  -74.871  52.377  1
238680  95.431  -74.881  52.320  1
238681  95.459  -74.891  52.265  1
238682  95.484  -74.892  52.211  1
238683  95.509  -74.891  52.159  1
238684  95.534  -74.890  52.110  1
238685  95.558  -74.889  52.063  1
238686  95.585  -74.883  52.018  1
238687  95.618  -74.857  51.974  1
238688  95.651  -74.831  51.932  1
238689  95.683  -74.805  51.892  1
238690  95.716  -74.779  51.853  1
238691  95.733  -74.772  51.814  1
238692  95.751  -74.766  51.778  1
238693  95.768  -74.759  51.743  1
238694  95.787  -74.753  51.709  1
238695  95.820  -74.769  51.678  1
238696  95.861  -74.795  51.646  1
238697  95.901  -74.821  51.615  1
238698  95.942  -74.847  51.586  1
238699  95.982  -74.873  51.557  1
238700  96.018  -74.909  51.529  1
238701  96.050  -74.922  51.502  1
238702  96.080  -74.933  51.476  1
238703  96.111  -74.944  51.451  1
238704  96.143  -74.952  51.427  1
238705  96.174  -74.959  51.405  1
238706  96.206  -74.965  51.384  1
238707  96.238  -74.971  51.365  1
238708  96.269  -74.978  51.347  1
238709  96.301  -74.984  51.331  1
238710  96.333  -74.991  51.317  1
238711  96.365  -74.997  51.301  1
238712  96.396  -75.004  51.285  1
238713  96.428  -75.010  51.267  1
238714  96.459  -75.016  51.249  1
238715  96.474  -75.030  51.231  1
238716  96.489  -75.044  51.212  1
238717  96.509  -75.058  51.193  1
238718  96.529  -75.073  51.172  1
238719  96.550  -75.087  51.150  1
238720  96.571  -75.101  51.128  1
238721  96.591  -75.116  51.106  1
238722  96.613  -75.129  51.085  1
238723  96.644  -75.135  51.065  1
238724  96.674  -75.141  51.044  1
238725  96.705  -75.146  51.024  1
238726  96.735  -75.151  51.002  1
238727  96.766  -75.157  50.980  1
238728  96.796  -75.163  50.957  1
238729  96.827  -75.168  50.935  1
238730  96.857  -75.174  50.916  1
238731  96.888  -75.179  50.898  1
238732  96.914  -75.190  50.880  1
238733  96.939  -75.201  50.862  1
238734  96.964  -75.212  50.842  1
238735  96.943  -75.346  50.820  1
238736  96.969  -75.349  50.795  1
238737  96.995  -75.352  50.768  1
238738  97.021  -75.355  50.742  1
238739  97.047  -75.358  50.717  1
238740  97.074  -75.361  50.691  1
238741  97.100  -75.364  50.666  1
238742  97.125  -75.364  50.639  1
238743  97.150  -75.356  50.614  1
238744  97.175  -75.348  50.587  1
238745  97.199  -75.339  50.560  1
238746  97.222  -75.338  50.528  1
238747  97.245  -75.345  50.496  1
238748  97.263  -75.354  50.464  1
238749  97.280  -75.362  50.430  1
238750  97.297  -75.370  50.397  1
238751  97.314  -75.378  50.365  1
238752  97.330  -75.386  50.334  1
238753  97.348  -75.394  50.305  1
238754  97.364  -75.402  50.277  1
238755  97.381  -75.411  50.248  1
238756  97.398  -75.418  50.219  1
238757  97.415  -75.427  50.188  1
238758  97.440  -75.433  50.155  1
238759  97.470  -75.440  50.121  1
238760  97.499  -75.447  50.086  1
238761  97.524  -75.453  50.049  1
238762  97.550  -75.459  50.011  1
238763  97.576  -75.466  49.975  1
238764  97.599  -75.470  49.939  1
238765  97.621  -75.474  49.904  1
238766  97.644  -75.478  49.870  1
238767  97.667  -75.482  49.834  1
238768  97.690  -75.486  49.797  1
238769  97.713  -75.490  49.755  1
238770  97.735  -75.494  49.711  1
238771  97.774  -75.493  49.666  1
238772  97.839  -75.481  49.621  1
238773  97.882  -75.493  49.574  1
238774  97.921  -75.508  49.527  1
238775  97.952  -75.530  49.479  1
238776  97.979  -75.555  49.431  1
238777  98.009  -75.577  49.383  1
238778  98.056  -75.586  49.338  1
238779  98.102  -75.594  49.293  1
238780  98.143  -75.602  49.249  1
238781  98.164  -75.612  49.205  1
238782  98.178  -75.629  49.158  1
238783  98.195  -75.640  49.112  1
238784  98.212  -75.649  49.066  1
238785  98.229  -75.660  49.020  1
238786  98.246  -75.671  48.974  1
238787  98.264  -75.681  48.928  1
238788  98.309  -75.690  48.882  1
238789  98.365  -75.697  48.837  1
238790  98.402  -75.709  48.790  1
238791  98.438  -75.720  48.744  1
238792  98.469  -75.740  48.698  1
238793  98.490  -75.779  48.652  1
238794  98.510  -75.818  48.605  1
238795  98.530  -75.856  48.558  1
238796  98.528  -75.865  48.512  1
238797  98.622  -75.859  48.466  1
238798  98.675  -75.840  48.421  1
238799  98.687  -75.846  48.377  1
238800  98.699  -75.851  48.333  1
238801  98.710  -75.856  48.288  1
238802  98.722  -75.862  48.245  1
238803  98.735  -75.869  48.203  1
238804  98.776  -75.886  48.161  1
238805  98.830  -75.864  48.122  1
238806  98.869  -75.852  48.085  1
238807  98.895  -75.850  48.048  1
238808  98.918  -75.852  48.012  1
238809  98.935  -75.868  47.977  1
238810  98.952  -75.884  47.943  1
238811  98.970  -75.900  47.911  1
238812  98.987  -75.916  47.880  1
238813  99.004  -75.933  47.850  1
238814  99.021  -75.949  47.822  1
238815  99.039  -75.966  47.795  1
238816  99.056  -75.981  47.770  1
238817  99.073  -75.998  47.746  1
238818  99.090  -76.014  47.722  1
238819  99.118  -76.025  47.697  1
238820  99.146  -76.038  47.673  1
238821  99.174  -76.053  47.649  1
238822  99.203  -76.068  47.626  1
238823  99.231  -76.082  47.604  1
238824  99.260  -76.097  47.580  1
238825  99.288  -76.111  47.555  1
238826  99.317  -76.126  47.530  1
238827  99.346  -76.141  47.504  1
238828  99.374  -76.151  47.478  1
238829  99.405  -76.155  47.452  1
238830  99.434  -76.160  47.427  1
238831  99.465  -76.165  47.402  1
238832  99.494  -76.169  47.374  1
238833  99.524  -76.175  47.346  1
238834  99.543  -76.178  47.319  1
238835  99.559  -76.180  47.294  1
238836  99.574  -76.183  47.271  1
238837  99.590  -76.185  47.246  1
238838  99.606  -76.188  47.219  1
238839  99.622  -76.191  47.191  1
238840  99.637  -76.193  47.163  1
238841  99.653  -76.196  47.133  1
238842  99.668  -76.198  47.102  1
238843  99.689  -76.202  47.071  1
238844  99.719  -76.207  47.041  1
238845  99.749  -76.211  47.010  1
238846  99.775  -76.219  46.979  1
238847  99.791  -76.238  46.947  1
238848  99.806  -76.259  46.914  1
238849  99.822  -76.279  46.883  1
238850  99.837  -76.299  46.855  1
238851  99.854  -76.320  46.825  1
238852  99.874  -76.325  46.796  1
238853  99.895  -76.329  46.767  1
238854  99.915  -76.332  46.737  1
238855  99.936  -76.336  46.707  1
238856  99.956  -76.339  46.679  1
238857  99.977  -76.343  46.651  1
238858  99.999  -76.344  46.621  1
238859  100.031  -76.344  46.591  1
238860  100.070  -76.348  46.561  1
238861  100.108  -76.354  46.529  1
238862  100.145  -76.359  46.497  1
238863  100.184  -76.364  46.466  1
238864  100.221  -76.370  46.434  1
238865  100.259  -76.376  46.401  1
238866  100.297  -76.381  46.367  1
238867  100.335  -76.386  46.333  1
238868  100.352  -76.399  46.298  1
238869  100.369  -76.412  46.262  1
238870  100.387  -76.425  46.227  1
238871  100.404  -76.437  46.190  1
238872  100.421  -76.450  46.153  1
238873  100.438  -76.463  46.116  1
238874  100.455  -76.476  46.080  1
238875  100.472  -76.489  46.045  1
238876  100.489  -76.501  46.011  1
238877  100.506  -76.514  45.978  1
238878  100.524  -76.527  45.946  1
238879  100.540  -76.548  45.916  1
238880  100.558  -76.565  45.887  1
238881  100.574  -76.586  45.859  1
238882  100.593  -76.605  45.833  1
238883  100.612  -76.624  45.808  1
238884  100.631  -76.642  45.784  1
238885  100.650  -76.661  45.762  1
238886  100.694  -76.656  45.742  1
238887  100.738  -76.651  45.720  1
238888  100.783  -76.645  45.700  1
238889  100.828  -76.640  45.681  1
238890  100.873  -76.634  45.661  1
238891  100.917  -76.628  45.641  1
238892  100.957  -76.626  45.620  1
238893  100.981  -76.636  45.598  1
238894  101.005  -76.645  45.577  1
238895  101.029  -76.654  45.556  1
238896  101.053  -76.663  45.534  1
238897  101.076  -76.672  45.512  1
238898  101.101  -76.681  45.492  1
238899  101.127  -76.692  45.471  1
238900  101.156  -76.702  45.450  1
238901  101.183  -76.712  45.429  1
238902  101.211  -76.723  45.411  1
238903  101.229  -76.735  45.392  1
238904  101.244  -76.747  45.373  1
238905  101.258  -76.759  45.356  1
238906  101.273  -76.771  45.340  1
238907  101.288  -76.783  45.325  1
238908  101.302  -76.795  45.311  1
238909  101.317  -76.807  45.298  1
238910  101.332  -76.819  45.286  1
238911  101.347  -76.831  45.273  1
238912  101.361  -76.843  45.260  1
238913  101.376  -76.855  45.248  1
238914  101.391  -76.867  45.235  1
238915  101.406  -76.879  45.222  1
238916  101.420  -76.891  45.209  1
238917  101.435  -76.903  45.197  1
238918  101.450  -76.915  45.183  1
238919  101.465  -76.927  45.168  1
238920  101.479  -76.939  45.154  1
238921  101.494  -76.951  45.138  1
238922  101.509  -76.963  45.122  1
238923  101.528  -76.968  45.106  1
238924  101.549  -76.968  45.090  1
238925  101.571  -76.968  45.073  1
238926  101.593  -76.969  45.055  1
238927  101.614  -76.969  45.039  1
238928  101.636  -76.969  45.024  1
238929  101.658  -76.969  45.007  1
238930  101.679  -76.969  44.991  1
238931  101.699  -76.973  44.973  1
238932  101.715  -76.984  44.955  1
238933  101.731  -76.996  44.937  1
238934  101.748  -77.006  44.917  1
238935  101.767  -77.020  44.897  1
238936  101.787  -77.034  44.880  1
238937  101.807  -77.047  44.864  1
238938  101.826  -77.061  44.848  1
238939  101.846  -77.075  44.831  1
238940  101.866  -77.088  44.815  1
238941  101.886  -77.102  44.799  1
238942  101.905  -77.116  44.784  1
238943  101.925  -77.129  44.768  1
238944  101.945  -77.143  44.753  1
238945  101.965  -77.160  44.737  1
238946  101.988  -77.183  44.721  1
238947  102.012  -77.207  44.705  1
238948  102.035  -77.231  44.691  1
238949  102.058  -77.254  44.676  1
238950  102.080  -77.273  44.662  1
238951  102.101  -77.292  44.649  1
238952  102.123  -77.312  44.634  1
238953  102.145  -77.331  44.619  1
238954  102.167  -77.351  44.605  1
238955  102.188  -77.370  44.590  1
238956  102.210  -77.389  44.572  1
238957  102.231  -77.407  44.556  1
238958  102.249  -77.418  44.539  1
238959  102.266  -77.429  44.522  1
238960  102.283  -77.439  44.507  1
238961  102.301  -77.450  44.491  1
238962  102.319  -77.461  44.474  1
238963  102.336  -77.472  44.457  1
238964  102.354  -77.483  44.440  1
238965  102.371  -77.493  44.422  1
238966  102.389  -77.504  44.404  1
238967  102.408  -77.508  44.386  1
238968  102.444  -77.516  44.366  1
238969  102.482  -77.523  44.347  1
238970  102.519  -77.530  44.328  1
238971  102.556  -77.535  44.311  1
238972  102.592  -77.540  44.293  1
238973  102.628  -77.545  44.276  1
238974  102.665  -77.551  44.258  1
238975  102.701  -77.557  44.241  1
238976  102.737  -77.562  44.225  1
238977  102.773  -77.567  44.209  1
238978  102.810  -77.573  44.194  1
238979  102.846  -77.578  44.179  1
238980  102.883  -77.583  44.162  1
238981  102.919  -77.589  44.146  1
238982  102.955  -77.594  44.130  1
238983  102.992  -77.599  44.114  1
238984  103.028  -77.605  44.098  1
238985  103.064  -77.610  44.082  1
239253  92.346  -74.656  54.393  1
239254  92.370  -74.666  54.401  1
239255  92.394  -74.678  54.411  1
239256  92.419  -74.688  54.421  1
239257  92.443  -74.699  54.430  1
239258  92.467  -74.709  54.439  1
239259  92.492  -74.721  54.448  1
239260  92.512  -74.719  54.455  1
239261  92.530  -74.701  54.463  1
239262  92.557  -74.692  54.472  1
239263  92.583  -74.683  54.479  1
239264  92.610  -74.673  54.487  1
239265  92.639  -74.665  54.492  1
239266  92.669  -74.656  54.496  1
239267  92.699  -74.648  54.499  1
239268  92.729  -74.640  54.502  1
239269  92.762  -74.636  54.504  1
239270  92.795  -74.635  54.504  1
239271  92.829  -74.639  54.502  1
239272  92.862  -74.645  54.502  1
239273  92.896  -74.650  54.502  1
239274  92.929  -74.656  54.503  1
239275  92.962  -74.662  54.501  1
239276  92.995  -74.668  54.496  1
239277  93.029  -74.674  54.488  1
239278  93.062  -74.680  54.481  1
239279  93.095  -74.686  54.475  1
239280  93.129  -74.692  54.469  1
239281  93.162  -74.697  54.461  1
239282  93.195  -74.703  54.454  1
239283  93.220  -74.695  54.449  1
239284  93.243  -74.685  54.444  1
239285  93.266  -74.675  54.439  1
239286  93.290  -74.665  54.435  1
239287  93.313  -74.656  54.432  1
239288  93.336  -74.646  54.429  1
239289  93.360  -74.636  54.427  1
239290  93.383  -74.625  54.428  1
239291  93.406  -74.615  54.433  1
239292  93.430  -74.606  54.440  1
239293  93.453  -74.596  54.448  1
239294  93.476  -74.586  54.456  1
239295  93.500  -74.576  54.461  1
239296  93.523  -74.566  54.467  1
239297  93.547  -74.556  54.474  1
239298  93.570  -74.546  54.481  1
239299  93.591  -74.543  54.484  1
239300  93.613  -74.538  54.487  1
239301  93.636  -74.538  54.491  1
239302  93.668  -74.550  54.497  1
239303  93.700  -74.562  54.507  1
239304  93.731  -74.575  54.520  1
239305  93.763  -74.587  54.538  1
239306  93.795  -74.600  54.554  1
239307  93.827  -74.612  54.567  1
239308  93.858  -74.625  54.577  1
239309  93.890  -74.637  54.584  1
239310  93.922  -74.650  54.593  1
239311  93.950  -74.659  54.604  1
239312  93.972  -74.661  54.617  1
239313  93.993  -74.661  54.634  1
239314  94.011  -74.659  54.650  1
239315  94.028  -74.657  54.661  1
239316  94.045  -74.655  54.668  1
239317  94.061  -74.653  54.672  1
239318  94.078  -74.650  54.674  1
239319  94.095  -74.648  54.671  1
239320  94.112  -74.646  54.666  1
239321  94.129  -74.643  54.659  1
239322  94.145  -74.639  54.647  1
239323  94.161  -74.634  54.633  1
239324  94.180  -74.632  54.617  1
239325  94.201  -74.629  54.595  1
239326  94.222  -74.627  54.570  1
239327  94.244  -74.624  54.546  1
239328  94.267  -74.627  54.522  1
239329  94.290  -74.628  54.495  1
239330  94.314  -74.631  54.464  1
239331  94.333  -74.633  54.435  1
239332  94.352  -74.635  54.406  1
239333  94.371  -74.637  54.381  1
239334  94.391  -74.639  54.361  1
239335  94.410  -74.641  54.339  1
239336  94.429  -74.643  54.314  1
239337  94.447  -74.646  54.284  1
239338  94.465  -74.649  54.253  1
239339  94.486  -74.651  54.219  1
239340  94.507  -74.653  54.185  1
239341  94.529  -74.656  54.154  1
239342  94.550  -74.657  54.121  1
239343  94.571  -74.659  54.088  1
239344  94.592  -74.662  54.056  1
239345  94.615  -74.667  54.024  1
239346  94.642  -74.673  53.995  1
239347  94.669  -74.680  53.971  1
239348  94.696  -74.686  53.952  1
239349  94.722  -74.692  53.936  1
239350  94.749  -74.698  53.918  1
239351  94.776  -74.705  53.896  1
239352  94.803  -74.711  53.870  1
239353  94.830  -74.717  53.838  1
239354  94.857  -74.723  53.804  1
239355  94.884  -74.730  53.766  1
239356  94.911  -74.736  53.724  1
239357  94.937  -74.742  53.681  1
239358  94.964  -74.748  53.638  1
239359  94.988  -74.753  53.593  1
239360  95.012  -74.758  53.546  1
239361  95.011  -74.747  53.494  1
239362  95.010  -74.737  53.439  1
239363  95.009  -74.726  53.382  1
239364  95.008  -74.715  53.324  1
239365  95.007  -74.705  53.267  1
239366  95.006  -74.694  53.210  1
239367  95.005  -74.684  53.152  1
239368  95.030  -74.687  53.091  1
239369  95.063  -74.703  53.027  1
239370  95.097  -74.718  52.963  1
239371  95.131  -74.734  52.900  1
239372  95.164  -74.750  52.841  1
239373  95.198  -74.765  52.783  1
239374  95.232  -74.781  52.725  1
239375  95.265  -74.796  52.668  1
239376  95.299  -74.812  52.610  1
239377  95.329  -74.825  52.552  1
239378  95.356  -74.835  52.494  1
239379  95.384  -74.845  52.437  1
239380  95.412  -74.856  52.379  1
239381  95.440  -74.866  52.322  1
239382  95.466  -74.873  52.267  1
239383  95.491  -74.872  52.213  1
239384  95.516  -74.872  52.161  1
239385  95.541  -74.870  52.112  1
239386  95.566  -74.869  52.065  1
239387  95.591  -74.869  52.021  1
239388  95.620  -74.853  51.977  1
239389  95.653  -74.826  51.935  1
239390  95.686  -74.800  51.895  1
239391  95.719  -74.774  51.855  1
239392  95.751  -74.748  51.817  1
239393  95.776  -74.732  51.780  1
239394  95.794  -74.725  51.745  1
239395  95.812  -74.718  51.709  1
239396  95.836  -74.722  51.677  1
239397  95.877  -74.747  51.645  1
239398  95.917  -74.773  51.614  1
239399  95.958  -74.799  51.584  1
239400  95.994  -74.833  51.554  1
239401  96.030  -74.869  51.525  1
239402  96.065  -74.897  51.497  1
239403  96.096  -74.907  51.471  1
239404  96.126  -74.918  51.446  1
239405  96.157  -74.928  51.423  1
239406  96.188  -74.939  51.400  1
239407  96.219  -74.950  51.379  1
239408  96.249  -74.960  51.360  1
239409  96.281  -74.969  51.343  1
239410  96.312  -74.976  51.328  1
239411  96.344  -74.982  51.314  1
239412  96.376  -74.989  51.300  1
239413  96.407  -74.995  51.284  1
239414  96.439  -75.002  51.267  1
239415  96.464  -75.011  51.249  1
239416  96.480  -75.025  51.232  1
239417  96.501  -75.039  51.215  1
239418  96.521  -75.054  51.197  1
239419  96.542  -75.068  51.179  1
239420  96.562  -75.082  51.157  1
239421  96.583  -75.097  51.135  1
239422  96.604  -75.112  51.114  1
239423  96.624  -75.126  51.092  1
239424  96.653  -75.134  51.072  1
239425  96.683  -75.139  51.053  1
239426  96.714  -75.145  51.032  1
239427  96.744  -75.151  51.009  1
239428  96.774  -75.156  50.986  1
239429  96.805  -75.161  50.964  1
239430  96.835  -75.167  50.943  1
239431  96.866  -75.173  50.924  1
239432  96.896  -75.178  50.906  1
239433  96.927  -75.184  50.889  1
239434  96.957  -75.189  50.871  1
239435  96.987  -75.193  50.852  1
239436  96.954  -75.365  50.830  1
239437  96.979  -75.365  50.805  1
239438  97.004  -75.357  50.779  1
239439  97.028  -75.348  50.755  1
239440  97.053  -75.340  50.731  1
239441  97.078  -75.332  50.707  1
239442  97.102  -75.323  50.682  1
239443  97.126  -75.315  50.657  1
239444  97.151  -75.307  50.632  1
239445  97.176  -75.298  50.606  1
239446  97.198  -75.301  50.578  1
239447  97.219  -75.308  50.548  1
239448  97.241  -75.317  50.516  1
239449  97.265  -75.325  50.483  1
239450  97.282  -75.333  50.450  1
239451  97.299  -75.342  50.417  1
239452  97.315  -75.350  50.385  1
239453  97.332  -75.358  50.354  1
239454  97.349  -75.366  50.324  1
239455  97.366  -75.374  50.297  1
239456  97.383  -75.382  50.269  1
239457  97.400  -75.390  50.240  1
239458  97.417  -75.398  50.209  1
239459  97.443  -75.405  50.176  1
239460  97.473  -75.411  50.141  1
239461  97.504  -75.418  50.106  1
239462  97.529  -75.424  50.069  1
239463  97.555  -75.431  50.031  1
239464  97.581  -75.437  49.994  1
239465  97.606  -75.444  49.959  1
239466  97.630  -75.448  49.923  1
239467  97.652  -75.452  49.888  1
239468  97.675  -75.456  49.852  1
239469  97.698  -75.460  49.813  1
239470  97.721  -75.464  49.771  1
239471  97.743  -75.468  49.726  1
239472  97.794  -75.462  49.681  1
239473  97.848  -75.461  49.635  1
239474  97.887  -75.477  49.588  1
239475  97.927  -75.492  49.541  1
239476  97.961  -75.511  49.494  1
239477  97.987  -75.537  49.444  1
239478  98.023  -75.555  49.397  1
239479  98.069  -75.563  49.352  1
239480  98.114  -75.571  49.307  1
239481  98.139  -75.578  49.262  1
239482  98.164  -75.585  49.218  1
239483  98.178  -75.602  49.171  1
239484  98.191  -75.621  49.124  1
239485  98.205  -75.636  49.076  1
239486  98.223  -75.646  49.031  1
239487  98.240  -75.656  48.985  1
239488  98.257  -75.667  48.940  1
239489  98.315  -75.674  48.895  1
239490  98.374  -75.681  48.849  1
239491  98.433  -75.688  48.803  1
239492  98.476  -75.699  48.757  1
239493  98.512  -75.710  48.711  1
239494  98.534  -75.746  48.663  1
239495  98.555  -75.785  48.616  1
239496  98.555  -75.798  48.569  1
239497  98.544  -75.794  48.522  1
239498  98.643  -75.793  48.477  1
239499  98.689  -75.809  48.432  1
239500  98.701  -75.815  48.386  1
239501  98.713  -75.821  48.342  1
239502  98.725  -75.827  48.297  1
239503  98.737  -75.833  48.252  1
239504  98.750  -75.839  48.209  1
239505  98.774  -75.837  48.165  1
239506  98.826  -75.815  48.124  1
239507  98.876  -75.794  48.085  1
239508  98.895  -75.813  48.048  1
239509  98.912  -75.830  48.011  1
239510  98.929  -75.846  47.975  1
239511  98.947  -75.862  47.940  1
239512  98.964  -75.879  47.908  1
239513  98.982  -75.895  47.876  1
239514  98.999  -75.912  47.846  1
239515  99.016  -75.928  47.818  1
239516  99.034  -75.945  47.791  1
239517  99.052  -75.961  47.765  1
239518  99.069  -75.978  47.740  1
239519  99.086  -75.994  47.715  1
239520  99.113  -76.009  47.690  1
239521  99.141  -76.024  47.665  1
239522  99.170  -76.038  47.640  1
239523  99.198  -76.053  47.616  1
239524  99.227  -76.067  47.593  1
239525  99.255  -76.082  47.568  1
239526  99.284  -76.097  47.543  1
239527  99.312  -76.111  47.517  1
239528  99.342  -76.121  47.491  1
239529  99.371  -76.126  47.465  1
239530  99.402  -76.131  47.438  1
239531  99.431  -76.135  47.412  1
239532  99.462  -76.140  47.387  1
239533  99.491  -76.145  47.360  1
239534  99.521  -76.150  47.333  1
239535  99.548  -76.154  47.307  1
239536  99.563  -76.157  47.282  1
239537  99.579  -76.160  47.259  1
239538  99.595  -76.162  47.235  1
239539  99.611  -76.164  47.208  1
239540  99.626  -76.167  47.180  1
239541  99.642  -76.169  47.151  1
239542  99.657  -76.173  47.122  1
239543  99.676  -76.176  47.091  1
239544  99.706  -76.180  47.060  1
239545  99.735  -76.185  47.031  1
239546  99.765  -76.189  47.000  1
239547  99.794  -76.195  46.968  1
239548  99.809  -76.215  46.936  1
239549  99.825  -76.235  46.904  1
239550  99.840  -76.255  46.874  1
239551  99.856  -76.276  46.845  1
239552  99.875  -76.299  46.815  1
239553  99.896  -76.310  46.787  1
239554  99.916  -76.314  46.758  1
239555  99.936  -76.318  46.728  1
239556  99.957  -76.322  46.698  1
239557  99.977  -76.325  46.670  1
239558  100.001  -76.323  46.642  1
239559  100.025  -76.320  46.613  1
239560  100.053  -76.318  46.583  1
239561  100.093  -76.321  46.552  1
239562  100.134  -76.323  46.521  1
239563  100.172  -76.329  46.490  1
239564  100.210  -76.334  46.460  1
239565  100.248  -76.339  46.428  1
239566  100.286  -76.345  46.395  1
239567  100.324  -76.351  46.362  1
239568  100.355  -76.358  46.327  1
239569  100.372  -76.371  46.292  1
239570  100.389  -76.384  46.256  1
239571  100.406  -76.396  46.221  1
239572  100.423  -76.409  46.184  1
239573  100.440  -76.422  46.148  1
239574  100.458  -76.435  46.111  1
239575  100.475  -76.447  46.075  1
239576  100.492  -76.462  46.039  1
239577  100.508  -76.486  46.005  1
239578  100.524  -76.509  45.972  1
239579  100.540  -76.532  45.941  1
239580  100.559  -76.546  45.911  1
239581  100.579  -76.558  45.882  1
239582  100.591  -76.586  45.854  1
239583  100.610  -76.605  45.828  1
239584  100.629  -76.623  45.802  1
239585  100.648  -76.642  45.779  1
239586  100.675  -76.654  45.756  1
239587  100.719  -76.648  45.736  1
239588  100.764  -76.643  45.715  1
239589  100.809  -76.636  45.694  1
239590  100.853  -76.631  45.675  1
239591  100.898  -76.626  45.655  1
239592  100.943  -76.620  45.634  1
239593  100.988  -76.614  45.613  1
239594  101.012  -76.624  45.592  1
239595  101.036  -76.633  45.571  1
239596  101.060  -76.642  45.549  1
239597  101.084  -76.651  45.528  1
239598  101.108  -76.660  45.506  1
239599  101.131  -76.669  45.484  1
239600  101.159  -76.680  45.464  1
239601  101.186  -76.690  45.444  1
239602  101.214  -76.700  45.423  1
239603  101.242  -76.711  45.404  1
239604  101.257  -76.723  45.385  1
239605  101.272  -76.735  45.367  1
239606  101.286  -76.747  45.350  1
239607  101.302  -76.759  45.333  1
239608  101.316  -76.771  45.318  1
239609  101.331  -76.783  45.303  1
239610  101.345  -76.795  45.290  1
239611  101.360  -76.807  45.278  1
239612  101.375  -76.819  45.265  1
239613  101.390  -76.831  45.251  1
239614  101.404  -76.843  45.239  1
239615  101.419  -76.856  45.226  1
239616  101.434  -76.867  45.213  1
239617  101.449  -76.879  45.200  1
239618  101.463  -76.891  45.186  1
239619  101.478  -76.903  45.172  1
239620  101.493  -76.915  45.158  1
239621  101.507  -76.928  45.143  1
239622  101.522  -76.940  45.128  1
239623  101.542  -76.943  45.111  1
239624  101.563  -76.943  45.095  1
239625  101.585  -76.943  45.078  1
239626  101.607  -76.943  45.060  1
239627  101.628  -76.943  45.043  1
239628  101.650  -76.943  45.027  1
239629  101.672  -76.943  45.011  1
239630  101.693  -76.943  44.994  1
239631  101.710  -76.953  44.978  1
239632  101.727  -76.964  44.960  1
239633  101.743  -76.975  44.942  1
239634  101.759  -76.987  44.925  1
239635  101.776  -76.998  44.905  1
239636  101.792  -77.009  44.886  1
239637  101.809  -77.020  44.869  1
239638  101.826  -77.031  44.853  1
239639  101.845  -77.045  44.837  1
239640  101.865  -77.059  44.821  1
239641  101.885  -77.073  44.805  1
239642  101.904  -77.087  44.789  1
239643  101.924  -77.100  44.773  1
239644  101.944  -77.114  44.757  1
239645  101.964  -77.128  44.743  1
239646  101.985  -77.145  44.726  1
239647  102.008  -77.169  44.710  1
239648  102.031  -77.193  44.695  1
239649  102.054  -77.215  44.681  1
239650  102.076  -77.234  44.665  1
239651  102.097  -77.254  44.652  1
239652  102.119  -77.273  44.639  1
239653  102.140  -77.292  44.623  1
239654  102.163  -77.311  44.609  1
239655  102.184  -77.331  44.594  1
239656  102.206  -77.351  44.579  1
239657  102.228  -77.370  44.563  1
239658  102.249  -77.389  44.547  1
239659  102.267  -77.401  44.531  1
239660  102.285  -77.411  44.514  1
239661  102.302  -77.422  44.498  1
239662  102.320  -77.432  44.480  1
239663  102.337  -77.443  44.463  1
239664  102.355  -77.454  44.445  1
239665  102.373  -77.463  44.428  1
239666  102.393  -77.464  44.410  1
239667  102.412  -77.467  44.392  1
239668  102.433  -77.468  44.373  1
239669  102.452  -77.470  44.353  1
239670  102.486  -77.476  44.334  1
239671  102.524  -77.484  44.316  1
239672  102.562  -77.492  44.300  1
239673  102.600  -77.500  44.282  1
239674  102.638  -77.508  44.265  1
239675  102.676  -77.515  44.249  1
239676  102.715  -77.523  44.232  1
239677  102.752  -77.531  44.216  1
239678  102.790  -77.539  44.200  1
239679  102.828  -77.546  44.184  1
239680  102.867  -77.554  44.168  1
239681  102.904  -77.562  44.152  1
239682  102.943  -77.570  44.137  1
239683  102.980  -77.577  44.121  1
239684  103.016  -77.582  44.105  1
239685  103.052  -77.587  44.089  1
239955  92.372  -74.634  54.407  1
239956  92.396  -74.645  54.416  1
239957  92.421  -74.656  54.425  1
239958  92.445  -74.666  54.433  1
239959  92.470  -74.678  54.441  1
239960  92.494  -74.688  54.451  1
239961  92.517  -74.695  54.458  1
239962  92.532  -74.675  54.466  1
239963  92.559  -74.665  54.475  1
239964  92.585  -74.656  54.482  1
239965  92.612  -74.646  54.489  1
239966  92.640  -74.637  54.495  1
239967  92.670  -74.629  54.500  1
239968  92.701  -74.621  54.503  1
239969  92.731  -74.613  54.506  1
239970  92.761  -74.605  54.508  1
239971  92.793  -74.603  54.508  1
239972  92.826  -74.609  54.506  1
239973  92.859  -74.615  54.506  1
239974  92.893  -74.621  54.507  1
239975  92.926  -74.627  54.510  1
239976  92.959  -74.633  54.510  1
239977  92.993  -74.639  54.509  1
239978  93.026  -74.644  54.507  1
239979  93.059  -74.650  54.502  1
239980  93.092  -74.656  54.498  1
239981  93.126  -74.662  54.493  1
239982  93.159  -74.668  54.487  1
239983  93.192  -74.674  54.482  1
239984  93.222  -74.675  54.477  1
239985  93.246  -74.665  54.473  1
239986  93.269  -74.655  54.470  1
239987  93.292  -74.645  54.466  1
239988  93.315  -74.634  54.463  1
239989  93.339  -74.624  54.461  1
239990  93.362  -74.615  54.460  1
239991  93.386  -74.605  54.462  1
239992  93.409  -74.595  54.466  1
239993  93.432  -74.585  54.474  1
239994  93.456  -74.575  54.483  1
239995  93.479  -74.565  54.494  1
239996  93.502  -74.555  54.501  1
239997  93.526  -74.545  54.508  1
239998  93.549  -74.535  54.517  1
239999  93.571  -74.530  54.523  1
240000  93.592  -74.526  54.526  1
240001  93.614  -74.521  54.527  1
240002  93.635  -74.517  54.525  1
240003  93.660  -74.519  54.526  1
240004  93.692  -74.532  54.534  1
240005  93.724  -74.544  54.548  1
240006  93.756  -74.557  54.566  1
240007  93.787  -74.569  54.582  1
240008  93.819  -74.581  54.597  1
240009  93.851  -74.594  54.606  1
240010  93.883  -74.606  54.609  1
240011  93.915  -74.619  54.614  1
240012  93.944  -74.629  54.621  1
240013  93.966  -74.631  54.631  1
240014  93.988  -74.634  54.647  1
240015  94.008  -74.634  54.662  1
240016  94.027  -74.632  54.673  1
240017  94.044  -74.630  54.681  1
240018  94.060  -74.628  54.685  1
240019  94.077  -74.624  54.685  1
240020  94.094  -74.622  54.682  1
240021  94.111  -74.620  54.676  1
240022  94.128  -74.618  54.668  1
240023  94.145  -74.615  54.655  1
240024  94.162  -74.613  54.640  1
240025  94.179  -74.611  54.623  1
240026  94.201  -74.610  54.601  1
240027  94.222  -74.607  54.579  1
240028  94.244  -74.605  54.557  1
240029  94.266  -74.605  54.535  1
240030  94.289  -74.607  54.509  1
240031  94.311  -74.609  54.479  1
240032  94.331  -74.611  54.450  1
240033  94.350  -74.613  54.420  1
240034  94.369  -74.615  54.395  1
240035  94.389  -74.617  54.374  1
240036  94.408  -74.619  54.352  1
240037  94.427  -74.621  54.327  1
240038  94.446  -74.623  54.298  1
240039  94.466  -74.625  54.265  1
240040  94.487  -74.628  54.229  1
240041  94.508  -74.631  54.192  1
240042  94.529  -74.633  54.157  1
240043  94.550  -74.636  54.121  1
240044  94.571  -74.638  54.086  1
240045  94.591  -74.642  54.052  1
240046  94.609  -74.650  54.018  1
240047  94.636  -74.656  53.987  1
240048  94.663  -74.662  53.959  1
240049  94.690  -74.668  53.937  1
240050  94.716  -74.675  53.919  1
240051  94.744  -74.681  53.900  1
240052  94.770  -74.687  53.877  1
240053  94.797  -74.693  53.851  1
240054  94.824  -74.700  53.818  1
240055  94.851  -74.706  53.783  1
240056  94.878  -74.712  53.746  1
240057  94.905  -74.718  53.706  1
240058  94.929  -74.724  53.663  1
240059  94.953  -74.729  53.621  1
240060  94.977  -74.734  53.577  1
240061  94.991  -74.733  53.530  1
240062  94.990  -74.722  53.481  1
240063  94.989  -74.712  53.428  1
240064  94.989  -74.701  53.371  1
240065  94.988  -74.690  53.316  1
240066  94.987  -74.680  53.260  1
240067  94.986  -74.668  53.204  1
240068  95.009  -74.658  53.148  1
240069  95.041  -74.669  53.088  1
240070  95.071  -74.687  53.025  1
240071  95.105  -74.703  52.963  1
240072  95.139  -74.718  52.901  1
240073  95.172  -74.734  52.842  1
240074  95.206  -74.750  52.785  1
240075  95.240  -74.766  52.727  1
240076  95.273  -74.781  52.668  1
240077  95.307  -74.797  52.610  1
240078  95.337  -74.809  52.552  1
240079  95.365  -74.820  52.495  1
240080  95.393  -74.831  52.438  1
240081  95.420  -74.841  52.381  1
240082  95.448  -74.851  52.324  1
240083  95.474  -74.853  52.269  1
240084  95.498  -74.853  52.216  1
240085  95.523  -74.851  52.164  1
240086  95.548  -74.850  52.115  1
240087  95.573  -74.850  52.069  1
240088  95.598  -74.849  52.024  1
240089  95.623  -74.847  51.980  1
240090  95.656  -74.822  51.939  1
240091  95.688  -74.795  51.899  1
240092  95.721  -74.769  51.859  1
240093  95.753  -74.743  51.820  1
240094  95.786  -74.717  51.783  1
240095  95.819  -74.691  51.747  1
240096  95.836  -74.684  51.711  1
240097  95.854  -74.678  51.678  1
240098  95.892  -74.700  51.645  1
240099  95.933  -74.725  51.614  1
240100  95.971  -74.757  51.582  1
240101  96.007  -74.793  51.551  1
240102  96.043  -74.828  51.521  1
240103  96.079  -74.863  51.492  1
240104  96.111  -74.882  51.465  1
240105  96.142  -74.893  51.440  1
240106  96.173  -74.903  51.417  1
240107  96.203  -74.913  51.395  1
240108  96.234  -74.924  51.373  1
240109  96.265  -74.935  51.354  1
240110  96.296  -74.945  51.338  1
240111  96.326  -74.956  51.323  1
240112  96.357  -74.966  51.310  1
240113  96.388  -74.977  51.296  1
240114  96.418  -74.988  51.281  1
240115  96.450  -74.994  51.265  1
240116  96.472  -75.006  51.249  1
240117  96.493  -75.020  51.233  1
240118  96.513  -75.035  51.217  1
240119  96.534  -75.049  51.200  1
240120  96.554  -75.063  51.182  1
240121  96.575  -75.078  51.162  1
240122  96.596  -75.093  51.142  1
240123  96.616  -75.107  51.121  1
240124  96.637  -75.122  51.100  1
240125  96.661  -75.132  51.080  1
240126  96.692  -75.138  51.060  1
240127  96.722  -75.144  51.040  1
240128  96.753  -75.149  51.016  1
240129  96.783  -75.155  50.993  1
240130  96.814  -75.160  50.972  1
240131  96.844  -75.166  50.952  1
240132  96.875  -75.172  50.932  1
240133  96.905  -75.177  50.915  1
240134  96.934  -75.179  50.898  1
240135  96.957  -75.174  50.880  1
240136  96.980  -75.169  50.860  1
240137  96.956  -75.323  50.839  1
240138  96.980  -75.315  50.817  1
240139  97.005  -75.307  50.793  1
240140  97.029  -75.298  50.770  1
240141  97.054  -75.290  50.746  1
240142  97.079  -75.282  50.723  1
240143  97.103  -75.273  50.698  1
240144  97.127  -75.265  50.674  1
240145  97.152  -75.258  50.650  1
240146  97.173  -75.265  50.624  1
240147  97.195  -75.273  50.597  1
240148  97.216  -75.279  50.567  1
240149  97.238  -75.287  50.537  1
240150  97.262  -75.296  50.505  1
240151  97.284  -75.305  50.472  1
240152  97.300  -75.313  50.439  1
240153  97.317  -75.321  50.407  1
240154  97.334  -75.330  50.376  1
240155  97.351  -75.337  50.346  1
240156  97.368  -75.345  50.319  1
240157  97.385  -75.354  50.291  1
240158  97.402  -75.362  50.262  1
240159  97.419  -75.370  50.231  1
240160  97.446  -75.377  50.197  1
240161  97.477  -75.383  50.162  1
240162  97.508  -75.389  50.127  1
240163  97.534  -75.396  50.089  1
240164  97.560  -75.402  50.051  1
240165  97.586  -75.409  50.015  1
240166  97.611  -75.415  49.979  1
240167  97.637  -75.421  49.942  1
240168  97.660  -75.426  49.907  1
240169  97.683  -75.430  49.869  1
240170  97.706  -75.434  49.829  1
240171  97.728  -75.438  49.786  1
240172  97.751  -75.442  49.742  1
240173  97.814  -75.432  49.696  1
240174  97.854  -75.446  49.650  1
240175  97.893  -75.461  49.603  1
240176  97.933  -75.476  49.556  1
240177  97.970  -75.493  49.508  1
240178  97.996  -75.519  49.458  1
240179  98.036  -75.532  49.411  1
240180  98.083  -75.540  49.366  1
240181  98.110  -75.548  49.321  1
240182  98.135  -75.555  49.277  1
240183  98.160  -75.561  49.232  1
240184  98.179  -75.574  49.185  1
240185  98.192  -75.593  49.137  1
240186  98.204  -75.611  49.090  1
240187  98.217  -75.630  49.044  1
240188  98.233  -75.642  48.998  1
240189  98.262  -75.652  48.953  1
240190  98.320  -75.659  48.907  1
240191  98.380  -75.666  48.862  1
240192  98.439  -75.673  48.816  1
240193  98.498  -75.681  48.771  1
240194  98.551  -75.689  48.725  1
240195  98.579  -75.714  48.676  1
240196  98.582  -75.731  48.629  1
240197  98.571  -75.727  48.581  1
240198  98.560  -75.724  48.533  1
240199  98.619  -75.742  48.488  1
240200  98.686  -75.765  48.442  1
240201  98.710  -75.775  48.396  1
240202  98.722  -75.780  48.352  1
240203  98.734  -75.786  48.306  1
240204  98.746  -75.792  48.260  1
240205  98.759  -75.798  48.214  1
240206  98.799  -75.784  48.169  1
240207  98.852  -75.763  48.126  1
240208  98.879  -75.753  48.085  1
240209  98.897  -75.778  48.047  1
240210  98.914  -75.803  48.009  1
240211  98.931  -75.827  47.973  1
240212  98.948  -75.847  47.938  1
240213  98.966  -75.863  47.904  1
240214  98.983  -75.880  47.873  1
240215  99.001  -75.896  47.843  1
240216  99.018  -75.912  47.814  1
240217  99.035  -75.929  47.786  1
240218  99.053  -75.945  47.760  1
240219  99.070  -75.962  47.734  1
240220  99.088  -75.978  47.708  1
240221  99.108  -75.994  47.683  1
240222  99.137  -76.009  47.657  1
240223  99.165  -76.023  47.630  1
240224  99.194  -76.038  47.605  1
240225  99.222  -76.053  47.582  1
240226  99.251  -76.067  47.556  1
240227  99.279  -76.082  47.531  1
240228  99.308  -76.091  47.505  1
240229  99.338  -76.096  47.478  1
240230  99.368  -76.100  47.451  1
240231  99.398  -76.106  47.424  1
240232  99.428  -76.110  47.398  1
240233  99.458  -76.116  47.372  1
240234  99.488  -76.120  47.346  1
240235  99.518  -76.125  47.320  1
240236  99.548  -76.130  47.294  1
240237  99.568  -76.133  47.270  1
240238  99.584  -76.135  47.248  1
240239  99.600  -76.138  47.224  1
240240  99.615  -76.141  47.198  1
240241  99.631  -76.144  47.170  1
240242  99.647  -76.146  47.141  1
240243  99.663  -76.149  47.111  1
240244  99.693  -76.154  47.080  1
240245  99.722  -76.158  47.050  1
240246  99.752  -76.163  47.020  1
240247  99.781  -76.167  46.989  1
240248  99.811  -76.172  46.958  1
240249  99.827  -76.191  46.926  1
240250  99.843  -76.211  46.895  1
240251  99.858  -76.231  46.865  1
240252  99.877  -76.254  46.836  1
240253  99.897  -76.278  46.806  1
240254  99.916  -76.297  46.778  1
240255  99.937  -76.301  46.749  1
240256  99.958  -76.304  46.720  1
240257  99.978  -76.307  46.690  1
240258  100.003  -76.304  46.662  1
240259  100.028  -76.301  46.634  1
240260  100.052  -76.297  46.604  1
240261  100.077  -76.294  46.575  1
240262  100.116  -76.295  46.545  1
240263  100.156  -76.298  46.513  1
240264  100.196  -76.301  46.482  1
240265  100.237  -76.304  46.452  1
240266  100.274  -76.309  46.420  1
240267  100.312  -76.314  46.388  1
240268  100.350  -76.320  46.355  1
240269  100.374  -76.330  46.321  1
240270  100.392  -76.342  46.285  1
240271  100.409  -76.355  46.250  1
240272  100.426  -76.368  46.214  1
240273  100.443  -76.381  46.178  1
240274  100.460  -76.400  46.142  1
240275  100.476  -76.423  46.106  1
240276  100.492  -76.446  46.070  1
240277  100.508  -76.470  46.034  1
240278  100.524  -76.493  46.000  1
240279  100.540  -76.517  45.967  1
240280  100.561  -76.527  45.936  1
240281  100.582  -76.535  45.905  1
240282  100.597  -76.556  45.876  1
240283  100.608  -76.586  45.849  1
240284  100.627  -76.604  45.822  1
240285  100.646  -76.623  45.797  1
240286  100.665  -76.641  45.773  1
240287  100.700  -76.646  45.750  1
240288  100.745  -76.640  45.729  1
240289  100.789  -76.634  45.708  1
240290  100.834  -76.628  45.688  1
240291  100.879  -76.623  45.668  1
240292  100.924  -76.617  45.648  1
240293  100.968  -76.611  45.628  1
240294  101.013  -76.606  45.607  1
240295  101.043  -76.611  45.585  1
240296  101.066  -76.621  45.565  1
240297  101.091  -76.630  45.543  1
240298  101.114  -76.639  45.521  1
240299  101.138  -76.648  45.499  1
240300  101.162  -76.657  45.478  1
240301  101.189  -76.668  45.458  1
240302  101.217  -76.678  45.437  1
240303  101.245  -76.688  45.416  1
240304  101.271  -76.699  45.397  1
240305  101.285  -76.712  45.378  1
240306  101.300  -76.723  45.360  1
240307  101.315  -76.735  45.342  1
240308  101.330  -76.747  45.326  1
240309  101.344  -76.759  45.310  1
240310  101.359  -76.771  45.295  1
240311  101.374  -76.784  45.282  1
240312  101.389  -76.796  45.269  1
240313  101.403  -76.807  45.256  1
240314  101.418  -76.819  45.243  1
240315  101.433  -76.831  45.230  1
240316  101.448  -76.843  45.217  1
240317  101.462  -76.856  45.203  1
240318  101.477  -76.868  45.190  1
240319  101.492  -76.880  45.176  1
240320  101.506  -76.891  45.162  1
240321  101.521  -76.903  45.147  1
240322  101.536  -76.915  45.132  1
240323  101.556  -76.918  45.116  1
240324  101.578  -76.918  45.099  1
240325  101.599  -76.918  45.082  1
240326  101.621  -76.919  45.065  1
240327  101.642  -76.919  45.047  1
240328  101.664  -76.919  45.030  1
240329  101.686  -76.919  45.013  1
240330  101.706  -76.922  44.997  1
240331  101.722  -76.933  44.980  1
240332  101.739  -76.944  44.964  1
240333  101.755  -76.956  44.947  1
240334  101.771  -76.967  44.929  1
240335  101.787  -76.978  44.912  1
240336  101.804  -76.989  44.893  1
240337  101.820  -77.000  44.875  1
240338  101.837  -77.011  44.857  1
240339  101.853  -77.022  44.840  1
240340  101.870  -77.034  44.825  1
240341  101.886  -77.045  44.810  1
240342  101.904  -77.057  44.794  1
240343  101.923  -77.071  44.777  1
240344  101.943  -77.085  44.761  1
240345  101.963  -77.098  44.746  1
240346  101.982  -77.112  44.731  1
240347  102.004  -77.131  44.714  1
240348  102.027  -77.155  44.699  1
240349  102.049  -77.175  44.684  1
240350  102.071  -77.195  44.669  1
240351  102.093  -77.214  44.653  1
240352  102.115  -77.234  44.639  1
240353  102.136  -77.253  44.625  1
240354  102.158  -77.273  44.610  1
240355  102.180  -77.291  44.595  1
240356  102.202  -77.311  44.581  1
240357  102.224  -77.331  44.566  1
240358  102.245  -77.350  44.550  1
240359  102.267  -77.370  44.534  1
240360  102.286  -77.383  44.519  1
240361  102.304  -77.394  44.503  1
240362  102.321  -77.404  44.486  1
240363  102.338  -77.415  44.468  1
240364  102.358  -77.419  44.450  1
240365  102.378  -77.420  44.432  1
240366  102.397  -77.423  44.415  1
240367  102.417  -77.424  44.397  1
240368  102.437  -77.426  44.377  1
240369  102.457  -77.428  44.358  1
240370  102.477  -77.429  44.340  1
240371  102.497  -77.432  44.322  1
240372  102.528  -77.437  44.305  1
240373  102.567  -77.445  44.288  1
240374  102.604  -77.453  44.271  1
240375  102.643  -77.461  44.255  1
240376  102.680  -77.468  44.239  1
240377  102.719  -77.476  44.222  1
240378  102.756  -77.484  44.207  1
240379  102.795  -77.492  44.190  1
240380  102.832  -77.499  44.174  1
240381  102.871  -77.507  44.160  1
240382  102.908  -77.515  44.144  1
240383  102.947  -77.523  44.128  1
240384  102.984  -77.530  44.113  1
240385  103.023  -77.538  44.096  1
240657  92.398  -74.612  54.421  1
240658  92.422  -74.623  54.430  1
240659  92.447  -74.634  54.437  1
240660  92.471  -74.645  54.445  1
240661  92.496  -74.656  54.454  1
240662  92.520  -74.666  54.461  1
240663  92.534  -74.649  54.468  1
240664  92.560  -74.638  54.477  1
240665  92.587  -74.628  54.485  1
240666  92.614  -74.619  54.492  1
240667  92.641  -74.610  54.498  1
240668  92.671  -74.602  54.504  1
240669  92.702  -74.594  54.507  1
240670  92.732  -74.586  54.509  1
240671  92.762  -74.577  54.511  1
240672  92.792  -74.579  54.511  1
240673  92.824  -74.581  54.510  1
240674  92.856  -74.585  54.510  1
240675  92.890  -74.591  54.511  1
240676  92.923  -74.597  54.514  1
240677  92.956  -74.603  54.517  1
240678  92.990  -74.609  54.520  1
240679  93.023  -74.615  54.522  1
240680  93.056  -74.621  54.523  1
240681  93.089  -74.627  54.520  1
240682  93.123  -74.632  54.516  1
240683  93.156  -74.638  54.510  1
240684  93.189  -74.644  54.506  1
240685  93.223  -74.650  54.503  1
240686  93.249  -74.644  54.501  1
240687  93.272  -74.634  54.499  1
240688  93.295  -74.624  54.496  1
240689  93.319  -74.614  54.494  1
240690  93.342  -74.604  54.492  1
240691  93.365  -74.594  54.491  1
240692  93.389  -74.584  54.494  1
240693  93.412  -74.574  54.499  1
240694  93.435  -74.565  54.508  1
240695  93.459  -74.555  54.519  1
240696  93.482  -74.544  54.529  1
240697  93.505  -74.534  54.539  1
240698  93.529  -74.524  54.548  1
240699  93.551  -74.518  54.557  1
240700  93.572  -74.513  54.565  1
240701  93.594  -74.509  54.571  1
240702  93.615  -74.505  54.570  1
240703  93.637  -74.500  54.564  1
240704  93.658  -74.496  54.560  1
240705  93.685  -74.501  54.566  1
240706  93.716  -74.513  54.579  1
240707  93.749  -74.526  54.598  1
240708  93.780  -74.538  54.617  1
240709  93.812  -74.551  54.634  1
240710  93.844  -74.563  54.644  1
240711  93.875  -74.575  54.643  1
240712  93.907  -74.588  54.640  1
240713  93.938  -74.599  54.642  1
240714  93.960  -74.602  54.649  1
240715  93.982  -74.604  54.662  1
240716  94.003  -74.606  54.677  1
240717  94.024  -74.606  54.687  1
240718  94.042  -74.604  54.694  1
240719  94.059  -74.602  54.698  1
240720  94.076  -74.599  54.696  1
240721  94.093  -74.597  54.692  1
240722  94.110  -74.595  54.685  1
240723  94.127  -74.593  54.675  1
240724  94.144  -74.590  54.662  1
240725  94.161  -74.588  54.646  1
240726  94.179  -74.586  54.627  1
240727  94.200  -74.587  54.607  1
240728  94.222  -74.587  54.587  1
240729  94.244  -74.586  54.568  1
240730  94.265  -74.583  54.549  1
240731  94.288  -74.585  54.523  1
240732  94.309  -74.587  54.494  1
240733  94.328  -74.589  54.464  1
240734  94.348  -74.591  54.434  1
240735  94.367  -74.593  54.408  1
240736  94.386  -74.595  54.385  1
240737  94.406  -74.597  54.361  1
240738  94.425  -74.598  54.334  1
240739  94.445  -74.599  54.304  1
240740  94.466  -74.604  54.271  1
240741  94.487  -74.606  54.234  1
240742  94.508  -74.609  54.196  1
240743  94.529  -74.612  54.158  1
240744  94.550  -74.615  54.120  1
240745  94.571  -74.617  54.082  1
240746  94.589  -74.624  54.047  1
240747  94.607  -74.632  54.011  1
240748  94.630  -74.639  53.979  1
240749  94.657  -74.645  53.950  1
240750  94.684  -74.651  53.924  1
240751  94.710  -74.657  53.901  1
240752  94.738  -74.664  53.879  1
240753  94.764  -74.670  53.855  1
240754  94.791  -74.676  53.826  1
240755  94.818  -74.682  53.794  1
240756  94.845  -74.689  53.761  1
240757  94.871  -74.695  53.725  1
240758  94.895  -74.700  53.685  1
240759  94.919  -74.705  53.644  1
240760  94.943  -74.709  53.602  1
240761  94.966  -74.715  53.558  1
240762  94.971  -74.707  53.511  1
240763  94.970  -74.697  53.464  1
240764  94.969  -74.686  53.413  1
240765  94.969  -74.675  53.361  1
240766  94.968  -74.665  53.310  1
240767  94.969  -74.654  53.258  1
240768  94.993  -74.643  53.205  1
240769  95.018  -74.636  53.150  1
240770  95.051  -74.652  53.088  1
240771  95.086  -74.668  53.026  1
240772  95.113  -74.688  52.964  1
240773  95.146  -74.703  52.904  1
240774  95.180  -74.719  52.845  1
240775  95.214  -74.734  52.787  1
240776  95.247  -74.750  52.729  1
240777  95.281  -74.766  52.670  1
240778  95.315  -74.781  52.612  1
240779  95.346  -74.794  52.554  1
240780  95.374  -74.805  52.496  1
240781  95.401  -74.816  52.438  1
240782  95.428  -74.826  52.382  1
240783  95.456  -74.834  52.326  1
240784  95.481  -74.834  52.272  1
240785  95.506  -74.833  52.219  1
240786  95.531  -74.831  52.168  1
240787  95.555  -74.831  52.119  1
240788  95.580  -74.830  52.072  1
240789  95.605  -74.829  52.028  1
240790  95.630  -74.828  51.984  1
240791  95.658  -74.817  51.943  1
240792  95.691  -74.791  51.903  1
240793  95.724  -74.765  51.864  1
240794  95.756  -74.738  51.825  1
240795  95.789  -74.712  51.787  1
240796  95.821  -74.686  51.749  1
240797  95.854  -74.660  51.713  1
240798  95.880  -74.643  51.679  1
240799  95.908  -74.653  51.646  1
240800  95.947  -74.682  51.613  1
240801  95.983  -74.717  51.581  1
240802  96.019  -74.753  51.548  1
240803  96.055  -74.788  51.517  1
240804  96.091  -74.823  51.487  1
240805  96.127  -74.856  51.460  1
240806  96.157  -74.867  51.435  1
240807  96.188  -74.878  51.411  1
240808  96.219  -74.888  51.389  1
240809  96.249  -74.898  51.366  1
240810  96.280  -74.909  51.348  1
240811  96.311  -74.919  51.332  1
240812  96.341  -74.930  51.318  1
240813  96.372  -74.941  51.304  1
240814  96.403  -74.951  51.290  1
240815  96.433  -74.962  51.276  1
240816  96.457  -74.973  51.262  1
240817  96.481  -74.992  51.249  1
240818  96.504  -75.013  51.233  1
240819  96.526  -75.030  51.218  1
240820  96.546  -75.044  51.202  1
240821  96.567  -75.059  51.185  1
240822  96.588  -75.073  51.166  1
240823  96.608  -75.088  51.147  1
240824  96.629  -75.103  51.128  1
240825  96.650  -75.117  51.108  1
240826  96.670  -75.132  51.088  1
240827  96.700  -75.137  51.068  1
240828  96.731  -75.142  51.046  1
240829  96.761  -75.148  51.022  1
240830  96.792  -75.154  51.000  1
240831  96.822  -75.159  50.979  1
240832  96.853  -75.165  50.959  1
240833  96.881  -75.166  50.940  1
240834  96.904  -75.160  50.923  1
240835  96.927  -75.155  50.907  1
240836  96.951  -75.149  50.889  1
240837  96.974  -75.144  50.870  1
240838  96.957  -75.274  50.850  1
240839  96.981  -75.266  50.829  1
240840  97.006  -75.258  50.807  1
240841  97.030  -75.249  50.785  1
240842  97.055  -75.241  50.762  1
240843  97.080  -75.232  50.738  1
240844  97.104  -75.224  50.715  1
240845  97.127  -75.222  50.691  1
240846  97.149  -75.229  50.667  1
240847  97.170  -75.236  50.642  1
240848  97.192  -75.244  50.615  1
240849  97.213  -75.251  50.587  1
240850  97.235  -75.258  50.557  1
240851  97.259  -75.267  50.527  1
240852  97.283  -75.276  50.495  1
240853  97.302  -75.285  50.462  1
240854  97.319  -75.293  50.431  1
240855  97.336  -75.301  50.401  1
240856  97.353  -75.309  50.370  1
240857  97.370  -75.317  50.342  1
240858  97.387  -75.325  50.313  1
240859  97.403  -75.333  50.283  1
240860  97.421  -75.342  50.251  1
240861  97.450  -75.348  50.217  1
240862  97.480  -75.355  50.183  1
240863  97.511  -75.361  50.147  1
240864  97.539  -75.367  50.110  1
240865  97.565  -75.374  50.072  1
240866  97.591  -75.380  50.035  1
240867  97.616  -75.386  49.998  1
240868  97.642  -75.393  49.961  1
240869  97.667  -75.399  49.925  1
240870  97.691  -75.404  49.886  1
240871  97.714  -75.408  49.846  1
240872  97.736  -75.412  49.803  1
240873  97.769  -75.412  49.758  1
240874  97.820  -75.415  49.712  1
240875  97.860  -75.430  49.665  1
240876  97.899  -75.445  49.618  1
240877  97.938  -75.460  49.571  1
240878  97.978  -75.475  49.522  1
240879  98.004  -75.501  49.472  1
240880  98.050  -75.510  49.426  1
240881  98.081  -75.517  49.380  1
240882  98.106  -75.524  49.335  1
240883  98.131  -75.530  49.290  1
240884  98.156  -75.537  49.245  1
240885  98.181  -75.545  49.199  1
240886  98.194  -75.564  49.151  1
240887  98.206  -75.583  49.104  1
240888  98.218  -75.602  49.058  1
240889  98.230  -75.621  49.012  1
240890  98.272  -75.622  48.966  1
240891  98.331  -75.629  48.921  1
240892  98.390  -75.636  48.875  1
240893  98.450  -75.643  48.830  1
240894  98.509  -75.649  48.785  1
240895  98.568  -75.656  48.739  1
240896  98.603  -75.673  48.690  1
240897  98.587  -75.676  48.642  1
240898  98.572  -75.680  48.594  1
240899  98.557  -75.683  48.545  1
240900  98.597  -75.693  48.498  1
240901  98.661  -75.714  48.452  1
240902  98.718  -75.734  48.407  1
240903  98.730  -75.740  48.361  1
240904  98.743  -75.746  48.314  1
240905  98.755  -75.752  48.267  1
240906  98.773  -75.753  48.219  1
240907  98.826  -75.732  48.173  1
240908  98.859  -75.718  48.128  1
240909  98.881  -75.714  48.086  1
240910  98.899  -75.739  48.046  1
240911  98.916  -75.763  48.008  1
240912  98.933  -75.788  47.972  1
240913  98.950  -75.813  47.936  1
240914  98.968  -75.838  47.902  1
240915  98.985  -75.863  47.869  1
240916  99.002  -75.880  47.839  1
240917  99.019  -75.897  47.810  1
240918  99.037  -75.913  47.782  1
240919  99.054  -75.929  47.754  1
240920  99.072  -75.946  47.728  1
240921  99.089  -75.963  47.701  1
240922  99.106  -75.978  47.675  1
240923  99.132  -75.994  47.648  1
240924  99.160  -76.009  47.621  1
240925  99.189  -76.023  47.596  1
240926  99.217  -76.038  47.572  1
240927  99.246  -76.052  47.546  1
240928  99.275  -76.062  47.519  1
240929  99.305  -76.066  47.492  1
240930  99.335  -76.071  47.466  1
240931  99.365  -76.076  47.438  1
240932  99.395  -76.081  47.411  1
240933  99.425  -76.085  47.385  1
240934  99.455  -76.091  47.359  1
240935  99.485  -76.095  47.333  1
240936  99.515  -76.100  47.308  1
240937  99.545  -76.105  47.283  1
240938  99.573  -76.110  47.258  1
240939  99.588  -76.112  47.235  1
240940  99.604  -76.115  47.211  1
240941  99.620  -76.117  47.185  1
240942  99.636  -76.120  47.159  1
240943  99.651  -76.122  47.130  1
240944  99.680  -76.127  47.099  1
240945  99.709  -76.132  47.069  1
240946  99.739  -76.136  47.041  1
240947  99.768  -76.141  47.010  1
240948  99.798  -76.145  46.980  1
240949  99.828  -76.151  46.949  1
240950  99.846  -76.167  46.918  1
240951  99.861  -76.188  46.887  1
240952  99.879  -76.210  46.857  1
240953  99.899  -76.234  46.828  1
240954  99.918  -76.257  46.798  1
240955  99.937  -76.281  46.770  1
240956  99.958  -76.286  46.741  1
240957  99.980  -76.287  46.711  1
240958  100.005  -76.283  46.682  1
240959  100.030  -76.280  46.654  1
240960  100.054  -76.277  46.625  1
240961  100.079  -76.273  46.596  1
240962  100.104  -76.270  46.567  1
240963  100.137  -76.270  46.537  1
240964  100.177  -76.273  46.505  1
240965  100.218  -76.276  46.475  1
240966  100.259  -76.278  46.444  1
240967  100.299  -76.280  46.413  1
240968  100.339  -76.284  46.380  1
240969  100.376  -76.289  46.347  1
240970  100.395  -76.301  46.314  1
240971  100.412  -76.314  46.279  1
240972  100.428  -76.338  46.243  1
240973  100.444  -76.361  46.208  1
240974  100.460  -76.384  46.172  1
240975  100.476  -76.408  46.136  1
240976  100.492  -76.431  46.100  1
240977  100.508  -76.455  46.064  1
240978  100.524  -76.478  46.029  1
240979  100.541  -76.500  45.995  1
240980  100.562  -76.508  45.962  1
240981  100.584  -76.516  45.931  1
240982  100.606  -76.524  45.900  1
240983  100.615  -76.554  45.871  1
240984  100.625  -76.585  45.843  1
240985  100.644  -76.604  45.817  1
240986  100.664  -76.622  45.792  1
240987  100.682  -76.641  45.768  1
240988  100.725  -76.636  45.745  1
240989  100.770  -76.631  45.724  1
240990  100.815  -76.626  45.703  1
240991  100.860  -76.620  45.682  1
240992  100.905  -76.614  45.662  1
240993  100.949  -76.608  45.642  1
240994  100.994  -76.603  45.622  1
240995  101.039  -76.598  45.601  1
240996  101.073  -76.599  45.579  1
240997  101.098  -76.608  45.557  1
240998  101.121  -76.618  45.535  1
240999  101.145  -76.627  45.514  1
241000  101.169  -76.636  45.492  1
241001  101.193  -76.645  45.471  1
241002  101.220  -76.655  45.450  1
241003  101.248  -76.666  45.430  1
241004  101.276  -76.677  45.410  1
241005  101.299  -76.687  45.390  1
241006  101.314  -76.699  45.372  1
241007  101.329  -76.712  45.353  1
241008  101.343  -76.724  45.335  1
241009  101.358  -76.736  45.319  1
241010  101.373  -76.747  45.303  1
241011  101.388  -76.759  45.287  1
241012  101.402  -76.771  45.274  1
241013  101.417  -76.784  45.260  1
241014  101.431  -76.796  45.247  1
241015  101.447  -76.808  45.234  1
241016  101.461  -76.820  45.221  1
241017  101.476  -76.831  45.207  1
241018  101.490  -76.843  45.193  1
241019  101.505  -76.856  45.179  1
241020  101.520  -76.868  45.166  1
241021  101.535  -76.880  45.150  1
241022  101.549  -76.892  45.134  1
241023  101.570  -76.894  45.119  1
241024  101.592  -76.894  45.104  1
241025  101.613  -76.894  45.085  1
241026  101.635  -76.894  45.068  1
241027  101.656  -76.894  45.051  1
241028  101.678  -76.894  45.033  1
241029  101.700  -76.894  45.016  1
241030  101.718  -76.902  44.999  1
241031  101.734  -76.913  44.983  1
241032  101.750  -76.925  44.965  1
241033  101.767  -76.935  44.949  1
241034  101.783  -76.947  44.932  1
241035  101.799  -76.958  44.914  1
241036  101.816  -76.969  44.897  1
241037  101.832  -76.980  44.880  1
241038  101.848  -76.991  44.862  1
241039  101.865  -77.003  44.845  1
241040  101.881  -77.014  44.828  1
241041  101.898  -77.025  44.813  1
241042  101.914  -77.036  44.797  1
241043  101.930  -77.047  44.781  1
241044  101.947  -77.058  44.765  1
241045  101.963  -77.069  44.749  1
241046  101.982  -77.082  44.733  1
241047  102.001  -77.096  44.718  1
241048  102.024  -77.117  44.701  1
241049  102.045  -77.136  44.686  1
241050  102.067  -77.156  44.672  1
241051  102.089  -77.175  44.657  1
241052  102.111  -77.194  44.640  1
241053  102.132  -77.214  44.625  1
241054  102.154  -77.233  44.611  1
241055  102.176  -77.253  44.596  1
241056  102.198  -77.273  44.580  1
241057  102.220  -77.291  44.565  1
241058  102.241  -77.311  44.550  1
241059  102.263  -77.330  44.534  1
241060  102.284  -77.350  44.519  1
241061  102.305  -77.366  44.504  1
241062  102.323  -77.373  44.488  1
241063  102.343  -77.375  44.471  1
241064  102.363  -77.376  44.453  1
241065  102.382  -77.379  44.435  1
241066  102.402  -77.380  44.416  1
241067  102.422  -77.382  44.399  1
241068  102.442  -77.384  44.382  1
241069  102.462  -77.385  44.364  1
241070  102.481  -77.388  44.346  1
241071  102.501  -77.389  44.329  1
241072  102.521  -77.391  44.311  1
241073  102.541  -77.393  44.294  1
241074  102.571  -77.398  44.277  1
241075  102.608  -77.406  44.261  1
241076  102.647  -77.414  44.245  1
241077  102.684  -77.421  44.228  1
241078  102.723  -77.429  44.212  1
241079  102.760  -77.437  44.197  1
241080  102.799  -77.445  44.181  1
241081  102.836  -77.452  44.165  1
241082  102.875  -77.460  44.150  1
241083  102.912  -77.468  44.135  1
241084  102.951  -77.476  44.120  1
241085  102.988  -77.483  44.104  1
241359  92.424  -74.591  54.436  1
241360  92.448  -74.602  54.443  1
241361  92.473  -74.612  54.451  1
241362  92.497  -74.623  54.458  1
241363  92.522  -74.634  54.465  1
241364  92.540  -74.624  54.472  1
241365  92.562  -74.611  54.480  1
241366  92.588  -74.602  54.488  1
241367  92.615  -74.592  54.495  1
241368  92.643  -74.583  54.502  1
241369  92.673  -74.575  54.508  1
241370  92.703  -74.567  54.510  1
241371  92.733  -74.559  54.513  1
241372  92.764  -74.550  54.514  1
241373  92.793  -74.557  54.515  1
241374  92.825  -74.559  54.515  1
241375  92.856  -74.560  54.514  1
241376  92.887  -74.562  54.514  1
241377  92.920  -74.568  54.517  1
241378  92.953  -74.574  54.522  1
241379  92.987  -74.579  54.527  1
241380  93.020  -74.585  54.534  1
241381  93.053  -74.591  54.542  1
241382  93.086  -74.596  54.541  1
241383  93.120  -74.603  54.537  1
241384  93.153  -74.609  54.532  1
241385  93.187  -74.615  54.530  1
241386  93.220  -74.620  54.529  1
241387  93.251  -74.623  54.529  1
241388  93.275  -74.613  54.528  1
241389  93.298  -74.603  54.525  1
241390  93.321  -74.593  54.524  1
241391  93.345  -74.584  54.523  1
241392  93.368  -74.574  54.522  1
241393  93.391  -74.564  54.525  1
241394  93.415  -74.553  54.532  1
241395  93.438  -74.543  54.543  1
241396  93.461  -74.534  54.555  1
241397  93.485  -74.524  54.565  1
241398  93.508  -74.514  54.576  1
241399  93.531  -74.505  54.587  1
241400  93.552  -74.501  54.598  1
241401  93.574  -74.496  54.607  1
241402  93.595  -74.493  54.612  1
241403  93.617  -74.488  54.611  1
241404  93.638  -74.483  54.603  1
241405  93.659  -74.480  54.597  1
241406  93.681  -74.475  54.601  1
241407  93.709  -74.483  54.613  1
241408  93.741  -74.495  54.633  1
241409  93.773  -74.507  54.653  1
241410  93.804  -74.520  54.671  1
241411  93.836  -74.532  54.683  1
241412  93.868  -74.545  54.682  1
241413  93.900  -74.557  54.674  1
241414  93.931  -74.570  54.670  1
241415  93.954  -74.572  54.673  1
241416  93.976  -74.574  54.684  1
241417  93.998  -74.577  54.697  1
241418  94.018  -74.577  54.704  1
241419  94.039  -74.577  54.707  1
241420  94.058  -74.577  54.710  1
241421  94.075  -74.574  54.707  1
241422  94.092  -74.572  54.700  1
241423  94.109  -74.570  54.691  1
241424  94.126  -74.567  54.681  1
241425  94.143  -74.565  54.666  1
241426  94.159  -74.562  54.649  1
241427  94.178  -74.561  54.629  1
241428  94.200  -74.562  54.612  1
241429  94.221  -74.562  54.596  1
241430  94.243  -74.563  54.579  1
241431  94.265  -74.564  54.562  1
241432  94.287  -74.563  54.537  1
241433  94.307  -74.565  54.507  1
241434  94.326  -74.567  54.477  1
241435  94.346  -74.568  54.447  1
241436  94.365  -74.569  54.419  1
241437  94.385  -74.570  54.394  1
241438  94.405  -74.571  54.367  1
241439  94.424  -74.572  54.337  1
241440  94.444  -74.574  54.307  1
241441  94.466  -74.581  54.273  1
241442  94.487  -74.586  54.237  1
241443  94.508  -74.588  54.199  1
241444  94.529  -74.591  54.160  1
241445  94.550  -74.593  54.120  1
241446  94.569  -74.598  54.081  1
241447  94.587  -74.606  54.043  1
241448  94.604  -74.614  54.007  1
241449  94.624  -74.621  53.974  1
241450  94.651  -74.628  53.943  1
241451  94.678  -74.634  53.914  1
241452  94.704  -74.640  53.887  1
241453  94.732  -74.646  53.861  1
241454  94.758  -74.653  53.835  1
241455  94.785  -74.659  53.806  1
241456  94.812  -74.665  53.775  1
241457  94.837  -74.670  53.743  1
241458  94.860  -74.675  53.710  1
241459  94.884  -74.681  53.673  1
241460  94.908  -74.685  53.634  1
241461  94.931  -74.690  53.592  1
241462  94.952  -74.693  53.548  1
241463  94.951  -74.682  53.503  1
241464  94.950  -74.671  53.457  1
241465  94.949  -74.661  53.409  1
241466  94.948  -74.650  53.362  1
241467  94.953  -74.640  53.317  1
241468  94.976  -74.628  53.269  1
241469  94.999  -74.618  53.217  1
241470  95.028  -74.618  53.160  1
241471  95.061  -74.635  53.098  1
241472  95.096  -74.651  53.035  1
241473  95.127  -74.668  52.972  1
241474  95.155  -74.688  52.911  1
241475  95.188  -74.703  52.850  1
241476  95.222  -74.719  52.790  1
241477  95.255  -74.734  52.731  1
241478  95.289  -74.750  52.672  1
241479  95.322  -74.766  52.614  1
241480  95.354  -74.780  52.555  1
241481  95.382  -74.790  52.497  1
241482  95.409  -74.800  52.439  1
241483  95.437  -74.811  52.384  1
241484  95.463  -74.815  52.329  1
241485  95.488  -74.814  52.275  1
241486  95.513  -74.813  52.223  1
241487  95.538  -74.812  52.172  1
241488  95.562  -74.811  52.123  1
241489  95.588  -74.810  52.076  1
241490  95.612  -74.809  52.030  1
241491  95.637  -74.808  51.988  1
241492  95.662  -74.807  51.947  1
241493  95.693  -74.786  51.907  1
241494  95.726  -74.760  51.867  1
241495  95.758  -74.734  51.829  1
241496  95.791  -74.708  51.790  1
241497  95.824  -74.681  51.753  1
241498  95.856  -74.656  51.715  1
241499  95.889  -74.629  51.682  1
241500  95.923  -74.609  51.648  1
241501  95.959  -74.641  51.613  1
241502  95.995  -74.677  51.579  1
241503  96.031  -74.712  51.546  1
241504  96.067  -74.748  51.514  1
241505  96.103  -74.783  51.484  1
241506  96.139  -74.819  51.455  1
241507  96.173  -74.841  51.430  1
241508  96.203  -74.852  51.405  1
241509  96.234  -74.863  51.382  1
241510  96.265  -74.873  51.361  1
241511  96.296  -74.883  51.342  1
241512  96.326  -74.894  51.325  1
241513  96.357  -74.904  51.310  1
241514  96.388  -74.915  51.296  1
241515  96.413  -74.926  51.282  1
241516  96.438  -74.937  51.270  1
241517  96.462  -74.948  51.257  1
241518  96.485  -74.966  51.244  1
241519  96.508  -74.988  51.231  1
241520  96.531  -75.008  51.218  1
241521  96.554  -75.029  51.204  1
241522  96.578  -75.050  51.187  1
241523  96.600  -75.069  51.170  1
241524  96.621  -75.084  51.152  1
241525  96.642  -75.098  51.135  1
241526  96.662  -75.113  51.116  1
241527  96.682  -75.127  51.096  1
241528  96.709  -75.136  51.075  1
241529  96.740  -75.142  51.052  1
241530  96.770  -75.147  51.030  1
241531  96.801  -75.153  51.007  1
241532  96.827  -75.152  50.986  1
241533  96.851  -75.147  50.967  1
241534  96.874  -75.142  50.949  1
241535  96.897  -75.135  50.932  1
241536  96.921  -75.130  50.916  1
241537  96.944  -75.125  50.898  1
241538  96.967  -75.120  50.882  1
241539  96.958  -75.225  50.863  1
241540  96.982  -75.217  50.843  1
241541  97.007  -75.207  50.822  1
241542  97.031  -75.199  50.800  1
241543  97.056  -75.191  50.777  1
241544  97.081  -75.182  50.753  1
241545  97.103  -75.185  50.730  1
241546  97.124  -75.193  50.706  1
241547  97.146  -75.200  50.683  1
241548  97.167  -75.207  50.659  1
241549  97.189  -75.214  50.634  1
241550  97.210  -75.222  50.605  1
241551  97.232  -75.229  50.577  1
241552  97.255  -75.239  50.549  1
241553  97.280  -75.248  50.521  1
241554  97.304  -75.257  50.489  1
241555  97.321  -75.264  50.459  1
241556  97.337  -75.273  50.428  1
241557  97.355  -75.281  50.396  1
241558  97.372  -75.289  50.366  1
241559  97.388  -75.297  50.335  1
241560  97.405  -75.305  50.303  1
241561  97.422  -75.313  50.270  1
241562  97.453  -75.320  50.236  1
241563  97.484  -75.326  50.202  1
241564  97.514  -75.333  50.167  1
241565  97.544  -75.339  50.131  1
241566  97.570  -75.345  50.093  1
241567  97.595  -75.352  50.056  1
241568  97.621  -75.358  50.019  1
241569  97.647  -75.364  49.980  1
241570  97.672  -75.371  49.942  1
241571  97.698  -75.377  49.904  1
241572  97.722  -75.382  49.864  1
241573  97.744  -75.386  49.821  1
241574  97.787  -75.384  49.776  1
241575  97.826  -75.399  49.729  1
241576  97.866  -75.414  49.680  1
241577  97.905  -75.429  49.632  1
241578  97.944  -75.444  49.584  1
241579  97.984  -75.459  49.535  1
241580  98.017  -75.479  49.487  1
241581  98.053  -75.486  49.440  1
241582  98.077  -75.493  49.393  1
241583  98.102  -75.500  49.347  1
241584  98.128  -75.507  49.302  1
241585  98.152  -75.514  49.259  1
241586  98.177  -75.521  49.213  1
241587  98.195  -75.535  49.166  1
241588  98.207  -75.554  49.118  1
241589  98.219  -75.573  49.072  1
241590  98.248  -75.586  49.026  1
241591  98.298  -75.577  48.980  1
241592  98.359  -75.557  48.934  1
241593  98.419  -75.555  48.889  1
241594  98.478  -75.561  48.843  1
241595  98.537  -75.568  48.798  1
241596  98.596  -75.575  48.752  1
241597  98.593  -75.620  48.702  1
241598  98.581  -75.638  48.653  1
241599  98.565  -75.641  48.604  1
241600  98.560  -75.646  48.555  1
241601  98.600  -75.656  48.508  1
241602  98.641  -75.665  48.462  1
241603  98.703  -75.686  48.417  1
241604  98.739  -75.699  48.371  1
241605  98.751  -75.705  48.324  1
241606  98.764  -75.711  48.275  1
241607  98.799  -75.701  48.227  1
241608  98.838  -75.685  48.179  1
241609  98.861  -75.674  48.133  1
241610  98.883  -75.675  48.089  1
241611  98.901  -75.699  48.047  1
241612  98.918  -75.724  48.007  1
241613  98.935  -75.749  47.970  1
241614  98.952  -75.775  47.935  1
241615  98.970  -75.800  47.901  1
241616  98.987  -75.824  47.868  1
241617  99.004  -75.849  47.837  1
241618  99.021  -75.874  47.807  1
241619  99.038  -75.897  47.778  1
241620  99.056  -75.913  47.749  1
241621  99.073  -75.930  47.721  1
241622  99.090  -75.947  47.694  1
241623  99.108  -75.963  47.667  1
241624  99.127  -75.979  47.640  1
241625  99.156  -75.994  47.613  1
241626  99.185  -76.008  47.586  1
241627  99.213  -76.022  47.562  1
241628  99.242  -76.032  47.536  1
241629  99.272  -76.037  47.508  1
241630  99.302  -76.041  47.480  1
241631  99.332  -76.047  47.453  1
241632  99.362  -76.051  47.425  1
241633  99.392  -76.056  47.398  1
241634  99.422  -76.061  47.373  1
241635  99.452  -76.066  47.347  1
241636  99.482  -76.070  47.322  1
241637  99.512  -76.075  47.297  1
241638  99.542  -76.080  47.272  1
241639  99.572  -76.085  47.247  1
241640  99.593  -76.088  47.223  1
241641  99.609  -76.091  47.199  1
241642  99.625  -76.094  47.173  1
241643  99.640  -76.096  47.148  1
241644  99.666  -76.100  47.119  1
241645  99.696  -76.105  47.089  1
241646  99.726  -76.110  47.060  1
241647  99.755  -76.114  47.032  1
241648  99.785  -76.119  47.002  1
241649  99.815  -76.124  46.971  1
241650  99.844  -76.129  46.941  1
241651  99.864  -76.144  46.912  1
241652  99.881  -76.166  46.880  1
241653  99.901  -76.189  46.850  1
241654  99.920  -76.213  46.821  1
241655  99.939  -76.236  46.791  1
241656  99.959  -76.260  46.763  1
241657  99.982  -76.267  46.733  1
241658  100.007  -76.263  46.703  1
241659  100.031  -76.260  46.674  1
241660  100.056  -76.257  46.645  1
241661  100.081  -76.254  46.617  1
241662  100.106  -76.251  46.588  1
241663  100.130  -76.247  46.558  1
241664  100.159  -76.245  46.528  1
241665  100.200  -76.248  46.498  1
241666  100.240  -76.250  46.467  1
241667  100.280  -76.253  46.436  1
241668  100.321  -76.255  46.405  1
241669  100.361  -76.257  46.373  1
241670  100.395  -76.271  46.340  1
241671  100.412  -76.298  46.307  1
241672  100.428  -76.322  46.272  1
241673  100.444  -76.345  46.237  1
241674  100.460  -76.369  46.202  1
241675  100.476  -76.392  46.167  1
241676  100.492  -76.416  46.130  1
241677  100.508  -76.439  46.094  1
241678  100.524  -76.463  46.059  1
241679  100.542  -76.480  46.024  1
241680  100.564  -76.489  45.990  1
241681  100.585  -76.496  45.958  1
241682  100.607  -76.505  45.926  1
241683  100.625  -76.518  45.896  1
241684  100.633  -76.552  45.867  1
241685  100.642  -76.585  45.839  1
241686  100.662  -76.603  45.812  1
241687  100.680  -76.622  45.787  1
241688  100.706  -76.634  45.763  1
241689  100.751  -76.628  45.740  1
241690  100.796  -76.623  45.719  1
241691  100.841  -76.617  45.698  1
241692  100.885  -76.611  45.677  1
241693  100.930  -76.606  45.657  1
241694  100.975  -76.600  45.636  1
241695  101.019  -76.595  45.616  1
241696  101.064  -76.589  45.594  1
241697  101.104  -76.586  45.573  1
241698  101.128  -76.596  45.550  1
241699  101.152  -76.605  45.529  1
241700  101.176  -76.614  45.507  1
241701  101.200  -76.624  45.485  1
241702  101.224  -76.633  45.464  1
241703  101.251  -76.643  45.443  1
241704  101.279  -76.654  45.423  1
241705  101.307  -76.665  45.403  1
241706  101.327  -76.676  45.384  1
241707  101.342  -76.687  45.365  1
241708  101.357  -76.699  45.347  1
241709  101.372  -76.712  45.329  1
241710  101.386  -76.724  45.312  1
241711  101.401  -76.736  45.296  1
241712  101.416  -76.748  45.280  1
241713  101.430  -76.760  45.266  1
241714  101.445  -76.771  45.250  1
241715  101.460  -76.784  45.236  1
241716  101.475  -76.796  45.223  1
241717  101.489  -76.808  45.210  1
241718  101.504  -76.820  45.195  1
241719  101.519  -76.832  45.180  1
241720  101.534  -76.844  45.166  1
241721  101.548  -76.856  45.152  1
241722  101.563  -76.868  45.136  1
241723  101.584  -76.869  45.121  1
241724  101.606  -76.869  45.105  1
241725  101.627  -76.869  45.090  1
241726  101.649  -76.870  45.072  1
241727  101.671  -76.870  45.055  1
241728  101.692  -76.870  45.037  1
241729  101.713  -76.871  45.019  1
241730  101.730  -76.882  45.002  1
241731  101.746  -76.893  44.985  1
241732  101.762  -76.904  44.969  1
241733  101.778  -76.915  44.951  1
241734  101.795  -76.927  44.935  1
241735  101.811  -76.938  44.918  1
241736  101.828  -76.949  44.900  1
241737  101.844  -76.960  44.883  1
241738  101.861  -76.972  44.866  1
241739  101.877  -76.982  44.849  1
241740  101.893  -76.994  44.832  1
241741  101.909  -77.005  44.816  1
241742  101.926  -77.016  44.800  1
241743  101.942  -77.027  44.784  1
241744  101.959  -77.038  44.768  1
241745  101.975  -77.050  44.752  1
241746  101.991  -77.061  44.736  1
241747  102.007  -77.072  44.720  1
241748  102.021  -77.081  44.704  1
241749  102.043  -77.100  44.687  1
241750  102.064  -77.120  44.672  1
241751  102.087  -77.140  44.658  1
241752  102.108  -77.160  44.643  1
241753  102.130  -77.179  44.626  1
241754  102.152  -77.199  44.610  1
241755  102.174  -77.219  44.595  1
241756  102.196  -77.238  44.580  1
241757  102.218  -77.257  44.564  1
241758  102.239  -77.277  44.549  1
241759  102.261  -77.297  44.533  1
241760  102.283  -77.316  44.517  1
241761  102.304  -77.330  44.502  1
241762  102.326  -77.332  44.487  1
241763  102.347  -77.333  44.471  1
241764  102.368  -77.335  44.454  1
241765  102.387  -77.336  44.438  1
241766  102.407  -77.338  44.420  1
241767  102.427  -77.340  44.402  1
241768  102.447  -77.341  44.385  1
241769  102.466  -77.344  44.368  1
241770  102.486  -77.345  44.351  1
241771  102.506  -77.348  44.333  1
241772  102.526  -77.349  44.316  1
241773  102.545  -77.351  44.299  1
241774  102.565  -77.353  44.282  1
241775  102.585  -77.354  44.266  1
241776  102.612  -77.359  44.251  1
241777  102.650  -77.367  44.234  1
241778  102.688  -77.374  44.218  1
241779  102.727  -77.382  44.202  1
241780  102.764  -77.390  44.187  1
241781  102.803  -77.398  44.172  1
241782  102.840  -77.405  44.156  1
241783  102.879  -77.413  44.141  1
241784  102.916  -77.421  44.126  1
241785  102.954  -77.429  44.110  1
242061  92.450  -74.569  54.450  1
242062  92.475  -74.580  54.457  1
242063  92.499  -74.590  54.464  1
242064  92.523  -74.602  54.470  1
242065  92.544  -74.600  54.476  1
242066  92.564  -74.584  54.485  1
242067  92.590  -74.574  54.492  1
242068  92.617  -74.565  54.499  1
242069  92.644  -74.556  54.506  1
242070  92.674  -74.548  54.511  1
242071  92.704  -74.540  54.514  1
242072  92.734  -74.531  54.516  1
242073  92.765  -74.524  54.518  1
242074  92.795  -74.531  54.519  1
242075  92.826  -74.537  54.519  1
242076  92.856  -74.539  54.518  1
242077  92.887  -74.540  54.518  1
242078  92.919  -74.541  54.520  1
242079  92.950  -74.543  54.524  1
242080  92.984  -74.549  54.530  1
242081  93.017  -74.555  54.538  1
242082  93.050  -74.562  54.548  1
242083  93.084  -74.567  54.551  1
242084  93.117  -74.573  54.551  1
242085  93.150  -74.579  54.551  1
242086  93.184  -74.585  54.552  1
242087  93.217  -74.590  54.555  1
242088  93.250  -74.596  54.556  1
242089  93.277  -74.593  54.557  1
242090  93.300  -74.583  54.554  1
242091  93.324  -74.573  54.553  1
242092  93.347  -74.563  54.553  1
242093  93.370  -74.552  54.553  1
242094  93.394  -74.543  54.556  1
242095  93.417  -74.533  54.565  1
242096  93.440  -74.523  54.578  1
242097  93.464  -74.513  54.591  1
242098  93.487  -74.503  54.602  1
242099  93.510  -74.493  54.613  1
242100  93.532  -74.488  54.624  1
242101  93.554  -74.484  54.638  1
242102  93.575  -74.480  54.648  1
242103  93.596  -74.475  54.651  1
242104  93.618  -74.471  54.649  1
242105  93.639  -74.467  54.641  1
242106  93.660  -74.463  54.634  1
242107  93.682  -74.458  54.637  1
242108  93.704  -74.455  54.648  1
242109  93.733  -74.464  54.669  1
242110  93.765  -74.477  54.690  1
242111  93.797  -74.489  54.707  1
242112  93.829  -74.501  54.718  1
242113  93.860  -74.514  54.716  1
242114  93.892  -74.526  54.708  1
242115  93.924  -74.539  54.700  1
242116  93.947  -74.543  54.698  1
242117  93.970  -74.545  54.707  1
242118  93.992  -74.547  54.717  1
242119  94.013  -74.549  54.721  1
242120  94.034  -74.549  54.721  1
242121  94.054  -74.549  54.718  1
242122  94.074  -74.549  54.712  1
242123  94.091  -74.546  54.705  1
242124  94.108  -74.544  54.696  1
242125  94.125  -74.542  54.684  1
242126  94.142  -74.540  54.669  1
242127  94.158  -74.537  54.650  1
242128  94.177  -74.536  54.630  1
242129  94.199  -74.537  54.614  1
242130  94.220  -74.537  54.598  1
242131  94.243  -74.538  54.583  1
242132  94.264  -74.539  54.566  1
242133  94.285  -74.540  54.543  1
242134  94.306  -74.540  54.516  1
242135  94.325  -74.542  54.486  1
242136  94.345  -74.543  54.454  1
242137  94.364  -74.543  54.425  1
242138  94.384  -74.544  54.398  1
242139  94.404  -74.545  54.370  1
242140  94.423  -74.546  54.338  1
242141  94.444  -74.550  54.306  1
242142  94.465  -74.557  54.271  1
242143  94.487  -74.564  54.235  1
242144  94.508  -74.568  54.200  1
242145  94.529  -74.570  54.163  1
242146  94.550  -74.573  54.123  1
242147  94.567  -74.581  54.082  1
242148  94.585  -74.588  54.043  1
242149  94.602  -74.596  54.007  1
242150  94.620  -74.603  53.974  1
242151  94.645  -74.610  53.941  1
242152  94.672  -74.616  53.908  1
242153  94.699  -74.623  53.876  1
242154  94.725  -74.629  53.847  1
242155  94.752  -74.635  53.819  1
242156  94.778  -74.641  53.790  1
242157  94.802  -74.646  53.760  1
242158  94.826  -74.651  53.730  1
242159  94.849  -74.656  53.700  1
242160  94.873  -74.661  53.666  1
242161  94.897  -74.666  53.629  1
242162  94.921  -74.671  53.588  1
242163  94.931  -74.668  53.545  1
242164  94.930  -74.657  53.501  1
242165  94.930  -74.646  53.456  1
242166  94.929  -74.636  53.411  1
242167  94.936  -74.624  53.368  1
242168  94.960  -74.614  53.327  1
242169  94.983  -74.603  53.281  1
242170  95.006  -74.593  53.230  1
242171  95.038  -74.601  53.172  1
242172  95.072  -74.618  53.110  1
242173  95.106  -74.634  53.045  1
242174  95.140  -74.650  52.981  1
242175  95.167  -74.670  52.917  1
242176  95.196  -74.688  52.854  1
242177  95.230  -74.704  52.794  1
242178  95.263  -74.719  52.734  1
242179  95.297  -74.735  52.675  1
242180  95.330  -74.750  52.616  1
242181  95.362  -74.765  52.557  1
242182  95.390  -74.775  52.499  1
242183  95.418  -74.785  52.442  1
242184  95.446  -74.796  52.386  1
242185  95.470  -74.795  52.332  1
242186  95.495  -74.794  52.278  1
242187  95.520  -74.793  52.227  1
242188  95.545  -74.792  52.176  1
242189  95.570  -74.791  52.127  1
242190  95.595  -74.791  52.080  1
242191  95.619  -74.789  52.035  1
242192  95.644  -74.788  51.992  1
242193  95.669  -74.787  51.951  1
242194  95.696  -74.781  51.911  1
242195  95.728  -74.755  51.872  1
242196  95.761  -74.729  51.833  1
242197  95.794  -74.703  51.795  1
242198  95.826  -74.677  51.757  1
242199  95.859  -74.650  51.719  1
242200  95.892  -74.624  51.684  1
242201  95.929  -74.629  51.649  1
242202  95.968  -74.640  51.614  1
242203  96.006  -74.650  51.578  1
242204  96.043  -74.672  51.545  1
242205  96.080  -74.707  51.512  1
242206  96.116  -74.743  51.481  1
242207  96.152  -74.778  51.452  1
242208  96.188  -74.814  51.425  1
242209  96.219  -74.826  51.400  1
242210  96.250  -74.837  51.376  1
242211  96.281  -74.847  51.355  1
242212  96.311  -74.858  51.335  1
242213  96.342  -74.869  51.318  1
242214  96.370  -74.879  51.302  1
242215  96.394  -74.890  51.289  1
242216  96.418  -74.901  51.275  1
242217  96.442  -74.913  51.262  1
242218  96.466  -74.923  51.250  1
242219  96.489  -74.941  51.237  1
242220  96.513  -74.962  51.225  1
242221  96.536  -74.983  51.214  1
242222  96.559  -75.004  51.202  1
242223  96.582  -75.025  51.187  1
242224  96.605  -75.045  51.172  1
242225  96.628  -75.066  51.157  1
242226  96.652  -75.087  51.140  1
242227  96.674  -75.108  51.123  1
242228  96.695  -75.123  51.103  1
242229  96.718  -75.135  51.082  1
242230  96.748  -75.140  51.059  1
242231  96.774  -75.138  51.037  1
242232  96.798  -75.133  51.015  1
242233  96.821  -75.128  50.995  1
242234  96.844  -75.123  50.975  1
242235  96.868  -75.116  50.957  1
242236  96.891  -75.111  50.941  1
242237  96.914  -75.106  50.925  1
242238  96.938  -75.100  50.909  1
242239  96.961  -75.095  50.894  1
242240  96.959  -75.175  50.876  1
242241  96.983  -75.167  50.856  1
242242  97.008  -75.158  50.836  1
242243  97.032  -75.150  50.814  1
242244  97.057  -75.142  50.791  1
242245  97.079  -75.149  50.768  1
242246  97.100  -75.157  50.745  1
242247  97.121  -75.163  50.722  1
242248  97.143  -75.171  50.698  1
242249  97.164  -75.179  50.675  1
242250  97.186  -75.185  50.651  1
242251  97.207  -75.193  50.626  1
242252  97.229  -75.201  50.601  1
242253  97.252  -75.209  50.576  1
242254  97.277  -75.218  50.549  1
242255  97.301  -75.227  50.520  1
242256  97.322  -75.236  50.490  1
242257  97.339  -75.245  50.459  1
242258  97.357  -75.252  50.426  1
242259  97.373  -75.261  50.394  1
242260  97.390  -75.269  50.360  1
242261  97.407  -75.276  50.325  1
242262  97.426  -75.285  50.290  1
242263  97.456  -75.291  50.256  1
242264  97.487  -75.298  50.221  1
242265  97.517  -75.305  50.186  1
242266  97.548  -75.311  50.151  1
242267  97.575  -75.317  50.114  1
242268  97.600  -75.323  50.077  1
242269  97.626  -75.330  50.039  1
242270  97.652  -75.336  50.000  1
242271  97.677  -75.342  49.961  1
242272  97.703  -75.349  49.922  1
242273  97.729  -75.355  49.882  1
242274  97.752  -75.360  49.838  1
242275  97.793  -75.368  49.792  1
242276  97.832  -75.383  49.744  1
242277  97.871  -75.398  49.695  1
242278  97.911  -75.413  49.647  1
242279  97.950  -75.428  49.599  1
242280  97.989  -75.443  49.550  1
242281  98.023  -75.456  49.502  1
242282  98.049  -75.463  49.455  1
242283  98.074  -75.470  49.407  1
242284  98.098  -75.477  49.361  1
242285  98.124  -75.483  49.316  1
242286  98.149  -75.490  49.273  1
242287  98.174  -75.497  49.227  1
242288  98.196  -75.507  49.181  1
242289  98.208  -75.525  49.133  1
242290  98.236  -75.539  49.086  1
242291  98.272  -75.549  49.039  1
242292  98.324  -75.538  48.993  1
242293  98.385  -75.518  48.948  1
242294  98.446  -75.497  48.902  1
242295  98.506  -75.481  48.856  1
242296  98.566  -75.488  48.810  1
242297  98.589  -75.516  48.763  1
242298  98.583  -75.562  48.712  1
242299  98.575  -75.599  48.663  1
242300  98.559  -75.603  48.614  1
242301  98.563  -75.609  48.565  1
242302  98.603  -75.618  48.518  1
242303  98.644  -75.628  48.471  1
242304  98.685  -75.638  48.425  1
242305  98.745  -75.658  48.379  1
242306  98.761  -75.665  48.331  1
242307  98.773  -75.670  48.282  1
242308  98.816  -75.652  48.233  1
242309  98.841  -75.642  48.185  1
242310  98.864  -75.631  48.138  1
242311  98.885  -75.636  48.092  1
242312  98.903  -75.661  48.049  1
242313  98.920  -75.686  48.007  1
242314  98.937  -75.711  47.970  1
242315  98.954  -75.736  47.934  1
242316  98.972  -75.760  47.900  1
242317  98.989  -75.785  47.867  1
242318  99.006  -75.810  47.835  1
242319  99.023  -75.835  47.804  1
242320  99.040  -75.859  47.773  1
242321  99.058  -75.884  47.743  1
242322  99.075  -75.909  47.714  1
242323  99.092  -75.931  47.686  1
242324  99.110  -75.947  47.659  1
242325  99.127  -75.963  47.632  1
242326  99.151  -75.978  47.604  1
242327  99.180  -75.994  47.577  1
242328  99.209  -76.002  47.551  1
242329  99.239  -76.007  47.524  1
242330  99.269  -76.012  47.496  1
242331  99.299  -76.016  47.469  1
242332  99.329  -76.022  47.441  1
242333  99.359  -76.026  47.413  1
242334  99.389  -76.031  47.386  1
242335  99.419  -76.036  47.361  1
242336  99.449  -76.041  47.336  1
242337  99.479  -76.046  47.312  1
242338  99.509  -76.050  47.287  1
242339  99.539  -76.055  47.261  1
242340  99.569  -76.060  47.236  1
242341  99.598  -76.065  47.212  1
242342  99.614  -76.067  47.186  1
242343  99.629  -76.070  47.161  1
242344  99.653  -76.074  47.136  1
242345  99.683  -76.079  47.108  1
242346  99.713  -76.083  47.080  1
242347  99.742  -76.088  47.052  1
242348  99.772  -76.092  47.025  1
242349  99.801  -76.097  46.994  1
242350  99.831  -76.102  46.965  1
242351  99.860  -76.107  46.935  1
242352  99.883  -76.121  46.905  1
242353  99.903  -76.144  46.874  1
242354  99.922  -76.167  46.844  1
242355  99.941  -76.190  46.815  1
242356  99.960  -76.213  46.785  1
242357  99.979  -76.235  46.756  1
242358  100.003  -76.248  46.726  1
242359  100.034  -76.240  46.696  1
242360  100.058  -76.237  46.666  1
242361  100.083  -76.233  46.638  1
242362  100.108  -76.230  46.609  1
242363  100.132  -76.227  46.580  1
242364  100.157  -76.223  46.550  1
242365  100.182  -76.220  46.520  1
242366  100.221  -76.223  46.489  1
242367  100.262  -76.225  46.458  1
242368  100.302  -76.227  46.428  1
242369  100.343  -76.230  46.396  1
242370  100.383  -76.232  46.365  1
242371  100.409  -76.259  46.332  1
242372  100.427  -76.299  46.298  1
242373  100.444  -76.330  46.263  1
242374  100.460  -76.354  46.229  1
242375  100.476  -76.377  46.196  1
242376  100.492  -76.401  46.160  1
242377  100.508  -76.424  46.124  1
242378  100.524  -76.448  46.089  1
242379  100.544  -76.461  46.054  1
242380  100.565  -76.470  46.019  1
242381  100.587  -76.477  45.986  1
242382  100.609  -76.486  45.954  1
242383  100.630  -76.493  45.922  1
242384  100.644  -76.517  45.893  1
242385  100.652  -76.550  45.864  1
242386  100.660  -76.583  45.836  1
242387  100.679  -76.603  45.808  1
242388  100.697  -76.621  45.783  1
242389  100.732  -76.626  45.759  1
242390  100.777  -76.620  45.736  1
242391  100.821  -76.614  45.715  1
242392  100.866  -76.608  45.693  1
242393  100.911  -76.603  45.672  1
242394  100.956  -76.598  45.652  1
242395  101.000  -76.592  45.630  1
242396  101.045  -76.586  45.610  1
242397  101.090  -76.580  45.588  1
242398  101.135  -76.575  45.566  1
242399  101.159  -76.584  45.544  1
242400  101.183  -76.593  45.522  1
242401  101.207  -76.602  45.500  1
242402  101.231  -76.611  45.478  1
242403  101.255  -76.621  45.457  1
242404  101.282  -76.631  45.437  1
242405  101.310  -76.642  45.417  1
242406  101.338  -76.652  45.397  1
242407  101.356  -76.664  45.377  1
242408  101.371  -76.676  45.359  1
242409  101.385  -76.688  45.340  1
242410  101.400  -76.700  45.322  1
242411  101.415  -76.712  45.305  1
242412  101.429  -76.724  45.289  1
242413  101.444  -76.736  45.273  1
242414  101.459  -76.748  45.257  1
242415  101.474  -76.760  45.242  1
242416  101.488  -76.772  45.227  1
242417  101.503  -76.784  45.213  1
242418  101.518  -76.796  45.198  1
242419  101.533  -76.808  45.183  1
242420  101.547  -76.820  45.168  1
242421  101.562  -76.832  45.153  1
242422  101.576  -76.844  45.138  1
242423  101.598  -76.845  45.123  1
242424  101.620  -76.845  45.107  1
242425  101.641  -76.845  45.091  1
242426  101.663  -76.845  45.076  1
242427  101.684  -76.845  45.058  1
242428  101.706  -76.845  45.041  1
242429  101.725  -76.851  45.023  1
242430  101.741  -76.862  45.006  1
242431  101.758  -76.873  44.989  1
242432  101.774  -76.884  44.972  1
242433  101.790  -76.896  44.955  1
242434  101.807  -76.906  44.938  1
242435  101.823  -76.918  44.921  1
242436  101.839  -76.929  44.904  1
242437  101.856  -76.940  44.887  1
242438  101.872  -76.951  44.869  1
242439  101.889  -76.962  44.852  1
242440  101.905  -76.974  44.836  1
242441  101.921  -76.985  44.819  1
242442  101.938  -76.996  44.803  1
242443  101.954  -77.007  44.786  1
242444  101.970  -77.019  44.770  1
242445  101.987  -77.029  44.755  1
242446  102.003  -77.041  44.738  1
242447  102.006  -77.041  44.721  1
242448  102.021  -77.052  44.705  1
242449  102.043  -77.072  44.689  1
242450  102.064  -77.091  44.673  1
242451  102.087  -77.110  44.658  1
242452  102.108  -77.130  44.643  1
242453  102.130  -77.150  44.627  1
242454  102.152  -77.169  44.610  1
242455  102.174  -77.189  44.595  1
242456  102.196  -77.209  44.580  1
242457  102.218  -77.229  44.564  1
242458  102.239  -77.248  44.549  1
242459  102.261  -77.267  44.534  1
242460  102.283  -77.287  44.518  1
242461  102.301  -77.290  44.502  1
242462  102.324  -77.291  44.487  1
242463  102.347  -77.292  44.472  1
242464  102.370  -77.293  44.456  1
242465  102.392  -77.294  44.439  1
242466  102.412  -77.296  44.423  1
242467  102.432  -77.298  44.405  1
242468  102.451  -77.300  44.388  1
242469  102.471  -77.301  44.372  1
242470  102.491  -77.304  44.356  1
242471  102.511  -77.305  44.338  1
242472  102.530  -77.307  44.321  1
242473  102.550  -77.309  44.304  1
242474  102.570  -77.310  44.288  1
242475  102.590  -77.313  44.271  1
242476  102.610  -77.314  44.255  1
242477  102.629  -77.316  44.240  1
242478  102.655  -77.320  44.224  1
242479  102.692  -77.327  44.208  1
242480  102.731  -77.335  44.192  1
242481  102.768  -77.343  44.176  1
242482  102.806  -77.351  44.162  1
242483  102.844  -77.358  44.147  1
242484  102.882  -77.366  44.131  1
242763  92.477  -74.547  54.463  1
242764  92.501  -74.559  54.469  1
242765  92.525  -74.569  54.476  1
242766  92.549  -74.576  54.482  1
242767  92.565  -74.557  54.490  1
242768  92.592  -74.547  54.497  1
242769  92.619  -74.538  54.503  1
242770  92.645  -74.529  54.509  1
242771  92.675  -74.521  54.514  1
242772  92.706  -74.512  54.517  1
242773  92.736  -74.505  54.520  1
242774  92.766  -74.496  54.522  1
242775  92.796  -74.505  54.522  1
242776  92.826  -74.516  54.523  1
242777  92.857  -74.517  54.522  1
242778  92.888  -74.518  54.522  1
242779  92.919  -74.519  54.523  1
242780  92.950  -74.521  54.526  1
242781  92.982  -74.521  54.531  1
242782  93.014  -74.526  54.539  1
242783  93.048  -74.532  54.548  1
242784  93.081  -74.537  54.553  1
242785  93.114  -74.543  54.556  1
242786  93.147  -74.549  54.561  1
242787  93.181  -74.555  54.569  1
242788  93.214  -74.561  54.574  1
242789  93.247  -74.567  54.579  1
242790  93.280  -74.572  54.582  1
242791  93.303  -74.562  54.578  1
242792  93.327  -74.552  54.577  1
242793  93.350  -74.542  54.578  1
242794  93.373  -74.532  54.580  1
242795  93.397  -74.522  54.587  1
242796  93.420  -74.512  54.599  1
242797  93.443  -74.502  54.613  1
242798  93.467  -74.493  54.628  1
242799  93.490  -74.483  54.639  1
242800  93.512  -74.476  54.649  1
242801  93.534  -74.471  54.660  1
242802  93.555  -74.468  54.677  1
242803  93.576  -74.463  54.688  1
242804  93.598  -74.458  54.690  1
242805  93.619  -74.455  54.684  1
242806  93.641  -74.450  54.674  1
242807  93.662  -74.446  54.669  1
242808  93.684  -74.442  54.672  1
242809  93.705  -74.437  54.684  1
242810  93.726  -74.433  54.705  1
242811  93.758  -74.446  54.726  1
242812  93.789  -74.458  54.741  1
242813  93.821  -74.471  54.750  1
242814  93.853  -74.483  54.748  1
242815  93.885  -74.496  54.741  1
242816  93.917  -74.508  54.732  1
242817  93.941  -74.513  54.725  1
242818  93.964  -74.515  54.730  1
242819  93.985  -74.518  54.736  1
242820  94.007  -74.520  54.737  1
242821  94.030  -74.522  54.732  1
242822  94.050  -74.521  54.724  1
242823  94.070  -74.521  54.715  1
242824  94.090  -74.521  54.706  1
242825  94.107  -74.519  54.697  1
242826  94.124  -74.517  54.685  1
242827  94.141  -74.515  54.669  1
242828  94.157  -74.512  54.650  1
242829  94.177  -74.511  54.630  1
242830  94.198  -74.512  54.613  1
242831  94.220  -74.512  54.597  1
242832  94.242  -74.513  54.581  1
242833  94.263  -74.514  54.565  1
242834  94.284  -74.515  54.543  1
242835  94.305  -74.515  54.517  1
242836  94.324  -74.515  54.489  1
242837  94.344  -74.517  54.458  1
242838  94.363  -74.518  54.428  1
242839  94.383  -74.518  54.399  1
242840  94.403  -74.519  54.370  1
242841  94.422  -74.521  54.337  1
242842  94.443  -74.526  54.305  1
242843  94.465  -74.533  54.271  1
242844  94.486  -74.540  54.237  1
242845  94.508  -74.546  54.204  1
242846  94.529  -74.549  54.169  1
242847  94.548  -74.555  54.129  1
242848  94.565  -74.562  54.088  1
242849  94.583  -74.570  54.048  1
242850  94.600  -74.577  54.013  1
242851  94.618  -74.586  53.979  1
242852  94.639  -74.593  53.946  1
242853  94.666  -74.599  53.910  1
242854  94.693  -74.606  53.876  1
242855  94.719  -74.612  53.844  1
242856  94.744  -74.617  53.813  1
242857  94.767  -74.621  53.783  1
242858  94.791  -74.627  53.754  1
242859  94.815  -74.631  53.724  1
242860  94.839  -74.637  53.694  1
242861  94.862  -74.642  53.662  1
242862  94.886  -74.646  53.627  1
242863  94.910  -74.652  53.590  1
242864  94.911  -74.642  53.551  1
242865  94.910  -74.631  53.510  1
242866  94.910  -74.621  53.465  1
242867  94.920  -74.610  53.421  1
242868  94.944  -74.599  53.378  1
242869  94.967  -74.588  53.335  1
242870  94.990  -74.577  53.291  1
242871  95.014  -74.568  53.241  1
242872  95.048  -74.584  53.184  1
242873  95.082  -74.600  53.121  1
242874  95.116  -74.616  53.055  1
242875  95.150  -74.632  52.989  1
242876  95.183  -74.649  52.923  1
242877  95.207  -74.671  52.859  1
242878  95.238  -74.688  52.798  1
242879  95.271  -74.704  52.737  1
242880  95.305  -74.719  52.676  1
242881  95.338  -74.735  52.618  1
242882  95.371  -74.750  52.560  1
242883  95.399  -74.760  52.502  1
242884  95.426  -74.771  52.445  1
242885  95.453  -74.776  52.388  1
242886  95.477  -74.775  52.334  1
242887  95.502  -74.775  52.281  1
242888  95.527  -74.773  52.230  1
242889  95.552  -74.772  52.180  1
242890  95.577  -74.772  52.131  1
242891  95.602  -74.771  52.085  1
242892  95.627  -74.769  52.041  1
242893  95.652  -74.769  51.996  1
242894  95.676  -74.768  51.955  1
242895  95.701  -74.767  51.916  1
242896  95.731  -74.750  51.877  1
242897  95.763  -74.725  51.838  1
242898  95.796  -74.698  51.799  1
242899  95.829  -74.672  51.762  1
242900  95.862  -74.646  51.723  1
242901  95.897  -74.639  51.686  1
242902  95.936  -74.650  51.650  1
242903  95.974  -74.660  51.614  1
242904  96.013  -74.671  51.578  1
242905  96.051  -74.681  51.544  1
242906  96.090  -74.692  51.511  1
242907  96.128  -74.703  51.479  1
242908  96.164  -74.738  51.450  1
242909  96.200  -74.774  51.422  1
242910  96.234  -74.800  51.395  1
242911  96.265  -74.811  51.370  1
242912  96.296  -74.822  51.349  1
242913  96.326  -74.832  51.329  1
242914  96.350  -74.843  51.310  1
242915  96.374  -74.854  51.295  1
242916  96.398  -74.866  51.281  1
242917  96.422  -74.876  51.267  1
242918  96.446  -74.888  51.254  1
242919  96.470  -74.899  51.242  1
242920  96.494  -74.916  51.229  1
242921  96.517  -74.937  51.219  1
242922  96.540  -74.957  51.210  1
242923  96.564  -74.979  51.200  1
242924  96.587  -74.999  51.187  1
242925  96.609  -75.020  51.175  1
242926  96.632  -75.041  51.161  1
242927  96.656  -75.062  51.146  1
242928  96.679  -75.082  51.129  1
242929  96.704  -75.099  51.109  1
242930  96.730  -75.112  51.088  1
242931  96.748  -75.118  51.066  1
242932  96.768  -75.114  51.044  1
242933  96.791  -75.109  51.023  1
242934  96.814  -75.103  51.003  1
242935  96.838  -75.098  50.983  1
242936  96.861  -75.092  50.965  1
242937  96.884  -75.087  50.949  1
242938  96.908  -75.081  50.934  1
242939  96.931  -75.076  50.919  1
242940  96.954  -75.070  50.905  1
242941  96.960  -75.126  50.887  1
242942  96.984  -75.117  50.868  1
242943  97.009  -75.109  50.849  1
242944  97.032  -75.106  50.827  1
242945  97.054  -75.113  50.805  1
242946  97.075  -75.120  50.782  1
242947  97.097  -75.128  50.760  1
242948  97.118  -75.135  50.737  1
242949  97.140  -75.142  50.714  1
242950  97.161  -75.150  50.692  1
242951  97.183  -75.157  50.669  1
242952  97.204  -75.164  50.648  1
242953  97.226  -75.172  50.627  1
242954  97.249  -75.180  50.604  1
242955  97.273  -75.189  50.579  1
242956  97.298  -75.198  50.551  1
242957  97.322  -75.207  50.521  1
242958  97.341  -75.216  50.490  1
242959  97.358  -75.224  50.457  1
242960  97.375  -75.232  50.423  1
242961  97.392  -75.240  50.387  1
242962  97.409  -75.248  50.349  1
242963  97.429  -75.256  50.311  1
242964  97.459  -75.263  50.276  1
242965  97.490  -75.269  50.241  1
242966  97.521  -75.276  50.205  1
242967  97.551  -75.282  50.170  1
242968  97.580  -75.289  50.134  1
242969  97.605  -75.295  50.097  1
242970  97.631  -75.301  50.058  1
242971  97.657  -75.308  50.020  1
242972  97.682  -75.314  49.980  1
242973  97.708  -75.320  49.940  1
242974  97.734  -75.326  49.899  1
242975  97.763  -75.333  49.854  1
242976  97.815  -75.345  49.807  1
242977  97.871  -75.358  49.758  1
242978  97.916  -75.370  49.709  1
242979  97.960  -75.384  49.661  1
242980  98.006  -75.398  49.614  1
242981  98.051  -75.411  49.566  1
242982  98.073  -75.420  49.517  1
242983  98.089  -75.430  49.469  1
242984  98.106  -75.438  49.421  1
242985  98.122  -75.447  49.375  1
242986  98.139  -75.455  49.330  1
242987  98.155  -75.464  49.286  1
242988  98.172  -75.473  49.241  1
242989  98.195  -75.480  49.194  1
242990  98.224  -75.491  49.147  1
242991  98.261  -75.501  49.099  1
242992  98.296  -75.511  49.052  1
242993  98.351  -75.498  49.005  1
242994  98.412  -75.477  48.961  1
242995  98.474  -75.457  48.914  1
242996  98.535  -75.436  48.868  1
242997  98.586  -75.420  48.822  1
242998  98.579  -75.458  48.771  1
242999  98.573  -75.505  48.722  1
243000  98.566  -75.551  48.672  1
243001  98.553  -75.565  48.623  1
243002  98.566  -75.571  48.575  1
243003  98.606  -75.581  48.527  1
243004  98.647  -75.591  48.480  1
243005  98.688  -75.601  48.432  1
243006  98.728  -75.611  48.385  1
243007  98.769  -75.624  48.338  1
243008  98.796  -75.619  48.289  1
243009  98.819  -75.609  48.239  1
243010  98.844  -75.598  48.190  1
243011  98.867  -75.587  48.143  1
243012  98.887  -75.597  48.096  1
243013  98.905  -75.622  48.052  1
243014  98.922  -75.647  48.008  1
243015  98.939  -75.671  47.970  1
243016  98.956  -75.696  47.934  1
243017  98.974  -75.721  47.899  1
243018  98.991  -75.746  47.866  1
243019  99.008  -75.771  47.832  1
243020  99.025  -75.796  47.800  1
243021  99.042  -75.821  47.769  1
243022  99.060  -75.846  47.738  1
243023  99.077  -75.871  47.708  1
243024  99.094  -75.896  47.679  1
243025  99.111  -75.920  47.651  1
243026  99.128  -75.945  47.622  1
243027  99.147  -75.964  47.594  1
243028  99.176  -75.972  47.566  1
243029  99.206  -75.977  47.539  1
243030  99.236  -75.982  47.511  1
243031  99.266  -75.987  47.484  1
243032  99.296  -75.992  47.456  1
243033  99.326  -75.997  47.429  1
243034  99.356  -76.001  47.400  1
243035  99.385  -76.007  47.374  1
243036  99.416  -76.011  47.349  1
243037  99.445  -76.016  47.324  1
243038  99.476  -76.021  47.301  1
243039  99.505  -76.025  47.277  1
243040  99.536  -76.031  47.252  1
243041  99.565  -76.035  47.226  1
243042  99.595  -76.040  47.204  1
243043  99.618  -76.044  47.180  1
243044  99.640  -76.047  47.155  1
243045  99.670  -76.052  47.130  1
243046  99.700  -76.057  47.102  1
243047  99.729  -76.061  47.074  1
243048  99.759  -76.066  47.046  1
243049  99.788  -76.071  47.019  1
243050  99.818  -76.076  46.989  1
243051  99.848  -76.082  46.959  1
243052  99.877  -76.087  46.929  1
243053  99.903  -76.097  46.899  1
243054  99.923  -76.120  46.868  1
243055  99.942  -76.143  46.838  1
243056  99.961  -76.166  46.809  1
243057  99.980  -76.188  46.779  1
243058  99.999  -76.211  46.749  1
243059  100.019  -76.232  46.719  1
243060  100.053  -76.222  46.689  1
243061  100.085  -76.213  46.659  1
243062  100.110  -76.210  46.630  1
243063  100.134  -76.207  46.601  1
243064  100.159  -76.204  46.572  1
243065  100.184  -76.201  46.542  1
243066  100.208  -76.197  46.511  1
243067  100.243  -76.198  46.480  1
243068  100.284  -76.200  46.449  1
243069  100.324  -76.202  46.419  1
243070  100.364  -76.204  46.387  1
243071  100.405  -76.207  46.356  1
243072  100.423  -76.247  46.323  1
243073  100.441  -76.288  46.289  1
243074  100.459  -76.328  46.255  1
243075  100.476  -76.362  46.221  1
243076  100.492  -76.386  46.188  1
243077  100.508  -76.408  46.153  1
243078  100.524  -76.432  46.119  1
243079  100.545  -76.442  46.084  1
243080  100.567  -76.450  46.050  1
243081  100.588  -76.458  46.015  1
243082  100.610  -76.467  45.982  1
243083  100.631  -76.474  45.951  1
243084  100.653  -76.483  45.920  1
243085  100.662  -76.514  45.889  1
243086  100.670  -76.548  45.860  1
243087  100.678  -76.582  45.832  1
243088  100.695  -76.602  45.805  1
243089  100.714  -76.621  45.781  1
243090  100.758  -76.618  45.757  1
243091  100.802  -76.611  45.733  1
243092  100.847  -76.606  45.711  1
243093  100.892  -76.600  45.688  1
243094  100.936  -76.595  45.667  1
243095  100.981  -76.589  45.646  1
243096  101.026  -76.583  45.624  1
243097  101.071  -76.578  45.603  1
243098  101.115  -76.572  45.582  1
243099  101.160  -76.567  45.560  1
243100  101.190  -76.572  45.538  1
243101  101.214  -76.581  45.516  1
243102  101.238  -76.590  45.494  1
243103  101.262  -76.599  45.473  1
243104  101.285  -76.608  45.452  1
243105  101.313  -76.619  45.431  1
243106  101.341  -76.630  45.411  1
243107  101.369  -76.640  45.391  1
243108  101.384  -76.652  45.371  1
243109  101.399  -76.664  45.352  1
243110  101.413  -76.676  45.334  1
243111  101.428  -76.688  45.316  1
243112  101.443  -76.700  45.298  1
243113  101.458  -76.712  45.282  1
243114  101.472  -76.724  45.266  1
243115  101.487  -76.736  45.249  1
243116  101.502  -76.748  45.233  1
243117  101.516  -76.760  45.218  1
243118  101.531  -76.772  45.203  1
243119  101.546  -76.784  45.188  1
243120  101.561  -76.796  45.173  1
243121  101.575  -76.809  45.157  1
243122  101.591  -76.820  45.141  1
243123  101.612  -76.820  45.125  1
243124  101.634  -76.820  45.110  1
243125  101.655  -76.820  45.093  1
243126  101.677  -76.821  45.077  1
243127  101.698  -76.821  45.061  1
243128  101.720  -76.821  45.044  1
243129  101.737  -76.831  45.028  1
243130  101.753  -76.842  45.011  1
243131  101.769  -76.853  44.993  1
243132  101.786  -76.865  44.977  1
243133  101.802  -76.875  44.959  1
243134  101.819  -76.887  44.941  1
243135  101.835  -76.898  44.925  1
243136  101.851  -76.909  44.908  1
243137  101.868  -76.920  44.891  1
243138  101.884  -76.931  44.874  1
243139  101.900  -76.943  44.856  1
243140  101.917  -76.953  44.839  1
243141  101.933  -76.965  44.823  1
243142  101.950  -76.976  44.807  1
243143  101.966  -76.987  44.790  1
243144  101.982  -76.998  44.774  1
243145  101.990  -77.003  44.758  1
243146  101.994  -77.003  44.742  1
243147  102.002  -77.006  44.725  1
243148  102.021  -77.022  44.708  1
243149  102.043  -77.042  44.692  1
243150  102.064  -77.062  44.676  1
243151  102.087  -77.081  44.660  1
243152  102.108  -77.100  44.645  1
243153  102.130  -77.120  44.629  1
243154  102.152  -77.140  44.613  1
243155  102.174  -77.160  44.596  1
243156  102.196  -77.179  44.580  1
243157  102.218  -77.199  44.565  1
243158  102.239  -77.219  44.550  1
243159  102.261  -77.238  44.535  1
243160  102.281  -77.250  44.519  1
243161  102.299  -77.250  44.504  1
243162  102.321  -77.251  44.488  1
243163  102.344  -77.252  44.473  1
243164  102.367  -77.253  44.458  1
243165  102.390  -77.254  44.442  1
243166  102.413  -77.255  44.426  1
243167  102.436  -77.256  44.409  1
243168  102.456  -77.257  44.392  1
243169  102.476  -77.260  44.376  1
243170  102.495  -77.261  44.359  1
243171  102.515  -77.263  44.343  1
243172  102.535  -77.265  44.326  1
243173  102.555  -77.266  44.310  1
243174  102.575  -77.269  44.293  1
243175  102.595  -77.270  44.276  1
243176  102.614  -77.272  44.260  1
243177  102.634  -77.274  44.244  1
243178  102.654  -77.276  44.229  1
243179  102.674  -77.278  44.213  1
243180  102.696  -77.280  44.197  1
243181  102.734  -77.288  44.182  1
243182  102.772  -77.296  44.166  1
243183  102.810  -77.304  44.152  1
243465  92.503  -74.526  54.477  1
243466  92.527  -74.537  54.482  1
243467  92.552  -74.547  54.488  1
243468  92.567  -74.530  54.495  1
243469  92.593  -74.521  54.501  1
243470  92.620  -74.512  54.508  1
243471  92.647  -74.502  54.513  1
243472  92.676  -74.493  54.517  1
243473  92.707  -74.486  54.521  1
243474  92.737  -74.477  54.524  1
243475  92.767  -74.469  54.526  1
243476  92.797  -74.479  54.526  1
243477  92.827  -74.495  54.527  1
243478  92.858  -74.496  54.527  1
243479  92.889  -74.497  54.527  1
243480  92.920  -74.498  54.527  1
243481  92.951  -74.499  54.528  1
243482  92.983  -74.500  54.531  1
243483  93.013  -74.501  54.537  1
243484  93.045  -74.502  54.544  1
243485  93.078  -74.508  54.549  1
243486  93.111  -74.514  54.555  1
243487  93.144  -74.520  54.564  1
243488  93.178  -74.525  54.578  1
243489  93.211  -74.531  54.588  1
243490  93.244  -74.537  54.595  1
243491  93.277  -74.543  54.600  1
243492  93.306  -74.541  54.597  1
243493  93.329  -74.531  54.597  1
243494  93.353  -74.521  54.600  1
243495  93.376  -74.512  54.605  1
243496  93.400  -74.502  54.617  1
243497  93.423  -74.492  54.633  1
243498  93.446  -74.482  54.650  1
243499  93.470  -74.471  54.665  1
243500  93.492  -74.463  54.675  1
243501  93.513  -74.459  54.684  1
243502  93.535  -74.455  54.694  1
243503  93.556  -74.451  54.712  1
243504  93.578  -74.446  54.719  1
243505  93.599  -74.442  54.719  1
243506  93.621  -74.438  54.713  1
243507  93.642  -74.433  54.705  1
243508  93.663  -74.430  54.702  1
243509  93.685  -74.425  54.707  1
243510  93.706  -74.421  54.718  1
243511  93.727  -74.417  54.735  1
243512  93.751  -74.415  54.754  1
243513  93.782  -74.427  54.771  1
243514  93.814  -74.440  54.783  1
243515  93.846  -74.452  54.780  1
243516  93.877  -74.465  54.771  1
243517  93.909  -74.477  54.761  1
243518  93.935  -74.483  54.754  1
243519  93.957  -74.486  54.754  1
243520  93.979  -74.488  54.754  1
243521  94.001  -74.490  54.749  1
243522  94.024  -74.493  54.739  1
243523  94.045  -74.494  54.726  1
243524  94.065  -74.494  54.714  1
243525  94.085  -74.493  54.703  1
243526  94.105  -74.493  54.693  1
243527  94.123  -74.491  54.683  1
243528  94.139  -74.489  54.667  1
243529  94.156  -74.487  54.649  1
243530  94.176  -74.486  54.629  1
243531  94.198  -74.487  54.609  1
243532  94.219  -74.487  54.592  1
243533  94.241  -74.488  54.576  1
243534  94.261  -74.488  54.559  1
243535  94.282  -74.489  54.538  1
243536  94.303  -74.489  54.514  1
243537  94.323  -74.490  54.487  1
243538  94.343  -74.491  54.458  1
243539  94.362  -74.492  54.427  1
243540  94.382  -74.493  54.398  1
243541  94.402  -74.493  54.368  1
243542  94.421  -74.496  54.335  1
243543  94.443  -74.502  54.303  1
243544  94.465  -74.508  54.271  1
243545  94.486  -74.515  54.238  1
243546  94.507  -74.522  54.208  1
243547  94.529  -74.528  54.173  1
243548  94.546  -74.537  54.135  1
243549  94.563  -74.544  54.094  1
243550  94.581  -74.552  54.054  1
243551  94.598  -74.560  54.018  1
243552  94.616  -74.568  53.983  1
243553  94.633  -74.575  53.949  1
243554  94.660  -74.582  53.913  1
243555  94.686  -74.587  53.876  1
243556  94.709  -74.593  53.842  1
243557  94.733  -74.597  53.810  1
243558  94.757  -74.603  53.778  1
243559  94.780  -74.607  53.748  1
243560  94.804  -74.612  53.718  1
243561  94.828  -74.617  53.688  1
243562  94.851  -74.622  53.656  1
243563  94.876  -74.628  53.623  1
243564  94.892  -74.628  53.588  1
243565  94.891  -74.617  53.552  1
243566  94.890  -74.606  53.513  1
243567  94.904  -74.596  53.472  1
243568  94.927  -74.584  53.429  1
243569  94.951  -74.574  53.387  1
243570  94.974  -74.563  53.344  1
243571  94.997  -74.552  53.299  1
243572  95.024  -74.550  53.249  1
243573  95.058  -74.567  53.192  1
243574  95.092  -74.583  53.128  1
243575  95.126  -74.599  53.062  1
243576  95.160  -74.615  52.995  1
243577  95.194  -74.631  52.928  1
243578  95.224  -74.650  52.863  1
243579  95.248  -74.671  52.801  1
243580  95.279  -74.689  52.739  1
243581  95.313  -74.704  52.678  1
243582  95.346  -74.720  52.620  1
243583  95.379  -74.735  52.562  1
243584  95.407  -74.745  52.505  1
243585  95.435  -74.756  52.448  1
243586  95.460  -74.756  52.392  1
243587  95.485  -74.756  52.338  1
243588  95.510  -74.754  52.285  1
243589  95.534  -74.753  52.234  1
243590  95.559  -74.753  52.185  1
243591  95.584  -74.752  52.136  1
243592  95.609  -74.750  52.090  1
243593  95.634  -74.750  52.046  1
243594  95.659  -74.749  52.003  1
243595  95.684  -74.748  51.962  1
243596  95.708  -74.747  51.922  1
243597  95.733  -74.746  51.882  1
243598  95.766  -74.720  51.842  1
243599  95.799  -74.693  51.804  1
243600  95.831  -74.668  51.765  1
243601  95.865  -74.648  51.725  1
243602  95.904  -74.659  51.688  1
243603  95.942  -74.669  51.651  1
243604  95.980  -74.680  51.614  1
243605  96.019  -74.690  51.578  1
243606  96.057  -74.701  51.543  1
243607  96.096  -74.712  51.510  1
243608  96.134  -74.722  51.477  1
243609  96.173  -74.733  51.447  1
243610  96.212  -74.744  51.418  1
243611  96.249  -74.769  51.391  1
243612  96.281  -74.785  51.365  1
243613  96.306  -74.797  51.343  1
243614  96.330  -74.807  51.322  1
243615  96.355  -74.819  51.303  1
243616  96.379  -74.829  51.287  1
243617  96.402  -74.841  51.272  1
243618  96.427  -74.852  51.259  1
243619  96.451  -74.863  51.245  1
243620  96.475  -74.874  51.233  1
243621  96.499  -74.891  51.222  1
243622  96.522  -74.911  51.213  1
243623  96.544  -74.932  51.204  1
243624  96.568  -74.953  51.196  1
243625  96.591  -74.974  51.187  1
243626  96.617  -74.988  51.176  1
243627  96.643  -75.001  51.164  1
243628  96.670  -75.013  51.150  1
243629  96.696  -75.026  51.133  1
243630  96.722  -75.039  51.114  1
243631  96.749  -75.053  51.093  1
243632  96.776  -75.081  51.071  1
243633  96.789  -75.079  51.051  1
243634  96.803  -75.077  51.031  1
243635  96.817  -75.075  51.010  1
243636  96.831  -75.073  50.990  1
243637  96.855  -75.067  50.972  1
243638  96.878  -75.062  50.956  1
243639  96.901  -75.057  50.941  1
243640  96.925  -75.051  50.928  1
243641  96.948  -75.045  50.914  1
243642  96.961  -75.076  50.898  1
243643  96.985  -75.067  50.880  1
243644  97.008  -75.069  50.861  1
243645  97.029  -75.077  50.841  1
243646  97.051  -75.084  50.819  1
243647  97.072  -75.091  50.797  1
243648  97.094  -75.099  50.776  1
243649  97.115  -75.106  50.752  1
243650  97.137  -75.113  50.731  1
243651  97.158  -75.120  50.710  1
243652  97.180  -75.128  50.689  1
243653  97.201  -75.135  50.672  1
243654  97.223  -75.142  50.653  1
243655  97.245  -75.151  50.633  1
243656  97.270  -75.160  50.610  1
243657  97.294  -75.170  50.583  1
243658  97.318  -75.179  50.553  1
243659  97.343  -75.188  50.522  1
243660  97.360  -75.196  50.488  1
243661  97.377  -75.204  50.453  1
243662  97.394  -75.212  50.414  1
243663  97.410  -75.220  50.373  1
243664  97.432  -75.228  50.333  1
243665  97.463  -75.234  50.295  1
243666  97.494  -75.241  50.259  1
243667  97.524  -75.247  50.224  1
243668  97.555  -75.254  50.189  1
243669  97.585  -75.260  50.153  1
243670  97.610  -75.267  50.116  1
243671  97.636  -75.273  50.077  1
243672  97.662  -75.279  50.039  1
243673  97.687  -75.286  50.000  1
243674  97.713  -75.292  49.959  1
243675  97.747  -75.299  49.916  1
243676  97.781  -75.306  49.869  1
243677  97.824  -75.316  49.821  1
243678  97.879  -75.328  49.773  1
243679  97.935  -75.340  49.724  1
243680  97.990  -75.352  49.677  1
243681  98.046  -75.364  49.630  1
243682  98.095  -75.377  49.582  1
243683  98.115  -75.386  49.532  1
243684  98.129  -75.395  49.484  1
243685  98.143  -75.405  49.436  1
243686  98.156  -75.414  49.388  1
243687  98.169  -75.424  49.342  1
243688  98.183  -75.433  49.298  1
243689  98.197  -75.442  49.252  1
243690  98.210  -75.452  49.206  1
243691  98.249  -75.454  49.159  1
243692  98.298  -75.453  49.111  1
243693  98.347  -75.452  49.063  1
243694  98.395  -75.452  49.017  1
243695  98.443  -75.440  48.972  1
243696  98.489  -75.425  48.925  1
243697  98.533  -75.410  48.879  1
243698  98.578  -75.395  48.831  1
243699  98.575  -75.419  48.780  1
243700  98.563  -75.451  48.731  1
243701  98.556  -75.493  48.681  1
243702  98.547  -75.527  48.631  1
243703  98.568  -75.534  48.583  1
243704  98.609  -75.544  48.535  1
243705  98.650  -75.554  48.487  1
243706  98.690  -75.564  48.439  1
243707  98.731  -75.574  48.390  1
243708  98.771  -75.581  48.343  1
243709  98.799  -75.576  48.294  1
243710  98.822  -75.565  48.243  1
243711  98.847  -75.555  48.194  1
243712  98.870  -75.544  48.147  1
243713  98.889  -75.558  48.100  1
243714  98.907  -75.583  48.054  1
243715  98.924  -75.608  48.010  1
243716  98.941  -75.633  47.970  1
243717  98.958  -75.658  47.931  1
243718  98.976  -75.683  47.895  1
243719  98.993  -75.708  47.861  1
243720  99.010  -75.732  47.828  1
243721  99.027  -75.757  47.795  1
243722  99.045  -75.782  47.763  1
243723  99.062  -75.807  47.732  1
243724  99.079  -75.832  47.701  1
243725  99.096  -75.856  47.671  1
243726  99.113  -75.881  47.641  1
243727  99.133  -75.911  47.611  1
243728  99.163  -75.921  47.582  1
243729  99.195  -75.921  47.554  1
243730  99.224  -75.927  47.527  1
243731  99.253  -75.932  47.498  1
243732  99.282  -75.938  47.471  1
243733  99.311  -75.944  47.443  1
243734  99.340  -75.950  47.416  1
243735  99.369  -75.956  47.388  1
243736  99.398  -75.963  47.362  1
243737  99.427  -75.968  47.336  1
243738  99.456  -75.974  47.312  1
243739  99.485  -75.980  47.289  1
243740  99.514  -75.986  47.265  1
243741  99.543  -75.992  47.241  1
243742  99.572  -75.998  47.216  1
243743  99.602  -76.003  47.195  1
243744  99.626  -76.020  47.173  1
243745  99.657  -76.027  47.149  1
243746  99.687  -76.032  47.124  1
243747  99.717  -76.038  47.097  1
243748  99.747  -76.043  47.069  1
243749  99.776  -76.048  47.041  1
243750  99.806  -76.053  47.013  1
243751  99.836  -76.059  46.984  1
243752  99.865  -76.064  46.954  1
243753  99.895  -76.069  46.923  1
243754  99.919  -76.082  46.893  1
243755  99.943  -76.096  46.861  1
243756  99.962  -76.119  46.832  1
243757  99.981  -76.141  46.803  1
243758  100.000  -76.164  46.773  1
243759  100.019  -76.187  46.743  1
243760  100.039  -76.210  46.713  1
243761  100.069  -76.207  46.682  1
243762  100.104  -76.196  46.651  1
243763  100.137  -76.187  46.622  1
243764  100.161  -76.183  46.593  1
243765  100.186  -76.180  46.563  1
243766  100.210  -76.177  46.533  1
243767  100.235  -76.173  46.501  1
243768  100.265  -76.173  46.470  1
243769  100.305  -76.175  46.440  1
243770  100.346  -76.177  46.409  1
243771  100.387  -76.179  46.378  1
243772  100.420  -76.194  46.346  1
243773  100.437  -76.235  46.314  1
243774  100.455  -76.276  46.280  1
243775  100.473  -76.316  46.247  1
243776  100.491  -76.357  46.213  1
243777  100.508  -76.393  46.180  1
243778  100.525  -76.415  46.146  1
243779  100.547  -76.423  46.111  1
243780  100.568  -76.431  46.077  1
243781  100.590  -76.439  46.043  1
243782  100.611  -76.447  46.010  1
243783  100.633  -76.455  45.977  1
243784  100.654  -76.463  45.946  1
243785  100.672  -76.479  45.915  1
243786  100.680  -76.513  45.885  1
243787  100.688  -76.546  45.856  1
243788  100.696  -76.580  45.828  1
243789  100.712  -76.602  45.802  1
243790  100.738  -76.614  45.777  1
243791  100.783  -76.608  45.753  1
243792  100.828  -76.603  45.729  1
243793  100.873  -76.598  45.706  1
243794  100.917  -76.592  45.684  1
243795  100.962  -76.586  45.662  1
243796  101.007  -76.580  45.640  1
243797  101.051  -76.575  45.619  1
243798  101.096  -76.570  45.598  1
243799  101.141  -76.564  45.576  1
243800  101.186  -76.558  45.554  1
243801  101.220  -76.560  45.532  1
243802  101.245  -76.569  45.509  1
243803  101.268  -76.578  45.488  1
243804  101.292  -76.587  45.467  1
243805  101.316  -76.596  45.446  1
243806  101.344  -76.607  45.425  1
243807  101.372  -76.618  45.404  1
243808  101.398  -76.628  45.385  1
243809  101.412  -76.640  45.365  1
243810  101.427  -76.652  45.346  1
243811  101.442  -76.665  45.327  1
243812  101.457  -76.676  45.310  1
243813  101.471  -76.688  45.291  1
243814  101.486  -76.700  45.275  1
243815  101.501  -76.712  45.258  1
243816  101.516  -76.724  45.241  1
243817  101.530  -76.737  45.225  1
243818  101.545  -76.748  45.209  1
243819  101.560  -76.760  45.194  1
243820  101.574  -76.772  45.178  1
243821  101.589  -76.784  45.162  1
243822  101.604  -76.796  45.146  1
243823  101.626  -76.796  45.131  1
243824  101.647  -76.796  45.115  1
243825  101.669  -76.796  45.099  1
243826  101.691  -76.796  45.082  1
243827  101.712  -76.796  45.066  1
243828  101.733  -76.799  45.049  1
243829  101.749  -76.811  45.032  1
243830  101.765  -76.822  45.015  1
243831  101.781  -76.834  44.999  1
243832  101.798  -76.844  44.981  1
243833  101.814  -76.856  44.964  1
243834  101.830  -76.867  44.947  1
243835  101.847  -76.878  44.930  1
243836  101.863  -76.889  44.912  1
243837  101.880  -76.900  44.896  1
243838  101.896  -76.912  44.879  1
243839  101.912  -76.922  44.862  1
243840  101.928  -76.934  44.844  1
243841  101.945  -76.945  44.827  1
243842  101.961  -76.956  44.811  1
243843  101.978  -76.967  44.794  1
243844  101.976  -76.965  44.778  1
243845  101.983  -76.967  44.762  1
243846  101.990  -76.969  44.745  1
243847  101.999  -76.973  44.729  1
243848  102.021  -76.993  44.713  1
243849  102.043  -77.012  44.696  1
243850  102.064  -77.032  44.680  1
243851  102.087  -77.052  44.664  1
243852  102.108  -77.072  44.648  1
243853  102.130  -77.091  44.632  1
243854  102.152  -77.110  44.616  1
243855  102.174  -77.130  44.600  1
243856  102.196  -77.150  44.583  1
243857  102.218  -77.169  44.568  1
243858  102.239  -77.189  44.552  1
243859  102.261  -77.209  44.537  1
243860  102.278  -77.209  44.522  1
243861  102.296  -77.210  44.506  1
243862  102.319  -77.210  44.491  1
243863  102.342  -77.212  44.475  1
243864  102.365  -77.213  44.460  1
243865  102.388  -77.213  44.445  1
243866  102.411  -77.215  44.429  1
243867  102.434  -77.216  44.413  1
243868  102.457  -77.216  44.396  1
243869  102.480  -77.217  44.380  1
243870  102.501  -77.219  44.363  1
243871  102.520  -77.221  44.347  1
243872  102.540  -77.222  44.331  1
243873  102.559  -77.225  44.315  1
243874  102.580  -77.226  44.299  1
243875  102.599  -77.229  44.282  1
243876  102.619  -77.230  44.265  1
243877  102.639  -77.232  44.249  1
243878  102.659  -77.234  44.233  1
243879  102.678  -77.235  44.218  1
243880  102.698  -77.237  44.202  1
243881  102.718  -77.239  44.187  1
243882  102.738  -77.241  44.172  1
244167  92.529  -74.504  54.489  1
244168  92.554  -74.515  54.494  1
244169  92.571  -74.505  54.501  1
244170  92.595  -74.493  54.507  1
244171  92.622  -74.484  54.513  1
244172  92.648  -74.475  54.518  1
244173  92.678  -74.467  54.522  1
244174  92.708  -74.458  54.525  1
244175  92.738  -74.450  54.528  1
244176  92.769  -74.442  54.530  1
244177  92.798  -74.452  54.531  1
244178  92.828  -74.471  54.532  1
244179  92.859  -74.474  54.532  1
244180  92.890  -74.475  54.532  1
244181  92.921  -74.477  54.531  1
244182  92.952  -74.477  54.531  1
244183  92.983  -74.479  54.532  1
244184  93.014  -74.480  54.535  1
244185  93.046  -74.480  54.539  1
244186  93.076  -74.482  54.544  1
244187  93.108  -74.484  54.550  1
244188  93.141  -74.490  54.561  1
244189  93.174  -74.496  54.576  1
244190  93.208  -74.502  54.590  1
244191  93.241  -74.508  54.601  1
244192  93.275  -74.513  54.608  1
244193  93.308  -74.519  54.610  1
244194  93.332  -74.511  54.613  1
244195  93.355  -74.501  54.619  1
244196  93.379  -74.491  54.629  1
244197  93.402  -74.480  54.646  1
244198  93.425  -74.471  54.666  1
244199  93.449  -74.461  54.685  1
244200  93.472  -74.451  54.702  1
244201  93.494  -74.446  54.711  1
244202  93.515  -74.443  54.718  1
244203  93.537  -74.438  54.726  1
244204  93.558  -74.434  54.742  1
244205  93.579  -74.430  54.745  1
244206  93.601  -74.425  54.743  1
244207  93.622  -74.421  54.739  1
244208  93.643  -74.417  54.735  1
244209  93.665  -74.413  54.734  1
244210  93.686  -74.408  54.738  1
244211  93.708  -74.404  54.747  1
244212  93.729  -74.400  54.761  1
244213  93.751  -74.396  54.778  1
244214  93.775  -74.396  54.795  1
244215  93.806  -74.408  54.807  1
244216  93.838  -74.421  54.805  1
244217  93.870  -74.433  54.794  1
244218  93.902  -74.446  54.784  1
244219  93.929  -74.454  54.776  1
244220  93.951  -74.456  54.772  1
244221  93.973  -74.458  54.767  1
244222  93.995  -74.461  54.757  1
244223  94.017  -74.463  54.743  1
244224  94.039  -74.465  54.728  1
244225  94.060  -74.466  54.712  1
244226  94.080  -74.466  54.698  1
244227  94.101  -74.465  54.686  1
244228  94.121  -74.465  54.674  1
244229  94.138  -74.464  54.659  1
244230  94.155  -74.461  54.642  1
244231  94.175  -74.461  54.623  1
244232  94.197  -74.461  54.602  1
244233  94.218  -74.462  54.583  1
244234  94.239  -74.462  54.565  1
244235  94.260  -74.463  54.549  1
244236  94.281  -74.463  54.527  1
244237  94.301  -74.464  54.505  1
244238  94.322  -74.464  54.480  1
244239  94.342  -74.465  54.452  1
244240  94.361  -74.466  54.424  1
244241  94.381  -74.467  54.395  1
244242  94.401  -74.468  54.365  1
244243  94.421  -74.471  54.333  1
244244  94.442  -74.478  54.302  1
244245  94.464  -74.485  54.271  1
244246  94.485  -74.491  54.241  1
244247  94.507  -74.497  54.211  1
244248  94.532  -74.496  54.176  1
244249  94.549  -74.505  54.138  1
244250  94.566  -74.515  54.099  1
244251  94.582  -74.524  54.059  1
244252  94.599  -74.534  54.023  1
244253  94.616  -74.544  53.987  1
244254  94.632  -74.553  53.951  1
244255  94.651  -74.563  53.916  1
244256  94.675  -74.568  53.878  1
244257  94.698  -74.573  53.842  1
244258  94.722  -74.578  53.809  1
244259  94.746  -74.583  53.774  1
244260  94.770  -74.588  53.743  1
244261  94.793  -74.593  53.712  1
244262  94.817  -74.598  53.681  1
244263  94.841  -74.603  53.650  1
244264  94.864  -74.608  53.617  1
244265  94.872  -74.603  53.584  1
244266  94.871  -74.592  53.550  1
244267  94.888  -74.581  53.514  1
244268  94.911  -74.570  53.475  1
244269  94.934  -74.559  53.436  1
244270  94.957  -74.548  53.394  1
244271  94.981  -74.537  53.351  1
244272  95.004  -74.527  53.305  1
244273  95.034  -74.534  53.254  1
244274  95.068  -74.549  53.198  1
244275  95.102  -74.565  53.135  1
244276  95.136  -74.581  53.068  1
244277  95.170  -74.597  53.000  1
244278  95.204  -74.614  52.932  1
244279  95.238  -74.630  52.866  1
244280  95.264  -74.650  52.803  1
244281  95.288  -74.672  52.741  1
244282  95.321  -74.689  52.679  1
244283  95.354  -74.705  52.622  1
244284  95.388  -74.720  52.564  1
244285  95.415  -74.731  52.507  1
244286  95.442  -74.737  52.452  1
244287  95.467  -74.737  52.396  1
244288  95.492  -74.736  52.342  1
244289  95.517  -74.734  52.290  1
244290  95.542  -74.734  52.239  1
244291  95.566  -74.733  52.190  1
244292  95.591  -74.732  52.142  1
244293  95.616  -74.731  52.096  1
244294  95.641  -74.730  52.052  1
244295  95.666  -74.729  52.009  1
244296  95.691  -74.728  51.968  1
244297  95.716  -74.727  51.928  1
244298  95.741  -74.726  51.888  1
244299  95.768  -74.715  51.848  1
244300  95.801  -74.689  51.808  1
244301  95.834  -74.662  51.769  1
244302  95.872  -74.668  51.729  1
244303  95.910  -74.679  51.691  1
244304  95.949  -74.690  51.654  1
244305  95.987  -74.700  51.617  1
244306  96.026  -74.711  51.580  1
244307  96.064  -74.722  51.545  1
244308  96.102  -74.732  51.510  1
244309  96.141  -74.743  51.477  1
244310  96.179  -74.752  51.447  1
244311  96.217  -74.756  51.417  1
244312  96.254  -74.761  51.389  1
244313  96.275  -74.769  51.363  1
244314  96.301  -74.779  51.340  1
244315  96.326  -74.789  51.318  1
244316  96.352  -74.800  51.298  1
244317  96.377  -74.809  51.281  1
244318  96.403  -74.819  51.265  1
244319  96.429  -74.829  51.251  1
244320  96.454  -74.839  51.238  1
244321  96.479  -74.849  51.226  1
244322  96.504  -74.863  51.215  1
244323  96.530  -74.876  51.206  1
244324  96.556  -74.889  51.199  1
244325  96.583  -74.902  51.192  1
244326  96.609  -74.915  51.184  1
244327  96.636  -74.928  51.175  1
244328  96.662  -74.941  51.165  1
244329  96.688  -74.954  51.152  1
244330  96.715  -74.967  51.137  1
244331  96.741  -74.980  51.118  1
244332  96.767  -74.993  51.098  1
244333  96.795  -75.019  51.077  1
244334  96.817  -75.041  51.057  1
244335  96.831  -75.040  51.036  1
244336  96.844  -75.038  51.017  1
244337  96.859  -75.035  50.998  1
244338  96.872  -75.034  50.981  1
244339  96.886  -75.032  50.965  1
244340  96.900  -75.030  50.950  1
244341  96.919  -75.026  50.937  1
244342  96.942  -75.021  50.923  1
244343  96.962  -75.026  50.908  1
244344  96.983  -75.033  50.891  1
244345  97.005  -75.041  50.873  1
244346  97.026  -75.048  50.853  1
244347  97.048  -75.055  50.832  1
244348  97.069  -75.063  50.810  1
244349  97.091  -75.069  50.788  1
244350  97.112  -75.077  50.767  1
244351  97.134  -75.085  50.747  1
244352  97.155  -75.091  50.728  1
244353  97.177  -75.099  50.711  1
244354  97.198  -75.107  50.695  1
244355  97.220  -75.113  50.677  1
244356  97.242  -75.122  50.657  1
244357  97.266  -75.131  50.634  1
244358  97.291  -75.140  50.608  1
244359  97.315  -75.149  50.579  1
244360  97.339  -75.158  50.548  1
244361  97.362  -75.167  50.515  1
244362  97.379  -75.176  50.478  1
244363  97.395  -75.184  50.438  1
244364  97.413  -75.192  50.397  1
244365  97.436  -75.199  50.355  1
244366  97.466  -75.206  50.317  1
244367  97.497  -75.212  50.281  1
244368  97.527  -75.219  50.247  1
244369  97.558  -75.225  50.211  1
244370  97.589  -75.232  50.173  1
244371  97.615  -75.238  50.136  1
244372  97.641  -75.245  50.098  1
244373  97.666  -75.251  50.060  1
244374  97.697  -75.258  50.019  1
244375  97.731  -75.264  49.976  1
244376  97.764  -75.272  49.931  1
244377  97.798  -75.279  49.885  1
244378  97.832  -75.286  49.837  1
244379  97.888  -75.298  49.789  1
244380  97.943  -75.311  49.742  1
244381  97.999  -75.323  49.694  1
244382  98.054  -75.335  49.646  1
244383  98.088  -75.346  49.597  1
244384  98.122  -75.357  49.546  1
244385  98.144  -75.367  49.498  1
244386  98.157  -75.377  49.450  1
244387  98.171  -75.386  49.403  1
244388  98.184  -75.395  49.355  1
244389  98.198  -75.404  49.311  1
244390  98.211  -75.414  49.265  1
244391  98.225  -75.423  49.217  1
244392  98.262  -75.426  49.170  1
244393  98.311  -75.424  49.121  1
244394  98.360  -75.424  49.074  1
244395  98.408  -75.426  49.028  1
244396  98.436  -75.415  48.982  1
244397  98.481  -75.400  48.935  1
244398  98.526  -75.385  48.888  1
244399  98.571  -75.369  48.840  1
244400  98.574  -75.388  48.789  1
244401  98.563  -75.420  48.740  1
244402  98.551  -75.452  48.689  1
244403  98.539  -75.483  48.638  1
244404  98.570  -75.496  48.588  1
244405  98.609  -75.502  48.541  1
244406  98.649  -75.509  48.493  1
244407  98.688  -75.516  48.445  1
244408  98.727  -75.523  48.396  1
244409  98.767  -75.530  48.348  1
244410  98.802  -75.532  48.297  1
244411  98.826  -75.521  48.246  1
244412  98.849  -75.511  48.197  1
244413  98.873  -75.501  48.149  1
244414  98.891  -75.520  48.102  1
244415  98.909  -75.544  48.056  1
244416  98.926  -75.569  48.011  1
244417  98.943  -75.594  47.970  1
244418  98.960  -75.619  47.930  1
244419  98.978  -75.644  47.892  1
244420  98.995  -75.668  47.857  1
244421  99.012  -75.693  47.824  1
244422  99.029  -75.718  47.791  1
244423  99.047  -75.743  47.757  1
244424  99.064  -75.768  47.726  1
244425  99.081  -75.793  47.694  1
244426  99.102  -75.825  47.662  1
244427  99.125  -75.858  47.631  1
244428  99.152  -75.876  47.600  1
244429  99.190  -75.862  47.570  1
244430  99.224  -75.856  47.542  1
244431  99.253  -75.862  47.514  1
244432  99.282  -75.868  47.486  1
244433  99.311  -75.874  47.458  1
244434  99.340  -75.880  47.431  1
244435  99.369  -75.886  47.403  1
244436  99.398  -75.892  47.375  1
244437  99.427  -75.897  47.349  1
244438  99.456  -75.903  47.324  1
244439  99.485  -75.909  47.300  1
244440  99.514  -75.916  47.276  1
244441  99.543  -75.923  47.253  1
244442  99.567  -75.939  47.229  1
244443  99.590  -75.956  47.207  1
244444  99.615  -75.972  47.186  1
244445  99.641  -75.990  47.164  1
244446  99.666  -76.014  47.141  1
244447  99.705  -76.014  47.117  1
244448  99.734  -76.019  47.090  1
244449  99.764  -76.025  47.062  1
244450  99.794  -76.030  47.034  1
244451  99.824  -76.035  47.007  1
244452  99.853  -76.041  46.978  1
244453  99.883  -76.046  46.948  1
244454  99.910  -76.054  46.918  1
244455  99.934  -76.067  46.887  1
244456  99.959  -76.080  46.855  1
244457  99.982  -76.094  46.825  1
244458  100.001  -76.117  46.797  1
244459  100.020  -76.140  46.767  1
244460  100.040  -76.163  46.737  1
244461  100.059  -76.185  46.707  1
244462  100.085  -76.191  46.675  1
244463  100.120  -76.181  46.644  1
244464  100.154  -76.170  46.614  1
244465  100.188  -76.160  46.584  1
244466  100.213  -76.157  46.554  1
244467  100.238  -76.154  46.524  1
244468  100.262  -76.151  46.492  1
244469  100.287  -76.147  46.461  1
244470  100.327  -76.150  46.430  1
244471  100.368  -76.152  46.399  1
244472  100.408  -76.154  46.368  1
244473  100.433  -76.182  46.336  1
244474  100.452  -76.223  46.304  1
244475  100.469  -76.263  46.271  1
244476  100.487  -76.304  46.237  1
244477  100.505  -76.345  46.204  1
244478  100.525  -76.383  46.171  1
244479  100.548  -76.404  46.137  1
244480  100.570  -76.412  46.103  1
244481  100.591  -76.420  46.069  1
244482  100.613  -76.428  46.036  1
244483  100.634  -76.436  46.003  1
244484  100.656  -76.444  45.972  1
244485  100.678  -76.452  45.941  1
244486  100.690  -76.477  45.910  1
244487  100.698  -76.511  45.880  1
244488  100.706  -76.544  45.852  1
244489  100.714  -76.577  45.824  1
244490  100.729  -76.602  45.797  1
244491  100.764  -76.606  45.772  1
244492  100.809  -76.600  45.748  1
244493  100.853  -76.595  45.725  1
244494  100.898  -76.589  45.702  1
244495  100.943  -76.583  45.680  1
244496  100.988  -76.578  45.657  1
244497  101.032  -76.572  45.635  1
244498  101.077  -76.567  45.614  1
244499  101.122  -76.561  45.593  1
244500  101.167  -76.555  45.570  1
244501  101.211  -76.550  45.547  1
244502  101.252  -76.547  45.525  1
244503  101.275  -76.557  45.503  1
244504  101.299  -76.566  45.482  1
244505  101.323  -76.575  45.460  1
244506  101.347  -76.584  45.440  1
244507  101.375  -76.595  45.418  1
244508  101.403  -76.605  45.398  1
244509  101.426  -76.616  45.378  1
244510  101.441  -76.628  45.359  1
244511  101.455  -76.640  45.339  1
244512  101.470  -76.652  45.321  1
244513  101.485  -76.665  45.303  1
244514  101.499  -76.677  45.285  1
244515  101.515  -76.688  45.267  1
244516  101.529  -76.700  45.250  1
244517  101.544  -76.712  45.233  1
244518  101.558  -76.724  45.217  1
244519  101.573  -76.737  45.200  1
244520  101.588  -76.749  45.184  1
244521  101.603  -76.761  45.168  1
244522  101.618  -76.771  45.152  1
244523  101.640  -76.771  45.136  1
244524  101.662  -76.771  45.120  1
244525  101.683  -76.771  45.104  1
244526  101.705  -76.771  45.087  1
244527  101.727  -76.771  45.071  1
244528  101.744  -76.780  45.055  1
244529  101.760  -76.791  45.037  1
244530  101.777  -76.802  45.020  1
244531  101.793  -76.813  45.003  1
244532  101.810  -76.824  44.987  1
244533  101.826  -76.836  44.969  1
244534  101.842  -76.846  44.952  1
244535  101.858  -76.858  44.935  1
244536  101.875  -76.869  44.918  1
244537  101.891  -76.881  44.900  1
244538  101.908  -76.891  44.884  1
244539  101.924  -76.903  44.867  1
244540  101.941  -76.914  44.850  1
244541  101.957  -76.925  44.833  1
244542  101.970  -76.934  44.817  1
244543  101.964  -76.927  44.800  1
244544  101.971  -76.930  44.783  1
244545  101.979  -76.933  44.766  1
244546  101.986  -76.935  44.750  1
244547  101.999  -76.943  44.734  1
244548  102.021  -76.963  44.718  1
244549  102.043  -76.983  44.701  1
244550  102.064  -77.003  44.685  1
244551  102.087  -77.022  44.669  1
244552  102.108  -77.042  44.652  1
244553  102.130  -77.062  44.636  1
244554  102.152  -77.081  44.620  1
244555  102.174  -77.101  44.604  1
244556  102.196  -77.120  44.588  1
244557  102.218  -77.140  44.571  1
244558  102.239  -77.160  44.556  1
244559  102.259  -77.169  44.541  1
244560  102.276  -77.169  44.525  1
244561  102.293  -77.169  44.510  1
244562  102.316  -77.170  44.494  1
244563  102.339  -77.172  44.478  1
244564  102.362  -77.172  44.463  1
244565  102.385  -77.173  44.447  1
244566  102.408  -77.174  44.432  1
244567  102.431  -77.175  44.416  1
244568  102.454  -77.176  44.400  1
244569  102.477  -77.177  44.384  1
244570  102.501  -77.179  44.367  1
244571  102.523  -77.179  44.351  1
244572  102.545  -77.181  44.336  1
244573  102.564  -77.182  44.319  1
244574  102.584  -77.185  44.303  1
244575  102.604  -77.186  44.287  1
244576  102.624  -77.188  44.271  1
244577  102.644  -77.190  44.254  1
244578  102.663  -77.191  44.238  1
244579  102.683  -77.194  44.223  1
244580  102.703  -77.195  44.208  1
244581  102.723  -77.197  44.192  1
244582  102.743  -77.199  44.177  1
244869  92.555  -74.483  54.500  1
244870  92.576  -74.481  54.507  1
244871  92.597  -74.467  54.513  1
244872  92.624  -74.457  54.518  1
244873  92.650  -74.448  54.523  1
244874  92.679  -74.440  54.527  1
244875  92.709  -74.431  54.530  1
244876  92.739  -74.423  54.532  1
244877  92.770  -74.415  54.534  1
244878  92.800  -74.427  54.536  1
244879  92.830  -74.446  54.537  1
244880  92.860  -74.452  54.537  1
244881  92.891  -74.454  54.537  1
244882  92.922  -74.455  54.535  1
244883  92.953  -74.456  54.534  1
244884  92.984  -74.457  54.535  1
244885  93.015  -74.458  54.536  1
244886  93.046  -74.459  54.538  1
244887  93.077  -74.461  54.541  1
244888  93.109  -74.461  54.547  1
244889  93.140  -74.462  54.556  1
244890  93.172  -74.466  54.570  1
244891  93.205  -74.472  54.583  1
244892  93.238  -74.478  54.595  1
244893  93.272  -74.483  54.606  1
244894  93.305  -74.490  54.612  1
244895  93.335  -74.490  54.620  1
244896  93.358  -74.480  54.631  1
244897  93.381  -74.470  54.646  1
244898  93.405  -74.460  54.666  1
244899  93.428  -74.450  54.688  1
244900  93.451  -74.440  54.709  1
244901  93.474  -74.434  54.730  1
244902  93.495  -74.430  54.744  1
244903  93.516  -74.426  54.752  1
244904  93.538  -74.421  54.756  1
244905  93.559  -74.418  54.764  1
244906  93.580  -74.413  54.767  1
244907  93.602  -74.408  54.765  1
244908  93.623  -74.405  54.761  1
244909  93.645  -74.400  54.763  1
244910  93.666  -74.396  54.762  1
244911  93.688  -74.392  54.764  1
244912  93.709  -74.387  54.771  1
244913  93.730  -74.383  54.782  1
244914  93.752  -74.379  54.798  1
244915  93.773  -74.375  54.814  1
244916  93.799  -74.377  54.825  1
244917  93.831  -74.390  54.823  1
244918  93.862  -74.402  54.813  1
244919  93.894  -74.415  54.802  1
244920  93.923  -74.424  54.793  1
244921  93.945  -74.427  54.785  1
244922  93.967  -74.429  54.776  1
244923  93.989  -74.431  54.763  1
244924  94.011  -74.433  54.747  1
244925  94.033  -74.436  54.731  1
244926  94.055  -74.438  54.712  1
244927  94.075  -74.438  54.694  1
244928  94.096  -74.438  54.678  1
244929  94.116  -74.438  54.664  1
244930  94.136  -74.437  54.650  1
244931  94.154  -74.436  54.633  1
244932  94.175  -74.436  54.615  1
244933  94.195  -74.436  54.594  1
244934  94.216  -74.436  54.573  1
244935  94.237  -74.436  54.554  1
244936  94.258  -74.437  54.536  1
244937  94.279  -74.437  54.516  1
244938  94.300  -74.438  54.495  1
244939  94.321  -74.438  54.472  1
244940  94.341  -74.439  54.446  1
244941  94.360  -74.440  54.419  1
244942  94.380  -74.441  54.392  1
244943  94.400  -74.442  54.364  1
244944  94.420  -74.447  54.334  1
244945  94.442  -74.454  54.304  1
244946  94.464  -74.461  54.274  1
244947  94.485  -74.466  54.244  1
244948  94.510  -74.465  54.213  1
244949  94.534  -74.463  54.179  1
244950  94.553  -74.470  54.142  1
244951  94.570  -74.479  54.104  1
244952  94.586  -74.489  54.066  1
244953  94.603  -74.499  54.027  1
244954  94.620  -74.508  53.990  1
244955  94.636  -74.518  53.953  1
244956  94.652  -74.521  53.916  1
244957  94.672  -74.534  53.877  1
244958  94.692  -74.546  53.839  1
244959  94.712  -74.558  53.803  1
244960  94.735  -74.564  53.767  1
244961  94.759  -74.568  53.735  1
244962  94.782  -74.574  53.703  1
244963  94.806  -74.578  53.672  1
244964  94.830  -74.584  53.642  1
244965  94.852  -74.587  53.610  1
244966  94.851  -74.577  53.577  1
244967  94.871  -74.566  53.543  1
244968  94.894  -74.555  53.509  1
244969  94.918  -74.544  53.473  1
244970  94.941  -74.534  53.436  1
244971  94.964  -74.523  53.398  1
244972  94.987  -74.512  53.356  1
244973  95.011  -74.501  53.309  1
244974  95.044  -74.516  53.257  1
244975  95.078  -74.532  53.202  1
244976  95.112  -74.548  53.140  1
244977  95.146  -74.564  53.073  1
244978  95.180  -74.581  53.004  1
244979  95.214  -74.596  52.935  1
244980  95.248  -74.612  52.868  1
244981  95.280  -74.630  52.804  1
244982  95.305  -74.652  52.742  1
244983  95.329  -74.674  52.681  1
244984  95.362  -74.689  52.623  1
244985  95.396  -74.705  52.565  1
244986  95.424  -74.715  52.509  1
244987  95.450  -74.718  52.454  1
244988  95.474  -74.717  52.400  1
244989  95.499  -74.715  52.347  1
244990  95.524  -74.715  52.295  1
244991  95.549  -74.714  52.244  1
244992  95.573  -74.713  52.195  1
244993  95.599  -74.712  52.148  1
244994  95.623  -74.711  52.102  1
244995  95.648  -74.710  52.058  1
244996  95.673  -74.709  52.015  1
244997  95.698  -74.709  51.974  1
244998  95.723  -74.707  51.934  1
244999  95.748  -74.706  51.894  1
245000  95.772  -74.706  51.853  1
245001  95.804  -74.684  51.813  1
245002  95.839  -74.678  51.773  1
245003  95.878  -74.689  51.733  1
245004  95.916  -74.700  51.695  1
245005  95.955  -74.710  51.658  1
245006  95.993  -74.719  51.621  1
245007  96.030  -74.724  51.583  1
245008  96.068  -74.728  51.547  1
245009  96.105  -74.733  51.512  1
245010  96.143  -74.737  51.478  1
245011  96.180  -74.742  51.446  1
245012  96.217  -74.747  51.416  1
245013  96.254  -74.752  51.388  1
245014  96.267  -74.761  51.362  1
245015  96.284  -74.772  51.336  1
245016  96.309  -74.781  51.314  1
245017  96.334  -74.792  51.293  1
245018  96.360  -74.802  51.275  1
245019  96.386  -74.812  51.258  1
245020  96.411  -74.822  51.244  1
245021  96.437  -74.831  51.231  1
245022  96.481  -74.826  51.218  1
245023  96.508  -74.833  51.207  1
245024  96.534  -74.840  51.199  1
245025  96.560  -74.847  51.192  1
245026  96.589  -74.858  51.186  1
245027  96.617  -74.869  51.180  1
245028  96.645  -74.879  51.173  1
245029  96.674  -74.890  51.164  1
245030  96.702  -74.900  51.153  1
245031  96.730  -74.910  51.139  1
245032  96.759  -74.921  51.122  1
245033  96.786  -74.934  51.102  1
245034  96.812  -74.952  51.082  1
245035  96.842  -74.997  51.063  1
245036  96.859  -75.002  51.042  1
245037  96.872  -75.001  51.023  1
245038  96.886  -74.998  51.006  1
245039  96.900  -74.997  50.989  1
245040  96.914  -74.994  50.972  1
245041  96.928  -74.992  50.958  1
245042  96.941  -74.991  50.946  1
245043  96.947  -74.994  50.932  1
245044  96.957  -75.003  50.917  1
245045  96.980  -75.005  50.900  1
245046  97.002  -75.012  50.882  1
245047  97.023  -75.019  50.863  1
245048  97.045  -75.026  50.843  1
245049  97.066  -75.034  50.822  1
245050  97.088  -75.041  50.802  1
245051  97.109  -75.048  50.782  1
245052  97.131  -75.056  50.764  1
245053  97.152  -75.063  50.748  1
245054  97.174  -75.070  50.733  1
245055  97.195  -75.078  50.717  1
245056  97.217  -75.085  50.699  1
245057  97.239  -75.093  50.678  1
245058  97.263  -75.102  50.655  1
245059  97.288  -75.111  50.629  1
245060  97.312  -75.120  50.601  1
245061  97.336  -75.129  50.571  1
245062  97.360  -75.138  50.538  1
245063  97.380  -75.147  50.500  1
245064  97.397  -75.155  50.460  1
245065  97.414  -75.163  50.419  1
245066  97.439  -75.170  50.378  1
245067  97.469  -75.177  50.339  1
245068  97.500  -75.183  50.303  1
245069  97.531  -75.190  50.269  1
245070  97.561  -75.197  50.233  1
245071  97.592  -75.203  50.195  1
245072  97.620  -75.210  50.157  1
245073  97.647  -75.216  50.119  1
245074  97.681  -75.223  50.079  1
245075  97.715  -75.230  50.037  1
245076  97.748  -75.237  49.993  1
245077  97.782  -75.245  49.948  1
245078  97.815  -75.251  49.901  1
245079  97.849  -75.258  49.853  1
245080  97.896  -75.269  49.806  1
245081  97.952  -75.281  49.760  1
245082  98.007  -75.293  49.712  1
245083  98.048  -75.305  49.663  1
245084  98.081  -75.316  49.612  1
245085  98.115  -75.326  49.561  1
245086  98.148  -75.337  49.512  1
245087  98.172  -75.348  49.465  1
245088  98.185  -75.357  49.417  1
245089  98.199  -75.366  49.369  1
245090  98.212  -75.376  49.325  1
245091  98.226  -75.385  49.277  1
245092  98.239  -75.394  49.229  1
245093  98.275  -75.397  49.180  1
245094  98.323  -75.396  49.132  1
245095  98.372  -75.395  49.085  1
245096  98.418  -75.408  49.038  1
245097  98.439  -75.392  48.991  1
245098  98.474  -75.375  48.944  1
245099  98.519  -75.359  48.897  1
245100  98.564  -75.344  48.849  1
245101  98.574  -75.358  48.798  1
245102  98.562  -75.389  48.748  1
245103  98.551  -75.420  48.696  1
245104  98.547  -75.446  48.644  1
245105  98.574  -75.448  48.593  1
245106  98.605  -75.451  48.545  1
245107  98.645  -75.458  48.498  1
245108  98.684  -75.464  48.449  1
245109  98.723  -75.471  48.401  1
245110  98.763  -75.478  48.352  1
245111  98.802  -75.486  48.300  1
245112  98.829  -75.478  48.249  1
245113  98.852  -75.467  48.199  1
245114  98.876  -75.457  48.150  1
245115  98.894  -75.480  48.102  1
245116  98.911  -75.505  48.057  1
245117  98.928  -75.530  48.013  1
245118  98.945  -75.555  47.971  1
245119  98.962  -75.580  47.931  1
245120  98.980  -75.605  47.891  1
245121  98.997  -75.630  47.853  1
245122  99.014  -75.655  47.820  1
245123  99.031  -75.680  47.786  1
245124  99.049  -75.705  47.752  1
245125  99.071  -75.738  47.720  1
245126  99.093  -75.771  47.686  1
245127  99.116  -75.806  47.653  1
245128  99.142  -75.831  47.622  1
245129  99.179  -75.818  47.591  1
245130  99.216  -75.804  47.559  1
245131  99.253  -75.791  47.530  1
245132  99.282  -75.797  47.502  1
245133  99.311  -75.803  47.473  1
245134  99.340  -75.809  47.446  1
245135  99.369  -75.815  47.418  1
245136  99.398  -75.821  47.391  1
245137  99.427  -75.827  47.363  1
245138  99.456  -75.833  47.337  1
245139  99.483  -75.843  47.312  1
245140  99.507  -75.859  47.288  1
245141  99.532  -75.876  47.265  1
245142  99.556  -75.892  47.242  1
245143  99.579  -75.909  47.220  1
245144  99.604  -75.925  47.199  1
245145  99.629  -75.943  47.178  1
245146  99.655  -75.959  47.156  1
245147  99.678  -75.988  47.134  1
245148  99.708  -76.004  47.110  1
245149  99.749  -76.003  47.084  1
245150  99.782  -76.007  47.057  1
245151  99.811  -76.013  47.029  1
245152  99.841  -76.018  47.002  1
245153  99.871  -76.022  46.974  1
245154  99.901  -76.028  46.944  1
245155  99.926  -76.039  46.914  1
245156  99.950  -76.052  46.883  1
245157  99.974  -76.065  46.850  1
245158  99.998  -76.077  46.820  1
245159  100.021  -76.093  46.791  1
245160  100.041  -76.116  46.761  1
245161  100.060  -76.138  46.731  1
245162  100.079  -76.161  46.700  1
245163  100.101  -76.176  46.669  1
245164  100.136  -76.166  46.636  1
245165  100.170  -76.155  46.606  1
245166  100.204  -76.144  46.576  1
245167  100.239  -76.134  46.546  1
245168  100.264  -76.130  46.515  1
245169  100.289  -76.127  46.484  1
245170  100.314  -76.123  46.452  1
245171  100.349  -76.124  46.420  1
245172  100.390  -76.127  46.389  1
245173  100.430  -76.129  46.358  1
245174  100.447  -76.170  46.327  1
245175  100.466  -76.210  46.294  1
245176  100.483  -76.251  46.261  1
245177  100.501  -76.292  46.227  1
245178  100.523  -76.327  46.194  1
245179  100.546  -76.360  46.162  1
245180  100.569  -76.393  46.128  1
245181  100.592  -76.402  46.094  1
245182  100.614  -76.409  46.061  1
245183  100.636  -76.417  46.029  1
245184  100.657  -76.425  45.996  1
245185  100.679  -76.433  45.966  1
245186  100.700  -76.442  45.935  1
245187  100.708  -76.475  45.905  1
245188  100.716  -76.508  45.875  1
245189  100.725  -76.542  45.846  1
245190  100.733  -76.576  45.818  1
245191  100.747  -76.602  45.792  1
245192  100.789  -76.598  45.768  1
245193  100.834  -76.592  45.743  1
245194  100.879  -76.586  45.719  1
245195  100.924  -76.580  45.697  1
245196  100.968  -76.575  45.674  1
245197  101.013  -76.570  45.652  1
245198  101.058  -76.564  45.629  1
245199  101.103  -76.558  45.607  1
245200  101.147  -76.552  45.585  1
245201  101.192  -76.547  45.563  1
245202  101.237  -76.541  45.541  1
245203  101.281  -76.536  45.519  1
245204  101.306  -76.545  45.497  1
245205  101.330  -76.554  45.475  1
245206  101.354  -76.563  45.454  1
245207  101.378  -76.572  45.433  1
245208  101.406  -76.583  45.412  1
245209  101.434  -76.593  45.391  1
245210  101.454  -76.605  45.371  1
245211  101.469  -76.617  45.352  1
245212  101.484  -76.628  45.333  1
245213  101.498  -76.640  45.314  1
245214  101.513  -76.652  45.296  1
245215  101.528  -76.665  45.278  1
245216  101.543  -76.677  45.260  1
245217  101.557  -76.689  45.242  1
245218  101.572  -76.701  45.225  1
245219  101.587  -76.712  45.209  1
245220  101.602  -76.724  45.192  1
245221  101.616  -76.737  45.175  1
245222  101.632  -76.746  45.158  1
245223  101.654  -76.746  45.142  1
245224  101.676  -76.746  45.126  1
245225  101.697  -76.746  45.109  1
245226  101.719  -76.746  45.093  1
245227  101.740  -76.749  45.076  1
245228  101.756  -76.760  45.060  1
245229  101.772  -76.771  45.043  1
245230  101.788  -76.782  45.027  1
245231  101.805  -76.793  45.009  1
245232  101.821  -76.805  44.992  1
245233  101.838  -76.815  44.975  1
245234  101.854  -76.827  44.958  1
245235  101.871  -76.838  44.941  1
245236  101.887  -76.850  44.923  1
245237  101.903  -76.860  44.906  1
245238  101.919  -76.871  44.888  1
245239  101.936  -76.883  44.872  1
245240  101.952  -76.893  44.855  1
245241  101.957  -76.896  44.838  1
245242  101.952  -76.890  44.821  1
245243  101.960  -76.893  44.805  1
245244  101.967  -76.896  44.788  1
245245  101.975  -76.899  44.771  1
245246  101.983  -76.901  44.755  1
245247  101.999  -76.915  44.739  1
245248  102.021  -76.934  44.723  1
245249  102.043  -76.953  44.706  1
245250  102.064  -76.973  44.689  1
245251  102.087  -76.993  44.673  1
245252  102.108  -77.012  44.657  1
245253  102.130  -77.032  44.641  1
245254  102.152  -77.052  44.624  1
245255  102.174  -77.072  44.608  1
245256  102.196  -77.091  44.592  1
245257  102.218  -77.110  44.576  1
245258  102.239  -77.128  44.559  1
245259  102.256  -77.128  44.544  1
245260  102.274  -77.128  44.528  1
245261  102.291  -77.129  44.513  1
245262  102.314  -77.130  44.498  1
245263  102.337  -77.132  44.482  1
245264  102.360  -77.132  44.466  1
245265  102.383  -77.133  44.450  1
245266  102.406  -77.134  44.435  1
245267  102.429  -77.135  44.419  1
245268  102.452  -77.136  44.404  1
245269  102.475  -77.137  44.389  1
245270  102.498  -77.138  44.373  1
245271  102.521  -77.139  44.356  1
245272  102.544  -77.140  44.340  1
245273  102.567  -77.141  44.324  1
245274  102.589  -77.142  44.308  1
245275  102.609  -77.144  44.292  1
245276  102.628  -77.146  44.277  1
245277  102.649  -77.147  44.260  1
245278  102.668  -77.150  44.244  1
245279  102.688  -77.151  44.228  1
245280  102.708  -77.153  44.213  1
245281  102.728  -77.155  44.198  1
245571  92.580  -74.458  54.514  1
245572  92.598  -74.440  54.519  1
245573  92.625  -74.430  54.525  1
245574  92.652  -74.421  54.529  1
245575  92.681  -74.412  54.532  1
245576  92.711  -74.404  54.535  1
245577  92.741  -74.396  54.537  1
245578  92.771  -74.388  54.540  1
245579  92.801  -74.400  54.541  1
245580  92.831  -74.419  54.542  1
245581  92.861  -74.431  54.542  1
245582  92.892  -74.433  54.541  1
245583  92.923  -74.433  54.540  1
245584  92.954  -74.435  54.539  1
245585  92.985  -74.436  54.538  1
245586  93.016  -74.436  54.538  1
245587  93.047  -74.438  54.539  1
245588  93.078  -74.439  54.542  1
245589  93.110  -74.440  54.546  1
245590  93.140  -74.441  54.552  1
245591  93.171  -74.443  54.562  1
245592  93.203  -74.443  54.573  1
245593  93.235  -74.448  54.585  1
245594  93.269  -74.454  54.599  1
245595  93.302  -74.460  54.609  1
245596  93.335  -74.466  54.622  1
245597  93.361  -74.459  54.637  1
245598  93.384  -74.449  54.656  1
245599  93.408  -74.440  54.678  1
245600  93.431  -74.430  54.701  1
245601  93.453  -74.421  54.725  1
245602  93.475  -74.418  54.748  1
245603  93.496  -74.413  54.764  1
245604  93.518  -74.409  54.775  1
245605  93.539  -74.405  54.782  1
245606  93.561  -74.401  54.786  1
245607  93.582  -74.396  54.786  1
245608  93.604  -74.392  54.785  1
245609  93.625  -74.388  54.786  1
245610  93.646  -74.383  54.793  1
245611  93.667  -74.380  54.795  1
245612  93.689  -74.375  54.796  1
245613  93.710  -74.371  54.796  1
245614  93.732  -74.367  54.799  1
245615  93.753  -74.362  54.812  1
245616  93.775  -74.358  54.826  1
245617  93.796  -74.354  54.838  1
245618  93.823  -74.359  54.836  1
245619  93.855  -74.371  54.825  1
245620  93.887  -74.384  54.811  1
245621  93.917  -74.395  54.799  1
245622  93.939  -74.397  54.788  1
245623  93.961  -74.399  54.778  1
245624  93.983  -74.402  54.765  1
245625  94.005  -74.404  54.749  1
245626  94.027  -74.406  54.732  1
245627  94.049  -74.408  54.714  1
245628  94.071  -74.411  54.693  1
245629  94.091  -74.410  54.671  1
245630  94.111  -74.410  54.654  1
245631  94.131  -74.410  54.639  1
245632  94.151  -74.410  54.623  1
245633  94.173  -74.410  54.605  1
245634  94.194  -74.411  54.584  1
245635  94.215  -74.411  54.564  1
245636  94.236  -74.411  54.543  1
245637  94.257  -74.411  54.524  1
245638  94.277  -74.412  54.505  1
245639  94.298  -74.412  54.485  1
245640  94.319  -74.413  54.463  1
245641  94.340  -74.413  54.439  1
245642  94.359  -74.414  54.415  1
245643  94.379  -74.415  54.390  1
245644  94.399  -74.417  54.364  1
245645  94.420  -74.423  54.336  1
245646  94.441  -74.430  54.307  1
245647  94.464  -74.435  54.278  1
245648  94.488  -74.433  54.248  1
245649  94.512  -74.432  54.215  1
245650  94.537  -74.430  54.182  1
245651  94.557  -74.434  54.146  1
245652  94.574  -74.444  54.109  1
245653  94.591  -74.454  54.073  1
245654  94.607  -74.464  54.033  1
245655  94.624  -74.474  53.993  1
245656  94.640  -74.482  53.954  1
245657  94.655  -74.482  53.915  1
245658  94.674  -74.491  53.874  1
245659  94.694  -74.503  53.834  1
245660  94.714  -74.515  53.795  1
245661  94.734  -74.527  53.758  1
245662  94.753  -74.540  53.723  1
245663  94.773  -74.552  53.691  1
245664  94.795  -74.559  53.660  1
245665  94.819  -74.565  53.629  1
245666  94.832  -74.562  53.598  1
245667  94.855  -74.552  53.566  1
245668  94.878  -74.540  53.534  1
245669  94.901  -74.530  53.500  1
245670  94.924  -74.519  53.465  1
245671  94.948  -74.508  53.429  1
245672  94.971  -74.497  53.393  1
245673  94.994  -74.487  53.352  1
245674  95.021  -74.483  53.305  1
245675  95.054  -74.499  53.255  1
245676  95.089  -74.515  53.201  1
245677  95.122  -74.530  53.140  1
245678  95.157  -74.546  53.074  1
245679  95.190  -74.563  53.006  1
245680  95.225  -74.579  52.937  1
245681  95.259  -74.595  52.869  1
245682  95.293  -74.611  52.805  1
245683  95.321  -74.631  52.743  1
245684  95.345  -74.653  52.682  1
245685  95.370  -74.674  52.625  1
245686  95.404  -74.690  52.568  1
245687  95.431  -74.699  52.512  1
245688  95.457  -74.698  52.458  1
245689  95.481  -74.697  52.403  1
245690  95.507  -74.696  52.350  1
245691  95.531  -74.695  52.299  1
245692  95.556  -74.694  52.249  1
245693  95.581  -74.693  52.201  1
245694  95.606  -74.692  52.155  1
245695  95.630  -74.691  52.110  1
245696  95.656  -74.690  52.065  1
245697  95.680  -74.690  52.021  1
245698  95.705  -74.688  51.980  1
245699  95.730  -74.687  51.939  1
245700  95.755  -74.687  51.899  1
245701  95.779  -74.686  51.858  1
245702  95.807  -74.686  51.819  1
245703  95.844  -74.690  51.780  1
245704  95.882  -74.696  51.739  1
245705  95.919  -74.700  51.701  1
245706  95.957  -74.705  51.663  1
245707  95.994  -74.709  51.625  1
245708  96.031  -74.714  51.587  1
245709  96.068  -74.718  51.550  1
245710  96.106  -74.723  51.515  1
245711  96.143  -74.728  51.480  1
245712  96.180  -74.733  51.447  1
245713  96.218  -74.737  51.416  1
245714  96.255  -74.742  51.386  1
245715  96.266  -74.752  51.358  1
245716  96.266  -74.764  51.333  1
245717  96.292  -74.774  51.309  1
245718  96.317  -74.784  51.288  1
245719  96.343  -74.794  51.269  1
245720  96.368  -74.804  51.252  1
245721  96.394  -74.814  51.237  1
245722  96.419  -74.824  51.223  1
245723  96.485  -74.800  51.211  1
245724  96.511  -74.807  51.200  1
245725  96.537  -74.815  51.192  1
245726  96.564  -74.822  51.185  1
245727  96.589  -74.828  51.179  1
245728  96.615  -74.835  51.174  1
245729  96.643  -74.845  51.168  1
245730  96.672  -74.856  51.161  1
245731  96.700  -74.866  51.151  1
245732  96.728  -74.877  51.140  1
245733  96.757  -74.888  51.124  1
245734  96.785  -74.897  51.107  1
245735  96.813  -74.908  51.087  1
245736  96.859  -74.932  51.069  1
245737  96.886  -74.965  51.049  1
245738  96.900  -74.963  51.030  1
245739  96.914  -74.961  51.014  1
245740  96.927  -74.960  50.996  1
245741  96.934  -74.963  50.980  1
245742  96.940  -74.965  50.966  1
245743  96.946  -74.968  50.954  1
245744  96.953  -74.971  50.940  1
245745  96.965  -74.980  50.924  1
245746  96.975  -74.991  50.906  1
245747  96.993  -74.997  50.888  1
245748  97.016  -74.999  50.870  1
245749  97.039  -75.002  50.851  1
245750  97.063  -75.005  50.833  1
245751  97.085  -75.012  50.815  1
245752  97.106  -75.019  50.799  1
245753  97.127  -75.027  50.784  1
245754  97.149  -75.034  50.770  1
245755  97.171  -75.041  50.755  1
245756  97.192  -75.048  50.738  1
245757  97.214  -75.056  50.719  1
245758  97.236  -75.063  50.697  1
245759  97.260  -75.073  50.672  1
245760  97.284  -75.082  50.646  1
245761  97.308  -75.091  50.619  1
245762  97.333  -75.101  50.591  1
245763  97.357  -75.110  50.558  1
245764  97.381  -75.119  50.520  1
245765  97.399  -75.127  50.479  1
245766  97.416  -75.135  50.439  1
245767  97.442  -75.142  50.401  1
245768  97.473  -75.148  50.363  1
245769  97.503  -75.155  50.326  1
245770  97.534  -75.161  50.291  1
245771  97.565  -75.168  50.256  1
245772  97.595  -75.175  50.219  1
245773  97.629  -75.182  50.180  1
245774  97.664  -75.189  50.139  1
245775  97.699  -75.196  50.098  1
245776  97.732  -75.203  50.055  1
245777  97.766  -75.210  50.011  1
245778  97.799  -75.217  49.966  1
245779  97.833  -75.224  49.917  1
245780  97.866  -75.231  49.871  1
245781  97.905  -75.239  49.825  1
245782  97.960  -75.251  49.780  1
245783  98.007  -75.264  49.733  1
245784  98.041  -75.274  49.682  1
245785  98.075  -75.285  49.630  1
245786  98.108  -75.296  49.577  1
245787  98.142  -75.307  49.528  1
245788  98.175  -75.318  49.479  1
245789  98.200  -75.328  49.431  1
245790  98.213  -75.337  49.384  1
245791  98.227  -75.347  49.337  1
245792  98.240  -75.356  49.289  1
245793  98.253  -75.365  49.241  1
245794  98.287  -75.369  49.192  1
245795  98.337  -75.368  49.142  1
245796  98.385  -75.369  49.094  1
245797  98.426  -75.387  49.048  1
245798  98.445  -75.368  49.001  1
245799  98.466  -75.349  48.953  1
245800  98.511  -75.334  48.906  1
245801  98.556  -75.319  48.857  1
245802  98.574  -75.326  48.806  1
245803  98.562  -75.358  48.754  1
245804  98.550  -75.389  48.703  1
245805  98.561  -75.404  48.651  1
245806  98.588  -75.405  48.600  1
245807  98.616  -75.406  48.550  1
245808  98.644  -75.408  48.501  1
245809  98.680  -75.413  48.453  1
245810  98.719  -75.420  48.403  1
245811  98.758  -75.427  48.353  1
245812  98.797  -75.433  48.302  1
245813  98.832  -75.435  48.250  1
245814  98.855  -75.424  48.201  1
245815  98.878  -75.417  48.153  1
245816  98.896  -75.442  48.106  1
245817  98.913  -75.467  48.061  1
245818  98.930  -75.492  48.016  1
245819  98.947  -75.517  47.974  1
245820  98.964  -75.541  47.932  1
245821  98.982  -75.566  47.891  1
245822  98.999  -75.591  47.852  1
245823  99.017  -75.618  47.815  1
245824  99.040  -75.651  47.780  1
245825  99.062  -75.685  47.746  1
245826  99.085  -75.719  47.712  1
245827  99.108  -75.753  47.678  1
245828  99.131  -75.786  47.644  1
245829  99.168  -75.772  47.612  1
245830  99.205  -75.759  47.580  1
245831  99.242  -75.746  47.549  1
245832  99.279  -75.733  47.519  1
245833  99.310  -75.733  47.490  1
245834  99.340  -75.739  47.461  1
245835  99.369  -75.745  47.434  1
245836  99.398  -75.750  47.406  1
245837  99.424  -75.762  47.379  1
245838  99.448  -75.779  47.351  1
245839  99.472  -75.796  47.326  1
245840  99.496  -75.812  47.301  1
245841  99.520  -75.828  47.277  1
245842  99.544  -75.845  47.254  1
245843  99.568  -75.862  47.232  1
245844  99.592  -75.878  47.211  1
245845  99.618  -75.895  47.190  1
245846  99.644  -75.912  47.169  1
245847  99.670  -75.930  47.149  1
245848  99.693  -75.957  47.127  1
245849  99.715  -75.987  47.102  1
245850  99.751  -75.994  47.078  1
245851  99.791  -75.994  47.051  1
245852  99.829  -75.994  47.024  1
245853  99.859  -76.000  46.997  1
245854  99.889  -76.005  46.969  1
245855  99.917  -76.011  46.940  1
245856  99.941  -76.024  46.909  1
245857  99.966  -76.037  46.878  1
245858  99.990  -76.050  46.846  1
245859  100.014  -76.062  46.816  1
245860  100.038  -76.075  46.786  1
245861  100.061  -76.091  46.755  1
245862  100.080  -76.114  46.725  1
245863  100.099  -76.137  46.694  1
245864  100.118  -76.160  46.662  1
245865  100.151  -76.151  46.629  1
245866  100.186  -76.140  46.599  1
245867  100.220  -76.129  46.569  1
245868  100.255  -76.119  46.538  1
245869  100.289  -76.108  46.506  1
245870  100.316  -76.104  46.475  1
245871  100.340  -76.100  46.443  1
245872  100.371  -76.099  46.411  1
245873  100.411  -76.101  46.380  1
245874  100.444  -76.117  46.349  1
245875  100.462  -76.158  46.317  1
245876  100.480  -76.199  46.285  1
245877  100.498  -76.238  46.252  1
245878  100.522  -76.271  46.218  1
245879  100.544  -76.304  46.185  1
245880  100.567  -76.338  46.152  1
245881  100.591  -76.371  46.120  1
245882  100.613  -76.394  46.087  1
245883  100.636  -76.400  46.054  1
245884  100.658  -76.407  46.021  1
245885  100.681  -76.414  45.989  1
245886  100.702  -76.422  45.959  1
245887  100.718  -76.439  45.929  1
245888  100.727  -76.473  45.899  1
245889  100.735  -76.507  45.870  1
245890  100.743  -76.540  45.841  1
245891  100.751  -76.574  45.814  1
245892  100.770  -76.595  45.788  1
245893  100.815  -76.589  45.763  1
245894  100.860  -76.583  45.739  1
245895  100.905  -76.578  45.715  1
245896  100.949  -76.572  45.692  1
245897  100.994  -76.567  45.669  1
245898  101.039  -76.561  45.646  1
245899  101.084  -76.555  45.624  1
245900  101.128  -76.550  45.601  1
245901  101.173  -76.544  45.579  1
245902  101.218  -76.539  45.557  1
245903  101.262  -76.533  45.535  1
245904  101.307  -76.527  45.513  1
245905  101.337  -76.533  45.491  1
245906  101.361  -76.542  45.468  1
245907  101.385  -76.551  45.447  1
245908  101.409  -76.560  45.427  1
245909  101.437  -76.571  45.405  1
245910  101.465  -76.581  45.385  1
245911  101.482  -76.592  45.365  1
245912  101.497  -76.605  45.345  1
245913  101.512  -76.617  45.326  1
245914  101.527  -76.629  45.307  1
245915  101.541  -76.641  45.288  1
245916  101.556  -76.652  45.270  1
245917  101.571  -76.665  45.252  1
245918  101.586  -76.677  45.234  1
245919  101.600  -76.689  45.217  1
245920  101.615  -76.701  45.200  1
245921  101.630  -76.713  45.183  1
245922  101.646  -76.721  45.166  1
245923  101.668  -76.721  45.149  1
245924  101.690  -76.721  45.132  1
245925  101.711  -76.721  45.115  1
245926  101.733  -76.722  45.099  1
245927  101.752  -76.729  45.082  1
245928  101.768  -76.740  45.065  1
245929  101.784  -76.751  45.048  1
245930  101.801  -76.762  45.032  1
245931  101.817  -76.774  45.015  1
245932  101.833  -76.784  44.997  1
245933  101.849  -76.796  44.980  1
245934  101.866  -76.807  44.963  1
245935  101.882  -76.818  44.946  1
245936  101.899  -76.829  44.929  1
245937  101.915  -76.840  44.911  1
245938  101.932  -76.852  44.894  1
245939  101.948  -76.862  44.877  1
245940  101.943  -76.858  44.861  1
245941  101.941  -76.853  44.844  1
245942  101.948  -76.856  44.827  1
245943  101.956  -76.859  44.810  1
245944  101.963  -76.862  44.793  1
245945  101.971  -76.865  44.776  1
245946  101.979  -76.867  44.759  1
245947  101.999  -76.885  44.743  1
245948  102.021  -76.905  44.727  1
245949  102.043  -76.925  44.711  1
245950  102.064  -76.944  44.695  1
245951  102.087  -76.963  44.678  1
245952  102.108  -76.983  44.661  1
245953  102.130  -77.003  44.645  1
245954  102.152  -77.022  44.629  1
245955  102.174  -77.042  44.613  1
245956  102.196  -77.062  44.597  1
245957  102.218  -77.081  44.580  1
245958  102.236  -77.088  44.564  1
245959  102.254  -77.088  44.546  1
245960  102.271  -77.088  44.531  1
245961  102.289  -77.089  44.516  1
245962  102.311  -77.090  44.500  1
245963  102.334  -77.091  44.484  1
245964  102.357  -77.092  44.469  1
245965  102.380  -77.093  44.453  1
245966  102.403  -77.094  44.438  1
245967  102.427  -77.095  44.423  1
245968  102.449  -77.096  44.408  1
245969  102.472  -77.097  44.392  1
245970  102.495  -77.098  44.376  1
245971  102.518  -77.099  44.361  1
245972  102.541  -77.100  44.344  1
245973  102.564  -77.100  44.328  1
245974  102.587  -77.102  44.312  1
245975  102.610  -77.103  44.297  1
245976  102.633  -77.103  44.281  1
245977  102.653  -77.106  44.266  1
245978  102.673  -77.107  44.249  1
245979  102.692  -77.109  44.233  1
245980  102.713  -77.111  44.218  1
246273  92.600  -74.412  54.526  1
246274  92.627  -74.403  54.531  1
246275  92.653  -74.394  54.535  1
246276  92.682  -74.385  54.538  1
246277  92.712  -74.377  54.541  1
246278  92.742  -74.369  54.544  1
246279  92.772  -74.361  54.547  1
246280  92.802  -74.374  54.547  1
246281  92.832  -74.393  54.548  1
246282  92.862  -74.410  54.548  1
246283  92.893  -74.411  54.547  1
246284  92.924  -74.412  54.546  1
246285  92.955  -74.413  54.545  1
246286  92.986  -74.415  54.544  1
246287  93.017  -74.415  54.542  1
246288  93.048  -74.417  54.543  1
246289  93.079  -74.418  54.544  1
246290  93.110  -74.418  54.547  1
246291  93.141  -74.420  54.550  1
246292  93.172  -74.421  54.556  1
246293  93.204  -74.422  54.564  1
246294  93.234  -74.423  54.574  1
246295  93.266  -74.424  54.588  1
246296  93.299  -74.430  54.602  1
246297  93.332  -74.436  54.620  1
246298  93.363  -74.439  54.639  1
246299  93.387  -74.429  54.659  1
246300  93.410  -74.419  54.682  1
246301  93.433  -74.409  54.708  1
246302  93.455  -74.405  54.734  1
246303  93.476  -74.401  54.758  1
246304  93.498  -74.396  54.776  1
246305  93.519  -74.393  54.790  1
246306  93.541  -74.388  54.801  1
246307  93.562  -74.383  54.805  1
246308  93.583  -74.380  54.804  1
246309  93.605  -74.375  54.805  1
246310  93.626  -74.371  54.811  1
246311  93.647  -74.367  54.822  1
246312  93.669  -74.363  54.828  1
246313  93.690  -74.358  54.829  1
246314  93.712  -74.354  54.825  1
246315  93.733  -74.350  54.823  1
246316  93.755  -74.346  54.830  1
246317  93.776  -74.342  54.838  1
246318  93.797  -74.337  54.847  1
246319  93.819  -74.333  54.845  1
246320  93.848  -74.341  54.834  1
246321  93.880  -74.353  54.820  1
246322  93.911  -74.365  54.804  1
246323  93.933  -74.368  54.790  1
246324  93.955  -74.370  54.777  1
246325  93.977  -74.372  54.763  1
246326  93.999  -74.374  54.747  1
246327  94.021  -74.377  54.731  1
246328  94.043  -74.379  54.712  1
246329  94.065  -74.381  54.690  1
246330  94.086  -74.383  54.667  1
246331  94.107  -74.382  54.649  1
246332  94.127  -74.382  54.630  1
246333  94.149  -74.383  54.612  1
246334  94.174  -74.385  54.595  1
246335  94.194  -74.386  54.574  1
246336  94.213  -74.386  54.554  1
246337  94.234  -74.386  54.535  1
246338  94.255  -74.386  54.516  1
246339  94.276  -74.386  54.496  1
246340  94.296  -74.386  54.476  1
246341  94.318  -74.387  54.455  1
246342  94.338  -74.387  54.434  1
246343  94.358  -74.388  54.412  1
246344  94.378  -74.389  54.390  1
246345  94.398  -74.393  54.366  1
246346  94.420  -74.399  54.340  1
246347  94.442  -74.404  54.311  1
246348  94.466  -74.402  54.282  1
246349  94.490  -74.401  54.252  1
246350  94.515  -74.399  54.220  1
246351  94.539  -74.398  54.187  1
246352  94.561  -74.399  54.152  1
246353  94.578  -74.409  54.117  1
246354  94.595  -74.419  54.079  1
246355  94.611  -74.429  54.039  1
246356  94.628  -74.439  53.998  1
246357  94.644  -74.445  53.956  1
246358  94.660  -74.445  53.914  1
246359  94.676  -74.449  53.871  1
246360  94.696  -74.461  53.829  1
246361  94.715  -74.473  53.787  1
246362  94.736  -74.485  53.746  1
246363  94.755  -74.498  53.710  1
246364  94.775  -74.510  53.677  1
246365  94.794  -74.522  53.645  1
246366  94.814  -74.534  53.614  1
246367  94.838  -74.537  53.583  1
246368  94.861  -74.526  53.553  1
246369  94.885  -74.515  53.523  1
246370  94.908  -74.504  53.489  1
246371  94.931  -74.493  53.454  1
246372  94.955  -74.483  53.419  1
246373  94.978  -74.472  53.383  1
246374  95.001  -74.461  53.343  1
246375  95.031  -74.465  53.298  1
246376  95.064  -74.481  53.249  1
246377  95.099  -74.497  53.196  1
246378  95.132  -74.513  53.136  1
246379  95.167  -74.530  53.072  1
246380  95.201  -74.546  53.005  1
246381  95.235  -74.562  52.937  1
246382  95.269  -74.577  52.870  1
246383  95.303  -74.593  52.806  1
246384  95.337  -74.610  52.743  1
246385  95.361  -74.631  52.683  1
246386  95.386  -74.653  52.626  1
246387  95.412  -74.674  52.570  1
246388  95.439  -74.679  52.515  1
246389  95.464  -74.678  52.461  1
246390  95.488  -74.678  52.407  1
246391  95.514  -74.676  52.354  1
246392  95.538  -74.675  52.303  1
246393  95.564  -74.674  52.253  1
246394  95.590  -74.671  52.206  1
246395  95.617  -74.668  52.161  1
246396  95.643  -74.666  52.117  1
246397  95.669  -74.664  52.072  1
246398  95.695  -74.661  52.028  1
246399  95.722  -74.659  51.986  1
246400  95.748  -74.656  51.946  1
246401  95.774  -74.654  51.906  1
246402  95.801  -74.652  51.866  1
246403  95.827  -74.654  51.826  1
246404  95.852  -74.673  51.785  1
246405  95.883  -74.686  51.745  1
246406  95.920  -74.690  51.706  1
246407  95.957  -74.695  51.668  1
246408  95.994  -74.700  51.630  1
246409  96.032  -74.705  51.592  1
246410  96.069  -74.709  51.554  1
246411  96.106  -74.714  51.518  1
246412  96.144  -74.718  51.482  1
246413  96.181  -74.723  51.448  1
246414  96.219  -74.728  51.417  1
246415  96.256  -74.733  51.386  1
246416  96.264  -74.743  51.358  1
246417  96.258  -74.756  51.331  1
246418  96.274  -74.766  51.307  1
246419  96.300  -74.777  51.285  1
246420  96.326  -74.787  51.265  1
246421  96.351  -74.797  51.247  1
246422  96.377  -74.806  51.231  1
246423  96.463  -74.768  51.217  1
246424  96.489  -74.775  51.203  1
246425  96.515  -74.782  51.192  1
246426  96.541  -74.789  51.184  1
246427  96.567  -74.796  51.177  1
246428  96.593  -74.803  51.171  1
246429  96.619  -74.810  51.166  1
246430  96.645  -74.817  51.161  1
246431  96.671  -74.824  51.154  1
246432  96.698  -74.832  51.145  1
246433  96.726  -74.843  51.137  1
246434  96.755  -74.853  51.125  1
246435  96.783  -74.864  51.109  1
246436  96.811  -74.875  51.091  1
246437  96.852  -74.894  51.073  1
246438  96.899  -74.919  51.054  1
246439  96.920  -74.931  51.037  1
246440  96.926  -74.933  51.020  1
246441  96.933  -74.936  51.003  1
246442  96.939  -74.939  50.986  1
246443  96.946  -74.941  50.971  1
246444  96.952  -74.944  50.959  1
246445  96.959  -74.947  50.945  1
246446  96.972  -74.957  50.929  1
246447  96.985  -74.967  50.912  1
246448  96.993  -74.981  50.893  1
246449  97.004  -74.991  50.876  1
246450  97.029  -74.991  50.858  1
246451  97.052  -74.994  50.842  1
246452  97.076  -74.996  50.827  1
246453  97.099  -74.999  50.814  1
246454  97.122  -75.002  50.801  1
246455  97.146  -75.005  50.788  1
246456  97.167  -75.013  50.774  1
246457  97.189  -75.019  50.756  1
246458  97.211  -75.027  50.735  1
246459  97.232  -75.035  50.712  1
246460  97.256  -75.044  50.688  1
246461  97.281  -75.053  50.662  1
246462  97.305  -75.062  50.635  1
246463  97.329  -75.071  50.606  1
246464  97.354  -75.080  50.573  1
246465  97.378  -75.090  50.537  1
246466  97.401  -75.098  50.500  1
246467  97.418  -75.107  50.461  1
246468  97.446  -75.113  50.424  1
246469  97.476  -75.120  50.385  1
246470  97.507  -75.126  50.348  1
246471  97.538  -75.133  50.312  1
246472  97.572  -75.140  50.276  1
246473  97.605  -75.147  50.240  1
246474  97.639  -75.154  50.200  1
246475  97.673  -75.161  50.159  1
246476  97.709  -75.168  50.116  1
246477  97.744  -75.176  50.073  1
246478  97.780  -75.182  50.029  1
246479  97.815  -75.189  49.984  1
246480  97.850  -75.197  49.935  1
246481  97.884  -75.204  49.889  1
246482  97.918  -75.211  49.845  1
246483  97.967  -75.222  49.800  1
246484  98.001  -75.233  49.752  1
246485  98.034  -75.244  49.700  1
246486  98.068  -75.254  49.647  1
246487  98.101  -75.266  49.593  1
246488  98.135  -75.276  49.541  1
246489  98.168  -75.287  49.492  1
246490  98.202  -75.298  49.443  1
246491  98.228  -75.308  49.395  1
246492  98.241  -75.318  49.349  1
246493  98.255  -75.327  49.300  1
246494  98.268  -75.336  49.251  1
246495  98.300  -75.341  49.202  1
246496  98.349  -75.340  49.152  1
246497  98.395  -75.352  49.103  1
246498  98.432  -75.364  49.057  1
246499  98.452  -75.345  49.010  1
246500  98.472  -75.326  48.962  1
246501  98.504  -75.309  48.914  1
246502  98.549  -75.294  48.865  1
246503  98.573  -75.295  48.814  1
246504  98.561  -75.327  48.761  1
246505  98.550  -75.358  48.709  1
246506  98.575  -75.361  48.657  1
246507  98.603  -75.363  48.605  1
246508  98.631  -75.364  48.555  1
246509  98.658  -75.365  48.506  1
246510  98.686  -75.367  48.456  1
246511  98.715  -75.368  48.406  1
246512  98.754  -75.375  48.356  1
246513  98.793  -75.382  48.304  1
246514  98.833  -75.389  48.253  1
246515  98.858  -75.380  48.204  1
246516  98.880  -75.378  48.157  1
246517  98.898  -75.403  48.111  1
246518  98.915  -75.428  48.065  1
246519  98.932  -75.453  48.020  1
246520  98.949  -75.477  47.976  1
246521  98.967  -75.502  47.933  1
246522  98.986  -75.531  47.891  1
246523  99.009  -75.565  47.851  1
246524  99.031  -75.599  47.811  1
246525  99.054  -75.633  47.774  1
246526  99.077  -75.667  47.739  1
246527  99.099  -75.700  47.704  1
246528  99.122  -75.734  47.670  1
246529  99.157  -75.728  47.636  1
246530  99.194  -75.715  47.603  1
246531  99.231  -75.701  47.569  1
246532  99.269  -75.688  47.539  1
246533  99.305  -75.674  47.508  1
246534  99.340  -75.668  47.478  1
246535  99.365  -75.683  47.450  1
246536  99.389  -75.699  47.422  1
246537  99.413  -75.715  47.394  1
246538  99.437  -75.732  47.367  1
246539  99.461  -75.749  47.340  1
246540  99.485  -75.765  47.316  1
246541  99.509  -75.781  47.292  1
246542  99.533  -75.798  47.268  1
246543  99.557  -75.815  47.245  1
246544  99.581  -75.831  47.223  1
246545  99.606  -75.848  47.201  1
246546  99.632  -75.865  47.179  1
246547  99.658  -75.883  47.160  1
246548  99.685  -75.900  47.141  1
246549  99.708  -75.926  47.120  1
246550  99.729  -75.956  47.096  1
246551  99.752  -75.985  47.071  1
246552  99.792  -75.984  47.046  1
246553  99.833  -75.984  47.019  1
246554  99.873  -75.983  46.991  1
246555  99.906  -75.987  46.963  1
246556  99.933  -75.996  46.934  1
246557  99.957  -76.009  46.904  1
246558  99.981  -76.022  46.874  1
246559  100.005  -76.035  46.841  1
246560  100.030  -76.047  46.811  1
246561  100.054  -76.060  46.782  1
246562  100.078  -76.072  46.751  1
246563  100.100  -76.089  46.720  1
246564  100.119  -76.112  46.689  1
246565  100.138  -76.135  46.656  1
246566  100.168  -76.135  46.623  1
246567  100.202  -76.125  46.592  1
246568  100.237  -76.114  46.562  1
246569  100.271  -76.104  46.531  1
246570  100.305  -76.093  46.499  1
246571  100.340  -76.082  46.467  1
246572  100.367  -76.077  46.435  1
246573  100.393  -76.074  46.403  1
246574  100.433  -76.076  46.372  1
246575  100.458  -76.105  46.340  1
246576  100.476  -76.146  46.309  1
246577  100.496  -76.183  46.276  1
246578  100.519  -76.216  46.243  1
246579  100.543  -76.249  46.210  1
246580  100.566  -76.282  46.177  1
246581  100.588  -76.316  46.143  1
246582  100.612  -76.349  46.111  1
246583  100.635  -76.383  46.079  1
246584  100.657  -76.392  46.046  1
246585  100.680  -76.398  46.014  1
246586  100.702  -76.405  45.982  1
246587  100.724  -76.411  45.952  1
246588  100.737  -76.437  45.923  1
246589  100.745  -76.470  45.894  1
246590  100.754  -76.504  45.864  1
246591  100.762  -76.537  45.836  1
246592  100.770  -76.571  45.809  1
246593  100.795  -76.578  45.783  1
246594  100.841  -76.580  45.758  1
246595  100.885  -76.575  45.734  1
246596  100.930  -76.570  45.710  1
246597  100.975  -76.564  45.687  1
246598  101.019  -76.558  45.664  1
246599  101.064  -76.552  45.641  1
246600  101.109  -76.547  45.618  1
246601  101.154  -76.542  45.596  1
246602  101.198  -76.536  45.574  1
246603  101.243  -76.530  45.551  1
246604  101.288  -76.524  45.529  1
246605  101.333  -76.519  45.506  1
246606  101.368  -76.520  45.484  1
246607  101.392  -76.530  45.462  1
246608  101.416  -76.539  45.441  1
246609  101.440  -76.548  45.420  1
246610  101.468  -76.558  45.400  1
246611  101.496  -76.569  45.379  1
246612  101.511  -76.581  45.358  1
246613  101.526  -76.592  45.339  1
246614  101.540  -76.605  45.319  1
246615  101.555  -76.617  45.300  1
246616  101.570  -76.629  45.281  1
246617  101.585  -76.641  45.263  1
246618  101.599  -76.653  45.245  1
246619  101.614  -76.665  45.226  1
246620  101.629  -76.677  45.208  1
246621  101.643  -76.689  45.192  1
246622  101.661  -76.697  45.175  1
246623  101.682  -76.697  45.157  1
246624  101.704  -76.697  45.140  1
246625  101.726  -76.697  45.123  1
246626  101.747  -76.698  45.106  1
246627  101.763  -76.708  45.088  1
246628  101.779  -76.720  45.071  1
246629  101.796  -76.731  45.054  1
246630  101.812  -76.742  45.038  1
246631  101.829  -76.753  45.021  1
246632  101.845  -76.765  45.004  1
246633  101.862  -76.776  44.985  1
246634  101.878  -76.787  44.968  1
246635  101.894  -76.798  44.952  1
246636  101.910  -76.809  44.935  1
246637  101.927  -76.821  44.916  1
246638  101.937  -76.827  44.900  1
246639  101.929  -76.819  44.883  1
246640  101.929  -76.817  44.866  1
246641  101.937  -76.820  44.850  1
246642  101.944  -76.822  44.833  1
246643  101.952  -76.825  44.815  1
246644  101.960  -76.828  44.798  1
246645  101.967  -76.831  44.781  1
246646  101.977  -76.836  44.764  1
246647  101.999  -76.856  44.747  1
246648  102.021  -76.875  44.731  1
246649  102.043  -76.895  44.716  1
246650  102.064  -76.915  44.699  1
246651  102.087  -76.934  44.683  1
246652  102.108  -76.954  44.667  1
246653  102.130  -76.973  44.649  1
246654  102.152  -76.993  44.633  1
246655  102.174  -77.012  44.617  1
246656  102.196  -77.032  44.601  1
246657  102.217  -77.047  44.585  1
246658  102.234  -77.047  44.568  1
246659  102.251  -77.047  44.552  1
246660  102.269  -77.048  44.535  1
246661  102.286  -77.049  44.520  1
246662  102.309  -77.050  44.504  1
246663  102.332  -77.050  44.488  1
246664  102.355  -77.052  44.472  1
246665  102.378  -77.053  44.457  1
246666  102.401  -77.053  44.441  1
246667  102.424  -77.055  44.425  1
246668  102.447  -77.056  44.411  1
246669  102.470  -77.056  44.395  1
246670  102.493  -77.057  44.380  1
246671  102.516  -77.059  44.364  1
246672  102.539  -77.059  44.349  1
246673  102.562  -77.060  44.332  1
246674  102.585  -77.062  44.317  1
246675  102.608  -77.063  44.301  1
246676  102.631  -77.063  44.286  1
246677  102.654  -77.065  44.270  1
246678  102.677  -77.066  44.254  1
246679  102.697  -77.067  44.238  1
246975  92.629  -74.377  54.538  1
246976  92.655  -74.367  54.542  1
246977  92.683  -74.358  54.545  1
246978  92.713  -74.350  54.548  1
246979  92.743  -74.342  54.550  1
246980  92.774  -74.333  54.553  1
246981  92.803  -74.349  54.554  1
246982  92.833  -74.367  54.554  1
246983  92.863  -74.386  54.554  1
246984  92.894  -74.389  54.554  1
246985  92.925  -74.390  54.552  1
246986  92.956  -74.392  54.551  1
246987  92.987  -74.393  54.550  1
246988  93.018  -74.394  54.549  1
246989  93.049  -74.395  54.548  1
246990  93.080  -74.396  54.548  1
246991  93.111  -74.397  54.549  1
246992  93.142  -74.399  54.551  1
246993  93.174  -74.399  54.556  1
246994  93.204  -74.400  54.561  1
246995  93.235  -74.402  54.570  1
246996  93.267  -74.402  54.581  1
246997  93.297  -74.404  54.597  1
246998  93.330  -74.406  54.615  1
246999  93.363  -74.412  54.634  1
247000  93.390  -74.408  54.655  1
247001  93.413  -74.398  54.679  1
247002  93.435  -74.393  54.704  1
247003  93.456  -74.388  54.730  1
247004  93.478  -74.384  54.755  1
247005  93.499  -74.380  54.777  1
247006  93.520  -74.376  54.794  1
247007  93.542  -74.371  54.807  1
247008  93.563  -74.367  54.817  1
247009  93.585  -74.363  54.820  1
247010  93.606  -74.358  54.826  1
247011  93.628  -74.355  54.836  1
247012  93.649  -74.350  54.851  1
247013  93.671  -74.346  54.860  1
247014  93.692  -74.342  54.863  1
247015  93.713  -74.337  54.860  1
247016  93.734  -74.333  54.853  1
247017  93.756  -74.329  54.850  1
247018  93.777  -74.325  54.851  1
247019  93.799  -74.320  54.855  1
247020  93.820  -74.316  54.854  1
247021  93.842  -74.312  54.844  1
247022  93.872  -74.322  54.830  1
247023  93.904  -74.335  54.813  1
247024  93.926  -74.338  54.795  1
247025  93.948  -74.340  54.779  1
247026  93.971  -74.342  54.762  1
247027  93.993  -74.345  54.744  1
247028  94.014  -74.347  54.727  1
247029  94.037  -74.349  54.708  1
247030  94.059  -74.352  54.685  1
247031  94.081  -74.354  54.662  1
247032  94.102  -74.355  54.642  1
247033  94.124  -74.355  54.622  1
247034  94.148  -74.358  54.603  1
247035  94.172  -74.359  54.585  1
247036  94.194  -74.361  54.566  1
247037  94.214  -74.361  54.548  1
247038  94.234  -74.361  54.530  1
247039  94.254  -74.361  54.513  1
247040  94.274  -74.361  54.493  1
247041  94.295  -74.361  54.473  1
247042  94.316  -74.361  54.454  1
247043  94.337  -74.362  54.435  1
247044  94.357  -74.362  54.415  1
247045  94.377  -74.364  54.394  1
247046  94.398  -74.368  54.371  1
247047  94.420  -74.374  54.345  1
247048  94.444  -74.372  54.317  1
247049  94.469  -74.370  54.287  1
247050  94.493  -74.368  54.255  1
247051  94.518  -74.367  54.224  1
247052  94.542  -74.365  54.192  1
247053  94.565  -74.364  54.158  1
247054  94.582  -74.374  54.122  1
247055  94.599  -74.384  54.084  1
247056  94.616  -74.394  54.043  1
247057  94.632  -74.404  54.001  1
247058  94.648  -74.408  53.959  1
247059  94.663  -74.408  53.916  1
247060  94.678  -74.407  53.871  1
247061  94.698  -74.418  53.826  1
247062  94.717  -74.431  53.781  1
247063  94.737  -74.443  53.738  1
247064  94.757  -74.455  53.698  1
247065  94.777  -74.468  53.662  1
247066  94.796  -74.480  53.628  1
247067  94.815  -74.495  53.596  1
247068  94.826  -74.530  53.568  1
247069  94.852  -74.527  53.539  1
247070  94.892  -74.490  53.509  1
247071  94.915  -74.479  53.476  1
247072  94.938  -74.468  53.440  1
247073  94.962  -74.457  53.404  1
247074  94.985  -74.446  53.369  1
247075  95.008  -74.436  53.330  1
247076  95.041  -74.448  53.286  1
247077  95.074  -74.464  53.238  1
247078  95.109  -74.480  53.186  1
247079  95.143  -74.496  53.129  1
247080  95.177  -74.512  53.067  1
247081  95.211  -74.528  53.002  1
247082  95.245  -74.544  52.936  1
247083  95.279  -74.560  52.870  1
247084  95.313  -74.577  52.806  1
247085  95.347  -74.593  52.744  1
247086  95.378  -74.611  52.684  1
247087  95.402  -74.633  52.627  1
247088  95.424  -74.645  52.572  1
247089  95.451  -74.647  52.517  1
247090  95.479  -74.647  52.463  1
247091  95.507  -74.646  52.410  1
247092  95.533  -74.643  52.357  1
247093  95.559  -74.640  52.306  1
247094  95.586  -74.638  52.258  1
247095  95.612  -74.636  52.212  1
247096  95.638  -74.634  52.167  1
247097  95.665  -74.631  52.123  1
247098  95.691  -74.628  52.078  1
247099  95.717  -74.626  52.035  1
247100  95.744  -74.624  51.993  1
247101  95.770  -74.621  51.953  1
247102  95.796  -74.618  51.913  1
247103  95.822  -74.616  51.873  1
247104  95.848  -74.618  51.833  1
247105  95.874  -74.637  51.792  1
247106  95.899  -74.657  51.751  1
247107  95.925  -74.676  51.711  1
247108  95.958  -74.686  51.673  1
247109  95.995  -74.690  51.634  1
247110  96.033  -74.695  51.596  1
247111  96.070  -74.700  51.558  1
247112  96.107  -74.704  51.521  1
247113  96.145  -74.709  51.484  1
247114  96.182  -74.714  51.450  1
247115  96.219  -74.718  51.418  1
247116  96.256  -74.723  51.387  1
247117  96.263  -74.734  51.357  1
247118  96.257  -74.747  51.329  1
247119  96.257  -74.759  51.304  1
247120  96.283  -74.769  51.281  1
247121  96.308  -74.779  51.260  1
247122  96.334  -74.789  51.242  1
247123  96.370  -74.791  51.225  1
247124  96.466  -74.743  51.210  1
247125  96.493  -74.750  51.196  1
247126  96.518  -74.756  51.183  1
247127  96.544  -74.763  51.175  1
247128  96.571  -74.771  51.167  1
247129  96.596  -74.778  51.161  1
247130  96.622  -74.784  51.156  1
247131  96.649  -74.791  51.151  1
247132  96.675  -74.798  51.146  1
247133  96.700  -74.806  51.139  1
247134  96.727  -74.812  51.133  1
247135  96.753  -74.819  51.123  1
247136  96.781  -74.830  51.110  1
247137  96.809  -74.841  51.094  1
247138  96.846  -74.856  51.076  1
247139  96.888  -74.881  51.059  1
247140  96.926  -74.907  51.042  1
247141  96.932  -74.910  51.026  1
247142  96.938  -74.913  51.009  1
247143  96.945  -74.916  50.992  1
247144  96.951  -74.918  50.977  1
247145  96.958  -74.921  50.963  1
247146  96.966  -74.925  50.949  1
247147  96.979  -74.935  50.933  1
247148  96.992  -74.945  50.917  1
247149  97.003  -74.956  50.898  1
247150  97.011  -74.969  50.882  1
247151  97.019  -74.982  50.865  1
247152  97.040  -74.984  50.851  1
247153  97.065  -74.985  50.839  1
247154  97.088  -74.988  50.828  1
247155  97.112  -74.990  50.817  1
247156  97.135  -74.993  50.805  1
247157  97.159  -74.996  50.791  1
247158  97.182  -74.999  50.772  1
247159  97.206  -75.001  50.751  1
247160  97.229  -75.006  50.728  1
247161  97.253  -75.015  50.704  1
247162  97.278  -75.024  50.678  1
247163  97.302  -75.033  50.651  1
247164  97.326  -75.042  50.621  1
247165  97.351  -75.051  50.589  1
247166  97.375  -75.060  50.555  1
247167  97.399  -75.069  50.520  1
247168  97.420  -75.079  50.484  1
247169  97.449  -75.085  50.447  1
247170  97.480  -75.091  50.407  1
247171  97.514  -75.098  50.369  1
247172  97.548  -75.106  50.332  1
247173  97.582  -75.113  50.295  1
247174  97.616  -75.120  50.258  1
247175  97.650  -75.126  50.219  1
247176  97.683  -75.134  50.178  1
247177  97.718  -75.141  50.135  1
247178  97.753  -75.148  50.091  1
247179  97.789  -75.155  50.047  1
247180  97.824  -75.162  50.002  1
247181  97.860  -75.169  49.952  1
247182  97.895  -75.176  49.907  1
247183  97.931  -75.183  49.863  1
247184  97.962  -75.192  49.818  1
247185  97.994  -75.202  49.769  1
247186  98.027  -75.214  49.716  1
247187  98.061  -75.224  49.662  1
247188  98.095  -75.236  49.607  1
247189  98.128  -75.246  49.554  1
247190  98.162  -75.257  49.504  1
247191  98.196  -75.268  49.454  1
247192  98.229  -75.279  49.405  1
247193  98.256  -75.289  49.358  1
247194  98.270  -75.298  49.310  1
247195  98.283  -75.308  49.260  1
247196  98.313  -75.312  49.210  1
247197  98.362  -75.311  49.160  1
247198  98.405  -75.334  49.111  1
247199  98.439  -75.341  49.064  1
247200  98.458  -75.322  49.018  1
247201  98.479  -75.303  48.970  1
247202  98.498  -75.284  48.922  1
247203  98.541  -75.268  48.872  1
247204  98.573  -75.264  48.821  1
247205  98.561  -75.296  48.767  1
247206  98.562  -75.318  48.715  1
247207  98.590  -75.319  48.663  1
247208  98.618  -75.320  48.610  1
247209  98.645  -75.322  48.561  1
247210  98.673  -75.323  48.510  1
247211  98.701  -75.324  48.459  1
247212  98.728  -75.326  48.409  1
247213  98.756  -75.326  48.358  1
247214  98.789  -75.330  48.307  1
247215  98.829  -75.338  48.256  1
247216  98.861  -75.337  48.207  1
247217  98.882  -75.339  48.161  1
247218  98.900  -75.364  48.115  1
247219  98.917  -75.389  48.069  1
247220  98.934  -75.414  48.024  1
247221  98.955  -75.444  47.978  1
247222  98.978  -75.478  47.934  1
247223  99.000  -75.512  47.891  1
247224  99.023  -75.546  47.850  1
247225  99.046  -75.580  47.809  1
247226  99.068  -75.614  47.770  1
247227  99.091  -75.648  47.732  1
247228  99.114  -75.682  47.697  1
247229  99.146  -75.683  47.662  1
247230  99.184  -75.669  47.628  1
247231  99.221  -75.656  47.593  1
247232  99.258  -75.643  47.560  1
247233  99.295  -75.630  47.528  1
247234  99.327  -75.627  47.497  1
247235  99.354  -75.636  47.468  1
247236  99.377  -75.652  47.439  1
247237  99.402  -75.668  47.411  1
247238  99.426  -75.685  47.383  1
247239  99.450  -75.702  47.356  1
247240  99.474  -75.718  47.330  1
247241  99.498  -75.734  47.306  1
247242  99.522  -75.751  47.283  1
247243  99.546  -75.768  47.259  1
247244  99.570  -75.784  47.235  1
247245  99.594  -75.801  47.214  1
247246  99.621  -75.818  47.192  1
247247  99.647  -75.835  47.171  1
247248  99.673  -75.853  47.152  1
247249  99.699  -75.870  47.134  1
247250  99.722  -75.895  47.114  1
247251  99.745  -75.925  47.091  1
247252  99.767  -75.954  47.066  1
247253  99.794  -75.975  47.040  1
247254  99.835  -75.974  47.013  1
247255  99.875  -75.974  46.986  1
247256  99.915  -75.973  46.959  1
247257  99.947  -75.981  46.930  1
247258  99.973  -75.994  46.900  1
247259  99.997  -76.007  46.870  1
247260  100.021  -76.019  46.838  1
247261  100.045  -76.032  46.807  1
247262  100.069  -76.044  46.778  1
247263  100.093  -76.057  46.747  1
247264  100.118  -76.069  46.715  1
247265  100.139  -76.088  46.682  1
247266  100.158  -76.110  46.650  1
247267  100.184  -76.119  46.617  1
247268  100.218  -76.109  46.586  1
247269  100.253  -76.098  46.555  1
247270  100.287  -76.088  46.524  1
247271  100.321  -76.077  46.493  1
247272  100.356  -76.066  46.460  1
247273  100.390  -76.056  46.428  1
247274  100.418  -76.050  46.396  1
247275  100.454  -76.053  46.364  1
247276  100.472  -76.094  46.333  1
247277  100.494  -76.127  46.301  1
247278  100.517  -76.160  46.268  1
247279  100.541  -76.194  46.235  1
247280  100.564  -76.227  46.202  1
247281  100.587  -76.260  46.169  1
247282  100.610  -76.294  46.135  1
247283  100.633  -76.327  46.103  1
247284  100.656  -76.360  46.071  1
247285  100.679  -76.383  46.039  1
247286  100.701  -76.389  46.007  1
247287  100.724  -76.396  45.975  1
247288  100.746  -76.403  45.945  1
247289  100.756  -76.433  45.916  1
247290  100.764  -76.467  45.888  1
247291  100.772  -76.500  45.859  1
247292  100.781  -76.533  45.832  1
247293  100.787  -76.538  45.805  1
247294  100.821  -76.547  45.779  1
247295  100.862  -76.558  45.753  1
247296  100.911  -76.567  45.729  1
247297  100.956  -76.561  45.706  1
247298  101.000  -76.555  45.682  1
247299  101.045  -76.550  45.660  1
247300  101.090  -76.544  45.636  1
247301  101.135  -76.539  45.613  1
247302  101.179  -76.533  45.590  1
247303  101.224  -76.527  45.568  1
247304  101.269  -76.522  45.545  1
247305  101.314  -76.516  45.522  1
247306  101.358  -76.511  45.500  1
247307  101.399  -76.508  45.478  1
247308  101.422  -76.517  45.456  1
247309  101.447  -76.527  45.435  1
247310  101.471  -76.536  45.414  1
247311  101.498  -76.546  45.394  1
247312  101.525  -76.557  45.373  1
247313  101.539  -76.569  45.353  1
247314  101.554  -76.581  45.333  1
247315  101.568  -76.593  45.313  1
247316  101.584  -76.605  45.294  1
247317  101.598  -76.617  45.274  1
247318  101.613  -76.629  45.256  1
247319  101.627  -76.641  45.237  1
247320  101.642  -76.653  45.219  1
247321  101.657  -76.665  45.200  1
247322  101.675  -76.672  45.183  1
247323  101.696  -76.672  45.166  1
247324  101.718  -76.672  45.148  1
247325  101.740  -76.672  45.130  1
247326  101.759  -76.677  45.113  1
247327  101.775  -76.689  45.095  1
247328  101.792  -76.700  45.078  1
247329  101.808  -76.711  45.061  1
247330  101.824  -76.722  45.044  1
247331  101.840  -76.734  45.027  1
247332  101.857  -76.745  45.010  1
247333  101.873  -76.755  44.992  1
247334  101.890  -76.767  44.974  1
247335  101.906  -76.778  44.957  1
247336  101.922  -76.789  44.940  1
247337  101.923  -76.788  44.923  1
247338  101.916  -76.781  44.905  1
247339  101.917  -76.780  44.888  1
247340  101.925  -76.783  44.871  1
247341  101.933  -76.786  44.855  1
247342  101.941  -76.788  44.838  1
247343  101.948  -76.791  44.821  1
247344  101.956  -76.793  44.804  1
247345  101.963  -76.796  44.787  1
247346  101.977  -76.807  44.770  1
247347  101.999  -76.826  44.753  1
247348  102.021  -76.846  44.737  1
247349  102.043  -76.865  44.720  1
247350  102.064  -76.885  44.704  1
247351  102.087  -76.905  44.688  1
247352  102.108  -76.925  44.672  1
247353  102.130  -76.944  44.655  1
247354  102.152  -76.964  44.638  1
247355  102.174  -76.983  44.622  1
247356  102.196  -77.003  44.606  1
247357  102.214  -77.006  44.589  1
247358  102.231  -77.007  44.573  1
247359  102.249  -77.007  44.556  1
247360  102.266  -77.008  44.540  1
247361  102.283  -77.009  44.524  1
247362  102.306  -77.009  44.508  1
247363  102.329  -77.010  44.492  1
247364  102.352  -77.012  44.477  1
247365  102.375  -77.012  44.461  1
247366  102.398  -77.013  44.445  1
247367  102.421  -77.014  44.429  1
247368  102.444  -77.016  44.413  1
247369  102.467  -77.016  44.398  1
247370  102.490  -77.017  44.382  1
247371  102.513  -77.019  44.367  1
247372  102.536  -77.019  44.352  1
247373  102.559  -77.020  44.337  1
247374  102.582  -77.022  44.321  1
247375  102.605  -77.022  44.305  1
247376  102.628  -77.023  44.289  1
247377  102.651  -77.024  44.274  1
247378  102.674  -77.025  44.258  1
247678  92.684  -74.331  54.553  1
247679  92.714  -74.323  54.555  1
247680  92.744  -74.314  54.557  1
247681  92.775  -74.306  54.559  1
247682  92.805  -74.322  54.561  1
247683  92.834  -74.341  54.561  1
247684  92.864  -74.359  54.561  1
247685  92.895  -74.368  54.561  1
247686  92.926  -74.369  54.559  1
247687  92.956  -74.371  54.558  1
247688  92.988  -74.371  54.557  1
247689  93.019  -74.372  54.555  1
247690  93.050  -74.374  54.554  1
247691  93.081  -74.374  54.553  1
247692  93.112  -74.376  54.553  1
247693  93.143  -74.377  54.555  1
247694  93.174  -74.378  54.557  1
247695  93.205  -74.379  54.561  1
247696  93.236  -74.380  54.567  1
247697  93.267  -74.381  54.577  1
247698  93.298  -74.382  54.592  1
247699  93.330  -74.383  54.610  1
247700  93.361  -74.384  54.630  1
247701  93.393  -74.387  54.652  1
247702  93.415  -74.380  54.676  1
247703  93.436  -74.376  54.701  1
247704  93.458  -74.371  54.726  1
247705  93.479  -74.368  54.751  1
247706  93.500  -74.363  54.775  1
247707  93.522  -74.359  54.797  1
247708  93.543  -74.355  54.815  1
247709  93.565  -74.350  54.825  1
247710  93.586  -74.346  54.832  1
247711  93.608  -74.342  54.842  1
247712  93.629  -74.338  54.856  1
247713  93.650  -74.333  54.877  1
247714  93.672  -74.329  54.891  1
247715  93.693  -74.325  54.898  1
247716  93.714  -74.320  54.894  1
247717  93.736  -74.317  54.884  1
247718  93.757  -74.312  54.876  1
247719  93.779  -74.308  54.870  1
247720  93.800  -74.304  54.868  1
247721  93.822  -74.299  54.866  1
247722  93.843  -74.295  54.859  1
247723  93.864  -74.292  54.846  1
247724  93.896  -74.304  54.831  1
247725  93.920  -74.308  54.809  1
247726  93.942  -74.311  54.787  1
247727  93.965  -74.313  54.764  1
247728  93.986  -74.315  54.741  1
247729  94.008  -74.317  54.721  1
247730  94.031  -74.320  54.701  1
247731  94.053  -74.322  54.679  1
247732  94.076  -74.325  54.655  1
247733  94.101  -74.329  54.635  1
247734  94.123  -74.330  54.614  1
247735  94.146  -74.331  54.594  1
247736  94.170  -74.333  54.577  1
247737  94.194  -74.335  54.560  1
247738  94.215  -74.336  54.544  1
247739  94.235  -74.336  54.528  1
247740  94.255  -74.336  54.512  1
247741  94.275  -74.336  54.493  1
247742  94.294  -74.336  54.475  1
247743  94.314  -74.336  54.456  1
247744  94.335  -74.336  54.438  1
247745  94.356  -74.336  54.420  1
247746  94.376  -74.338  54.400  1
247747  94.398  -74.342  54.376  1
247748  94.422  -74.341  54.349  1
247749  94.447  -74.339  54.321  1
247750  94.471  -74.337  54.290  1
247751  94.495  -74.336  54.258  1
247752  94.520  -74.334  54.228  1
247753  94.544  -74.333  54.196  1
247754  94.568  -74.331  54.162  1
247755  94.586  -74.339  54.126  1
247756  94.603  -74.349  54.087  1
247757  94.620  -74.359  54.045  1
247758  94.636  -74.368  54.003  1
247759  94.652  -74.371  53.960  1
247760  94.667  -74.370  53.916  1
247761  94.682  -74.370  53.869  1
247762  94.700  -74.377  53.822  1
247763  94.719  -74.389  53.775  1
247764  94.739  -74.401  53.731  1
247765  94.759  -74.413  53.688  1
247766  94.779  -74.425  53.649  1
247767  94.799  -74.437  53.613  1
247768  94.814  -74.460  53.580  1
247769  94.824  -74.496  53.552  1
247770  94.835  -74.533  53.526  1
247771  94.866  -74.517  53.497  1
247772  94.908  -74.476  53.463  1
247773  94.945  -74.443  53.427  1
247774  94.969  -74.432  53.391  1
247775  94.992  -74.421  53.354  1
247776  95.017  -74.415  53.314  1
247777  95.051  -74.430  53.271  1
247778  95.085  -74.446  53.224  1
247779  95.119  -74.462  53.174  1
247780  95.153  -74.479  53.117  1
247781  95.187  -74.495  53.057  1
247782  95.221  -74.511  52.995  1
247783  95.255  -74.527  52.931  1
247784  95.289  -74.543  52.866  1
247785  95.321  -74.557  52.803  1
247786  95.354  -74.571  52.742  1
247787  95.388  -74.580  52.682  1
247788  95.413  -74.587  52.626  1
247789  95.435  -74.599  52.571  1
247790  95.461  -74.603  52.517  1
247791  95.489  -74.603  52.463  1
247792  95.519  -74.603  52.410  1
247793  95.547  -74.602  52.358  1
247794  95.576  -74.601  52.308  1
247795  95.605  -74.601  52.260  1
247796  95.634  -74.600  52.216  1
247797  95.660  -74.598  52.172  1
247798  95.686  -74.596  52.128  1
247799  95.712  -74.593  52.084  1
247800  95.739  -74.590  52.042  1
247801  95.765  -74.588  52.000  1
247802  95.792  -74.586  51.960  1
247803  95.818  -74.584  51.921  1
247804  95.844  -74.581  51.880  1
247805  95.870  -74.584  51.840  1
247806  95.896  -74.603  51.799  1
247807  95.921  -74.621  51.757  1
247808  95.947  -74.640  51.717  1
247809  95.972  -74.659  51.677  1
247810  95.997  -74.678  51.638  1
247811  96.033  -74.686  51.600  1
247812  96.071  -74.690  51.562  1
247813  96.108  -74.695  51.524  1
247814  96.145  -74.700  51.486  1
247815  96.182  -74.704  51.452  1
247816  96.220  -74.709  51.419  1
247817  96.257  -74.713  51.387  1
247818  96.261  -74.725  51.356  1
247819  96.256  -74.737  51.328  1
247820  96.250  -74.750  51.301  1
247821  96.265  -74.762  51.278  1
247822  96.291  -74.772  51.256  1
247823  96.317  -74.781  51.237  1
247824  96.444  -74.710  51.219  1
247825  96.470  -74.717  51.202  1
247826  96.496  -74.724  51.188  1
247827  96.522  -74.731  51.175  1
247828  96.548  -74.738  51.165  1
247829  96.574  -74.745  51.157  1
247830  96.600  -74.752  51.151  1
247831  96.626  -74.759  51.144  1
247832  96.652  -74.766  51.140  1
247833  96.678  -74.773  51.136  1
247834  96.704  -74.780  51.132  1
247835  96.730  -74.787  51.126  1
247836  96.756  -74.794  51.118  1
247837  96.782  -74.801  51.107  1
247838  96.808  -74.808  51.094  1
247839  96.838  -74.819  51.080  1
247840  96.876  -74.844  51.063  1
247841  96.913  -74.870  51.047  1
247842  96.938  -74.887  51.031  1
247843  96.944  -74.889  51.015  1
247844  96.951  -74.892  50.999  1
247845  96.957  -74.895  50.983  1
247846  96.963  -74.897  50.968  1
247847  96.973  -74.903  50.953  1
247848  96.986  -74.913  50.937  1
247849  96.999  -74.923  50.921  1
247850  97.012  -74.932  50.904  1
247851  97.021  -74.945  50.888  1
247852  97.029  -74.958  50.873  1
247853  97.037  -74.971  50.861  1
247854  97.052  -74.978  50.851  1
247855  97.077  -74.977  50.842  1
247856  97.101  -74.979  50.832  1
247857  97.124  -74.982  50.820  1
247858  97.148  -74.984  50.807  1
247859  97.171  -74.987  50.788  1
247860  97.198  -74.986  50.767  1
247861  97.229  -74.982  50.744  1
247862  97.253  -74.991  50.720  1
247863  97.277  -75.000  50.694  1
247864  97.301  -75.008  50.666  1
247865  97.325  -75.017  50.636  1
247866  97.349  -75.026  50.605  1
247867  97.373  -75.034  50.573  1
247868  97.397  -75.043  50.540  1
247869  97.425  -75.050  50.506  1
247870  97.457  -75.057  50.468  1
247871  97.491  -75.064  50.429  1
247872  97.525  -75.071  50.389  1
247873  97.559  -75.078  50.350  1
247874  97.592  -75.085  50.312  1
247875  97.626  -75.092  50.274  1
247876  97.660  -75.099  50.235  1
247877  97.694  -75.106  50.196  1
247878  97.728  -75.113  50.154  1
247879  97.762  -75.120  50.110  1
247880  97.798  -75.127  50.065  1
247881  97.833  -75.135  50.019  1
247882  97.869  -75.142  49.970  1
247883  97.904  -75.148  49.925  1
247884  97.938  -75.156  49.880  1
247885  97.968  -75.166  49.832  1
247886  97.999  -75.176  49.783  1
247887  98.029  -75.185  49.729  1
247888  98.060  -75.195  49.675  1
247889  98.090  -75.205  49.621  1
247890  98.122  -75.216  49.566  1
247891  98.155  -75.226  49.514  1
247892  98.189  -75.238  49.463  1
247893  98.222  -75.248  49.414  1
247894  98.256  -75.259  49.366  1
247895  98.284  -75.270  49.317  1
247896  98.297  -75.279  49.267  1
247897  98.326  -75.284  49.216  1
247898  98.372  -75.294  49.167  1
247899  98.414  -75.317  49.118  1
247900  98.445  -75.318  49.071  1
247901  98.465  -75.299  49.024  1
247902  98.485  -75.280  48.977  1
247903  98.505  -75.261  48.928  1
247904  98.534  -75.243  48.878  1
247905  98.572  -75.234  48.827  1
247906  98.561  -75.265  48.773  1
247907  98.576  -75.276  48.721  1
247908  98.604  -75.276  48.669  1
247909  98.632  -75.278  48.616  1
247910  98.659  -75.279  48.566  1
247911  98.687  -75.280  48.515  1
247912  98.715  -75.282  48.463  1
247913  98.742  -75.283  48.411  1
247914  98.770  -75.284  48.360  1
247915  98.798  -75.286  48.309  1
247916  98.826  -75.286  48.258  1
247917  98.864  -75.293  48.209  1
247918  98.884  -75.301  48.162  1
247919  98.902  -75.326  48.116  1
247920  98.924  -75.358  48.070  1
247921  98.946  -75.392  48.023  1
247922  98.969  -75.426  47.978  1
247923  98.992  -75.460  47.934  1
247924  99.014  -75.493  47.891  1
247925  99.037  -75.527  47.848  1
247926  99.060  -75.561  47.806  1
247927  99.082  -75.596  47.766  1
247928  99.106  -75.629  47.727  1
247929  99.136  -75.638  47.690  1
247930  99.173  -75.624  47.654  1
247931  99.210  -75.611  47.619  1
247932  99.247  -75.598  47.584  1
247933  99.281  -75.592  47.551  1
247934  99.312  -75.593  47.518  1
247935  99.343  -75.596  47.487  1
247936  99.368  -75.605  47.458  1
247937  99.391  -75.621  47.429  1
247938  99.415  -75.638  47.401  1
247939  99.439  -75.655  47.373  1
247940  99.463  -75.671  47.346  1
247941  99.487  -75.687  47.320  1
247942  99.511  -75.704  47.297  1
247943  99.535  -75.721  47.273  1
247944  99.559  -75.737  47.250  1
247945  99.583  -75.753  47.227  1
247946  99.609  -75.771  47.205  1
247947  99.635  -75.788  47.183  1
247948  99.661  -75.806  47.162  1
247949  99.687  -75.823  47.144  1
247950  99.713  -75.840  47.126  1
247951  99.737  -75.864  47.106  1
247952  99.759  -75.894  47.084  1
247953  99.781  -75.923  47.060  1
247954  99.803  -75.953  47.034  1
247955  99.836  -75.965  47.008  1
247956  99.876  -75.964  46.982  1
247957  99.917  -75.964  46.955  1
247958  99.947  -75.974  46.926  1
247959  99.976  -75.984  46.897  1
247960  100.006  -75.994  46.866  1
247961  100.035  -76.004  46.834  1
247962  100.061  -76.016  46.804  1
247963  100.085  -76.029  46.773  1
247964  100.109  -76.042  46.742  1
247965  100.133  -76.054  46.709  1
247966  100.157  -76.067  46.676  1
247967  100.179  -76.086  46.643  1
247968  100.200  -76.104  46.612  1
247969  100.234  -76.094  46.580  1
247970  100.269  -76.083  46.549  1
247971  100.303  -76.072  46.517  1
247972  100.337  -76.062  46.486  1
247973  100.371  -76.051  46.453  1
247974  100.406  -76.041  46.420  1
247975  100.440  -76.030  46.389  1
247976  100.470  -76.038  46.358  1
247977  100.493  -76.072  46.325  1
247978  100.516  -76.105  46.293  1
247979  100.539  -76.138  46.261  1
247980  100.562  -76.172  46.228  1
247981  100.585  -76.205  46.194  1
247982  100.608  -76.238  46.161  1
247983  100.631  -76.271  46.129  1
247984  100.654  -76.304  46.096  1
247985  100.677  -76.338  46.064  1
247986  100.700  -76.371  46.032  1
247987  100.723  -76.381  46.000  1
247988  100.745  -76.388  45.969  1
247989  100.767  -76.395  45.939  1
247990  100.775  -76.429  45.910  1
247991  100.783  -76.462  45.882  1
247992  100.791  -76.495  45.854  1
247993  100.798  -76.502  45.827  1
247994  100.805  -76.505  45.800  1
247995  100.846  -76.515  45.774  1
247996  100.888  -76.527  45.749  1
247997  100.929  -76.538  45.725  1
247998  100.981  -76.552  45.701  1
247999  101.026  -76.547  45.677  1
248000  101.071  -76.542  45.654  1
248001  101.115  -76.536  45.631  1
248002  101.160  -76.530  45.608  1
248003  101.205  -76.524  45.585  1
248004  101.250  -76.519  45.563  1
248005  101.294  -76.514  45.539  1
248006  101.339  -76.508  45.516  1
248007  101.384  -76.502  45.494  1
248008  101.428  -76.496  45.473  1
248009  101.454  -76.505  45.451  1
248010  101.477  -76.514  45.429  1
248011  101.501  -76.524  45.409  1
248012  101.530  -76.534  45.389  1
248013  101.553  -76.546  45.368  1
248014  101.567  -76.557  45.348  1
248015  101.582  -76.569  45.328  1
248016  101.597  -76.581  45.308  1
248017  101.612  -76.593  45.287  1
248018  101.626  -76.605  45.267  1
248019  101.641  -76.618  45.249  1
248020  101.656  -76.630  45.229  1
248021  101.671  -76.641  45.211  1
248022  101.689  -76.648  45.192  1
248023  101.710  -76.648  45.173  1
248024  101.732  -76.648  45.157  1
248025  101.754  -76.648  45.139  1
248026  101.770  -76.658  45.120  1
248027  101.787  -76.669  45.102  1
248028  101.803  -76.680  45.085  1
248029  101.820  -76.691  45.068  1
248030  101.836  -76.702  45.051  1
248031  101.852  -76.713  45.034  1
248032  101.869  -76.724  45.016  1
248033  101.885  -76.736  44.999  1
248034  101.901  -76.747  44.981  1
248035  101.917  -76.757  44.963  1
248036  101.910  -76.750  44.946  1
248037  101.903  -76.743  44.929  1
248038  101.906  -76.743  44.912  1
248039  101.913  -76.746  44.895  1
248040  101.921  -76.749  44.878  1
248041  101.929  -76.752  44.860  1
248042  101.937  -76.754  44.843  1
248043  101.944  -76.757  44.827  1
248044  101.952  -76.759  44.810  1
248045  101.959  -76.762  44.793  1
248046  101.977  -76.777  44.776  1
248047  101.999  -76.797  44.759  1
248048  102.021  -76.816  44.742  1
248049  102.043  -76.836  44.726  1
248050  102.064  -76.856  44.709  1
248051  102.087  -76.875  44.693  1
248052  102.108  -76.895  44.677  1
248053  102.130  -76.915  44.660  1
248054  102.152  -76.934  44.643  1
248055  102.174  -76.954  44.626  1
248056  102.194  -76.965  44.610  1
248057  102.211  -76.966  44.594  1
248058  102.229  -76.966  44.577  1
248059  102.246  -76.967  44.561  1
248060  102.264  -76.968  44.545  1
248061  102.281  -76.969  44.528  1
248062  102.304  -76.969  44.511  1
248063  102.327  -76.970  44.497  1
248064  102.350  -76.971  44.481  1
248065  102.373  -76.972  44.465  1
248066  102.396  -76.973  44.450  1
248067  102.419  -76.974  44.433  1
248068  102.442  -76.975  44.417  1
248069  102.465  -76.976  44.402  1
248070  102.488  -76.977  44.387  1
248071  102.511  -76.978  44.371  1
248072  102.534  -76.979  44.356  1
248073  102.557  -76.980  44.341  1
248074  102.580  -76.981  44.325  1
248075  102.603  -76.982  44.309  1
248076  102.626  -76.983  44.293  1
248380  92.716  -74.295  54.562  1
248381  92.746  -74.287  54.564  1
248382  92.776  -74.280  54.566  1
248383  92.806  -74.296  54.568  1
248384  92.836  -74.314  54.569  1
248385  92.865  -74.333  54.569  1
248386  92.896  -74.346  54.568  1
248387  92.926  -74.348  54.567  1
248388  92.957  -74.349  54.566  1
248389  92.989  -74.350  54.563  1
248390  93.019  -74.351  54.562  1
248391  93.051  -74.352  54.561  1
248392  93.082  -74.353  54.560  1
248393  93.113  -74.355  54.560  1
248394  93.144  -74.355  54.560  1
248395  93.175  -74.356  54.560  1
248396  93.206  -74.358  54.563  1
248397  93.237  -74.358  54.568  1
248398  93.268  -74.360  54.576  1
248399  93.299  -74.361  54.590  1
248400  93.331  -74.362  54.607  1
248401  93.361  -74.363  54.628  1
248402  93.392  -74.361  54.649  1
248403  93.416  -74.360  54.673  1
248404  93.438  -74.356  54.699  1
248405  93.459  -74.352  54.725  1
248406  93.481  -74.349  54.749  1
248407  93.502  -74.345  54.774  1
248408  93.523  -74.341  54.799  1
248409  93.545  -74.337  54.822  1
248410  93.566  -74.333  54.831  1
248411  93.587  -74.329  54.842  1
248412  93.609  -74.325  54.857  1
248413  93.630  -74.321  54.876  1
248414  93.652  -74.317  54.899  1
248415  93.673  -74.312  54.916  1
248416  93.695  -74.308  54.925  1
248417  93.716  -74.304  54.923  1
248418  93.737  -74.300  54.911  1
248419  93.759  -74.295  54.900  1
248420  93.780  -74.291  54.890  1
248421  93.801  -74.287  54.883  1
248422  93.823  -74.283  54.878  1
248423  93.844  -74.279  54.871  1
248424  93.866  -74.274  54.861  1
248425  93.889  -74.273  54.848  1
248426  93.914  -74.279  54.827  1
248427  93.936  -74.281  54.801  1
248428  93.958  -74.283  54.773  1
248429  93.981  -74.286  54.745  1
248430  94.005  -74.290  54.721  1
248431  94.028  -74.293  54.698  1
248432  94.052  -74.297  54.674  1
248433  94.075  -74.301  54.649  1
248434  94.109  -74.307  54.628  1
248435  94.126  -74.306  54.607  1
248436  94.145  -74.305  54.588  1
248437  94.169  -74.307  54.574  1
248438  94.193  -74.309  54.559  1
248439  94.216  -74.311  54.545  1
248440  94.236  -74.311  54.531  1
248441  94.256  -74.311  54.516  1
248442  94.275  -74.311  54.499  1
248443  94.295  -74.311  54.481  1
248444  94.315  -74.311  54.463  1
248445  94.335  -74.311  54.443  1
248446  94.355  -74.311  54.425  1
248447  94.376  -74.311  54.404  1
248448  94.401  -74.310  54.379  1
248449  94.425  -74.308  54.352  1
248450  94.449  -74.307  54.323  1
248451  94.474  -74.305  54.292  1
248452  94.498  -74.303  54.261  1
248453  94.522  -74.302  54.231  1
248454  94.547  -74.300  54.199  1
248455  94.571  -74.299  54.165  1
248456  94.591  -74.304  54.128  1
248457  94.607  -74.314  54.087  1
248458  94.624  -74.324  54.046  1
248459  94.640  -74.333  54.003  1
248460  94.655  -74.333  53.959  1
248461  94.671  -74.333  53.914  1
248462  94.686  -74.333  53.866  1
248463  94.702  -74.334  53.817  1
248464  94.721  -74.346  53.769  1
248465  94.741  -74.358  53.725  1
248466  94.761  -74.371  53.679  1
248467  94.780  -74.383  53.636  1
248468  94.801  -74.395  53.598  1
248469  94.813  -74.425  53.565  1
248470  94.823  -74.461  53.538  1
248471  94.834  -74.498  53.513  1
248472  94.852  -74.514  53.486  1
248473  94.888  -74.487  53.452  1
248474  94.924  -74.461  53.415  1
248475  94.964  -74.425  53.378  1
248476  94.998  -74.396  53.341  1
248477  95.027  -74.397  53.300  1
248478  95.061  -74.413  53.256  1
248479  95.095  -74.429  53.209  1
248480  95.127  -74.443  53.160  1
248481  95.160  -74.457  53.104  1
248482  95.192  -74.471  53.046  1
248483  95.225  -74.484  52.986  1
248484  95.258  -74.499  52.924  1
248485  95.290  -74.512  52.861  1
248486  95.323  -74.526  52.798  1
248487  95.355  -74.540  52.737  1
248488  95.392  -74.542  52.677  1
248489  95.424  -74.542  52.622  1
248490  95.446  -74.553  52.568  1
248491  95.471  -74.559  52.515  1
248492  95.499  -74.559  52.461  1
248493  95.529  -74.558  52.408  1
248494  95.557  -74.558  52.358  1
248495  95.586  -74.557  52.310  1
248496  95.615  -74.556  52.263  1
248497  95.644  -74.556  52.219  1
248498  95.673  -74.555  52.175  1
248499  95.701  -74.555  52.132  1
248500  95.731  -74.555  52.089  1
248501  95.759  -74.554  52.047  1
248502  95.787  -74.553  52.006  1
248503  95.813  -74.550  51.966  1
248504  95.839  -74.548  51.928  1
248505  95.866  -74.546  51.887  1
248506  95.892  -74.549  51.846  1
248507  95.917  -74.568  51.805  1
248508  95.943  -74.587  51.763  1
248509  95.968  -74.606  51.722  1
248510  95.994  -74.624  51.682  1
248511  96.020  -74.643  51.642  1
248512  96.045  -74.662  51.603  1
248513  96.071  -74.681  51.565  1
248514  96.108  -74.685  51.526  1
248515  96.146  -74.690  51.488  1
248516  96.183  -74.695  51.453  1
248517  96.221  -74.700  51.419  1
248518  96.258  -74.704  51.387  1
248519  96.260  -74.715  51.355  1
248520  96.254  -74.728  51.326  1
248521  96.249  -74.741  51.299  1
248522  96.248  -74.754  51.274  1
248523  96.274  -74.764  51.252  1
248524  96.372  -74.716  51.231  1
248525  96.447  -74.684  51.213  1
248526  96.473  -74.692  51.195  1
248527  96.500  -74.699  51.179  1
248528  96.525  -74.706  51.166  1
248529  96.551  -74.712  51.156  1
248530  96.578  -74.720  51.147  1
248531  96.603  -74.727  51.139  1
248532  96.629  -74.734  51.134  1
248533  96.656  -74.740  51.128  1
248534  96.682  -74.747  51.123  1
248535  96.708  -74.755  51.120  1
248536  96.733  -74.762  51.116  1
248537  96.758  -74.769  51.110  1
248538  96.783  -74.776  51.101  1
248539  96.808  -74.784  51.091  1
248540  96.834  -74.794  51.079  1
248541  96.863  -74.808  51.065  1
248542  96.900  -74.833  51.050  1
248543  96.937  -74.859  51.035  1
248544  96.950  -74.866  51.019  1
248545  96.956  -74.869  51.005  1
248546  96.963  -74.872  50.990  1
248547  96.969  -74.874  50.974  1
248548  96.979  -74.881  50.958  1
248549  96.993  -74.891  50.941  1
248550  97.006  -74.900  50.925  1
248551  97.019  -74.910  50.909  1
248552  97.031  -74.920  50.894  1
248553  97.039  -74.934  50.881  1
248554  97.047  -74.947  50.870  1
248555  97.055  -74.960  50.862  1
248556  97.064  -74.972  50.854  1
248557  97.088  -74.971  50.845  1
248558  97.113  -74.970  50.834  1
248559  97.137  -74.972  50.821  1
248560  97.168  -74.966  50.802  1
248561  97.202  -74.957  50.782  1
248562  97.230  -74.960  50.760  1
248563  97.254  -74.968  50.735  1
248564  97.278  -74.977  50.708  1
248565  97.302  -74.985  50.679  1
248566  97.326  -74.994  50.649  1
248567  97.350  -75.003  50.620  1
248568  97.374  -75.011  50.589  1
248569  97.406  -75.016  50.556  1
248570  97.443  -75.019  50.521  1
248571  97.476  -75.026  50.485  1
248572  97.508  -75.033  50.446  1
248573  97.540  -75.041  50.406  1
248574  97.571  -75.050  50.367  1
248575  97.603  -75.057  50.328  1
248576  97.637  -75.065  50.291  1
248577  97.670  -75.072  50.253  1
248578  97.704  -75.079  50.213  1
248579  97.738  -75.085  50.174  1
248580  97.772  -75.092  50.130  1
248581  97.807  -75.100  50.085  1
248582  97.843  -75.107  50.038  1
248583  97.878  -75.114  49.987  1
248584  97.911  -75.121  49.939  1
248585  97.943  -75.129  49.891  1
248586  97.973  -75.138  49.842  1
248587  98.004  -75.148  49.790  1
248588  98.034  -75.158  49.737  1
248589  98.065  -75.169  49.685  1
248590  98.095  -75.179  49.633  1
248591  98.126  -75.189  49.577  1
248592  98.156  -75.198  49.523  1
248593  98.186  -75.208  49.471  1
248594  98.217  -75.218  49.421  1
248595  98.249  -75.229  49.372  1
248596  98.283  -75.240  49.322  1
248597  98.312  -75.250  49.272  1
248598  98.339  -75.256  49.222  1
248599  98.382  -75.276  49.171  1
248600  98.424  -75.299  49.123  1
248601  98.452  -75.295  49.076  1
248602  98.472  -75.276  49.029  1
248603  98.492  -75.257  48.981  1
248604  98.512  -75.238  48.932  1
248605  98.531  -75.219  48.882  1
248606  98.572  -75.203  48.831  1
248607  98.563  -75.232  48.778  1
248608  98.591  -75.233  48.726  1
248609  98.619  -75.234  48.673  1
248610  98.646  -75.236  48.621  1
248611  98.674  -75.237  48.570  1
248612  98.702  -75.238  48.518  1
248613  98.729  -75.239  48.466  1
248614  98.757  -75.241  48.414  1
248615  98.785  -75.242  48.361  1
248616  98.812  -75.243  48.310  1
248617  98.840  -75.245  48.260  1
248618  98.867  -75.248  48.210  1
248619  98.892  -75.271  48.163  1
248620  98.915  -75.305  48.116  1
248621  98.938  -75.339  48.069  1
248622  98.960  -75.373  48.022  1
248623  98.983  -75.407  47.976  1
248624  99.006  -75.441  47.932  1
248625  99.029  -75.475  47.889  1
248626  99.052  -75.509  47.845  1
248627  99.074  -75.543  47.803  1
248628  99.097  -75.577  47.761  1
248629  99.125  -75.593  47.721  1
248630  99.162  -75.580  47.684  1
248631  99.199  -75.566  47.646  1
248632  99.235  -75.555  47.610  1
248633  99.266  -75.558  47.575  1
248634  99.297  -75.560  47.541  1
248635  99.328  -75.561  47.508  1
248636  99.358  -75.564  47.477  1
248637  99.383  -75.574  47.448  1
248638  99.404  -75.591  47.419  1
248639  99.427  -75.608  47.391  1
248640  99.451  -75.624  47.364  1
248641  99.476  -75.640  47.337  1
248642  99.500  -75.657  47.311  1
248643  99.524  -75.674  47.287  1
248644  99.548  -75.690  47.264  1
248645  99.572  -75.706  47.241  1
248646  99.597  -75.724  47.218  1
248647  99.624  -75.741  47.196  1
248648  99.650  -75.758  47.175  1
248649  99.676  -75.775  47.153  1
248650  99.702  -75.793  47.135  1
248651  99.728  -75.810  47.116  1
248652  99.752  -75.833  47.097  1
248653  99.774  -75.862  47.077  1
248654  99.796  -75.892  47.054  1
248655  99.818  -75.922  47.028  1
248656  99.840  -75.951  47.003  1
248657  99.878  -75.955  46.978  1
248658  99.918  -75.956  46.950  1
248659  99.947  -75.966  46.921  1
248660  99.977  -75.976  46.892  1
248661  100.006  -75.986  46.861  1
248662  100.035  -75.997  46.830  1
248663  100.064  -76.007  46.799  1
248664  100.094  -76.017  46.768  1
248665  100.123  -76.027  46.736  1
248666  100.149  -76.039  46.703  1
248667  100.173  -76.052  46.670  1
248668  100.197  -76.065  46.637  1
248669  100.218  -76.085  46.605  1
248670  100.250  -76.079  46.574  1
248671  100.284  -76.068  46.542  1
248672  100.319  -76.057  46.510  1
248673  100.353  -76.047  46.478  1
248674  100.387  -76.036  46.445  1
248675  100.419  -76.027  46.413  1
248676  100.452  -76.017  46.382  1
248677  100.481  -76.025  46.351  1
248678  100.508  -76.055  46.318  1
248679  100.535  -76.085  46.286  1
248680  100.560  -76.116  46.254  1
248681  100.583  -76.150  46.221  1
248682  100.606  -76.182  46.187  1
248683  100.629  -76.216  46.155  1
248684  100.652  -76.249  46.122  1
248685  100.676  -76.282  46.089  1
248686  100.698  -76.316  46.057  1
248687  100.721  -76.349  46.025  1
248688  100.745  -76.373  45.993  1
248689  100.767  -76.379  45.962  1
248690  100.786  -76.392  45.934  1
248691  100.794  -76.425  45.905  1
248692  100.802  -76.458  45.877  1
248693  100.809  -76.467  45.850  1
248694  100.816  -76.469  45.822  1
248695  100.831  -76.473  45.795  1
248696  100.872  -76.484  45.770  1
248697  100.913  -76.495  45.745  1
248698  100.955  -76.507  45.720  1
248699  100.996  -76.518  45.696  1
248700  101.050  -76.535  45.673  1
248701  101.096  -76.533  45.649  1
248702  101.141  -76.527  45.626  1
248703  101.186  -76.522  45.603  1
248704  101.231  -76.516  45.580  1
248705  101.275  -76.511  45.557  1
248706  101.320  -76.505  45.534  1
248707  101.365  -76.499  45.511  1
248708  101.409  -76.494  45.489  1
248709  101.454  -76.488  45.468  1
248710  101.484  -76.493  45.445  1
248711  101.508  -76.502  45.424  1
248712  101.533  -76.511  45.404  1
248713  101.560  -76.522  45.384  1
248714  101.581  -76.533  45.362  1
248715  101.596  -76.546  45.342  1
248716  101.611  -76.558  45.322  1
248717  101.625  -76.570  45.301  1
248718  101.640  -76.581  45.281  1
248719  101.655  -76.593  45.261  1
248720  101.670  -76.605  45.242  1
248721  101.684  -76.618  45.222  1
248722  101.703  -76.623  45.203  1
248723  101.725  -76.623  45.185  1
248724  101.746  -76.623  45.167  1
248725  101.766  -76.627  45.148  1
248726  101.782  -76.637  45.130  1
248727  101.799  -76.649  45.112  1
248728  101.815  -76.660  45.093  1
248729  101.831  -76.671  45.075  1
248730  101.848  -76.682  45.058  1
248731  101.864  -76.693  45.041  1
248732  101.881  -76.705  45.023  1
248733  101.897  -76.716  45.005  1
248734  101.903  -76.719  44.988  1
248735  101.896  -76.712  44.971  1
248736  101.889  -76.705  44.952  1
248737  101.894  -76.706  44.936  1
248738  101.902  -76.709  44.919  1
248739  101.909  -76.712  44.901  1
248740  101.917  -76.715  44.884  1
248741  101.925  -76.718  44.867  1
248742  101.933  -76.720  44.849  1
248743  101.940  -76.723  44.832  1
248744  101.948  -76.725  44.816  1
248745  101.956  -76.728  44.799  1
248746  101.977  -76.748  44.782  1
248747  101.999  -76.768  44.765  1
248748  102.021  -76.787  44.748  1
248749  102.043  -76.807  44.731  1
248750  102.065  -76.826  44.714  1
248751  102.087  -76.846  44.698  1
248752  102.108  -76.865  44.682  1
248753  102.130  -76.885  44.666  1
248754  102.152  -76.905  44.649  1
248755  102.174  -76.925  44.632  1
248756  102.191  -76.925  44.615  1
248757  102.209  -76.926  44.599  1
248758  102.227  -76.926  44.582  1
248759  102.244  -76.927  44.566  1
248760  102.261  -76.928  44.549  1
248761  102.279  -76.928  44.533  1
248762  102.301  -76.929  44.517  1
248763  102.324  -76.930  44.500  1
248764  102.347  -76.931  44.485  1
248765  102.370  -76.932  44.470  1
248766  102.393  -76.933  44.454  1
248767  102.416  -76.934  44.438  1
248768  102.439  -76.935  44.422  1
248769  102.462  -76.936  44.406  1
248770  102.485  -76.937  44.390  1
248771  102.508  -76.937  44.376  1
249082  92.747  -74.261  54.571  1
249083  92.778  -74.252  54.573  1
249084  92.807  -74.270  54.575  1
249085  92.837  -74.289  54.576  1
249086  92.866  -74.308  54.576  1
249087  92.896  -74.325  54.576  1
249088  92.927  -74.327  54.575  1
249089  92.958  -74.327  54.573  1
249090  92.989  -74.328  54.571  1
249091  93.020  -74.330  54.570  1
249092  93.052  -74.330  54.568  1
249093  93.083  -74.332  54.567  1
249094  93.114  -74.333  54.566  1
249095  93.145  -74.334  54.566  1
249096  93.176  -74.335  54.566  1
249097  93.207  -74.336  54.568  1
249098  93.238  -74.337  54.572  1
249099  93.269  -74.338  54.578  1
249100  93.300  -74.339  54.590  1
249101  93.331  -74.340  54.607  1
249102  93.362  -74.340  54.626  1
249103  93.389  -74.337  54.648  1
249104  93.412  -74.337  54.672  1
249105  93.436  -74.333  54.698  1
249106  93.461  -74.329  54.726  1
249107  93.483  -74.325  54.754  1
249108  93.504  -74.321  54.780  1
249109  93.525  -74.317  54.802  1
249110  93.547  -74.314  54.822  1
249111  93.568  -74.309  54.836  1
249112  93.589  -74.305  54.852  1
249113  93.611  -74.302  54.872  1
249114  93.632  -74.298  54.895  1
249115  93.653  -74.294  54.918  1
249116  93.675  -74.290  54.935  1
249117  93.696  -74.286  54.945  1
249118  93.718  -74.283  54.946  1
249119  93.739  -74.278  54.935  1
249120  93.760  -74.274  54.922  1
249121  93.782  -74.270  54.910  1
249122  93.803  -74.267  54.901  1
249123  93.825  -74.263  54.891  1
249124  93.846  -74.259  54.882  1
249125  93.867  -74.255  54.873  1
249126  93.889  -74.252  54.860  1
249127  93.911  -74.252  54.840  1
249128  93.934  -74.255  54.813  1
249129  93.958  -74.258  54.782  1
249130  93.981  -74.262  54.749  1
249131  94.004  -74.265  54.723  1
249132  94.028  -74.269  54.696  1
249133  94.051  -74.273  54.670  1
249134  94.074  -74.276  54.644  1
249135  94.112  -74.283  54.621  1
249136  94.134  -74.284  54.601  1
249137  94.152  -74.283  54.584  1
249138  94.170  -74.282  54.571  1
249139  94.191  -74.283  54.558  1
249140  94.215  -74.285  54.547  1
249141  94.237  -74.286  54.535  1
249142  94.257  -74.286  54.521  1
249143  94.276  -74.286  54.504  1
249144  94.296  -74.286  54.486  1
249145  94.316  -74.286  54.467  1
249146  94.336  -74.286  54.446  1
249147  94.356  -74.289  54.426  1
249148  94.379  -74.288  54.404  1
249149  94.403  -74.277  54.380  1
249150  94.427  -74.276  54.352  1
249151  94.452  -74.274  54.323  1
249152  94.476  -74.273  54.292  1
249153  94.500  -74.270  54.261  1
249154  94.525  -74.269  54.231  1
249155  94.549  -74.267  54.199  1
249156  94.573  -74.266  54.164  1
249157  94.595  -74.269  54.126  1
249158  94.611  -74.279  54.084  1
249159  94.628  -74.289  54.041  1
249160  94.644  -74.296  53.997  1
249161  94.660  -74.295  53.953  1
249162  94.675  -74.295  53.907  1
249163  94.690  -74.295  53.858  1
249164  94.705  -74.295  53.808  1
249165  94.723  -74.304  53.761  1
249166  94.743  -74.316  53.715  1
249167  94.763  -74.328  53.668  1
249168  94.782  -74.340  53.624  1
249169  94.802  -74.354  53.584  1
249170  94.812  -74.390  53.552  1
249171  94.822  -74.427  53.525  1
249172  94.834  -74.461  53.501  1
249173  94.856  -74.471  53.476  1
249174  94.892  -74.445  53.441  1
249175  94.927  -74.418  53.405  1
249176  94.963  -74.393  53.367  1
249177  94.998  -74.366  53.330  1
249178  95.031  -74.371  53.287  1
249179  95.063  -74.384  53.242  1
249180  95.096  -74.399  53.194  1
249181  95.128  -74.412  53.145  1
249182  95.161  -74.426  53.092  1
249183  95.194  -74.440  53.034  1
249184  95.226  -74.454  52.975  1
249185  95.259  -74.468  52.915  1
249186  95.291  -74.482  52.854  1
249187  95.324  -74.496  52.791  1
249188  95.356  -74.509  52.730  1
249189  95.395  -74.503  52.671  1
249190  95.435  -74.497  52.617  1
249191  95.457  -74.507  52.564  1
249192  95.481  -74.515  52.511  1
249193  95.510  -74.515  52.458  1
249194  95.539  -74.514  52.406  1
249195  95.567  -74.513  52.357  1
249196  95.596  -74.513  52.310  1
249197  95.625  -74.512  52.265  1
249198  95.654  -74.512  52.221  1
249199  95.683  -74.512  52.178  1
249200  95.711  -74.511  52.136  1
249201  95.741  -74.510  52.094  1
249202  95.769  -74.510  52.052  1
249203  95.798  -74.509  52.011  1
249204  95.827  -74.509  51.971  1
249205  95.856  -74.508  51.933  1
249206  95.885  -74.508  51.893  1
249207  95.912  -74.513  51.852  1
249208  95.939  -74.532  51.811  1
249209  95.965  -74.551  51.769  1
249210  95.990  -74.570  51.727  1
249211  96.016  -74.590  51.686  1
249212  96.041  -74.609  51.646  1
249213  96.067  -74.628  51.606  1
249214  96.092  -74.646  51.567  1
249215  96.118  -74.665  51.528  1
249216  96.147  -74.681  51.490  1
249217  96.184  -74.685  51.454  1
249218  96.221  -74.690  51.420  1
249219  96.258  -74.694  51.387  1
249220  96.259  -74.706  51.355  1
249221  96.253  -74.719  51.325  1
249222  96.247  -74.732  51.297  1
249223  96.242  -74.745  51.271  1
249224  96.259  -74.754  51.248  1
249225  96.425  -74.653  51.226  1
249226  96.451  -74.659  51.207  1
249227  96.477  -74.666  51.190  1
249228  96.503  -74.673  51.173  1
249229  96.529  -74.681  51.159  1
249230  96.555  -74.687  51.147  1
249231  96.580  -74.694  51.137  1
249232  96.605  -74.702  51.128  1
249233  96.630  -74.709  51.122  1
249234  96.655  -74.716  51.116  1
249235  96.680  -74.724  51.111  1
249236  96.705  -74.731  51.107  1
249237  96.730  -74.738  51.105  1
249238  96.755  -74.746  51.100  1
249239  96.780  -74.753  51.093  1
249240  96.805  -74.760  51.086  1
249241  96.832  -74.773  51.077  1
249242  96.860  -74.784  51.065  1
249243  96.887  -74.796  51.052  1
249244  96.925  -74.822  51.038  1
249245  96.956  -74.843  51.024  1
249246  96.962  -74.845  51.011  1
249247  96.968  -74.848  50.997  1
249248  96.975  -74.851  50.981  1
249249  96.986  -74.859  50.963  1
249250  97.000  -74.869  50.946  1
249251  97.013  -74.878  50.930  1
249252  97.026  -74.888  50.916  1
249253  97.039  -74.898  50.901  1
249254  97.049  -74.910  50.889  1
249255  97.058  -74.922  50.879  1
249256  97.065  -74.935  50.872  1
249257  97.073  -74.949  50.865  1
249258  97.081  -74.962  50.858  1
249259  97.100  -74.966  50.848  1
249260  97.139  -74.947  50.835  1
249261  97.172  -74.938  50.817  1
249262  97.206  -74.928  50.797  1
249263  97.231  -74.937  50.775  1
249264  97.254  -74.945  50.749  1
249265  97.279  -74.954  50.720  1
249266  97.302  -74.963  50.692  1
249267  97.326  -74.971  50.663  1
249268  97.350  -74.980  50.634  1
249269  97.387  -74.983  50.603  1
249270  97.424  -74.986  50.571  1
249271  97.461  -74.989  50.536  1
249272  97.496  -74.994  50.500  1
249273  97.528  -75.001  50.463  1
249274  97.559  -75.010  50.424  1
249275  97.591  -75.018  50.384  1
249276  97.623  -75.026  50.346  1
249277  97.654  -75.034  50.309  1
249278  97.685  -75.042  50.270  1
249279  97.717  -75.050  50.231  1
249280  97.748  -75.058  50.191  1
249281  97.782  -75.065  50.147  1
249282  97.816  -75.072  50.102  1
249283  97.852  -75.079  50.054  1
249284  97.885  -75.086  50.002  1
249285  97.917  -75.093  49.951  1
249286  97.948  -75.101  49.900  1
249287  97.979  -75.112  49.849  1
249288  98.009  -75.122  49.796  1
249289  98.040  -75.132  49.745  1
249290  98.070  -75.142  49.694  1
249291  98.100  -75.151  49.643  1
249292  98.131  -75.161  49.587  1
249293  98.161  -75.172  49.531  1
249294  98.192  -75.182  49.477  1
249295  98.222  -75.192  49.426  1
249296  98.253  -75.201  49.377  1
249297  98.284  -75.211  49.326  1
249298  98.314  -75.221  49.276  1
249299  98.349  -75.237  49.226  1
249300  98.391  -75.259  49.176  1
249301  98.434  -75.282  49.127  1
249302  98.459  -75.272  49.079  1
249303  98.479  -75.253  49.032  1
249304  98.499  -75.234  48.983  1
249305  98.518  -75.215  48.935  1
249306  98.538  -75.196  48.885  1
249307  98.564  -75.178  48.834  1
249308  98.577  -75.189  48.782  1
249309  98.605  -75.191  48.730  1
249310  98.633  -75.192  48.677  1
249311  98.661  -75.193  48.625  1
249312  98.689  -75.195  48.573  1
249313  98.715  -75.198  48.520  1
249314  98.742  -75.203  48.468  1
249315  98.770  -75.207  48.416  1
249316  98.796  -75.212  48.363  1
249317  98.823  -75.217  48.311  1
249318  98.850  -75.221  48.261  1
249319  98.877  -75.228  48.211  1
249320  98.903  -75.258  48.163  1
249321  98.928  -75.289  48.114  1
249322  98.952  -75.320  48.066  1
249323  98.975  -75.355  48.020  1
249324  98.998  -75.389  47.974  1
249325  99.020  -75.422  47.929  1
249326  99.043  -75.456  47.885  1
249327  99.066  -75.490  47.842  1
249328  99.088  -75.524  47.799  1
249329  99.114  -75.548  47.757  1
249330  99.151  -75.534  47.716  1
249331  99.189  -75.521  47.678  1
249332  99.220  -75.521  47.639  1
249333  99.251  -75.524  47.602  1
249334  99.282  -75.526  47.566  1
249335  99.312  -75.527  47.531  1
249336  99.343  -75.530  47.498  1
249337  99.374  -75.532  47.467  1
249338  99.398  -75.544  47.438  1
249339  99.418  -75.561  47.409  1
249340  99.440  -75.577  47.381  1
249341  99.465  -75.593  47.354  1
249342  99.489  -75.610  47.327  1
249343  99.512  -75.627  47.302  1
249344  99.537  -75.643  47.278  1
249345  99.561  -75.659  47.255  1
249346  99.586  -75.677  47.232  1
249347  99.612  -75.693  47.210  1
249348  99.638  -75.711  47.187  1
249349  99.664  -75.728  47.166  1
249350  99.690  -75.746  47.145  1
249351  99.716  -75.763  47.126  1
249352  99.743  -75.780  47.108  1
249353  99.767  -75.802  47.089  1
249354  99.789  -75.831  47.069  1
249355  99.811  -75.862  47.048  1
249356  99.833  -75.891  47.023  1
249357  99.855  -75.921  46.997  1
249358  99.880  -75.946  46.972  1
249359  99.918  -75.947  46.945  1
249360  99.947  -75.958  46.917  1
249361  99.977  -75.968  46.888  1
249362  100.006  -75.978  46.856  1
249363  100.036  -75.988  46.825  1
249364  100.065  -75.999  46.794  1
249365  100.094  -76.009  46.762  1
249366  100.123  -76.019  46.730  1
249367  100.153  -76.029  46.697  1
249368  100.182  -76.040  46.663  1
249369  100.211  -76.050  46.630  1
249370  100.237  -76.062  46.597  1
249371  100.266  -76.063  46.566  1
249372  100.300  -76.053  46.534  1
249373  100.332  -76.043  46.503  1
249374  100.364  -76.034  46.471  1
249375  100.396  -76.024  46.438  1
249376  100.428  -76.014  46.406  1
249377  100.461  -76.004  46.374  1
249378  100.490  -76.015  46.344  1
249379  100.517  -76.044  46.312  1
249380  100.544  -76.074  46.280  1
249381  100.571  -76.104  46.247  1
249382  100.598  -76.133  46.214  1
249383  100.625  -76.163  46.181  1
249384  100.650  -76.194  46.148  1
249385  100.674  -76.227  46.116  1
249386  100.697  -76.260  46.083  1
249387  100.720  -76.294  46.050  1
249388  100.743  -76.326  46.018  1
249389  100.766  -76.360  45.987  1
249390  100.788  -76.370  45.956  1
249391  100.805  -76.388  45.928  1
249392  100.814  -76.421  45.900  1
249393  100.820  -76.431  45.872  1
249394  100.827  -76.433  45.845  1
249395  100.833  -76.436  45.817  1
249396  100.856  -76.442  45.790  1
249397  100.898  -76.453  45.765  1
249398  100.939  -76.464  45.741  1
249399  100.981  -76.476  45.716  1
249400  101.022  -76.487  45.692  1
249401  101.064  -76.498  45.669  1
249402  101.117  -76.515  45.645  1
249403  101.167  -76.519  45.621  1
249404  101.211  -76.514  45.598  1
249405  101.256  -76.508  45.574  1
249406  101.301  -76.502  45.551  1
249407  101.345  -76.496  45.529  1
249408  101.390  -76.491  45.506  1
249409  101.435  -76.485  45.484  1
249410  101.480  -76.480  45.462  1
249411  101.515  -76.481  45.440  1
249412  101.539  -76.490  45.418  1
249413  101.563  -76.499  45.398  1
249414  101.592  -76.510  45.377  1
249415  101.609  -76.521  45.356  1
249416  101.624  -76.533  45.336  1
249417  101.639  -76.546  45.315  1
249418  101.653  -76.558  45.294  1
249419  101.668  -76.570  45.274  1
249420  101.683  -76.582  45.254  1
249421  101.698  -76.594  45.235  1
249422  101.717  -76.599  45.215  1
249423  101.739  -76.599  45.196  1
249424  101.760  -76.599  45.177  1
249425  101.778  -76.606  45.158  1
249426  101.794  -76.618  45.139  1
249427  101.811  -76.629  45.121  1
249428  101.827  -76.640  45.103  1
249429  101.843  -76.651  45.084  1
249430  101.859  -76.662  45.066  1
249431  101.876  -76.674  45.048  1
249432  101.892  -76.684  45.031  1
249433  101.890  -76.681  45.013  1
249434  101.883  -76.674  44.994  1
249435  101.876  -76.668  44.977  1
249436  101.883  -76.670  44.960  1
249437  101.890  -76.672  44.942  1
249438  101.898  -76.675  44.926  1
249439  101.906  -76.678  44.908  1
249440  101.913  -76.680  44.891  1
249441  101.921  -76.683  44.873  1
249442  101.928  -76.686  44.856  1
249443  101.936  -76.689  44.839  1
249444  101.944  -76.692  44.822  1
249445  101.956  -76.699  44.805  1
249446  101.977  -76.718  44.788  1
249447  101.999  -76.738  44.771  1
249448  102.021  -76.758  44.754  1
249449  102.043  -76.777  44.737  1
249450  102.065  -76.797  44.720  1
249451  102.087  -76.817  44.704  1
249452  102.108  -76.836  44.687  1
249453  102.130  -76.856  44.671  1
249454  102.152  -76.875  44.654  1
249455  102.172  -76.884  44.637  1
249456  102.189  -76.885  44.620  1
249457  102.206  -76.886  44.603  1
249458  102.224  -76.886  44.587  1
249459  102.241  -76.887  44.571  1
249460  102.259  -76.887  44.555  1
249461  102.276  -76.887  44.538  1
249462  102.299  -76.889  44.522  1
249463  102.322  -76.890  44.506  1
249464  102.345  -76.890  44.489  1
249465  102.368  -76.892  44.474  1
249466  102.391  -76.893  44.459  1
249467  102.414  -76.893  44.443  1
249784  92.779  -74.225  54.580  1
249785  92.808  -74.244  54.582  1
249786  92.838  -74.263  54.583  1
249787  92.868  -74.281  54.583  1
249788  92.898  -74.300  54.583  1
249789  92.928  -74.305  54.583  1
249790  92.959  -74.306  54.581  1
249791  92.990  -74.307  54.579  1
249792  93.021  -74.308  54.578  1
249793  93.053  -74.309  54.576  1
249794  93.083  -74.310  54.574  1
249795  93.115  -74.311  54.573  1
249796  93.146  -74.312  54.573  1
249797  93.177  -74.314  54.573  1
249798  93.208  -74.314  54.574  1
249799  93.239  -74.316  54.576  1
249800  93.270  -74.317  54.582  1
249801  93.301  -74.318  54.592  1
249802  93.332  -74.319  54.606  1
249803  93.364  -74.305  54.625  1
249804  93.385  -74.313  54.646  1
249805  93.408  -74.314  54.670  1
249806  93.432  -74.310  54.696  1
249807  93.457  -74.306  54.724  1
249808  93.481  -74.302  54.753  1
249809  93.505  -74.298  54.779  1
249810  93.527  -74.294  54.801  1
249811  93.549  -74.289  54.820  1
249812  93.570  -74.286  54.842  1
249813  93.591  -74.282  54.862  1
249814  93.613  -74.278  54.881  1
249815  93.634  -74.274  54.903  1
249816  93.655  -74.270  54.925  1
249817  93.677  -74.267  54.939  1
249818  93.698  -74.263  54.945  1
249819  93.719  -74.259  54.947  1
249820  93.741  -74.255  54.949  1
249821  93.762  -74.251  54.943  1
249822  93.784  -74.247  54.932  1
249823  93.805  -74.243  54.923  1
249824  93.827  -74.239  54.908  1
249825  93.848  -74.236  54.893  1
249826  93.869  -74.232  54.878  1
249827  93.891  -74.229  54.860  1
249828  93.912  -74.230  54.840  1
249829  93.933  -74.230  54.816  1
249830  93.957  -74.233  54.787  1
249831  93.980  -74.237  54.753  1
249832  94.004  -74.241  54.724  1
249833  94.027  -74.245  54.696  1
249834  94.051  -74.248  54.668  1
249835  94.074  -74.252  54.639  1
249836  94.115  -74.260  54.616  1
249837  94.141  -74.262  54.597  1
249838  94.159  -74.261  54.581  1
249839  94.177  -74.261  54.568  1
249840  94.195  -74.259  54.558  1
249841  94.213  -74.258  54.548  1
249842  94.237  -74.261  54.538  1
249843  94.257  -74.261  54.525  1
249844  94.277  -74.261  54.508  1
249845  94.297  -74.261  54.489  1
249846  94.317  -74.263  54.469  1
249847  94.337  -74.266  54.447  1
249848  94.358  -74.270  54.425  1
249849  94.382  -74.267  54.402  1
249850  94.407  -74.258  54.378  1
249851  94.430  -74.243  54.350  1
249852  94.454  -74.242  54.321  1
249853  94.478  -74.240  54.291  1
249854  94.503  -74.238  54.260  1
249855  94.527  -74.236  54.229  1
249856  94.551  -74.235  54.196  1
249857  94.576  -74.233  54.161  1
249858  94.599  -74.234  54.122  1
249859  94.615  -74.244  54.077  1
249860  94.632  -74.254  54.033  1
249861  94.648  -74.259  53.987  1
249862  94.663  -74.258  53.941  1
249863  94.678  -74.258  53.895  1
249864  94.693  -74.258  53.846  1
249865  94.708  -74.258  53.797  1
249866  94.725  -74.261  53.749  1
249867  94.745  -74.273  53.702  1
249868  94.765  -74.286  53.656  1
249869  94.784  -74.298  53.611  1
249870  94.801  -74.319  53.570  1
249871  94.811  -74.355  53.538  1
249872  94.822  -74.392  53.512  1
249873  94.836  -74.423  53.489  1
249874  94.859  -74.428  53.465  1
249875  94.895  -74.402  53.431  1
249876  94.930  -74.376  53.395  1
249877  94.966  -74.349  53.357  1
249878  95.000  -74.342  53.318  1
249879  95.032  -74.345  53.275  1
249880  95.065  -74.354  53.228  1
249881  95.097  -74.368  53.179  1
249882  95.130  -74.382  53.129  1
249883  95.162  -74.396  53.076  1
249884  95.195  -74.409  53.020  1
249885  95.228  -74.424  52.962  1
249886  95.260  -74.437  52.904  1
249887  95.293  -74.451  52.843  1
249888  95.325  -74.465  52.782  1
249889  95.360  -74.471  52.723  1
249890  95.399  -74.465  52.666  1
249891  95.438  -74.458  52.611  1
249892  95.468  -74.461  52.557  1
249893  95.491  -74.471  52.505  1
249894  95.520  -74.470  52.452  1
249895  95.549  -74.469  52.403  1
249896  95.578  -74.469  52.355  1
249897  95.606  -74.468  52.308  1
249898  95.635  -74.468  52.265  1
249899  95.664  -74.468  52.222  1
249900  95.693  -74.467  52.180  1
249901  95.722  -74.467  52.138  1
249902  95.751  -74.466  52.096  1
249903  95.779  -74.465  52.055  1
249904  95.808  -74.465  52.014  1
249905  95.837  -74.465  51.974  1
249906  95.867  -74.471  51.936  1
249907  95.895  -74.477  51.897  1
249908  95.905  -74.473  51.857  1
249909  95.928  -74.493  51.817  1
249910  95.956  -74.512  51.774  1
249911  95.988  -74.532  51.731  1
249912  96.020  -74.552  51.689  1
249913  96.052  -74.572  51.648  1
249914  96.085  -74.592  51.609  1
249915  96.114  -74.611  51.569  1
249916  96.139  -74.631  51.529  1
249917  96.165  -74.650  51.491  1
249918  96.191  -74.668  51.456  1
249919  96.222  -74.681  51.421  1
249920  96.259  -74.685  51.387  1
249921  96.257  -74.697  51.354  1
249922  96.252  -74.710  51.324  1
249923  96.246  -74.723  51.296  1
249924  96.315  -74.679  51.269  1
249925  96.390  -74.631  51.245  1
249926  96.428  -74.627  51.223  1
249927  96.452  -74.634  51.203  1
249928  96.477  -74.642  51.185  1
249929  96.502  -74.649  51.168  1
249930  96.527  -74.656  51.152  1
249931  96.552  -74.664  51.139  1
249932  96.577  -74.671  51.127  1
249933  96.602  -74.678  51.117  1
249934  96.627  -74.686  51.110  1
249935  96.652  -74.693  51.104  1
249936  96.677  -74.700  51.098  1
249937  96.702  -74.708  51.094  1
249938  96.727  -74.715  51.091  1
249939  96.752  -74.722  51.088  1
249940  96.777  -74.729  51.084  1
249941  96.802  -74.737  51.080  1
249942  96.830  -74.752  51.074  1
249943  96.859  -74.766  51.064  1
249944  96.884  -74.774  51.053  1
249945  96.911  -74.784  51.040  1
249946  96.949  -74.809  51.029  1
249947  96.968  -74.822  51.017  1
249948  96.974  -74.825  51.003  1
249949  96.980  -74.828  50.988  1
249950  96.994  -74.837  50.969  1
249951  97.007  -74.847  50.953  1
249952  97.020  -74.856  50.937  1
249953  97.033  -74.866  50.923  1
249954  97.046  -74.875  50.909  1
249955  97.059  -74.885  50.898  1
249956  97.068  -74.898  50.889  1
249957  97.076  -74.911  50.882  1
249958  97.083  -74.924  50.877  1
249959  97.091  -74.938  50.871  1
249960  97.100  -74.943  50.862  1
249961  97.143  -74.918  50.848  1
249962  97.176  -74.909  50.831  1
249963  97.207  -74.905  50.811  1
249964  97.231  -74.914  50.787  1
249965  97.255  -74.922  50.761  1
249966  97.279  -74.931  50.732  1
249967  97.303  -74.940  50.704  1
249968  97.330  -74.947  50.677  1
249969  97.368  -74.950  50.646  1
249970  97.405  -74.953  50.616  1
249971  97.442  -74.956  50.583  1
249972  97.479  -74.958  50.549  1
249973  97.516  -74.962  50.515  1
249974  97.547  -74.969  50.479  1
249975  97.579  -74.978  50.441  1
249976  97.610  -74.986  50.403  1
249977  97.642  -74.994  50.364  1
249978  97.673  -75.002  50.326  1
249979  97.705  -75.010  50.288  1
249980  97.736  -75.018  50.249  1
249981  97.768  -75.026  50.207  1
249982  97.800  -75.035  50.163  1
249983  97.831  -75.042  50.116  1
249984  97.858  -75.052  50.067  1
249985  97.890  -75.059  50.014  1
249986  97.923  -75.066  49.961  1
249987  97.956  -75.074  49.908  1
249988  97.986  -75.084  49.855  1
249989  98.017  -75.094  49.802  1
249990  98.048  -75.104  49.753  1
249991  98.078  -75.113  49.703  1
249992  98.108  -75.123  49.650  1
249993  98.139  -75.133  49.594  1
249994  98.170  -75.143  49.537  1
249995  98.201  -75.153  49.482  1
249996  98.231  -75.163  49.430  1
249997  98.262  -75.173  49.380  1
249998  98.292  -75.184  49.330  1
249999  98.323  -75.197  49.280  1
250000  98.360  -75.217  49.230  1
250001  98.401  -75.242  49.180  1
250002  98.444  -75.264  49.131  1
250003  98.465  -75.249  49.082  1
250004  98.485  -75.229  49.034  1
250005  98.505  -75.210  48.986  1
250006  98.525  -75.192  48.937  1
250007  98.545  -75.173  48.888  1
250008  98.565  -75.151  48.837  1
250009  98.591  -75.153  48.786  1
250010  98.618  -75.157  48.734  1
250011  98.645  -75.162  48.681  1
250012  98.671  -75.167  48.628  1
250013  98.699  -75.171  48.575  1
250014  98.725  -75.176  48.522  1
250015  98.752  -75.180  48.469  1
250016  98.779  -75.185  48.416  1
250017  98.806  -75.189  48.363  1
250018  98.834  -75.194  48.311  1
250019  98.860  -75.198  48.259  1
250020  98.886  -75.217  48.209  1
250021  98.912  -75.247  48.160  1
250022  98.937  -75.277  48.111  1
250023  98.962  -75.308  48.063  1
250024  98.988  -75.338  48.017  1
250025  99.012  -75.370  47.971  1
250026  99.034  -75.404  47.926  1
250027  99.057  -75.438  47.882  1
250028  99.080  -75.471  47.838  1
250029  99.103  -75.503  47.796  1
250030  99.141  -75.489  47.753  1
250031  99.174  -75.486  47.712  1
250032  99.205  -75.487  47.672  1
250033  99.235  -75.489  47.633  1
250034  99.267  -75.492  47.594  1
250035  99.297  -75.494  47.558  1
250036  99.327  -75.498  47.523  1
250037  99.357  -75.502  47.489  1
250038  99.387  -75.506  47.458  1
250039  99.412  -75.514  47.428  1
250040  99.433  -75.530  47.399  1
250041  99.453  -75.546  47.371  1
250042  99.478  -75.563  47.344  1
250043  99.501  -75.580  47.318  1
250044  99.525  -75.596  47.293  1
250045  99.550  -75.612  47.269  1
250046  99.574  -75.629  47.246  1
250047  99.600  -75.646  47.224  1
250048  99.627  -75.664  47.201  1
250049  99.652  -75.681  47.179  1
250050  99.679  -75.698  47.158  1
250051  99.705  -75.715  47.137  1
250052  99.731  -75.733  47.118  1
250053  99.757  -75.750  47.100  1
250054  99.782  -75.771  47.081  1
250055  99.804  -75.801  47.062  1
250056  99.826  -75.831  47.042  1
250057  99.848  -75.860  47.017  1
250058  99.870  -75.890  46.992  1
250059  99.892  -75.919  46.967  1
250060  99.918  -75.940  46.941  1
250061  99.947  -75.950  46.913  1
250062  99.978  -75.959  46.883  1
250063  100.007  -75.966  46.852  1
250064  100.037  -75.975  46.820  1
250065  100.068  -75.983  46.789  1
250066  100.098  -75.991  46.756  1
250067  100.128  -75.999  46.723  1
250068  100.158  -76.007  46.690  1
250069  100.188  -76.015  46.657  1
250070  100.218  -76.023  46.623  1
250071  100.249  -76.032  46.590  1
250072  100.277  -76.050  46.557  1
250073  100.309  -76.041  46.526  1
250074  100.341  -76.031  46.495  1
250075  100.373  -76.021  46.463  1
250076  100.405  -76.011  46.430  1
250077  100.437  -76.002  46.398  1
250078  100.470  -75.992  46.367  1
250079  100.499  -76.005  46.338  1
250080  100.526  -76.035  46.306  1
250081  100.553  -76.063  46.274  1
250082  100.580  -76.093  46.241  1
250083  100.607  -76.122  46.208  1
250084  100.634  -76.152  46.175  1
250085  100.661  -76.182  46.142  1
250086  100.688  -76.211  46.109  1
250087  100.715  -76.241  46.076  1
250088  100.741  -76.271  46.043  1
250089  100.764  -76.304  46.012  1
250090  100.787  -76.338  45.981  1
250091  100.810  -76.361  45.950  1
250092  100.824  -76.383  45.923  1
250093  100.831  -76.395  45.894  1
250094  100.838  -76.398  45.866  1
250095  100.844  -76.400  45.839  1
250096  100.850  -76.402  45.811  1
250097  100.882  -76.411  45.785  1
250098  100.923  -76.422  45.760  1
250099  100.965  -76.433  45.735  1
250100  101.006  -76.445  45.711  1
250101  101.048  -76.456  45.687  1
250102  101.090  -76.467  45.663  1
250103  101.131  -76.478  45.640  1
250104  101.184  -76.495  45.615  1
250105  101.237  -76.505  45.592  1
250106  101.281  -76.499  45.568  1
250107  101.326  -76.494  45.546  1
250108  101.371  -76.488  45.523  1
250109  101.416  -76.483  45.501  1
250110  101.461  -76.477  45.478  1
250111  101.505  -76.471  45.456  1
250112  101.546  -76.469  45.434  1
250113  101.570  -76.478  45.413  1
250114  101.595  -76.487  45.391  1
250115  101.622  -76.498  45.370  1
250116  101.638  -76.510  45.350  1
250117  101.653  -76.522  45.329  1
250118  101.667  -76.533  45.309  1
250119  101.682  -76.546  45.287  1
250120  101.697  -76.558  45.267  1
250121  101.711  -76.570  45.247  1
250122  101.731  -76.574  45.227  1
250123  101.752  -76.574  45.207  1
250124  101.773  -76.575  45.188  1
250130  101.872  -76.643  45.075  1
250131  101.883  -76.650  45.056  1
250132  101.876  -76.643  45.038  1
250133  101.869  -76.636  45.020  1
250134  101.864  -76.630  45.003  1
250135  101.871  -76.633  44.984  1
250136  101.879  -76.636  44.967  1
250137  101.887  -76.638  44.949  1
250138  101.894  -76.641  44.931  1
250139  101.902  -76.644  44.914  1
250140  101.909  -76.646  44.897  1
250141  101.917  -76.649  44.879  1
250142  101.924  -76.652  44.862  1
250143  101.933  -76.655  44.845  1
250144  101.940  -76.658  44.828  1
250145  101.956  -76.670  44.811  1
250146  101.977  -76.689  44.793  1
250147  101.999  -76.708  44.777  1
250148  102.021  -76.728  44.760  1
250149  102.043  -76.748  44.743  1
250150  102.065  -76.768  44.725  1
250151  102.087  -76.787  44.709  1
250152  102.108  -76.807  44.692  1
250153  102.130  -76.827  44.676  1
250154  102.152  -76.843  44.659  1
250155  102.169  -76.844  44.642  1
250156  102.186  -76.845  44.625  1
250157  102.204  -76.846  44.609  1
250158  102.222  -76.846  44.592  1
250159  102.239  -76.846  44.576  1
250160  102.256  -76.847  44.560  1
250161  102.274  -76.847  44.544  1
250162  102.296  -76.849  44.528  1
250488  92.869  -74.255  54.591  1
250489  92.899  -74.273  54.590  1
250490  92.929  -74.283  54.591  1
250491  92.960  -74.284  54.590  1
250492  92.991  -74.286  54.588  1
250493  93.022  -74.286  54.586  1
250494  93.053  -74.288  54.584  1
250495  93.084  -74.289  54.582  1
250496  93.116  -74.290  54.581  1
250497  93.146  -74.291  54.580  1
250498  93.178  -74.292  54.580  1
250499  93.209  -74.293  54.580  1
250500  93.240  -74.294  54.583  1
250501  93.271  -74.295  54.587  1
250502  93.302  -74.296  54.595  1
250503  93.335  -74.281  54.607  1
250504  93.360  -74.280  54.624  1
250505  93.381  -74.289  54.644  1
250506  93.404  -74.291  54.666  1
250507  93.428  -74.286  54.692  1
250508  93.452  -74.283  54.721  1
250509  93.477  -74.279  54.749  1
250510  93.501  -74.274  54.775  1
250511  93.525  -74.270  54.797  1
250512  93.550  -74.266  54.817  1
250513  93.572  -74.262  54.844  1
250514  93.593  -74.258  54.866  1
250515  93.615  -74.255  54.884  1
250516  93.636  -74.251  54.904  1
250517  93.657  -74.247  54.925  1
250518  93.679  -74.243  54.937  1
250519  93.700  -74.239  54.945  1
250520  93.721  -74.235  54.953  1
250521  93.743  -74.231  54.961  1
250522  93.764  -74.227  54.961  1
250523  93.785  -74.223  54.954  1
250524  93.807  -74.220  54.945  1
250525  93.828  -74.216  54.928  1
250526  93.850  -74.212  54.909  1
250527  93.871  -74.208  54.888  1
250528  93.893  -74.208  54.864  1
250529  93.914  -74.208  54.841  1
250530  93.935  -74.209  54.815  1
250531  93.957  -74.210  54.786  1
250532  93.980  -74.213  54.754  1
250533  94.003  -74.216  54.723  1
250534  94.027  -74.220  54.694  1
250535  94.050  -74.223  54.665  1
250536  94.073  -74.226  54.636  1
250537  94.118  -74.236  54.611  1
250538  94.149  -74.240  54.590  1
250539  94.167  -74.239  54.574  1
250540  94.185  -74.239  54.565  1
250541  94.202  -74.237  54.558  1
250542  94.220  -74.236  54.549  1
250543  94.238  -74.236  54.538  1
250544  94.258  -74.236  54.526  1
250545  94.278  -74.237  54.507  1
250546  94.298  -74.240  54.488  1
250547  94.319  -74.243  54.468  1
250548  94.339  -74.246  54.445  1
250549  94.359  -74.250  54.422  1
250550  94.384  -74.245  54.399  1
250551  94.410  -74.240  54.375  1
250552  94.433  -74.228  54.349  1
250553  94.457  -74.213  54.319  1
250554  94.481  -74.208  54.289  1
250555  94.505  -74.205  54.258  1
250556  94.530  -74.204  54.225  1
250557  94.554  -74.202  54.192  1
250558  94.578  -74.201  54.155  1
250559  94.603  -74.199  54.114  1
250560  94.619  -74.209  54.068  1
250561  94.636  -74.219  54.022  1
250562  94.652  -74.222  53.975  1
250563  94.667  -74.221  53.927  1
250564  94.682  -74.221  53.881  1
250565  94.697  -74.220  53.832  1
250566  94.712  -74.220  53.783  1
250567  94.728  -74.220  53.735  1
250568  94.747  -74.231  53.688  1
250569  94.767  -74.244  53.642  1
250570  94.786  -74.256  53.597  1
250571  94.800  -74.285  53.556  1
250572  94.810  -74.321  53.524  1
250573  94.823  -74.353  53.500  1
250574  94.837  -74.384  53.478  1
250575  94.862  -74.386  53.455  1
250576  94.898  -74.359  53.421  1
250577  94.934  -74.333  53.385  1
250578  94.969  -74.314  53.348  1
250579  95.001  -74.317  53.308  1
250580  95.034  -74.321  53.262  1
250581  95.066  -74.324  53.214  1
250582  95.099  -74.337  53.164  1
250583  95.131  -74.351  53.113  1
250584  95.164  -74.365  53.059  1
250585  95.196  -74.379  53.005  1
250586  95.229  -74.393  52.949  1
250587  95.261  -74.407  52.894  1
250588  95.294  -74.421  52.833  1
250589  95.326  -74.434  52.773  1
250590  95.364  -74.433  52.715  1
250591  95.403  -74.427  52.658  1
250592  95.442  -74.420  52.603  1
250593  95.479  -74.415  52.550  1
250594  95.501  -74.426  52.497  1
250595  95.530  -74.426  52.447  1
250596  95.559  -74.425  52.399  1
250597  95.588  -74.424  52.352  1
250598  95.616  -74.424  52.306  1
250599  95.645  -74.424  52.264  1
250600  95.674  -74.424  52.222  1
250601  95.703  -74.423  52.181  1
250602  95.732  -74.422  52.139  1
250603  95.761  -74.422  52.098  1
250604  95.790  -74.424  52.058  1
250605  95.819  -74.430  52.017  1
250606  95.848  -74.436  51.976  1
250607  95.878  -74.443  51.937  1
250608  95.892  -74.442  51.898  1
250609  95.902  -74.438  51.858  1
250610  95.922  -74.452  51.819  1
250611  95.946  -74.472  51.777  1
250612  95.970  -74.492  51.734  1
250613  96.001  -74.512  51.692  1
250614  96.033  -74.531  51.650  1
250615  96.065  -74.551  51.610  1
250616  96.097  -74.571  51.570  1
250617  96.129  -74.591  51.530  1
250618  96.161  -74.611  51.492  1
250619  96.193  -74.631  51.456  1
250620  96.225  -74.650  51.421  1
250621  96.259  -74.668  51.388  1
250622  96.285  -74.654  51.355  1
250623  96.311  -74.637  51.324  1
250624  96.336  -74.618  51.296  1
250625  96.363  -74.601  51.269  1
250626  96.389  -74.584  51.244  1
250627  96.423  -74.602  51.221  1
250628  96.450  -74.611  51.200  1
250629  96.474  -74.618  51.181  1
250630  96.500  -74.625  51.163  1
250631  96.524  -74.633  51.145  1
250632  96.549  -74.640  51.131  1
250633  96.574  -74.647  51.119  1
250634  96.599  -74.655  51.108  1
250635  96.624  -74.662  51.099  1
250636  96.649  -74.669  51.092  1
250637  96.674  -74.677  51.086  1
250638  96.699  -74.684  51.081  1
250639  96.724  -74.691  51.078  1
250640  96.749  -74.699  51.075  1
250641  96.774  -74.706  51.073  1
250642  96.799  -74.713  51.071  1
250643  96.829  -74.731  51.067  1
250644  96.858  -74.747  51.061  1
250645  96.884  -74.755  51.052  1
250646  96.909  -74.763  51.040  1
250647  96.936  -74.772  51.030  1
250648  96.973  -74.798  51.020  1
250649  96.980  -74.801  51.008  1
250650  96.987  -74.805  50.995  1
250651  97.000  -74.815  50.976  1
250652  97.013  -74.825  50.960  1
250653  97.026  -74.834  50.944  1
250654  97.039  -74.844  50.930  1
250655  97.052  -74.853  50.917  1
250656  97.066  -74.863  50.908  1
250657  97.078  -74.874  50.900  1
250658  97.086  -74.887  50.895  1
250659  97.094  -74.897  50.889  1
250660  97.102  -74.903  50.883  1
250661  97.110  -74.908  50.876  1
250662  97.146  -74.889  50.862  1
250663  97.180  -74.880  50.843  1
250664  97.208  -74.882  50.821  1
250665  97.232  -74.891  50.797  1
250666  97.256  -74.900  50.771  1
250667  97.280  -74.908  50.742  1
250668  97.311  -74.913  50.715  1
250669  97.349  -74.916  50.687  1
250670  97.385  -74.919  50.657  1
250671  97.423  -74.922  50.627  1
250672  97.460  -74.925  50.596  1
250673  97.497  -74.928  50.563  1
250674  97.534  -74.931  50.530  1
250675  97.567  -74.938  50.495  1
250676  97.598  -74.946  50.458  1
250677  97.630  -74.954  50.419  1
250678  97.661  -74.962  50.381  1
250679  97.693  -74.970  50.341  1
250680  97.724  -74.979  50.301  1
250681  97.756  -74.986  50.260  1
250682  97.788  -74.994  50.216  1
250683  97.819  -75.003  50.171  1
250684  97.845  -75.013  50.124  1
250685  97.868  -75.023  50.074  1
250686  97.896  -75.032  50.020  1
250687  97.929  -75.039  49.965  1
250688  97.964  -75.045  49.912  1
250689  97.995  -75.055  49.859  1
250690  98.025  -75.065  49.808  1
250691  98.056  -75.075  49.760  1
250692  98.087  -75.085  49.710  1
250693  98.117  -75.095  49.657  1
250694  98.148  -75.104  49.600  1
250695  98.178  -75.114  49.542  1
250696  98.209  -75.124  49.486  1
250697  98.239  -75.135  49.433  1
250698  98.271  -75.148  49.382  1
250699  98.302  -75.161  49.331  1
250700  98.333  -75.174  49.281  1
250701  98.371  -75.196  49.231  1
250702  98.413  -75.221  49.182  1
250703  98.452  -75.242  49.134  1
250704  98.472  -75.220  49.086  1
250705  98.492  -75.198  49.038  1
250706  98.512  -75.176  48.989  1
250707  98.531  -75.154  48.939  1
250708  98.551  -75.132  48.889  1
250709  98.573  -75.119  48.839  1
250710  98.600  -75.130  48.787  1
250711  98.628  -75.135  48.735  1
250712  98.655  -75.139  48.682  1
250713  98.681  -75.144  48.629  1
250714  98.709  -75.148  48.575  1
250715  98.735  -75.153  48.522  1
250716  98.763  -75.157  48.469  1
250717  98.789  -75.161  48.416  1
250718  98.816  -75.166  48.362  1
250719  98.843  -75.170  48.310  1
250720  98.870  -75.175  48.258  1
250721  98.896  -75.204  48.208  1
250722  98.921  -75.235  48.158  1
250723  98.946  -75.265  48.109  1
250724  98.972  -75.295  48.060  1
250725  98.997  -75.326  48.014  1
250726  99.023  -75.356  47.969  1
250727  99.048  -75.386  47.924  1
250728  99.072  -75.419  47.879  1
250729  99.094  -75.453  47.835  1
250730  99.128  -75.449  47.793  1
250731  99.159  -75.452  47.750  1
250732  99.189  -75.455  47.709  1
250733  99.219  -75.458  47.668  1
250734  99.250  -75.462  47.627  1
250735  99.279  -75.467  47.588  1
250736  99.309  -75.471  47.550  1
250737  99.340  -75.474  47.515  1
250738  99.369  -75.479  47.480  1
250739  99.398  -75.484  47.448  1
250740  99.422  -75.493  47.418  1
250741  99.447  -75.501  47.390  1
250742  99.468  -75.516  47.362  1
250743  99.490  -75.533  47.335  1
250744  99.514  -75.549  47.309  1
250745  99.539  -75.565  47.284  1
250746  99.563  -75.582  47.261  1
250747  99.589  -75.599  47.238  1
250748  99.615  -75.617  47.216  1
250749  99.641  -75.634  47.193  1
250750  99.667  -75.651  47.172  1
250751  99.693  -75.668  47.151  1
250752  99.719  -75.686  47.130  1
250753  99.746  -75.703  47.111  1
250754  99.771  -75.720  47.092  1
250755  99.796  -75.740  47.073  1
250756  99.819  -75.770  47.055  1
250757  99.841  -75.800  47.035  1
250758  99.863  -75.829  47.011  1
250759  99.885  -75.859  46.987  1
250760  99.908  -75.887  46.962  1
250761  99.931  -75.897  46.937  1
250762  99.961  -75.905  46.908  1
250763  99.991  -75.913  46.879  1
250764  100.021  -75.922  46.848  1
250765  100.051  -75.930  46.815  1
250766  100.081  -75.938  46.783  1
250767  100.112  -75.946  46.750  1
250768  100.142  -75.954  46.717  1
250769  100.172  -75.962  46.683  1
250770  100.202  -75.970  46.650  1
250771  100.232  -75.978  46.616  1
250772  100.261  -75.994  46.582  1
250773  100.289  -76.016  46.550  1
250774  100.318  -76.028  46.518  1
250775  100.350  -76.018  46.487  1
250776  100.382  -76.009  46.455  1
250777  100.414  -75.999  46.423  1
250778  100.446  -75.989  46.391  1
250779  100.479  -75.979  46.361  1
250780  100.507  -75.994  46.331  1
250781  100.535  -76.024  46.299  1
250782  100.562  -76.053  46.267  1
250783  100.588  -76.083  46.235  1
250784  100.616  -76.112  46.203  1
250785  100.643  -76.141  46.169  1
250786  100.670  -76.171  46.136  1
250787  100.697  -76.201  46.104  1
250788  100.724  -76.230  46.071  1
250789  100.751  -76.260  46.039  1
250790  100.778  -76.289  46.008  1
250791  100.805  -76.319  45.976  1
250792  100.831  -76.349  45.945  1
250793  100.842  -76.360  45.917  1
250794  100.848  -76.362  45.889  1
250795  100.855  -76.364  45.861  1
250796  100.861  -76.367  45.834  1
250797  100.868  -76.369  45.807  1
250798  100.908  -76.379  45.780  1
250799  100.950  -76.391  45.755  1
250800  100.991  -76.402  45.730  1
250801  101.032  -76.414  45.706  1
250802  101.074  -76.424  45.681  1
250803  101.115  -76.436  45.657  1
250804  101.157  -76.447  45.634  1
250805  101.198  -76.458  45.610  1
250806  101.252  -76.475  45.586  1
250807  101.307  -76.491  45.562  1
250808  101.352  -76.486  45.540  1
250809  101.397  -76.480  45.518  1
250810  101.442  -76.474  45.495  1
250811  101.486  -76.468  45.472  1
250812  101.531  -76.463  45.449  1
250813  101.575  -76.457  45.428  1
250814  101.601  -76.466  45.407  1
250815  101.625  -76.475  45.386  1
250816  101.652  -76.486  45.364  1
250817  101.666  -76.498  45.343  1
250818  101.681  -76.510  45.322  1
250819  101.695  -76.522  45.302  1
250820  101.710  -76.534  45.281  1
250821  101.725  -76.546  45.260  1
250822  101.745  -76.549  45.239  1
250823  101.766  -76.549  45.219  1
250824  101.785  -76.555  45.199  1
250825  101.802  -76.567  45.179  1
250840  101.905  -76.612  44.903  1
250841  101.913  -76.615  44.886  1
251189  92.870  -74.229  54.598  1
251190  92.900  -74.248  54.597  1
251191  92.930  -74.262  54.598  1
251192  92.961  -74.263  54.598  1
251193  92.992  -74.264  54.596  1
251194  93.023  -74.265  54.594  1
251195  93.054  -74.266  54.592  1
251196  93.085  -74.267  54.590  1
251197  93.116  -74.268  54.589  1
251198  93.147  -74.270  54.588  1
251199  93.179  -74.270  54.587  1
251200  93.210  -74.272  54.588  1
251201  93.240  -74.273  54.591  1
251202  93.272  -74.274  54.593  1
251203  93.304  -74.262  54.600  1
251204  93.335  -74.248  54.611  1
251205  93.356  -74.256  54.625  1
251206  93.377  -74.264  54.642  1
251207  93.400  -74.267  54.662  1
251208  93.424  -74.264  54.686  1
251209  93.448  -74.260  54.712  1
251210  93.473  -74.255  54.738  1
251211  93.497  -74.252  54.763  1
251212  93.521  -74.247  54.788  1
251213  93.546  -74.243  54.812  1
251214  93.570  -74.239  54.839  1
251215  93.595  -74.235  54.862  1
251216  93.617  -74.231  54.881  1
251217  93.638  -74.227  54.897  1
251218  93.659  -74.223  54.915  1
251219  93.681  -74.220  54.929  1
251220  93.702  -74.216  54.942  1
251221  93.723  -74.211  54.961  1
251222  93.745  -74.208  54.971  1
251223  93.766  -74.204  54.974  1
251224  93.787  -74.200  54.972  1
251225  93.809  -74.196  54.963  1
251226  93.830  -74.192  54.945  1
251227  93.852  -74.189  54.923  1
251228  93.873  -74.186  54.897  1
251229  93.895  -74.186  54.869  1
251230  93.916  -74.187  54.842  1
251231  93.937  -74.188  54.815  1
251232  93.959  -74.189  54.787  1
251233  93.980  -74.189  54.755  1
251234  94.003  -74.192  54.724  1
251235  94.026  -74.195  54.693  1
251236  94.050  -74.198  54.663  1
251237  94.074  -74.202  54.634  1
251238  94.121  -74.212  54.608  1
251239  94.157  -74.218  54.584  1
251240  94.175  -74.217  54.566  1
251241  94.192  -74.217  54.560  1
251242  94.210  -74.216  54.554  1
251243  94.228  -74.214  54.546  1
251244  94.244  -74.214  54.536  1
251245  94.260  -74.214  54.522  1
251246  94.280  -74.217  54.504  1
251247  94.300  -74.220  54.484  1
251248  94.321  -74.223  54.464  1
251249  94.341  -74.227  54.441  1
251250  94.361  -74.230  54.417  1
251251  94.387  -74.224  54.394  1
251252  94.412  -74.219  54.370  1
251253  94.437  -74.213  54.344  1
251254  94.461  -74.198  54.314  1
251255  94.484  -74.183  54.284  1
251256  94.508  -74.173  54.252  1
251257  94.532  -74.171  54.217  1
251258  94.556  -74.170  54.182  1
251259  94.581  -74.168  54.145  1
251260  94.605  -74.167  54.104  1
251261  94.623  -74.174  54.057  1
251262  94.640  -74.183  54.009  1
251263  94.655  -74.184  53.961  1
251264  94.671  -74.184  53.913  1
251265  94.686  -74.183  53.865  1
251266  94.701  -74.183  53.817  1
251267  94.716  -74.183  53.768  1
251268  94.731  -74.183  53.720  1
251269  94.749  -74.189  53.671  1
251270  94.768  -74.201  53.624  1
251271  94.788  -74.214  53.581  1
251272  94.799  -74.250  53.542  1
251273  94.811  -74.283  53.511  1
251274  94.825  -74.314  53.488  1
251275  94.839  -74.346  53.467  1
251276  94.866  -74.343  53.445  1
251277  94.901  -74.317  53.411  1
251278  94.937  -74.290  53.376  1
251279  94.970  -74.291  53.340  1
251280  95.002  -74.294  53.298  1
251281  95.035  -74.298  53.250  1
251282  95.067  -74.301  53.200  1
251283  95.100  -74.307  53.149  1
251284  95.132  -74.320  53.097  1
251285  95.165  -74.334  53.043  1
251286  95.197  -74.349  52.989  1
251287  95.230  -74.362  52.936  1
251288  95.262  -74.376  52.883  1
251289  95.295  -74.390  52.823  1
251290  95.328  -74.402  52.764  1
251291  95.368  -74.395  52.706  1
251292  95.406  -74.388  52.650  1
251293  95.446  -74.382  52.595  1
251294  95.485  -74.375  52.541  1
251295  95.512  -74.380  52.489  1
251296  95.540  -74.381  52.442  1
251297  95.569  -74.381  52.394  1
251298  95.598  -74.380  52.348  1
251299  95.626  -74.380  52.304  1
251300  95.656  -74.380  52.263  1
251301  95.684  -74.379  52.222  1
251302  95.713  -74.379  52.181  1
251303  95.742  -74.383  52.140  1
251304  95.772  -74.390  52.100  1
251305  95.801  -74.396  52.060  1
251306  95.830  -74.402  52.019  1
251307  95.860  -74.408  51.978  1
251308  95.880  -74.410  51.939  1
251309  95.890  -74.407  51.898  1
251310  95.899  -74.403  51.859  1
251311  95.916  -74.412  51.819  1
251312  95.940  -74.432  51.778  1
251313  95.964  -74.452  51.736  1
251314  95.987  -74.471  51.694  1
251315  96.014  -74.491  51.653  1
251316  96.045  -74.511  51.612  1
251317  96.078  -74.530  51.572  1
251318  96.110  -74.551  51.532  1
251319  96.142  -74.571  51.494  1
251320  96.174  -74.590  51.457  1
251321  96.209  -74.606  51.423  1
251322  96.254  -74.614  51.389  1
251323  96.270  -74.614  51.356  1
251324  96.297  -74.596  51.325  1
251325  96.323  -74.578  51.296  1
251326  96.349  -74.561  51.269  1
251327  96.376  -74.547  51.244  1
251328  96.410  -74.566  51.220  1
251329  96.445  -74.585  51.198  1
251330  96.471  -74.595  51.177  1
251331  96.497  -74.602  51.158  1
251332  96.521  -74.609  51.140  1
251333  96.546  -74.617  51.124  1
251334  96.572  -74.624  51.111  1
251335  96.596  -74.631  51.100  1
251336  96.621  -74.639  51.090  1
251337  96.646  -74.646  51.082  1
251338  96.671  -74.653  51.075  1
251339  96.696  -74.661  51.069  1
251340  96.721  -74.668  51.066  1
251341  96.746  -74.675  51.064  1
251342  96.771  -74.683  51.062  1
251343  96.797  -74.691  51.060  1
251344  96.827  -74.709  51.059  1
251345  96.858  -74.728  51.055  1
251346  96.883  -74.737  51.048  1
251347  96.909  -74.744  51.039  1
251348  96.935  -74.753  51.029  1
251349  96.960  -74.761  51.021  1
251350  96.985  -74.778  51.011  1
251351  96.994  -74.783  50.999  1
251352  97.007  -74.793  50.982  1
251353  97.020  -74.802  50.966  1
251354  97.033  -74.812  50.952  1
251355  97.046  -74.822  50.938  1
251356  97.060  -74.831  50.927  1
251357  97.073  -74.841  50.918  1
251358  97.085  -74.851  50.911  1
251359  97.096  -74.856  50.906  1
251360  97.105  -74.863  50.900  1
251361  97.113  -74.868  50.895  1
251362  97.121  -74.873  50.888  1
251363  97.150  -74.860  50.876  1
251364  97.184  -74.852  50.855  1
251365  97.209  -74.859  50.832  1
251366  97.232  -74.868  50.807  1
251367  97.256  -74.877  50.780  1
251368  97.292  -74.880  50.751  1
251369  97.329  -74.883  50.723  1
251370  97.366  -74.886  50.695  1
251371  97.403  -74.889  50.666  1
251372  97.441  -74.892  50.637  1
251373  97.477  -74.894  50.606  1
251374  97.515  -74.897  50.575  1
251375  97.552  -74.900  50.543  1
251376  97.586  -74.906  50.508  1
251377  97.618  -74.914  50.470  1
251378  97.649  -74.922  50.431  1
251379  97.681  -74.930  50.392  1
251380  97.712  -74.938  50.351  1
251381  97.744  -74.947  50.309  1
251382  97.776  -74.954  50.266  1
251383  97.807  -74.963  50.222  1
251384  97.833  -74.972  50.177  1
251385  97.856  -74.984  50.129  1
251386  97.879  -74.994  50.079  1
251387  97.902  -75.006  50.025  1
251388  97.936  -75.011  49.969  1
251389  97.973  -75.016  49.916  1
251390  98.003  -75.026  49.864  1
251391  98.034  -75.036  49.813  1
251392  98.065  -75.047  49.766  1
251393  98.095  -75.057  49.716  1
251394  98.126  -75.066  49.662  1
251395  98.156  -75.076  49.605  1
251396  98.187  -75.086  49.547  1
251397  98.218  -75.098  49.490  1
251398  98.249  -75.112  49.436  1
251399  98.280  -75.125  49.385  1
251400  98.311  -75.138  49.333  1
251401  98.343  -75.151  49.282  1
251402  98.382  -75.175  49.233  1
251403  98.424  -75.201  49.184  1
251404  98.458  -75.201  49.136  1
251405  98.479  -75.179  49.088  1
251406  98.498  -75.157  49.040  1
251407  98.518  -75.135  48.991  1
251408  98.538  -75.113  48.941  1
251409  98.558  -75.090  48.890  1
251410  98.583  -75.092  48.839  1
251411  98.610  -75.103  48.786  1
251412  98.638  -75.112  48.734  1
251413  98.664  -75.116  48.682  1
251414  98.692  -75.120  48.628  1
251415  98.718  -75.125  48.574  1
251416  98.745  -75.129  48.520  1
251417  98.773  -75.134  48.467  1
251418  98.799  -75.138  48.415  1
251419  98.827  -75.143  48.361  1
251420  98.853  -75.148  48.309  1
251421  98.880  -75.162  48.257  1
251422  98.905  -75.192  48.206  1
251423  98.931  -75.223  48.156  1
251424  98.956  -75.253  48.107  1
251425  98.981  -75.283  48.059  1
251426  99.007  -75.314  48.012  1
251427  99.032  -75.344  47.966  1
251428  99.058  -75.374  47.922  1
251429  99.083  -75.405  47.877  1
251430  99.112  -75.419  47.833  1
251431  99.141  -75.423  47.789  1
251432  99.171  -75.427  47.747  1
251433  99.202  -75.431  47.706  1
251434  99.232  -75.435  47.666  1
251435  99.262  -75.439  47.624  1
251436  99.292  -75.443  47.583  1
251437  99.322  -75.447  47.544  1
251438  99.352  -75.452  47.507  1
251439  99.382  -75.455  47.471  1
251440  99.409  -75.462  47.439  1
251441  99.433  -75.471  47.410  1
251442  99.457  -75.479  47.381  1
251443  99.482  -75.486  47.353  1
251444  99.503  -75.502  47.327  1
251445  99.527  -75.518  47.301  1
251446  99.551  -75.535  47.275  1
251447  99.577  -75.552  47.253  1
251448  99.604  -75.569  47.230  1
251449  99.630  -75.587  47.208  1
251450  99.655  -75.604  47.186  1
251451  99.682  -75.621  47.166  1
251452  99.708  -75.638  47.144  1
251453  99.734  -75.656  47.123  1
251454  99.760  -75.673  47.105  1
251455  99.786  -75.690  47.086  1
251456  99.811  -75.709  47.067  1
251457  99.834  -75.739  47.048  1
251458  99.855  -75.768  47.029  1
251459  99.877  -75.798  47.006  1
251460  99.900  -75.828  46.982  1
251461  99.946  -75.832  46.958  1
251462  99.951  -75.850  46.932  1
251463  99.975  -75.860  46.904  1
251464  100.005  -75.869  46.874  1
251465  100.035  -75.876  46.843  1
251466  100.065  -75.884  46.809  1
251467  100.095  -75.893  46.777  1
251468  100.125  -75.900  46.744  1
251469  100.155  -75.909  46.710  1
251470  100.186  -75.917  46.676  1
251471  100.216  -75.925  46.643  1
251472  100.246  -75.935  46.608  1
251473  100.273  -75.957  46.574  1
251474  100.301  -75.979  46.542  1
251475  100.329  -76.001  46.511  1
251476  100.359  -76.006  46.479  1
251477  100.391  -75.996  46.448  1
251478  100.423  -75.986  46.416  1
251479  100.456  -75.977  46.385  1
251480  100.488  -75.967  46.354  1
251481  100.516  -75.984  46.324  1
251482  100.543  -76.013  46.294  1
251483  100.570  -76.043  46.262  1
251484  100.598  -76.072  46.230  1
251485  100.625  -76.102  46.198  1
251486  100.651  -76.132  46.164  1
251487  100.679  -76.161  46.132  1
251488  100.706  -76.190  46.099  1
251489  100.733  -76.220  46.067  1
251490  100.760  -76.249  46.035  1
251491  100.787  -76.279  46.004  1
251492  100.816  -76.303  45.972  1
251493  100.847  -76.320  45.941  1
251494  100.859  -76.326  45.912  1
251495  100.866  -76.329  45.885  1
251496  100.873  -76.331  45.857  1
251497  100.879  -76.333  45.829  1
251498  100.892  -76.337  45.802  1
251499  100.933  -76.348  45.776  1
251500  100.975  -76.360  45.750  1
251501  101.016  -76.371  45.726  1
251502  101.058  -76.383  45.701  1
251503  101.100  -76.393  45.677  1
251504  101.141  -76.404  45.652  1
251505  101.183  -76.416  45.628  1
251506  101.224  -76.427  45.604  1
251507  101.266  -76.439  45.580  1
251508  101.319  -76.455  45.557  1
251509  101.376  -76.473  45.533  1
251510  101.422  -76.471  45.512  1
251511  101.467  -76.466  45.489  1
251512  101.512  -76.460  45.467  1
251513  101.556  -76.455  45.444  1
251514  101.601  -76.448  45.422  1
251515  101.631  -76.454  45.401  1
251516  101.656  -76.463  45.380  1
251517  101.680  -76.474  45.358  1
251518  101.694  -76.486  45.337  1
251519  101.709  -76.498  45.316  1
251520  101.724  -76.510  45.295  1
251521  101.739  -76.522  45.274  1
251522  101.759  -76.524  45.252  1
251523  101.780  -76.524  45.232  1
251524  101.797  -76.536  45.211  1
251525  101.813  -76.546  45.191  1
251526  101.830  -76.558  45.170  1
251889  92.842  -74.184  54.604  1
251890  92.871  -74.203  54.605  1
251891  92.901  -74.222  54.605  1
251892  92.931  -74.240  54.605  1
251893  92.962  -74.242  54.605  1
251894  92.993  -74.242  54.603  1
251895  93.024  -74.244  54.601  1
251896  93.055  -74.245  54.600  1
251897  93.086  -74.246  54.598  1
251898  93.117  -74.247  54.597  1
251899  93.148  -74.248  54.597  1
251900  93.180  -74.249  54.596  1
251901  93.210  -74.250  54.596  1
251902  93.241  -74.252  54.599  1
251903  93.274  -74.243  54.601  1
251904  93.307  -74.223  54.606  1
251905  93.332  -74.223  54.615  1
251906  93.353  -74.232  54.628  1
251907  93.374  -74.240  54.642  1
251908  93.396  -74.245  54.659  1
251909  93.420  -74.241  54.679  1
251910  93.444  -74.236  54.703  1
251911  93.469  -74.233  54.727  1
251912  93.493  -74.228  54.752  1
251913  93.518  -74.224  54.778  1
251914  93.542  -74.220  54.804  1
251915  93.566  -74.216  54.829  1
251916  93.591  -74.212  54.850  1
251917  93.615  -74.208  54.867  1
251918  93.639  -74.204  54.882  1
251919  93.661  -74.200  54.902  1
251920  93.683  -74.196  54.922  1
251921  93.704  -74.192  54.942  1
251922  93.725  -74.188  54.962  1
251923  93.747  -74.184  54.972  1
251924  93.768  -74.180  54.974  1
251925  93.789  -74.176  54.970  1
251926  93.811  -74.173  54.965  1
251927  93.832  -74.169  54.949  1
251928  93.853  -74.165  54.927  1
251929  93.875  -74.164  54.900  1
251930  93.897  -74.165  54.873  1
251931  93.918  -74.166  54.845  1
251932  93.939  -74.167  54.819  1
251933  93.961  -74.167  54.793  1
251934  93.982  -74.168  54.759  1
251935  94.004  -74.170  54.726  1
251936  94.026  -74.170  54.694  1
251937  94.049  -74.174  54.663  1
251938  94.077  -74.179  54.634  1
251939  94.124  -74.189  54.606  1
251940  94.165  -74.196  54.580  1
251941  94.182  -74.195  54.558  1
251942  94.200  -74.195  54.552  1
251943  94.214  -74.193  54.548  1
251944  94.228  -74.191  54.542  1
251945  94.243  -74.189  54.532  1
251946  94.261  -74.193  54.517  1
251947  94.281  -74.198  54.497  1
251948  94.302  -74.201  54.477  1
251949  94.322  -74.205  54.457  1
251950  94.342  -74.208  54.435  1
251951  94.364  -74.208  54.411  1
251952  94.390  -74.203  54.387  1
251953  94.415  -74.198  54.363  1
251954  94.440  -74.193  54.335  1
251955  94.465  -74.183  54.306  1
251956  94.488  -74.167  54.275  1
251957  94.511  -74.152  54.242  1
251958  94.535  -74.139  54.207  1
251959  94.559  -74.137  54.169  1
251960  94.583  -74.136  54.130  1
251961  94.608  -74.134  54.087  1
251962  94.628  -74.139  54.041  1
251963  94.644  -74.148  53.994  1
251964  94.660  -74.147  53.946  1
251965  94.675  -74.147  53.898  1
251966  94.690  -74.146  53.850  1
251967  94.705  -74.146  53.802  1
251968  94.720  -74.145  53.753  1
251969  94.735  -74.145  53.704  1
251970  94.751  -74.147  53.655  1
251971  94.770  -74.159  53.608  1
251972  94.787  -74.179  53.566  1
251973  94.799  -74.214  53.529  1
251974  94.813  -74.245  53.501  1
251975  94.827  -74.276  53.480  1
251976  94.841  -74.307  53.460  1
251977  94.869  -74.300  53.437  1
251978  94.905  -74.274  53.403  1
251979  94.938  -74.264  53.366  1
251980  94.971  -74.267  53.328  1
251981  95.003  -74.270  53.286  1
251982  95.036  -74.274  53.237  1
251983  95.068  -74.277  53.185  1
251984  95.101  -74.281  53.132  1
251985  95.133  -74.290  53.081  1
251986  95.166  -74.304  53.029  1
251987  95.198  -74.317  52.975  1
251988  95.231  -74.332  52.921  1
251989  95.264  -74.346  52.867  1
251990  95.296  -74.359  52.810  1
251991  95.332  -74.363  52.752  1
251992  95.371  -74.356  52.695  1
251993  95.410  -74.350  52.639  1
251994  95.449  -74.343  52.585  1
251995  95.488  -74.337  52.532  1
251996  95.523  -74.335  52.482  1
251997  95.550  -74.337  52.435  1
251998  95.579  -74.336  52.389  1
251999  95.608  -74.336  52.344  1
252000  95.636  -74.336  52.301  1
252001  95.666  -74.337  52.260  1
252002  95.695  -74.343  52.220  1
252003  95.725  -74.350  52.180  1
252004  95.754  -74.356  52.141  1
252005  95.783  -74.362  52.101  1
252006  95.812  -74.368  52.061  1
252007  95.842  -74.374  52.020  1
252008  95.867  -74.379  51.980  1
252009  95.877  -74.376  51.940  1
252010  95.887  -74.372  51.899  1
252011  95.896  -74.368  51.859  1
252012  95.910  -74.372  51.819  1
252013  95.934  -74.392  51.777  1
252014  95.958  -74.411  51.736  1
252015  95.981  -74.431  51.695  1
252016  96.005  -74.451  51.654  1
252017  96.029  -74.471  51.613  1
252018  96.058  -74.490  51.574  1
252019  96.090  -74.510  51.535  1
252020  96.122  -74.530  51.496  1
252021  96.160  -74.544  51.459  1
252022  96.204  -74.552  51.425  1
252023  96.249  -74.559  51.391  1
252024  96.257  -74.574  51.358  1
252025  96.283  -74.556  51.326  1
252026  96.309  -74.538  51.297  1
252027  96.335  -74.521  51.270  1
252028  96.363  -74.512  51.244  1
252029  96.397  -74.530  51.219  1
252030  96.432  -74.549  51.196  1
252031  96.466  -74.568  51.175  1
252032  96.493  -74.578  51.154  1
252033  96.519  -74.586  51.136  1
252034  96.543  -74.593  51.119  1
252035  96.569  -74.600  51.104  1
252036  96.593  -74.608  51.092  1
252037  96.618  -74.615  51.081  1
252038  96.643  -74.622  51.072  1
252039  96.668  -74.630  51.065  1
252040  96.693  -74.637  51.058  1
252041  96.718  -74.644  51.055  1
252042  96.743  -74.652  51.052  1
252043  96.768  -74.659  51.050  1
252044  96.795  -74.670  51.049  1
252045  96.825  -74.688  51.050  1
252046  96.856  -74.707  51.047  1
252047  96.883  -74.718  51.042  1
252048  96.908  -74.726  51.035  1
252049  96.934  -74.734  51.027  1
252050  96.959  -74.742  51.020  1
252051  96.985  -74.750  51.013  1
252052  97.001  -74.760  51.002  1
252053  97.014  -74.770  50.987  1
252054  97.026  -74.781  50.973  1
252055  97.035  -74.792  50.959  1
252056  97.045  -74.803  50.947  1
252057  97.055  -74.814  50.937  1
252058  97.067  -74.822  50.928  1
252059  97.083  -74.824  50.921  1
252060  97.099  -74.825  50.915  1
252061  97.115  -74.828  50.911  1
252062  97.124  -74.833  50.907  1
252063  97.132  -74.838  50.900  1
252064  97.154  -74.832  50.888  1
252065  97.185  -74.828  50.867  1
252066  97.209  -74.837  50.844  1
252067  97.236  -74.844  50.817  1
252068  97.273  -74.847  50.789  1
252069  97.310  -74.850  50.759  1
252070  97.347  -74.853  50.730  1
252071  97.384  -74.856  50.701  1
252072  97.422  -74.859  50.673  1
252073  97.458  -74.861  50.645  1
252074  97.496  -74.864  50.615  1
252075  97.533  -74.867  50.584  1
252076  97.570  -74.870  50.553  1
252077  97.606  -74.874  50.518  1
252078  97.637  -74.882  50.479  1
252079  97.669  -74.891  50.440  1
252080  97.701  -74.898  50.400  1
252081  97.732  -74.907  50.357  1
252082  97.764  -74.915  50.314  1
252083  97.795  -74.922  50.270  1
252084  97.821  -74.932  50.225  1
252085  97.844  -74.944  50.180  1
252086  97.867  -74.955  50.132  1
252087  97.890  -74.966  50.081  1
252088  97.913  -74.977  50.027  1
252089  97.944  -74.984  49.973  1
252090  97.982  -74.988  49.920  1
252091  98.012  -74.998  49.869  1
252092  98.042  -75.008  49.819  1
252093  98.073  -75.018  49.771  1
252094  98.103  -75.028  49.720  1
252095  98.134  -75.038  49.666  1
252096  98.165  -75.050  49.609  1
252097  98.196  -75.063  49.551  1
252098  98.227  -75.076  49.494  1
252099  98.258  -75.088  49.439  1
252100  98.290  -75.102  49.387  1
252101  98.321  -75.115  49.336  1
252102  98.353  -75.129  49.285  1
252103  98.394  -75.154  49.234  1
252104  98.435  -75.179  49.186  1
252105  98.465  -75.160  49.137  1
252106  98.485  -75.137  49.089  1
252107  98.505  -75.115  49.040  1
252108  98.524  -75.093  48.992  1
252109  98.545  -75.071  48.940  1
252110  98.565  -75.054  48.888  1
252111  98.593  -75.065  48.837  1
252112  98.620  -75.076  48.784  1
252113  98.647  -75.087  48.731  1
252114  98.674  -75.093  48.679  1
252115  98.702  -75.098  48.625  1
252116  98.728  -75.102  48.571  1
252117  98.756  -75.107  48.517  1
252118  98.782  -75.111  48.463  1
252119  98.809  -75.116  48.410  1
252120  98.837  -75.120  48.359  1
252121  98.863  -75.125  48.307  1
252122  98.889  -75.150  48.256  1
252123  98.915  -75.180  48.204  1
252124  98.940  -75.210  48.155  1
252125  98.966  -75.241  48.106  1
252126  98.991  -75.271  48.058  1
252127  99.016  -75.301  48.011  1
252128  99.042  -75.332  47.966  1
252129  99.067  -75.358  47.920  1
252130  99.091  -75.377  47.875  1
252131  99.124  -75.395  47.830  1
252132  99.154  -75.399  47.787  1
252133  99.184  -75.404  47.743  1
252134  99.214  -75.408  47.701  1
252135  99.244  -75.412  47.660  1
252136  99.274  -75.416  47.618  1
252137  99.304  -75.420  47.577  1
252138  99.334  -75.424  47.537  1
252139  99.364  -75.428  47.499  1
252140  99.394  -75.432  47.464  1
252141  99.419  -75.440  47.432  1
252142  99.443  -75.449  47.401  1
252143  99.468  -75.457  47.372  1
252144  99.493  -75.464  47.345  1
252145  99.517  -75.473  47.319  1
252146  99.540  -75.488  47.293  1
252147  99.566  -75.505  47.268  1
252148  99.592  -75.522  47.245  1
252149  99.618  -75.540  47.223  1
252150  99.644  -75.557  47.201  1
252151  99.670  -75.574  47.180  1
252152  99.696  -75.591  47.159  1
252153  99.722  -75.609  47.137  1
252154  99.748  -75.626  47.117  1
252155  99.774  -75.643  47.098  1
252156  99.800  -75.660  47.080  1
252157  99.826  -75.678  47.061  1
252158  99.848  -75.708  47.043  1
252159  99.870  -75.737  47.024  1
252160  99.893  -75.767  47.001  1
252161  99.932  -75.779  46.977  1
252162  99.969  -75.784  46.953  1
252163  99.974  -75.802  46.928  1
252164  99.988  -75.815  46.899  1
252165  100.018  -75.823  46.869  1
252166  100.049  -75.831  46.837  1
252167  100.079  -75.840  46.803  1
252168  100.109  -75.847  46.770  1
252169  100.139  -75.856  46.737  1
252170  100.169  -75.864  46.703  1
252171  100.199  -75.872  46.669  1
252172  100.229  -75.880  46.635  1
252173  100.258  -75.899  46.601  1
252174  100.285  -75.921  46.567  1
252175  100.314  -75.943  46.535  1
252176  100.341  -75.965  46.504  1
252177  100.369  -75.987  46.472  1
252178  100.400  -75.984  46.441  1
252179  100.432  -75.974  46.409  1
252180  100.465  -75.964  46.379  1
252181  100.497  -75.954  46.349  1
252182  100.525  -75.974  46.318  1
252183  100.552  -76.003  46.289  1
252184  100.579  -76.032  46.257  1
252185  100.606  -76.062  46.225  1
252186  100.633  -76.091  46.194  1
252187  100.661  -76.121  46.160  1
252188  100.687  -76.151  46.128  1
252189  100.714  -76.180  46.096  1
252190  100.742  -76.210  46.064  1
252191  100.770  -76.235  46.031  1
252192  100.804  -76.252  45.999  1
252193  100.836  -76.270  45.969  1
252194  100.859  -76.282  45.939  1
252195  100.876  -76.293  45.909  1
252196  100.883  -76.295  45.881  1
252197  100.890  -76.298  45.853  1
252198  100.896  -76.300  45.825  1
252199  100.918  -76.306  45.798  1
252200  100.960  -76.317  45.772  1
252201  101.001  -76.329  45.746  1
252202  101.042  -76.340  45.721  1
252203  101.084  -76.351  45.697  1
252204  101.125  -76.362  45.672  1
252205  101.167  -76.373  45.647  1
252206  101.208  -76.385  45.623  1
252207  101.250  -76.396  45.599  1
252208  101.291  -76.407  45.575  1
252209  101.333  -76.418  45.552  1
252210  101.386  -76.436  45.528  1
252211  101.443  -76.454  45.506  1
252212  101.492  -76.457  45.483  1
252213  101.537  -76.451  45.461  1
252214  101.582  -76.446  45.438  1
252215  101.627  -76.440  45.417  1
252216  101.662  -76.442  45.395  1
252217  101.687  -76.451  45.374  1
252218  101.708  -76.462  45.352  1
252219  101.723  -76.474  45.331  1
252220  101.738  -76.486  45.309  1
252221  101.752  -76.499  45.288  1
252222  101.773  -76.500  45.266  1
252223  101.793  -76.505  45.245  1
252224  101.809  -76.515  45.224  1
252225  101.825  -76.527  45.204  1
252226  101.841  -76.538  45.183  1
252227  101.850  -76.542  45.162  1
252589  92.813  -74.139  54.609  1
252590  92.843  -74.158  54.610  1
252591  92.873  -74.176  54.611  1
252592  92.902  -74.195  54.611  1
252593  92.932  -74.214  54.612  1
252594  92.963  -74.220  54.612  1
252595  92.994  -74.221  54.611  1
252596  93.025  -74.222  54.609  1
252597  93.056  -74.223  54.608  1
252598  93.087  -74.224  54.607  1
252599  93.118  -74.226  54.607  1
252600  93.149  -74.226  54.607  1
252601  93.180  -74.228  54.607  1
252602  93.211  -74.229  54.607  1
252603  93.243  -74.224  54.608  1
252604  93.277  -74.204  54.610  1
252605  93.306  -74.192  54.613  1
252606  93.328  -74.199  54.620  1
252607  93.349  -74.208  54.631  1
252608  93.370  -74.216  54.643  1
252609  93.392  -74.221  54.657  1
252610  93.416  -74.217  54.674  1
252611  93.441  -74.214  54.694  1
252612  93.465  -74.209  54.717  1
252613  93.489  -74.205  54.741  1
252614  93.514  -74.201  54.767  1
252615  93.538  -74.197  54.793  1
252616  93.562  -74.193  54.816  1
252617  93.587  -74.189  54.834  1
252618  93.611  -74.185  54.851  1
252619  93.636  -74.180  54.867  1
252620  93.660  -74.176  54.891  1
252621  93.684  -74.173  54.917  1
252622  93.706  -74.168  54.942  1
252623  93.727  -74.164  54.961  1
252624  93.749  -74.161  54.969  1
252625  93.770  -74.157  54.972  1
252626  93.791  -74.153  54.972  1
252627  93.813  -74.149  54.968  1
252628  93.834  -74.145  54.953  1
252629  93.855  -74.142  54.932  1
252630  93.877  -74.143  54.907  1
252631  93.899  -74.144  54.881  1
252632  93.920  -74.145  54.854  1
252633  93.941  -74.145  54.828  1
252634  93.963  -74.146  54.802  1
252635  93.984  -74.148  54.765  1
252636  94.006  -74.148  54.729  1
252637  94.027  -74.149  54.696  1
252638  94.049  -74.150  54.663  1
252639  94.080  -74.155  54.631  1
252640  94.127  -74.165  54.601  1
252641  94.171  -74.174  54.573  1
252642  94.185  -74.173  54.550  1
252643  94.199  -74.171  54.545  1
252644  94.213  -74.169  54.541  1
252645  94.227  -74.167  54.535  1
252646  94.243  -74.167  54.525  1
252647  94.263  -74.173  54.509  1
252648  94.283  -74.177  54.488  1
252649  94.303  -74.181  54.467  1
252650  94.324  -74.185  54.447  1
252651  94.344  -74.188  54.425  1
252652  94.366  -74.187  54.401  1
252653  94.392  -74.183  54.377  1
252654  94.417  -74.177  54.351  1
252655  94.443  -74.172  54.323  1
252656  94.468  -74.167  54.293  1
252657  94.492  -74.152  54.262  1
252658  94.515  -74.137  54.229  1
252659  94.538  -74.122  54.194  1
252660  94.561  -74.107  54.153  1
252661  94.585  -74.103  54.110  1
252662  94.610  -74.101  54.066  1
252663  94.632  -74.104  54.023  1
252664  94.648  -74.111  53.977  1
252665  94.663  -74.110  53.930  1
252666  94.678  -74.110  53.883  1
252667  94.693  -74.109  53.835  1
252668  94.708  -74.109  53.786  1
252669  94.723  -74.108  53.737  1
252670  94.739  -74.108  53.686  1
252671  94.754  -74.107  53.638  1
252672  94.772  -74.117  53.593  1
252673  94.786  -74.144  53.552  1
252674  94.800  -74.175  53.518  1
252675  94.814  -74.206  53.493  1
252676  94.829  -74.237  53.474  1
252677  94.843  -74.268  53.455  1
252678  94.873  -74.258  53.430  1
252679  94.908  -74.236  53.395  1
252680  94.940  -74.240  53.356  1
252681  94.972  -74.243  53.316  1
252682  95.005  -74.247  53.272  1
252683  95.037  -74.250  53.223  1
252684  95.070  -74.254  53.170  1
252685  95.102  -74.258  53.117  1
252686  95.135  -74.261  53.064  1
252687  95.167  -74.273  53.013  1
252688  95.200  -74.287  52.960  1
252689  95.233  -74.301  52.906  1
252690  95.265  -74.315  52.853  1
252691  95.298  -74.329  52.798  1
252692  95.336  -74.324  52.742  1
252693  95.375  -74.318  52.686  1
252694  95.414  -74.311  52.630  1
252695  95.453  -74.305  52.576  1
252696  95.492  -74.299  52.524  1
252697  95.531  -74.292  52.474  1
252698  95.560  -74.293  52.428  1
252699  95.589  -74.292  52.383  1
252700  95.618  -74.297  52.339  1
252701  95.648  -74.303  52.297  1
252702  95.677  -74.310  52.257  1
252703  95.706  -74.316  52.217  1
252704  95.736  -74.322  52.179  1
252705  95.765  -74.328  52.140  1
252706  95.795  -74.334  52.101  1
252707  95.824  -74.341  52.061  1
252708  95.853  -74.347  52.021  1
252709  95.865  -74.344  51.981  1
252710  95.874  -74.341  51.940  1
252711  95.884  -74.337  51.900  1
252712  95.894  -74.333  51.860  1
252713  95.904  -74.331  51.819  1
252714  95.928  -74.352  51.778  1
252715  95.952  -74.371  51.737  1
252716  95.975  -74.391  51.697  1
252717  95.999  -74.411  51.656  1
252718  96.023  -74.430  51.616  1
252719  96.046  -74.450  51.576  1
252720  96.071  -74.470  51.537  1
252721  96.111  -74.481  51.498  1
252722  96.155  -74.489  51.461  1
252723  96.200  -74.496  51.426  1
252724  96.244  -74.504  51.392  1
252725  96.251  -74.521  51.358  1
252726  96.269  -74.515  51.326  1
252727  96.295  -74.498  51.296  1
252728  96.321  -74.480  51.268  1
252729  96.350  -74.476  51.242  1
252730  96.385  -74.495  51.218  1
252731  96.419  -74.514  51.194  1
252732  96.453  -74.533  51.172  1
252733  96.488  -74.552  51.151  1
252734  96.516  -74.562  51.132  1
252735  96.540  -74.570  51.115  1
252736  96.566  -74.577  51.099  1
252737  96.591  -74.584  51.086  1
252738  96.615  -74.592  51.074  1
252739  96.641  -74.599  51.064  1
252740  96.665  -74.606  51.056  1
252741  96.690  -74.614  51.049  1
252742  96.715  -74.621  51.044  1
252743  96.740  -74.628  51.040  1
252744  96.765  -74.636  51.038  1
252745  96.793  -74.649  51.036  1
252746  96.823  -74.667  51.035  1
252747  96.854  -74.686  51.034  1
252748  96.882  -74.700  51.032  1
252749  96.907  -74.707  51.027  1
252750  96.933  -74.715  51.021  1
252751  96.959  -74.724  51.018  1
252752  96.982  -74.732  51.012  1
252753  96.996  -74.744  51.004  1
252754  97.006  -74.754  50.991  1
252755  97.016  -74.766  50.979  1
252756  97.025  -74.777  50.968  1
252757  97.035  -74.787  50.957  1
252758  97.050  -74.791  50.949  1
252759  97.067  -74.793  50.940  1
252760  97.083  -74.794  50.931  1
252761  97.099  -74.797  50.924  1
252762  97.115  -74.798  50.921  1
252763  97.131  -74.800  50.916  1
252764  97.143  -74.804  50.909  1
252765  97.158  -74.803  50.898  1
252766  97.186  -74.805  50.877  1
252767  97.217  -74.810  50.853  1
252768  97.254  -74.813  50.827  1
252769  97.291  -74.816  50.797  1
252770  97.328  -74.819  50.766  1
252771  97.365  -74.822  50.735  1
252772  97.402  -74.825  50.705  1
252773  97.439  -74.828  50.677  1
252774  97.476  -74.831  50.650  1
252775  97.514  -74.834  50.621  1
252776  97.550  -74.837  50.590  1
252777  97.588  -74.840  50.558  1
252778  97.625  -74.843  50.521  1
252779  97.657  -74.850  50.482  1
252780  97.688  -74.859  50.442  1
252781  97.720  -74.866  50.400  1
252782  97.751  -74.875  50.356  1
252783  97.783  -74.882  50.311  1
252784  97.809  -74.892  50.267  1
252785  97.832  -74.903  50.222  1
252786  97.855  -74.915  50.176  1
252787  97.878  -74.925  50.127  1
252788  97.904  -74.939  50.076  1
252789  97.929  -74.949  50.022  1
252790  97.952  -74.956  49.970  1
252791  97.990  -74.960  49.918  1
252792  98.020  -74.969  49.868  1
252793  98.051  -74.979  49.820  1
252794  98.082  -74.989  49.773  1
252795  98.112  -75.001  49.722  1
252796  98.144  -75.013  49.668  1
252797  98.174  -75.026  49.610  1
252798  98.206  -75.039  49.551  1
252799  98.237  -75.053  49.495  1
252800  98.268  -75.066  49.441  1
252801  98.299  -75.079  49.389  1
252802  98.330  -75.091  49.337  1
252803  98.364  -75.108  49.285  1
252804  98.405  -75.133  49.235  1
252805  98.443  -75.146  49.186  1
252806  98.472  -75.118  49.137  1
252807  98.491  -75.096  49.089  1
252808  98.511  -75.073  49.039  1
252809  98.531  -75.051  48.988  1
252810  98.551  -75.029  48.936  1
252811  98.575  -75.027  48.884  1
252812  98.602  -75.038  48.832  1
252813  98.630  -75.049  48.778  1
252814  98.657  -75.060  48.726  1
252815  98.685  -75.070  48.673  1
252816  98.712  -75.075  48.620  1
252817  98.738  -75.079  48.566  1
252818  98.766  -75.084  48.512  1
252819  98.792  -75.088  48.458  1
252820  98.819  -75.093  48.406  1
252821  98.846  -75.098  48.354  1
252822  98.873  -75.108  48.303  1
252823  98.899  -75.138  48.252  1
252824  98.924  -75.169  48.201  1
252825  98.949  -75.198  48.152  1
252826  98.975  -75.229  48.103  1
252827  99.000  -75.259  48.055  1
252828  99.025  -75.289  48.009  1
252829  99.050  -75.311  47.964  1
252830  99.075  -75.329  47.918  1
252831  99.099  -75.347  47.872  1
252832  99.134  -75.367  47.826  1
252833  99.166  -75.377  47.782  1
252834  99.196  -75.380  47.738  1
252835  99.226  -75.384  47.695  1
252836  99.257  -75.389  47.653  1
252837  99.286  -75.392  47.611  1
252838  99.316  -75.396  47.571  1
252839  99.347  -75.401  47.531  1
252840  99.376  -75.405  47.491  1
252841  99.405  -75.410  47.457  1
252842  99.430  -75.418  47.424  1
252843  99.454  -75.427  47.393  1
252844  99.479  -75.435  47.364  1
252845  99.503  -75.442  47.337  1
252846  99.527  -75.451  47.311  1
252847  99.558  -75.457  47.286  1
252848  99.580  -75.475  47.261  1
252849  99.607  -75.493  47.238  1
252850  99.632  -75.509  47.216  1
252851  99.658  -75.527  47.195  1
252852  99.685  -75.544  47.173  1
252853  99.711  -75.561  47.152  1
252854  99.736  -75.578  47.131  1
252855  99.763  -75.596  47.111  1
252856  99.789  -75.613  47.091  1
252857  99.815  -75.630  47.074  1
252858  99.841  -75.648  47.056  1
252859  99.863  -75.677  47.039  1
252860  99.885  -75.706  47.019  1
252861  99.916  -75.727  46.997  1
252862  99.972  -75.724  46.973  1
252863  99.991  -75.736  46.948  1
252864  99.996  -75.753  46.923  1
252865  100.002  -75.770  46.895  1
252866  100.032  -75.778  46.864  1
252867  100.062  -75.787  46.832  1
252868  100.092  -75.794  46.797  1
252869  100.123  -75.803  46.763  1
252870  100.152  -75.811  46.730  1
252871  100.183  -75.818  46.696  1
252872  100.213  -75.827  46.662  1
252873  100.242  -75.840  46.628  1
252874  100.270  -75.862  46.594  1
252875  100.298  -75.884  46.560  1
252876  100.326  -75.906  46.529  1
252877  100.353  -75.928  46.496  1
252878  100.382  -75.950  46.465  1
252879  100.409  -75.971  46.434  1
252880  100.441  -75.961  46.403  1
252881  100.474  -75.952  46.372  1
252882  100.506  -75.942  46.343  1
252883  100.534  -75.963  46.313  1
252884  100.561  -75.993  46.283  1
252885  100.588  -76.022  46.252  1
252886  100.615  -76.052  46.221  1
252887  100.642  -76.081  46.190  1
252888  100.669  -76.110  46.156  1
252889  100.696  -76.140  46.125  1
252890  100.724  -76.166  46.093  1
252891  100.758  -76.184  46.061  1
252892  100.790  -76.201  46.029  1
252893  100.823  -76.219  45.998  1
252894  100.855  -76.235  45.967  1
252895  100.872  -76.246  45.936  1
252896  100.890  -76.257  45.907  1
252897  100.901  -76.262  45.878  1
252898  100.907  -76.264  45.850  1
252899  100.913  -76.267  45.822  1
252900  100.944  -76.275  45.795  1
252901  100.985  -76.286  45.769  1
252902  101.027  -76.298  45.742  1
252903  101.068  -76.309  45.717  1
252904  101.110  -76.320  45.693  1
252905  101.151  -76.331  45.667  1
252906  101.193  -76.342  45.642  1
252907  101.234  -76.354  45.618  1
252908  101.276  -76.365  45.594  1
252909  101.317  -76.376  45.570  1
252910  101.358  -76.387  45.547  1
252911  101.400  -76.398  45.524  1
252912  101.454  -76.415  45.500  1
252913  101.510  -76.434  45.477  1
252914  101.563  -76.443  45.455  1
252915  101.608  -76.438  45.433  1
252916  101.653  -76.432  45.411  1
252917  101.693  -76.430  45.390  1
252918  101.718  -76.439  45.368  1
252919  101.736  -76.451  45.345  1
252920  101.751  -76.462  45.324  1
252921  101.766  -76.474  45.303  1
252922  101.787  -76.475  45.281  1
252923  101.804  -76.484  45.259  1
252924  101.821  -76.495  45.238  1
252925  101.837  -76.507  45.216  1
252926  101.836  -76.505  45.195  1
252927  101.829  -76.498  45.175  1
252928  101.822  -76.491  45.154  1
253289  92.785  -74.095  54.613  1
253290  92.814  -74.114  54.614  1
253291  92.844  -74.132  54.616  1
253292  92.874  -74.151  54.617  1
253293  92.904  -74.170  54.618  1
253294  92.933  -74.188  54.619  1
253295  92.964  -74.198  54.619  1
253296  92.995  -74.200  54.619  1
253297  93.025  -74.201  54.617  1
253298  93.057  -74.202  54.617  1
253299  93.088  -74.203  54.617  1
253300  93.119  -74.204  54.617  1
253301  93.150  -74.205  54.617  1
253302  93.181  -74.206  54.617  1
253303  93.212  -74.205  54.617  1
253304  93.246  -74.185  54.619  1
253305  93.280  -74.164  54.619  1
253306  93.303  -74.167  54.623  1
253307  93.324  -74.175  54.628  1
253308  93.345  -74.183  54.636  1
253309  93.366  -74.191  54.645  1
253310  93.388  -74.198  54.656  1
253311  93.412  -74.195  54.670  1
253312  93.437  -74.190  54.686  1
253313  93.461  -74.186  54.707  1
253314  93.485  -74.182  54.730  1
253315  93.510  -74.178  54.754  1
253316  93.534  -74.174  54.779  1
253317  93.559  -74.170  54.798  1
253318  93.583  -74.166  54.815  1
253319  93.607  -74.161  54.832  1
253320  93.632  -74.157  54.853  1
253321  93.656  -74.154  54.883  1
253322  93.680  -74.149  54.914  1
253323  93.705  -74.145  54.941  1
253324  93.729  -74.141  54.958  1
253325  93.751  -74.137  54.963  1
253326  93.772  -74.133  54.968  1
253327  93.793  -74.129  54.974  1
253328  93.815  -74.126  54.971  1
253329  93.836  -74.122  54.958  1
253330  93.857  -74.121  54.939  1
253331  93.879  -74.122  54.916  1
253332  93.900  -74.123  54.892  1
253333  93.922  -74.123  54.865  1
253334  93.943  -74.124  54.838  1
253335  93.965  -74.126  54.809  1
253336  93.986  -74.126  54.771  1
253337  94.008  -74.127  54.733  1
253338  94.029  -74.129  54.696  1
253339  94.050  -74.131  54.659  1
253340  94.087  -74.139  54.624  1
253341  94.136  -74.151  54.592  1
253342  94.159  -74.150  54.564  1
253343  94.182  -74.148  54.542  1
253344  94.198  -74.147  54.536  1
253345  94.212  -74.145  54.531  1
253346  94.225  -74.144  54.524  1
253347  94.245  -74.147  54.514  1
253348  94.265  -74.152  54.497  1
253349  94.285  -74.157  54.475  1
253350  94.305  -74.161  54.452  1
253351  94.325  -74.165  54.431  1
253352  94.346  -74.168  54.409  1
253353  94.369  -74.167  54.386  1
253354  94.395  -74.161  54.361  1
253355  94.420  -74.156  54.334  1
253356  94.445  -74.151  54.303  1
253357  94.471  -74.145  54.273  1
253358  94.495  -74.136  54.243  1
253359  94.519  -74.122  54.210  1
253360  94.542  -74.107  54.172  1
253361  94.565  -74.092  54.131  1
253362  94.589  -74.076  54.087  1
253363  94.613  -74.069  54.042  1
253364  94.636  -74.069  54.001  1
253365  94.651  -74.073  53.956  1
253366  94.667  -74.073  53.910  1
253367  94.682  -74.072  53.863  1
253368  94.697  -74.072  53.815  1
253369  94.712  -74.071  53.766  1
253370  94.728  -74.071  53.716  1
253371  94.743  -74.070  53.665  1
253372  94.758  -74.070  53.619  1
253373  94.774  -74.074  53.577  1
253374  94.788  -74.106  53.540  1
253375  94.802  -74.137  53.509  1
253376  94.816  -74.168  53.487  1
253377  94.830  -74.199  53.471  1
253378  94.844  -74.230  53.452  1
253379  94.876  -74.215  53.424  1
253380  94.909  -74.213  53.387  1
253381  94.942  -74.217  53.346  1
253382  94.974  -74.220  53.303  1
253383  95.006  -74.223  53.258  1
253384  95.039  -74.226  53.207  1
253385  95.071  -74.230  53.154  1
253386  95.104  -74.233  53.101  1
253387  95.136  -74.237  53.048  1
253388  95.169  -74.242  52.996  1
253389  95.201  -74.257  52.945  1
253390  95.234  -74.270  52.892  1
253391  95.266  -74.285  52.839  1
253392  95.301  -74.292  52.786  1
253393  95.339  -74.286  52.732  1
253394  95.379  -74.280  52.677  1
253395  95.418  -74.273  52.622  1
253396  95.457  -74.267  52.567  1
253397  95.496  -74.260  52.516  1
253398  95.534  -74.255  52.468  1
253399  95.571  -74.257  52.421  1
253400  95.600  -74.263  52.378  1
253401  95.630  -74.269  52.335  1
253402  95.659  -74.276  52.293  1
253403  95.688  -74.282  52.252  1
253404  95.718  -74.288  52.214  1
253405  95.747  -74.294  52.176  1
253406  95.776  -74.301  52.139  1
253407  95.806  -74.307  52.101  1
253408  95.835  -74.313  52.060  1
253409  95.852  -74.313  52.021  1
253410  95.862  -74.309  51.982  1
253411  95.872  -74.306  51.941  1
253412  95.881  -74.302  51.901  1
253413  95.891  -74.299  51.861  1
253414  95.901  -74.295  51.820  1
253415  95.922  -74.311  51.779  1
253416  95.946  -74.331  51.739  1
253417  95.969  -74.351  51.699  1
253418  95.993  -74.371  51.659  1
253419  96.017  -74.390  51.618  1
253420  96.040  -74.410  51.579  1
253421  96.066  -74.423  51.539  1
253422  96.106  -74.427  51.500  1
253423  96.151  -74.434  51.462  1
253424  96.195  -74.442  51.427  1
253425  96.239  -74.449  51.393  1
253426  96.246  -74.466  51.359  1
253427  96.255  -74.475  51.327  1
253428  96.282  -74.458  51.296  1
253429  96.308  -74.440  51.268  1
253430  96.338  -74.440  51.241  1
253431  96.372  -74.459  51.216  1
253432  96.406  -74.478  51.192  1
253433  96.441  -74.497  51.170  1
253434  96.475  -74.516  51.148  1
253435  96.509  -74.535  51.128  1
253436  96.538  -74.546  51.111  1
253437  96.562  -74.553  51.095  1
253438  96.588  -74.561  51.080  1
253439  96.612  -74.568  51.067  1
253440  96.638  -74.575  51.057  1
253441  96.662  -74.583  51.047  1
253442  96.687  -74.590  51.039  1
253443  96.713  -74.597  51.033  1
253444  96.737  -74.605  51.029  1
253445  96.762  -74.612  51.025  1
253446  96.791  -74.628  51.023  1
253447  96.822  -74.646  51.022  1
253448  96.852  -74.665  51.021  1
253449  96.881  -74.681  51.020  1
253450  96.907  -74.689  51.018  1
253451  96.933  -74.697  51.015  1
253452  96.954  -74.707  51.014  1
253453  96.975  -74.717  51.011  1
253454  96.986  -74.728  51.004  1
253455  96.996  -74.739  50.993  1
253456  97.006  -74.750  50.984  1
253457  97.018  -74.758  50.975  1
253458  97.034  -74.759  50.968  1
253459  97.050  -74.762  50.961  1
253460  97.066  -74.763  50.952  1
253461  97.082  -74.765  50.942  1
253462  97.098  -74.767  50.935  1
253463  97.114  -74.769  50.931  1
253464  97.131  -74.771  50.925  1
253465  97.147  -74.772  50.917  1
253466  97.162  -74.775  50.906  1
253467  97.197  -74.778  50.885  1
253468  97.235  -74.780  50.861  1
253469  97.272  -74.783  50.833  1
253470  97.309  -74.786  50.803  1
253471  97.346  -74.789  50.771  1
253472  97.383  -74.792  50.740  1
253473  97.420  -74.795  50.710  1
253474  97.457  -74.797  50.681  1
253475  97.495  -74.800  50.655  1
253476  97.531  -74.803  50.626  1
253477  97.569  -74.806  50.594  1
253478  97.606  -74.809  50.560  1
253479  97.643  -74.812  50.522  1
253480  97.676  -74.819  50.482  1
253481  97.708  -74.826  50.439  1
253482  97.739  -74.834  50.396  1
253483  97.771  -74.843  50.351  1
253484  97.798  -74.853  50.305  1
253485  97.820  -74.863  50.259  1
253486  97.844  -74.875  50.214  1
253487  97.869  -74.888  50.166  1
253488  97.896  -74.902  50.117  1
253489  97.921  -74.912  50.067  1
253490  97.944  -74.919  50.014  1
253491  97.967  -74.925  49.965  1
253492  97.998  -74.931  49.916  1
253493  98.029  -74.941  49.868  1
253494  98.060  -74.951  49.821  1
253495  98.091  -74.964  49.774  1
253496  98.122  -74.977  49.722  1
253497  98.153  -74.991  49.667  1
253498  98.184  -75.004  49.610  1
253499  98.215  -75.016  49.551  1
253500  98.246  -75.029  49.495  1
253501  98.278  -75.043  49.441  1
253502  98.308  -75.056  49.389  1
253503  98.340  -75.069  49.336  1
253504  98.375  -75.087  49.284  1
253505  98.416  -75.113  49.234  1
253506  98.450  -75.104  49.184  1
253507  98.478  -75.076  49.136  1
253508  98.498  -75.054  49.087  1
253509  98.517  -75.032  49.036  1
253510  98.537  -75.010  48.982  1
253511  98.557  -74.988  48.931  1
253512  98.585  -75.000  48.879  1
253513  98.612  -75.011  48.826  1
253514  98.640  -75.022  48.772  1
253515  98.667  -75.033  48.719  1
253516  98.695  -75.044  48.665  1
253517  98.722  -75.052  48.612  1
253518  98.748  -75.057  48.560  1
253519  98.776  -75.061  48.506  1
253520  98.802  -75.066  48.453  1
253521  98.830  -75.070  48.400  1
253522  98.856  -75.075  48.349  1
253523  98.882  -75.096  48.297  1
253524  98.908  -75.126  48.246  1
253525  98.933  -75.157  48.196  1
253526  98.958  -75.187  48.147  1
253527  98.984  -75.217  48.099  1
253528  99.009  -75.245  48.052  1
253529  99.034  -75.264  48.006  1
253530  99.059  -75.282  47.961  1
253531  99.083  -75.300  47.915  1
253532  99.109  -75.318  47.868  1
253533  99.144  -75.338  47.822  1
253534  99.179  -75.353  47.777  1
253535  99.209  -75.357  47.731  1
253536  99.239  -75.361  47.687  1
253537  99.269  -75.365  47.644  1
253538  99.299  -75.369  47.603  1
253539  99.329  -75.373  47.563  1
253540  99.359  -75.377  47.523  1
253541  99.389  -75.381  47.485  1
253542  99.416  -75.388  47.449  1
253543  99.440  -75.396  47.416  1
253544  99.465  -75.405  47.385  1
253545  99.489  -75.413  47.357  1
253546  99.514  -75.420  47.329  1
253547  99.542  -75.427  47.304  1
253548  99.578  -75.431  47.279  1
253549  99.611  -75.437  47.254  1
253550  99.627  -75.461  47.231  1
253551  99.650  -75.480  47.209  1
253552  99.674  -75.497  47.187  1
253553  99.699  -75.514  47.167  1
253554  99.725  -75.531  47.146  1
253555  99.751  -75.549  47.124  1
253556  99.777  -75.566  47.104  1
253557  99.803  -75.583  47.086  1
253558  99.830  -75.600  47.068  1
253559  99.855  -75.618  47.051  1
253560  99.878  -75.646  47.034  1
253561  99.901  -75.674  47.015  1
253562  99.956  -75.672  46.991  1
253563  100.008  -75.671  46.968  1
253564  100.013  -75.688  46.944  1
253565  100.018  -75.706  46.918  1
253566  100.022  -75.722  46.889  1
253567  100.046  -75.733  46.858  1
253568  100.076  -75.741  46.825  1
253569  100.106  -75.749  46.790  1
253570  100.136  -75.757  46.756  1
253571  100.167  -75.765  46.722  1
253572  100.196  -75.774  46.688  1
253573  100.226  -75.782  46.655  1
253574  100.254  -75.804  46.621  1
253575  100.282  -75.826  46.586  1
253576  100.310  -75.848  46.552  1
253577  100.338  -75.870  46.521  1
253578  100.366  -75.892  46.489  1
253579  100.394  -75.914  46.458  1
253580  100.421  -75.936  46.427  1
253581  100.451  -75.949  46.398  1
253582  100.483  -75.939  46.367  1
253583  100.515  -75.929  46.338  1
253584  100.543  -75.953  46.309  1
253585  100.570  -75.982  46.279  1
253586  100.597  -76.012  46.248  1
253587  100.624  -76.041  46.218  1
253588  100.651  -76.071  46.186  1
253589  100.679  -76.098  46.153  1
253590  100.712  -76.116  46.122  1
253591  100.745  -76.133  46.090  1
253592  100.777  -76.151  46.059  1
253593  100.810  -76.167  46.027  1
253594  100.843  -76.185  45.996  1
253595  100.868  -76.198  45.965  1
253596  100.885  -76.209  45.934  1
253597  100.902  -76.220  45.905  1
253598  100.918  -76.229  45.876  1
253599  100.924  -76.231  45.848  1
253600  100.931  -76.233  45.820  1
253601  100.969  -76.244  45.793  1
253602  101.011  -76.255  45.765  1
253603  101.052  -76.267  45.739  1
253604  101.094  -76.277  45.714  1
253605  101.135  -76.289  45.688  1
253606  101.177  -76.300  45.663  1
253607  101.218  -76.311  45.638  1
253608  101.260  -76.323  45.614  1
253609  101.302  -76.333  45.589  1
253610  101.343  -76.345  45.565  1
253611  101.385  -76.356  45.541  1
253612  101.426  -76.367  45.518  1
253613  101.467  -76.379  45.495  1
253614  101.521  -76.395  45.472  1
253615  101.578  -76.414  45.449  1
253616  101.633  -76.429  45.428  1
253617  101.678  -76.423  45.406  1
253618  101.723  -76.418  45.384  1
253619  101.749  -76.426  45.362  1
253620  101.764  -76.439  45.339  1
253621  101.779  -76.451  45.317  1
253622  101.799  -76.453  45.296  1
253623  101.816  -76.464  45.275  1
253624  101.830  -76.473  45.253  1
253625  101.823  -76.467  45.231  1
253626  101.816  -76.460  45.209  1
253627  101.809  -76.453  45.187  1
253628  101.802  -76.446  45.166  1
253629  101.806  -76.446  45.145  1
253989  92.756  -74.070  54.616  1
253990  92.786  -74.069  54.618  1
253991  92.816  -74.087  54.619  1
253992  92.846  -74.106  54.620  1
253993  92.875  -74.125  54.622  1
253994  92.905  -74.143  54.623  1
253995  92.934  -74.162  54.625  1
253996  92.965  -74.177  54.626  1
253997  92.996  -74.178  54.626  1
253998  93.026  -74.179  54.625  1
253999  93.058  -74.180  54.625  1
254000  93.089  -74.182  54.626  1
254001  93.120  -74.183  54.626  1
254002  93.151  -74.184  54.627  1
254003  93.182  -74.185  54.628  1
254004  93.215  -74.166  54.628  1
254005  93.249  -74.145  54.629  1
254006  93.278  -74.135  54.630  1
254007  93.299  -74.142  54.632  1
254008  93.321  -74.151  54.636  1
254009  93.342  -74.159  54.642  1
254010  93.363  -74.167  54.648  1
254011  93.384  -74.175  54.656  1
254012  93.408  -74.171  54.667  1
254013  93.433  -74.167  54.680  1
254014  93.457  -74.163  54.698  1
254015  93.482  -74.159  54.718  1
254016  93.506  -74.154  54.739  1
254017  93.530  -74.151  54.760  1
254018  93.555  -74.147  54.777  1
254019  93.579  -74.142  54.795  1
254020  93.603  -74.139  54.814  1
254021  93.628  -74.134  54.840  1
254022  93.652  -74.130  54.870  1
254023  93.677  -74.126  54.899  1
254024  93.701  -74.122  54.924  1
254025  93.725  -74.118  54.943  1
254026  93.750  -74.114  54.950  1
254027  93.774  -74.110  54.958  1
254028  93.795  -74.106  54.969  1
254029  93.817  -74.102  54.975  1
254030  93.838  -74.099  54.967  1
254031  93.859  -74.100  54.951  1
254032  93.881  -74.101  54.928  1
254033  93.902  -74.101  54.903  1
254034  93.924  -74.103  54.877  1
254035  93.945  -74.104  54.847  1
254036  93.967  -74.107  54.813  1
254037  93.988  -74.108  54.777  1
254038  94.009  -74.111  54.736  1
254039  94.031  -74.113  54.694  1
254040  94.052  -74.114  54.652  1
254041  94.098  -74.126  54.614  1
254042  94.126  -74.127  54.580  1
254043  94.148  -74.126  54.553  1
254044  94.170  -74.124  54.534  1
254045  94.192  -74.123  54.526  1
254046  94.210  -74.121  54.519  1
254047  94.226  -74.122  54.511  1
254048  94.247  -74.126  54.500  1
254049  94.267  -74.132  54.482  1
254050  94.287  -74.136  54.460  1
254051  94.307  -74.141  54.436  1
254052  94.327  -74.145  54.412  1
254053  94.347  -74.148  54.391  1
254054  94.371  -74.145  54.367  1
254055  94.397  -74.140  54.341  1
254056  94.422  -74.135  54.313  1
254057  94.448  -74.129  54.282  1
254058  94.473  -74.125  54.251  1
254059  94.499  -74.120  54.221  1
254060  94.523  -74.106  54.188  1
254061  94.546  -74.092  54.149  1
254062  94.569  -74.076  54.108  1
254063  94.593  -74.061  54.064  1
254064  94.616  -74.046  54.019  1
254065  94.639  -74.035  53.977  1
254066  94.655  -74.035  53.932  1
254067  94.671  -74.035  53.886  1
254068  94.686  -74.035  53.839  1
254069  94.701  -74.035  53.792  1
254070  94.716  -74.036  53.743  1
254071  94.731  -74.038  53.694  1
254072  94.746  -74.040  53.645  1
254073  94.761  -74.042  53.601  1
254074  94.780  -74.045  53.562  1
254075  94.793  -74.071  53.528  1
254076  94.804  -74.098  53.501  1
254077  94.818  -74.129  53.484  1
254078  94.832  -74.161  53.467  1
254079  94.846  -74.192  53.447  1
254080  94.878  -74.186  53.417  1
254081  94.910  -74.189  53.377  1
254082  94.943  -74.193  53.334  1
254083  94.975  -74.196  53.289  1
254084  95.007  -74.200  53.243  1
254085  95.040  -74.203  53.191  1
254086  95.072  -74.207  53.137  1
254087  95.105  -74.210  53.083  1
254088  95.137  -74.214  53.032  1
254089  95.170  -74.217  52.981  1
254090  95.202  -74.226  52.930  1
254091  95.235  -74.240  52.879  1
254092  95.267  -74.254  52.827  1
254093  95.304  -74.255  52.775  1
254094  95.343  -74.248  52.723  1
254095  95.382  -74.242  52.669  1
254096  95.421  -74.235  52.614  1
254097  95.459  -74.230  52.559  1
254098  95.492  -74.235  52.508  1
254099  95.534  -74.234  52.460  1
254100  95.575  -74.233  52.416  1
254101  95.612  -74.236  52.373  1
254102  95.641  -74.242  52.330  1
254103  95.670  -74.248  52.288  1
254104  95.700  -74.254  52.249  1
254105  95.729  -74.260  52.210  1
254106  95.758  -74.267  52.173  1
254107  95.788  -74.273  52.135  1
254108  95.817  -74.279  52.097  1
254109  95.839  -74.282  52.058  1
254110  95.849  -74.278  52.020  1
254111  95.859  -74.274  51.981  1
254112  95.869  -74.271  51.942  1
254113  95.879  -74.267  51.902  1
254114  95.888  -74.264  51.862  1
254115  95.898  -74.261  51.822  1
254116  95.916  -74.270  51.781  1
254117  95.940  -74.290  51.742  1
254118  95.963  -74.311  51.702  1
254119  95.987  -74.330  51.662  1
254120  96.011  -74.350  51.620  1
254121  96.034  -74.370  51.581  1
254122  96.065  -74.372  51.542  1
254123  96.098  -74.370  51.502  1
254124  96.146  -74.379  51.464  1
254125  96.190  -74.386  51.429  1
254126  96.234  -74.394  51.395  1
254127  96.241  -74.411  51.360  1
254128  96.245  -74.429  51.328  1
254129  96.268  -74.418  51.297  1
254130  96.294  -74.399  51.268  1
254131  96.325  -74.405  51.240  1
254132  96.359  -74.424  51.215  1
254133  96.394  -74.443  51.191  1
254134  96.428  -74.461  51.168  1
254135  96.462  -74.480  51.146  1
254136  96.497  -74.499  51.125  1
254137  96.531  -74.518  51.107  1
254138  96.559  -74.530  51.091  1
254139  96.585  -74.537  51.076  1
254140  96.610  -74.545  51.061  1
254141  96.635  -74.552  51.049  1
254142  96.660  -74.559  51.039  1
254143  96.684  -74.567  51.029  1
254144  96.710  -74.574  51.023  1
254145  96.734  -74.581  51.018  1
254146  96.759  -74.589  51.014  1
254147  96.790  -74.606  51.011  1
254148  96.820  -74.625  51.010  1
254149  96.851  -74.643  51.009  1
254150  96.881  -74.662  51.008  1
254151  96.905  -74.671  51.008  1
254152  96.926  -74.681  51.009  1
254153  96.947  -74.691  51.010  1
254154  96.966  -74.702  51.008  1
254155  96.976  -74.713  51.003  1
254156  96.986  -74.725  50.995  1
254157  97.002  -74.727  50.988  1
254158  97.018  -74.728  50.982  1
254159  97.034  -74.730  50.978  1
254160  97.050  -74.732  50.971  1
254161  97.066  -74.734  50.963  1
254162  97.082  -74.736  50.954  1
254163  97.098  -74.741  50.947  1
254164  97.114  -74.749  50.941  1
254165  97.131  -74.756  50.934  1
254166  97.147  -74.763  50.924  1
254167  97.163  -74.770  50.912  1
254168  97.197  -74.769  50.891  1
254169  97.240  -74.766  50.866  1
254170  97.283  -74.761  50.838  1
254171  97.326  -74.757  50.808  1
254172  97.364  -74.759  50.776  1
254173  97.401  -74.762  50.745  1
254174  97.438  -74.764  50.715  1
254175  97.475  -74.767  50.687  1
254176  97.512  -74.770  50.660  1
254177  97.549  -74.773  50.630  1
254178  97.587  -74.776  50.597  1
254179  97.624  -74.779  50.561  1
254180  97.661  -74.781  50.522  1
254181  97.696  -74.787  50.479  1
254182  97.727  -74.794  50.434  1
254183  97.759  -74.803  50.390  1
254184  97.786  -74.812  50.343  1
254185  97.809  -74.824  50.295  1
254186  97.833  -74.836  50.248  1
254187  97.861  -74.850  50.202  1
254188  97.887  -74.864  50.153  1
254189  97.913  -74.875  50.104  1
254190  97.936  -74.881  50.055  1
254191  97.959  -74.888  50.004  1
254192  97.983  -74.896  49.958  1
254193  98.007  -74.903  49.914  1
254194  98.038  -74.915  49.870  1
254195  98.069  -74.928  49.823  1
254196  98.100  -74.941  49.774  1
254197  98.131  -74.954  49.721  1
254198  98.162  -74.967  49.665  1
254199  98.194  -74.980  49.608  1
254200  98.225  -74.994  49.551  1
254201  98.256  -75.007  49.494  1
254202  98.287  -75.019  49.440  1
254203  98.318  -75.033  49.387  1
254204  98.349  -75.046  49.334  1
254205  98.386  -75.066  49.282  1
254206  98.427  -75.091  49.233  1
254207  98.457  -75.063  49.181  1
254208  98.484  -75.035  49.132  1
254209  98.504  -75.013  49.081  1
254210  98.524  -74.991  49.029  1
254211  98.544  -74.969  48.976  1
254212  98.567  -74.962  48.923  1
254213  98.594  -74.972  48.871  1
254214  98.622  -74.984  48.818  1
254215  98.649  -74.994  48.765  1
254216  98.676  -75.006  48.711  1
254217  98.704  -75.017  48.657  1
254218  98.731  -75.028  48.602  1
254219  98.759  -75.034  48.550  1
254220  98.786  -75.038  48.497  1
254221  98.812  -75.043  48.445  1
254222  98.840  -75.048  48.393  1
254223  98.866  -75.054  48.341  1
254224  98.891  -75.084  48.289  1
254225  98.917  -75.114  48.239  1
254226  98.942  -75.145  48.189  1
254227  98.968  -75.175  48.141  1
254228  98.993  -75.198  48.093  1
254229  99.017  -75.216  48.046  1
254230  99.042  -75.234  48.000  1
254231  99.067  -75.252  47.955  1
254232  99.091  -75.271  47.908  1
254233  99.119  -75.289  47.862  1
254234  99.154  -75.309  47.815  1
254235  99.191  -75.329  47.770  1
254236  99.221  -75.333  47.725  1
254237  99.251  -75.338  47.681  1
254238  99.281  -75.342  47.638  1
254239  99.311  -75.346  47.595  1
254240  99.341  -75.350  47.554  1
254241  99.371  -75.354  47.515  1
254242  99.402  -75.358  47.476  1
254243  99.426  -75.366  47.440  1
254244  99.451  -75.374  47.408  1
254245  99.475  -75.383  47.377  1
254246  99.500  -75.391  47.349  1
254247  99.525  -75.398  47.321  1
254248  99.561  -75.402  47.296  1
254249  99.597  -75.405  47.271  1
254250  99.633  -75.408  47.247  1
254251  99.660  -75.421  47.223  1
254252  99.673  -75.449  47.201  1
254253  99.696  -75.466  47.180  1
254254  99.720  -75.483  47.159  1
254255  99.743  -75.501  47.139  1
254256  99.767  -75.518  47.117  1
254257  99.792  -75.536  47.097  1
254258  99.818  -75.553  47.079  1
254259  99.844  -75.571  47.062  1
254260  99.870  -75.588  47.045  1
254261  99.893  -75.615  47.028  1
254262  99.940  -75.620  47.009  1
254263  99.995  -75.617  46.984  1
254264  100.031  -75.622  46.961  1
254265  100.035  -75.640  46.938  1
254266  100.040  -75.657  46.912  1
254267  100.045  -75.674  46.882  1
254268  100.059  -75.688  46.851  1
254269  100.089  -75.696  46.818  1
254270  100.120  -75.704  46.782  1
254271  100.150  -75.712  46.748  1
254272  100.180  -75.721  46.714  1
254273  100.210  -75.728  46.680  1
254274  100.239  -75.746  46.647  1
254275  100.267  -75.768  46.613  1
254276  100.294  -75.790  46.578  1
254277  100.322  -75.812  46.545  1
254278  100.350  -75.834  46.513  1
254279  100.378  -75.856  46.482  1
254280  100.406  -75.878  46.452  1
254281  100.433  -75.900  46.421  1
254282  100.462  -75.922  46.392  1
254283  100.492  -75.927  46.362  1
254284  100.524  -75.917  46.333  1
254285  100.551  -75.942  46.304  1
254286  100.578  -75.972  46.275  1
254287  100.606  -76.001  46.245  1
254288  100.633  -76.030  46.214  1
254289  100.665  -76.047  46.183  1
254290  100.699  -76.065  46.151  1
254291  100.732  -76.082  46.120  1
254292  100.764  -76.099  46.089  1
254293  100.797  -76.116  46.058  1
254294  100.830  -76.134  46.026  1
254295  100.863  -76.151  45.995  1
254296  100.881  -76.162  45.963  1
254297  100.898  -76.173  45.933  1
254298  100.915  -76.182  45.905  1
254299  100.932  -76.193  45.876  1
254300  100.942  -76.198  45.847  1
254301  100.954  -76.201  45.819  1
254302  100.995  -76.213  45.791  1
254303  101.037  -76.224  45.763  1
254304  101.078  -76.235  45.736  1
254305  101.120  -76.246  45.710  1
254306  101.161  -76.257  45.684  1
254307  101.203  -76.269  45.658  1
254308  101.244  -76.280  45.633  1
254309  101.286  -76.292  45.609  1
254310  101.327  -76.302  45.584  1
254311  101.369  -76.314  45.560  1
254312  101.410  -76.325  45.536  1
254313  101.452  -76.336  45.513  1
254314  101.493  -76.348  45.490  1
254315  101.535  -76.358  45.466  1
254316  101.589  -76.376  45.443  1
254317  101.645  -76.394  45.421  1
254318  101.702  -76.413  45.399  1
254319  101.748  -76.410  45.377  1
254320  101.778  -76.415  45.355  1
254321  101.793  -76.426  45.332  1
254322  101.812  -76.433  45.310  1
254323  101.817  -76.436  45.289  1
254324  101.810  -76.429  45.267  1
254325  101.802  -76.422  45.245  1
254326  101.796  -76.415  45.223  1
254327  101.788  -76.408  45.201  1
254328  101.794  -76.410  45.179  1
254329  101.802  -76.412  45.158  1
254330  101.810  -76.415  45.137  1
254689  92.727  -74.051  54.619  1
254690  92.758  -74.043  54.620  1
254691  92.787  -74.042  54.622  1
254692  92.817  -74.061  54.623  1
254693  92.847  -74.080  54.624  1
254694  92.876  -74.098  54.626  1
254695  92.906  -74.117  54.628  1
254696  92.936  -74.136  54.630  1
254697  92.966  -74.154  54.632  1
254698  92.996  -74.157  54.632  1
254699  93.027  -74.158  54.632  1
254700  93.059  -74.159  54.633  1
254701  93.089  -74.160  54.634  1
254702  93.121  -74.161  54.635  1
254703  93.152  -74.162  54.637  1
254704  93.185  -74.147  54.638  1
254705  93.218  -74.126  54.639  1
254706  93.252  -74.105  54.639  1
254707  93.274  -74.111  54.641  1
254708  93.295  -74.118  54.642  1
254709  93.317  -74.126  54.645  1
254710  93.338  -74.135  54.648  1
254711  93.359  -74.142  54.651  1
254712  93.380  -74.151  54.657  1
254713  93.405  -74.148  54.665  1
254714  93.429  -74.144  54.675  1
254715  93.453  -74.140  54.690  1
254716  93.478  -74.136  54.707  1
254717  93.502  -74.132  54.725  1
254718  93.526  -74.128  54.741  1
254719  93.551  -74.123  54.757  1
254720  93.575  -74.120  54.775  1
254721  93.600  -74.115  54.796  1
254722  93.624  -74.111  54.824  1
254723  93.648  -74.107  54.854  1
254724  93.673  -74.103  54.880  1
254725  93.697  -74.099  54.903  1
254726  93.721  -74.095  54.920  1
254727  93.746  -74.091  54.932  1
254728  93.770  -74.087  54.943  1
254729  93.794  -74.082  54.957  1
254730  93.819  -74.079  54.963  1
254731  93.840  -74.079  54.963  1
254732  93.861  -74.080  54.955  1
254733  93.883  -74.082  54.939  1
254734  93.904  -74.084  54.911  1
254735  93.925  -74.086  54.881  1
254736  93.946  -74.089  54.849  1
254737  93.968  -74.090  54.816  1
254738  93.989  -74.092  54.775  1
254739  94.010  -74.094  54.734  1
254740  94.032  -74.096  54.690  1
254741  94.059  -74.101  54.645  1
254742  94.092  -74.104  54.602  1
254743  94.115  -74.103  54.569  1
254744  94.136  -74.101  54.545  1
254745  94.158  -74.101  54.527  1
254746  94.181  -74.099  54.517  1
254747  94.208  -74.098  54.507  1
254748  94.233  -74.099  54.496  1
254749  94.249  -74.106  54.482  1
254750  94.268  -74.111  54.463  1
254751  94.288  -74.116  54.441  1
254752  94.309  -74.120  54.417  1
254753  94.329  -74.126  54.392  1
254754  94.349  -74.129  54.369  1
254755  94.374  -74.124  54.345  1
254756  94.400  -74.119  54.319  1
254757  94.425  -74.114  54.290  1
254758  94.451  -74.109  54.258  1
254759  94.476  -74.104  54.227  1
254760  94.501  -74.098  54.196  1
254761  94.527  -74.091  54.164  1
254762  94.550  -74.076  54.125  1
254763  94.573  -74.061  54.084  1
254764  94.596  -74.046  54.041  1
254765  94.620  -74.031  53.995  1
254766  94.641  -74.020  53.951  1
254767  94.658  -74.016  53.907  1
254768  94.673  -74.017  53.861  1
254769  94.688  -74.019  53.814  1
254770  94.703  -74.020  53.767  1
254771  94.718  -74.022  53.719  1
254772  94.733  -74.023  53.671  1
254773  94.748  -74.026  53.624  1
254774  94.763  -74.027  53.583  1
254775  94.783  -74.031  53.548  1
254776  94.812  -74.052  53.518  1
254777  94.823  -74.079  53.495  1
254778  94.833  -74.105  53.481  1
254779  94.843  -74.132  53.463  1
254780  94.853  -74.158  53.439  1
254781  94.878  -74.161  53.407  1
254782  94.911  -74.166  53.365  1
254783  94.944  -74.169  53.321  1
254784  94.976  -74.173  53.275  1
254785  95.009  -74.176  53.227  1
254786  95.041  -74.179  53.175  1
254787  95.073  -74.183  53.121  1
254788  95.106  -74.186  53.068  1
254789  95.138  -74.190  53.018  1
254790  95.171  -74.193  52.968  1
254791  95.203  -74.197  52.919  1
254792  95.236  -74.210  52.869  1
254793  95.269  -74.223  52.818  1
254794  95.308  -74.216  52.767  1
254795  95.347  -74.210  52.714  1
254796  95.385  -74.205  52.660  1
254797  95.415  -74.212  52.605  1
254798  95.452  -74.214  52.553  1
254799  95.493  -74.214  52.502  1
254800  95.534  -74.213  52.455  1
254801  95.576  -74.212  52.410  1
254802  95.617  -74.211  52.367  1
254803  95.653  -74.214  52.325  1
254804  95.682  -74.220  52.284  1
254805  95.711  -74.226  52.245  1
254806  95.740  -74.233  52.207  1
254807  95.770  -74.239  52.169  1
254808  95.799  -74.245  52.131  1
254809  95.827  -74.250  52.094  1
254810  95.837  -74.247  52.056  1
254811  95.846  -74.243  52.017  1
254812  95.856  -74.240  51.979  1
254813  95.866  -74.236  51.940  1
254814  95.876  -74.233  51.901  1
254815  95.885  -74.230  51.862  1
254816  95.895  -74.226  51.823  1
254817  95.910  -74.230  51.784  1
254818  95.934  -74.250  51.744  1
254819  95.957  -74.270  51.705  1
254820  95.981  -74.289  51.666  1
254821  96.005  -74.310  51.625  1
254822  96.031  -74.322  51.584  1
254823  96.064  -74.320  51.544  1
254824  96.097  -74.318  51.505  1
254825  96.136  -74.321  51.467  1
254826  96.185  -74.332  51.430  1
254827  96.229  -74.339  51.395  1
254828  96.236  -74.357  51.361  1
254829  96.240  -74.374  51.329  1
254830  96.254  -74.377  51.298  1
254831  96.280  -74.359  51.269  1
254832  96.312  -74.369  51.241  1
254833  96.346  -74.388  51.215  1
254834  96.381  -74.407  51.191  1
254835  96.415  -74.426  51.167  1
254836  96.450  -74.445  51.144  1
254837  96.484  -74.463  51.123  1
254838  96.518  -74.482  51.104  1
254839  96.552  -74.501  51.087  1
254840  96.582  -74.514  51.070  1
254841  96.607  -74.521  51.057  1
254842  96.631  -74.528  51.044  1
254843  96.657  -74.536  51.032  1
254844  96.681  -74.543  51.022  1
254845  96.707  -74.550  51.015  1
254846  96.732  -74.558  51.009  1
254847  96.757  -74.567  51.004  1
254848  96.788  -74.585  51.001  1
254849  96.818  -74.604  50.998  1
254850  96.849  -74.622  50.998  1
254851  96.875  -74.639  50.998  1
254852  96.897  -74.653  50.999  1
254853  96.919  -74.666  51.002  1
254854  96.940  -74.676  51.005  1
254855  96.956  -74.687  51.005  1
254856  96.969  -74.693  51.001  1
254857  96.985  -74.695  50.995  1
254858  97.001  -74.697  50.990  1
254859  97.017  -74.703  50.986  1
254860  97.033  -74.711  50.982  1
254861  97.050  -74.718  50.977  1
254862  97.066  -74.725  50.971  1
254863  97.082  -74.732  50.965  1
254864  97.098  -74.740  50.960  1
254865  97.114  -74.747  50.954  1
254866  97.131  -74.754  50.946  1
254867  97.147  -74.762  50.934  1
254868  97.163  -74.769  50.920  1
254869  97.190  -74.771  50.898  1
254870  97.233  -74.767  50.872  1
254871  97.276  -74.762  50.842  1
254872  97.318  -74.759  50.811  1
254873  97.361  -74.754  50.780  1
254874  97.404  -74.750  50.750  1
254875  97.446  -74.746  50.721  1
254876  97.489  -74.742  50.693  1
254877  97.530  -74.740  50.664  1
254878  97.567  -74.743  50.633  1
254879  97.604  -74.746  50.599  1
254880  97.642  -74.748  50.561  1
254881  97.678  -74.751  50.520  1
254882  97.715  -74.755  50.475  1
254883  97.747  -74.762  50.428  1
254884  97.774  -74.772  50.380  1
254885  97.798  -74.784  50.333  1
254886  97.825  -74.799  50.285  1
254887  97.852  -74.812  50.238  1
254888  97.879  -74.827  50.193  1
254889  97.904  -74.838  50.144  1
254890  97.928  -74.844  50.095  1
254891  97.951  -74.852  50.047  1
254892  97.974  -74.859  49.999  1
254893  97.995  -74.864  49.957  1
254894  98.016  -74.869  49.914  1
254895  98.048  -74.891  49.870  1
254896  98.079  -74.905  49.822  1
254897  98.109  -74.918  49.773  1
254898  98.141  -74.932  49.720  1
254899  98.172  -74.944  49.663  1
254900  98.203  -74.957  49.607  1
254901  98.234  -74.970  49.549  1
254902  98.265  -74.984  49.492  1
254903  98.296  -74.997  49.437  1
254904  98.327  -75.010  49.384  1
254905  98.359  -75.022  49.330  1
254906  98.397  -75.045  49.279  1
254907  98.434  -75.051  49.229  1
254908  98.463  -75.021  49.176  1
254909  98.491  -74.993  49.125  1
254910  98.511  -74.971  49.074  1
254911  98.530  -74.949  49.022  1
254912  98.550  -74.927  48.968  1
254913  98.577  -74.935  48.916  1
254914  98.604  -74.946  48.862  1
254915  98.632  -74.957  48.809  1
254916  98.659  -74.968  48.755  1
254917  98.687  -74.979  48.701  1
254918  98.714  -74.990  48.647  1
254919  98.741  -75.001  48.593  1
254920  98.769  -75.011  48.540  1
254921  98.795  -75.016  48.488  1
254922  98.822  -75.020  48.436  1
254923  98.850  -75.025  48.384  1
254924  98.876  -75.041  48.332  1
254925  98.901  -75.072  48.282  1
254926  98.926  -75.102  48.232  1
254927  98.952  -75.132  48.183  1
254928  98.977  -75.151  48.133  1
254929  99.001  -75.169  48.086  1
254930  99.026  -75.187  48.039  1
254931  99.051  -75.205  47.993  1
254932  99.075  -75.223  47.947  1
254933  99.100  -75.242  47.901  1
254934  99.129  -75.261  47.855  1
254935  99.165  -75.280  47.809  1
254936  99.201  -75.300  47.764  1
254937  99.233  -75.311  47.719  1
254938  99.264  -75.314  47.674  1
254939  99.293  -75.318  47.631  1
254940  99.324  -75.323  47.587  1
254941  99.354  -75.326  47.547  1
254942  99.383  -75.330  47.507  1
254943  99.412  -75.336  47.469  1
254944  99.437  -75.344  47.432  1
254945  99.462  -75.352  47.400  1
254946  99.486  -75.361  47.369  1
254947  99.510  -75.369  47.341  1
254948  99.545  -75.373  47.314  1
254949  99.581  -75.376  47.288  1
254950  99.617  -75.380  47.263  1
254951  99.652  -75.383  47.239  1
254952  99.688  -75.386  47.215  1
254953  99.709  -75.405  47.193  1
254954  99.723  -75.432  47.172  1
254955  99.742  -75.453  47.151  1
254956  99.766  -75.471  47.131  1
254957  99.789  -75.488  47.110  1
254958  99.812  -75.505  47.090  1
254959  99.836  -75.523  47.072  1
254960  99.860  -75.540  47.055  1
254961  99.885  -75.558  47.039  1
254962  99.924  -75.569  47.022  1
254963  99.971  -75.577  47.002  1
254964  100.018  -75.584  46.978  1
254965  100.049  -75.589  46.955  1
254966  100.057  -75.592  46.931  1
254967  100.062  -75.609  46.904  1
254968  100.067  -75.626  46.875  1
254969  100.073  -75.643  46.843  1
254970  100.103  -75.651  46.809  1
254971  100.133  -75.659  46.772  1
254972  100.163  -75.668  46.739  1
254973  100.194  -75.675  46.705  1
254974  100.223  -75.687  46.671  1
254975  100.251  -75.709  46.638  1
254976  100.279  -75.731  46.604  1
254977  100.307  -75.753  46.570  1
254978  100.335  -75.775  46.538  1
254979  100.362  -75.798  46.506  1
254980  100.390  -75.820  46.476  1
254981  100.418  -75.842  46.445  1
254982  100.446  -75.864  46.415  1
254983  100.474  -75.886  46.385  1
254984  100.501  -75.908  46.356  1
254985  100.533  -75.904  46.328  1
254986  100.560  -75.932  46.299  1
254987  100.587  -75.962  46.271  1
254988  100.620  -75.979  46.241  1
254989  100.653  -75.997  46.212  1
254990  100.686  -76.013  46.181  1
254991  100.718  -76.031  46.149  1
254992  100.751  -76.048  46.119  1
254993  100.784  -76.066  46.089  1
254994  100.817  -76.083  46.058  1
254995  100.850  -76.100  46.027  1
254996  100.876  -76.114  45.995  1
254997  100.893  -76.125  45.964  1
254998  100.910  -76.135  45.933  1
254999  100.928  -76.146  45.904  1
255000  100.945  -76.157  45.876  1
255001  100.959  -76.164  45.847  1
255002  100.979  -76.170  45.818  1
255003  101.021  -76.182  45.790  1
255004  101.062  -76.193  45.761  1
255005  101.104  -76.204  45.733  1
255006  101.145  -76.215  45.707  1
255007  101.187  -76.226  45.680  1
255008  101.229  -76.238  45.654  1
255009  101.270  -76.249  45.629  1
255010  101.312  -76.260  45.604  1
255011  101.353  -76.271  45.579  1
255012  101.395  -76.282  45.554  1
255013  101.436  -76.294  45.530  1
255014  101.477  -76.305  45.507  1
255015  101.519  -76.316  45.483  1
255016  101.560  -76.327  45.460  1
255017  101.602  -76.339  45.437  1
255018  101.656  -76.356  45.414  1
255019  101.713  -76.374  45.392  1
255020  101.770  -76.392  45.369  1
255021  101.807  -76.402  45.347  1
255022  101.803  -76.398  45.326  1
255023  101.796  -76.391  45.303  1
255024  101.789  -76.384  45.281  1
255025  101.782  -76.377  45.259  1
255026  101.775  -76.370  45.237  1
255027  101.782  -76.373  45.215  1
255028  101.790  -76.376  45.193  1
255029  101.798  -76.378  45.171  1
255030  101.806  -76.381  45.149  1
255031  101.813  -76.383  45.128  1
255389  92.702  -74.034  54.623  1
255390  92.728  -74.024  54.624  1
255391  92.759  -74.016  54.624  1
255392  92.789  -74.017  54.626  1
255393  92.818  -74.035  54.627  1
255394  92.848  -74.054  54.628  1
255395  92.878  -74.073  54.630  1
255396  92.907  -74.091  54.632  1
255397  92.937  -74.110  54.634  1
255398  92.967  -74.129  54.636  1
255399  92.997  -74.136  54.637  1
255400  93.028  -74.136  54.638  1
255401  93.059  -74.138  54.640  1
255402  93.090  -74.139  54.641  1
255403  93.122  -74.140  54.642  1
255404  93.154  -74.128  54.645  1
255405  93.188  -74.107  54.647  1
255406  93.221  -74.086  54.648  1
255407  93.250  -74.078  54.649  1
255408  93.271  -74.086  54.650  1
255409  93.292  -74.094  54.651  1
255410  93.313  -74.102  54.652  1
255411  93.334  -74.111  54.655  1
255412  93.355  -74.117  54.656  1
255413  93.379  -74.121  54.659  1
255414  93.406  -74.114  54.664  1
255415  93.430  -74.110  54.673  1
255416  93.454  -74.105  54.684  1
255417  93.479  -74.101  54.697  1
255418  93.503  -74.098  54.711  1
255419  93.527  -74.093  54.724  1
255420  93.552  -74.089  54.738  1
255421  93.576  -74.085  54.756  1
255422  93.600  -74.081  54.778  1
255423  93.625  -74.077  54.806  1
255424  93.649  -74.073  54.834  1
255425  93.674  -74.069  54.859  1
255426  93.698  -74.064  54.879  1
255427  93.722  -74.060  54.893  1
255428  93.747  -74.057  54.908  1
255429  93.771  -74.052  54.924  1
255430  93.796  -74.048  54.939  1
255431  93.819  -74.055  54.948  1
255432  93.840  -74.057  54.954  1
255433  93.861  -74.060  54.952  1
255434  93.883  -74.062  54.942  1
255435  93.904  -74.065  54.913  1
255436  93.926  -74.068  54.881  1
255437  93.947  -74.070  54.847  1
255438  93.969  -74.073  54.813  1
255439  93.990  -74.076  54.771  1
255440  94.011  -74.078  54.728  1
255441  94.033  -74.079  54.684  1
255442  94.059  -74.082  54.638  1
255443  94.082  -74.080  54.591  1
255444  94.109  -74.079  54.559  1
255445  94.135  -74.078  54.536  1
255446  94.161  -74.076  54.519  1
255447  94.188  -74.075  54.507  1
255448  94.217  -74.074  54.495  1
255449  94.248  -74.073  54.481  1
255450  94.269  -74.077  54.465  1
255451  94.285  -74.084  54.444  1
255452  94.301  -74.091  54.420  1
255453  94.318  -74.097  54.396  1
255454  94.334  -74.104  54.370  1
255455  94.351  -74.108  54.346  1
255456  94.377  -74.103  54.321  1
255457  94.402  -74.098  54.295  1
255458  94.428  -74.093  54.265  1
255459  94.453  -74.088  54.234  1
255460  94.479  -74.082  54.203  1
255461  94.504  -74.077  54.172  1
255462  94.530  -74.072  54.140  1
255463  94.553  -74.060  54.103  1
255464  94.577  -74.045  54.062  1
255465  94.600  -74.031  54.019  1
255466  94.621  -74.020  53.971  1
255467  94.641  -74.010  53.926  1
255468  94.660  -74.001  53.880  1
255469  94.675  -74.003  53.834  1
255470  94.690  -74.004  53.788  1
255471  94.705  -74.006  53.741  1
255472  94.720  -74.007  53.694  1
255473  94.735  -74.009  53.648  1
255474  94.750  -74.010  53.604  1
255475  94.765  -74.013  53.567  1
255476  94.785  -74.017  53.535  1
255477  94.832  -74.034  53.509  1
255478  94.842  -74.060  53.490  1
255479  94.852  -74.087  53.477  1
255480  94.862  -74.114  53.458  1
255481  94.873  -74.140  53.430  1
255482  94.892  -74.141  53.395  1
255483  94.913  -74.136  53.351  1
255484  94.940  -74.136  53.306  1
255485  94.974  -74.141  53.259  1
255486  95.007  -74.147  53.211  1
255487  95.041  -74.152  53.157  1
255488  95.074  -74.157  53.105  1
255489  95.107  -74.163  53.054  1
255490  95.140  -74.167  53.005  1
255491  95.172  -74.170  52.957  1
255492  95.205  -74.173  52.909  1
255493  95.237  -74.179  52.860  1
255494  95.272  -74.184  52.810  1
255495  95.310  -74.180  52.759  1
255496  95.340  -74.187  52.706  1
255497  95.370  -74.194  52.652  1
255498  95.411  -74.194  52.597  1
255499  95.452  -74.193  52.546  1
255500  95.494  -74.192  52.497  1
255501  95.535  -74.191  52.450  1
255502  95.577  -74.190  52.405  1
255503  95.618  -74.189  52.362  1
255504  95.660  -74.189  52.320  1
255505  95.693  -74.192  52.280  1
255506  95.723  -74.198  52.242  1
255507  95.752  -74.205  52.203  1
255508  95.781  -74.211  52.165  1
255509  95.811  -74.217  52.127  1
255510  95.824  -74.216  52.090  1
255511  95.834  -74.212  52.052  1
255512  95.843  -74.208  52.014  1
255513  95.853  -74.205  51.977  1
255514  95.863  -74.201  51.939  1
255515  95.873  -74.198  51.901  1
255516  95.883  -74.195  51.863  1
255517  95.892  -74.191  51.825  1
255518  95.904  -74.190  51.786  1
255519  95.927  -74.210  51.747  1
255520  95.951  -74.230  51.709  1
255521  95.975  -74.249  51.669  1
255522  95.999  -74.269  51.629  1
255523  96.030  -74.270  51.588  1
255524  96.063  -74.269  51.547  1
255525  96.096  -74.267  51.507  1
255526  96.129  -74.264  51.470  1
255527  96.180  -74.277  51.432  1
255528  96.225  -74.285  51.397  1
255529  96.232  -74.302  51.363  1
255530  96.236  -74.320  51.331  1
255531  96.240  -74.336  51.300  1
255532  96.266  -74.319  51.270  1
255533  96.300  -74.333  51.241  1
255534  96.334  -74.352  51.215  1
255535  96.368  -74.371  51.190  1
255536  96.402  -74.389  51.166  1
255537  96.437  -74.408  51.143  1
255538  96.471  -74.427  51.121  1
255539  96.506  -74.446  51.102  1
255540  96.540  -74.465  51.084  1
255541  96.574  -74.484  51.067  1
255542  96.604  -74.498  51.053  1
255543  96.629  -74.505  51.040  1
255544  96.654  -74.512  51.027  1
255545  96.679  -74.520  51.017  1
255546  96.703  -74.527  51.009  1
255547  96.729  -74.534  51.002  1
255548  96.755  -74.546  50.996  1
255549  96.786  -74.564  50.992  1
255550  96.816  -74.583  50.989  1
255551  96.844  -74.600  50.988  1
255552  96.866  -74.615  50.989  1
255553  96.888  -74.628  50.991  1
255554  96.910  -74.643  50.995  1
255555  96.932  -74.656  50.999  1
255556  96.952  -74.667  51.001  1
255557  96.969  -74.679  50.999  1
255558  96.985  -74.687  50.996  1
255559  97.002  -74.694  50.992  1
255560  97.018  -74.702  50.989  1
255561  97.034  -74.709  50.986  1
255562  97.050  -74.716  50.982  1
255563  97.067  -74.724  50.979  1
255564  97.083  -74.731  50.975  1
255565  97.099  -74.738  50.971  1
255566  97.115  -74.745  50.965  1
255567  97.131  -74.753  50.956  1
255568  97.148  -74.759  50.943  1
255569  97.164  -74.767  50.927  1
255570  97.183  -74.773  50.904  1
255571  97.226  -74.769  50.878  1
255572  97.268  -74.765  50.848  1
255573  97.311  -74.760  50.816  1
255574  97.354  -74.756  50.786  1
255575  97.396  -74.752  50.756  1
255576  97.439  -74.747  50.728  1
255577  97.482  -74.744  50.699  1
255578  97.525  -74.739  50.668  1
255579  97.567  -74.735  50.635  1
255580  97.610  -74.731  50.599  1
255581  97.653  -74.727  50.560  1
255582  97.696  -74.722  50.517  1
255583  97.734  -74.724  50.471  1
255584  97.763  -74.734  50.422  1
255585  97.790  -74.747  50.372  1
255586  97.817  -74.761  50.323  1
255587  97.844  -74.775  50.274  1
255588  97.870  -74.789  50.227  1
255589  97.896  -74.800  50.182  1
255590  97.919  -74.808  50.134  1
255591  97.943  -74.815  50.087  1
255592  97.964  -74.820  50.042  1
255593  97.984  -74.825  49.998  1
255594  98.005  -74.829  49.957  1
255595  98.026  -74.835  49.914  1
255596  98.057  -74.856  49.870  1
255597  98.088  -74.878  49.822  1
255598  98.119  -74.895  49.771  1
255599  98.150  -74.908  49.718  1
255600  98.181  -74.922  49.662  1
255601  98.213  -74.935  49.605  1
255602  98.243  -74.947  49.547  1
255603  98.275  -74.960  49.489  1
255604  98.306  -74.974  49.433  1
255605  98.337  -74.987  49.379  1
255606  98.368  -75.000  49.326  1
255607  98.409  -75.025  49.274  1
255608  98.441  -75.009  49.223  1
255609  98.471  -74.979  49.170  1
255610  98.497  -74.952  49.117  1
255611  98.517  -74.929  49.066  1
255612  98.537  -74.907  49.014  1
255613  98.559  -74.897  48.961  1
255614  98.586  -74.907  48.908  1
255615  98.614  -74.919  48.854  1
255616  98.641  -74.929  48.800  1
255617  98.669  -74.941  48.746  1
255618  98.696  -74.952  48.692  1
255619  98.723  -74.963  48.637  1
255620  98.751  -74.974  48.583  1
255621  98.778  -74.985  48.531  1
255622  98.805  -74.992  48.479  1
255623  98.833  -74.997  48.427  1
255624  98.859  -75.001  48.375  1
255625  98.885  -75.029  48.324  1
255626  98.911  -75.060  48.274  1
255627  98.935  -75.085  48.225  1
255628  98.960  -75.103  48.176  1
255629  98.985  -75.121  48.126  1
255630  99.009  -75.139  48.079  1
255631  99.034  -75.157  48.032  1
255632  99.059  -75.176  47.986  1
255633  99.083  -75.195  47.940  1
255634  99.108  -75.213  47.894  1
255635  99.139  -75.232  47.849  1
255636  99.175  -75.251  47.804  1
255637  99.211  -75.271  47.759  1
255638  99.246  -75.287  47.713  1
255639  99.276  -75.291  47.668  1
255640  99.306  -75.295  47.624  1
255641  99.336  -75.299  47.581  1
255642  99.366  -75.303  47.540  1
255643  99.396  -75.308  47.501  1
255644  99.423  -75.314  47.463  1
255645  99.447  -75.322  47.425  1
255646  99.472  -75.330  47.392  1
255647  99.496  -75.339  47.361  1
255648  99.529  -75.343  47.333  1
255649  99.565  -75.347  47.305  1
255650  99.600  -75.350  47.279  1
255651  99.636  -75.354  47.254  1
255652  99.672  -75.357  47.231  1
255653  99.708  -75.360  47.208  1
255654  99.744  -75.364  47.186  1
255655  99.759  -75.389  47.165  1
255656  99.772  -75.416  47.145  1
255657  99.788  -75.440  47.123  1
255658  99.811  -75.458  47.103  1
255659  99.835  -75.475  47.083  1
255660  99.859  -75.493  47.064  1
255661  99.882  -75.510  47.047  1
255662  99.911  -75.533  47.031  1
255663  99.946  -75.537  47.014  1
255664  99.993  -75.545  46.994  1
255665  100.041  -75.553  46.970  1
255666  100.067  -75.557  46.947  1
255667  100.076  -75.557  46.923  1
255668  100.084  -75.561  46.896  1
255669  100.089  -75.578  46.866  1
255670  100.093  -75.596  46.834  1
255671  100.117  -75.606  46.799  1
255672  100.147  -75.614  46.763  1
255673  100.177  -75.622  46.729  1
255674  100.207  -75.630  46.695  1
255675  100.235  -75.651  46.662  1
255676  100.263  -75.673  46.629  1
255677  100.291  -75.695  46.596  1
255678  100.319  -75.718  46.562  1
255679  100.347  -75.740  46.530  1
255680  100.374  -75.762  46.499  1
255681  100.402  -75.784  46.469  1
255682  100.430  -75.806  46.439  1
255683  100.458  -75.828  46.410  1
255684  100.486  -75.850  46.380  1
255685  100.514  -75.872  46.351  1
255686  100.542  -75.892  46.323  1
255687  100.574  -75.911  46.295  1
255688  100.607  -75.928  46.267  1
255689  100.640  -75.945  46.238  1
255690  100.673  -75.963  46.208  1
255691  100.705  -75.980  46.178  1
255692  100.739  -75.997  46.147  1
255693  100.771  -76.015  46.117  1
255694  100.804  -76.032  46.088  1
255695  100.837  -76.049  46.058  1
255696  100.869  -76.066  46.027  1
255697  100.889  -76.078  45.997  1
255698  100.906  -76.088  45.966  1
255699  100.923  -76.098  45.934  1
255700  100.940  -76.109  45.905  1
255701  100.958  -76.119  45.875  1
255702  100.975  -76.130  45.847  1
255703  101.005  -76.139  45.818  1
255704  101.047  -76.151  45.789  1
255705  101.088  -76.162  45.760  1
255706  101.130  -76.173  45.732  1
255707  101.171  -76.184  45.704  1
255708  101.213  -76.195  45.678  1
255709  101.254  -76.207  45.650  1
255710  101.296  -76.218  45.624  1
255711  101.337  -76.229  45.599  1
255712  101.379  -76.240  45.574  1
255713  101.420  -76.251  45.549  1
255714  101.462  -76.263  45.525  1
255715  101.503  -76.274  45.501  1
255716  101.545  -76.285  45.477  1
255717  101.586  -76.296  45.454  1
255718  101.628  -76.307  45.430  1
255719  101.669  -76.319  45.407  1
255720  101.723  -76.336  45.385  1
255721  101.738  -76.375  45.362  1
255722  101.782  -76.352  45.339  1
255723  101.775  -76.345  45.317  1
255724  101.768  -76.339  45.295  1
255725  101.763  -76.333  45.273  1
255726  101.771  -76.336  45.251  1
255727  101.779  -76.339  45.229  1
255728  101.786  -76.342  45.206  1
255729  101.794  -76.344  45.184  1
255730  101.802  -76.347  45.162  1
255731  101.809  -76.349  45.140  1
255732  101.817  -76.352  45.118  1
256089  92.683  -74.007  54.626  1
256090  92.703  -74.007  54.627  1
256091  92.730  -73.998  54.627  1
256092  92.760  -73.989  54.628  1
256093  92.790  -73.990  54.629  1
256094  92.819  -74.009  54.630  1
256095  92.849  -74.028  54.631  1
256096  92.879  -74.046  54.633  1
256097  92.909  -74.065  54.635  1
256098  92.938  -74.084  54.637  1
256099  92.968  -74.102  54.640  1
256100  92.998  -74.114  54.641  1
256101  93.029  -74.115  54.643  1
256102  93.060  -74.116  54.645  1
256103  93.091  -74.117  54.647  1
256104  93.124  -74.109  54.649  1
256105  93.157  -74.088  54.651  1
256106  93.191  -74.067  54.653  1
256107  93.224  -74.047  54.655  1
256108  93.246  -74.054  54.657  1
256109  93.267  -74.062  54.659  1
256110  93.288  -74.070  54.660  1
256111  93.309  -74.078  54.660  1
256112  93.330  -74.083  54.662  1
256113  93.350  -74.088  54.662  1
256114  93.380  -74.090  54.663  1
256115  93.409  -74.087  54.665  1
256116  93.431  -74.074  54.671  1
256117  93.455  -74.070  54.679  1
256118  93.480  -74.066  54.689  1
256119  93.504  -74.061  54.700  1
256120  93.529  -74.057  54.711  1
256121  93.553  -74.053  54.724  1
256122  93.577  -74.049  54.740  1
256123  93.602  -74.045  54.759  1
256124  93.626  -74.041  54.784  1
256125  93.650  -74.037  54.808  1
256126  93.675  -74.032  54.830  1
256127  93.699  -74.029  54.847  1
256128  93.723  -74.025  54.862  1
256129  93.748  -74.020  54.879  1
256130  93.785  -74.026  54.897  1
256131  93.807  -74.032  54.917  1
256132  93.819  -74.032  54.936  1
256133  93.840  -74.034  54.942  1
256134  93.861  -74.036  54.940  1
256135  93.883  -74.038  54.934  1
256136  93.904  -74.042  54.908  1
256137  93.925  -74.045  54.877  1
256138  93.947  -74.048  54.842  1
256139  93.969  -74.050  54.801  1
256140  93.990  -74.053  54.762  1
256141  94.011  -74.056  54.720  1
256142  94.033  -74.057  54.675  1
256143  94.062  -74.058  54.628  1
256144  94.089  -74.057  54.581  1
256145  94.115  -74.055  54.549  1
256146  94.142  -74.054  54.527  1
256147  94.168  -74.052  54.509  1
256148  94.196  -74.051  54.497  1
256149  94.227  -74.050  54.482  1
256150  94.258  -74.049  54.466  1
256151  94.289  -74.048  54.448  1
256152  94.306  -74.055  54.424  1
256153  94.322  -74.062  54.400  1
256154  94.338  -74.068  54.374  1
256155  94.354  -74.075  54.349  1
256156  94.367  -74.079  54.324  1
256157  94.376  -74.073  54.299  1
256158  94.402  -74.071  54.272  1
256159  94.429  -74.068  54.242  1
256160  94.455  -74.065  54.210  1
256161  94.481  -74.061  54.179  1
256162  94.506  -74.056  54.148  1
256163  94.532  -74.051  54.117  1
256164  94.557  -74.045  54.081  1
256165  94.580  -74.030  54.040  1
256166  94.601  -74.020  53.996  1
256167  94.621  -74.010  53.948  1
256168  94.641  -74.001  53.902  1
256169  94.661  -73.991  53.856  1
256170  94.677  -73.988  53.810  1
256171  94.692  -73.990  53.764  1
256172  94.707  -73.991  53.718  1
256173  94.722  -73.993  53.672  1
256174  94.737  -73.995  53.628  1
256175  94.752  -73.996  53.587  1
256176  94.767  -73.998  53.553  1
256177  94.788  -74.003  53.525  1
256178  94.835  -74.020  53.502  1
256179  94.861  -74.042  53.487  1
256180  94.872  -74.069  53.471  1
256181  94.882  -74.095  53.449  1
256182  94.892  -74.122  53.419  1
256183  94.910  -74.126  53.379  1
256184  94.931  -74.120  53.336  1
256185  94.953  -74.115  53.290  1
256186  94.974  -74.110  53.243  1
256187  95.002  -74.110  53.195  1
256188  95.035  -74.116  53.143  1
256189  95.069  -74.121  53.092  1
256190  95.103  -74.126  53.043  1
256191  95.136  -74.132  52.995  1
256192  95.170  -74.138  52.946  1
256193  95.203  -74.144  52.898  1
256194  95.237  -74.149  52.850  1
256195  95.266  -74.162  52.801  1
256196  95.296  -74.169  52.749  1
256197  95.329  -74.174  52.697  1
256198  95.370  -74.173  52.644  1
256199  95.411  -74.173  52.590  1
256200  95.453  -74.171  52.539  1
256201  95.494  -74.170  52.491  1
256202  95.536  -74.170  52.445  1
256203  95.578  -74.169  52.400  1
256204  95.619  -74.168  52.358  1
256205  95.661  -74.167  52.316  1
256206  95.702  -74.166  52.276  1
256207  95.734  -74.170  52.238  1
256208  95.763  -74.177  52.200  1
256209  95.793  -74.183  52.162  1
256210  95.812  -74.184  52.124  1
256211  95.821  -74.181  52.087  1
256212  95.831  -74.177  52.048  1
256213  95.841  -74.173  52.011  1
256214  95.850  -74.170  51.975  1
256215  95.861  -74.167  51.938  1
256216  95.870  -74.164  51.901  1
256217  95.880  -74.160  51.864  1
256218  95.890  -74.156  51.826  1
256219  95.899  -74.153  51.787  1
256220  95.921  -74.170  51.750  1
256221  95.945  -74.189  51.712  1
256222  95.969  -74.209  51.673  1
256223  95.995  -74.221  51.632  1
256224  96.029  -74.219  51.591  1
256225  96.062  -74.217  51.549  1
256226  96.095  -74.215  51.509  1
256227  96.128  -74.213  51.472  1
256228  96.161  -74.211  51.435  1
256229  96.220  -74.230  51.400  1
256230  96.227  -74.247  51.366  1
256231  96.231  -74.264  51.333  1
256232  96.235  -74.283  51.301  1
256233  96.252  -74.279  51.271  1
256234  96.287  -74.298  51.242  1
256235  96.321  -74.317  51.215  1
256236  96.356  -74.335  51.189  1
256237  96.390  -74.354  51.165  1
256238  96.424  -74.373  51.141  1
256239  96.458  -74.392  51.120  1
256240  96.493  -74.411  51.100  1
256241  96.527  -74.430  51.081  1
256242  96.561  -74.449  51.065  1
256243  96.596  -74.468  51.049  1
256244  96.626  -74.481  51.035  1
256245  96.651  -74.489  51.024  1
256246  96.676  -74.496  51.013  1
256247  96.700  -74.503  51.003  1
256248  96.726  -74.511  50.996  1
256249  96.754  -74.524  50.990  1
256250  96.784  -74.543  50.985  1
256251  96.814  -74.561  50.982  1
256252  96.835  -74.575  50.981  1
256253  96.858  -74.590  50.981  1
256254  96.879  -74.604  50.984  1
256255  96.900  -74.611  50.989  1
256256  96.921  -74.616  50.993  1
256257  96.946  -74.632  50.996  1
256258  96.963  -74.644  50.997  1
256259  96.980  -74.656  50.998  1
256260  96.997  -74.668  50.996  1
256261  97.014  -74.681  50.994  1
256262  97.031  -74.692  50.991  1
256263  97.048  -74.704  50.988  1
256264  97.066  -74.716  50.986  1
256265  97.083  -74.728  50.984  1
256266  97.099  -74.736  50.981  1
256267  97.115  -74.744  50.974  1
256268  97.132  -74.750  50.964  1
256269  97.148  -74.758  50.951  1
256270  97.164  -74.766  50.933  1
256271  97.180  -74.772  50.910  1
256272  97.219  -74.770  50.884  1
256273  97.261  -74.766  50.855  1
256274  97.304  -74.762  50.824  1
256275  97.347  -74.758  50.792  1
256276  97.389  -74.753  50.763  1
256277  97.432  -74.749  50.734  1
256278  97.474  -74.745  50.705  1
256279  97.520  -74.735  50.672  1
256280  97.567  -74.722  50.636  1
256281  97.613  -74.709  50.597  1
256282  97.660  -74.696  50.557  1
256283  97.708  -74.682  50.512  1
256284  97.743  -74.685  50.465  1
256285  97.776  -74.705  50.417  1
256286  97.808  -74.724  50.366  1
256287  97.835  -74.737  50.314  1
256288  97.862  -74.752  50.263  1
256289  97.888  -74.763  50.216  1
256290  97.911  -74.771  50.171  1
256291  97.932  -74.775  50.125  1
256292  97.953  -74.781  50.081  1
256293  97.973  -74.785  50.039  1
256294  97.994  -74.791  50.000  1
256295  98.014  -74.795  49.957  1
256296  98.035  -74.800  49.914  1
256297  98.067  -74.822  49.869  1
256298  98.097  -74.844  49.821  1
256299  98.129  -74.866  49.769  1
256300  98.160  -74.885  49.715  1
256301  98.191  -74.898  49.661  1
256302  98.222  -74.911  49.604  1
256303  98.253  -74.925  49.544  1
256304  98.284  -74.938  49.485  1
256305  98.315  -74.950  49.429  1
256306  98.347  -74.964  49.373  1
256307  98.379  -74.979  49.320  1
256308  98.419  -74.997  49.268  1
256309  98.448  -74.967  49.216  1
256310  98.477  -74.938  49.162  1
256311  98.504  -74.910  49.109  1
256312  98.523  -74.888  49.058  1
256313  98.543  -74.866  49.007  1
256314  98.569  -74.869  48.955  1
256315  98.596  -74.881  48.900  1
256316  98.624  -74.891  48.845  1
256317  98.651  -74.903  48.791  1
256318  98.678  -74.913  48.737  1
256319  98.706  -74.925  48.682  1
256320  98.733  -74.935  48.628  1
256321  98.761  -74.947  48.574  1
256322  98.788  -74.958  48.522  1
256323  98.815  -74.969  48.469  1
256324  98.843  -74.974  48.417  1
256325  98.869  -74.988  48.366  1
256326  98.895  -75.018  48.316  1
256327  98.919  -75.037  48.265  1
256328  98.944  -75.056  48.216  1
256329  98.969  -75.074  48.167  1
256330  98.993  -75.092  48.119  1
256331  99.018  -75.110  48.071  1
256332  99.043  -75.129  48.025  1
256333  99.067  -75.147  47.979  1
256334  99.092  -75.165  47.933  1
256335  99.117  -75.184  47.887  1
256336  99.149  -75.203  47.842  1
256337  99.186  -75.223  47.796  1
256338  99.221  -75.242  47.751  1
256339  99.257  -75.261  47.705  1
256340  99.288  -75.268  47.660  1
256341  99.318  -75.272  47.617  1
256342  99.348  -75.276  47.574  1
256343  99.378  -75.280  47.533  1
256344  99.409  -75.284  47.493  1
256345  99.433  -75.292  47.455  1
256346  99.458  -75.300  47.418  1
256347  99.483  -75.308  47.385  1
256348  99.512  -75.314  47.355  1
256349  99.548  -75.317  47.325  1
256350  99.584  -75.321  47.297  1
256351  99.620  -75.324  47.271  1
256352  99.656  -75.327  47.247  1
256353  99.692  -75.331  47.223  1
256354  99.727  -75.334  47.201  1
256355  99.763  -75.338  47.179  1
256356  99.795  -75.345  47.158  1
256357  99.808  -75.372  47.138  1
256358  99.822  -75.399  47.116  1
256359  99.835  -75.427  47.095  1
256360  99.857  -75.445  47.075  1
256361  99.883  -75.464  47.056  1
256362  99.913  -75.489  47.039  1
256363  99.940  -75.505  47.023  1
256364  99.968  -75.506  47.005  1
256365  100.015  -75.514  46.985  1
256366  100.063  -75.521  46.962  1
256367  100.085  -75.524  46.939  1
256368  100.094  -75.525  46.914  1
256369  100.103  -75.525  46.887  1
256370  100.111  -75.530  46.856  1
256371  100.116  -75.547  46.823  1
256372  100.131  -75.561  46.789  1
256373  100.161  -75.569  46.753  1
256374  100.191  -75.577  46.719  1
256375  100.220  -75.593  46.686  1
256376  100.248  -75.615  46.653  1
256377  100.275  -75.637  46.620  1
256378  100.303  -75.659  46.587  1
256379  100.331  -75.681  46.554  1
256380  100.359  -75.703  46.522  1
256381  100.387  -75.725  46.493  1
256382  100.415  -75.747  46.463  1
256383  100.442  -75.769  46.433  1
256384  100.471  -75.793  46.404  1
256385  100.499  -75.821  46.376  1
256386  100.528  -75.847  46.347  1
256387  100.556  -75.864  46.319  1
256388  100.596  -75.868  46.291  1
256389  100.628  -75.887  46.263  1
256390  100.661  -75.906  46.233  1
256391  100.693  -75.926  46.204  1
256392  100.725  -75.946  46.175  1
256393  100.758  -75.963  46.144  1
256394  100.791  -75.981  46.116  1
256395  100.824  -75.998  46.087  1
256396  100.857  -76.016  46.058  1
256397  100.884  -76.030  46.028  1
256398  100.902  -76.041  45.998  1
256399  100.919  -76.051  45.967  1
256400  100.936  -76.062  45.936  1
256401  100.955  -76.073  45.906  1
256402  100.974  -76.084  45.876  1
256403  100.991  -76.093  45.848  1
256404  101.016  -76.100  45.819  1
256405  101.058  -76.112  45.788  1
256406  101.100  -76.123  45.759  1
256407  101.141  -76.135  45.730  1
256408  101.183  -76.146  45.701  1
256409  101.225  -76.157  45.674  1
256410  101.267  -76.169  45.647  1
256411  101.308  -76.180  45.621  1
256412  101.350  -76.191  45.595  1
256413  101.392  -76.203  45.569  1
256414  101.433  -76.214  45.544  1
256415  101.475  -76.225  45.519  1
256416  101.516  -76.236  45.495  1
256417  101.558  -76.248  45.471  1
256418  101.600  -76.259  45.447  1
256419  101.641  -76.270  45.423  1
256420  101.684  -76.281  45.400  1
256421  101.715  -76.291  45.378  1
256422  101.733  -76.317  45.355  1
256423  101.755  -76.301  45.332  1
256424  101.752  -76.296  45.310  1
256425  101.759  -76.299  45.287  1
256426  101.767  -76.302  45.264  1
256427  101.775  -76.304  45.242  1
256428  101.782  -76.307  45.220  1
256429  101.790  -76.310  45.197  1
256430  101.798  -76.313  45.174  1
256431  101.806  -76.316  45.152  1
256432  101.813  -76.318  45.131  1
256433  101.821  -76.321  45.108  1
256789  92.660  -73.963  54.629  1
256790  92.684  -73.975  54.629  1
256791  92.707  -73.982  54.629  1
256792  92.732  -73.970  54.630  1
256793  92.761  -73.962  54.630  1
256794  92.791  -73.964  54.631  1
256795  92.821  -73.983  54.632  1
256796  92.851  -74.001  54.633  1
256797  92.880  -74.020  54.635  1
256798  92.910  -74.039  54.637  1
256799  92.939  -74.057  54.639  1
256800  92.969  -74.076  54.642  1
256801  92.999  -74.092  54.644  1
256802  93.030  -74.094  54.647  1
256803  93.061  -74.095  54.650  1
256804  93.093  -74.090  54.653  1
256805  93.127  -74.069  54.655  1
256806  93.160  -74.048  54.657  1
256807  93.194  -74.028  54.659  1
256808  93.221  -74.021  54.660  1
256809  93.242  -74.029  54.663  1
256810  93.263  -74.038  54.666  1
256811  93.284  -74.044  54.668  1
256812  93.304  -74.049  54.668  1
256813  93.325  -74.054  54.669  1
256814  93.348  -74.057  54.668  1
256815  93.380  -74.060  54.667  1
256816  93.413  -74.060  54.667  1
256817  93.435  -74.047  54.669  1
256818  93.458  -74.034  54.674  1
256819  93.482  -74.029  54.681  1
256820  93.506  -74.026  54.690  1
256821  93.530  -74.021  54.699  1
256822  93.555  -74.017  54.710  1
256823  93.579  -74.013  54.723  1
256824  93.604  -74.009  54.739  1
256825  93.628  -74.005  54.760  1
256826  93.652  -74.001  54.781  1
256827  93.677  -73.997  54.799  1
256828  93.701  -73.993  54.814  1
256829  93.725  -73.988  54.830  1
256830  93.775  -74.004  54.849  1
256831  93.794  -74.009  54.871  1
256832  93.804  -74.010  54.895  1
256833  93.819  -74.010  54.916  1
256834  93.840  -74.011  54.926  1
256835  93.860  -74.013  54.927  1
256836  93.882  -74.016  54.918  1
256837  93.904  -74.018  54.895  1
256838  93.925  -74.021  54.863  1
256839  93.946  -74.024  54.826  1
256840  93.968  -74.026  54.788  1
256841  93.990  -74.029  54.746  1
256842  94.011  -74.031  54.703  1
256843  94.037  -74.032  54.658  1
256844  94.067  -74.033  54.609  1
256845  94.096  -74.032  54.566  1
256846  94.122  -74.031  54.537  1
256847  94.148  -74.029  54.517  1
256848  94.175  -74.028  54.499  1
256849  94.205  -74.027  54.485  1
256850  94.237  -74.026  54.470  1
256851  94.268  -74.026  54.452  1
256852  94.299  -74.025  54.431  1
256853  94.326  -74.026  54.406  1
256854  94.342  -74.033  54.379  1
256855  94.358  -74.039  54.353  1
256856  94.374  -74.046  54.329  1
256857  94.387  -74.050  54.303  1
256858  94.385  -74.043  54.278  1
256859  94.401  -74.038  54.251  1
256860  94.427  -74.035  54.222  1
256861  94.454  -74.032  54.188  1
256862  94.480  -74.030  54.155  1
256863  94.506  -74.027  54.124  1
256864  94.533  -74.024  54.094  1
256865  94.559  -74.023  54.058  1
256866  94.581  -74.020  54.018  1
256867  94.601  -74.010  53.974  1
256868  94.621  -74.001  53.926  1
256869  94.640  -73.991  53.880  1
256870  94.661  -73.982  53.834  1
256871  94.679  -73.974  53.788  1
256872  94.694  -73.976  53.741  1
256873  94.709  -73.977  53.696  1
256874  94.724  -73.979  53.652  1
256875  94.739  -73.980  53.610  1
256876  94.754  -73.982  53.572  1
256877  94.769  -73.983  53.541  1
256878  94.791  -73.988  53.516  1
256879  94.838  -74.005  53.497  1
256880  94.881  -74.023  53.483  1
256881  94.891  -74.050  53.464  1
256882  94.901  -74.076  53.439  1
256883  94.911  -74.103  53.407  1
256884  94.928  -74.111  53.364  1
256885  94.950  -74.105  53.320  1
256886  94.971  -74.100  53.275  1
256887  94.992  -74.094  53.228  1
256888  95.014  -74.089  53.180  1
256889  95.035  -74.083  53.130  1
256890  95.063  -74.085  53.081  1
256891  95.097  -74.090  53.032  1
256892  95.131  -74.095  52.984  1
256893  95.164  -74.101  52.935  1
256894  95.198  -74.107  52.886  1
256895  95.231  -74.113  52.838  1
256896  95.254  -74.144  52.789  1
256897  95.288  -74.154  52.738  1
256898  95.329  -74.153  52.686  1
256899  95.371  -74.152  52.633  1
256900  95.412  -74.151  52.581  1
256901  95.454  -74.150  52.532  1
256902  95.495  -74.149  52.485  1
256903  95.537  -74.148  52.440  1
256904  95.578  -74.147  52.396  1
256905  95.620  -74.146  52.354  1
256906  95.661  -74.145  52.312  1
256907  95.702  -74.145  52.272  1
256908  95.744  -74.144  52.234  1
256909  95.774  -74.149  52.196  1
256910  95.799  -74.153  52.159  1
256911  95.809  -74.149  52.122  1
256912  95.819  -74.146  52.084  1
256913  95.828  -74.142  52.046  1
256914  95.838  -74.139  52.009  1
256915  95.848  -74.136  51.972  1
256916  95.858  -74.132  51.937  1
256917  95.868  -74.129  51.901  1
256918  95.877  -74.125  51.865  1
256919  95.887  -74.121  51.828  1
256920  95.897  -74.118  51.791  1
256921  95.915  -74.129  51.753  1
256922  95.939  -74.149  51.715  1
256923  95.963  -74.169  51.676  1
256924  95.994  -74.170  51.635  1
256925  96.028  -74.167  51.594  1
256926  96.060  -74.166  51.554  1
256927  96.094  -74.164  51.513  1
256928  96.127  -74.161  51.475  1
256929  96.160  -74.159  51.438  1
256930  96.209  -74.170  51.402  1
256931  96.222  -74.192  51.368  1
256932  96.226  -74.210  51.334  1
256933  96.230  -74.227  51.302  1
256934  96.240  -74.243  51.272  1
256935  96.274  -74.262  51.243  1
256936  96.308  -74.280  51.216  1
256937  96.343  -74.299  51.189  1
256938  96.377  -74.318  51.164  1
256939  96.411  -74.337  51.140  1
256940  96.446  -74.356  51.118  1
256941  96.480  -74.375  51.098  1
256942  96.514  -74.394  51.079  1
256943  96.548  -74.413  51.062  1
256944  96.583  -74.432  51.047  1
256945  96.617  -74.451  51.033  1
256946  96.648  -74.465  51.020  1
256947  96.673  -74.473  51.009  1
256948  96.698  -74.480  50.999  1
256949  96.723  -74.487  50.991  1
256950  96.752  -74.503  50.985  1
256951  96.783  -74.522  50.981  1
256952  96.805  -74.537  50.978  1
256953  96.826  -74.550  50.977  1
256954  96.848  -74.561  50.977  1
256955  96.869  -74.566  50.980  1
256956  96.889  -74.571  50.983  1
256957  96.910  -74.577  50.988  1
256958  96.939  -74.597  50.993  1
256959  96.956  -74.609  50.997  1
256960  96.973  -74.621  51.002  1
256961  96.991  -74.634  51.004  1
256962  97.008  -74.645  51.003  1
256963  97.025  -74.657  51.002  1
256964  97.042  -74.669  50.999  1
256965  97.060  -74.681  50.997  1
256966  97.077  -74.693  50.994  1
256967  97.094  -74.706  50.989  1
256968  97.111  -74.718  50.982  1
256969  97.128  -74.730  50.972  1
256970  97.145  -74.741  50.958  1
256971  97.162  -74.753  50.940  1
256972  97.179  -74.766  50.916  1
256973  97.216  -74.760  50.890  1
256974  97.263  -74.747  50.860  1
256975  97.310  -74.734  50.829  1
256976  97.357  -74.721  50.799  1
256977  97.404  -74.707  50.770  1
256978  97.451  -74.694  50.741  1
256979  97.498  -74.681  50.709  1
256980  97.544  -74.668  50.674  1
256981  97.592  -74.654  50.635  1
256982  97.639  -74.641  50.593  1
256983  97.685  -74.628  50.551  1
256984  97.721  -74.632  50.506  1
256985  97.747  -74.648  50.460  1
256986  97.778  -74.666  50.412  1
256987  97.815  -74.690  50.361  1
256988  97.852  -74.712  50.309  1
256989  97.880  -74.727  50.257  1
256990  97.900  -74.731  50.208  1
256991  97.921  -74.737  50.162  1
256992  97.942  -74.741  50.118  1
256993  97.962  -74.746  50.077  1
256994  97.983  -74.751  50.038  1
256995  98.004  -74.756  49.999  1
256996  98.024  -74.761  49.958  1
256997  98.045  -74.766  49.914  1
256998  98.076  -74.787  49.868  1
256999  98.107  -74.809  49.818  1
257000  98.138  -74.831  49.767  1
257001  98.169  -74.853  49.713  1
257002  98.200  -74.875  49.656  1
257003  98.231  -74.888  49.597  1
257004  98.263  -74.901  49.537  1
257005  98.294  -74.915  49.478  1
257006  98.325  -74.928  49.421  1
257007  98.356  -74.941  49.366  1
257008  98.390  -74.957  49.312  1
257009  98.425  -74.954  49.259  1
257010  98.454  -74.925  49.207  1
257011  98.484  -74.896  49.153  1
257012  98.510  -74.869  49.100  1
257013  98.530  -74.847  49.048  1
257014  98.551  -74.831  48.997  1
257015  98.579  -74.842  48.945  1
257016  98.606  -74.853  48.892  1
257017  98.633  -74.864  48.838  1
257018  98.661  -74.875  48.783  1
257019  98.688  -74.887  48.728  1
257020  98.716  -74.897  48.673  1
257021  98.743  -74.909  48.619  1
257022  98.771  -74.919  48.565  1
257023  98.798  -74.931  48.513  1
257024  98.825  -74.941  48.460  1
257025  98.853  -74.951  48.409  1
257026  98.878  -74.972  48.358  1
257027  98.903  -74.990  48.307  1
257028  98.927  -75.008  48.257  1
257029  98.952  -75.026  48.208  1
257030  98.977  -75.044  48.159  1
257031  99.001  -75.063  48.111  1
257032  99.026  -75.082  48.064  1
257033  99.051  -75.100  48.018  1
257034  99.075  -75.118  47.972  1
257035  99.100  -75.136  47.927  1
257036  99.125  -75.154  47.881  1
257037  99.160  -75.174  47.835  1
257038  99.196  -75.194  47.789  1
257039  99.231  -75.213  47.744  1
257040  99.268  -75.232  47.697  1
257041  99.300  -75.245  47.652  1
257042  99.331  -75.248  47.609  1
257043  99.361  -75.252  47.567  1
257044  99.391  -75.257  47.526  1
257045  99.420  -75.261  47.486  1
257046  99.444  -75.270  47.447  1
257047  99.469  -75.278  47.411  1
257048  99.496  -75.285  47.378  1
257049  99.532  -75.289  47.347  1
257050  99.568  -75.292  47.318  1
257051  99.604  -75.295  47.290  1
257052  99.639  -75.298  47.264  1
257053  99.676  -75.301  47.240  1
257054  99.711  -75.305  47.216  1
257055  99.747  -75.308  47.193  1
257056  99.783  -75.312  47.172  1
257057  99.819  -75.315  47.151  1
257058  99.845  -75.329  47.130  1
257059  99.858  -75.356  47.109  1
257060  99.871  -75.383  47.087  1
257061  99.887  -75.415  47.067  1
257062  99.914  -75.445  47.047  1
257063  99.944  -75.470  47.030  1
257064  99.969  -75.477  47.014  1
257065  99.991  -75.475  46.996  1
257066  100.037  -75.482  46.976  1
257067  100.085  -75.490  46.952  1
257068  100.104  -75.493  46.929  1
257069  100.113  -75.493  46.904  1
257070  100.121  -75.493  46.877  1
257071  100.130  -75.494  46.846  1
257072  100.138  -75.499  46.812  1
257073  100.144  -75.516  46.778  1
257074  100.174  -75.524  46.743  1
257075  100.204  -75.534  46.709  1
257076  100.232  -75.557  46.676  1
257077  100.260  -75.579  46.644  1
257078  100.288  -75.601  46.612  1
257079  100.316  -75.623  46.580  1
257080  100.343  -75.645  46.547  1
257081  100.371  -75.668  46.516  1
257082  100.400  -75.694  46.487  1
257083  100.429  -75.721  46.457  1
257084  100.458  -75.748  46.428  1
257085  100.486  -75.775  46.399  1
257086  100.515  -75.802  46.370  1
257087  100.544  -75.829  46.341  1
257088  100.571  -75.835  46.313  1
257089  100.612  -75.828  46.286  1
257090  100.650  -75.841  46.258  1
257091  100.682  -75.860  46.229  1
257092  100.715  -75.880  46.201  1
257093  100.747  -75.900  46.172  1
257094  100.780  -75.919  46.142  1
257095  100.812  -75.939  46.114  1
257096  100.845  -75.959  46.086  1
257097  100.877  -75.978  46.058  1
257098  100.901  -75.994  46.029  1
257099  100.920  -76.006  45.998  1
257100  100.939  -76.017  45.967  1
257101  100.958  -76.028  45.936  1
257102  100.977  -76.039  45.906  1
257103  100.993  -76.047  45.877  1
257104  101.008  -76.053  45.848  1
257105  101.023  -76.060  45.818  1
257106  101.062  -76.070  45.787  1
257107  101.104  -76.082  45.757  1
257108  101.145  -76.093  45.727  1
257109  101.187  -76.104  45.699  1
257110  101.229  -76.115  45.670  1
257111  101.270  -76.126  45.644  1
257112  101.312  -76.138  45.617  1
257113  101.353  -76.149  45.590  1
257114  101.395  -76.160  45.564  1
257115  101.437  -76.172  45.538  1
257116  101.479  -76.183  45.513  1
257117  101.521  -76.195  45.489  1
257118  101.562  -76.206  45.465  1
257119  101.605  -76.216  45.440  1
257120  101.649  -76.226  45.417  1
257121  101.683  -76.236  45.394  1
257122  101.709  -76.246  45.370  1
257123  101.740  -76.259  45.348  1
257124  101.748  -76.263  45.325  1
257125  101.756  -76.265  45.302  1
257126  101.763  -76.268  45.279  1
257127  101.771  -76.270  45.256  1
257128  101.778  -76.273  45.234  1
257129  101.786  -76.276  45.211  1
257130  101.794  -76.279  45.188  1
257131  101.802  -76.282  45.165  1
257132  101.809  -76.284  45.143  1
257133  101.817  -76.287  45.121  1
257134  101.824  -76.289  45.098  1
257489  92.637  -73.920  54.633  1
257490  92.661  -73.932  54.632  1
257491  92.686  -73.942  54.631  1
257492  92.710  -73.953  54.631  1
257493  92.733  -73.943  54.632  1
257494  92.763  -73.935  54.632  1
257495  92.792  -73.938  54.633  1
257496  92.822  -73.957  54.634  1
257497  92.852  -73.976  54.635  1
257498  92.881  -73.994  54.637  1
257499  92.911  -74.013  54.639  1
257500  92.941  -74.032  54.641  1
257501  92.971  -74.050  54.645  1
257502  93.000  -74.069  54.647  1
257503  93.031  -74.072  54.650  1
257504  93.062  -74.071  54.653  1
257505  93.096  -74.050  54.657  1
257506  93.129  -74.029  54.659  1
257507  93.163  -74.009  54.660  1
257508  93.196  -73.989  54.661  1
257509  93.217  -73.997  54.661  1
257510  93.238  -74.005  54.664  1
257511  93.259  -74.010  54.667  1
257512  93.279  -74.014  54.670  1
257513  93.300  -74.020  54.672  1
257514  93.320  -74.024  54.673  1
257515  93.348  -74.027  54.672  1
257516  93.381  -74.029  54.670  1
257517  93.414  -74.030  54.668  1
257518  93.438  -74.020  54.667  1
257519  93.461  -74.007  54.669  1
257520  93.483  -73.995  54.674  1
257521  93.507  -73.990  54.681  1
257522  93.532  -73.985  54.688  1
257523  93.556  -73.982  54.696  1
257524  93.580  -73.977  54.706  1
257525  93.605  -73.973  54.717  1
257526  93.629  -73.969  54.734  1
257527  93.653  -73.965  54.751  1
257528  93.678  -73.961  54.767  1
257529  93.707  -73.960  54.781  1
257530  93.765  -73.982  54.799  1
257531  93.782  -73.986  54.820  1
257532  93.792  -73.986  54.844  1
257533  93.802  -73.987  54.870  1
257534  93.819  -73.988  54.892  1
257535  93.840  -73.989  54.905  1
257536  93.861  -73.991  54.907  1
257537  93.882  -73.992  54.898  1
257538  93.903  -73.995  54.878  1
257539  93.925  -73.998  54.847  1
257540  93.946  -74.001  54.810  1
257541  93.968  -74.002  54.771  1
257542  93.990  -74.004  54.727  1
257543  94.011  -74.006  54.683  1
257544  94.040  -74.007  54.637  1
257545  94.071  -74.007  54.588  1
257546  94.102  -74.008  54.549  1
257547  94.128  -74.007  54.522  1
257548  94.155  -74.006  54.503  1
257549  94.184  -74.004  54.485  1
257550  94.215  -74.004  54.472  1
257551  94.247  -74.003  54.457  1
257552  94.278  -74.002  54.438  1
257553  94.309  -74.001  54.415  1
257554  94.340  -74.001  54.388  1
257555  94.362  -74.004  54.360  1
257556  94.379  -74.010  54.333  1
257557  94.395  -74.017  54.309  1
257558  94.407  -74.021  54.283  1
257559  94.405  -74.014  54.257  1
257560  94.404  -74.007  54.231  1
257561  94.426  -74.004  54.202  1
257562  94.454  -74.003  54.168  1
257563  94.481  -74.001  54.134  1
257564  94.508  -74.000  54.101  1
257565  94.535  -73.999  54.072  1
257566  94.562  -74.000  54.037  1
257567  94.582  -74.007  53.996  1
257568  94.601  -74.001  53.952  1
257569  94.621  -73.991  53.905  1
257570  94.640  -73.982  53.859  1
257571  94.661  -73.973  53.814  1
257572  94.680  -73.963  53.769  1
257573  94.696  -73.961  53.721  1
257574  94.711  -73.963  53.677  1
257575  94.726  -73.964  53.634  1
257576  94.742  -73.966  53.594  1
257577  94.756  -73.967  53.560  1
257578  94.771  -73.969  53.532  1
257579  94.794  -73.974  53.510  1
257580  94.840  -73.991  53.493  1
257581  94.887  -74.008  53.478  1
257582  94.910  -74.032  53.455  1
257583  94.920  -74.058  53.427  1
257584  94.930  -74.085  53.394  1
257585  94.947  -74.095  53.350  1
257586  94.968  -74.089  53.306  1
257587  94.989  -74.084  53.260  1
257588  95.011  -74.079  53.214  1
257589  95.032  -74.073  53.166  1
257590  95.054  -74.068  53.118  1
257591  95.075  -74.063  53.070  1
257592  95.097  -74.057  53.020  1
257593  95.125  -74.059  52.971  1
257594  95.159  -74.064  52.922  1
257595  95.192  -74.070  52.874  1
257596  95.226  -74.076  52.825  1
257597  95.239  -74.121  52.775  1
257598  95.277  -74.127  52.724  1
257599  95.319  -74.129  52.674  1
257600  95.361  -74.129  52.622  1
257601  95.404  -74.128  52.572  1
257602  95.446  -74.127  52.524  1
257603  95.489  -74.126  52.478  1
257604  95.532  -74.126  52.434  1
257605  95.574  -74.125  52.392  1
257606  95.617  -74.124  52.350  1
257607  95.659  -74.123  52.309  1
257608  95.702  -74.123  52.268  1
257609  95.745  -74.122  52.230  1
257610  95.786  -74.121  52.193  1
257611  95.796  -74.118  52.156  1
257612  95.806  -74.115  52.120  1
257613  95.816  -74.111  52.082  1
257614  95.825  -74.107  52.044  1
257615  95.835  -74.104  52.007  1
257616  95.845  -74.101  51.971  1
257617  95.855  -74.097  51.936  1
257618  95.865  -74.094  51.901  1
257619  95.874  -74.090  51.865  1
257620  95.884  -74.086  51.829  1
257621  95.894  -74.083  51.794  1
257622  95.909  -74.089  51.757  1
257623  95.933  -74.109  51.718  1
257624  95.960  -74.120  51.678  1
257625  95.993  -74.118  51.637  1
257626  96.026  -74.116  51.597  1
257627  96.059  -74.114  51.557  1
257628  96.093  -74.112  51.516  1
257629  96.125  -74.110  51.478  1
257630  96.156  -74.122  51.441  1
257631  96.185  -74.135  51.405  1
257632  96.217  -74.136  51.370  1
257633  96.253  -74.142  51.336  1
257634  96.256  -74.161  51.304  1
257635  96.253  -74.205  51.274  1
257636  96.272  -74.231  51.245  1
257637  96.304  -74.248  51.217  1
257638  96.335  -74.266  51.190  1
257639  96.366  -74.283  51.164  1
257640  96.399  -74.302  51.140  1
257641  96.433  -74.320  51.118  1
257642  96.467  -74.339  51.097  1
257643  96.502  -74.358  51.078  1
257644  96.536  -74.377  51.060  1
257645  96.570  -74.396  51.045  1
257646  96.604  -74.415  51.030  1
257647  96.639  -74.434  51.017  1
257648  96.670  -74.449  51.005  1
257649  96.695  -74.456  50.995  1
257650  96.720  -74.464  50.987  1
257651  96.750  -74.482  50.982  1
257652  96.774  -74.497  50.977  1
257653  96.796  -74.510  50.974  1
257654  96.816  -74.515  50.973  1
257655  96.837  -74.521  50.973  1
257656  96.858  -74.526  50.975  1
257657  96.879  -74.531  50.979  1
257658  96.904  -74.541  50.985  1
257659  96.933  -74.562  50.992  1
257660  96.950  -74.574  51.000  1
257661  96.967  -74.586  51.007  1
257662  96.984  -74.598  51.011  1
257663  97.002  -74.610  51.013  1
257664  97.019  -74.622  51.011  1
257665  97.036  -74.634  51.008  1
257666  97.053  -74.646  51.006  1
257667  97.071  -74.659  51.003  1
257668  97.088  -74.671  50.998  1
257669  97.105  -74.683  50.990  1
257670  97.122  -74.694  50.979  1
257671  97.139  -74.706  50.965  1
257672  97.167  -74.708  50.946  1
257673  97.202  -74.701  50.922  1
257674  97.241  -74.693  50.895  1
257675  97.288  -74.680  50.866  1
257676  97.335  -74.666  50.836  1
257677  97.382  -74.653  50.806  1
257678  97.429  -74.640  50.777  1
257679  97.476  -74.627  50.746  1
257680  97.523  -74.613  50.712  1
257681  97.570  -74.600  50.674  1
257682  97.616  -74.587  50.634  1
257683  97.663  -74.574  50.590  1
257684  97.698  -74.579  50.547  1
257685  97.724  -74.595  50.501  1
257686  97.751  -74.611  50.455  1
257687  97.779  -74.628  50.407  1
257688  97.816  -74.650  50.356  1
257689  97.853  -74.674  50.303  1
257690  97.884  -74.690  50.251  1
257691  97.907  -74.695  50.202  1
257692  97.929  -74.701  50.156  1
257693  97.951  -74.707  50.112  1
257694  97.972  -74.712  50.072  1
257695  97.993  -74.716  50.034  1
257696  98.013  -74.722  49.997  1
257697  98.034  -74.726  49.956  1
257698  98.055  -74.731  49.912  1
257699  98.086  -74.753  49.865  1
257700  98.117  -74.775  49.815  1
257701  98.148  -74.797  49.762  1
257702  98.179  -74.819  49.707  1
257703  98.210  -74.841  49.649  1
257704  98.241  -74.863  49.589  1
257705  98.272  -74.878  49.529  1
257706  98.303  -74.891  49.470  1
257707  98.334  -74.905  49.412  1
257708  98.365  -74.918  49.357  1
257709  98.402  -74.937  49.303  1
257710  98.432  -74.913  49.250  1
257711  98.461  -74.883  49.197  1
257712  98.491  -74.853  49.144  1
257713  98.516  -74.827  49.091  1
257714  98.536  -74.805  49.039  1
257715  98.561  -74.804  48.987  1
257716  98.588  -74.816  48.936  1
257717  98.616  -74.826  48.883  1
257718  98.643  -74.838  48.830  1
257719  98.670  -74.848  48.775  1
257720  98.698  -74.859  48.720  1
257721  98.725  -74.870  48.664  1
257722  98.752  -74.881  48.610  1
257723  98.780  -74.893  48.556  1
257724  98.807  -74.903  48.504  1
257725  98.834  -74.922  48.452  1
257726  98.863  -74.934  48.400  1
257727  98.886  -74.943  48.349  1
257728  98.911  -74.961  48.299  1
257729  98.936  -74.979  48.249  1
257730  98.960  -74.997  48.200  1
257731  98.985  -75.016  48.151  1
257732  99.010  -75.034  48.103  1
257733  99.034  -75.052  48.057  1
257734  99.059  -75.070  48.011  1
257735  99.084  -75.089  47.965  1
257736  99.109  -75.107  47.919  1
257737  99.134  -75.126  47.874  1
257738  99.170  -75.145  47.828  1
257739  99.206  -75.165  47.782  1
257740  99.242  -75.184  47.737  1
257741  99.278  -75.204  47.689  1
257742  99.313  -75.221  47.644  1
257743  99.343  -75.225  47.601  1
257744  99.373  -75.229  47.559  1
257745  99.403  -75.233  47.519  1
257746  99.430  -75.239  47.479  1
257747  99.454  -75.248  47.441  1
257748  99.480  -75.256  47.404  1
257749  99.516  -75.259  47.371  1
257750  99.552  -75.263  47.340  1
257751  99.587  -75.266  47.311  1
257752  99.623  -75.269  47.283  1
257753  99.659  -75.273  47.257  1
257754  99.695  -75.276  47.232  1
257755  99.730  -75.279  47.208  1
257756  99.766  -75.283  47.187  1
257757  99.802  -75.286  47.165  1
257758  99.838  -75.289  47.143  1
257759  99.874  -75.293  47.122  1
257760  99.894  -75.313  47.101  1
257761  99.907  -75.339  47.079  1
257762  99.926  -75.380  47.059  1
257763  99.947  -75.424  47.040  1
257764  99.976  -75.450  47.021  1
257765  99.998  -75.449  47.004  1
257766  100.020  -75.446  46.985  1
257767  100.060  -75.451  46.965  1
257768  100.107  -75.458  46.942  1
257769  100.122  -75.460  46.918  1
257770  100.131  -75.461  46.892  1
257771  100.139  -75.461  46.864  1
257772  100.148  -75.461  46.834  1
257773  100.157  -75.462  46.801  1
257774  100.164  -75.468  46.767  1
257775  100.188  -75.479  46.733  1
257776  100.216  -75.499  46.700  1
257777  100.244  -75.521  46.667  1
257778  100.272  -75.543  46.635  1
257779  100.300  -75.568  46.603  1
257780  100.329  -75.596  46.572  1
257781  100.358  -75.622  46.540  1
257782  100.387  -75.649  46.509  1
257783  100.416  -75.676  46.480  1
257784  100.444  -75.703  46.451  1
257785  100.473  -75.730  46.422  1
257786  100.502  -75.757  46.393  1
257787  100.531  -75.784  46.364  1
257788  100.559  -75.811  46.335  1
257789  100.586  -75.806  46.308  1
257790  100.622  -75.798  46.281  1
257791  100.671  -75.795  46.253  1
257792  100.704  -75.815  46.225  1
257793  100.737  -75.834  46.197  1
257794  100.769  -75.853  46.168  1
257795  100.802  -75.873  46.139  1
257796  100.834  -75.893  46.112  1
257797  100.865  -75.916  46.084  1
257798  100.897  -75.942  46.057  1
257799  100.922  -75.961  46.028  1
257800  100.941  -75.972  45.998  1
257801  100.961  -75.983  45.967  1
257802  100.980  -75.994  45.936  1
257803  100.995  -76.001  45.906  1
257804  101.010  -76.007  45.877  1
257805  101.025  -76.013  45.846  1
257806  101.040  -76.020  45.816  1
257807  101.065  -76.028  45.785  1
257808  101.107  -76.039  45.754  1
257809  101.149  -76.050  45.725  1
257810  101.191  -76.062  45.696  1
257811  101.232  -76.073  45.667  1
257812  101.274  -76.085  45.641  1
257813  101.316  -76.096  45.613  1
257814  101.357  -76.107  45.586  1
257815  101.399  -76.119  45.559  1
257816  101.441  -76.130  45.533  1
257817  101.482  -76.141  45.507  1
257818  101.526  -76.151  45.482  1
257819  101.569  -76.161  45.458  1
257820  101.613  -76.171  45.433  1
257821  101.650  -76.181  45.409  1
257822  101.677  -76.191  45.386  1
257823  101.708  -76.205  45.362  1
257824  101.744  -76.229  45.339  1
257825  101.752  -76.231  45.316  1
257826  101.759  -76.234  45.293  1
257827  101.767  -76.236  45.271  1
257828  101.774  -76.239  45.248  1
257829  101.782  -76.242  45.225  1
257830  101.790  -76.245  45.202  1
257831  101.798  -76.248  45.179  1
257832  101.805  -76.250  45.155  1
257833  101.813  -76.253  45.133  1
257834  101.821  -76.255  45.111  1
257835  101.828  -76.258  45.088  1
258189  92.615  -73.877  54.635  1
258190  92.639  -73.888  54.635  1
258191  92.663  -73.899  54.634  1
258192  92.688  -73.910  54.633  1
258193  92.712  -73.920  54.633  1
258194  92.735  -73.916  54.633  1
258195  92.764  -73.907  54.634  1
258196  92.794  -73.912  54.635  1
258197  92.824  -73.931  54.636  1
258198  92.853  -73.949  54.637  1
258199  92.882  -73.968  54.638  1
258200  92.912  -73.987  54.640  1
258201  92.942  -74.005  54.644  1
258202  92.972  -74.024  54.647  1
258203  93.001  -74.043  54.651  1
258204  93.032  -74.051  54.653  1
258205  93.065  -74.031  54.655  1
258206  93.099  -74.010  54.660  1
258207  93.132  -73.990  54.662  1
258208  93.166  -73.969  54.663  1
258209  93.192  -73.965  54.662  1
258210  93.213  -73.970  54.662  1
258211  93.233  -73.976  54.664  1
258212  93.254  -73.980  54.667  1
258213  93.274  -73.985  54.670  1
258214  93.295  -73.990  54.673  1
258215  93.316  -73.995  54.675  1
258216  93.349  -73.996  54.674  1
258217  93.382  -73.998  54.671  1
258218  93.415  -73.999  54.669  1
258219  93.442  -73.993  54.668  1
258220  93.465  -73.980  54.667  1
258221  93.487  -73.967  54.668  1
258222  93.509  -73.954  54.673  1
258223  93.534  -73.950  54.677  1
258224  93.558  -73.945  54.682  1
258225  93.582  -73.941  54.689  1
258226  93.607  -73.938  54.698  1
258227  93.631  -73.933  54.709  1
258228  93.655  -73.929  54.722  1
258229  93.697  -73.938  54.736  1
258230  93.754  -73.960  54.751  1
258231  93.770  -73.963  54.769  1
258232  93.780  -73.963  54.792  1
258233  93.790  -73.964  54.818  1
258234  93.800  -73.964  54.844  1
258235  93.819  -73.965  54.865  1
258236  93.840  -73.966  54.876  1
258237  93.861  -73.968  54.878  1
258238  93.882  -73.969  54.873  1
258239  93.903  -73.972  54.857  1
258240  93.924  -73.973  54.830  1
258241  93.946  -73.976  54.793  1
258242  93.968  -73.977  54.752  1
258243  93.989  -73.979  54.707  1
258244  94.013  -73.981  54.660  1
258245  94.044  -73.982  54.612  1
258246  94.075  -73.982  54.564  1
258247  94.106  -73.983  54.530  1
258248  94.135  -73.983  54.506  1
258249  94.163  -73.982  54.488  1
258250  94.194  -73.981  54.469  1
258251  94.225  -73.980  54.457  1
258252  94.256  -73.979  54.442  1
258253  94.287  -73.979  54.423  1
258254  94.319  -73.978  54.399  1
258255  94.350  -73.977  54.371  1
258256  94.381  -73.976  54.342  1
258257  94.399  -73.982  54.313  1
258258  94.415  -73.988  54.288  1
258259  94.427  -73.992  54.262  1
258260  94.425  -73.985  54.236  1
258261  94.422  -73.980  54.209  1
258262  94.429  -73.979  54.180  1
258263  94.457  -73.978  54.147  1
258264  94.484  -73.976  54.113  1
258265  94.511  -73.975  54.079  1
258266  94.539  -73.973  54.049  1
258267  94.563  -73.981  54.014  1
258268  94.584  -73.992  53.974  1
258269  94.602  -73.990  53.929  1
258270  94.621  -73.982  53.883  1
258271  94.640  -73.973  53.837  1
258272  94.660  -73.963  53.793  1
258273  94.680  -73.954  53.750  1
258274  94.699  -73.947  53.704  1
258275  94.713  -73.948  53.660  1
258276  94.729  -73.950  53.619  1
258277  94.744  -73.951  53.581  1
258278  94.759  -73.953  53.549  1
258279  94.773  -73.954  53.525  1
258280  94.796  -73.960  53.505  1
258281  94.843  -73.977  53.489  1
258282  94.890  -73.994  53.470  1
258283  94.929  -74.013  53.444  1
258284  94.939  -74.040  53.413  1
258285  94.950  -74.067  53.377  1
258286  94.965  -74.079  53.335  1
258287  94.986  -74.074  53.292  1
258288  95.007  -74.069  53.248  1
258289  95.029  -74.064  53.204  1
258290  95.050  -74.058  53.158  1
258291  95.072  -74.053  53.109  1
258292  95.093  -74.048  53.059  1
258293  95.115  -74.042  53.007  1
258294  95.136  -74.037  52.958  1
258295  95.158  -74.032  52.908  1
258296  95.187  -74.033  52.859  1
258297  95.220  -74.039  52.810  1
258298  95.228  -74.090  52.760  1
258299  95.267  -74.095  52.710  1
258300  95.307  -74.101  52.660  1
258301  95.347  -74.105  52.610  1
258302  95.390  -74.104  52.562  1
258303  95.432  -74.104  52.516  1
258304  95.475  -74.103  52.472  1
258305  95.517  -74.102  52.428  1
258306  95.560  -74.101  52.386  1
258307  95.603  -74.101  52.345  1
258308  95.645  -74.100  52.305  1
258309  95.688  -74.099  52.265  1
258310  95.731  -74.098  52.227  1
258311  95.766  -74.096  52.190  1
258312  95.779  -74.091  52.154  1
258313  95.794  -74.085  52.117  1
258314  95.807  -74.079  52.080  1
258315  95.821  -74.073  52.042  1
258316  95.832  -74.070  52.006  1
258317  95.842  -74.066  51.971  1
258318  95.852  -74.062  51.935  1
258319  95.862  -74.059  51.901  1
258320  95.872  -74.055  51.866  1
258321  95.881  -74.052  51.832  1
258322  95.891  -74.048  51.797  1
258323  95.903  -74.049  51.760  1
258324  95.927  -74.069  51.722  1
258325  95.959  -74.069  51.681  1
258326  95.992  -74.067  51.640  1
258327  96.025  -74.064  51.599  1
258328  96.057  -74.070  51.560  1
258329  96.087  -74.082  51.519  1
258330  96.116  -74.095  51.481  1
258331  96.146  -74.107  51.444  1
258332  96.176  -74.120  51.408  1
258333  96.206  -74.126  51.373  1
258334  96.238  -74.123  51.338  1
258335  96.271  -74.124  51.306  1
258336  96.275  -74.161  51.276  1
258337  96.277  -74.203  51.246  1
258338  96.308  -74.220  51.218  1
258339  96.339  -74.239  51.190  1
258340  96.370  -74.256  51.164  1
258341  96.401  -74.273  51.141  1
258342  96.433  -74.291  51.118  1
258343  96.464  -74.308  51.097  1
258344  96.495  -74.326  51.077  1
258345  96.526  -74.343  51.059  1
258346  96.557  -74.361  51.043  1
258347  96.592  -74.380  51.028  1
258348  96.626  -74.399  51.014  1
258349  96.661  -74.418  51.003  1
258350  96.692  -74.433  50.993  1
258351  96.718  -74.443  50.985  1
258352  96.743  -74.458  50.979  1
258353  96.764  -74.465  50.974  1
258354  96.785  -74.470  50.970  1
258355  96.805  -74.476  50.968  1
258356  96.826  -74.481  50.969  1
258357  96.847  -74.487  50.970  1
258358  96.868  -74.492  50.976  1
258359  96.899  -74.508  50.983  1
258360  96.927  -74.527  50.992  1
258361  96.944  -74.539  51.003  1
258362  96.961  -74.551  51.012  1
258363  96.978  -74.563  51.018  1
258364  96.996  -74.575  51.020  1
258365  97.013  -74.587  51.019  1
258366  97.030  -74.599  51.017  1
258367  97.047  -74.612  51.014  1
258368  97.064  -74.624  51.011  1
258369  97.082  -74.635  51.007  1
258370  97.099  -74.647  50.998  1
258371  97.124  -74.651  50.987  1
258372  97.159  -74.645  50.972  1
258373  97.194  -74.639  50.951  1
258374  97.230  -74.632  50.927  1
258375  97.266  -74.625  50.901  1
258376  97.313  -74.612  50.873  1
258377  97.360  -74.599  50.843  1
258378  97.407  -74.585  50.813  1
258379  97.454  -74.572  50.782  1
258380  97.501  -74.559  50.749  1
258381  97.547  -74.546  50.714  1
258382  97.594  -74.532  50.674  1
258383  97.642  -74.519  50.632  1
258384  97.674  -74.526  50.588  1
258385  97.702  -74.542  50.544  1
258386  97.728  -74.558  50.498  1
258387  97.755  -74.574  50.451  1
258388  97.782  -74.590  50.402  1
258389  97.818  -74.612  50.352  1
258390  97.855  -74.635  50.297  1
258391  97.885  -74.650  50.246  1
258392  97.908  -74.656  50.197  1
258393  97.931  -74.662  50.152  1
258394  97.953  -74.668  50.109  1
258395  97.975  -74.674  50.067  1
258396  97.998  -74.680  50.028  1
258397  98.021  -74.686  49.993  1
258398  98.043  -74.692  49.952  1
258399  98.064  -74.697  49.908  1
258400  98.095  -74.718  49.860  1
258401  98.126  -74.740  49.809  1
258402  98.157  -74.762  49.754  1
258403  98.189  -74.784  49.698  1
258404  98.219  -74.806  49.639  1
258405  98.250  -74.828  49.578  1
258406  98.282  -74.850  49.518  1
258407  98.312  -74.869  49.460  1
258408  98.344  -74.881  49.404  1
258409  98.375  -74.894  49.347  1
258410  98.409  -74.900  49.293  1
258411  98.439  -74.871  49.240  1
258412  98.468  -74.841  49.187  1
258413  98.498  -74.812  49.134  1
258414  98.523  -74.786  49.081  1
258415  98.543  -74.766  49.028  1
258416  98.571  -74.777  48.978  1
258417  98.598  -74.788  48.927  1
258418  98.626  -74.799  48.875  1
258419  98.653  -74.810  48.821  1
258420  98.680  -74.822  48.766  1
258421  98.708  -74.832  48.711  1
258422  98.735  -74.844  48.656  1
258423  98.762  -74.859  48.601  1
258424  98.787  -74.886  48.547  1
258425  98.812  -74.913  48.494  1
258426  98.837  -74.941  48.442  1
258427  98.875  -74.916  48.391  1
258428  98.899  -74.916  48.340  1
258429  98.919  -74.932  48.290  1
258430  98.944  -74.950  48.241  1
258431  98.969  -74.969  48.192  1
258432  98.993  -74.987  48.143  1
258433  99.018  -75.005  48.095  1
258434  99.043  -75.023  48.048  1
258435  99.067  -75.041  48.001  1
258436  99.092  -75.060  47.956  1
258437  99.117  -75.078  47.911  1
258438  99.144  -75.097  47.865  1
258439  99.180  -75.116  47.820  1
258440  99.216  -75.136  47.775  1
258441  99.252  -75.155  47.728  1
258442  99.288  -75.175  47.682  1
258443  99.324  -75.195  47.637  1
258444  99.355  -75.202  47.593  1
258445  99.385  -75.206  47.551  1
258446  99.416  -75.210  47.511  1
258447  99.441  -75.217  47.471  1
258448  99.465  -75.226  47.433  1
258449  99.499  -75.230  47.397  1
258450  99.536  -75.233  47.363  1
258451  99.571  -75.236  47.332  1
258452  99.607  -75.240  47.304  1
258453  99.643  -75.243  47.276  1
258454  99.679  -75.247  47.250  1
258455  99.714  -75.250  47.225  1
258456  99.750  -75.254  47.201  1
258457  99.786  -75.257  47.179  1
258458  99.822  -75.261  47.157  1
258459  99.857  -75.264  47.136  1
258460  99.894  -75.267  47.115  1
258461  99.929  -75.270  47.093  1
258462  99.945  -75.300  47.071  1
258463  99.966  -75.344  47.050  1
258464  99.977  -75.392  47.030  1
258465  100.005  -75.420  47.011  1
258466  100.027  -75.420  46.993  1
258467  100.049  -75.417  46.974  1
258468  100.082  -75.420  46.953  1
258469  100.129  -75.427  46.929  1
258470  100.140  -75.428  46.905  1
258471  100.149  -75.429  46.879  1
258472  100.157  -75.429  46.851  1
258473  100.167  -75.430  46.820  1
258474  100.175  -75.430  46.788  1
258475  100.184  -75.430  46.755  1
258476  100.201  -75.442  46.722  1
258477  100.230  -75.469  46.690  1
258478  100.259  -75.496  46.657  1
258479  100.287  -75.523  46.625  1
258480  100.316  -75.550  46.594  1
258481  100.345  -75.577  46.564  1
258482  100.373  -75.604  46.533  1
258483  100.403  -75.630  46.503  1
258484  100.431  -75.658  46.473  1
258485  100.460  -75.684  46.444  1
258486  100.489  -75.712  46.416  1
258487  100.517  -75.738  46.387  1
258488  100.546  -75.765  46.358  1
258489  100.575  -75.789  46.330  1
258490  100.601  -75.778  46.302  1
258491  100.633  -75.768  46.275  1
258492  100.682  -75.764  46.248  1
258493  100.726  -75.768  46.221  1
258494  100.759  -75.787  46.192  1
258495  100.791  -75.807  46.163  1
258496  100.823  -75.828  46.135  1
258497  100.854  -75.854  46.110  1
258498  100.885  -75.879  46.082  1
258499  100.916  -75.905  46.054  1
258500  100.945  -75.927  46.026  1
258501  100.964  -75.938  45.997  1
258502  100.983  -75.950  45.966  1
258503  100.997  -75.956  45.935  1
258504  101.012  -75.962  45.905  1
258505  101.027  -75.968  45.874  1
258506  101.042  -75.974  45.842  1
258507  101.057  -75.980  45.811  1
258508  101.072  -75.986  45.780  1
258509  101.111  -75.997  45.749  1
258510  101.152  -76.009  45.720  1
258511  101.194  -76.020  45.692  1
258512  101.236  -76.032  45.664  1
258513  101.278  -76.042  45.637  1
258514  101.319  -76.053  45.610  1
258515  101.361  -76.065  45.582  1
258516  101.403  -76.076  45.555  1
258517  101.447  -76.086  45.527  1
258518  101.490  -76.096  45.501  1
258519  101.534  -76.107  45.475  1
258520  101.577  -76.116  45.451  1
258521  101.618  -76.126  45.426  1
258522  101.645  -76.136  45.402  1
258523  101.677  -76.151  45.378  1
258524  101.734  -76.189  45.354  1
258525  101.748  -76.197  45.331  1
258526  101.755  -76.200  45.308  1
258527  101.763  -76.202  45.284  1
258528  101.771  -76.205  45.262  1
258529  101.778  -76.208  45.238  1
258530  101.786  -76.210  45.215  1
258531  101.793  -76.213  45.192  1
258532  101.801  -76.216  45.169  1
258533  101.809  -76.219  45.146  1
258534  101.817  -76.221  45.123  1
258535  101.824  -76.224  45.101  1
258536  101.832  -76.227  45.077  1
258889  92.592  -73.834  54.638  1
258890  92.617  -73.845  54.638  1
258891  92.641  -73.856  54.637  1
258892  92.665  -73.866  54.636  1
258893  92.690  -73.877  54.636  1
258894  92.714  -73.888  54.635  1
258895  92.737  -73.889  54.634  1
258896  92.765  -73.881  54.635  1
258897  92.795  -73.886  54.635  1
258898  92.825  -73.904  54.636  1
258899  92.854  -73.923  54.637  1
258900  92.884  -73.942  54.640  1
258901  92.914  -73.960  54.641  1
258902  92.943  -73.979  54.644  1
258903  92.973  -73.998  54.648  1
258904  93.002  -74.017  54.652  1
258905  93.029  -74.021  54.654  1
258906  93.062  -74.001  54.656  1
258907  93.096  -73.979  54.661  1
258908  93.131  -73.957  54.663  1
258909  93.165  -73.935  54.664  1
258910  93.188  -73.936  54.664  1
258911  93.208  -73.941  54.663  1
258912  93.228  -73.946  54.663  1
258913  93.249  -73.951  54.665  1
258914  93.269  -73.955  54.669  1
258915  93.290  -73.960  54.673  1
258916  93.317  -73.963  54.675  1
258917  93.350  -73.965  54.674  1
258918  93.382  -73.966  54.672  1
258919  93.416  -73.968  54.670  1
258920  93.446  -73.966  54.668  1
258921  93.468  -73.953  54.666  1
258922  93.490  -73.940  54.665  1
258923  93.513  -73.927  54.665  1
258924  93.535  -73.914  54.667  1
258925  93.559  -73.910  54.670  1
258926  93.583  -73.906  54.673  1
258927  93.608  -73.901  54.679  1
258928  93.632  -73.897  54.686  1
258929  93.686  -73.916  54.695  1
258930  93.744  -73.938  54.707  1
258931  93.758  -73.941  54.720  1
258932  93.768  -73.941  54.739  1
258933  93.778  -73.941  54.762  1
258934  93.788  -73.941  54.787  1
258935  93.798  -73.941  54.811  1
258936  93.819  -73.943  54.828  1
258937  93.840  -73.944  54.840  1
258938  93.861  -73.945  54.844  1
258939  93.882  -73.946  54.838  1
258940  93.903  -73.947  54.824  1
258941  93.924  -73.948  54.800  1
258942  93.946  -73.951  54.767  1
258943  93.968  -73.952  54.726  1
258944  93.989  -73.954  54.681  1
258945  94.016  -73.956  54.633  1
258946  94.048  -73.957  54.585  1
258947  94.078  -73.957  54.539  1
258948  94.110  -73.958  54.509  1
258949  94.140  -73.959  54.486  1
258950  94.172  -73.958  54.468  1
258951  94.203  -73.957  54.451  1
258952  94.235  -73.957  54.439  1
258953  94.266  -73.956  54.424  1
258954  94.297  -73.955  54.405  1
258955  94.329  -73.954  54.380  1
258956  94.360  -73.954  54.353  1
258957  94.391  -73.953  54.324  1
258958  94.420  -73.954  54.294  1
258959  94.436  -73.960  54.268  1
258960  94.448  -73.963  54.240  1
258961  94.445  -73.956  54.213  1
258962  94.440  -73.954  54.185  1
258963  94.434  -73.954  54.157  1
258964  94.460  -73.953  54.125  1
258965  94.487  -73.951  54.092  1
258966  94.514  -73.950  54.057  1
258967  94.542  -73.948  54.024  1
258968  94.564  -73.963  53.990  1
258969  94.586  -73.976  53.950  1
258970  94.604  -73.974  53.906  1
258971  94.621  -73.972  53.860  1
258972  94.640  -73.963  53.815  1
258973  94.660  -73.954  53.772  1
258974  94.680  -73.944  53.730  1
258975  94.700  -73.935  53.686  1
258976  94.716  -73.934  53.644  1
258977  94.731  -73.935  53.604  1
258978  94.746  -73.937  53.569  1
258979  94.761  -73.938  53.539  1
258980  94.776  -73.940  53.517  1
258981  94.800  -73.946  53.500  1
258982  94.846  -73.963  53.483  1
258983  94.893  -73.980  53.460  1
258984  94.939  -73.997  53.431  1
258985  94.959  -74.021  53.398  1
258986  94.969  -74.048  53.361  1
258987  94.983  -74.064  53.320  1
258988  95.004  -74.059  53.278  1
258989  95.026  -74.054  53.237  1
258990  95.047  -74.048  53.194  1
258991  95.068  -74.043  53.148  1
258992  95.090  -74.038  53.098  1
258993  95.112  -74.032  53.046  1
258994  95.133  -74.027  52.993  1
258995  95.155  -74.022  52.943  1
258996  95.176  -74.016  52.893  1
258997  95.197  -74.010  52.844  1
258998  95.218  -74.005  52.795  1
258999  95.218  -74.058  52.745  1
259000  95.257  -74.064  52.695  1
259001  95.297  -74.069  52.647  1
259002  95.336  -74.073  52.599  1
259003  95.376  -74.079  52.552  1
259004  95.418  -74.079  52.508  1
259005  95.461  -74.079  52.465  1
259006  95.503  -74.078  52.422  1
259007  95.546  -74.077  52.381  1
259008  95.589  -74.076  52.341  1
259009  95.631  -74.076  52.301  1
259010  95.674  -74.075  52.262  1
259011  95.716  -74.074  52.225  1
259012  95.744  -74.071  52.188  1
259013  95.758  -74.066  52.152  1
259014  95.772  -74.060  52.115  1
259015  95.785  -74.054  52.078  1
259016  95.800  -74.048  52.041  1
259017  95.813  -74.043  52.005  1
259018  95.827  -74.038  51.970  1
259019  95.841  -74.032  51.935  1
259020  95.855  -74.026  51.901  1
259021  95.869  -74.020  51.867  1
259022  95.879  -74.017  51.833  1
259023  95.888  -74.013  51.799  1
259024  95.898  -74.010  51.762  1
259025  95.925  -74.020  51.723  1
259026  95.958  -74.017  51.682  1
259027  95.988  -74.030  51.642  1
259028  96.018  -74.042  51.602  1
259029  96.047  -74.054  51.562  1
259030  96.077  -74.067  51.522  1
259031  96.107  -74.079  51.483  1
259032  96.137  -74.092  51.446  1
259033  96.167  -74.104  51.409  1
259034  96.196  -74.117  51.374  1
259035  96.228  -74.115  51.340  1
259036  96.261  -74.117  51.308  1
259037  96.294  -74.123  51.277  1
259038  96.295  -74.164  51.247  1
259039  96.312  -74.193  51.219  1
259040  96.343  -74.211  51.192  1
259041  96.375  -74.228  51.166  1
259042  96.406  -74.245  51.142  1
259043  96.437  -74.263  51.119  1
259044  96.468  -74.280  51.097  1
259045  96.499  -74.298  51.077  1
259046  96.530  -74.315  51.059  1
259047  96.561  -74.333  51.042  1
259048  96.593  -74.350  51.027  1
259049  96.623  -74.368  51.014  1
259050  96.655  -74.385  51.002  1
259051  96.686  -74.402  50.992  1
259052  96.712  -74.415  50.983  1
259053  96.732  -74.420  50.976  1
259054  96.753  -74.425  50.971  1
259055  96.774  -74.430  50.967  1
259056  96.795  -74.436  50.965  1
259057  96.815  -74.441  50.966  1
259058  96.836  -74.446  50.967  1
259059  96.857  -74.452  50.972  1
259060  96.895  -74.474  50.980  1
259061  96.921  -74.492  50.990  1
259062  96.938  -74.504  51.002  1
259063  96.955  -74.516  51.012  1
259064  96.972  -74.528  51.019  1
259065  96.990  -74.540  51.023  1
259066  97.007  -74.552  51.025  1
259067  97.024  -74.565  51.025  1
259068  97.041  -74.577  51.023  1
259069  97.058  -74.588  51.019  1
259070  97.081  -74.595  51.015  1
259071  97.116  -74.589  51.006  1
259072  97.151  -74.582  50.994  1
259073  97.186  -74.576  50.978  1
259074  97.222  -74.569  50.957  1
259075  97.257  -74.563  50.933  1
259076  97.293  -74.556  50.907  1
259077  97.338  -74.544  50.878  1
259078  97.385  -74.530  50.848  1
259079  97.432  -74.518  50.816  1
259080  97.478  -74.504  50.783  1
259081  97.526  -74.491  50.749  1
259082  97.573  -74.477  50.713  1
259083  97.619  -74.465  50.673  1
259084  97.651  -74.473  50.630  1
259085  97.678  -74.489  50.586  1
259086  97.705  -74.505  50.540  1
259087  97.732  -74.521  50.494  1
259088  97.759  -74.537  50.446  1
259089  97.786  -74.552  50.397  1
259090  97.819  -74.573  50.344  1
259091  97.857  -74.596  50.291  1
259092  97.887  -74.612  50.241  1
259093  97.910  -74.618  50.194  1
259094  97.932  -74.623  50.149  1
259095  97.954  -74.629  50.105  1
259096  97.977  -74.635  50.063  1
259097  98.000  -74.641  50.023  1
259098  98.022  -74.647  49.987  1
259099  98.044  -74.653  49.945  1
259100  98.074  -74.665  49.901  1
259101  98.107  -74.678  49.852  1
259102  98.138  -74.699  49.799  1
259103  98.168  -74.723  49.743  1
259104  98.199  -74.748  49.685  1
259105  98.229  -74.772  49.625  1
259106  98.260  -74.794  49.565  1
259107  98.291  -74.816  49.506  1
259108  98.322  -74.838  49.448  1
259109  98.353  -74.859  49.391  1
259110  98.384  -74.872  49.337  1
259111  98.416  -74.859  49.284  1
259112  98.445  -74.829  49.230  1
259113  98.475  -74.800  49.177  1
259114  98.504  -74.770  49.122  1
259115  98.529  -74.744  49.069  1
259116  98.553  -74.739  49.018  1
259117  98.580  -74.750  48.967  1
259118  98.608  -74.761  48.917  1
259119  98.635  -74.772  48.865  1
259120  98.662  -74.783  48.811  1
259121  98.690  -74.795  48.756  1
259122  98.715  -74.822  48.702  1
259123  98.740  -74.850  48.646  1
259124  98.765  -74.876  48.591  1
259125  98.790  -74.903  48.537  1
259126  98.815  -74.931  48.484  1
259127  98.844  -74.943  48.433  1
259128  98.888  -74.898  48.381  1
259129  98.915  -74.890  48.331  1
259130  98.931  -74.904  48.281  1
259131  98.952  -74.921  48.232  1
259132  98.977  -74.939  48.183  1
259133  99.002  -74.957  48.135  1
259134  99.026  -74.975  48.087  1
259135  99.051  -74.994  48.039  1
259136  99.076  -75.013  47.992  1
259137  99.100  -75.031  47.946  1
259138  99.125  -75.049  47.901  1
259139  99.154  -75.068  47.855  1
259140  99.191  -75.088  47.810  1
259141  99.226  -75.107  47.766  1
259142  99.263  -75.126  47.719  1
259143  99.298  -75.146  47.673  1
259144  99.334  -75.166  47.629  1
259145  99.368  -75.179  47.585  1
259146  99.398  -75.182  47.543  1
259147  99.427  -75.188  47.503  1
259148  99.451  -75.195  47.464  1
259149  99.483  -75.201  47.426  1
259150  99.519  -75.204  47.389  1
259151  99.555  -75.207  47.356  1
259152  99.590  -75.210  47.325  1
259153  99.627  -75.214  47.296  1
259154  99.662  -75.217  47.269  1
259155  99.698  -75.221  47.242  1
259156  99.734  -75.224  47.217  1
259157  99.770  -75.228  47.193  1
259158  99.805  -75.231  47.171  1
259159  99.841  -75.235  47.149  1
259160  99.877  -75.238  47.128  1
259161  99.905  -75.245  47.107  1
259162  99.922  -75.258  47.085  1
259163  99.932  -75.285  47.062  1
259164  99.951  -75.322  47.040  1
259165  100.003  -75.339  47.020  1
259166  100.054  -75.355  47.000  1
259167  100.056  -75.391  46.981  1
259168  100.078  -75.389  46.961  1
259169  100.104  -75.388  46.941  1
259170  100.149  -75.395  46.916  1
259171  100.158  -75.396  46.891  1
259172  100.167  -75.396  46.864  1
259173  100.176  -75.397  46.836  1
259174  100.185  -75.398  46.807  1
259175  100.196  -75.406  46.775  1
259176  100.213  -75.427  46.743  1
259177  100.229  -75.439  46.710  1
259178  100.246  -75.452  46.679  1
259179  100.274  -75.478  46.647  1
259180  100.303  -75.505  46.616  1
259181  100.332  -75.532  46.586  1
259182  100.360  -75.558  46.555  1
259183  100.389  -75.586  46.525  1
259184  100.418  -75.612  46.495  1
259185  100.447  -75.640  46.467  1
259186  100.476  -75.666  46.437  1
259187  100.504  -75.693  46.409  1
259188  100.533  -75.720  46.380  1
259189  100.562  -75.747  46.351  1
259190  100.590  -75.760  46.323  1
259191  100.616  -75.748  46.296  1
259192  100.643  -75.737  46.270  1
259193  100.693  -75.734  46.243  1
259194  100.742  -75.731  46.216  1
259195  100.780  -75.742  46.187  1
259196  100.812  -75.766  46.158  1
259197  100.843  -75.791  46.129  1
259198  100.874  -75.817  46.104  1
259199  100.905  -75.843  46.077  1
259200  100.936  -75.869  46.050  1
259201  100.967  -75.894  46.022  1
259202  100.985  -75.903  45.993  1
259203  101.000  -75.910  45.962  1
259204  101.015  -75.916  45.930  1
259205  101.029  -75.922  45.898  1
259206  101.044  -75.928  45.868  1
259207  101.059  -75.934  45.836  1
259208  101.074  -75.941  45.805  1
259209  101.089  -75.947  45.774  1
259210  101.115  -75.955  45.744  1
259211  101.156  -75.966  45.716  1
259212  101.198  -75.978  45.688  1
259213  101.240  -75.989  45.660  1
259214  101.281  -76.000  45.633  1
259215  101.324  -76.011  45.606  1
259216  101.368  -76.021  45.578  1
259217  101.411  -76.032  45.549  1
259218  101.454  -76.041  45.521  1
259219  101.498  -76.051  45.494  1
259220  101.541  -76.061  45.468  1
259221  101.585  -76.072  45.443  1
259222  101.613  -76.082  45.418  1
259223  101.645  -76.097  45.394  1
259224  101.702  -76.135  45.369  1
259225  101.744  -76.163  45.347  1
259226  101.752  -76.166  45.323  1
259227  101.759  -76.168  45.299  1
259228  101.767  -76.171  45.275  1
259229  101.774  -76.174  45.251  1
259230  101.782  -76.176  45.229  1
259231  101.790  -76.179  45.205  1
259232  101.798  -76.182  45.182  1
259233  101.805  -76.185  45.159  1
259234  101.813  -76.188  45.135  1
259235  101.820  -76.190  45.113  1
259236  101.828  -76.193  45.090  1
259589  92.570  -73.791  54.641  1
259590  92.594  -73.802  54.640  1
259591  92.619  -73.813  54.640  1
259592  92.643  -73.823  54.638  1
259593  92.667  -73.834  54.638  1
259594  92.692  -73.844  54.637  1
259595  92.716  -73.856  54.636  1
259596  92.739  -73.863  54.635  1
259597  92.766  -73.854  54.634  1
259598  92.796  -73.860  54.634  1
259599  92.826  -73.879  54.635  1
259600  92.855  -73.897  54.637  1
259601  92.885  -73.916  54.639  1
259602  92.915  -73.935  54.641  1
259603  92.944  -73.954  54.644  1
259604  92.974  -73.970  54.648  1
259605  93.003  -73.976  54.652  1
259606  93.031  -73.982  54.654  1
259607  93.054  -73.979  54.657  1
259608  93.080  -73.972  54.660  1
259609  93.115  -73.949  54.663  1
259610  93.149  -73.927  54.664  1
259611  93.183  -73.907  54.665  1
259612  93.203  -73.911  54.664  1
259613  93.223  -73.916  54.662  1
259614  93.244  -73.921  54.663  1
259615  93.265  -73.926  54.665  1
259616  93.285  -73.931  54.668  1
259617  93.318  -73.932  54.671  1
259618  93.350  -73.934  54.672  1
259619  93.383  -73.935  54.671  1
259620  93.416  -73.937  54.669  1
259621  93.449  -73.939  54.666  1
259622  93.472  -73.926  54.664  1
259623  93.494  -73.913  54.662  1
259624  93.516  -73.901  54.659  1
259625  93.539  -73.888  54.658  1
259626  93.561  -73.875  54.658  1
259627  93.585  -73.869  54.659  1
259628  93.618  -73.872  54.661  1
259629  93.676  -73.894  54.665  1
259630  93.733  -73.916  54.671  1
259631  93.746  -73.917  54.679  1
259632  93.756  -73.918  54.690  1
259633  93.766  -73.918  54.708  1
259634  93.776  -73.918  54.729  1
259635  93.786  -73.919  54.751  1
259636  93.798  -73.919  54.773  1
259637  93.819  -73.919  54.786  1
259638  93.840  -73.920  54.797  1
259639  93.861  -73.921  54.804  1
259640  93.882  -73.922  54.799  1
259641  93.903  -73.922  54.786  1
259642  93.924  -73.924  54.765  1
259643  93.946  -73.926  54.736  1
259644  93.968  -73.928  54.698  1
259645  93.989  -73.929  54.652  1
259646  94.020  -73.930  54.604  1
259647  94.051  -73.931  54.557  1
259648  94.082  -73.932  54.514  1
259649  94.114  -73.931  54.485  1
259650  94.146  -73.929  54.463  1
259651  94.176  -73.936  54.445  1
259652  94.209  -73.936  54.429  1
259653  94.242  -73.935  54.418  1
259654  94.275  -73.932  54.404  1
259655  94.307  -73.932  54.385  1
259656  94.338  -73.931  54.361  1
259657  94.369  -73.930  54.335  1
259658  94.401  -73.929  54.306  1
259659  94.432  -73.929  54.276  1
259660  94.456  -73.931  54.248  1
259661  94.468  -73.934  54.219  1
259662  94.464  -73.929  54.190  1
259663  94.458  -73.929  54.160  1
259664  94.453  -73.929  54.130  1
259665  94.463  -73.927  54.098  1
259666  94.490  -73.926  54.065  1
259667  94.518  -73.924  54.032  1
259668  94.543  -73.930  53.999  1
259669  94.565  -73.944  53.964  1
259670  94.587  -73.959  53.925  1
259671  94.605  -73.959  53.881  1
259672  94.623  -73.957  53.835  1
259673  94.640  -73.954  53.791  1
259674  94.660  -73.944  53.749  1
259675  94.680  -73.935  53.708  1
259676  94.700  -73.926  53.666  1
259677  94.718  -73.919  53.627  1
259678  94.733  -73.921  53.591  1
259679  94.748  -73.922  53.557  1
259680  94.763  -73.924  53.531  1
259681  94.778  -73.926  53.510  1
259682  94.802  -73.932  53.491  1
259683  94.849  -73.949  53.474  1
259684  94.896  -73.966  53.447  1
259685  94.943  -73.983  53.415  1
259686  94.978  -74.003  53.381  1
259687  94.988  -74.029  53.343  1
259688  95.001  -74.048  53.305  1
259689  95.023  -74.043  53.266  1
259690  95.044  -74.038  53.226  1
259691  95.065  -74.032  53.185  1
259692  95.087  -74.027  53.138  1
259693  95.108  -74.022  53.085  1
259694  95.130  -74.017  53.031  1
259695  95.151  -74.011  52.978  1
259696  95.173  -74.006  52.927  1
259697  95.194  -74.001  52.877  1
259698  95.180  -74.037  52.827  1
259699  95.187  -74.026  52.779  1
259700  95.217  -74.028  52.729  1
259701  95.250  -74.032  52.681  1
259702  95.287  -74.037  52.634  1
259703  95.326  -74.042  52.589  1
259704  95.366  -74.047  52.544  1
259705  95.406  -74.052  52.500  1
259706  95.447  -74.055  52.458  1
259707  95.489  -74.054  52.417  1
259708  95.532  -74.054  52.376  1
259709  95.574  -74.053  52.337  1
259710  95.617  -74.052  52.298  1
259711  95.660  -74.051  52.259  1
259712  95.702  -74.051  52.222  1
259713  95.722  -74.046  52.186  1
259714  95.736  -74.040  52.149  1
259715  95.750  -74.035  52.113  1
259716  95.764  -74.029  52.075  1
259717  95.778  -74.023  52.039  1
259718  95.792  -74.018  52.003  1
259719  95.806  -74.012  51.969  1
259720  95.819  -74.007  51.935  1
259721  95.833  -74.001  51.901  1
259722  95.847  -73.995  51.868  1
259723  95.861  -73.990  51.834  1
259724  95.875  -73.984  51.800  1
259725  95.897  -73.979  51.763  1
259726  95.924  -73.989  51.724  1
259727  95.949  -74.002  51.684  1
259728  95.978  -74.015  51.644  1
259729  96.008  -74.027  51.604  1
259730  96.038  -74.039  51.564  1
259731  96.068  -74.052  51.524  1
259732  96.098  -74.064  51.485  1
259733  96.127  -74.076  51.448  1
259734  96.158  -74.089  51.411  1
259735  96.187  -74.101  51.375  1
259736  96.218  -74.106  51.342  1
259737  96.251  -74.109  51.309  1
259738  96.284  -74.115  51.278  1
259739  96.317  -74.121  51.248  1
259740  96.317  -74.165  51.220  1
259741  96.347  -74.183  51.193  1
259742  96.379  -74.200  51.167  1
259743  96.410  -74.217  51.143  1
259744  96.441  -74.235  51.120  1
259745  96.472  -74.252  51.098  1
259746  96.504  -74.270  51.077  1
259747  96.534  -74.287  51.059  1
259748  96.566  -74.305  51.042  1
259749  96.597  -74.322  51.027  1
259750  96.628  -74.337  51.013  1
259751  96.660  -74.351  51.001  1
259752  96.691  -74.364  50.991  1
259753  96.716  -74.375  50.982  1
259754  96.728  -74.380  50.974  1
259755  96.742  -74.385  50.969  1
259756  96.763  -74.390  50.965  1
259757  96.784  -74.396  50.963  1
259758  96.804  -74.402  50.963  1
259759  96.825  -74.407  50.964  1
259760  96.846  -74.412  50.969  1
259761  96.890  -74.440  50.977  1
259762  96.914  -74.457  50.987  1
259763  96.932  -74.469  50.998  1
259764  96.949  -74.481  51.009  1
259765  96.966  -74.493  51.017  1
259766  96.983  -74.505  51.023  1
259767  97.001  -74.518  51.027  1
259768  97.018  -74.530  51.029  1
259769  97.037  -74.539  51.028  1
259770  97.073  -74.532  51.026  1
259771  97.108  -74.526  51.021  1
259772  97.144  -74.519  51.012  1
259773  97.179  -74.513  50.999  1
259774  97.214  -74.506  50.982  1
259775  97.249  -74.500  50.961  1
259776  97.285  -74.493  50.936  1
259777  97.320  -74.487  50.909  1
259778  97.363  -74.476  50.880  1
259779  97.409  -74.463  50.847  1
259780  97.457  -74.449  50.815  1
259781  97.504  -74.436  50.782  1
259782  97.550  -74.423  50.747  1
259783  97.597  -74.410  50.713  1
259784  97.628  -74.420  50.673  1
259785  97.655  -74.436  50.630  1
259786  97.682  -74.452  50.585  1
259787  97.709  -74.468  50.538  1
259788  97.736  -74.483  50.489  1
259789  97.763  -74.499  50.440  1
259790  97.790  -74.515  50.389  1
259791  97.821  -74.534  50.337  1
259792  97.858  -74.558  50.286  1
259793  97.888  -74.573  50.237  1
259794  97.911  -74.578  50.190  1
259795  97.933  -74.584  50.145  1
259796  97.956  -74.590  50.100  1
259797  97.979  -74.596  50.058  1
259798  98.001  -74.602  50.018  1
259799  98.023  -74.608  49.980  1
259800  98.052  -74.618  49.938  1
259801  98.085  -74.633  49.893  1
259802  98.118  -74.646  49.843  1
259803  98.150  -74.661  49.789  1
259804  98.183  -74.675  49.731  1
259805  98.214  -74.697  49.672  1
259806  98.244  -74.722  49.612  1
259807  98.274  -74.747  49.552  1
259808  98.304  -74.771  49.495  1
259809  98.335  -74.795  49.437  1
259810  98.365  -74.819  49.380  1
259811  98.380  -74.842  49.327  1
259812  98.423  -74.817  49.273  1
259813  98.452  -74.787  49.220  1
259814  98.482  -74.758  49.166  1
259815  98.511  -74.728  49.111  1
259816  98.535  -74.703  49.058  1
259817  98.563  -74.712  49.007  1
259818  98.590  -74.723  48.956  1
259819  98.618  -74.734  48.907  1
259820  98.643  -74.758  48.855  1
259821  98.668  -74.785  48.801  1
259822  98.693  -74.812  48.747  1
259823  98.718  -74.840  48.692  1
259824  98.743  -74.867  48.637  1
259825  98.768  -74.894  48.582  1
259826  98.793  -74.922  48.528  1
259827  98.818  -74.948  48.475  1
259828  98.856  -74.925  48.424  1
259829  98.900  -74.880  48.372  1
259830  98.930  -74.865  48.322  1
259831  98.947  -74.879  48.271  1
259832  98.964  -74.894  48.223  1
259833  98.985  -74.910  48.174  1
259834  99.010  -74.928  48.126  1
259835  99.034  -74.947  48.078  1
259836  99.059  -74.965  48.030  1
259837  99.084  -74.983  47.983  1
259838  99.109  -75.002  47.937  1
259839  99.133  -75.020  47.891  1
259840  99.165  -75.039  47.845  1
259841  99.201  -75.059  47.800  1
259842  99.237  -75.078  47.756  1
259843  99.273  -75.098  47.710  1
259844  99.308  -75.117  47.665  1
259845  99.345  -75.137  47.620  1
259846  99.380  -75.155  47.577  1
259847  99.410  -75.159  47.535  1
259848  99.437  -75.166  47.496  1
259849  99.467  -75.172  47.457  1
259850  99.503  -75.175  47.419  1
259851  99.539  -75.178  47.382  1
259852  99.574  -75.182  47.349  1
259853  99.610  -75.185  47.319  1
259854  99.646  -75.189  47.289  1
259855  99.682  -75.192  47.261  1
259856  99.717  -75.195  47.234  1
259857  99.754  -75.198  47.208  1
259858  99.772  -75.210  47.184  1
259859  99.789  -75.223  47.161  1
259860  99.806  -75.236  47.139  1
259861  99.831  -75.244  47.118  1
259862  99.862  -75.248  47.097  1
259863  99.893  -75.252  47.075  1
259864  99.928  -75.262  47.052  1
259865  99.985  -75.272  47.031  1
259866  100.041  -75.278  47.009  1
259867  100.093  -75.295  46.989  1
259868  100.109  -75.326  46.968  1
259869  100.107  -75.360  46.947  1
259870  100.129  -75.358  46.927  1
259871  100.168  -75.364  46.902  1
259872  100.176  -75.364  46.876  1
259873  100.185  -75.364  46.850  1
259874  100.194  -75.364  46.821  1
259875  100.213  -75.402  46.792  1
259876  100.230  -75.417  46.761  1
259877  100.247  -75.430  46.729  1
259878  100.263  -75.442  46.697  1
259879  100.279  -75.454  46.667  1
259880  100.295  -75.466  46.637  1
259881  100.319  -75.486  46.607  1
259882  100.347  -75.513  46.576  1
259883  100.376  -75.540  46.546  1
259884  100.405  -75.567  46.516  1
259885  100.433  -75.594  46.487  1
259886  100.462  -75.621  46.459  1
259887  100.491  -75.648  46.430  1
259888  100.520  -75.674  46.402  1
259889  100.549  -75.702  46.373  1
259890  100.577  -75.728  46.344  1
259891  100.605  -75.731  46.316  1
259892  100.631  -75.719  46.289  1
259893  100.657  -75.708  46.263  1
259894  100.703  -75.703  46.236  1
259895  100.752  -75.699  46.210  1
259896  100.798  -75.704  46.181  1
259897  100.830  -75.729  46.151  1
259898  100.861  -75.755  46.123  1
259899  100.892  -75.781  46.098  1
259900  100.923  -75.806  46.072  1
259901  100.955  -75.832  46.045  1
259902  100.985  -75.856  46.017  1
259903  101.002  -75.863  45.987  1
259904  101.017  -75.870  45.956  1
259905  101.032  -75.877  45.923  1
259906  101.046  -75.883  45.891  1
259907  101.061  -75.889  45.860  1
259908  101.076  -75.895  45.830  1
259909  101.091  -75.901  45.799  1
259910  101.106  -75.907  45.769  1
259911  101.120  -75.913  45.739  1
259912  101.160  -75.925  45.712  1
259913  101.202  -75.936  45.684  1
259914  101.245  -75.946  45.656  1
259915  101.288  -75.956  45.629  1
259916  101.332  -75.966  45.601  1
259917  101.375  -75.976  45.572  1
259918  101.418  -75.986  45.542  1
259919  101.462  -75.997  45.514  1
259920  101.505  -76.007  45.487  1
259921  101.549  -76.016  45.461  1
259922  101.581  -76.026  45.435  1
259923  101.614  -76.043  45.410  1
259924  101.671  -76.082  45.385  1
259925  101.728  -76.119  45.361  1
259926  101.748  -76.132  45.337  1
259927  101.755  -76.135  45.313  1
259928  101.763  -76.137  45.289  1
259929  101.770  -76.140  45.265  1
259930  101.778  -76.142  45.241  1
259931  101.786  -76.145  45.218  1
259932  101.793  -76.148  45.195  1
259933  101.801  -76.151  45.171  1
259934  101.809  -76.154  45.148  1
259935  101.816  -76.156  45.125  1
259936  101.824  -76.159  45.101  1
259937  101.832  -76.161  45.079  1
260290  92.571  -73.759  54.643  1
260291  92.596  -73.769  54.642  1
260292  92.620  -73.780  54.640  1
260293  92.645  -73.791  54.639  1
260294  92.669  -73.801  54.638  1
260295  92.693  -73.813  54.637  1
260296  92.718  -73.823  54.636  1
260297  92.742  -73.834  54.635  1
260298  92.768  -73.826  54.634  1
260299  92.797  -73.834  54.633  1
260300  92.827  -73.852  54.635  1
260301  92.857  -73.871  54.637  1
260302  92.886  -73.890  54.638  1
260303  92.916  -73.908  54.641  1
260304  92.945  -73.922  54.644  1
260305  92.974  -73.929  54.648  1
260306  93.003  -73.935  54.651  1
260307  93.031  -73.941  54.654  1
260308  93.056  -73.941  54.657  1
260309  93.079  -73.938  54.660  1
260310  93.102  -73.935  54.663  1
260311  93.133  -73.919  54.665  1
260312  93.167  -73.897  54.666  1
260313  93.198  -73.882  54.666  1
260314  93.219  -73.887  54.663  1
260315  93.239  -73.891  54.661  1
260316  93.260  -73.896  54.662  1
260317  93.285  -73.900  54.664  1
260318  93.318  -73.901  54.666  1
260319  93.351  -73.903  54.667  1
260320  93.384  -73.904  54.668  1
260321  93.417  -73.907  54.667  1
260322  93.450  -73.908  54.664  1
260323  93.475  -73.899  54.661  1
260324  93.498  -73.886  54.658  1
260325  93.520  -73.873  54.655  1
260326  93.542  -73.860  54.652  1
260327  93.565  -73.847  54.649  1
260328  93.614  -73.855  54.646  1
260329  93.665  -73.872  54.646  1
260330  93.723  -73.894  54.646  1
260331  93.733  -73.894  54.649  1
260332  93.743  -73.894  54.653  1
260333  93.752  -73.894  54.659  1
260334  93.761  -73.894  54.673  1
260335  93.770  -73.894  54.689  1
260336  93.780  -73.894  54.707  1
260337  93.798  -73.895  54.725  1
260338  93.820  -73.896  54.739  1
260339  93.840  -73.897  54.748  1
260340  93.861  -73.897  54.753  1
260341  93.883  -73.897  54.756  1
260342  93.904  -73.899  54.745  1
260343  93.924  -73.900  54.726  1
260344  93.946  -73.901  54.701  1
260345  93.968  -73.903  54.668  1
260346  93.993  -73.904  54.623  1
260347  94.024  -73.905  54.575  1
260348  94.055  -73.905  54.528  1
260349  94.087  -73.903  54.489  1
260350  94.119  -73.901  54.460  1
260351  94.150  -73.899  54.438  1
260352  94.175  -73.898  54.421  1
260353  94.213  -73.917  54.406  1
260354  94.246  -73.915  54.396  1
260355  94.279  -73.913  54.382  1
260356  94.312  -73.911  54.364  1
260357  94.344  -73.910  54.341  1
260358  94.378  -73.907  54.314  1
260359  94.410  -73.906  54.286  1
260360  94.442  -73.905  54.257  1
260361  94.473  -73.904  54.228  1
260362  94.488  -73.905  54.198  1
260363  94.482  -73.904  54.167  1
260364  94.476  -73.904  54.136  1
260365  94.470  -73.903  54.105  1
260366  94.466  -73.902  54.072  1
260367  94.493  -73.901  54.039  1
260368  94.521  -73.899  54.005  1
260369  94.544  -73.912  53.971  1
260370  94.566  -73.926  53.935  1
260371  94.588  -73.940  53.896  1
260372  94.607  -73.944  53.854  1
260373  94.625  -73.941  53.810  1
260374  94.642  -73.939  53.767  1
260375  94.660  -73.935  53.725  1
260376  94.680  -73.926  53.685  1
260377  94.699  -73.916  53.647  1
260378  94.719  -73.907  53.611  1
260379  94.735  -73.907  53.577  1
260380  94.750  -73.908  53.548  1
260381  94.765  -73.910  53.525  1
260382  94.780  -73.911  53.503  1
260383  94.805  -73.917  53.482  1
260384  94.852  -73.935  53.460  1
260385  94.898  -73.951  53.431  1
260386  94.945  -73.969  53.399  1
260387  94.992  -73.985  53.364  1
260388  95.008  -74.010  53.328  1
260389  95.020  -74.033  53.291  1
260390  95.041  -74.028  53.253  1
260391  95.062  -74.023  53.213  1
260392  95.084  -74.017  53.170  1
260393  95.105  -74.012  53.121  1
260394  95.127  -74.007  53.068  1
260395  95.148  -74.001  53.014  1
260396  95.170  -73.996  52.960  1
260397  95.182  -74.001  52.909  1
260398  95.174  -74.016  52.859  1
260399  95.181  -74.004  52.810  1
260400  95.192  -73.995  52.762  1
260401  95.224  -73.999  52.715  1
260402  95.257  -74.003  52.668  1
260403  95.289  -74.007  52.623  1
260404  95.322  -74.011  52.579  1
260405  95.356  -74.015  52.536  1
260406  95.396  -74.020  52.494  1
260407  95.435  -74.026  52.452  1
260408  95.475  -74.030  52.412  1
260409  95.518  -74.029  52.372  1
260410  95.560  -74.029  52.333  1
260411  95.603  -74.028  52.295  1
260412  95.645  -74.027  52.256  1
260413  95.687  -74.026  52.220  1
260414  95.700  -74.021  52.183  1
260415  95.714  -74.015  52.147  1
260416  95.728  -74.010  52.110  1
260417  95.742  -74.004  52.073  1
260418  95.756  -73.998  52.037  1
260419  95.770  -73.993  52.002  1
260420  95.784  -73.987  51.968  1
260421  95.798  -73.982  51.935  1
260422  95.812  -73.976  51.901  1
260423  95.836  -73.971  51.868  1
260424  95.862  -73.966  51.836  1
260425  95.887  -73.960  51.800  1
260426  95.918  -73.955  51.763  1
260427  95.933  -73.957  51.726  1
260428  95.966  -73.977  51.686  1
260429  95.995  -73.995  51.645  1
260430  96.019  -74.008  51.606  1
260431  96.043  -74.022  51.566  1
260432  96.067  -74.035  51.525  1
260433  96.092  -74.048  51.486  1
260434  96.118  -74.061  51.449  1
260435  96.148  -74.074  51.413  1
260436  96.178  -74.086  51.377  1
260437  96.208  -74.098  51.344  1
260438  96.241  -74.101  51.311  1
260439  96.274  -74.107  51.279  1
260440  96.308  -74.114  51.250  1
260441  96.337  -74.124  51.221  1
260442  96.352  -74.154  51.194  1
260443  96.383  -74.172  51.169  1
260444  96.414  -74.189  51.144  1
260445  96.445  -74.207  51.122  1
260446  96.476  -74.224  51.099  1
260447  96.508  -74.242  51.078  1
260448  96.539  -74.257  51.060  1
260449  96.571  -74.270  51.042  1
260450  96.602  -74.284  51.027  1
260451  96.634  -74.298  51.013  1
260452  96.666  -74.312  51.001  1
260453  96.697  -74.326  50.989  1
260454  96.722  -74.336  50.980  1
260455  96.734  -74.342  50.973  1
260456  96.746  -74.346  50.966  1
260457  96.758  -74.351  50.963  1
260458  96.773  -74.356  50.961  1
260459  96.794  -74.361  50.961  1
260460  96.814  -74.367  50.962  1
260461  96.835  -74.372  50.967  1
260462  96.886  -74.406  50.974  1
260463  96.908  -74.422  50.983  1
260464  96.926  -74.434  50.994  1
260465  96.943  -74.446  51.004  1
260466  96.960  -74.458  51.013  1
260467  96.977  -74.471  51.021  1
260468  96.995  -74.482  51.028  1
260469  97.030  -74.476  51.032  1
260470  97.065  -74.469  51.032  1
260471  97.100  -74.463  51.030  1
260472  97.136  -74.456  51.027  1
260473  97.171  -74.450  51.016  1
260474  97.206  -74.443  51.002  1
260475  97.241  -74.437  50.983  1
260476  97.277  -74.430  50.961  1
260477  97.312  -74.424  50.936  1
260478  97.348  -74.418  50.908  1
260479  97.388  -74.408  50.878  1
260480  97.435  -74.396  50.845  1
260481  97.481  -74.382  50.812  1
260482  97.528  -74.369  50.779  1
260483  97.575  -74.355  50.745  1
260484  97.605  -74.368  50.711  1
260485  97.632  -74.383  50.672  1
260486  97.659  -74.399  50.629  1
260487  97.686  -74.415  50.584  1
260488  97.713  -74.431  50.535  1
260489  97.740  -74.447  50.485  1
260490  97.767  -74.463  50.435  1
260491  97.794  -74.479  50.383  1
260492  97.822  -74.496  50.333  1
260493  97.860  -74.519  50.282  1
260494  97.890  -74.534  50.234  1
260495  97.912  -74.540  50.187  1
260496  97.935  -74.546  50.140  1
260497  97.957  -74.552  50.095  1
260498  97.980  -74.557  50.053  1
260499  98.002  -74.563  50.014  1
260500  98.029  -74.573  49.973  1
260501  98.063  -74.587  49.931  1
260502  98.095  -74.601  49.884  1
260503  98.128  -74.615  49.834  1
260504  98.161  -74.629  49.779  1
260505  98.194  -74.643  49.720  1
260506  98.227  -74.657  49.659  1
260507  98.260  -74.671  49.599  1
260508  98.290  -74.696  49.540  1
260509  98.319  -74.720  49.484  1
260510  98.350  -74.745  49.426  1
260511  98.304  -74.699  49.369  1
260512  98.305  -74.788  49.317  1
260513  98.325  -74.839  49.262  1
260514  98.397  -74.784  49.208  1
260515  98.468  -74.728  49.154  1
260516  98.518  -74.687  49.099  1
260517  98.545  -74.674  49.046  1
260518  98.571  -74.694  48.995  1
260519  98.596  -74.722  48.945  1
260520  98.621  -74.749  48.897  1
260521  98.646  -74.776  48.845  1
260522  98.671  -74.803  48.792  1
260523  98.696  -74.831  48.737  1
260524  98.721  -74.857  48.681  1
260525  98.746  -74.885  48.627  1
260526  98.771  -74.912  48.573  1
260527  98.796  -74.939  48.520  1
260528  98.825  -74.953  48.467  1
260529  98.869  -74.907  48.416  1
260530  98.913  -74.862  48.364  1
260531  98.946  -74.839  48.313  1
260532  98.963  -74.853  48.262  1
260533  98.980  -74.868  48.213  1
260534  98.997  -74.882  48.165  1
260535  99.018  -74.900  48.116  1
260536  99.043  -74.918  48.068  1
260537  99.068  -74.936  48.021  1
260538  99.092  -74.954  47.974  1
260539  99.117  -74.972  47.927  1
260540  99.142  -74.991  47.882  1
260541  99.175  -75.010  47.837  1
260542  99.211  -75.030  47.792  1
260543  99.247  -75.049  47.748  1
260544  99.283  -75.069  47.702  1
260545  99.319  -75.088  47.657  1
260546  99.355  -75.108  47.613  1
260547  99.391  -75.128  47.570  1
260548  99.423  -75.136  47.529  1
260549  99.450  -75.142  47.489  1
260550  99.487  -75.145  47.450  1
260551  99.522  -75.149  47.411  1
260552  99.558  -75.152  47.375  1
260553  99.594  -75.156  47.342  1
260554  99.621  -75.163  47.312  1
260555  99.639  -75.176  47.282  1
260556  99.663  -75.184  47.254  1
260557  99.694  -75.189  47.226  1
260558  99.725  -75.192  47.200  1
260559  99.756  -75.197  47.175  1
260560  99.787  -75.201  47.153  1
260561  99.819  -75.205  47.130  1
260562  99.849  -75.210  47.108  1
260563  99.880  -75.214  47.087  1
260564  99.912  -75.218  47.064  1
260565  99.949  -75.231  47.042  1
260566  100.000  -75.259  47.020  1
260567  100.056  -75.270  46.998  1
260568  100.117  -75.267  46.977  1
260569  100.154  -75.270  46.956  1
260570  100.157  -75.298  46.934  1
260571  100.158  -75.330  46.912  1
260572  100.186  -75.331  46.886  1
260573  100.194  -75.332  46.861  1
260574  100.211  -75.361  46.835  1
260575  100.230  -75.395  46.807  1
260576  100.247  -75.408  46.778  1
260577  100.263  -75.420  46.748  1
260578  100.280  -75.432  46.716  1
260579  100.296  -75.444  46.685  1
260580  100.313  -75.456  46.656  1
260581  100.329  -75.469  46.627  1
260582  100.345  -75.481  46.597  1
260583  100.363  -75.495  46.567  1
260584  100.392  -75.521  46.538  1
260585  100.420  -75.549  46.507  1
260586  100.449  -75.575  46.478  1
260587  100.478  -75.602  46.451  1
260588  100.506  -75.629  46.423  1
260589  100.536  -75.656  46.394  1
260590  100.564  -75.683  46.366  1
260591  100.593  -75.710  46.337  1
260592  100.619  -75.702  46.308  1
260593  100.646  -75.690  46.281  1
260594  100.672  -75.678  46.255  1
260595  100.713  -75.672  46.229  1
260596  100.763  -75.670  46.202  1
260597  100.812  -75.671  46.174  1
260598  100.846  -75.693  46.145  1
260599  100.878  -75.718  46.117  1
260600  100.909  -75.744  46.091  1
260601  100.940  -75.770  46.065  1
260602  100.971  -75.796  46.039  1
260603  101.002  -75.812  46.011  1
260604  101.023  -75.822  45.979  1
260605  101.037  -75.828  45.948  1
260606  101.052  -75.834  45.916  1
260607  101.066  -75.841  45.884  1
260608  101.080  -75.847  45.853  1
260609  101.095  -75.854  45.823  1
260610  101.110  -75.860  45.793  1
260611  101.124  -75.867  45.764  1
260612  101.138  -75.873  45.734  1
260613  101.165  -75.881  45.706  1
260614  101.209  -75.891  45.678  1
260615  101.253  -75.901  45.649  1
260616  101.296  -75.911  45.623  1
260617  101.339  -75.922  45.593  1
260618  101.383  -75.931  45.563  1
260619  101.426  -75.941  45.533  1
260620  101.470  -75.951  45.504  1
260621  101.513  -75.962  45.477  1
260622  101.548  -75.972  45.451  1
260623  101.583  -75.989  45.425  1
260624  101.639  -76.027  45.399  1
260625  101.696  -76.066  45.375  1
260626  101.744  -76.097  45.351  1
260627  101.751  -76.100  45.327  1
260628  101.759  -76.103  45.303  1
260629  101.767  -76.106  45.278  1
260630  101.774  -76.108  45.254  1
260631  101.782  -76.111  45.230  1
260632  101.790  -76.114  45.206  1
260633  101.797  -76.116  45.183  1
260634  101.805  -76.119  45.160  1
260635  101.813  -76.122  45.136  1
260636  101.820  -76.125  45.113  1
260637  101.828  -76.127  45.089  1
260638  101.835  -76.130  45.066  1
260990  92.549  -73.716  54.646  1
260991  92.573  -73.726  54.645  1
260992  92.598  -73.737  54.643  1
260993  92.622  -73.747  54.641  1
260994  92.646  -73.758  54.639  1
260995  92.671  -73.769  54.638  1
260996  92.695  -73.780  54.636  1
260997  92.720  -73.791  54.635  1
260998  92.744  -73.801  54.634  1
260999  92.769  -73.799  54.633  1
261000  92.799  -73.807  54.633  1
261001  92.829  -73.826  54.634  1
261002  92.858  -73.845  54.635  1
261003  92.887  -73.863  54.637  1
261004  92.917  -73.875  54.639  1
261005  92.945  -73.881  54.642  1
261006  92.974  -73.888  54.646  1
261007  93.003  -73.894  54.650  1
261008  93.031  -73.900  54.654  1
261009  93.058  -73.902  54.657  1
261010  93.081  -73.900  54.660  1
261011  93.104  -73.897  54.663  1
261012  93.127  -73.894  54.665  1
261013  93.151  -73.889  54.667  1
261014  93.186  -73.866  54.667  1
261015  93.214  -73.857  54.664  1
261016  93.234  -73.862  54.661  1
261017  93.255  -73.866  54.659  1
261018  93.286  -73.869  54.659  1
261019  93.319  -73.870  54.660  1
261020  93.352  -73.872  54.662  1
261021  93.384  -73.874  54.664  1
261022  93.418  -73.875  54.664  1
261023  93.450  -73.877  54.662  1
261024  93.479  -73.872  54.659  1
261025  93.501  -73.860  54.655  1
261026  93.523  -73.847  54.652  1
261027  93.546  -73.834  54.647  1
261028  93.602  -73.844  54.641  1
261029  93.666  -73.865  54.636  1
261030  93.694  -73.868  54.633  1
261031  93.718  -73.870  54.630  1
261032  93.727  -73.870  54.629  1
261033  93.736  -73.870  54.629  1
261034  93.746  -73.871  54.630  1
261035  93.755  -73.871  54.637  1
261036  93.764  -73.871  54.647  1
261037  93.777  -73.871  54.660  1
261038  93.798  -73.872  54.673  1
261039  93.820  -73.872  54.685  1
261040  93.841  -73.872  54.694  1
261041  93.862  -73.873  54.701  1
261042  93.883  -73.874  54.704  1
261043  93.904  -73.875  54.697  1
261044  93.925  -73.875  54.683  1
261045  93.946  -73.876  54.665  1
261046  93.967  -73.878  54.635  1
261047  93.997  -73.879  54.595  1
261048  94.029  -73.877  54.549  1
261049  94.061  -73.875  54.501  1
261050  94.092  -73.873  54.463  1
261051  94.124  -73.872  54.434  1
261052  94.154  -73.869  54.412  1
261053  94.179  -73.869  54.394  1
261054  94.204  -73.869  54.382  1
261055  94.249  -73.896  54.371  1
261056  94.282  -73.894  54.358  1
261057  94.315  -73.892  54.341  1
261058  94.348  -73.890  54.317  1
261059  94.381  -73.888  54.291  1
261060  94.414  -73.886  54.263  1
261061  94.447  -73.885  54.235  1
261062  94.480  -73.882  54.207  1
261063  94.498  -73.880  54.176  1
261064  94.500  -73.879  54.145  1
261065  94.494  -73.878  54.113  1
261066  94.488  -73.877  54.080  1
261067  94.483  -73.876  54.047  1
261068  94.497  -73.875  54.012  1
261069  94.523  -73.879  53.978  1
261070  94.545  -73.893  53.942  1
261071  94.567  -73.907  53.905  1
261072  94.589  -73.922  53.866  1
261073  94.609  -73.929  53.826  1
261074  94.626  -73.926  53.784  1
261075  94.644  -73.924  53.742  1
261076  94.661  -73.922  53.701  1
261077  94.680  -73.916  53.662  1
261078  94.699  -73.907  53.628  1
261079  94.719  -73.897  53.595  1
261080  94.737  -73.891  53.565  1
261081  94.752  -73.894  53.539  1
261082  94.767  -73.895  53.518  1
261083  94.782  -73.897  53.496  1
261084  94.808  -73.904  53.471  1
261085  94.854  -73.920  53.445  1
261086  94.901  -73.938  53.415  1
261087  94.948  -73.954  53.383  1
261088  94.994  -73.972  53.349  1
261089  95.027  -73.992  53.314  1
261090  95.038  -74.018  53.278  1
261091  95.059  -74.013  53.239  1
261092  95.080  -74.007  53.198  1
261093  95.102  -74.002  53.153  1
261094  95.123  -73.997  53.102  1
261095  95.145  -73.991  53.049  1
261096  95.166  -73.986  52.995  1
261097  95.160  -74.006  52.941  1
261098  95.167  -73.995  52.890  1
261099  95.175  -73.983  52.841  1
261100  95.182  -73.972  52.793  1
261101  95.199  -73.966  52.746  1
261102  95.232  -73.970  52.701  1
261103  95.264  -73.974  52.657  1
261104  95.297  -73.979  52.613  1
261105  95.329  -73.982  52.570  1
261106  95.361  -73.986  52.528  1
261107  95.394  -73.990  52.488  1
261108  95.426  -73.994  52.448  1
261109  95.465  -73.999  52.408  1
261110  95.505  -74.004  52.368  1
261111  95.546  -74.005  52.329  1
261112  95.589  -74.004  52.291  1
261113  95.631  -74.004  52.253  1
261114  95.665  -74.001  52.216  1
261115  95.679  -73.996  52.180  1
261116  95.693  -73.990  52.144  1
261117  95.706  -73.985  52.108  1
261118  95.721  -73.979  52.072  1
261119  95.734  -73.973  52.037  1
261120  95.750  -73.968  52.002  1
261121  95.775  -73.963  51.968  1
261122  95.801  -73.957  51.936  1
261123  95.826  -73.952  51.903  1
261124  95.851  -73.948  51.870  1
261125  95.877  -73.942  51.836  1
261126  95.902  -73.937  51.801  1
261127  95.945  -73.930  51.764  1
261128  95.940  -73.923  51.725  1
261129  95.973  -73.944  51.686  1
261130  96.007  -73.964  51.646  1
261131  96.039  -73.985  51.606  1
261132  96.066  -74.001  51.566  1
261133  96.091  -74.014  51.526  1
261134  96.114  -74.027  51.488  1
261135  96.138  -74.041  51.451  1
261136  96.163  -74.054  51.415  1
261137  96.187  -74.068  51.379  1
261138  96.211  -74.081  51.346  1
261139  96.237  -74.090  51.314  1
261140  96.264  -74.099  51.283  1
261141  96.298  -74.105  51.252  1
261142  96.331  -74.112  51.224  1
261143  96.356  -74.126  51.197  1
261144  96.387  -74.144  51.171  1
261145  96.418  -74.161  51.146  1
261146  96.450  -74.176  51.122  1
261147  96.481  -74.190  51.100  1
261148  96.513  -74.204  51.079  1
261149  96.545  -74.217  51.061  1
261150  96.577  -74.232  51.043  1
261151  96.608  -74.245  51.027  1
261152  96.640  -74.259  51.013  1
261153  96.671  -74.273  51.000  1
261154  96.703  -74.286  50.989  1
261155  96.729  -74.298  50.980  1
261156  96.740  -74.302  50.971  1
261157  96.752  -74.308  50.964  1
261158  96.764  -74.312  50.960  1
261159  96.777  -74.317  50.958  1
261160  96.789  -74.322  50.958  1
261161  96.804  -74.327  50.960  1
261162  96.824  -74.333  50.964  1
261163  96.881  -74.372  50.970  1
261164  96.902  -74.387  50.978  1
261165  96.920  -74.399  50.988  1
261166  96.937  -74.411  51.001  1
261167  96.954  -74.424  51.010  1
261168  96.986  -74.419  51.018  1
261169  97.022  -74.413  51.026  1
261170  97.058  -74.406  51.032  1
261171  97.093  -74.400  51.034  1
261172  97.128  -74.393  51.032  1
261173  97.163  -74.387  51.029  1
261174  97.198  -74.380  51.017  1
261175  97.234  -74.374  51.001  1
261176  97.269  -74.368  50.982  1
261177  97.304  -74.361  50.959  1
261178  97.339  -74.355  50.931  1
261179  97.375  -74.349  50.903  1
261180  97.413  -74.341  50.874  1
261181  97.459  -74.327  50.841  1
261182  97.507  -74.314  50.808  1
261183  97.554  -74.301  50.775  1
261184  97.582  -74.314  50.741  1
261185  97.609  -74.330  50.706  1
261186  97.636  -74.346  50.667  1
261187  97.663  -74.362  50.624  1
261188  97.690  -74.378  50.579  1
261189  97.717  -74.394  50.532  1
261190  97.744  -74.410  50.483  1
261191  97.771  -74.426  50.434  1
261192  97.798  -74.442  50.385  1
261193  97.825  -74.458  50.334  1
261194  97.861  -74.480  50.284  1
261195  97.891  -74.495  50.234  1
261196  97.914  -74.501  50.184  1
261197  97.936  -74.507  50.135  1
261198  97.959  -74.512  50.090  1
261199  97.982  -74.518  50.048  1
261200  98.007  -74.527  50.008  1
261201  98.040  -74.541  49.968  1
261202  98.073  -74.555  49.923  1
261203  98.105  -74.569  49.875  1
261204  98.139  -74.584  49.824  1
261205  98.171  -74.597  49.770  1
261206  98.204  -74.612  49.711  1
261207  98.237  -74.626  49.650  1
261208  98.270  -74.640  49.589  1
261209  98.303  -74.654  49.530  1
261210  98.327  -74.661  49.473  1
261211  98.322  -74.631  49.416  1
261212  98.283  -74.649  49.361  1
261213  98.230  -74.734  49.308  1
261214  98.231  -74.823  49.253  1
261215  98.279  -74.818  49.197  1
261216  98.351  -74.762  49.141  1
261217  98.521  -74.667  49.087  1
261218  98.560  -74.708  49.034  1
261219  98.574  -74.712  48.984  1
261220  98.599  -74.739  48.936  1
261221  98.624  -74.766  48.887  1
261222  98.649  -74.794  48.835  1
261223  98.674  -74.821  48.782  1
261224  98.699  -74.848  48.727  1
261225  98.724  -74.875  48.673  1
261226  98.749  -74.903  48.618  1
261227  98.774  -74.929  48.564  1
261228  98.799  -74.957  48.510  1
261229  98.837  -74.935  48.457  1
261230  98.881  -74.889  48.406  1
261231  98.925  -74.844  48.355  1
261232  98.962  -74.813  48.304  1
261233  98.979  -74.828  48.254  1
261234  98.996  -74.843  48.205  1
261235  99.012  -74.857  48.157  1
261236  99.029  -74.872  48.108  1
261237  99.051  -74.888  48.060  1
261238  99.076  -74.907  48.013  1
261239  99.100  -74.925  47.966  1
261240  99.125  -74.944  47.919  1
261241  99.150  -74.962  47.873  1
261242  99.185  -74.982  47.829  1
261243  99.221  -75.001  47.784  1
261244  99.257  -75.020  47.740  1
261245  99.293  -75.040  47.695  1
261246  99.329  -75.060  47.650  1
261247  99.365  -75.079  47.606  1
261248  99.401  -75.099  47.564  1
261249  99.434  -75.113  47.522  1
261250  99.470  -75.116  47.482  1
261251  99.495  -75.124  47.443  1
261252  99.526  -75.129  47.405  1
261253  99.558  -75.132  47.369  1
261254  99.588  -75.137  47.336  1
261255  99.620  -75.141  47.305  1
261256  99.651  -75.145  47.276  1
261257  99.682  -75.150  47.247  1
261258  99.713  -75.154  47.219  1
261259  99.744  -75.158  47.192  1
261260  99.775  -75.162  47.167  1
261261  99.806  -75.167  47.144  1
261262  99.837  -75.170  47.121  1
261263  99.868  -75.175  47.099  1
261264  99.900  -75.179  47.076  1
261265  99.930  -75.183  47.054  1
261266  99.971  -75.199  47.031  1
261267  100.021  -75.227  47.009  1
261268  100.072  -75.256  46.987  1
261269  100.127  -75.269  46.965  1
261270  100.158  -75.274  46.944  1
261271  100.174  -75.285  46.922  1
261272  100.190  -75.295  46.897  1
261273  100.209  -75.318  46.872  1
261274  100.229  -75.357  46.847  1
261275  100.248  -75.386  46.820  1
261276  100.264  -75.398  46.792  1
261277  100.280  -75.410  46.764  1
261278  100.296  -75.422  46.735  1
261279  100.313  -75.434  46.704  1
261280  100.329  -75.447  46.674  1
261281  100.346  -75.459  46.645  1
261282  100.362  -75.471  46.617  1
261283  100.379  -75.483  46.589  1
261284  100.395  -75.496  46.559  1
261285  100.411  -75.508  46.530  1
261286  100.436  -75.530  46.500  1
261287  100.465  -75.557  46.471  1
261288  100.493  -75.584  46.443  1
261289  100.522  -75.611  46.415  1
261290  100.551  -75.638  46.386  1
261291  100.580  -75.665  46.358  1
261292  100.608  -75.685  46.329  1
261293  100.634  -75.674  46.301  1
261294  100.661  -75.662  46.274  1
261295  100.687  -75.649  46.248  1
261296  100.724  -75.642  46.222  1
261297  100.773  -75.641  46.195  1
261298  100.823  -75.643  46.166  1
261299  100.863  -75.656  46.138  1
261300  100.894  -75.682  46.110  1
261301  100.925  -75.708  46.084  1
261302  100.957  -75.734  46.058  1
261303  100.988  -75.754  46.031  1
261304  101.018  -75.768  46.003  1
261305  101.043  -75.780  45.971  1
261306  101.058  -75.786  45.939  1
261307  101.072  -75.793  45.907  1
261308  101.087  -75.799  45.876  1
261309  101.101  -75.806  45.845  1
261310  101.115  -75.812  45.816  1
261311  101.130  -75.818  45.786  1
261312  101.144  -75.825  45.757  1
261313  101.158  -75.834  45.729  1
261314  101.181  -75.840  45.700  1
261315  101.217  -75.847  45.672  1
261316  101.260  -75.856  45.642  1
261317  101.304  -75.866  45.614  1
261318  101.347  -75.876  45.584  1
261319  101.391  -75.887  45.553  1
261320  101.434  -75.897  45.523  1
261321  101.477  -75.906  45.494  1
261322  101.516  -75.916  45.467  1
261323  101.552  -75.935  45.441  1
261324  101.608  -75.973  45.414  1
261325  101.665  -76.012  45.389  1
261326  101.721  -76.050  45.364  1
261327  101.747  -76.066  45.340  1
261328  101.755  -76.069  45.316  1
261329  101.763  -76.072  45.292  1
261330  101.770  -76.074  45.267  1
261331  101.778  -76.077  45.242  1
261332  101.785  -76.080  45.219  1
261333  101.793  -76.082  45.194  1
261334  101.801  -76.085  45.170  1
261335  101.809  -76.088  45.147  1
261336  101.816  -76.091  45.123  1
261337  101.824  -76.093  45.100  1
261338  101.831  -76.096  45.076  1
261339  101.839  -76.099  45.053  1
261690  92.526  -73.672  54.650  1
261691  92.551  -73.683  54.649  1
261692  92.575  -73.694  54.647  1
261693  92.599  -73.704  54.645  1
261694  92.624  -73.716  54.642  1
261695  92.648  -73.726  54.640  1
261696  92.672  -73.737  54.638  1
261697  92.697  -73.747  54.636  1
261698  92.721  -73.758  54.634  1
261699  92.746  -73.769  54.633  1
261700  92.770  -73.772  54.632  1
261701  92.800  -73.781  54.632  1
261702  92.830  -73.800  54.632  1
261703  92.859  -73.819  54.633  1
261704  92.888  -73.827  54.635  1
261705  92.917  -73.834  54.637  1
261706  92.945  -73.840  54.640  1
261707  92.974  -73.846  54.644  1
261708  93.003  -73.853  54.648  1
261709  93.031  -73.859  54.652  1
261710  93.059  -73.863  54.655  1
261711  93.082  -73.861  54.658  1
261712  93.106  -73.858  54.662  1
261713  93.129  -73.855  54.665  1
261714  93.152  -73.852  54.667  1
261715  93.175  -73.850  54.666  1
261716  93.204  -73.836  54.663  1
261717  93.229  -73.832  54.661  1
261718  93.254  -73.836  54.659  1
261719  93.286  -73.838  54.656  1
261720  93.320  -73.839  54.657  1
261721  93.352  -73.841  54.658  1
261722  93.386  -73.843  54.659  1
261723  93.418  -73.844  54.660  1
261724  93.451  -73.846  54.659  1
261725  93.483  -73.845  54.657  1
261726  93.505  -73.832  54.653  1
261727  93.527  -73.819  54.649  1
261728  93.586  -73.833  54.642  1
261729  93.627  -73.840  54.635  1
261730  93.658  -73.841  54.629  1
261731  93.687  -73.844  54.621  1
261732  93.711  -73.847  54.615  1
261733  93.721  -73.847  54.610  1
261734  93.730  -73.847  54.606  1
261735  93.739  -73.847  54.603  1
261736  93.749  -73.847  54.604  1
261737  93.758  -73.847  54.608  1
261738  93.778  -73.847  54.614  1
261739  93.798  -73.848  54.623  1
261740  93.820  -73.849  54.632  1
261741  93.841  -73.849  54.640  1
261742  93.862  -73.850  54.647  1
261743  93.883  -73.850  54.651  1
261744  93.904  -73.851  54.648  1
261745  93.925  -73.852  54.640  1
261746  93.946  -73.853  54.625  1
261747  93.968  -73.850  54.600  1
261748  94.002  -73.849  54.564  1
261749  94.034  -73.847  54.521  1
261750  94.066  -73.845  54.475  1
261751  94.098  -73.844  54.437  1
261752  94.130  -73.841  54.407  1
261753  94.158  -73.840  54.384  1
261754  94.183  -73.839  54.367  1
261755  94.207  -73.838  54.355  1
261756  94.244  -73.857  54.344  1
261757  94.285  -73.875  54.331  1
261758  94.319  -73.872  54.314  1
261759  94.351  -73.871  54.291  1
261760  94.385  -73.869  54.263  1
261761  94.417  -73.867  54.234  1
261762  94.450  -73.865  54.204  1
261763  94.478  -73.863  54.174  1
261764  94.483  -73.860  54.144  1
261765  94.488  -73.858  54.113  1
261766  94.494  -73.855  54.084  1
261767  94.499  -73.853  54.053  1
261768  94.501  -73.850  54.020  1
261769  94.500  -73.850  53.986  1
261770  94.524  -73.860  53.950  1
261771  94.546  -73.875  53.914  1
261772  94.568  -73.889  53.876  1
261773  94.590  -73.904  53.837  1
261774  94.611  -73.913  53.798  1
261775  94.628  -73.910  53.756  1
261776  94.646  -73.908  53.717  1
261777  94.663  -73.906  53.679  1
261778  94.681  -73.904  53.643  1
261779  94.699  -73.897  53.610  1
261780  94.719  -73.888  53.581  1
261781  94.739  -73.879  53.554  1
261782  94.754  -73.879  53.531  1
261783  94.769  -73.881  53.512  1
261784  94.784  -73.882  53.488  1
261785  94.811  -73.889  53.460  1
261786  94.857  -73.907  53.430  1
261787  94.904  -73.923  53.400  1
261788  94.951  -73.940  53.368  1
261789  94.997  -73.957  53.334  1
261790  95.044  -73.974  53.300  1
261791  95.057  -74.001  53.265  1
261792  95.077  -73.997  53.226  1
261793  95.099  -73.991  53.182  1
261794  95.120  -73.986  53.134  1
261795  95.141  -73.981  53.082  1
261796  95.146  -73.996  53.029  1
261797  95.154  -73.985  52.974  1
261798  95.161  -73.973  52.921  1
261799  95.168  -73.962  52.872  1
261800  95.176  -73.951  52.824  1
261801  95.183  -73.939  52.777  1
261802  95.206  -73.938  52.731  1
261803  95.239  -73.941  52.688  1
261804  95.271  -73.945  52.646  1
261805  95.304  -73.950  52.604  1
261806  95.336  -73.954  52.563  1
261807  95.369  -73.957  52.522  1
261808  95.401  -73.961  52.482  1
261809  95.433  -73.965  52.443  1
261810  95.466  -73.969  52.404  1
261811  95.498  -73.973  52.365  1
261812  95.534  -73.977  52.326  1
261813  95.574  -73.981  52.287  1
261814  95.617  -73.980  52.250  1
261815  95.643  -73.976  52.213  1
261816  95.657  -73.971  52.177  1
261817  95.671  -73.965  52.141  1
261818  95.689  -73.960  52.106  1
261819  95.714  -73.954  52.071  1
261820  95.740  -73.949  52.036  1
261821  95.765  -73.944  52.002  1
261822  95.790  -73.939  51.969  1
261823  95.816  -73.934  51.936  1
261824  95.841  -73.929  51.904  1
261825  95.866  -73.923  51.872  1
261826  95.891  -73.919  51.838  1
261827  95.917  -73.913  51.803  1
261828  95.968  -73.906  51.765  1
261829  95.950  -73.891  51.726  1
261830  95.980  -73.910  51.687  1
261831  96.014  -73.930  51.647  1
261832  96.046  -73.951  51.607  1
261833  96.080  -73.971  51.567  1
261834  96.112  -73.992  51.528  1
261835  96.137  -74.006  51.490  1
261836  96.162  -74.020  51.453  1
261837  96.186  -74.033  51.417  1
261838  96.210  -74.047  51.382  1
261839  96.229  -74.058  51.349  1
261840  96.257  -74.067  51.317  1
261841  96.285  -74.076  51.285  1
261842  96.312  -74.085  51.255  1
261843  96.340  -74.095  51.227  1
261844  96.362  -74.104  51.199  1
261845  96.393  -74.110  51.173  1
261846  96.424  -74.123  51.148  1
261847  96.456  -74.137  51.124  1
261848  96.487  -74.151  51.102  1
261849  96.519  -74.165  51.081  1
261850  96.551  -74.179  51.062  1
261851  96.582  -74.192  51.044  1
261852  96.614  -74.206  51.028  1
261853  96.646  -74.220  51.014  1
261854  96.677  -74.234  51.000  1
261855  96.709  -74.248  50.989  1
261856  96.735  -74.259  50.979  1
261857  96.747  -74.264  50.970  1
261858  96.758  -74.269  50.962  1
261859  96.770  -74.273  50.958  1
261860  96.783  -74.278  50.956  1
261861  96.795  -74.283  50.957  1
261862  96.807  -74.288  50.958  1
261863  96.822  -74.298  50.961  1
261864  96.876  -74.338  50.967  1
261865  96.896  -74.352  50.975  1
261866  96.913  -74.364  50.984  1
261867  96.944  -74.363  50.997  1
261868  96.979  -74.356  51.009  1
261869  97.014  -74.350  51.018  1
261870  97.049  -74.343  51.027  1
261871  97.085  -74.337  51.032  1
261872  97.120  -74.330  51.033  1
261873  97.155  -74.324  51.031  1
261874  97.190  -74.317  51.027  1
261875  97.226  -74.311  51.013  1
261876  97.261  -74.305  50.997  1
261877  97.297  -74.299  50.977  1
261878  97.332  -74.292  50.954  1
261879  97.367  -74.286  50.926  1
261880  97.402  -74.280  50.898  1
261881  97.438  -74.273  50.869  1
261882  97.485  -74.260  50.838  1
261883  97.531  -74.246  50.804  1
261884  97.559  -74.261  50.771  1
261885  97.586  -74.277  50.736  1
261886  97.613  -74.293  50.700  1
261887  97.640  -74.309  50.662  1
261888  97.667  -74.325  50.620  1
261889  97.694  -74.341  50.575  1
261890  97.721  -74.357  50.530  1
261891  97.748  -74.373  50.483  1
261892  97.775  -74.389  50.436  1
261893  97.802  -74.405  50.389  1
261894  97.828  -74.421  50.341  1
261895  97.863  -74.442  50.289  1
261896  97.892  -74.456  50.237  1
261897  97.915  -74.461  50.186  1
261898  97.938  -74.468  50.135  1
261899  97.960  -74.474  50.088  1
261900  97.985  -74.481  50.046  1
261901  98.018  -74.496  50.005  1
261902  98.051  -74.509  49.964  1
261903  98.083  -74.524  49.917  1
261904  98.116  -74.537  49.868  1
261905  98.149  -74.552  49.816  1
261906  98.182  -74.566  49.761  1
261907  98.215  -74.580  49.702  1
261908  98.247  -74.594  49.641  1
261909  98.279  -74.608  49.580  1
261910  98.309  -74.622  49.520  1
261911  98.328  -74.635  49.463  1
261912  98.345  -74.631  49.406  1
261913  98.425  -74.612  49.350  1
261914  98.337  -74.694  49.297  1
261915  98.247  -74.776  49.241  1
261916  98.179  -74.844  49.185  1
261917  98.428  -74.717  49.129  1
261918  98.600  -74.828  49.075  1
261919  98.600  -74.803  49.023  1
261920  98.600  -74.778  48.974  1
261921  98.602  -74.757  48.925  1
261922  98.627  -74.784  48.876  1
261923  98.652  -74.811  48.825  1
261924  98.677  -74.838  48.772  1
261925  98.702  -74.866  48.718  1
261926  98.727  -74.893  48.664  1
261927  98.752  -74.920  48.609  1
261928  98.777  -74.947  48.555  1
261929  98.806  -74.962  48.501  1
261930  98.850  -74.916  48.448  1
261931  98.894  -74.872  48.397  1
261932  98.937  -74.826  48.346  1
261933  98.978  -74.788  48.296  1
261934  98.995  -74.803  48.246  1
261935  99.011  -74.817  48.197  1
261936  99.028  -74.831  48.148  1
261937  99.045  -74.846  48.100  1
261938  99.062  -74.860  48.052  1
261939  99.084  -74.878  48.005  1
261940  99.109  -74.896  47.958  1
261941  99.134  -74.914  47.911  1
261942  99.159  -74.933  47.864  1
261943  99.196  -74.953  47.820  1
261944  99.231  -74.972  47.775  1
261945  99.268  -74.991  47.731  1
261946  99.303  -75.011  47.687  1
261947  99.340  -75.031  47.643  1
261948  99.375  -75.051  47.600  1
261949  99.411  -75.072  47.557  1
261950  99.448  -75.085  47.516  1
261951  99.482  -75.086  47.475  1
261952  99.514  -75.090  47.436  1
261953  99.546  -75.094  47.398  1
261954  99.576  -75.098  47.362  1
261955  99.608  -75.102  47.329  1
261956  99.639  -75.107  47.298  1
261957  99.669  -75.110  47.268  1
261958  99.701  -75.115  47.240  1
261959  99.732  -75.119  47.212  1
261960  99.763  -75.123  47.185  1
261961  99.794  -75.128  47.159  1
261962  99.825  -75.132  47.135  1
261963  99.856  -75.136  47.112  1
261964  99.887  -75.140  47.089  1
261965  99.918  -75.145  47.066  1
261966  99.949  -75.148  47.042  1
261967  99.992  -75.167  47.020  1
261968  100.043  -75.196  46.998  1
261969  100.093  -75.224  46.976  1
261970  100.143  -75.252  46.954  1
261971  100.178  -75.290  46.934  1
261972  100.202  -75.308  46.912  1
261973  100.225  -75.325  46.887  1
261974  100.247  -75.353  46.861  1
261975  100.264  -75.376  46.836  1
261976  100.281  -75.388  46.809  1
261977  100.297  -75.400  46.781  1
261978  100.314  -75.412  46.752  1
261979  100.330  -75.425  46.724  1
261980  100.346  -75.437  46.694  1
261981  100.362  -75.449  46.664  1
261982  100.379  -75.461  46.635  1
261983  100.395  -75.474  46.607  1
261984  100.412  -75.486  46.579  1
261985  100.428  -75.499  46.550  1
261986  100.444  -75.511  46.521  1
261987  100.461  -75.523  46.491  1
261988  100.480  -75.539  46.462  1
261989  100.509  -75.565  46.434  1
261990  100.538  -75.593  46.406  1
261991  100.566  -75.619  46.378  1
261992  100.595  -75.646  46.350  1
261993  100.623  -75.656  46.321  1
261994  100.649  -75.645  46.294  1
261995  100.676  -75.633  46.267  1
261996  100.702  -75.621  46.240  1
261997  100.735  -75.612  46.214  1
261998  100.784  -75.613  46.187  1
261999  100.833  -75.615  46.158  1
262000  100.880  -75.620  46.130  1
262001  100.911  -75.646  46.103  1
262002  100.942  -75.671  46.077  1
262003  100.973  -75.696  46.050  1
262004  101.004  -75.711  46.023  1
262005  101.034  -75.724  45.994  1
262006  101.063  -75.737  45.962  1
262007  101.078  -75.744  45.930  1
262008  101.092  -75.750  45.898  1
262009  101.107  -75.757  45.867  1
262010  101.121  -75.763  45.837  1
262011  101.135  -75.770  45.808  1
262012  101.150  -75.778  45.779  1
262013  101.164  -75.787  45.750  1
262014  101.178  -75.796  45.723  1
262015  101.200  -75.802  45.694  1
262016  101.231  -75.805  45.665  1
262017  101.268  -75.812  45.635  1
262018  101.311  -75.822  45.604  1
262019  101.355  -75.831  45.573  1
262020  101.398  -75.842  45.542  1
262021  101.442  -75.852  45.512  1
262022  101.484  -75.862  45.484  1
262023  101.520  -75.881  45.457  1
262024  101.576  -75.919  45.431  1
262025  101.633  -75.957  45.404  1
262026  101.690  -75.996  45.378  1
262027  101.744  -76.032  45.353  1
262028  101.751  -76.035  45.329  1
262029  101.759  -76.038  45.304  1
262030  101.766  -76.040  45.280  1
262031  101.774  -76.043  45.255  1
262032  101.782  -76.046  45.230  1
262033  101.790  -76.048  45.206  1
262034  101.797  -76.051  45.181  1
262035  101.805  -76.053  45.158  1
262036  101.812  -76.057  45.134  1
262037  101.820  -76.060  45.110  1
262038  101.828  -76.062  45.086  1
262039  101.835  -76.065  45.062  1
262040  101.846  -76.072  45.039  1
262390  92.504  -73.629  54.656  1
262391  92.528  -73.640  54.654  1
262392  92.553  -73.650  54.651  1
262393  92.577  -73.661  54.649  1
262394  92.601  -73.672  54.646  1
262395  92.626  -73.683  54.643  1
262396  92.650  -73.694  54.640  1
262397  92.674  -73.704  54.637  1
262398  92.699  -73.715  54.635  1
262399  92.723  -73.726  54.633  1
262400  92.747  -73.737  54.631  1
262401  92.772  -73.745  54.631  1
262402  92.801  -73.756  54.631  1
262403  92.831  -73.773  54.630  1
262404  92.859  -73.780  54.631  1
262405  92.888  -73.786  54.633  1
262406  92.917  -73.792  54.635  1
262407  92.945  -73.798  54.638  1
262408  92.974  -73.805  54.642  1
262409  93.003  -73.811  54.645  1
262410  93.031  -73.817  54.649  1
262411  93.060  -73.824  54.653  1
262412  93.084  -73.822  54.657  1
262413  93.108  -73.819  54.661  1
262414  93.131  -73.816  54.665  1
262415  93.153  -73.814  54.667  1
262416  93.177  -73.811  54.665  1
262417  93.200  -73.808  54.663  1
262418  93.223  -73.805  54.661  1
262419  93.254  -73.805  54.658  1
262420  93.287  -73.807  54.655  1
262421  93.320  -73.809  54.653  1
262422  93.353  -73.810  54.653  1
262423  93.386  -73.812  54.653  1
262424  93.419  -73.813  54.653  1
262425  93.452  -73.815  54.654  1
262426  93.485  -73.816  54.653  1
262427  93.508  -73.805  54.650  1
262428  93.556  -73.813  54.646  1
262429  93.587  -73.815  54.639  1
262430  93.618  -73.816  54.632  1
262431  93.649  -73.817  54.624  1
262432  93.679  -73.819  54.614  1
262433  93.705  -73.822  54.605  1
262434  93.714  -73.822  54.597  1
262435  93.723  -73.822  54.589  1
262436  93.733  -73.823  54.582  1
262437  93.742  -73.823  54.577  1
262438  93.757  -73.823  54.574  1
262439  93.778  -73.824  54.574  1
262440  93.799  -73.825  54.577  1
262441  93.820  -73.825  54.582  1
262442  93.841  -73.825  54.587  1
262443  93.862  -73.826  54.593  1
262444  93.883  -73.827  54.598  1
262445  93.904  -73.828  54.600  1
262446  93.925  -73.827  54.596  1
262447  93.947  -73.823  54.583  1
262448  93.969  -73.819  54.562  1
262449  94.000  -73.817  54.530  1
262450  94.039  -73.818  54.491  1
262451  94.071  -73.816  54.448  1
262452  94.103  -73.814  54.410  1
262453  94.135  -73.812  54.379  1
262454  94.163  -73.810  54.355  1
262455  94.187  -73.810  54.338  1
262456  94.211  -73.808  54.327  1
262457  94.236  -73.807  54.315  1
262458  94.284  -73.844  54.302  1
262459  94.322  -73.854  54.285  1
262460  94.355  -73.851  54.262  1
262461  94.388  -73.850  54.234  1
262462  94.421  -73.847  54.203  1
262463  94.454  -73.846  54.171  1
262464  94.463  -73.844  54.140  1
262465  94.468  -73.841  54.109  1
262466  94.473  -73.838  54.079  1
262467  94.478  -73.835  54.050  1
262468  94.484  -73.833  54.021  1
262469  94.491  -73.832  53.989  1
262470  94.506  -73.836  53.955  1
262471  94.525  -73.842  53.921  1
262472  94.547  -73.857  53.884  1
262473  94.569  -73.871  53.845  1
262474  94.591  -73.885  53.806  1
262475  94.613  -73.897  53.768  1
262476  94.630  -73.895  53.729  1
262477  94.647  -73.893  53.691  1
262478  94.665  -73.891  53.656  1
262479  94.682  -73.888  53.622  1
262480  94.700  -73.886  53.593  1
262481  94.719  -73.879  53.567  1
262482  94.739  -73.869  53.544  1
262483  94.756  -73.864  53.524  1
262484  94.771  -73.866  53.505  1
262485  94.786  -73.868  53.480  1
262486  94.813  -73.875  53.451  1
262487  94.860  -73.892  53.420  1
262488  94.907  -73.909  53.388  1
262489  94.954  -73.926  53.355  1
262490  95.000  -73.943  53.320  1
262491  95.047  -73.960  53.285  1
262492  95.076  -73.982  53.249  1
262493  95.096  -73.982  53.207  1
262494  95.117  -73.976  53.162  1
262495  95.138  -73.971  53.113  1
262496  95.139  -73.975  53.060  1
262497  95.147  -73.963  53.006  1
262498  95.155  -73.952  52.953  1
262499  95.162  -73.941  52.902  1
262500  95.169  -73.929  52.854  1
262501  95.176  -73.918  52.808  1
262502  95.184  -73.907  52.763  1
262503  95.213  -73.909  52.719  1
262504  95.246  -73.913  52.677  1
262505  95.278  -73.916  52.636  1
262506  95.311  -73.921  52.595  1
262507  95.343  -73.925  52.556  1
262508  95.376  -73.929  52.516  1
262509  95.408  -73.932  52.477  1
262510  95.441  -73.936  52.439  1
262511  95.473  -73.940  52.399  1
262512  95.505  -73.944  52.361  1
262513  95.538  -73.948  52.322  1
262514  95.570  -73.952  52.284  1
262515  95.603  -73.956  52.246  1
262516  95.628  -73.951  52.210  1
262517  95.654  -73.946  52.174  1
262518  95.679  -73.941  52.139  1
262519  95.704  -73.936  52.105  1
262520  95.729  -73.931  52.070  1
262521  95.755  -73.926  52.035  1
262522  95.780  -73.920  52.002  1
262523  95.805  -73.916  51.969  1
262524  95.830  -73.910  51.937  1
262525  95.856  -73.905  51.905  1
262526  95.881  -73.900  51.873  1
262527  95.906  -73.895  51.841  1
262528  95.934  -73.890  51.805  1
262529  95.987  -73.881  51.767  1
262530  95.969  -73.866  51.727  1
262531  95.987  -73.876  51.687  1
262532  96.021  -73.897  51.648  1
262533  96.053  -73.917  51.608  1
262534  96.087  -73.938  51.567  1
262535  96.120  -73.958  51.529  1
262536  96.153  -73.979  51.492  1
262537  96.185  -73.998  51.456  1
262538  96.209  -74.012  51.420  1
262539  96.233  -74.026  51.386  1
262540  96.249  -74.035  51.353  1
262541  96.276  -74.045  51.320  1
262542  96.304  -74.054  51.288  1
262543  96.325  -74.063  51.259  1
262544  96.341  -74.073  51.230  1
262545  96.367  -74.079  51.202  1
262546  96.395  -74.085  51.176  1
262547  96.430  -74.085  51.150  1
262548  96.462  -74.098  51.127  1
262549  96.493  -74.112  51.104  1
262550  96.525  -74.126  51.083  1
262551  96.556  -74.139  51.063  1
262552  96.588  -74.154  51.045  1
262553  96.620  -74.167  51.029  1
262554  96.651  -74.181  51.015  1
262555  96.683  -74.195  51.001  1
262556  96.715  -74.209  50.988  1
262557  96.741  -74.220  50.978  1
262558  96.753  -74.225  50.969  1
262559  96.764  -74.230  50.961  1
262560  96.777  -74.235  50.957  1
262561  96.789  -74.239  50.955  1
262562  96.801  -74.245  50.955  1
262563  96.813  -74.249  50.956  1
262564  96.840  -74.276  50.959  1
262565  96.872  -74.305  50.964  1
262566  96.900  -74.306  50.970  1
262567  96.936  -74.300  50.979  1
262568  96.971  -74.293  50.993  1
262569  97.007  -74.287  51.006  1
262570  97.042  -74.280  51.017  1
262571  97.077  -74.274  51.026  1
262572  97.112  -74.268  51.029  1
262573  97.148  -74.261  51.030  1
262574  97.183  -74.255  51.027  1
262575  97.218  -74.248  51.022  1
262576  97.253  -74.242  51.007  1
262577  97.289  -74.236  50.990  1
262578  97.324  -74.230  50.971  1
262579  97.359  -74.223  50.949  1
262580  97.394  -74.217  50.922  1
262581  97.430  -74.210  50.894  1
262582  97.465  -74.204  50.865  1
262583  97.509  -74.192  50.835  1
262584  97.536  -74.208  50.801  1
262585  97.563  -74.224  50.767  1
262586  97.590  -74.240  50.732  1
262587  97.617  -74.256  50.696  1
262588  97.644  -74.272  50.658  1
262589  97.671  -74.288  50.616  1
262590  97.698  -74.304  50.572  1
262591  97.725  -74.320  50.528  1
262592  97.752  -74.336  50.484  1
262593  97.779  -74.352  50.439  1
262594  97.806  -74.368  50.393  1
262595  97.832  -74.383  50.347  1
262596  97.864  -74.403  50.294  1
262597  97.894  -74.417  50.242  1
262598  97.917  -74.423  50.189  1
262599  97.939  -74.429  50.136  1
262600  97.962  -74.435  50.089  1
262601  97.995  -74.449  50.046  1
262602  98.028  -74.464  50.004  1
262603  98.061  -74.477  49.960  1
262604  98.094  -74.492  49.912  1
262605  98.127  -74.506  49.861  1
262606  98.159  -74.520  49.808  1
262607  98.192  -74.534  49.752  1
262608  98.222  -74.548  49.692  1
262609  98.252  -74.562  49.632  1
262610  98.283  -74.577  49.572  1
262611  98.313  -74.590  49.511  1
262612  98.329  -74.603  49.453  1
262613  98.307  -74.609  49.396  1
262614  98.337  -74.602  49.339  1
262615  98.324  -74.640  49.285  1
262616  98.229  -74.722  49.229  1
262617  98.250  -74.781  49.172  1
262618  98.468  -74.714  49.117  1
262619  98.640  -74.924  49.063  1
262620  98.640  -74.898  49.012  1
262621  98.640  -74.872  48.963  1
262622  98.640  -74.847  48.914  1
262623  98.639  -74.821  48.865  1
262624  98.655  -74.829  48.814  1
262625  98.680  -74.856  48.761  1
262626  98.705  -74.884  48.708  1
262627  98.730  -74.910  48.654  1
262628  98.756  -74.938  48.600  1
262629  98.780  -74.965  48.546  1
262630  98.818  -74.944  48.492  1
262631  98.862  -74.899  48.439  1
262632  98.906  -74.853  48.388  1
262633  98.950  -74.809  48.337  1
262634  98.994  -74.763  48.287  1
262635  99.010  -74.777  48.238  1
262636  99.027  -74.791  48.188  1
262637  99.044  -74.806  48.139  1
262638  99.061  -74.821  48.091  1
262639  99.077  -74.835  48.043  1
262640  99.094  -74.850  47.995  1
262641  99.117  -74.867  47.948  1
262642  99.142  -74.885  47.902  1
262643  99.170  -74.904  47.856  1
262644  99.206  -74.924  47.810  1
262645  99.242  -74.943  47.765  1
262646  99.278  -74.963  47.721  1
262647  99.313  -74.982  47.678  1
262648  99.349  -75.004  47.635  1
262649  99.383  -75.026  47.592  1
262650  99.420  -75.043  47.551  1
262651  99.458  -75.054  47.509  1
262652  99.494  -75.060  47.469  1
262653  99.528  -75.060  47.430  1
262654  99.563  -75.061  47.392  1
262655  99.595  -75.063  47.355  1
262656  99.626  -75.068  47.323  1
262657  99.657  -75.072  47.292  1
262658  99.689  -75.076  47.262  1
262659  99.720  -75.080  47.233  1
262660  99.751  -75.085  47.204  1
262661  99.782  -75.088  47.177  1
262662  99.813  -75.093  47.151  1
262663  99.844  -75.097  47.127  1
262664  99.875  -75.101  47.103  1
262665  99.906  -75.105  47.080  1
262666  99.937  -75.110  47.056  1
262667  99.968  -75.114  47.032  1
262668  100.013  -75.135  47.009  1
262669  100.064  -75.164  46.987  1
262670  100.114  -75.192  46.966  1
262671  100.153  -75.227  46.945  1
262672  100.187  -75.265  46.924  1
262673  100.221  -75.303  46.902  1
262674  100.255  -75.341  46.877  1
262675  100.279  -75.363  46.850  1
262676  100.297  -75.378  46.825  1
262677  100.314  -75.390  46.798  1
262678  100.330  -75.403  46.770  1
262679  100.347  -75.415  46.741  1
262680  100.363  -75.427  46.713  1
262681  100.379  -75.439  46.684  1
262682  100.396  -75.452  46.655  1
262683  100.412  -75.464  46.626  1
262684  100.428  -75.477  46.598  1
262685  100.445  -75.489  46.570  1
262686  100.462  -75.501  46.541  1
262687  100.478  -75.513  46.512  1
262688  100.494  -75.525  46.482  1
262689  100.510  -75.538  46.453  1
262690  100.527  -75.550  46.425  1
262691  100.553  -75.574  46.397  1
262692  100.582  -75.601  46.370  1
262693  100.611  -75.628  46.341  1
262694  100.638  -75.627  46.313  1
262695  100.664  -75.615  46.286  1
262696  100.690  -75.604  46.259  1
262697  100.717  -75.592  46.233  1
262698  100.749  -75.583  46.206  1
262699  100.794  -75.584  46.178  1
262700  100.844  -75.587  46.150  1
262701  100.893  -75.588  46.123  1
262702  100.928  -75.609  46.096  1
262703  100.959  -75.635  46.070  1
262704  100.990  -75.652  46.043  1
262705  101.020  -75.667  46.014  1
262706  101.051  -75.681  45.984  1
262707  101.081  -75.694  45.953  1
262708  101.098  -75.702  45.921  1
262709  101.113  -75.709  45.889  1
262710  101.127  -75.715  45.860  1
262711  101.141  -75.721  45.830  1
262712  101.156  -75.731  45.800  1
262713  101.170  -75.740  45.771  1
262714  101.183  -75.749  45.742  1
262715  101.197  -75.757  45.713  1
262716  101.219  -75.764  45.684  1
262717  101.250  -75.767  45.655  1
262718  101.281  -75.770  45.625  1
262719  101.319  -75.777  45.593  1
262720  101.362  -75.787  45.561  1
262721  101.406  -75.796  45.531  1
262722  101.449  -75.807  45.501  1
262723  101.489  -75.827  45.473  1
262724  101.545  -75.865  45.446  1
262725  101.602  -75.903  45.419  1
262726  101.659  -75.942  45.393  1
262727  101.715  -75.980  45.367  1
262728  101.747  -76.000  45.341  1
262729  101.755  -76.003  45.317  1
262730  101.763  -76.007  45.292  1
262731  101.770  -76.009  45.267  1
262732  101.778  -76.012  45.242  1
262733  101.785  -76.014  45.218  1
262734  101.793  -76.017  45.193  1
262735  101.801  -76.019  45.169  1
262736  101.809  -76.022  45.145  1
262737  101.816  -76.025  45.121  1
262738  101.824  -76.028  45.097  1
262739  101.831  -76.031  45.073  1
262740  101.846  -76.042  45.049  1
262741  101.869  -76.062  45.026  1
263090  92.465  -73.588  54.663  1
263091  92.492  -73.599  54.660  1
263092  92.518  -73.609  54.657  1
263093  92.545  -73.620  54.654  1
263094  92.571  -73.630  54.651  1
263095  92.597  -73.640  54.648  1
263096  92.624  -73.651  54.644  1
263097  92.650  -73.662  54.641  1
263098  92.676  -73.672  54.638  1
263099  92.701  -73.683  54.635  1
263100  92.725  -73.694  54.632  1
263101  92.749  -73.704  54.631  1
263102  92.774  -73.715  54.630  1
263103  92.802  -73.726  54.630  1
263104  92.831  -73.732  54.629  1
263105  92.859  -73.738  54.629  1
263106  92.888  -73.744  54.631  1
263107  92.917  -73.751  54.633  1
263108  92.945  -73.757  54.635  1
263109  92.974  -73.763  54.639  1
263110  93.003  -73.770  54.643  1
263111  93.031  -73.776  54.647  1
263112  93.060  -73.782  54.651  1
263113  93.086  -73.784  54.655  1
263114  93.109  -73.781  54.660  1
263115  93.132  -73.778  54.664  1
263116  93.155  -73.775  54.667  1
263117  93.179  -73.772  54.665  1
263118  93.202  -73.769  54.663  1
263119  93.227  -73.770  54.661  1
263120  93.259  -73.778  54.657  1
263121  93.292  -73.779  54.653  1
263122  93.324  -73.781  54.650  1
263123  93.357  -73.781  54.648  1
263124  93.389  -73.783  54.646  1
263125  93.422  -73.784  54.647  1
263126  93.454  -73.785  54.647  1
263127  93.487  -73.787  54.647  1
263128  93.516  -73.788  54.646  1
263129  93.547  -73.790  54.642  1
263130  93.578  -73.791  54.635  1
263131  93.610  -73.792  54.627  1
263132  93.641  -73.794  54.619  1
263133  93.672  -73.795  54.609  1
263134  93.698  -73.799  54.598  1
263135  93.708  -73.799  54.588  1
263136  93.717  -73.799  54.576  1
263137  93.726  -73.799  54.563  1
263138  93.735  -73.799  54.554  1
263139  93.757  -73.800  54.548  1
263140  93.778  -73.800  54.543  1
263141  93.799  -73.801  54.542  1
263142  93.820  -73.801  54.542  1
263143  93.841  -73.802  54.543  1
263144  93.862  -73.803  54.544  1
263145  93.883  -73.803  54.548  1
263146  93.905  -73.800  54.548  1
263147  93.927  -73.796  54.544  1
263148  93.949  -73.791  54.533  1
263149  93.971  -73.788  54.518  1
263150  93.993  -73.784  54.490  1
263151  94.032  -73.784  54.455  1
263152  94.076  -73.786  54.416  1
263153  94.108  -73.784  54.380  1
263154  94.140  -73.782  54.350  1
263155  94.167  -73.781  54.326  1
263156  94.192  -73.780  54.307  1
263157  94.216  -73.778  54.296  1
263158  94.240  -73.778  54.284  1
263159  94.272  -73.789  54.270  1
263160  94.325  -73.832  54.253  1
263161  94.358  -73.832  54.230  1
263162  94.391  -73.830  54.201  1
263163  94.424  -73.828  54.169  1
263164  94.442  -73.826  54.135  1
263165  94.448  -73.824  54.103  1
263166  94.453  -73.821  54.071  1
263167  94.458  -73.819  54.041  1
263168  94.469  -73.819  54.013  1
263169  94.484  -73.824  53.985  1
263170  94.499  -73.828  53.955  1
263171  94.514  -73.832  53.922  1
263172  94.529  -73.834  53.889  1
263173  94.548  -73.838  53.852  1
263174  94.570  -73.853  53.813  1
263175  94.592  -73.866  53.775  1
263176  94.614  -73.881  53.737  1
263177  94.632  -73.880  53.700  1
263178  94.649  -73.878  53.665  1
263179  94.667  -73.875  53.632  1
263180  94.684  -73.873  53.603  1
263181  94.702  -73.871  53.576  1
263182  94.719  -73.869  53.554  1
263183  94.739  -73.860  53.534  1
263184  94.759  -73.850  53.516  1
263185  94.773  -73.851  53.495  1
263186  94.788  -73.854  53.469  1
263187  94.816  -73.861  53.440  1
263188  94.863  -73.878  53.409  1
263189  94.909  -73.895  53.376  1
263190  94.956  -73.912  53.341  1
263191  95.003  -73.929  53.305  1
263192  95.050  -73.946  53.269  1
263193  95.096  -73.963  53.230  1
263194  95.114  -73.966  53.186  1
263195  95.126  -73.965  53.139  1
263196  95.133  -73.954  53.089  1
263197  95.140  -73.942  53.036  1
263198  95.148  -73.931  52.983  1
263199  95.155  -73.919  52.932  1
263200  95.163  -73.908  52.883  1
263201  95.170  -73.897  52.837  1
263202  95.177  -73.885  52.793  1
263203  95.188  -73.876  52.749  1
263204  95.220  -73.880  52.706  1
263205  95.253  -73.884  52.666  1
263206  95.285  -73.888  52.627  1
263207  95.318  -73.892  52.588  1
263208  95.350  -73.896  52.550  1
263209  95.383  -73.900  52.510  1
263210  95.415  -73.904  52.472  1
263211  95.448  -73.907  52.433  1
263212  95.480  -73.911  52.394  1
263213  95.513  -73.915  52.357  1
263214  95.545  -73.919  52.318  1
263215  95.577  -73.926  52.280  1
263216  95.608  -73.934  52.243  1
263217  95.640  -73.928  52.208  1
263218  95.668  -73.922  52.172  1
263219  95.693  -73.917  52.137  1
263220  95.719  -73.913  52.103  1
263221  95.744  -73.907  52.069  1
263222  95.769  -73.902  52.034  1
263223  95.795  -73.897  52.001  1
263224  95.820  -73.892  51.968  1
263225  95.845  -73.887  51.937  1
263226  95.871  -73.882  51.905  1
263227  95.896  -73.876  51.873  1
263228  95.921  -73.871  51.841  1
263229  95.960  -73.865  51.805  1
263230  96.007  -73.856  51.767  1
263231  95.989  -73.841  51.727  1
263232  95.994  -73.842  51.687  1
263233  96.028  -73.863  51.647  1
263234  96.060  -73.883  51.608  1
263235  96.094  -73.904  51.569  1
263236  96.127  -73.924  51.532  1
263237  96.160  -73.944  51.495  1
263238  96.193  -73.966  51.459  1
263239  96.226  -73.986  51.424  1
263240  96.256  -74.004  51.389  1
263241  96.269  -74.013  51.356  1
263242  96.289  -74.022  51.324  1
263243  96.305  -74.032  51.292  1
263244  96.320  -74.042  51.262  1
263245  96.346  -74.048  51.234  1
263246  96.372  -74.055  51.206  1
263247  96.399  -74.062  51.179  1
263248  96.432  -74.064  51.154  1
263249  96.466  -74.064  51.129  1
263250  96.499  -74.073  51.107  1
263251  96.531  -74.087  51.086  1
263252  96.562  -74.101  51.066  1
263253  96.594  -74.114  51.048  1
263254  96.625  -74.129  51.031  1
263255  96.657  -74.142  51.016  1
263256  96.689  -74.156  51.002  1
263257  96.721  -74.170  50.989  1
263258  96.747  -74.181  50.978  1
263259  96.759  -74.186  50.968  1
263260  96.771  -74.191  50.960  1
263261  96.783  -74.195  50.956  1
263262  96.795  -74.201  50.954  1
263263  96.807  -74.205  50.953  1
263264  96.831  -74.228  50.953  1
263265  96.858  -74.254  50.955  1
263266  96.890  -74.272  50.959  1
263267  96.925  -74.269  50.966  1
263268  96.960  -74.261  50.973  1
263269  96.996  -74.255  50.986  1
263270  97.031  -74.247  50.999  1
263271  97.067  -74.239  51.010  1
263272  97.102  -74.233  51.019  1
263273  97.137  -74.225  51.024  1
263274  97.173  -74.217  51.024  1
263275  97.208  -74.211  51.021  1
263276  97.243  -74.203  51.014  1
263277  97.279  -74.195  50.999  1
263278  97.314  -74.189  50.982  1
263279  97.350  -74.181  50.964  1
263280  97.385  -74.174  50.944  1
263281  97.420  -74.167  50.919  1
263282  97.456  -74.159  50.892  1
263283  97.486  -74.149  50.863  1
263284  97.511  -74.157  50.833  1
263285  97.540  -74.171  50.799  1
263286  97.567  -74.187  50.766  1
263287  97.594  -74.203  50.732  1
263288  97.621  -74.219  50.696  1
263289  97.648  -74.235  50.656  1
263290  97.675  -74.251  50.615  1
263291  97.702  -74.267  50.572  1
263292  97.729  -74.283  50.527  1
263293  97.755  -74.299  50.483  1
263294  97.783  -74.314  50.438  1
263295  97.809  -74.330  50.393  1
263296  97.837  -74.346  50.346  1
263297  97.866  -74.364  50.295  1
263298  97.895  -74.378  50.243  1
263299  97.918  -74.384  50.190  1
263300  97.940  -74.390  50.137  1
263301  97.973  -74.404  50.092  1
263302  98.006  -74.418  50.049  1
263303  98.038  -74.432  50.005  1
263304  98.071  -74.446  49.958  1
263305  98.104  -74.460  49.907  1
263306  98.135  -74.474  49.853  1
263307  98.165  -74.488  49.799  1
263308  98.196  -74.502  49.742  1
263309  98.226  -74.517  49.683  1
263310  98.256  -74.531  49.622  1
263311  98.287  -74.545  49.562  1
263312  98.317  -74.559  49.501  1
263313  98.329  -74.571  49.443  1
263314  98.308  -74.577  49.386  1
263315  98.287  -74.584  49.329  1
263316  98.304  -74.586  49.274  1
263317  98.250  -74.659  49.217  1
263318  98.334  -74.706  49.161  1
263319  98.417  -74.754  49.106  1
263320  98.598  -74.881  49.052  1
263321  98.647  -74.938  49.001  1
263322  98.680  -74.967  48.952  1
263323  98.679  -74.942  48.903  1
263324  98.679  -74.916  48.854  1
263325  98.679  -74.891  48.804  1
263326  98.684  -74.874  48.752  1
263327  98.709  -74.901  48.698  1
263328  98.733  -74.928  48.644  1
263329  98.759  -74.956  48.590  1
263330  98.787  -74.971  48.537  1
263331  98.831  -74.926  48.483  1
263332  98.874  -74.881  48.430  1
263333  98.918  -74.835  48.379  1
263334  98.962  -74.791  48.329  1
263335  99.006  -74.745  48.278  1
263336  99.026  -74.752  48.228  1
263337  99.043  -74.766  48.179  1
263338  99.060  -74.781  48.130  1
263339  99.077  -74.795  48.081  1
263340  99.093  -74.809  48.034  1
263341  99.110  -74.824  47.986  1
263342  99.127  -74.838  47.940  1
263343  99.150  -74.856  47.893  1
263344  99.180  -74.875  47.847  1
263345  99.216  -74.895  47.801  1
263346  99.252  -74.914  47.756  1
263347  99.287  -74.936  47.712  1
263348  99.322  -74.958  47.669  1
263349  99.357  -74.980  47.626  1
263350  99.392  -75.001  47.585  1
263351  99.430  -75.012  47.543  1
263352  99.469  -75.022  47.502  1
263353  99.506  -75.032  47.463  1
263354  99.541  -75.033  47.424  1
263355  99.575  -75.034  47.386  1
263356  99.609  -75.035  47.349  1
263357  99.643  -75.035  47.317  1
263358  99.677  -75.037  47.286  1
263359  99.707  -75.041  47.256  1
263360  99.738  -75.046  47.226  1
263361  99.770  -75.050  47.197  1
263362  99.801  -75.054  47.170  1
263363  99.832  -75.058  47.143  1
263364  99.863  -75.063  47.119  1
263365  99.894  -75.066  47.094  1
263366  99.925  -75.071  47.070  1
263367  99.956  -75.075  47.046  1
263368  99.987  -75.079  47.021  1
263369  100.034  -75.104  46.998  1
263370  100.085  -75.132  46.976  1
263371  100.130  -75.164  46.955  1
263372  100.162  -75.202  46.935  1
263373  100.196  -75.240  46.914  1
263374  100.230  -75.278  46.891  1
263375  100.263  -75.312  46.866  1
263376  100.291  -75.328  46.838  1
263377  100.310  -75.344  46.813  1
263378  100.329  -75.361  46.786  1
263379  100.347  -75.377  46.759  1
263380  100.366  -75.393  46.730  1
263381  100.385  -75.409  46.702  1
263382  100.403  -75.426  46.673  1
263383  100.422  -75.442  46.645  1
263384  100.440  -75.458  46.617  1
263385  100.460  -75.474  46.589  1
263386  100.478  -75.491  46.560  1
263387  100.495  -75.503  46.531  1
263388  100.511  -75.516  46.502  1
263389  100.528  -75.528  46.473  1
263390  100.544  -75.540  46.445  1
263391  100.560  -75.552  46.417  1
263392  100.576  -75.565  46.390  1
263393  100.598  -75.583  46.362  1
263394  100.626  -75.609  46.333  1
263395  100.653  -75.599  46.304  1
263396  100.680  -75.587  46.277  1
263397  100.707  -75.574  46.251  1
263398  100.735  -75.562  46.224  1
263399  100.767  -75.554  46.197  1
263400  100.811  -75.556  46.170  1
263401  100.855  -75.558  46.142  1
263402  100.904  -75.559  46.115  1
263403  100.945  -75.573  46.088  1
263404  100.975  -75.595  46.061  1
263405  101.006  -75.609  46.034  1
263406  101.037  -75.623  46.005  1
263407  101.067  -75.637  45.974  1
263408  101.098  -75.651  45.943  1
263409  101.118  -75.660  45.910  1
263410  101.133  -75.667  45.879  1
263411  101.147  -75.674  45.849  1
263412  101.161  -75.684  45.818  1
263413  101.175  -75.692  45.789  1
263414  101.189  -75.701  45.759  1
263415  101.203  -75.710  45.730  1
263416  101.217  -75.719  45.701  1
263417  101.239  -75.725  45.672  1
263418  101.269  -75.728  45.643  1
263419  101.301  -75.731  45.613  1
263420  101.331  -75.734  45.581  1
263421  101.370  -75.742  45.549  1
263422  101.413  -75.752  45.518  1
263423  101.458  -75.773  45.489  1
263424  101.514  -75.811  45.461  1
263425  101.570  -75.850  45.434  1
263426  101.627  -75.887  45.407  1
263427  101.684  -75.926  45.381  1
263428  101.740  -75.964  45.355  1
263429  101.751  -75.969  45.329  1
263430  101.759  -75.972  45.304  1
263431  101.766  -75.975  45.279  1
263432  101.774  -75.978  45.254  1
263433  101.781  -75.980  45.229  1
263434  101.789  -75.983  45.204  1
263435  101.797  -75.986  45.180  1
263436  101.805  -75.988  45.156  1
263437  101.812  -75.991  45.132  1
263438  101.820  -75.994  45.108  1
263439  101.827  -75.997  45.084  1
263440  101.846  -76.013  45.060  1
263441  101.869  -76.032  45.036  1
263442  101.890  -76.052  45.012  1
263790  92.419  -73.549  54.671  1
263791  92.445  -73.559  54.668  1
263792  92.472  -73.570  54.665  1
263793  92.498  -73.581  54.660  1
263794  92.524  -73.591  54.657  1
263795  92.551  -73.601  54.653  1
263796  92.577  -73.612  54.650  1
263797  92.603  -73.622  54.646  1
263798  92.630  -73.633  54.642  1
263799  92.656  -73.643  54.638  1
263800  92.683  -73.653  54.635  1
263801  92.709  -73.664  54.632  1
263802  92.740  -73.675  54.630  1
263803  92.771  -73.684  54.629  1
263804  92.804  -73.689  54.628  1
263805  92.831  -73.691  54.627  1
263806  92.859  -73.697  54.628  1
263807  92.888  -73.703  54.629  1
263808  92.917  -73.709  54.630  1
263809  92.945  -73.716  54.633  1
263810  92.974  -73.722  54.636  1
263811  93.003  -73.728  54.640  1
263812  93.031  -73.734  54.644  1
263813  93.060  -73.741  54.648  1
263814  93.087  -73.745  54.653  1
263815  93.111  -73.742  54.657  1
263816  93.134  -73.740  54.661  1
263817  93.157  -73.737  54.663  1
263818  93.180  -73.734  54.662  1
263819  93.203  -73.731  54.661  1
263820  93.233  -73.738  54.658  1
263821  93.266  -73.747  54.654  1
263822  93.298  -73.753  54.651  1
263823  93.330  -73.754  54.647  1
263824  93.363  -73.755  54.644  1
263825  93.395  -73.756  54.642  1
263826  93.428  -73.757  54.641  1
263827  93.460  -73.759  54.641  1
263828  93.491  -73.760  54.640  1
263829  93.513  -73.763  54.640  1
263830  93.539  -73.766  54.635  1
263831  93.570  -73.767  54.629  1
263832  93.601  -73.769  54.622  1
263833  93.632  -73.770  54.614  1
263834  93.663  -73.772  54.604  1
263835  93.690  -73.775  54.592  1
263836  93.701  -73.775  54.580  1
263837  93.711  -73.775  54.565  1
263838  93.720  -73.775  54.547  1
263839  93.736  -73.775  54.534  1
263840  93.757  -73.776  54.524  1
263841  93.778  -73.777  54.517  1
263842  93.799  -73.777  54.510  1
263843  93.820  -73.778  54.506  1
263844  93.841  -73.778  54.503  1
263845  93.863  -73.776  54.500  1
263846  93.885  -73.772  54.499  1
263847  93.907  -73.769  54.497  1
263848  93.929  -73.764  54.491  1
263849  93.951  -73.760  54.482  1
263850  93.973  -73.756  54.468  1
263851  93.995  -73.752  54.445  1
263852  94.019  -73.749  54.416  1
263853  94.065  -73.751  54.382  1
263854  94.111  -73.753  54.349  1
263855  94.145  -73.753  54.320  1
263856  94.172  -73.751  54.296  1
263857  94.196  -73.750  54.276  1
263858  94.220  -73.749  54.263  1
263859  94.245  -73.748  54.250  1
263860  94.269  -73.747  54.236  1
263861  94.313  -73.777  54.219  1
263862  94.362  -73.813  54.194  1
263863  94.395  -73.811  54.165  1
263864  94.422  -73.809  54.134  1
263865  94.427  -73.807  54.102  1
263866  94.432  -73.803  54.070  1
263867  94.447  -73.807  54.038  1
263868  94.462  -73.811  54.007  1
263869  94.477  -73.816  53.978  1
263870  94.492  -73.819  53.949  1
263871  94.507  -73.823  53.917  1
263872  94.522  -73.827  53.884  1
263873  94.537  -73.831  53.850  1
263874  94.551  -73.825  53.814  1
263875  94.571  -73.834  53.777  1
263876  94.593  -73.848  53.740  1
263877  94.615  -73.863  53.705  1
263878  94.634  -73.865  53.670  1
263879  94.651  -73.863  53.638  1
263880  94.669  -73.860  53.609  1
263881  94.686  -73.858  53.583  1
263882  94.703  -73.856  53.560  1
263883  94.721  -73.854  53.540  1
263884  94.739  -73.850  53.523  1
263885  94.759  -73.841  53.506  1
263886  94.776  -73.837  53.483  1
263887  94.790  -73.838  53.456  1
263888  94.819  -73.847  53.426  1
263889  94.865  -73.863  53.395  1
263890  94.912  -73.881  53.361  1
263891  94.959  -73.897  53.325  1
263892  95.005  -73.915  53.288  1
263893  95.052  -73.932  53.252  1
263894  95.099  -73.949  53.209  1
263895  95.119  -73.944  53.163  1
263896  95.127  -73.932  53.113  1
263897  95.134  -73.921  53.063  1
263898  95.141  -73.910  53.011  1
263899  95.149  -73.898  52.961  1
263900  95.156  -73.887  52.911  1
263901  95.164  -73.875  52.865  1
263902  95.171  -73.864  52.821  1
263903  95.178  -73.853  52.778  1
263904  95.195  -73.847  52.736  1
263905  95.228  -73.851  52.695  1
263906  95.260  -73.855  52.655  1
263907  95.293  -73.859  52.618  1
263908  95.325  -73.863  52.582  1
263909  95.357  -73.867  52.544  1
263910  95.390  -73.871  52.504  1
263911  95.422  -73.875  52.466  1
263912  95.455  -73.879  52.427  1
263913  95.487  -73.882  52.389  1
263914  95.520  -73.886  52.352  1
263915  95.552  -73.897  52.314  1
263916  95.584  -73.912  52.277  1
263917  95.612  -73.910  52.240  1
263918  95.643  -73.903  52.205  1
263919  95.677  -73.898  52.170  1
263920  95.708  -73.894  52.135  1
263921  95.734  -73.889  52.102  1
263922  95.759  -73.884  52.068  1
263923  95.784  -73.879  52.034  1
263924  95.810  -73.873  52.000  1
263925  95.835  -73.868  51.967  1
263926  95.861  -73.863  51.936  1
263927  95.886  -73.858  51.904  1
263928  95.911  -73.853  51.871  1
263929  95.936  -73.847  51.840  1
263930  95.986  -73.841  51.803  1
263931  96.027  -73.831  51.765  1
263932  96.009  -73.816  51.726  1
263933  96.002  -73.809  51.687  1
263934  96.035  -73.829  51.647  1
263935  96.067  -73.850  51.609  1
263936  96.101  -73.870  51.571  1
263937  96.134  -73.891  51.534  1
263938  96.167  -73.911  51.499  1
263939  96.200  -73.932  51.464  1
263940  96.232  -73.954  51.429  1
263941  96.261  -73.979  51.394  1
263942  96.268  -73.991  51.361  1
263943  96.284  -74.001  51.329  1
263944  96.300  -74.010  51.297  1
263945  96.324  -74.018  51.267  1
263946  96.351  -74.025  51.239  1
263947  96.378  -74.032  51.211  1
263948  96.404  -74.038  51.183  1
263949  96.434  -74.042  51.157  1
263950  96.468  -74.042  51.133  1
263951  96.503  -74.042  51.111  1
263952  96.536  -74.048  51.090  1
263953  96.568  -74.062  51.069  1
263954  96.600  -74.076  51.050  1
263955  96.631  -74.089  51.033  1
263956  96.663  -74.103  51.018  1
263957  96.694  -74.117  51.002  1
263958  96.726  -74.131  50.989  1
263959  96.753  -74.142  50.977  1
263960  96.765  -74.147  50.967  1
263961  96.777  -74.152  50.959  1
263962  96.789  -74.157  50.954  1
263963  96.801  -74.162  50.952  1
263964  96.822  -74.179  50.951  1
263965  96.849  -74.206  50.949  1
263966  96.882  -74.223  50.950  1
263967  96.914  -74.239  50.954  1
263968  96.948  -74.242  50.960  1
263969  96.984  -74.234  50.967  1
263970  97.019  -74.227  50.979  1
263971  97.054  -74.220  50.991  1
263972  97.090  -74.212  51.001  1
263973  97.125  -74.205  51.011  1
263974  97.161  -74.198  51.014  1
263975  97.196  -74.190  51.014  1
263976  97.231  -74.183  51.011  1
263977  97.267  -74.176  51.003  1
263978  97.302  -74.168  50.988  1
263979  97.337  -74.161  50.972  1
263980  97.373  -74.154  50.955  1
263981  97.408  -74.146  50.937  1
263982  97.440  -74.137  50.915  1
263983  97.462  -74.122  50.890  1
263984  97.486  -74.126  50.862  1
263985  97.510  -74.132  50.831  1
263986  97.534  -74.140  50.798  1
263987  97.564  -74.154  50.765  1
263988  97.593  -74.169  50.731  1
263989  97.622  -74.184  50.694  1
263990  97.651  -74.198  50.656  1
263991  97.678  -74.214  50.615  1
263992  97.706  -74.230  50.572  1
263993  97.733  -74.245  50.527  1
263994  97.759  -74.261  50.482  1
263995  97.787  -74.277  50.436  1
263996  97.813  -74.293  50.390  1
263997  97.841  -74.309  50.344  1
263998  97.867  -74.325  50.293  1
263999  97.897  -74.339  50.241  1
264000  97.919  -74.345  50.189  1
264001  97.950  -74.358  50.137  1
264002  97.983  -74.372  50.092  1
264003  98.016  -74.386  50.049  1
264004  98.048  -74.400  50.004  1
264005  98.078  -74.415  49.954  1
264006  98.108  -74.428  49.901  1
264007  98.139  -74.443  49.845  1
264008  98.169  -74.457  49.789  1
264009  98.200  -74.471  49.731  1
264010  98.230  -74.485  49.672  1
264011  98.260  -74.499  49.612  1
264012  98.291  -74.514  49.552  1
264013  98.321  -74.527  49.492  1
264014  98.329  -74.539  49.434  1
264015  98.308  -74.545  49.378  1
264016  98.287  -74.552  49.322  1
264017  98.266  -74.558  49.266  1
264018  98.307  -74.581  49.208  1
264019  98.360  -74.612  49.151  1
264020  98.414  -74.643  49.095  1
264021  98.464  -74.686  49.042  1
264022  98.514  -74.743  48.991  1
264023  98.564  -74.800  48.942  1
264024  98.613  -74.858  48.893  1
264025  98.662  -74.916  48.843  1
264026  98.712  -74.973  48.793  1
264027  98.719  -74.960  48.742  1
264028  98.719  -74.934  48.688  1
264029  98.736  -74.946  48.634  1
264030  98.762  -74.973  48.581  1
264031  98.799  -74.954  48.527  1
264032  98.843  -74.908  48.473  1
264033  98.886  -74.863  48.420  1
264034  98.931  -74.818  48.370  1
264035  98.975  -74.772  48.320  1
264036  99.018  -74.728  48.269  1
264037  99.042  -74.726  48.219  1
264038  99.059  -74.740  48.170  1
264039  99.076  -74.755  48.120  1
264040  99.092  -74.769  48.072  1
264041  99.109  -74.784  48.024  1
264042  99.126  -74.799  47.977  1
264043  99.143  -74.813  47.931  1
264044  99.159  -74.828  47.884  1
264045  99.190  -74.847  47.838  1
264046  99.225  -74.869  47.792  1
264047  99.260  -74.891  47.747  1
264048  99.295  -74.913  47.704  1
264049  99.330  -74.934  47.661  1
264050  99.365  -74.956  47.618  1
264051  99.402  -74.969  47.577  1
264052  99.440  -74.980  47.536  1
264053  99.479  -74.991  47.495  1
264054  99.517  -75.003  47.457  1
264055  99.553  -75.007  47.418  1
264056  99.587  -75.007  47.380  1
264057  99.621  -75.008  47.344  1
264058  99.655  -75.009  47.311  1
264059  99.689  -75.010  47.279  1
264060  99.723  -75.010  47.248  1
264061  99.758  -75.011  47.219  1
264062  99.788  -75.015  47.190  1
264063  99.820  -75.019  47.162  1
264064  99.851  -75.023  47.136  1
264065  99.881  -75.028  47.111  1
264066  99.913  -75.032  47.085  1
264067  99.944  -75.036  47.060  1
264068  99.975  -75.041  47.035  1
264069  100.006  -75.044  47.012  1
264070  100.056  -75.073  46.988  1
264071  100.106  -75.101  46.965  1
264072  100.139  -75.139  46.944  1
264073  100.171  -75.177  46.925  1
264074  100.205  -75.215  46.903  1
264075  100.239  -75.253  46.879  1
264076  100.269  -75.277  46.854  1
264077  100.297  -75.293  46.827  1
264078  100.322  -75.309  46.801  1
264079  100.341  -75.326  46.775  1
264080  100.359  -75.342  46.747  1
264081  100.378  -75.358  46.719  1
264082  100.397  -75.374  46.692  1
264083  100.415  -75.391  46.663  1
264084  100.434  -75.407  46.635  1
264085  100.453  -75.424  46.608  1
264086  100.471  -75.439  46.580  1
264087  100.490  -75.456  46.551  1
264088  100.508  -75.472  46.522  1
264089  100.527  -75.489  46.493  1
264090  100.546  -75.505  46.464  1
264091  100.565  -75.521  46.436  1
264092  100.583  -75.537  46.408  1
264093  100.602  -75.554  46.381  1
264094  100.621  -75.570  46.352  1
264095  100.642  -75.581  46.324  1
264096  100.670  -75.569  46.296  1
264097  100.697  -75.557  46.268  1
264098  100.725  -75.545  46.242  1
264099  100.752  -75.533  46.215  1
264100  100.786  -75.526  46.188  1
264101  100.830  -75.527  46.161  1
264102  100.874  -75.529  46.134  1
264103  100.918  -75.531  46.107  1
264104  100.961  -75.536  46.080  1
264105  100.992  -75.551  46.053  1
264106  101.022  -75.565  46.025  1
264107  101.053  -75.579  45.996  1
264108  101.084  -75.593  45.965  1
264109  101.114  -75.607  45.934  1
264110  101.139  -75.618  45.901  1
264111  101.153  -75.627  45.870  1
264112  101.167  -75.636  45.838  1
264113  101.181  -75.645  45.807  1
264114  101.195  -75.654  45.777  1
264115  101.209  -75.662  45.746  1
264116  101.222  -75.671  45.716  1
264117  101.237  -75.681  45.689  1
264118  101.258  -75.687  45.659  1
264119  101.289  -75.690  45.629  1
264120  101.320  -75.693  45.598  1
264121  101.351  -75.696  45.566  1
264122  101.382  -75.699  45.535  1
264123  101.426  -75.719  45.505  1
264124  101.483  -75.757  45.476  1
264125  101.539  -75.796  45.448  1
264126  101.596  -75.834  45.422  1
264127  101.652  -75.872  45.395  1
264128  101.708  -75.910  45.369  1
264129  101.747  -75.935  45.342  1
264130  101.755  -75.938  45.317  1
264131  101.762  -75.941  45.291  1
264132  101.770  -75.944  45.266  1
264133  101.778  -75.946  45.241  1
264134  101.785  -75.949  45.216  1
264135  101.793  -75.952  45.191  1
264136  101.801  -75.954  45.166  1
264137  101.808  -75.957  45.143  1
264138  101.816  -75.960  45.118  1
264139  101.825  -75.964  45.094  1
264140  101.846  -75.984  45.070  1
264141  101.869  -76.003  45.046  1
264142  101.890  -76.022  45.022  1
264143  101.910  -76.033  44.998  1
264491  92.399  -73.520  54.678  1
264492  92.425  -73.531  54.674  1
264493  92.451  -73.541  54.670  1
264494  92.478  -73.552  54.665  1
264495  92.504  -73.562  54.660  1
264496  92.531  -73.572  54.657  1
264497  92.557  -73.583  54.652  1
264498  92.583  -73.593  54.646  1
264499  92.613  -73.604  54.642  1
264500  92.644  -73.614  54.638  1
264501  92.674  -73.625  54.635  1
264502  92.705  -73.634  54.632  1
264503  92.735  -73.645  54.629  1
264504  92.766  -73.656  54.627  1
264505  92.807  -73.666  54.626  1
264506  92.838  -73.665  54.626  1
264507  92.860  -73.656  54.625  1
264508  92.888  -73.662  54.626  1
264509  92.917  -73.669  54.628  1
264510  92.945  -73.675  54.630  1
264511  92.974  -73.681  54.633  1
264512  93.003  -73.687  54.637  1
264513  93.031  -73.694  54.640  1
264514  93.060  -73.700  54.645  1
264515  93.089  -73.706  54.650  1
264516  93.113  -73.703  54.654  1
264517  93.136  -73.701  54.658  1
264518  93.159  -73.698  54.660  1
264519  93.182  -73.695  54.660  1
264520  93.208  -73.697  54.658  1
264521  93.240  -73.706  54.655  1
264522  93.272  -73.715  54.651  1
264523  93.304  -73.724  54.647  1
264524  93.337  -73.728  54.644  1
264525  93.369  -73.728  54.641  1
264526  93.402  -73.730  54.637  1
264527  93.434  -73.731  54.634  1
264528  93.467  -73.732  54.632  1
264529  93.493  -73.734  54.629  1
264530  93.514  -73.738  54.628  1
264531  93.537  -73.741  54.625  1
264532  93.561  -73.744  54.621  1
264533  93.592  -73.745  54.614  1
264534  93.623  -73.747  54.606  1
264535  93.654  -73.748  54.596  1
264536  93.683  -73.750  54.585  1
264537  93.695  -73.751  54.571  1
264538  93.704  -73.751  54.554  1
264539  93.715  -73.751  54.535  1
264540  93.736  -73.752  54.518  1
264541  93.757  -73.753  54.504  1
264542  93.778  -73.753  54.493  1
264543  93.799  -73.753  54.483  1
264544  93.821  -73.753  54.476  1
264545  93.842  -73.749  54.468  1
264546  93.864  -73.745  54.459  1
264547  93.887  -73.741  54.453  1
264548  93.908  -73.737  54.447  1
264549  93.930  -73.733  54.440  1
264550  93.953  -73.729  54.429  1
264551  93.975  -73.725  54.415  1
264552  93.996  -73.721  54.397  1
264553  94.018  -73.716  54.375  1
264554  94.052  -73.716  54.346  1
264555  94.098  -73.718  54.316  1
264556  94.142  -73.720  54.289  1
264557  94.173  -73.719  54.265  1
264558  94.200  -73.721  54.244  1
264559  94.224  -73.719  54.230  1
264560  94.249  -73.719  54.215  1
264561  94.273  -73.718  54.199  1
264562  94.300  -73.722  54.182  1
264563  94.353  -73.765  54.155  1
264564  94.398  -73.791  54.127  1
264565  94.410  -73.791  54.097  1
264566  94.425  -73.795  54.066  1
264567  94.440  -73.799  54.035  1
264568  94.455  -73.803  54.003  1
264569  94.470  -73.807  53.972  1
264570  94.485  -73.811  53.943  1
264571  94.500  -73.815  53.912  1
264572  94.515  -73.819  53.879  1
264573  94.530  -73.822  53.844  1
264574  94.545  -73.827  53.810  1
264575  94.560  -73.831  53.775  1
264576  94.572  -73.817  53.741  1
264577  94.594  -73.830  53.707  1
264578  94.616  -73.844  53.674  1
264579  94.636  -73.849  53.642  1
264580  94.653  -73.847  53.612  1
264581  94.671  -73.844  53.585  1
264582  94.688  -73.843  53.562  1
264583  94.705  -73.841  53.541  1
264584  94.723  -73.838  53.525  1
264585  94.740  -73.836  53.509  1
264586  94.758  -73.832  53.492  1
264587  94.778  -73.822  53.467  1
264588  94.793  -73.824  53.439  1
264589  94.822  -73.832  53.409  1
264590  94.868  -73.850  53.378  1
264591  94.915  -73.866  53.343  1
264592  94.962  -73.884  53.306  1
264593  95.008  -73.901  53.268  1
264594  95.050  -73.914  53.228  1
264595  95.084  -73.922  53.183  1
264596  95.116  -73.921  53.135  1
264597  95.128  -73.900  53.086  1
264598  95.135  -73.888  53.036  1
264599  95.142  -73.877  52.986  1
264600  95.150  -73.866  52.938  1
264601  95.157  -73.854  52.892  1
264602  95.165  -73.843  52.847  1
264603  95.172  -73.832  52.805  1
264604  95.179  -73.820  52.763  1
264605  95.202  -73.819  52.723  1
264606  95.235  -73.822  52.684  1
264607  95.267  -73.826  52.647  1
264608  95.300  -73.830  52.611  1
264609  95.332  -73.835  52.574  1
264610  95.365  -73.838  52.536  1
264611  95.397  -73.842  52.497  1
264612  95.429  -73.846  52.459  1
264613  95.462  -73.850  52.421  1
264614  95.494  -73.855  52.384  1
264615  95.526  -73.869  52.347  1
264616  95.558  -73.884  52.310  1
264617  95.590  -73.898  52.273  1
264618  95.616  -73.886  52.236  1
264619  95.646  -73.878  52.202  1
264620  95.680  -73.873  52.167  1
264621  95.715  -73.869  52.133  1
264622  95.749  -73.866  52.101  1
264623  95.774  -73.860  52.068  1
264624  95.800  -73.855  52.034  1
264625  95.825  -73.850  51.999  1
264626  95.850  -73.844  51.965  1
264627  95.875  -73.840  51.933  1
264628  95.901  -73.835  51.901  1
264629  95.926  -73.829  51.868  1
264630  95.951  -73.824  51.837  1
264631  96.013  -73.816  51.800  1
264632  96.047  -73.806  51.763  1
264633  96.029  -73.791  51.725  1
264634  96.011  -73.776  51.687  1
264635  96.042  -73.795  51.649  1
264636  96.075  -73.816  51.611  1
264637  96.108  -73.836  51.574  1
264638  96.141  -73.857  51.538  1
264639  96.169  -73.883  51.503  1
264640  96.198  -73.909  51.468  1
264641  96.227  -73.935  51.435  1
264642  96.256  -73.960  51.400  1
264643  96.263  -73.969  51.368  1
264644  96.279  -73.979  51.335  1
264645  96.303  -73.987  51.303  1
264646  96.329  -73.994  51.272  1
264647  96.356  -74.001  51.243  1
264648  96.383  -74.007  51.215  1
264649  96.409  -74.014  51.188  1
264650  96.436  -74.021  51.161  1
264651  96.470  -74.021  51.138  1
264652  96.505  -74.021  51.115  1
264653  96.540  -74.021  51.093  1
264654  96.574  -74.023  51.072  1
264655  96.605  -74.037  51.053  1
264656  96.637  -74.051  51.036  1
264657  96.669  -74.064  51.019  1
264658  96.700  -74.078  51.003  1
264659  96.732  -74.092  50.989  1
264660  96.759  -74.104  50.976  1
264661  96.771  -74.108  50.966  1
264662  96.783  -74.114  50.957  1
264663  96.795  -74.118  50.953  1
264664  96.813  -74.132  50.950  1
264665  96.840  -74.157  50.947  1
264666  96.873  -74.174  50.945  1
264667  96.905  -74.190  50.945  1
264668  96.938  -74.206  50.948  1
264669  96.972  -74.214  50.953  1
264670  97.007  -74.207  50.960  1
264671  97.043  -74.199  50.972  1
264672  97.078  -74.192  50.983  1
264673  97.113  -74.185  50.992  1
264674  97.149  -74.177  51.001  1
264675  97.184  -74.170  51.004  1
264676  97.220  -74.163  51.003  1
264677  97.255  -74.155  50.999  1
264678  97.290  -74.148  50.992  1
264679  97.326  -74.141  50.976  1
264680  97.361  -74.133  50.961  1
264681  97.393  -74.125  50.945  1
264682  97.416  -74.110  50.928  1
264683  97.439  -74.095  50.908  1
264684  97.462  -74.097  50.885  1
264685  97.486  -74.103  50.859  1
264686  97.510  -74.110  50.829  1
264687  97.533  -74.116  50.797  1
264688  97.558  -74.123  50.764  1
264689  97.587  -74.138  50.729  1
264690  97.616  -74.153  50.693  1
264691  97.646  -74.167  50.656  1
264692  97.675  -74.182  50.616  1
264693  97.704  -74.196  50.572  1
264694  97.733  -74.211  50.526  1
264695  97.762  -74.225  50.480  1
264696  97.790  -74.240  50.434  1
264697  97.817  -74.256  50.388  1
264698  97.844  -74.272  50.341  1
264699  97.871  -74.288  50.291  1
264700  97.898  -74.300  50.240  1
264701  97.928  -74.312  50.188  1
264702  97.961  -74.326  50.136  1
264703  97.991  -74.340  50.091  1
264704  98.021  -74.355  50.048  1
264705  98.052  -74.369  50.002  1
264706  98.082  -74.383  49.950  1
264707  98.112  -74.397  49.895  1
264708  98.143  -74.411  49.838  1
264709  98.173  -74.425  49.779  1
264710  98.204  -74.440  49.720  1
264711  98.234  -74.454  49.661  1
264712  98.264  -74.468  49.602  1
264713  98.294  -74.482  49.543  1
264714  98.325  -74.496  49.485  1
264715  98.329  -74.506  49.427  1
264716  98.308  -74.513  49.371  1
264717  98.287  -74.519  49.316  1
264718  98.282  -74.531  49.259  1
264719  98.358  -74.546  49.200  1
264720  98.412  -74.577  49.142  1
264721  98.465  -74.608  49.085  1
264722  98.512  -74.668  49.032  1
264723  98.542  -74.711  48.982  1
264724  98.570  -74.747  48.933  1
264725  98.597  -74.781  48.884  1
264726  98.625  -74.817  48.833  1
264727  98.652  -74.852  48.782  1
264728  98.679  -74.888  48.731  1
264729  98.707  -74.922  48.679  1
264730  98.735  -74.958  48.625  1
264731  98.768  -74.980  48.572  1
264732  98.811  -74.935  48.518  1
264733  98.855  -74.890  48.463  1
264734  98.899  -74.845  48.410  1
264735  98.943  -74.800  48.360  1
264736  98.987  -74.755  48.310  1
264737  99.030  -74.709  48.259  1
264738  99.058  -74.700  48.209  1
264739  99.075  -74.715  48.160  1
264740  99.091  -74.730  48.111  1
264741  99.108  -74.744  48.062  1
264742  99.125  -74.759  48.015  1
264743  99.142  -74.773  47.968  1
264744  99.158  -74.787  47.921  1
264745  99.175  -74.802  47.874  1
264746  99.196  -74.819  47.829  1
264747  99.233  -74.844  47.784  1
264748  99.268  -74.866  47.739  1
264749  99.303  -74.888  47.696  1
264750  99.338  -74.910  47.654  1
264751  99.374  -74.927  47.611  1
264752  99.413  -74.938  47.570  1
264753  99.451  -74.949  47.530  1
264754  99.489  -74.960  47.490  1
264755  99.527  -74.971  47.450  1
264756  99.565  -74.979  47.412  1
264757  99.599  -74.980  47.375  1
264758  99.633  -74.981  47.339  1
264759  99.667  -74.982  47.305  1
264760  99.701  -74.982  47.273  1
264761  99.735  -74.983  47.242  1
264762  99.770  -74.984  47.212  1
264763  99.803  -74.985  47.183  1
264764  99.838  -74.985  47.155  1
264765  99.869  -74.989  47.128  1
264766  99.901  -74.993  47.102  1
264767  99.932  -74.997  47.076  1
264768  99.963  -75.001  47.051  1
264769  99.994  -75.006  47.026  1
264770  100.027  -75.013  47.002  1
264771  100.077  -75.041  46.977  1
264772  100.115  -75.076  46.955  1
264773  100.148  -75.114  46.934  1
264774  100.181  -75.152  46.915  1
264775  100.214  -75.190  46.892  1
264776  100.248  -75.226  46.868  1
264777  100.276  -75.242  46.842  1
264778  100.304  -75.258  46.816  1
264779  100.332  -75.274  46.790  1
264780  100.352  -75.291  46.763  1
264781  100.371  -75.307  46.736  1
264782  100.390  -75.323  46.709  1
264783  100.408  -75.339  46.681  1
264784  100.427  -75.356  46.653  1
264785  100.446  -75.372  46.624  1
264786  100.465  -75.389  46.598  1
264787  100.483  -75.405  46.570  1
264788  100.502  -75.421  46.541  1
264789  100.521  -75.437  46.513  1
264790  100.539  -75.454  46.484  1
264791  100.558  -75.470  46.454  1
264792  100.576  -75.486  46.426  1
264793  100.595  -75.502  46.398  1
264794  100.614  -75.519  46.371  1
264795  100.632  -75.535  46.343  1
264796  100.659  -75.543  46.315  1
264797  100.687  -75.537  46.287  1
264798  100.715  -75.527  46.259  1
264799  100.742  -75.515  46.233  1
264800  100.770  -75.503  46.206  1
264801  100.805  -75.497  46.178  1
264802  100.848  -75.499  46.153  1
264803  100.892  -75.501  46.125  1
264804  100.936  -75.502  46.099  1
264805  100.981  -75.503  46.072  1
264806  101.025  -75.533  46.045  1
264807  101.055  -75.546  46.016  1
264808  101.086  -75.560  45.987  1
264809  101.116  -75.574  45.957  1
264810  101.146  -75.587  45.926  1
264811  101.155  -75.593  45.894  1
264812  101.173  -75.588  45.861  1
264813  101.186  -75.597  45.829  1
264814  101.200  -75.606  45.797  1
264815  101.214  -75.615  45.765  1
264816  101.229  -75.624  45.733  1
264817  101.242  -75.633  45.702  1
264818  101.256  -75.642  45.672  1
264819  101.277  -75.649  45.643  1
264820  101.308  -75.652  45.613  1
264821  101.339  -75.655  45.582  1
264822  101.370  -75.658  45.552  1
264823  101.403  -75.668  45.520  1
264824  101.451  -75.703  45.491  1
264825  101.508  -75.741  45.463  1
264826  101.564  -75.780  45.435  1
264827  101.621  -75.818  45.408  1
264828  101.677  -75.856  45.381  1
264829  101.734  -75.894  45.355  1
264830  101.751  -75.904  45.329  1
264831  101.758  -75.906  45.303  1
264832  101.766  -75.909  45.277  1
264833  101.774  -75.912  45.251  1
264834  101.781  -75.915  45.226  1
264835  101.789  -75.918  45.201  1
264836  101.796  -75.920  45.176  1
264837  101.804  -75.923  45.152  1
264838  101.812  -75.925  45.128  1
264839  101.825  -75.934  45.104  1
264840  101.846  -75.954  45.079  1
264841  101.869  -75.974  45.055  1
264842  101.890  -75.992  45.031  1
264843  101.907  -75.993  45.007  1
264844  101.925  -75.993  44.984  1
265191  92.353  -73.481  54.692  1
265192  92.379  -73.491  54.685  1
265193  92.405  -73.502  54.680  1
265194  92.432  -73.512  54.675  1
265195  92.458  -73.523  54.670  1
265196  92.486  -73.533  54.665  1
265197  92.517  -73.543  54.660  1
265198  92.548  -73.554  54.654  1
265199  92.578  -73.564  54.648  1
265200  92.609  -73.575  54.643  1
265201  92.639  -73.585  54.639  1
265202  92.670  -73.595  54.635  1
265203  92.701  -73.606  54.631  1
265204  92.731  -73.616  54.628  1
265205  92.762  -73.626  54.625  1
265206  92.804  -73.637  54.624  1
265207  92.847  -73.648  54.623  1
265208  92.871  -73.641  54.622  1
265209  92.894  -73.632  54.623  1
265210  92.917  -73.627  54.625  1
265211  92.945  -73.634  54.628  1
265212  92.974  -73.640  54.631  1
265213  93.003  -73.646  54.634  1
265214  93.031  -73.652  54.637  1
265215  93.060  -73.659  54.641  1
265216  93.089  -73.665  54.646  1
265217  93.114  -73.666  54.650  1
265218  93.137  -73.662  54.655  1
265219  93.160  -73.659  54.657  1
265220  93.184  -73.656  54.656  1
265221  93.214  -73.664  54.654  1
265222  93.247  -73.673  54.651  1
265223  93.278  -73.682  54.647  1
265224  93.310  -73.691  54.644  1
265225  93.343  -73.700  54.641  1
265226  93.375  -73.703  54.637  1
265227  93.408  -73.703  54.632  1
265228  93.440  -73.705  54.627  1
265229  93.473  -73.706  54.623  1
265230  93.494  -73.709  54.618  1
265231  93.516  -73.713  54.616  1
265232  93.538  -73.716  54.613  1
265233  93.560  -73.719  54.609  1
265234  93.583  -73.722  54.603  1
265235  93.615  -73.723  54.596  1
265236  93.646  -73.725  54.587  1
265237  93.675  -73.726  54.575  1
265238  93.689  -73.727  54.561  1
265239  93.698  -73.727  54.543  1
265240  93.715  -73.728  54.523  1
265241  93.736  -73.728  54.504  1
265242  93.757  -73.729  54.488  1
265243  93.778  -73.729  54.474  1
265244  93.800  -73.726  54.461  1
265245  93.822  -73.722  54.451  1
265246  93.844  -73.718  54.440  1
265247  93.866  -73.714  54.427  1
265248  93.888  -73.709  54.417  1
265249  93.910  -73.706  54.406  1
265250  93.932  -73.701  54.395  1
265251  93.954  -73.697  54.382  1
265252  93.976  -73.694  54.368  1
265253  93.998  -73.689  54.351  1
265254  94.020  -73.685  54.331  1
265255  94.042  -73.681  54.307  1
265256  94.084  -73.683  54.280  1
265257  94.120  -73.678  54.255  1
265258  94.156  -73.673  54.233  1
265259  94.185  -73.675  54.213  1
265260  94.213  -73.678  54.196  1
265261  94.242  -73.680  54.178  1
265262  94.270  -73.682  54.160  1
265263  94.299  -73.685  54.140  1
265264  94.327  -73.698  54.114  1
265265  94.359  -73.725  54.086  1
265266  94.392  -73.752  54.058  1
265267  94.424  -73.779  54.029  1
265268  94.448  -73.794  53.998  1
265269  94.463  -73.799  53.968  1
265270  94.478  -73.803  53.937  1
265271  94.493  -73.807  53.906  1
265272  94.508  -73.810  53.874  1
265273  94.523  -73.814  53.839  1
265274  94.538  -73.819  53.804  1
265275  94.553  -73.822  53.770  1
265276  94.568  -73.826  53.738  1
265277  94.582  -73.823  53.705  1
265278  94.595  -73.812  53.674  1
265279  94.617  -73.826  53.644  1
265280  94.637  -73.834  53.614  1
265281  94.655  -73.832  53.587  1
265282  94.673  -73.829  53.561  1
265283  94.690  -73.827  53.540  1
265284  94.707  -73.825  53.522  1
265285  94.724  -73.822  53.507  1
265286  94.742  -73.820  53.493  1
265287  94.760  -73.818  53.474  1
265288  94.778  -73.813  53.449  1
265289  94.795  -73.810  53.421  1
265290  94.824  -73.819  53.391  1
265291  94.871  -73.835  53.359  1
265292  94.918  -73.853  53.323  1
265293  94.965  -73.869  53.284  1
265294  94.999  -73.879  53.244  1
265295  95.034  -73.887  53.200  1
265296  95.068  -73.895  53.155  1
265297  95.102  -73.904  53.107  1
265298  95.127  -73.870  53.058  1
265299  95.136  -73.856  53.010  1
265300  95.143  -73.844  52.963  1
265301  95.150  -73.833  52.917  1
265302  95.158  -73.822  52.874  1
265303  95.166  -73.810  52.831  1
265304  95.173  -73.799  52.790  1
265305  95.180  -73.788  52.750  1
265306  95.210  -73.790  52.711  1
265307  95.242  -73.794  52.673  1
265308  95.274  -73.797  52.638  1
265309  95.307  -73.801  52.602  1
265310  95.339  -73.806  52.566  1
265311  95.372  -73.810  52.528  1
265312  95.404  -73.813  52.489  1
265313  95.437  -73.817  52.452  1
265314  95.469  -73.828  52.415  1
265315  95.500  -73.842  52.378  1
265316  95.533  -73.856  52.341  1
265317  95.564  -73.870  52.305  1
265318  95.594  -73.875  52.269  1
265319  95.621  -73.863  52.233  1
265320  95.649  -73.853  52.199  1
265321  95.683  -73.849  52.166  1
265322  95.718  -73.844  52.133  1
265323  95.752  -73.841  52.100  1
265324  95.787  -73.836  52.067  1
265325  95.814  -73.832  52.033  1
265326  95.840  -73.826  51.998  1
265327  95.865  -73.821  51.964  1
265328  95.890  -73.816  51.931  1
265329  95.915  -73.811  51.898  1
265330  95.941  -73.806  51.865  1
265331  95.976  -73.800  51.832  1
265332  96.039  -73.791  51.797  1
265333  96.066  -73.781  51.761  1
265334  96.048  -73.766  51.725  1
265335  96.031  -73.751  51.690  1
265336  96.049  -73.762  51.653  1
265337  96.078  -73.788  51.616  1
265338  96.106  -73.813  51.579  1
265339  96.135  -73.839  51.544  1
265340  96.164  -73.865  51.509  1
265341  96.193  -73.891  51.474  1
265342  96.222  -73.916  51.441  1
265343  96.242  -73.938  51.407  1
265344  96.258  -73.948  51.374  1
265345  96.281  -73.956  51.342  1
265346  96.308  -73.963  51.311  1
265347  96.334  -73.969  51.279  1
265348  96.361  -73.976  51.250  1
265349  96.388  -73.983  51.221  1
265350  96.414  -73.990  51.193  1
265351  96.441  -73.997  51.167  1
265352  96.472  -73.999  51.142  1
265353  96.507  -73.999  51.119  1
265354  96.542  -73.999  51.096  1
265355  96.576  -73.999  51.075  1
265356  96.611  -73.999  51.056  1
265357  96.643  -74.011  51.038  1
265358  96.674  -74.026  51.020  1
265359  96.706  -74.039  51.004  1
265360  96.738  -74.053  50.989  1
265361  96.765  -74.065  50.976  1
265362  96.777  -74.070  50.964  1
265363  96.789  -74.074  50.955  1
265364  96.804  -74.083  50.950  1
265365  96.831  -74.109  50.946  1
265366  96.864  -74.125  50.943  1
265367  96.897  -74.141  50.939  1
265368  96.930  -74.157  50.940  1
265369  96.962  -74.173  50.942  1
265370  96.996  -74.186  50.946  1
265371  97.031  -74.179  50.953  1
265372  97.066  -74.172  50.964  1
265373  97.101  -74.164  50.974  1
265374  97.137  -74.157  50.984  1
265375  97.172  -74.150  50.992  1
265376  97.208  -74.142  50.993  1
265377  97.243  -74.136  50.991  1
265378  97.279  -74.128  50.985  1
265379  97.314  -74.120  50.978  1
265380  97.348  -74.112  50.963  1
265381  97.370  -74.098  50.948  1
265382  97.393  -74.083  50.932  1
265383  97.416  -74.069  50.914  1
265384  97.439  -74.068  50.897  1
265385  97.462  -74.074  50.877  1
265386  97.486  -74.080  50.853  1
265387  97.510  -74.087  50.825  1
265388  97.533  -74.093  50.793  1
265389  97.557  -74.099  50.761  1
265390  97.582  -74.107  50.728  1
265391  97.611  -74.121  50.691  1
265392  97.640  -74.136  50.656  1
265393  97.669  -74.151  50.616  1
265394  97.699  -74.165  50.573  1
265395  97.728  -74.179  50.526  1
265396  97.757  -74.194  50.479  1
265397  97.786  -74.208  50.433  1
265398  97.815  -74.223  50.387  1
265399  97.845  -74.238  50.339  1
265400  97.874  -74.252  50.291  1
265401  97.904  -74.267  50.240  1
265402  97.934  -74.280  50.187  1
265403  97.965  -74.295  50.134  1
265404  97.995  -74.309  50.088  1
265405  98.025  -74.323  50.044  1
265406  98.056  -74.337  49.998  1
265407  98.086  -74.352  49.946  1
265408  98.117  -74.365  49.890  1
265409  98.147  -74.380  49.832  1
265410  98.177  -74.394  49.773  1
265411  98.208  -74.408  49.713  1
265412  98.238  -74.422  49.655  1
265413  98.268  -74.436  49.595  1
265414  98.298  -74.450  49.536  1
265415  98.329  -74.465  49.478  1
265416  98.330  -74.474  49.421  1
265417  98.309  -74.480  49.365  1
265418  98.288  -74.487  49.309  1
265419  98.317  -74.512  49.252  1
265420  98.386  -74.542  49.193  1
265421  98.463  -74.541  49.134  1
265422  98.517  -74.572  49.077  1
265423  98.563  -74.639  49.021  1
265424  98.600  -74.710  48.971  1
265425  98.628  -74.745  48.922  1
265426  98.656  -74.781  48.873  1
265427  98.683  -74.816  48.823  1
265428  98.711  -74.851  48.772  1
265429  98.738  -74.887  48.720  1
265430  98.759  -74.911  48.668  1
265431  98.769  -74.922  48.615  1
265432  98.782  -74.929  48.562  1
265433  98.825  -74.907  48.508  1
265434  98.867  -74.872  48.453  1
265435  98.912  -74.827  48.399  1
265436  98.955  -74.782  48.348  1
265437  98.999  -74.737  48.297  1
265438  99.043  -74.691  48.247  1
265439  99.074  -74.675  48.197  1
265440  99.090  -74.690  48.148  1
265441  99.108  -74.704  48.100  1
265442  99.124  -74.718  48.052  1
265443  99.141  -74.733  48.004  1
265444  99.157  -74.747  47.957  1
265445  99.174  -74.762  47.911  1
265446  99.191  -74.776  47.865  1
265447  99.207  -74.790  47.819  1
265448  99.237  -74.814  47.775  1
265449  99.276  -74.842  47.731  1
265450  99.311  -74.864  47.687  1
265451  99.346  -74.885  47.645  1
265452  99.384  -74.895  47.604  1
265453  99.423  -74.907  47.563  1
265454  99.461  -74.918  47.524  1
265455  99.499  -74.928  47.485  1
265456  99.538  -74.940  47.446  1
265457  99.576  -74.951  47.407  1
265458  99.611  -74.953  47.370  1
265459  99.645  -74.954  47.334  1
265460  99.679  -74.954  47.299  1
265461  99.713  -74.955  47.266  1
265462  99.748  -74.957  47.235  1
265463  99.782  -74.957  47.205  1
265464  99.816  -74.958  47.175  1
265465  99.850  -74.959  47.147  1
265466  99.884  -74.960  47.119  1
265467  99.918  -74.960  47.094  1
265468  99.950  -74.963  47.067  1
265469  99.982  -74.967  47.041  1
265470  100.013  -74.971  47.017  1
265471  100.048  -74.981  46.992  1
265472  100.091  -75.013  46.967  1
265473  100.124  -75.051  46.945  1
265474  100.157  -75.089  46.924  1
265475  100.190  -75.127  46.904  1
265476  100.223  -75.165  46.881  1
265477  100.254  -75.192  46.856  1
265478  100.282  -75.208  46.831  1
265479  100.310  -75.224  46.805  1
265480  100.338  -75.240  46.779  1
265481  100.364  -75.256  46.752  1
265482  100.383  -75.272  46.725  1
265483  100.402  -75.289  46.698  1
265484  100.420  -75.305  46.670  1
265485  100.439  -75.321  46.642  1
265486  100.458  -75.337  46.614  1
265487  100.476  -75.354  46.587  1
265488  100.495  -75.370  46.559  1
265489  100.513  -75.386  46.532  1
265490  100.533  -75.402  46.504  1
265491  100.551  -75.419  46.474  1
265492  100.570  -75.435  46.444  1
265493  100.588  -75.452  46.416  1
265494  100.607  -75.467  46.388  1
265495  100.626  -75.484  46.361  1
265496  100.650  -75.496  46.333  1
265497  100.678  -75.504  46.305  1
265498  100.705  -75.499  46.277  1
265499  100.733  -75.493  46.249  1
265500  100.760  -75.486  46.222  1
265501  100.787  -75.474  46.195  1
265502  100.823  -75.468  46.168  1
265503  100.867  -75.471  46.141  1
265504  100.912  -75.469  46.114  1
265505  100.957  -75.465  46.088  1
265506  101.001  -75.470  46.061  1
265507  101.047  -75.502  46.033  1
265508  101.093  -75.534  46.004  1
265509  101.125  -75.550  45.975  1
265510  101.154  -75.564  45.946  1
265511  101.161  -75.572  45.915  1
265512  101.169  -75.580  45.882  1
265513  101.187  -75.570  45.849  1
265514  101.206  -75.559  45.817  1
265515  101.220  -75.568  45.785  1
265516  101.234  -75.577  45.753  1
265517  101.248  -75.586  45.721  1
265518  101.262  -75.594  45.688  1
265519  101.276  -75.603  45.657  1
265520  101.296  -75.610  45.627  1
265521  101.327  -75.613  45.597  1
265522  101.358  -75.616  45.566  1
265523  101.389  -75.620  45.536  1
265524  101.429  -75.652  45.506  1
265525  101.476  -75.687  45.477  1
265526  101.533  -75.725  45.449  1
265527  101.590  -75.764  45.422  1
265528  101.646  -75.802  45.393  1
265529  101.702  -75.840  45.366  1
265530  101.747  -75.870  45.340  1
265531  101.755  -75.872  45.314  1
265532  101.762  -75.875  45.288  1
265533  101.770  -75.878  45.262  1
265534  101.777  -75.881  45.236  1
265535  101.785  -75.884  45.211  1
265536  101.793  -75.886  45.186  1
265537  101.801  -75.889  45.162  1
265538  101.808  -75.891  45.137  1
265539  101.825  -75.905  45.112  1
265540  101.846  -75.925  45.088  1
265541  101.869  -75.944  45.064  1
265542  101.888  -75.952  45.040  1
265543  101.905  -75.953  45.015  1
265544  101.922  -75.953  44.992  1
265545  101.940  -75.953  44.969  1
265892  92.333  -73.452  54.699  1
265893  92.359  -73.462  54.692  1
265894  92.390  -73.473  54.686  1
265895  92.421  -73.484  54.680  1
265896  92.451  -73.493  54.674  1
265897  92.482  -73.504  54.668  1
265898  92.513  -73.515  54.663  1
265899  92.544  -73.524  54.657  1
265900  92.574  -73.535  54.650  1
265901  92.604  -73.546  54.644  1
265902  92.635  -73.556  54.639  1
265903  92.666  -73.566  54.635  1
265904  92.697  -73.576  54.631  1
265905  92.727  -73.587  54.626  1
265906  92.758  -73.597  54.623  1
265907  92.801  -73.608  54.620  1
265908  92.844  -73.619  54.619  1
265909  92.882  -73.625  54.618  1
265910  92.904  -73.617  54.619  1
265911  92.927  -73.609  54.621  1
265912  92.949  -73.600  54.623  1
265913  92.974  -73.598  54.628  1
265914  93.003  -73.605  54.630  1
265915  93.031  -73.611  54.633  1
265916  93.060  -73.617  54.638  1
265917  93.089  -73.624  54.642  1
265918  93.116  -73.627  54.646  1
265919  93.139  -73.624  54.649  1
265920  93.162  -73.621  54.651  1
265921  93.189  -73.623  54.651  1
265922  93.221  -73.631  54.649  1
265923  93.253  -73.640  54.645  1
265924  93.285  -73.650  54.642  1
265925  93.317  -73.659  54.639  1
265926  93.349  -73.668  54.636  1
265927  93.381  -73.676  54.631  1
265928  93.414  -73.677  54.627  1
265929  93.446  -73.678  54.620  1
265930  93.474  -73.681  54.614  1
265931  93.496  -73.684  54.608  1
265932  93.517  -73.687  54.603  1
265933  93.540  -73.690  54.600  1
265934  93.561  -73.693  54.595  1
265935  93.583  -73.697  54.589  1
265936  93.606  -73.699  54.584  1
265937  93.637  -73.700  54.575  1
265938  93.667  -73.702  54.564  1
265939  93.682  -73.703  54.550  1
265940  93.694  -73.703  54.532  1
265941  93.715  -73.704  54.511  1
265942  93.736  -73.705  54.491  1
265943  93.758  -73.703  54.472  1
265944  93.780  -73.699  54.456  1
265945  93.802  -73.694  54.441  1
265946  93.824  -73.691  54.428  1
265947  93.846  -73.687  54.414  1
265948  93.868  -73.682  54.399  1
265949  93.890  -73.678  54.385  1
265950  93.912  -73.674  54.371  1
265951  93.934  -73.670  54.357  1
265952  93.956  -73.666  54.343  1
265953  93.978  -73.662  54.328  1
265954  94.000  -73.659  54.311  1
265955  94.021  -73.656  54.291  1
265956  94.042  -73.653  54.268  1
265957  94.071  -73.651  54.245  1
265958  94.110  -73.649  54.222  1
265959  94.146  -73.649  54.202  1
265960  94.175  -73.652  54.183  1
265961  94.203  -73.656  54.163  1
265962  94.233  -73.659  54.142  1
265963  94.261  -73.663  54.121  1
265964  94.285  -73.675  54.099  1
265965  94.309  -73.685  54.072  1
265966  94.333  -73.696  54.045  1
265967  94.357  -73.706  54.017  1
265968  94.381  -73.717  53.987  1
265969  94.405  -73.728  53.958  1
265970  94.429  -73.739  53.928  1
265971  94.461  -73.765  53.897  1
265972  94.493  -73.792  53.865  1
265973  94.516  -73.806  53.834  1
265974  94.531  -73.810  53.802  1
265975  94.546  -73.814  53.768  1
265976  94.561  -73.818  53.735  1
265977  94.576  -73.822  53.704  1
265978  94.591  -73.825  53.674  1
265979  94.604  -73.815  53.643  1
265980  94.618  -73.807  53.614  1
265981  94.639  -73.819  53.586  1
265982  94.657  -73.816  53.561  1
265983  94.674  -73.814  53.538  1
265984  94.692  -73.812  53.516  1
265985  94.709  -73.810  53.500  1
265986  94.726  -73.807  53.486  1
265987  94.744  -73.805  53.471  1
265988  94.761  -73.803  53.452  1
265989  94.779  -73.800  53.428  1
265990  94.797  -73.795  53.401  1
265991  94.827  -73.804  53.371  1
265992  94.874  -73.821  53.338  1
265993  94.915  -73.835  53.300  1
265994  94.950  -73.843  53.259  1
265995  94.984  -73.852  53.216  1
265996  95.018  -73.860  53.171  1
265997  95.052  -73.869  53.125  1
265998  95.087  -73.877  53.078  1
265999  95.116  -73.864  53.031  1
266000  95.137  -73.823  52.985  1
266001  95.144  -73.812  52.941  1
266002  95.151  -73.800  52.898  1
266003  95.159  -73.789  52.856  1
266004  95.167  -73.778  52.815  1
266005  95.174  -73.766  52.775  1
266006  95.184  -73.757  52.736  1
266007  95.217  -73.761  52.699  1
266008  95.249  -73.765  52.663  1
266009  95.282  -73.769  52.628  1
266010  95.314  -73.772  52.593  1
266011  95.346  -73.777  52.558  1
266012  95.379  -73.781  52.519  1
266013  95.411  -73.785  52.481  1
266014  95.443  -73.800  52.444  1
266015  95.475  -73.814  52.408  1
266016  95.507  -73.828  52.372  1
266017  95.539  -73.843  52.335  1
266018  95.571  -73.857  52.300  1
266019  95.599  -73.851  52.265  1
266020  95.625  -73.839  52.229  1
266021  95.652  -73.828  52.197  1
266022  95.687  -73.824  52.164  1
266023  95.721  -73.819  52.132  1
266024  95.755  -73.816  52.100  1
266025  95.790  -73.811  52.067  1
266026  95.824  -73.807  52.033  1
266027  95.854  -73.803  51.998  1
266028  95.880  -73.797  51.964  1
266029  95.905  -73.792  51.930  1
266030  95.931  -73.788  51.897  1
266031  95.956  -73.782  51.864  1
266032  96.002  -73.775  51.831  1
266033  96.066  -73.767  51.796  1
266034  96.086  -73.756  51.761  1
266035  96.068  -73.741  51.727  1
266036  96.051  -73.735  51.693  1
266037  96.052  -73.744  51.657  1
266038  96.076  -73.768  51.621  1
266039  96.102  -73.794  51.585  1
266040  96.130  -73.821  51.549  1
266041  96.159  -73.847  51.515  1
266042  96.188  -73.872  51.481  1
266043  96.217  -73.898  51.447  1
266044  96.237  -73.917  51.415  1
266045  96.259  -73.925  51.381  1
266046  96.286  -73.932  51.349  1
266047  96.313  -73.938  51.317  1
266048  96.339  -73.945  51.286  1
266049  96.366  -73.952  51.256  1
266050  96.393  -73.959  51.227  1
266051  96.419  -73.966  51.199  1
266052  96.446  -73.973  51.172  1
266053  96.475  -73.978  51.148  1
266054  96.509  -73.978  51.123  1
266055  96.544  -73.978  51.100  1
266056  96.578  -73.978  51.078  1
266057  96.613  -73.978  51.058  1
266058  96.648  -73.978  51.039  1
266059  96.680  -73.986  51.022  1
266060  96.712  -74.000  51.005  1
266061  96.743  -74.014  50.989  1
266062  96.771  -74.026  50.975  1
266063  96.783  -74.031  50.963  1
266064  96.795  -74.035  50.953  1
266065  96.823  -74.060  50.946  1
266066  96.856  -74.076  50.941  1
266067  96.888  -74.092  50.937  1
266068  96.921  -74.108  50.934  1
266069  96.954  -74.125  50.933  1
266070  96.986  -74.141  50.935  1
266071  97.019  -74.157  50.939  1
266072  97.054  -74.151  50.946  1
266073  97.090  -74.145  50.957  1
266074  97.125  -74.137  50.967  1
266075  97.160  -74.129  50.975  1
266076  97.196  -74.123  50.983  1
266077  97.231  -74.115  50.983  1
266078  97.266  -74.107  50.979  1
266079  97.302  -74.100  50.972  1
266080  97.324  -74.085  50.963  1
266081  97.347  -74.071  50.948  1
266082  97.369  -74.057  50.933  1
266083  97.392  -74.042  50.918  1
266084  97.415  -74.038  50.900  1
266085  97.439  -74.045  50.884  1
266086  97.462  -74.051  50.865  1
266087  97.486  -74.057  50.844  1
266088  97.510  -74.064  50.818  1
266089  97.533  -74.070  50.789  1
266090  97.558  -74.076  50.758  1
266091  97.581  -74.083  50.726  1
266092  97.605  -74.090  50.691  1
266093  97.635  -74.105  50.656  1
266094  97.664  -74.120  50.616  1
266095  97.693  -74.134  50.572  1
266096  97.722  -74.148  50.523  1
266097  97.751  -74.163  50.476  1
266098  97.782  -74.178  50.429  1
266099  97.813  -74.194  50.383  1
266100  97.845  -74.209  50.335  1
266101  97.876  -74.225  50.286  1
266102  97.907  -74.239  50.235  1
266103  97.938  -74.249  50.183  1
266104  97.968  -74.263  50.130  1
266105  97.999  -74.277  50.084  1
266106  98.029  -74.292  50.040  1
266107  98.060  -74.305  49.994  1
266108  98.090  -74.320  49.942  1
266109  98.121  -74.334  49.884  1
266110  98.151  -74.348  49.824  1
266111  98.181  -74.362  49.764  1
266112  98.212  -74.377  49.704  1
266113  98.242  -74.390  49.646  1
266114  98.272  -74.405  49.587  1
266115  98.302  -74.419  49.528  1
266116  98.333  -74.433  49.470  1
266117  98.330  -74.443  49.413  1
266118  98.309  -74.449  49.358  1
266119  98.289  -74.455  49.302  1
266120  98.353  -74.493  49.245  1
266121  98.418  -74.530  49.185  1
266122  98.508  -74.515  49.126  1
266123  98.569  -74.537  49.067  1
266124  98.613  -74.609  49.011  1
266125  98.655  -74.693  48.960  1
266126  98.687  -74.744  48.911  1
266127  98.714  -74.780  48.862  1
266128  98.742  -74.815  48.811  1
266129  98.756  -74.831  48.760  1
266130  98.767  -74.841  48.709  1
266131  98.777  -74.851  48.657  1
266132  98.788  -74.861  48.604  1
266133  98.798  -74.871  48.550  1
266134  98.840  -74.849  48.496  1
266135  98.882  -74.827  48.442  1
266136  98.924  -74.804  48.388  1
266137  98.968  -74.764  48.336  1
266138  99.011  -74.718  48.284  1
266139  99.056  -74.674  48.234  1
266140  99.090  -74.650  48.185  1
266141  99.106  -74.664  48.136  1
266142  99.123  -74.678  48.088  1
266143  99.140  -74.693  48.040  1
266144  99.156  -74.707  47.993  1
266145  99.173  -74.722  47.946  1
266146  99.190  -74.736  47.900  1
266147  99.206  -74.750  47.855  1
266148  99.222  -74.764  47.810  1
266149  99.239  -74.778  47.765  1
266150  99.278  -74.809  47.721  1
266151  99.318  -74.838  47.678  1
266152  99.356  -74.853  47.637  1
266153  99.395  -74.864  47.597  1
266154  99.433  -74.875  47.557  1
266155  99.472  -74.886  47.518  1
266156  99.510  -74.897  47.479  1
266157  99.548  -74.909  47.441  1
266158  99.586  -74.919  47.403  1
266159  99.623  -74.926  47.365  1
266160  99.657  -74.927  47.328  1
266161  99.691  -74.928  47.293  1
266162  99.725  -74.928  47.260  1
266163  99.760  -74.929  47.228  1
266164  99.794  -74.930  47.197  1
266165  99.828  -74.931  47.168  1
266166  99.862  -74.932  47.139  1
266167  99.896  -74.932  47.111  1
266168  99.930  -74.933  47.085  1
266169  99.964  -74.934  47.059  1
266170  99.998  -74.935  47.033  1
266171  100.031  -74.937  47.007  1
266172  100.067  -74.950  46.982  1
266173  100.101  -74.988  46.958  1
266174  100.133  -75.026  46.936  1
266175  100.166  -75.064  46.914  1
266176  100.199  -75.102  46.893  1
266177  100.232  -75.140  46.870  1
266178  100.261  -75.157  46.846  1
266179  100.289  -75.173  46.819  1
266180  100.317  -75.189  46.793  1
266181  100.345  -75.205  46.767  1
266182  100.372  -75.221  46.741  1
266183  100.395  -75.237  46.714  1
266184  100.414  -75.254  46.687  1
266185  100.432  -75.270  46.660  1
266186  100.451  -75.286  46.632  1
266187  100.470  -75.302  46.604  1
266188  100.488  -75.319  46.577  1
266189  100.507  -75.335  46.550  1
266190  100.525  -75.352  46.522  1
266191  100.544  -75.367  46.494  1
266192  100.563  -75.384  46.464  1
266193  100.581  -75.400  46.435  1
266194  100.600  -75.417  46.406  1
266195  100.619  -75.433  46.379  1
266196  100.640  -75.447  46.351  1
266197  100.668  -75.458  46.323  1
266198  100.695  -75.465  46.296  1
266199  100.722  -75.460  46.268  1
266200  100.750  -75.455  46.239  1
266201  100.777  -75.449  46.212  1
266202  100.805  -75.444  46.186  1
266203  100.842  -75.439  46.159  1
266204  100.887  -75.436  46.130  1
266205  100.932  -75.433  46.103  1
266206  100.977  -75.430  46.076  1
266207  101.022  -75.437  46.048  1
266208  101.067  -75.469  46.021  1
266209  101.113  -75.501  45.994  1
266210  101.156  -75.533  45.965  1
266211  101.169  -75.548  45.935  1
266212  101.177  -75.556  45.904  1
266213  101.184  -75.565  45.870  1
266214  101.200  -75.558  45.837  1
266215  101.219  -75.547  45.805  1
266216  101.238  -75.536  45.772  1
266217  101.254  -75.538  45.740  1
266218  101.268  -75.547  45.708  1
266219  101.281  -75.556  45.675  1
266220  101.296  -75.565  45.642  1
266221  101.316  -75.571  45.611  1
266222  101.347  -75.574  45.580  1
266223  101.378  -75.578  45.550  1
266224  101.416  -75.604  45.521  1
266225  101.456  -75.637  45.492  1
266226  101.501  -75.671  45.463  1
266227  101.558  -75.710  45.434  1
266228  101.615  -75.748  45.406  1
266229  101.671  -75.787  45.378  1
266230  101.728  -75.825  45.351  1
266231  101.751  -75.838  45.325  1
266232  101.758  -75.841  45.298  1
266233  101.766  -75.844  45.272  1
266234  101.773  -75.847  45.246  1
266235  101.781  -75.850  45.221  1
266236  101.789  -75.852  45.195  1
266237  101.796  -75.855  45.171  1
266238  101.804  -75.858  45.146  1
266239  101.825  -75.875  45.121  1
266240  101.846  -75.895  45.096  1
266241  101.868  -75.911  45.072  1
266242  101.885  -75.912  45.047  1
266243  101.902  -75.912  45.023  1
266244  101.920  -75.912  45.000  1
266245  101.938  -75.913  44.976  1
266592  92.294  -73.413  54.714  1
266593  92.324  -73.423  54.706  1
266594  92.355  -73.434  54.699  1
266595  92.386  -73.444  54.692  1
266596  92.417  -73.454  54.685  1
266597  92.447  -73.465  54.678  1
266598  92.478  -73.474  54.672  1
266599  92.508  -73.485  54.665  1
266600  92.539  -73.496  54.659  1
266601  92.570  -73.506  54.652  1
266602  92.600  -73.516  54.646  1
266603  92.631  -73.527  54.641  1
266604  92.662  -73.537  54.635  1
266605  92.693  -73.547  54.630  1
266606  92.723  -73.558  54.625  1
266607  92.755  -73.568  54.620  1
266608  92.798  -73.579  54.617  1
266609  92.841  -73.590  54.615  1
266610  92.884  -73.601  54.614  1
266611  92.915  -73.601  54.615  1
266612  92.938  -73.593  54.617  1
266613  92.960  -73.584  54.619  1
266614  92.982  -73.576  54.623  1
266615  93.005  -73.567  54.626  1
266616  93.031  -73.570  54.630  1
266617  93.060  -73.576  54.634  1
266618  93.089  -73.582  54.637  1
266619  93.118  -73.588  54.641  1
266620  93.141  -73.585  54.644  1
266621  93.164  -73.582  54.646  1
266622  93.195  -73.590  54.645  1
266623  93.227  -73.600  54.643  1
266624  93.259  -73.609  54.640  1
266625  93.291  -73.618  54.637  1
266626  93.324  -73.627  54.634  1
266627  93.355  -73.636  54.630  1
266628  93.388  -73.645  54.625  1
266629  93.420  -73.651  54.620  1
266630  93.452  -73.652  54.613  1
266631  93.476  -73.655  54.605  1
266632  93.497  -73.658  54.598  1
266633  93.519  -73.661  54.591  1
266634  93.541  -73.664  54.585  1
266635  93.563  -73.668  54.578  1
266636  93.584  -73.671  54.571  1
266637  93.606  -73.674  54.565  1
266638  93.628  -73.677  54.558  1
266639  93.659  -73.678  54.550  1
266640  93.676  -73.679  54.538  1
266641  93.694  -73.680  54.521  1
266642  93.715  -73.679  54.500  1
266643  93.737  -73.675  54.479  1
266644  93.760  -73.672  54.459  1
266645  93.781  -73.667  54.439  1
266646  93.803  -73.663  54.422  1
266647  93.826  -73.659  54.407  1
266648  93.847  -73.655  54.391  1
266649  93.869  -73.652  54.374  1
266650  93.890  -73.650  54.358  1
266651  93.911  -73.647  54.342  1
266652  93.932  -73.644  54.326  1
266653  93.954  -73.642  54.309  1
266654  93.975  -73.639  54.293  1
266655  93.996  -73.637  54.275  1
266656  94.017  -73.634  54.254  1
266657  94.038  -73.631  54.232  1
266658  94.067  -73.630  54.211  1
266659  94.105  -73.628  54.191  1
266660  94.137  -73.630  54.172  1
266661  94.166  -73.633  54.152  1
266662  94.195  -73.637  54.130  1
266663  94.221  -73.644  54.107  1
266664  94.245  -73.655  54.084  1
266665  94.269  -73.666  54.060  1
266666  94.293  -73.676  54.033  1
266667  94.317  -73.687  54.006  1
266668  94.341  -73.698  53.978  1
266669  94.365  -73.709  53.949  1
266670  94.389  -73.719  53.920  1
266671  94.413  -73.730  53.890  1
266672  94.437  -73.741  53.860  1
266673  94.461  -73.752  53.828  1
266674  94.485  -73.763  53.799  1
266675  94.509  -73.773  53.767  1
266676  94.533  -73.784  53.735  1
266677  94.562  -73.805  53.703  1
266678  94.584  -73.817  53.673  1
266679  94.599  -73.822  53.643  1
266680  94.613  -73.821  53.614  1
266681  94.625  -73.806  53.586  1
266682  94.641  -73.803  53.560  1
266683  94.659  -73.801  53.535  1
266684  94.676  -73.799  53.513  1
266685  94.694  -73.797  53.492  1
266686  94.711  -73.794  53.476  1
266687  94.729  -73.792  53.462  1
266688  94.746  -73.790  53.448  1
266689  94.763  -73.788  53.429  1
266690  94.781  -73.785  53.405  1
266691  94.798  -73.783  53.377  1
266692  94.830  -73.790  53.346  1
266693  94.865  -73.799  53.311  1
266694  94.899  -73.808  53.272  1
266695  94.933  -73.816  53.230  1
266696  94.968  -73.825  53.186  1
266697  95.002  -73.833  53.141  1
266698  95.036  -73.842  53.095  1
266699  95.070  -73.850  53.050  1
266700  95.105  -73.859  53.005  1
266701  95.127  -73.813  52.962  1
266702  95.145  -73.779  52.921  1
266703  95.153  -73.768  52.880  1
266704  95.160  -73.756  52.839  1
266705  95.167  -73.745  52.798  1
266706  95.175  -73.734  52.761  1
266707  95.192  -73.728  52.724  1
266708  95.224  -73.732  52.689  1
266709  95.257  -73.736  52.654  1
266710  95.289  -73.740  52.619  1
266711  95.321  -73.744  52.585  1
266712  95.354  -73.748  52.549  1
266713  95.386  -73.758  52.511  1
266714  95.418  -73.772  52.473  1
266715  95.450  -73.786  52.436  1
266716  95.482  -73.800  52.401  1
266717  95.514  -73.815  52.365  1
266718  95.545  -73.829  52.329  1
266719  95.577  -73.839  52.294  1
266720  95.603  -73.827  52.260  1
266721  95.629  -73.816  52.226  1
266722  95.656  -73.803  52.194  1
266723  95.690  -73.799  52.163  1
266724  95.724  -73.794  52.132  1
266725  95.758  -73.791  52.100  1
266726  95.793  -73.787  52.067  1
266727  95.827  -73.782  52.033  1
266728  95.861  -73.778  51.999  1
266729  95.895  -73.774  51.965  1
266730  95.920  -73.769  51.932  1
266731  95.946  -73.764  51.898  1
266732  95.971  -73.759  51.864  1
266733  96.029  -73.750  51.831  1
266734  96.092  -73.743  51.796  1
266735  96.106  -73.731  51.763  1
266736  96.089  -73.728  51.730  1
266737  96.072  -73.731  51.696  1
266738  96.076  -73.739  51.661  1
266739  96.084  -73.749  51.626  1
266740  96.107  -73.773  51.591  1
266741  96.133  -73.800  51.555  1
266742  96.159  -73.826  51.521  1
266743  96.185  -73.854  51.488  1
266744  96.212  -73.880  51.454  1
266745  96.238  -73.894  51.422  1
266746  96.264  -73.901  51.389  1
266747  96.291  -73.908  51.356  1
266748  96.318  -73.915  51.324  1
266749  96.344  -73.922  51.293  1
266750  96.371  -73.929  51.263  1
266751  96.398  -73.935  51.234  1
266752  96.425  -73.942  51.205  1
266753  96.451  -73.949  51.178  1
266754  96.477  -73.956  51.153  1
266755  96.511  -73.957  51.128  1
266756  96.546  -73.957  51.104  1
266757  96.581  -73.956  51.081  1
266758  96.615  -73.956  51.060  1
266759  96.650  -73.956  51.041  1
266760  96.684  -73.956  51.023  1
266761  96.718  -73.961  51.006  1
266762  96.749  -73.975  50.990  1
266763  96.777  -73.987  50.975  1
266764  96.789  -73.992  50.962  1
266765  96.814  -74.010  50.951  1
266766  96.847  -74.027  50.943  1
266767  96.880  -74.043  50.937  1
266768  96.912  -74.060  50.932  1
266769  96.945  -74.076  50.928  1
266770  96.978  -74.092  50.927  1
266771  97.011  -74.108  50.929  1
266772  97.043  -74.124  50.933  1
266773  97.078  -74.124  50.939  1
266774  97.113  -74.117  50.950  1
266775  97.149  -74.110  50.959  1
266776  97.184  -74.102  50.967  1
266777  97.219  -74.095  50.974  1
266778  97.255  -74.088  50.974  1
266779  97.278  -74.073  50.968  1
266780  97.301  -74.059  50.959  1
266781  97.323  -74.045  50.949  1
266782  97.346  -74.030  50.933  1
266783  97.369  -74.016  50.919  1
266784  97.391  -74.010  50.903  1
266785  97.415  -74.016  50.887  1
266786  97.439  -74.022  50.870  1
266787  97.463  -74.029  50.853  1
266788  97.487  -74.035  50.833  1
266789  97.510  -74.041  50.811  1
266790  97.534  -74.048  50.784  1
266791  97.558  -74.054  50.755  1
266792  97.581  -74.060  50.723  1
266793  97.605  -74.067  50.690  1
266794  97.629  -74.073  50.655  1
266795  97.659  -74.089  50.614  1
266796  97.690  -74.104  50.569  1
266797  97.722  -74.120  50.520  1
266798  97.753  -74.136  50.471  1
266799  97.784  -74.151  50.424  1
266800  97.815  -74.167  50.377  1
266801  97.847  -74.183  50.330  1
266802  97.878  -74.198  50.279  1
266803  97.910  -74.213  50.228  1
266804  97.941  -74.223  50.176  1
266805  97.972  -74.234  50.125  1
266806  98.003  -74.245  50.080  1
266807  98.033  -74.260  50.036  1
266808  98.064  -74.274  49.989  1
266809  98.094  -74.288  49.936  1
266810  98.125  -74.302  49.876  1
266811  98.155  -74.317  49.815  1
266812  98.185  -74.330  49.753  1
266813  98.215  -74.345  49.694  1
266814  98.246  -74.359  49.636  1
266815  98.276  -74.373  49.577  1
266816  98.306  -74.387  49.518  1
266817  98.337  -74.402  49.460  1
266818  98.331  -74.410  49.404  1
266819  98.309  -74.417  49.348  1
266820  98.324  -74.436  49.292  1
266821  98.388  -74.473  49.235  1
266822  98.453  -74.510  49.176  1
266823  98.535  -74.512  49.116  1
266824  98.621  -74.501  49.057  1
266825  98.663  -74.580  49.001  1
266826  98.705  -74.664  48.948  1
266827  98.743  -74.740  48.899  1
266828  98.754  -74.750  48.850  1
266829  98.764  -74.760  48.799  1
266830  98.775  -74.770  48.748  1
266831  98.785  -74.780  48.696  1
266832  98.796  -74.791  48.644  1
266833  98.806  -74.800  48.591  1
266834  98.816  -74.810  48.537  1
266835  98.856  -74.791  48.483  1
266836  98.898  -74.769  48.430  1
266837  98.940  -74.747  48.376  1
266838  98.982  -74.725  48.324  1
266839  99.024  -74.701  48.273  1
266840  99.068  -74.656  48.222  1
266841  99.106  -74.624  48.172  1
266842  99.122  -74.639  48.124  1
266843  99.139  -74.653  48.076  1
266844  99.155  -74.667  48.029  1
266845  99.172  -74.681  47.981  1
266846  99.189  -74.696  47.935  1
266847  99.205  -74.709  47.889  1
266848  99.224  -74.727  47.844  1
266849  99.243  -74.744  47.799  1
266850  99.262  -74.760  47.755  1
266851  99.305  -74.794  47.712  1
266852  99.343  -74.816  47.669  1
266853  99.370  -74.823  47.628  1
266854  99.405  -74.833  47.589  1
266855  99.443  -74.844  47.551  1
266856  99.482  -74.855  47.512  1
266857  99.520  -74.866  47.473  1
266858  99.559  -74.877  47.435  1
266859  99.597  -74.888  47.396  1
266860  99.635  -74.899  47.358  1
266861  99.669  -74.900  47.321  1
266862  99.703  -74.900  47.287  1
266863  99.737  -74.901  47.254  1
266864  99.772  -74.902  47.221  1
266865  99.806  -74.903  47.190  1
266866  99.840  -74.903  47.160  1
266867  99.874  -74.904  47.131  1
266868  99.908  -74.905  47.104  1
266869  99.942  -74.906  47.078  1
266870  99.976  -74.907  47.051  1
266871  100.010  -74.908  47.024  1
266872  100.045  -74.909  46.998  1
266873  100.078  -74.925  46.973  1
266874  100.111  -74.963  46.948  1
266875  100.144  -75.001  46.926  1
266876  100.177  -75.038  46.904  1
266877  100.210  -75.076  46.882  1
266878  100.241  -75.109  46.859  1
266879  100.267  -75.123  46.834  1
266880  100.295  -75.138  46.809  1
266881  100.323  -75.154  46.782  1
266882  100.351  -75.170  46.756  1
266883  100.379  -75.186  46.730  1
266884  100.407  -75.202  46.703  1
266885  100.425  -75.219  46.677  1
266886  100.444  -75.235  46.649  1
266887  100.463  -75.251  46.621  1
266888  100.481  -75.267  46.594  1
266889  100.500  -75.284  46.568  1
266890  100.519  -75.300  46.540  1
266891  100.538  -75.317  46.512  1
266892  100.556  -75.333  46.484  1
266893  100.575  -75.349  46.454  1
266894  100.594  -75.365  46.425  1
266895  100.612  -75.382  46.397  1
266896  100.631  -75.398  46.369  1
266897  100.658  -75.408  46.342  1
266898  100.685  -75.419  46.313  1
266899  100.713  -75.427  46.286  1
266900  100.740  -75.421  46.258  1
266901  100.768  -75.416  46.229  1
266902  100.795  -75.411  46.203  1
266903  100.823  -75.405  46.177  1
266904  100.863  -75.403  46.149  1
266905  100.907  -75.400  46.120  1
266906  100.952  -75.396  46.091  1
266907  100.997  -75.393  46.063  1
266908  101.042  -75.404  46.036  1
266909  101.088  -75.436  46.009  1
266910  101.125  -75.470  45.983  1
266911  101.156  -75.504  45.955  1
266912  101.177  -75.525  45.925  1
266913  101.192  -75.540  45.893  1
266914  101.199  -75.549  45.860  1
266915  101.213  -75.546  45.826  1
266916  101.232  -75.535  45.793  1
266917  101.251  -75.524  45.760  1
266918  101.270  -75.513  45.726  1
266919  101.287  -75.508  45.693  1
266920  101.301  -75.518  45.660  1
266921  101.315  -75.527  45.628  1
266922  101.335  -75.533  45.596  1
266923  101.366  -75.536  45.566  1
266924  101.402  -75.556  45.536  1
266925  101.442  -75.589  45.506  1
266926  101.482  -75.621  45.477  1
266927  101.527  -75.656  45.448  1
266928  101.583  -75.694  45.419  1
266929  101.640  -75.732  45.391  1
266930  101.696  -75.771  45.363  1
266931  101.747  -75.804  45.336  1
266932  101.754  -75.807  45.309  1
266933  101.762  -75.810  45.283  1
266934  101.770  -75.812  45.256  1
266935  101.777  -75.815  45.231  1
266936  101.785  -75.818  45.205  1
266937  101.793  -75.821  45.179  1
266938  101.803  -75.827  45.155  1
266939  101.825  -75.847  45.130  1
266940  101.846  -75.865  45.105  1
266941  101.865  -75.871  45.079  1
266942  101.883  -75.872  45.056  1
266943  101.900  -75.872  45.032  1
266944  101.917  -75.872  45.008  1
266945  101.935  -75.873  44.984  1
266946  101.952  -75.874  44.960  1
267293  92.290  -73.383  54.722  1
267294  92.320  -73.394  54.714  1
267295  92.351  -73.404  54.706  1
267296  92.382  -73.415  54.698  1
267297  92.412  -73.425  54.691  1
267298  92.443  -73.435  54.683  1
267299  92.474  -73.446  54.676  1
267300  92.504  -73.456  54.668  1
267301  92.535  -73.466  54.661  1
267302  92.566  -73.477  54.655  1
267303  92.596  -73.487  54.650  1
267304  92.627  -73.497  54.644  1
267305  92.658  -73.508  54.639  1
267306  92.688  -73.518  54.632  1
267307  92.719  -73.528  54.625  1
267308  92.752  -73.539  54.620  1
267309  92.795  -73.550  54.616  1
267310  92.838  -73.561  54.612  1
267311  92.880  -73.571  54.611  1
267312  92.923  -73.583  54.611  1
267313  92.949  -73.577  54.612  1
267314  92.971  -73.568  54.614  1
267315  92.993  -73.560  54.618  1
267316  93.016  -73.552  54.622  1
267317  93.038  -73.543  54.625  1
267318  93.060  -73.534  54.630  1
267319  93.089  -73.541  54.633  1
267320  93.118  -73.547  54.636  1
267321  93.142  -73.546  54.640  1
267322  93.169  -73.549  54.640  1
267323  93.202  -73.558  54.640  1
267324  93.233  -73.567  54.638  1
267325  93.266  -73.576  54.634  1
267326  93.298  -73.585  54.631  1
267327  93.330  -73.594  54.629  1
267328  93.362  -73.603  54.624  1
267329  93.394  -73.612  54.619  1
267330  93.426  -73.622  54.612  1
267331  93.455  -73.626  54.605  1
267332  93.477  -73.629  54.597  1
267333  93.499  -73.632  54.588  1
267334  93.521  -73.636  54.578  1
267335  93.543  -73.639  54.570  1
267336  93.564  -73.642  54.561  1
267337  93.586  -73.645  54.553  1
267338  93.608  -73.648  54.545  1
267339  93.630  -73.651  54.538  1
267340  93.651  -73.655  54.530  1
267341  93.673  -73.656  54.520  1
267342  93.695  -73.652  54.505  1
267343  93.717  -73.648  54.485  1
267344  93.738  -73.646  54.464  1
267345  93.759  -73.644  54.444  1
267346  93.781  -73.640  54.423  1
267347  93.802  -73.638  54.405  1
267348  93.823  -73.636  54.388  1
267349  93.844  -73.633  54.371  1
267350  93.865  -73.631  54.353  1
267351  93.887  -73.628  54.335  1
267352  93.908  -73.625  54.318  1
267353  93.929  -73.623  54.300  1
267354  93.950  -73.620  54.283  1
267355  93.971  -73.618  54.265  1
267356  93.992  -73.615  54.245  1
267357  94.013  -73.612  54.225  1
267358  94.035  -73.610  54.203  1
267359  94.063  -73.608  54.183  1
267360  94.100  -73.607  54.163  1
267361  94.128  -73.611  54.143  1
267362  94.157  -73.614  54.123  1
267363  94.182  -73.625  54.099  1
267364  94.206  -73.635  54.074  1
267365  94.229  -73.646  54.048  1
267366  94.254  -73.657  54.023  1
267367  94.278  -73.668  53.996  1
267368  94.301  -73.678  53.969  1
267369  94.326  -73.689  53.942  1
267370  94.350  -73.700  53.912  1
267371  94.373  -73.711  53.884  1
267372  94.398  -73.722  53.855  1
267373  94.421  -73.732  53.825  1
267374  94.445  -73.743  53.795  1
267375  94.470  -73.754  53.765  1
267376  94.493  -73.765  53.735  1
267377  94.518  -73.775  53.703  1
267378  94.542  -73.786  53.672  1
267379  94.566  -73.796  53.642  1
267380  94.592  -73.803  53.614  1
267381  94.617  -73.811  53.586  1
267382  94.631  -73.813  53.559  1
267383  94.640  -73.807  53.533  1
267384  94.652  -73.794  53.510  1
267385  94.690  -73.781  53.488  1
267386  94.708  -73.779  53.468  1
267387  94.726  -73.776  53.451  1
267388  94.744  -73.774  53.436  1
267389  94.762  -73.772  53.422  1
267390  94.780  -73.769  53.404  1
267391  94.796  -73.769  53.380  1
267392  94.811  -73.769  53.352  1
267393  94.825  -73.769  53.319  1
267394  94.849  -73.772  53.283  1
267395  94.884  -73.781  53.241  1
267396  94.918  -73.789  53.199  1
267397  94.952  -73.798  53.156  1
267398  94.986  -73.807  53.111  1
267399  95.021  -73.815  53.068  1
267400  95.055  -73.823  53.024  1
267401  95.089  -73.832  52.982  1
267402  95.116  -73.807  52.941  1
267403  95.139  -73.763  52.901  1
267404  95.154  -73.735  52.862  1
267405  95.161  -73.724  52.823  1
267406  95.168  -73.713  52.784  1
267407  95.176  -73.701  52.748  1
267408  95.199  -73.700  52.713  1
267409  95.231  -73.703  52.678  1
267410  95.264  -73.707  52.645  1
267411  95.296  -73.711  52.610  1
267412  95.328  -73.716  52.575  1
267413  95.360  -73.730  52.540  1
267414  95.392  -73.744  52.503  1
267415  95.424  -73.759  52.465  1
267416  95.456  -73.773  52.429  1
267417  95.488  -73.787  52.395  1
267418  95.520  -73.801  52.359  1
267419  95.552  -73.816  52.324  1
267420  95.581  -73.816  52.290  1
267421  95.607  -73.803  52.256  1
267422  95.634  -73.791  52.224  1
267423  95.660  -73.780  52.193  1
267424  95.693  -73.774  52.163  1
267425  95.727  -73.770  52.132  1
267426  95.761  -73.766  52.101  1
267427  95.796  -73.762  52.068  1
267428  95.830  -73.757  52.034  1
267429  95.865  -73.753  52.000  1
267430  95.899  -73.749  51.967  1
267431  95.933  -73.745  51.934  1
267432  95.960  -73.740  51.902  1
267433  95.991  -73.734  51.869  1
267434  96.055  -73.726  51.836  1
267435  96.118  -73.718  51.802  1
267436  96.126  -73.719  51.768  1
267437  96.110  -73.722  51.734  1
267438  96.093  -73.725  51.699  1
267439  96.099  -73.734  51.665  1
267440  96.107  -73.744  51.630  1
267441  96.115  -73.754  51.596  1
267442  96.138  -73.778  51.561  1
267443  96.164  -73.805  51.528  1
267444  96.190  -73.832  51.495  1
267445  96.219  -73.856  51.462  1
267446  96.248  -73.865  51.428  1
267447  96.270  -73.876  51.395  1
267448  96.296  -73.884  51.362  1
267449  96.323  -73.891  51.330  1
267450  96.349  -73.897  51.300  1
267451  96.376  -73.904  51.269  1
267452  96.403  -73.911  51.239  1
267453  96.430  -73.918  51.212  1
267454  96.456  -73.925  51.185  1
267455  96.482  -73.932  51.159  1
267456  96.513  -73.935  51.133  1
267457  96.548  -73.935  51.108  1
267458  96.583  -73.935  51.084  1
267459  96.617  -73.935  51.063  1
267460  96.652  -73.935  51.043  1
267461  96.686  -73.935  51.024  1
267462  96.721  -73.935  51.007  1
267463  96.755  -73.936  50.991  1
267464  96.783  -73.948  50.976  1
267465  96.806  -73.962  50.962  1
267466  96.838  -73.978  50.950  1
267467  96.871  -73.995  50.941  1
267468  96.904  -74.010  50.934  1
267469  96.937  -74.026  50.927  1
267470  96.969  -74.043  50.923  1
267471  97.002  -74.059  50.921  1
267472  97.035  -74.075  50.923  1
267473  97.068  -74.092  50.927  1
267474  97.101  -74.097  50.932  1
267475  97.137  -74.089  50.942  1
267476  97.172  -74.082  50.950  1
267477  97.208  -74.075  50.958  1
267478  97.232  -74.061  50.965  1
267479  97.254  -74.047  50.965  1
267480  97.277  -74.032  50.958  1
267481  97.300  -74.018  50.948  1
267482  97.322  -74.004  50.936  1
267483  97.345  -73.989  50.919  1
267484  97.368  -73.980  50.904  1
267485  97.392  -73.987  50.889  1
267486  97.416  -73.993  50.875  1
267487  97.439  -73.999  50.857  1
267488  97.463  -74.006  50.841  1
267489  97.487  -74.012  50.823  1
267490  97.510  -74.018  50.804  1
267491  97.534  -74.025  50.780  1
267492  97.558  -74.031  50.751  1
267493  97.581  -74.037  50.721  1
267494  97.601  -74.043  50.690  1
267495  97.633  -74.048  50.653  1
267496  97.664  -74.061  50.611  1
267497  97.692  -74.077  50.564  1
267498  97.724  -74.093  50.514  1
267499  97.755  -74.109  50.463  1
267500  97.787  -74.124  50.416  1
267501  97.818  -74.140  50.370  1
267502  97.850  -74.156  50.322  1
267503  97.881  -74.171  50.270  1
267504  97.912  -74.187  50.218  1
267505  97.943  -74.198  50.167  1
267506  97.974  -74.208  50.120  1
267507  98.006  -74.219  50.077  1
267508  98.037  -74.230  50.032  1
267509  98.068  -74.242  49.983  1
267510  98.098  -74.257  49.929  1
267511  98.129  -74.270  49.866  1
267512  98.159  -74.285  49.804  1
267513  98.189  -74.299  49.742  1
267514  98.219  -74.313  49.681  1
267515  98.250  -74.327  49.624  1
267516  98.280  -74.342  49.566  1
267517  98.310  -74.355  49.508  1
267518  98.341  -74.370  49.450  1
267519  98.331  -74.378  49.392  1
267520  98.310  -74.384  49.336  1
267521  98.360  -74.416  49.279  1
267522  98.424  -74.453  49.221  1
267523  98.489  -74.490  49.162  1
267524  98.563  -74.508  49.104  1
267525  98.639  -74.468  49.046  1
267526  98.672  -74.453  48.989  1
267527  98.706  -74.443  48.936  1
267528  98.740  -74.678  48.886  1
267529  98.770  -74.690  48.836  1
267530  98.782  -74.700  48.785  1
267531  98.793  -74.709  48.735  1
267532  98.803  -74.720  48.683  1
267533  98.814  -74.730  48.631  1
267534  98.825  -74.740  48.579  1
267535  98.835  -74.750  48.524  1
267536  98.871  -74.734  48.470  1
267537  98.913  -74.712  48.417  1
267538  98.955  -74.690  48.365  1
267539  98.997  -74.667  48.313  1
267540  99.040  -74.645  48.262  1
267541  99.081  -74.623  48.212  1
267542  99.121  -74.599  48.162  1
267543  99.139  -74.614  48.114  1
267544  99.158  -74.631  48.065  1
267545  99.177  -74.648  48.017  1
267546  99.196  -74.665  47.970  1
267547  99.215  -74.681  47.924  1
267548  99.234  -74.699  47.878  1
267549  99.253  -74.715  47.833  1
267550  99.272  -74.733  47.788  1
267551  99.293  -74.751  47.745  1
267552  99.337  -74.783  47.701  1
267553  99.365  -74.790  47.659  1
267554  99.393  -74.797  47.619  1
267555  99.421  -74.803  47.581  1
267556  99.454  -74.812  47.544  1
267557  99.492  -74.824  47.507  1
267558  99.531  -74.834  47.468  1
267559  99.569  -74.846  47.429  1
267560  99.607  -74.857  47.391  1
267561  99.645  -74.868  47.352  1
267562  99.681  -74.872  47.314  1
267563  99.715  -74.874  47.280  1
267564  99.750  -74.875  47.247  1
267565  99.784  -74.875  47.215  1
267566  99.818  -74.876  47.184  1
267567  99.852  -74.877  47.154  1
267568  99.886  -74.878  47.124  1
267569  99.920  -74.878  47.096  1
267570  99.955  -74.879  47.071  1
267571  99.988  -74.880  47.043  1
267572  100.022  -74.881  47.015  1
267573  100.056  -74.895  46.989  1
267574  100.089  -74.910  46.964  1
267575  100.123  -74.937  46.938  1
267576  100.155  -74.975  46.916  1
267577  100.189  -75.013  46.894  1
267578  100.221  -75.051  46.872  1
267579  100.251  -75.079  46.848  1
267580  100.276  -75.091  46.823  1
267581  100.301  -75.104  46.798  1
267582  100.330  -75.120  46.771  1
267583  100.357  -75.135  46.744  1
267584  100.385  -75.151  46.719  1
267585  100.413  -75.167  46.693  1
267586  100.437  -75.184  46.666  1
267587  100.456  -75.200  46.638  1
267588  100.475  -75.217  46.611  1
267589  100.493  -75.232  46.584  1
267590  100.512  -75.249  46.559  1
267591  100.531  -75.265  46.530  1
267592  100.549  -75.282  46.502  1
267593  100.568  -75.298  46.473  1
267594  100.586  -75.314  46.444  1
267595  100.606  -75.330  46.415  1
267596  100.624  -75.347  46.388  1
267597  100.648  -75.359  46.360  1
267598  100.676  -75.370  46.332  1
267599  100.703  -75.380  46.303  1
267600  100.731  -75.387  46.274  1
267601  100.758  -75.383  46.246  1
267602  100.785  -75.377  46.219  1
267603  100.813  -75.372  46.193  1
267604  100.845  -75.367  46.166  1
267605  100.888  -75.365  46.138  1
267606  100.931  -75.362  46.109  1
267607  100.974  -75.360  46.081  1
267608  101.017  -75.357  46.053  1
267609  101.061  -75.371  46.026  1
267610  101.093  -75.405  46.000  1
267611  101.125  -75.440  45.972  1
267612  101.156  -75.473  45.942  1
267613  101.177  -75.494  45.910  1
267614  101.198  -75.515  45.878  1
267615  101.214  -75.533  45.845  1
267616  101.227  -75.533  45.812  1
267617  101.245  -75.523  45.779  1
267618  101.264  -75.512  45.746  1
267619  101.283  -75.501  45.713  1
267620  101.302  -75.490  45.679  1
267621  101.321  -75.480  45.645  1
267622  101.335  -75.488  45.612  1
267623  101.354  -75.495  45.581  1
267624  101.388  -75.508  45.551  1
267625  101.428  -75.540  45.521  1
267626  101.468  -75.574  45.492  1
267627  101.508  -75.606  45.462  1
267628  101.552  -75.640  45.433  1
267629  101.608  -75.678  45.404  1
267630  101.665  -75.716  45.376  1
267631  101.722  -75.755  45.348  1
267632  101.751  -75.773  45.320  1
267633  101.758  -75.776  45.294  1
267634  101.766  -75.778  45.267  1
267635  101.773  -75.781  45.241  1
267636  101.781  -75.784  45.215  1
267637  101.788  -75.787  45.190  1
267638  101.803  -75.797  45.164  1
267639  101.825  -75.817  45.139  1
267640  101.845  -75.830  45.115  1
267641  101.863  -75.831  45.089  1
267642  101.880  -75.831  45.063  1
267643  101.897  -75.831  45.040  1
267644  101.915  -75.832  45.016  1
267645  101.933  -75.833  44.993  1
267646  101.950  -75.834  44.968  1
267994  92.286  -73.355  54.730  1
267995  92.316  -73.365  54.722  1
267996  92.347  -73.375  54.713  1
267997  92.377  -73.385  54.704  1
267998  92.408  -73.396  54.696  1
267999  92.439  -73.406  54.688  1
268000  92.470  -73.416  54.680  1
268001  92.500  -73.427  54.672  1
268002  92.531  -73.437  54.664  1
268003  92.562  -73.447  54.658  1
268004  92.592  -73.458  54.653  1
268005  92.623  -73.468  54.647  1
268006  92.653  -73.478  54.640  1
268007  92.684  -73.489  54.632  1
268008  92.715  -73.499  54.625  1
268009  92.748  -73.509  54.619  1
268010  92.791  -73.521  54.614  1
268011  92.835  -73.531  54.610  1
268012  92.877  -73.543  54.608  1
268013  92.920  -73.553  54.607  1
268014  92.960  -73.562  54.607  1
268015  92.982  -73.553  54.609  1
268016  93.004  -73.544  54.612  1
268017  93.027  -73.536  54.615  1
268018  93.049  -73.528  54.620  1
268019  93.071  -73.519  54.624  1
268020  93.094  -73.511  54.627  1
268021  93.118  -73.506  54.631  1
268022  93.144  -73.508  54.633  1
268023  93.176  -73.517  54.635  1
268024  93.208  -73.526  54.634  1
268025  93.240  -73.535  54.631  1
268026  93.272  -73.544  54.629  1
268027  93.305  -73.555  54.625  1
268028  93.338  -73.566  54.621  1
268029  93.371  -73.578  54.617  1
268030  93.404  -73.589  54.611  1
268031  93.436  -73.600  54.604  1
268032  93.462  -73.606  54.597  1
268033  93.484  -73.609  54.588  1
268034  93.506  -73.612  54.577  1
268035  93.528  -73.616  54.565  1
268036  93.549  -73.619  54.555  1
268037  93.571  -73.622  54.544  1
268038  93.592  -73.625  54.534  1
268039  93.615  -73.628  54.525  1
268040  93.636  -73.631  54.517  1
268041  93.657  -73.633  54.509  1
268042  93.677  -73.631  54.500  1
268043  93.697  -73.628  54.486  1
268044  93.717  -73.626  54.468  1
268045  93.737  -73.624  54.448  1
268046  93.757  -73.622  54.427  1
268047  93.777  -73.619  54.407  1
268048  93.798  -73.616  54.388  1
268049  93.819  -73.614  54.370  1
268050  93.840  -73.612  54.351  1
268051  93.861  -73.609  54.332  1
268052  93.883  -73.606  54.314  1
268053  93.904  -73.604  54.295  1
268054  93.925  -73.601  54.276  1
268055  93.946  -73.599  54.257  1
268056  93.968  -73.597  54.239  1
268057  93.989  -73.593  54.219  1
268058  94.010  -73.591  54.199  1
268059  94.031  -73.589  54.179  1
268060  94.059  -73.587  54.158  1
268061  94.090  -73.588  54.136  1
268062  94.118  -73.594  54.114  1
268063  94.142  -73.605  54.093  1
268064  94.166  -73.615  54.068  1
268065  94.190  -73.627  54.043  1
268066  94.214  -73.637  54.017  1
268067  94.238  -73.648  53.991  1
268068  94.262  -73.659  53.964  1
268069  94.286  -73.670  53.937  1
268070  94.310  -73.681  53.909  1
268071  94.334  -73.691  53.881  1
268072  94.359  -73.700  53.852  1
268073  94.385  -73.707  53.823  1
268074  94.410  -73.715  53.793  1
268075  94.436  -73.722  53.764  1
268076  94.462  -73.729  53.734  1
268077  94.488  -73.737  53.704  1
268078  94.513  -73.744  53.673  1
268079  94.539  -73.752  53.643  1
268080  94.565  -73.759  53.614  1
268081  94.591  -73.766  53.586  1
268082  94.616  -73.774  53.559  1
268083  94.642  -73.781  53.533  1
268084  94.649  -73.780  53.508  1
268085  94.656  -73.779  53.485  1
268086  94.663  -73.778  53.464  1
268087  94.689  -73.774  53.444  1
268088  94.733  -73.762  53.425  1
268089  94.769  -73.756  53.409  1
268090  94.784  -73.756  53.394  1
268091  94.799  -73.756  53.377  1
268092  94.814  -73.756  53.353  1
268093  94.828  -73.756  53.324  1
268094  94.842  -73.756  53.290  1
268095  94.857  -73.756  53.252  1
268096  94.871  -73.756  53.210  1
268097  94.902  -73.763  53.168  1
268098  94.936  -73.771  53.126  1
268099  94.970  -73.780  53.083  1
268100  95.004  -73.788  53.041  1
268101  95.039  -73.797  53.000  1
268102  95.073  -73.805  52.961  1
268103  95.105  -73.802  52.921  1
268104  95.128  -73.756  52.882  1
268105  95.150  -73.712  52.844  1
268106  95.162  -73.691  52.807  1
268107  95.169  -73.680  52.770  1
268108  95.177  -73.669  52.736  1
268109  95.206  -73.671  52.702  1
268110  95.239  -73.675  52.669  1
268111  95.271  -73.678  52.636  1
268112  95.303  -73.688  52.601  1
268113  95.335  -73.702  52.566  1
268114  95.367  -73.716  52.531  1
268115  95.399  -73.731  52.495  1
268116  95.430  -73.745  52.458  1
268117  95.463  -73.760  52.423  1
268118  95.494  -73.774  52.389  1
268119  95.527  -73.788  52.353  1
268120  95.558  -73.802  52.319  1
268121  95.585  -73.791  52.286  1
268122  95.612  -73.780  52.253  1
268123  95.638  -73.768  52.222  1
268124  95.665  -73.756  52.192  1
268125  95.696  -73.749  52.163  1
268126  95.730  -73.745  52.133  1
268127  95.764  -73.741  52.103  1
268128  95.799  -73.737  52.070  1
268129  95.833  -73.732  52.037  1
268130  95.868  -73.728  52.003  1
268131  95.902  -73.724  51.970  1
268132  95.936  -73.720  51.937  1
268133  95.970  -73.716  51.905  1
268134  96.022  -73.727  51.872  1
268135  96.094  -73.754  51.840  1
268136  96.111  -73.739  51.806  1
268137  96.128  -73.725  51.772  1
268138  96.130  -73.717  51.738  1
268139  96.115  -73.721  51.703  1
268140  96.123  -73.730  51.668  1
268141  96.131  -73.740  51.635  1
268142  96.138  -73.750  51.601  1
268143  96.147  -73.760  51.566  1
268144  96.169  -73.783  51.533  1
268145  96.195  -73.810  51.500  1
268146  96.240  -73.819  51.467  1
268147  96.262  -73.831  51.433  1
268148  96.285  -73.843  51.400  1
268149  96.306  -73.854  51.368  1
268150  96.328  -73.866  51.336  1
268151  96.355  -73.873  51.306  1
268152  96.381  -73.880  51.275  1
268153  96.408  -73.887  51.246  1
268154  96.435  -73.894  51.217  1
268155  96.461  -73.901  51.190  1
268156  96.487  -73.907  51.164  1
268157  96.516  -73.913  51.137  1
268158  96.550  -73.913  51.112  1
268159  96.585  -73.913  51.087  1
268160  96.619  -73.913  51.065  1
268161  96.654  -73.913  51.044  1
268162  96.688  -73.913  51.025  1
268163  96.723  -73.913  51.008  1
268164  96.757  -73.913  50.992  1
268165  96.791  -73.914  50.977  1
268166  96.825  -73.930  50.962  1
268167  96.861  -73.945  50.949  1
268168  96.895  -73.961  50.940  1
268169  96.928  -73.978  50.931  1
268170  96.961  -73.994  50.925  1
268171  96.994  -74.010  50.920  1
268172  97.026  -74.026  50.917  1
268173  97.058  -74.042  50.918  1
268174  97.091  -74.059  50.920  1
268175  97.125  -74.070  50.925  1
268176  97.160  -74.062  50.933  1
268177  97.186  -74.049  50.940  1
268178  97.209  -74.035  50.946  1
268179  97.231  -74.020  50.953  1
268180  97.254  -74.006  50.953  1
268181  97.277  -73.991  50.948  1
268182  97.299  -73.977  50.938  1
268183  97.321  -73.962  50.925  1
268184  97.345  -73.951  50.909  1
268185  97.368  -73.957  50.894  1
268186  97.392  -73.964  50.880  1
268187  97.416  -73.970  50.867  1
268188  97.439  -73.976  50.850  1
268189  97.463  -73.983  50.834  1
268190  97.487  -73.989  50.817  1
268191  97.510  -73.995  50.799  1
268192  97.533  -74.002  50.776  1
268193  97.552  -74.007  50.749  1
268194  97.572  -74.013  50.719  1
268195  97.599  -74.019  50.686  1
268196  97.640  -74.023  50.648  1
268197  97.676  -74.032  50.603  1
268198  97.703  -74.048  50.554  1
268199  97.729  -74.066  50.503  1
268200  97.758  -74.082  50.452  1
268201  97.789  -74.098  50.403  1
268202  97.821  -74.114  50.357  1
268203  97.852  -74.129  50.310  1
268204  97.883  -74.145  50.259  1
268205  97.915  -74.161  50.209  1
268206  97.946  -74.172  50.162  1
268207  97.977  -74.183  50.117  1
268208  98.008  -74.193  50.074  1
268209  98.039  -74.204  50.028  1
268210  98.071  -74.214  49.978  1
268211  98.102  -74.225  49.922  1
268212  98.132  -74.239  49.859  1
268213  98.163  -74.253  49.795  1
268214  98.193  -74.267  49.732  1
268215  98.223  -74.282  49.669  1
268216  98.254  -74.295  49.611  1
268217  98.284  -74.310  49.553  1
268218  98.314  -74.324  49.496  1
268219  98.345  -74.339  49.439  1
268220  98.332  -74.346  49.382  1
268221  98.331  -74.360  49.325  1
268222  98.395  -74.397  49.267  1
268223  98.459  -74.434  49.210  1
268224  98.524  -74.471  49.151  1
268225  98.571  -74.487  49.092  1
268226  98.623  -74.428  49.034  1
268227  98.655  -74.415  48.976  1
268228  98.707  -74.433  48.923  1
268229  98.736  -74.613  48.872  1
268230  98.765  -74.632  48.821  1
268231  98.795  -74.640  48.771  1
268232  98.811  -74.649  48.720  1
268233  98.822  -74.659  48.669  1
268234  98.833  -74.669  48.618  1
268235  98.843  -74.679  48.566  1
268236  98.854  -74.690  48.511  1
268237  98.886  -74.677  48.457  1
268238  98.929  -74.654  48.404  1
268239  98.971  -74.632  48.352  1
268240  99.013  -74.609  48.301  1
268241  99.055  -74.587  48.251  1
268242  99.096  -74.567  48.201  1
268243  99.129  -74.571  48.151  1
268244  99.153  -74.592  48.102  1
268245  99.177  -74.612  48.054  1
268246  99.201  -74.634  48.006  1
268247  99.225  -74.654  47.958  1
268248  99.244  -74.671  47.912  1
268249  99.264  -74.687  47.867  1
268250  99.283  -74.705  47.822  1
268251  99.301  -74.722  47.777  1
268252  99.329  -74.744  47.734  1
268253  99.360  -74.756  47.691  1
268254  99.387  -74.763  47.650  1
268255  99.416  -74.770  47.611  1
268256  99.443  -74.777  47.573  1
268257  99.472  -74.784  47.537  1
268258  99.502  -74.792  47.500  1
268259  99.541  -74.803  47.462  1
268260  99.579  -74.815  47.423  1
268261  99.618  -74.825  47.384  1
268262  99.656  -74.837  47.346  1
268263  99.693  -74.846  47.308  1
268264  99.727  -74.847  47.274  1
268265  99.762  -74.847  47.241  1
268266  99.796  -74.848  47.209  1
268267  99.830  -74.849  47.178  1
268268  99.864  -74.850  47.147  1
268269  99.898  -74.850  47.117  1
268270  99.932  -74.851  47.090  1
268271  99.967  -74.852  47.063  1
268272  100.000  -74.853  47.035  1
268273  100.034  -74.866  47.007  1
268274  100.067  -74.881  46.980  1
268275  100.101  -74.897  46.955  1
268276  100.134  -74.912  46.929  1
268277  100.167  -74.950  46.906  1
268278  100.200  -74.988  46.885  1
268279  100.233  -75.026  46.863  1
268280  100.261  -75.048  46.838  1
268281  100.286  -75.060  46.813  1
268282  100.311  -75.073  46.787  1
268283  100.336  -75.085  46.760  1
268284  100.364  -75.101  46.734  1
268285  100.392  -75.117  46.708  1
268286  100.420  -75.133  46.682  1
268287  100.448  -75.149  46.655  1
268288  100.468  -75.165  46.628  1
268289  100.487  -75.182  46.601  1
268290  100.505  -75.198  46.574  1
268291  100.524  -75.214  46.547  1
268292  100.543  -75.230  46.520  1
268293  100.561  -75.247  46.492  1
268294  100.580  -75.263  46.464  1
268295  100.599  -75.279  46.435  1
268296  100.617  -75.295  46.405  1
268297  100.639  -75.310  46.377  1
268298  100.666  -75.320  46.350  1
268299  100.693  -75.331  46.322  1
268300  100.721  -75.342  46.294  1
268301  100.748  -75.348  46.265  1
268302  100.776  -75.344  46.237  1
268303  100.803  -75.339  46.209  1
268304  100.831  -75.333  46.183  1
268305  100.870  -75.330  46.156  1
268306  100.913  -75.327  46.127  1
268307  100.956  -75.325  46.099  1
268308  100.998  -75.322  46.071  1
268309  101.037  -75.324  46.043  1
268310  101.061  -75.342  46.015  1
268311  101.094  -75.376  45.988  1
268312  101.126  -75.411  45.959  1
268313  101.155  -75.442  45.928  1
268314  101.176  -75.463  45.896  1
268315  101.197  -75.484  45.862  1
268316  101.218  -75.506  45.830  1
268317  101.238  -75.516  45.798  1
268318  101.258  -75.508  45.765  1
268319  101.277  -75.499  45.732  1
268320  101.296  -75.489  45.698  1
268321  101.315  -75.478  45.664  1
268322  101.334  -75.467  45.630  1
268323  101.353  -75.457  45.597  1
268324  101.375  -75.460  45.566  1
268325  101.415  -75.493  45.536  1
268326  101.455  -75.525  45.506  1
268327  101.494  -75.558  45.477  1
268328  101.534  -75.590  45.447  1
268329  101.577  -75.624  45.417  1
268330  101.633  -75.662  45.388  1
268331  101.690  -75.701  45.360  1
268332  101.747  -75.739  45.332  1
268333  101.754  -75.742  45.304  1
268334  101.762  -75.744  45.278  1
268335  101.769  -75.747  45.251  1
268336  101.777  -75.750  45.225  1
268337  101.785  -75.753  45.199  1
268338  101.803  -75.768  45.174  1
268339  101.825  -75.787  45.148  1
268340  101.842  -75.790  45.123  1
268341  101.860  -75.790  45.098  1
268342  101.878  -75.791  45.073  1
268343  101.895  -75.791  45.048  1
268344  101.912  -75.792  45.024  1
268345  101.930  -75.793  45.000  1
268346  101.947  -75.793  44.976  1
268347  101.965  -75.793  44.952  1
268695  92.281  -73.325  54.738  1
268696  92.312  -73.336  54.729  1
268697  92.343  -73.346  54.720  1
268698  92.373  -73.356  54.711  1
268699  92.404  -73.367  54.701  1
268700  92.435  -73.377  54.692  1
268701  92.465  -73.387  54.684  1
268702  92.496  -73.398  54.675  1
268703  92.526  -73.408  54.667  1
268704  92.557  -73.418  54.661  1
268705  92.588  -73.428  54.655  1
268706  92.619  -73.439  54.649  1
268707  92.649  -73.449  54.641  1
268708  92.680  -73.459  54.631  1
268709  92.711  -73.470  54.624  1
268710  92.745  -73.481  54.617  1
268711  92.788  -73.491  54.612  1
268712  92.831  -73.503  54.608  1
268713  92.874  -73.513  54.605  1
268714  92.917  -73.524  54.603  1
268715  92.960  -73.535  54.602  1
268716  92.993  -73.537  54.604  1
268717  93.015  -73.529  54.606  1
268718  93.038  -73.521  54.610  1
268719  93.060  -73.512  54.613  1
268720  93.082  -73.503  54.617  1
268721  93.105  -73.495  54.620  1
268722  93.127  -73.487  54.624  1
268723  93.154  -73.484  54.626  1
268724  93.186  -73.496  54.628  1
268725  93.219  -73.507  54.626  1
268726  93.252  -73.518  54.624  1
268727  93.285  -73.530  54.621  1
268728  93.318  -73.541  54.617  1
268729  93.351  -73.553  54.613  1
268730  93.384  -73.564  54.609  1
268731  93.417  -73.575  54.603  1
268732  93.450  -73.587  54.596  1
268733  93.472  -73.590  54.587  1
268734  93.493  -73.593  54.577  1
268735  93.515  -73.596  54.565  1
268736  93.537  -73.600  54.552  1
268737  93.559  -73.603  54.540  1
268738  93.580  -73.606  54.529  1
268739  93.602  -73.608  54.517  1
268740  93.622  -73.610  54.507  1
268741  93.643  -73.611  54.497  1
268742  93.663  -73.609  54.488  1
268743  93.683  -73.606  54.478  1
268744  93.703  -73.604  54.465  1
268745  93.723  -73.602  54.448  1
268746  93.744  -73.600  54.429  1
268747  93.764  -73.597  54.409  1
268748  93.783  -73.595  54.390  1
268749  93.803  -73.593  54.371  1
268750  93.824  -73.590  54.352  1
268751  93.844  -73.588  54.332  1
268752  93.863  -73.586  54.312  1
268753  93.884  -73.584  54.292  1
268754  93.904  -73.581  54.273  1
268755  93.924  -73.579  54.254  1
268756  93.944  -73.577  54.233  1
268757  93.964  -73.575  54.214  1
268758  93.985  -73.572  54.195  1
268759  94.006  -73.570  54.175  1
268760  94.028  -73.567  54.156  1
268761  94.053  -73.565  54.134  1
268762  94.078  -73.575  54.110  1
268763  94.102  -73.586  54.086  1
268764  94.126  -73.597  54.063  1
268765  94.152  -73.604  54.038  1
268766  94.178  -73.611  54.012  1
268767  94.203  -73.618  53.986  1
268768  94.229  -73.626  53.959  1
268769  94.255  -73.634  53.933  1
268770  94.281  -73.640  53.906  1
268771  94.307  -73.648  53.878  1
268772  94.332  -73.656  53.850  1
268773  94.358  -73.663  53.822  1
268774  94.384  -73.670  53.793  1
268775  94.409  -73.678  53.763  1
268776  94.435  -73.685  53.735  1
268777  94.461  -73.692  53.705  1
268778  94.486  -73.700  53.675  1
268779  94.512  -73.707  53.646  1
268780  94.538  -73.715  53.616  1
268781  94.564  -73.722  53.588  1
268782  94.590  -73.729  53.560  1
268783  94.615  -73.737  53.534  1
268784  94.641  -73.744  53.509  1
268785  94.660  -73.748  53.484  1
268786  94.667  -73.747  53.461  1
268787  94.674  -73.747  53.440  1
268788  94.683  -73.746  53.419  1
268789  94.711  -73.745  53.400  1
268790  94.754  -73.733  53.381  1
268791  94.790  -73.728  53.363  1
268792  94.805  -73.741  53.344  1
268793  94.829  -73.744  53.319  1
268794  94.845  -73.744  53.290  1
268795  94.859  -73.744  53.257  1
268796  94.874  -73.743  53.219  1
268797  94.888  -73.743  53.179  1
268798  94.903  -73.743  53.139  1
268799  94.920  -73.744  53.099  1
268800  94.955  -73.753  53.058  1
268801  94.989  -73.761  53.018  1
268802  95.023  -73.770  52.979  1
268803  95.057  -73.778  52.941  1
268804  95.092  -73.787  52.902  1
268805  95.116  -73.751  52.864  1
268806  95.139  -73.706  52.827  1
268807  95.162  -73.661  52.792  1
268808  95.170  -73.647  52.757  1
268809  95.181  -73.638  52.725  1
268810  95.213  -73.642  52.692  1
268811  95.246  -73.646  52.659  1
268812  95.277  -73.660  52.627  1
268813  95.310  -73.675  52.592  1
268814  95.341  -73.689  52.557  1
268815  95.373  -73.703  52.523  1
268816  95.405  -73.717  52.488  1
268817  95.437  -73.731  52.451  1
268818  95.469  -73.746  52.416  1
268819  95.501  -73.760  52.382  1
268820  95.533  -73.774  52.347  1
268821  95.563  -73.780  52.314  1
268822  95.590  -73.768  52.282  1
268823  95.616  -73.756  52.251  1
268824  95.642  -73.744  52.220  1
268825  95.669  -73.732  52.192  1
268826  95.699  -73.724  52.164  1
268827  95.733  -73.720  52.135  1
268828  95.767  -73.716  52.104  1
268829  95.802  -73.712  52.074  1
268830  95.836  -73.708  52.041  1
268831  95.871  -73.703  52.007  1
268832  95.905  -73.700  51.974  1
268833  95.943  -73.702  51.941  1
268834  96.008  -73.750  51.908  1
268835  96.060  -73.783  51.876  1
268836  96.077  -73.769  51.843  1
268837  96.094  -73.754  51.809  1
268838  96.111  -73.740  51.775  1
268839  96.128  -73.725  51.741  1
268840  96.138  -73.716  51.707  1
268841  96.147  -73.726  51.672  1
268842  96.154  -73.735  51.638  1
268843  96.162  -73.745  51.605  1
268844  96.170  -73.755  51.572  1
268845  96.178  -73.765  51.538  1
268846  96.201  -73.787  51.505  1
268847  96.255  -73.785  51.472  1
268848  96.277  -73.797  51.438  1
268849  96.299  -73.809  51.406  1
268850  96.321  -73.820  51.373  1
268851  96.343  -73.832  51.342  1
268852  96.365  -73.844  51.311  1
268853  96.387  -73.856  51.281  1
268854  96.413  -73.863  51.252  1
268855  96.440  -73.869  51.223  1
268856  96.466  -73.876  51.195  1
268857  96.493  -73.883  51.168  1
268858  96.519  -73.890  51.142  1
268859  96.552  -73.891  51.115  1
268860  96.587  -73.891  51.090  1
268861  96.621  -73.891  51.067  1
268862  96.656  -73.891  51.046  1
268863  96.690  -73.891  51.027  1
268864  96.725  -73.891  51.010  1
268865  96.758  -73.888  50.993  1
268866  96.791  -73.890  50.977  1
268867  96.820  -73.903  50.962  1
268868  96.854  -73.918  50.949  1
268869  96.890  -73.933  50.939  1
268870  96.926  -73.949  50.930  1
268871  96.961  -73.965  50.923  1
268872  96.997  -73.981  50.918  1
268873  97.032  -73.996  50.914  1
268874  97.068  -74.012  50.913  1
268875  97.103  -74.028  50.914  1
268876  97.138  -74.036  50.917  1
268877  97.163  -74.023  50.924  1
268878  97.185  -74.008  50.930  1
268879  97.208  -73.994  50.935  1
268880  97.230  -73.979  50.939  1
268881  97.253  -73.965  50.939  1
268882  97.276  -73.950  50.936  1
268883  97.298  -73.935  50.928  1
268884  97.321  -73.922  50.915  1
268885  97.345  -73.929  50.899  1
268886  97.368  -73.935  50.886  1
268887  97.392  -73.941  50.874  1
268888  97.416  -73.948  50.862  1
268889  97.439  -73.954  50.846  1
268890  97.463  -73.960  50.831  1
268891  97.485  -73.966  50.815  1
268892  97.504  -73.972  50.797  1
268893  97.523  -73.977  50.775  1
268894  97.543  -73.983  50.747  1
268895  97.567  -73.988  50.716  1
268896  97.606  -73.994  50.681  1
268897  97.646  -73.999  50.641  1
268898  97.686  -74.004  50.594  1
268899  97.714  -74.020  50.543  1
268900  97.740  -74.036  50.491  1
268901  97.767  -74.054  50.441  1
268902  97.793  -74.070  50.392  1
268903  97.823  -74.086  50.345  1
268904  97.855  -74.102  50.299  1
268905  97.886  -74.118  50.249  1
268906  97.918  -74.133  50.203  1
268907  97.949  -74.145  50.158  1
268908  97.980  -74.157  50.115  1
268909  98.011  -74.167  50.071  1
268910  98.042  -74.178  50.024  1
268911  98.073  -74.189  49.972  1
268912  98.104  -74.199  49.914  1
268913  98.136  -74.210  49.852  1
268914  98.167  -74.222  49.787  1
268915  98.197  -74.236  49.722  1
268916  98.227  -74.250  49.658  1
268917  98.257  -74.264  49.598  1
268918  98.288  -74.279  49.539  1
268919  98.318  -74.292  49.482  1
268920  98.349  -74.307  49.427  1
268921  98.332  -74.314  49.371  1
268922  98.366  -74.340  49.314  1
268923  98.431  -74.377  49.256  1
268924  98.495  -74.415  49.199  1
268925  98.528  -74.435  49.139  1
268926  98.567  -74.422  49.079  1
268927  98.606  -74.389  49.020  1
268928  98.649  -74.390  48.963  1
268929  98.708  -74.441  48.908  1
268930  98.733  -74.547  48.857  1
268931  98.759  -74.574  48.807  1
268932  98.790  -74.582  48.757  1
268933  98.820  -74.590  48.705  1
268934  98.840  -74.599  48.654  1
268935  98.851  -74.609  48.603  1
268936  98.861  -74.619  48.552  1
268937  98.872  -74.629  48.498  1
268938  98.902  -74.619  48.444  1
268939  98.944  -74.596  48.391  1
268940  98.986  -74.574  48.340  1
268941  99.028  -74.552  48.288  1
268942  99.068  -74.536  48.239  1
268943  99.100  -74.540  48.189  1
268944  99.133  -74.546  48.139  1
268945  99.158  -74.564  48.089  1
268946  99.183  -74.584  48.041  1
268947  99.207  -74.605  47.994  1
268948  99.231  -74.626  47.947  1
268949  99.255  -74.646  47.900  1
268950  99.279  -74.667  47.856  1
268951  99.303  -74.687  47.811  1
268952  99.328  -74.709  47.767  1
268953  99.354  -74.722  47.725  1
268954  99.382  -74.730  47.682  1
268955  99.410  -74.737  47.641  1
268956  99.438  -74.744  47.602  1
268957  99.466  -74.750  47.564  1
268958  99.494  -74.758  47.528  1
268959  99.522  -74.765  47.491  1
268960  99.551  -74.772  47.453  1
268961  99.589  -74.783  47.415  1
268962  99.628  -74.794  47.377  1
268963  99.666  -74.806  47.339  1
268964  99.704  -74.816  47.301  1
268965  99.739  -74.819  47.268  1
268966  99.774  -74.820  47.235  1
268967  99.808  -74.821  47.203  1
268968  99.842  -74.822  47.172  1
268969  99.876  -74.822  47.141  1
268970  99.910  -74.823  47.111  1
268971  99.944  -74.825  47.082  1
268972  99.979  -74.825  47.056  1
268973  100.012  -74.838  47.028  1
268974  100.045  -74.853  47.000  1
268975  100.079  -74.868  46.974  1
268976  100.112  -74.883  46.948  1
268977  100.145  -74.898  46.921  1
268978  100.179  -74.924  46.899  1
268979  100.212  -74.962  46.877  1
268980  100.245  -75.000  46.855  1
268981  100.271  -75.017  46.830  1
268982  100.296  -75.029  46.804  1
268983  100.321  -75.042  46.778  1
268984  100.346  -75.054  46.751  1
268985  100.370  -75.066  46.724  1
268986  100.398  -75.082  46.698  1
268987  100.426  -75.098  46.672  1
268988  100.454  -75.114  46.645  1
268989  100.480  -75.130  46.618  1
268990  100.498  -75.147  46.591  1
268991  100.517  -75.163  46.563  1
268992  100.536  -75.179  46.536  1
268993  100.554  -75.195  46.509  1
268994  100.573  -75.212  46.482  1
268995  100.592  -75.228  46.453  1
268996  100.611  -75.245  46.424  1
268997  100.629  -75.261  46.394  1
268998  100.656  -75.271  46.367  1
268999  100.684  -75.282  46.340  1
269000  100.711  -75.292  46.312  1
269001  100.739  -75.303  46.284  1
269002  100.766  -75.310  46.256  1
269003  100.793  -75.305  46.228  1
269004  100.821  -75.300  46.200  1
269005  100.852  -75.295  46.174  1
269006  100.895  -75.292  46.145  1
269007  100.937  -75.290  46.116  1
269008  100.980  -75.287  46.088  1
269009  101.018  -75.289  46.061  1
269010  101.042  -75.305  46.033  1
269011  101.066  -75.321  46.004  1
269012  101.094  -75.346  45.975  1
269013  101.126  -75.381  45.944  1
269014  101.155  -75.411  45.913  1
269015  101.176  -75.432  45.880  1
269016  101.196  -75.453  45.847  1
269017  101.214  -75.460  45.815  1
269018  101.231  -75.450  45.782  1
269019  101.251  -75.442  45.749  1
269020  101.271  -75.434  45.716  1
269021  101.291  -75.426  45.682  1
269022  101.311  -75.418  45.648  1
269023  101.336  -75.420  45.615  1
269024  101.370  -75.435  45.582  1
269025  101.403  -75.451  45.551  1
269026  101.441  -75.477  45.520  1
269027  101.481  -75.510  45.490  1
269028  101.521  -75.543  45.461  1
269029  101.560  -75.575  45.430  1
269030  101.602  -75.609  45.402  1
269031  101.659  -75.646  45.373  1
269032  101.715  -75.685  45.344  1
269033  101.750  -75.708  45.317  1
269034  101.758  -75.710  45.290  1
269035  101.766  -75.713  45.263  1
269036  101.773  -75.716  45.236  1
269037  101.781  -75.718  45.209  1
269038  101.803  -75.738  45.183  1
269039  101.823  -75.749  45.158  1
269040  101.840  -75.749  45.133  1
269041  101.857  -75.750  45.107  1
269042  101.875  -75.751  45.082  1
269043  101.893  -75.751  45.057  1
269044  101.910  -75.752  45.032  1
269045  101.927  -75.753  45.008  1
269046  101.945  -75.753  44.984  1
269047  101.962  -75.753  44.960  1
269396  92.277  -73.296  54.747  1
269397  92.308  -73.306  54.737  1
269398  92.339  -73.317  54.727  1
269399  92.369  -73.327  54.717  1
269400  92.400  -73.337  54.706  1
269401  92.430  -73.348  54.697  1
269402  92.461  -73.358  54.688  1
269403  92.492  -73.368  54.678  1
269404  92.522  -73.379  54.670  1
269405  92.553  -73.389  54.662  1
269406  92.584  -73.399  54.655  1
269407  92.615  -73.410  54.648  1
269408  92.645  -73.420  54.639  1
269409  92.676  -73.430  54.630  1
269410  92.706  -73.440  54.622  1
269411  92.742  -73.451  54.615  1
269412  92.785  -73.462  54.610  1
269413  92.828  -73.473  54.605  1
269414  92.871  -73.484  54.602  1
269415  92.914  -73.495  54.600  1
269416  92.956  -73.506  54.600  1
269417  93.000  -73.517  54.601  1
269418  93.026  -73.513  54.603  1
269419  93.049  -73.505  54.605  1
269420  93.071  -73.496  54.607  1
269421  93.093  -73.488  54.609  1
269422  93.116  -73.479  54.612  1
269423  93.138  -73.471  54.615  1
269424  93.163  -73.466  54.619  1
269425  93.202  -73.479  54.619  1
269426  93.234  -73.491  54.618  1
269427  93.266  -73.504  54.615  1
269428  93.298  -73.515  54.612  1
269429  93.331  -73.528  54.608  1
269430  93.364  -73.539  54.604  1
269431  93.397  -73.550  54.600  1
269432  93.430  -73.562  54.594  1
269433  93.459  -73.570  54.586  1
269434  93.481  -73.573  54.576  1
269435  93.503  -73.576  54.565  1
269436  93.524  -73.579  54.552  1
269437  93.546  -73.582  54.538  1
269438  93.567  -73.584  54.526  1
269439  93.588  -73.587  54.514  1
269440  93.609  -73.589  54.501  1
269441  93.630  -73.589  54.490  1
269442  93.649  -73.587  54.479  1
269443  93.670  -73.584  54.468  1
269444  93.690  -73.582  54.457  1
269445  93.710  -73.580  54.444  1
269446  93.730  -73.578  54.427  1
269447  93.750  -73.575  54.409  1
269448  93.770  -73.574  54.390  1
269449  93.790  -73.571  54.372  1
269450  93.810  -73.569  54.352  1
269451  93.830  -73.567  54.332  1
269452  93.850  -73.565  54.313  1
269453  93.870  -73.562  54.292  1
269454  93.890  -73.560  54.271  1
269455  93.910  -73.558  54.251  1
269456  93.930  -73.556  54.230  1
269457  93.950  -73.553  54.210  1
269458  93.970  -73.551  54.190  1
269459  93.990  -73.549  54.170  1
269460  94.010  -73.545  54.151  1
269461  94.029  -73.540  54.132  1
269462  94.048  -73.535  54.109  1
269463  94.073  -73.545  54.084  1
269464  94.100  -73.552  54.058  1
269465  94.125  -73.559  54.034  1
269466  94.151  -73.567  54.007  1
269467  94.177  -73.574  53.981  1
269468  94.202  -73.581  53.955  1
269469  94.228  -73.589  53.929  1
269470  94.254  -73.597  53.902  1
269471  94.279  -73.603  53.875  1
269472  94.305  -73.611  53.848  1
269473  94.331  -73.618  53.820  1
269474  94.357  -73.626  53.793  1
269475  94.383  -73.633  53.764  1
269476  94.408  -73.640  53.735  1
269477  94.434  -73.648  53.707  1
269478  94.460  -73.655  53.678  1
269479  94.485  -73.662  53.649  1
269480  94.511  -73.670  53.620  1
269481  94.537  -73.678  53.590  1
269482  94.562  -73.684  53.563  1
269483  94.588  -73.692  53.536  1
269484  94.614  -73.700  53.510  1
269485  94.640  -73.707  53.485  1
269486  94.666  -73.714  53.461  1
269487  94.678  -73.716  53.438  1
269488  94.685  -73.715  53.416  1
269489  94.692  -73.713  53.396  1
269490  94.706  -73.716  53.375  1
269491  94.732  -73.716  53.354  1
269492  94.775  -73.705  53.334  1
269493  94.812  -73.698  53.312  1
269494  94.826  -73.711  53.286  1
269495  94.841  -73.725  53.257  1
269496  94.864  -73.728  53.224  1
269497  94.889  -73.731  53.187  1
269498  94.905  -73.731  53.149  1
269499  94.920  -73.731  53.111  1
269500  94.934  -73.731  53.073  1
269501  94.949  -73.730  53.034  1
269502  94.973  -73.734  52.996  1
269503  95.007  -73.743  52.958  1
269504  95.041  -73.751  52.921  1
269505  95.075  -73.760  52.884  1
269506  95.105  -73.745  52.847  1
269507  95.128  -73.700  52.812  1
269508  95.150  -73.655  52.778  1
269509  95.171  -73.615  52.745  1
269510  95.188  -73.609  52.714  1
269511  95.220  -73.618  52.682  1
269512  95.252  -73.632  52.649  1
269513  95.284  -73.647  52.616  1
269514  95.316  -73.661  52.582  1
269515  95.348  -73.675  52.549  1
269516  95.380  -73.690  52.515  1
269517  95.412  -73.703  52.481  1
269518  95.444  -73.718  52.445  1
269519  95.475  -73.732  52.410  1
269520  95.508  -73.747  52.376  1
269521  95.539  -73.761  52.343  1
269522  95.567  -73.756  52.311  1
269523  95.594  -73.744  52.280  1
269524  95.620  -73.732  52.249  1
269525  95.647  -73.721  52.220  1
269526  95.673  -73.709  52.193  1
269527  95.702  -73.700  52.166  1
269528  95.736  -73.695  52.138  1
269529  95.770  -73.691  52.108  1
269530  95.805  -73.687  52.076  1
269531  95.839  -73.683  52.044  1
269532  95.874  -73.678  52.011  1
269533  95.932  -73.716  51.977  1
269534  95.986  -73.740  51.944  1
269535  96.020  -73.744  51.911  1
269536  96.050  -73.756  51.878  1
269537  96.075  -73.751  51.845  1
269538  96.091  -73.738  51.810  1
269539  96.107  -73.724  51.776  1
269540  96.124  -73.710  51.743  1
269541  96.141  -73.696  51.709  1
269542  96.144  -73.697  51.675  1
269543  96.151  -73.700  51.642  1
269544  96.159  -73.703  51.609  1
269545  96.167  -73.707  51.576  1
269546  96.177  -73.722  51.543  1
269547  96.225  -73.749  51.510  1
269548  96.269  -73.751  51.477  1
269549  96.291  -73.763  51.444  1
269550  96.313  -73.775  51.411  1
269551  96.335  -73.787  51.379  1
269552  96.357  -73.798  51.348  1
269553  96.379  -73.810  51.316  1
269554  96.401  -73.822  51.287  1
269555  96.423  -73.833  51.257  1
269556  96.445  -73.845  51.228  1
269557  96.471  -73.853  51.200  1
269558  96.498  -73.860  51.173  1
269559  96.524  -73.866  51.146  1
269560  96.554  -73.870  51.119  1
269561  96.589  -73.870  51.093  1
269562  96.623  -73.870  51.070  1
269563  96.658  -73.870  51.049  1
269564  96.692  -73.869  51.029  1
269565  96.726  -73.866  51.011  1
269566  96.759  -73.863  50.995  1
269567  96.791  -73.866  50.979  1
269568  96.820  -73.879  50.964  1
269569  96.849  -73.891  50.950  1
269570  96.883  -73.906  50.940  1
269571  96.919  -73.922  50.931  1
269572  96.954  -73.937  50.923  1
269573  96.990  -73.953  50.916  1
269574  97.025  -73.969  50.913  1
269575  97.061  -73.985  50.910  1
269576  97.096  -74.000  50.909  1
269577  97.129  -73.992  50.910  1
269578  97.161  -73.981  50.916  1
269579  97.184  -73.967  50.920  1
269580  97.207  -73.953  50.923  1
269581  97.230  -73.938  50.925  1
269582  97.252  -73.923  50.925  1
269583  97.275  -73.909  50.921  1
269584  97.297  -73.894  50.914  1
269585  97.321  -73.900  50.905  1
269586  97.345  -73.906  50.891  1
269587  97.368  -73.912  50.881  1
269588  97.392  -73.919  50.872  1
269589  97.416  -73.925  50.861  1
269590  97.436  -73.930  50.847  1
269591  97.455  -73.936  50.832  1
269592  97.474  -73.941  50.817  1
269593  97.494  -73.948  50.799  1
269594  97.513  -73.953  50.775  1
269595  97.533  -73.959  50.745  1
269596  97.573  -73.963  50.711  1
269597  97.613  -73.969  50.675  1
269598  97.653  -73.974  50.631  1
269599  97.693  -73.979  50.583  1
269600  97.726  -73.990  50.531  1
269601  97.752  -74.007  50.478  1
269602  97.779  -74.024  50.431  1
269603  97.805  -74.042  50.384  1
269604  97.831  -74.058  50.337  1
269605  97.858  -74.076  50.292  1
269606  97.888  -74.091  50.245  1
269607  97.920  -74.107  50.201  1
269608  97.951  -74.120  50.157  1
269609  97.983  -74.130  50.114  1
269610  98.014  -74.142  50.068  1
269611  98.045  -74.152  50.019  1
269612  98.076  -74.163  49.965  1
269613  98.107  -74.173  49.906  1
269614  98.138  -74.184  49.843  1
269615  98.169  -74.195  49.778  1
269616  98.201  -74.205  49.712  1
269617  98.231  -74.219  49.648  1
269618  98.262  -74.233  49.584  1
269619  98.292  -74.247  49.524  1
269620  98.322  -74.261  49.467  1
269621  98.353  -74.275  49.412  1
269622  98.337  -74.283  49.355  1
269623  98.402  -74.320  49.299  1
269624  98.466  -74.358  49.243  1
269625  98.490  -74.374  49.184  1
269626  98.536  -74.367  49.123  1
269627  98.564  -74.357  49.063  1
269628  98.592  -74.352  49.004  1
269629  98.651  -74.375  48.948  1
269630  98.707  -74.436  48.894  1
269631  98.729  -74.482  48.843  1
269632  98.754  -74.517  48.793  1
269633  98.784  -74.524  48.742  1
269634  98.815  -74.532  48.692  1
269635  98.845  -74.540  48.641  1
269636  98.869  -74.548  48.590  1
269637  98.880  -74.559  48.539  1
269638  98.890  -74.568  48.486  1
269639  98.918  -74.562  48.433  1
269640  98.959  -74.539  48.380  1
269641  99.002  -74.517  48.327  1
269642  99.040  -74.505  48.275  1
269643  99.072  -74.509  48.225  1
269644  99.104  -74.515  48.175  1
269645  99.137  -74.519  48.125  1
269646  99.163  -74.535  48.077  1
269647  99.188  -74.556  48.029  1
269648  99.212  -74.577  47.981  1
269649  99.236  -74.597  47.935  1
269650  99.260  -74.618  47.889  1
269651  99.284  -74.639  47.844  1
269652  99.308  -74.659  47.800  1
269653  99.334  -74.680  47.756  1
269654  99.373  -74.693  47.714  1
269655  99.403  -74.702  47.673  1
269656  99.432  -74.710  47.632  1
269657  99.461  -74.717  47.592  1
269658  99.489  -74.724  47.556  1
269659  99.516  -74.731  47.519  1
269660  99.545  -74.738  47.483  1
269661  99.573  -74.745  47.446  1
269662  99.600  -74.752  47.407  1
269663  99.638  -74.763  47.370  1
269664  99.677  -74.774  47.332  1
269665  99.715  -74.785  47.295  1
269666  99.752  -74.793  47.262  1
269667  99.786  -74.794  47.229  1
269668  99.820  -74.794  47.197  1
269669  99.854  -74.795  47.166  1
269670  99.888  -74.796  47.135  1
269671  99.922  -74.797  47.104  1
269672  99.957  -74.797  47.075  1
269673  99.990  -74.810  47.049  1
269674  100.023  -74.825  47.021  1
269675  100.057  -74.840  46.993  1
269676  100.090  -74.855  46.967  1
269677  100.124  -74.870  46.940  1
269678  100.157  -74.885  46.914  1
269679  100.190  -74.900  46.892  1
269680  100.223  -74.936  46.870  1
269681  100.256  -74.974  46.847  1
269682  100.281  -74.987  46.823  1
269683  100.306  -74.999  46.796  1
269684  100.331  -75.011  46.769  1
269685  100.356  -75.024  46.742  1
269686  100.381  -75.036  46.715  1
269687  100.405  -75.048  46.689  1
269688  100.432  -75.063  46.662  1
269689  100.461  -75.079  46.635  1
269690  100.489  -75.095  46.608  1
269691  100.510  -75.112  46.580  1
269692  100.529  -75.128  46.553  1
269693  100.548  -75.145  46.526  1
269694  100.566  -75.160  46.498  1
269695  100.585  -75.177  46.471  1
269696  100.604  -75.193  46.443  1
269697  100.622  -75.210  46.413  1
269698  100.647  -75.222  46.383  1
269699  100.674  -75.232  46.356  1
269700  100.701  -75.243  46.329  1
269701  100.729  -75.254  46.303  1
269702  100.756  -75.264  46.275  1
269703  100.783  -75.271  46.247  1
269704  100.811  -75.266  46.219  1
269705  100.838  -75.261  46.191  1
269706  100.876  -75.258  46.164  1
269707  100.919  -75.254  46.135  1
269708  100.962  -75.252  46.107  1
269709  100.999  -75.254  46.078  1
269710  101.024  -75.271  46.050  1
269711  101.048  -75.287  46.020  1
269712  101.072  -75.303  45.990  1
269713  101.096  -75.319  45.960  1
269714  101.127  -75.351  45.928  1
269715  101.154  -75.380  45.896  1
269716  101.175  -75.401  45.864  1
269717  101.192  -75.405  45.831  1
269718  101.207  -75.394  45.798  1
269719  101.225  -75.384  45.766  1
269720  101.244  -75.377  45.733  1
269721  101.267  -75.373  45.700  1
269722  101.301  -75.389  45.665  1
269723  101.334  -75.404  45.631  1
269724  101.368  -75.420  45.599  1
269725  101.402  -75.436  45.567  1
269726  101.435  -75.451  45.536  1
269727  101.469  -75.467  45.505  1
269728  101.507  -75.494  45.475  1
269729  101.547  -75.527  45.445  1
269730  101.587  -75.560  45.415  1
269731  101.627  -75.593  45.386  1
269732  101.684  -75.631  45.357  1
269733  101.740  -75.669  45.328  1
269734  101.754  -75.676  45.302  1
269735  101.762  -75.679  45.274  1
269736  101.769  -75.682  45.247  1
269737  101.781  -75.690  45.220  1
269738  101.802  -75.709  45.194  1
269739  101.820  -75.709  45.167  1
269740  101.838  -75.709  45.142  1
269741  101.855  -75.710  45.117  1
269742  101.873  -75.710  45.090  1
269743  101.890  -75.711  45.065  1
269744  101.907  -75.712  45.041  1
269745  101.925  -75.712  45.016  1
269746  101.943  -75.712  44.992  1
269747  101.960  -75.713  44.968  1
269748  101.977  -75.714  44.944  1
270097  92.273  -73.267  54.755  1
270098  92.304  -73.277  54.745  1
270099  92.335  -73.287  54.734  1
270100  92.365  -73.298  54.722  1
270101  92.395  -73.308  54.712  1
270102  92.426  -73.318  54.702  1
270103  92.457  -73.329  54.691  1
270104  92.488  -73.339  54.682  1
270105  92.518  -73.349  54.672  1
270106  92.549  -73.360  54.663  1
270107  92.580  -73.370  54.655  1
270108  92.611  -73.380  54.646  1
270109  92.641  -73.391  54.637  1
270110  92.671  -73.401  54.628  1
270111  92.702  -73.412  54.620  1
270112  92.739  -73.422  54.614  1
270113  92.782  -73.433  54.608  1
270114  92.825  -73.444  54.603  1
270115  92.868  -73.455  54.599  1
270116  92.911  -73.466  54.598  1
270117  92.953  -73.477  54.598  1
270118  92.996  -73.488  54.598  1
270119  93.038  -73.498  54.600  1
270120  93.060  -73.489  54.600  1
270121  93.082  -73.481  54.601  1
270122  93.105  -73.472  54.601  1
270123  93.127  -73.464  54.604  1
270124  93.149  -73.456  54.606  1
270125  93.173  -73.448  54.607  1
270126  93.214  -73.462  54.609  1
270127  93.249  -73.475  54.607  1
270128  93.281  -73.487  54.604  1
270129  93.313  -73.499  54.601  1
270130  93.346  -73.512  54.597  1
270131  93.378  -73.524  54.594  1
270132  93.410  -73.536  54.589  1
270133  93.443  -73.547  54.584  1
270134  93.469  -73.553  54.574  1
270135  93.490  -73.556  54.563  1
270136  93.511  -73.559  54.551  1
270137  93.532  -73.561  54.537  1
270138  93.553  -73.562  54.523  1
270139  93.574  -73.565  54.511  1
270140  93.595  -73.567  54.499  1
270141  93.616  -73.568  54.485  1
270142  93.636  -73.565  54.474  1
270143  93.656  -73.563  54.461  1
270144  93.676  -73.561  54.449  1
270145  93.696  -73.559  54.437  1
270146  93.716  -73.556  54.424  1
270147  93.736  -73.554  54.407  1
270148  93.756  -73.552  54.390  1
270149  93.776  -73.550  54.372  1
270150  93.796  -73.547  54.353  1
270151  93.817  -73.545  54.332  1
270152  93.836  -73.543  54.312  1
270153  93.856  -73.540  54.293  1
270154  93.876  -73.538  54.271  1
270155  93.897  -73.536  54.249  1
270156  93.917  -73.534  54.228  1
270157  93.936  -73.531  54.207  1
270158  93.956  -73.526  54.186  1
270159  93.974  -73.521  54.166  1
270160  93.993  -73.516  54.145  1
270161  94.012  -73.511  54.124  1
270162  94.031  -73.506  54.103  1
270163  94.050  -73.500  54.079  1
270164  94.072  -73.504  54.055  1
270165  94.098  -73.515  54.029  1
270166  94.124  -73.522  54.005  1
270167  94.149  -73.530  53.979  1
270168  94.176  -73.537  53.953  1
270169  94.201  -73.544  53.927  1
270170  94.227  -73.552  53.900  1
270171  94.253  -73.559  53.874  1
270172  94.278  -73.566  53.848  1
270173  94.304  -73.574  53.822  1
270174  94.330  -73.581  53.794  1
270175  94.355  -73.589  53.766  1
270176  94.381  -73.596  53.737  1
270177  94.407  -73.603  53.709  1
270178  94.433  -73.611  53.682  1
270179  94.459  -73.618  53.653  1
270180  94.484  -73.625  53.624  1
270181  94.510  -73.633  53.596  1
270182  94.536  -73.640  53.567  1
270183  94.561  -73.647  53.539  1
270184  94.587  -73.655  53.512  1
270185  94.613  -73.662  53.487  1
270186  94.638  -73.670  53.462  1
270187  94.664  -73.677  53.439  1
270188  94.688  -73.684  53.416  1
270189  94.695  -73.683  53.395  1
270190  94.702  -73.681  53.374  1
270191  94.709  -73.681  53.351  1
270192  94.730  -73.685  53.329  1
270193  94.753  -73.687  53.307  1
270194  94.796  -73.676  53.281  1
270195  94.834  -73.669  53.253  1
270196  94.848  -73.682  53.224  1
270197  94.862  -73.695  53.192  1
270198  94.877  -73.709  53.158  1
270199  94.899  -73.714  53.121  1
270200  94.924  -73.716  53.085  1
270201  94.950  -73.718  53.049  1
270202  94.966  -73.718  53.012  1
270203  94.980  -73.718  52.975  1
270204  94.995  -73.718  52.938  1
270205  95.026  -73.725  52.902  1
270206  95.060  -73.733  52.866  1
270207  95.094  -73.740  52.830  1
270208  95.116  -73.694  52.797  1
270209  95.139  -73.650  52.765  1
270210  95.162  -73.604  52.733  1
270211  95.194  -73.590  52.703  1
270212  95.227  -73.605  52.671  1
270213  95.259  -73.618  52.639  1
270214  95.290  -73.633  52.606  1
270215  95.322  -73.647  52.573  1
270216  95.354  -73.662  52.540  1
270217  95.386  -73.676  52.507  1
270218  95.418  -73.691  52.474  1
270219  95.450  -73.704  52.439  1
270220  95.482  -73.719  52.404  1
270221  95.514  -73.733  52.371  1
270222  95.545  -73.744  52.339  1
270223  95.571  -73.732  52.308  1
270224  95.598  -73.721  52.278  1
270225  95.624  -73.709  52.249  1
270226  95.651  -73.697  52.220  1
270227  95.678  -73.685  52.194  1
270228  95.705  -73.675  52.168  1
270229  95.739  -73.670  52.141  1
270230  95.774  -73.666  52.111  1
270231  95.808  -73.662  52.079  1
270232  95.857  -73.683  52.047  1
270233  95.908  -73.698  52.014  1
270234  95.948  -73.687  51.982  1
270235  95.978  -73.700  51.949  1
270236  96.008  -73.713  51.916  1
270237  96.038  -73.726  51.883  1
270238  96.074  -73.726  51.849  1
270239  96.089  -73.720  51.814  1
270240  96.105  -73.706  51.780  1
270241  96.121  -73.693  51.746  1
270242  96.138  -73.678  51.712  1
270243  96.138  -73.675  51.679  1
270244  96.146  -73.677  51.645  1
270245  96.153  -73.680  51.612  1
270246  96.161  -73.683  51.579  1
270247  96.177  -73.688  51.546  1
270248  96.250  -73.710  51.513  1
270249  96.285  -73.725  51.481  1
270250  96.306  -73.733  51.449  1
270251  96.328  -73.742  51.416  1
270252  96.349  -73.753  51.384  1
270253  96.372  -73.764  51.353  1
270254  96.394  -73.776  51.321  1
270255  96.415  -73.788  51.292  1
270256  96.438  -73.800  51.263  1
270257  96.460  -73.811  51.234  1
270258  96.481  -73.822  51.204  1
270259  96.504  -73.835  51.177  1
270260  96.530  -73.842  51.149  1
270261  96.556  -73.849  51.122  1
270262  96.591  -73.849  51.096  1
270263  96.625  -73.849  51.073  1
270264  96.659  -73.846  51.052  1
270265  96.692  -73.843  51.032  1
270266  96.726  -73.840  51.013  1
270267  96.759  -73.837  50.996  1
270268  96.791  -73.841  50.981  1
270269  96.820  -73.854  50.966  1
270270  96.849  -73.866  50.952  1
270271  96.878  -73.879  50.940  1
270272  96.911  -73.894  50.930  1
270273  96.947  -73.910  50.922  1
270274  96.982  -73.925  50.915  1
270275  97.018  -73.941  50.910  1
270276  97.054  -73.957  50.907  1
270277  97.088  -73.958  50.905  1
270278  97.119  -73.948  50.905  1
270279  97.152  -73.937  50.908  1
270280  97.183  -73.926  50.911  1
270281  97.206  -73.911  50.912  1
270282  97.229  -73.897  50.913  1
270283  97.251  -73.882  50.911  1
270284  97.274  -73.868  50.907  1
270285  97.297  -73.870  50.901  1
270286  97.321  -73.876  50.893  1
270287  97.345  -73.883  50.883  1
270288  97.367  -73.889  50.875  1
270289  97.387  -73.894  50.868  1
270290  97.406  -73.901  50.860  1
270291  97.426  -73.906  50.847  1
270292  97.445  -73.912  50.835  1
270293  97.464  -73.917  50.821  1
270294  97.484  -73.923  50.803  1
270295  97.504  -73.929  50.776  1
270296  97.540  -73.934  50.743  1
270297  97.580  -73.939  50.706  1
270298  97.620  -73.944  50.666  1
270299  97.660  -73.949  50.623  1
270300  97.700  -73.954  50.576  1
270301  97.738  -73.961  50.527  1
270302  97.764  -73.978  50.477  1
270303  97.791  -73.995  50.429  1
270304  97.817  -74.012  50.383  1
270305  97.843  -74.029  50.337  1
270306  97.870  -74.046  50.292  1
270307  97.896  -74.063  50.247  1
270308  97.923  -74.080  50.202  1
270309  97.954  -74.094  50.157  1
270310  97.985  -74.104  50.111  1
270311  98.016  -74.115  50.062  1
270312  98.048  -74.126  50.010  1
270313  98.079  -74.137  49.954  1
270314  98.110  -74.148  49.893  1
270315  98.141  -74.158  49.829  1
270316  98.172  -74.169  49.764  1
270317  98.203  -74.179  49.699  1
270318  98.234  -74.190  49.635  1
270319  98.266  -74.201  49.570  1
270320  98.296  -74.215  49.508  1
270321  98.326  -74.230  49.449  1
270322  98.354  -74.243  49.393  1
270323  98.373  -74.264  49.338  1
270324  98.433  -74.299  49.283  1
270325  98.452  -74.313  49.226  1
270326  98.486  -74.316  49.167  1
270327  98.533  -74.302  49.106  1
270328  98.566  -74.309  49.046  1
270329  98.603  -74.330  48.988  1
270330  98.650  -74.353  48.932  1
270331  98.702  -74.377  48.880  1
270332  98.725  -74.417  48.830  1
270333  98.748  -74.459  48.779  1
270334  98.779  -74.467  48.729  1
270335  98.809  -74.474  48.678  1
270336  98.840  -74.482  48.627  1
270337  98.870  -74.490  48.576  1
270338  98.898  -74.498  48.526  1
270339  98.909  -74.508  48.474  1
270340  98.933  -74.504  48.421  1
270341  98.975  -74.481  48.368  1
270342  99.012  -74.473  48.315  1
270343  99.045  -74.478  48.263  1
270344  99.076  -74.483  48.212  1
270345  99.109  -74.488  48.161  1
270346  99.141  -74.493  48.112  1
270347  99.168  -74.507  48.064  1
270348  99.193  -74.527  48.016  1
270349  99.217  -74.548  47.969  1
270350  99.241  -74.569  47.923  1
270351  99.265  -74.590  47.878  1
270352  99.290  -74.610  47.832  1
270353  99.314  -74.631  47.788  1
270354  99.349  -74.648  47.745  1
270355  99.390  -74.662  47.704  1
270356  99.421  -74.671  47.663  1
270357  99.450  -74.680  47.623  1
270358  99.481  -74.688  47.583  1
270359  99.510  -74.697  47.547  1
270360  99.539  -74.705  47.510  1
270361  99.567  -74.712  47.474  1
270362  99.595  -74.718  47.438  1
270363  99.623  -74.725  47.400  1
270364  99.651  -74.733  47.362  1
270365  99.687  -74.743  47.325  1
270366  99.725  -74.754  47.289  1
270367  99.763  -74.765  47.256  1
270368  99.798  -74.766  47.222  1
270369  99.832  -74.767  47.191  1
270370  99.866  -74.768  47.160  1
270371  99.900  -74.769  47.129  1
270372  99.934  -74.769  47.098  1
270373  99.968  -74.782  47.069  1
270374  100.001  -74.797  47.042  1
270375  100.034  -74.812  47.014  1
270376  100.068  -74.827  46.986  1
270377  100.102  -74.841  46.959  1
270378  100.135  -74.856  46.933  1
270379  100.168  -74.872  46.908  1
270380  100.202  -74.887  46.885  1
270381  100.235  -74.910  46.862  1
270382  100.266  -74.944  46.840  1
270383  100.291  -74.956  46.814  1
270384  100.316  -74.969  46.788  1
270385  100.341  -74.981  46.760  1
270386  100.366  -74.993  46.732  1
270387  100.391  -75.006  46.707  1
270388  100.415  -75.018  46.680  1
270389  100.440  -75.030  46.653  1
270390  100.467  -75.045  46.626  1
270391  100.495  -75.061  46.598  1
270392  100.522  -75.077  46.571  1
270393  100.541  -75.093  46.544  1
270394  100.560  -75.110  46.517  1
270395  100.578  -75.126  46.489  1
270396  100.597  -75.142  46.461  1
270397  100.616  -75.158  46.433  1
270398  100.637  -75.173  46.404  1
270399  100.665  -75.183  46.373  1
270400  100.692  -75.194  46.346  1
270401  100.719  -75.204  46.319  1
270402  100.747  -75.215  46.292  1
270403  100.774  -75.226  46.264  1
270404  100.801  -75.232  46.237  1
270405  100.829  -75.227  46.210  1
270406  100.858  -75.223  46.181  1
270407  100.901  -75.220  46.153  1
270408  100.944  -75.217  46.125  1
270409  100.981  -75.220  46.096  1
270410  101.005  -75.236  46.067  1
270411  101.029  -75.252  46.039  1
270412  101.053  -75.268  46.007  1
270413  101.077  -75.285  45.976  1
270414  101.102  -75.301  45.944  1
270415  101.128  -75.321  45.912  1
270416  101.153  -75.348  45.879  1
270417  101.171  -75.349  45.847  1
270418  101.185  -75.339  45.814  1
270419  101.201  -75.330  45.782  1
270420  101.231  -75.340  45.749  1
270421  101.265  -75.357  45.716  1
270422  101.299  -75.373  45.682  1
270423  101.332  -75.389  45.649  1
270424  101.366  -75.405  45.615  1
270425  101.400  -75.420  45.583  1
270426  101.433  -75.436  45.551  1
270427  101.467  -75.452  45.520  1
270428  101.501  -75.467  45.490  1
270429  101.535  -75.483  45.460  1
270430  101.573  -75.511  45.430  1
270431  101.613  -75.544  45.400  1
270432  101.653  -75.577  45.370  1
270433  101.709  -75.615  45.341  1
270434  101.750  -75.643  45.313  1
270435  101.758  -75.645  45.286  1
270436  101.765  -75.648  45.258  1
270437  101.781  -75.660  45.231  1
270438  101.800  -75.668  45.204  1
270439  101.818  -75.668  45.178  1
270440  101.835  -75.669  45.152  1
270441  101.852  -75.670  45.126  1
270442  101.870  -75.670  45.100  1
270443  101.888  -75.671  45.075  1
270444  101.905  -75.671  45.050  1
270445  101.922  -75.671  45.025  1
270446  101.940  -75.672  45.001  1
270447  101.957  -75.673  44.976  1
270448  101.975  -75.674  44.952  1
270798  92.269  -73.237  54.763  1
270799  92.299  -73.248  54.752  1
270800  92.330  -73.258  54.740  1
270801  92.361  -73.268  54.728  1
270802  92.391  -73.279  54.718  1
270803  92.422  -73.289  54.707  1
270804  92.453  -73.299  54.695  1
270805  92.484  -73.310  54.685  1
270806  92.514  -73.321  54.675  1
270807  92.545  -73.330  54.665  1
270808  92.575  -73.341  54.654  1
270809  92.606  -73.351  54.644  1
270810  92.637  -73.362  54.635  1
270811  92.667  -73.372  54.626  1
270812  92.698  -73.382  54.619  1
270813  92.736  -73.393  54.613  1
270814  92.779  -73.404  54.607  1
270815  92.821  -73.415  54.601  1
270816  92.864  -73.426  54.598  1
270817  92.907  -73.437  54.596  1
270818  92.950  -73.448  54.596  1
270819  92.993  -73.459  54.596  1
270820  93.036  -73.470  54.596  1
270821  93.071  -73.474  54.596  1
270822  93.093  -73.465  54.595  1
270823  93.116  -73.456  54.595  1
270824  93.138  -73.448  54.596  1
270825  93.160  -73.440  54.597  1
270826  93.183  -73.431  54.597  1
270827  93.223  -73.445  54.598  1
270828  93.264  -73.459  54.596  1
270829  93.297  -73.471  54.593  1
270830  93.329  -73.484  54.590  1
270831  93.361  -73.496  54.586  1
270832  93.394  -73.508  54.582  1
270833  93.425  -73.520  54.577  1
270834  93.455  -73.531  54.571  1
270835  93.476  -73.534  54.561  1
270836  93.497  -73.537  54.548  1
270837  93.518  -73.539  54.535  1
270838  93.540  -73.541  54.521  1
270839  93.561  -73.543  54.508  1
270840  93.582  -73.546  54.496  1
270841  93.603  -73.546  54.484  1
270842  93.622  -73.543  54.470  1
270843  93.642  -73.541  54.456  1
270844  93.662  -73.539  54.443  1
270845  93.683  -73.537  54.431  1
270846  93.703  -73.534  54.418  1
270847  93.722  -73.532  54.405  1
270848  93.743  -73.530  54.388  1
270849  93.763  -73.528  54.371  1
270850  93.783  -73.525  54.352  1
270851  93.802  -73.523  54.332  1
270852  93.823  -73.521  54.312  1
270853  93.843  -73.518  54.292  1
270854  93.863  -73.516  54.272  1
270855  93.883  -73.513  54.249  1
270856  93.901  -73.508  54.227  1
270857  93.920  -73.503  54.204  1
270858  93.939  -73.497  54.182  1
270859  93.958  -73.492  54.162  1
270860  93.977  -73.487  54.142  1
270861  93.995  -73.481  54.120  1
270862  94.014  -73.476  54.096  1
270863  94.033  -73.471  54.073  1
270864  94.052  -73.466  54.050  1
270865  94.071  -73.461  54.026  1
270866  94.097  -73.474  54.001  1
270867  94.123  -73.485  53.977  1
270868  94.148  -73.493  53.952  1
270869  94.174  -73.500  53.925  1
270870  94.200  -73.507  53.899  1
270871  94.225  -73.515  53.872  1
270872  94.252  -73.522  53.846  1
270873  94.277  -73.529  53.821  1
270874  94.303  -73.537  53.796  1
270875  94.329  -73.544  53.768  1
270876  94.354  -73.552  53.740  1
270877  94.380  -73.559  53.712  1
270878  94.406  -73.566  53.684  1
270879  94.431  -73.574  53.657  1
270880  94.457  -73.581  53.629  1
270881  94.483  -73.588  53.600  1
270882  94.509  -73.596  53.572  1
270883  94.535  -73.603  53.545  1
270884  94.560  -73.610  53.517  1
270885  94.586  -73.618  53.490  1
270886  94.612  -73.625  53.465  1
270887  94.637  -73.633  53.441  1
270888  94.663  -73.640  53.417  1
270889  94.689  -73.647  53.395  1
270890  94.706  -73.651  53.373  1
270891  94.713  -73.650  53.352  1
270892  94.720  -73.649  53.329  1
270893  94.733  -73.650  53.306  1
270894  94.754  -73.655  53.283  1
270895  94.774  -73.659  53.256  1
270896  94.817  -73.647  53.228  1
270897  94.856  -73.639  53.198  1
270898  94.870  -73.653  53.167  1
270899  94.885  -73.666  53.133  1
270900  94.899  -73.679  53.098  1
270901  94.913  -73.693  53.063  1
270902  94.934  -73.699  53.028  1
270903  94.959  -73.701  52.992  1
270904  94.984  -73.703  52.955  1
270905  95.010  -73.705  52.919  1
270906  95.027  -73.705  52.883  1
270907  95.044  -73.706  52.849  1
270908  95.078  -73.715  52.814  1
270909  95.105  -73.689  52.782  1
270910  95.128  -73.644  52.751  1
270911  95.150  -73.614  52.720  1
270912  95.177  -73.593  52.689  1
270913  95.219  -73.600  52.658  1
270914  95.263  -73.607  52.627  1
270915  95.297  -73.619  52.596  1
270916  95.329  -73.634  52.563  1
270917  95.360  -73.648  52.532  1
270918  95.393  -73.662  52.500  1
270919  95.424  -73.677  52.466  1
270920  95.457  -73.691  52.431  1
270921  95.488  -73.705  52.398  1
270922  95.520  -73.719  52.366  1
270923  95.549  -73.721  52.335  1
270924  95.576  -73.709  52.305  1
270925  95.602  -73.697  52.277  1
270926  95.629  -73.685  52.249  1
270927  95.656  -73.673  52.221  1
270928  95.682  -73.662  52.196  1
270929  95.708  -73.650  52.170  1
270930  95.743  -73.645  52.143  1
270931  95.782  -73.650  52.113  1
270932  95.829  -73.656  52.083  1
270933  95.870  -73.645  52.050  1
270934  95.906  -73.643  52.017  1
270935  95.936  -73.656  51.987  1
270936  95.966  -73.669  51.954  1
270937  95.995  -73.682  51.921  1
270938  96.025  -73.696  51.888  1
270939  96.061  -73.697  51.854  1
270940  96.090  -73.697  51.819  1
270941  96.103  -73.689  51.785  1
270942  96.119  -73.675  51.751  1
270943  96.135  -73.661  51.717  1
270944  96.141  -73.653  51.682  1
270945  96.141  -73.655  51.649  1
270946  96.148  -73.657  51.616  1
270947  96.156  -73.660  51.583  1
270948  96.215  -73.678  51.550  1
270949  96.262  -73.698  51.517  1
270950  96.303  -73.716  51.484  1
270951  96.324  -73.725  51.452  1
270952  96.346  -73.734  51.420  1
270953  96.368  -73.742  51.389  1
270954  96.389  -73.751  51.357  1
270955  96.411  -73.760  51.326  1
270956  96.432  -73.769  51.297  1
270957  96.454  -73.778  51.268  1
270958  96.475  -73.787  51.239  1
270959  96.497  -73.795  51.208  1
270960  96.519  -73.804  51.180  1
270961  96.540  -73.813  51.153  1
270962  96.562  -73.824  51.126  1
270963  96.592  -73.826  51.100  1
270964  96.626  -73.823  51.077  1
270965  96.660  -73.820  51.055  1
270966  96.693  -73.817  51.035  1
270967  96.727  -73.813  51.016  1
270968  96.760  -73.810  50.998  1
270969  96.791  -73.817  50.983  1
270970  96.820  -73.830  50.968  1
270971  96.849  -73.842  50.953  1
270972  96.878  -73.855  50.940  1
270973  96.907  -73.867  50.930  1
270974  96.940  -73.882  50.922  1
270975  96.975  -73.897  50.914  1
270976  97.011  -73.913  50.908  1
270977  97.046  -73.925  50.904  1
270978  97.078  -73.914  50.901  1
270979  97.110  -73.903  50.900  1
270980  97.142  -73.892  50.901  1
270981  97.174  -73.882  50.902  1
270982  97.205  -73.870  50.903  1
270983  97.228  -73.856  50.903  1
270984  97.250  -73.841  50.899  1
270985  97.274  -73.841  50.895  1
270986  97.298  -73.847  50.890  1
270987  97.318  -73.854  50.884  1
270988  97.337  -73.859  50.876  1
270989  97.357  -73.865  50.870  1
270990  97.377  -73.870  50.864  1
270991  97.396  -73.876  50.856  1
270992  97.416  -73.882  50.846  1
270993  97.435  -73.888  50.836  1
270994  97.455  -73.893  50.823  1
270995  97.474  -73.899  50.806  1
270996  97.507  -73.904  50.778  1
270997  97.547  -73.909  50.744  1
270998  97.587  -73.914  50.705  1
270999  97.627  -73.919  50.663  1
271000  97.667  -73.924  50.620  1
271001  97.707  -73.929  50.573  1
271002  97.747  -73.935  50.524  1
271003  97.776  -73.949  50.476  1
271004  97.802  -73.966  50.429  1
271005  97.829  -73.983  50.383  1
271006  97.855  -74.000  50.337  1
271007  97.881  -74.017  50.292  1
271008  97.908  -74.034  50.248  1
271009  97.934  -74.051  50.202  1
271010  97.968  -74.064  50.155  1
271011  98.005  -74.076  50.106  1
271012  98.032  -74.087  50.054  1
271013  98.060  -74.098  49.999  1
271014  98.087  -74.110  49.941  1
271015  98.114  -74.121  49.879  1
271016  98.144  -74.132  49.814  1
271017  98.175  -74.143  49.749  1
271018  98.206  -74.154  49.684  1
271019  98.237  -74.164  49.620  1
271020  98.268  -74.175  49.556  1
271021  98.299  -74.186  49.492  1
271022  98.331  -74.198  49.431  1
271023  98.354  -74.211  49.373  1
271024  98.394  -74.238  49.320  1
271025  98.414  -74.252  49.265  1
271026  98.434  -74.265  49.208  1
271027  98.498  -74.248  49.149  1
271028  98.539  -74.267  49.088  1
271029  98.576  -74.287  49.029  1
271030  98.614  -74.308  48.972  1
271031  98.651  -74.329  48.916  1
271032  98.692  -74.350  48.865  1
271033  98.719  -74.368  48.816  1
271034  98.744  -74.398  48.766  1
271035  98.773  -74.409  48.715  1
271036  98.804  -74.417  48.665  1
271037  98.835  -74.424  48.614  1
271038  98.865  -74.432  48.563  1
271039  98.896  -74.440  48.513  1
271040  98.926  -74.447  48.461  1
271041  98.948  -74.446  48.408  1
271042  98.984  -74.442  48.355  1
271043  99.016  -74.447  48.303  1
271044  99.049  -74.452  48.250  1
271045  99.081  -74.457  48.199  1
271046  99.113  -74.461  48.149  1
271047  99.145  -74.467  48.099  1
271048  99.173  -74.478  48.050  1
271049  99.198  -74.499  48.003  1
271050  99.222  -74.520  47.957  1
271051  99.246  -74.540  47.912  1
271052  99.271  -74.562  47.867  1
271053  99.295  -74.582  47.821  1
271054  99.323  -74.601  47.777  1
271055  99.364  -74.616  47.735  1
271056  99.405  -74.631  47.694  1
271057  99.439  -74.641  47.654  1
271058  99.469  -74.650  47.614  1
271059  99.498  -74.659  47.575  1
271060  99.528  -74.667  47.538  1
271061  99.558  -74.675  47.501  1
271062  99.588  -74.684  47.465  1
271063  99.618  -74.692  47.428  1
271064  99.646  -74.699  47.392  1
271065  99.674  -74.706  47.355  1
271066  99.702  -74.713  47.318  1
271067  99.735  -74.722  47.282  1
271068  99.774  -74.734  47.249  1
271069  99.810  -74.739  47.216  1
271070  99.844  -74.740  47.184  1
271071  99.878  -74.740  47.154  1
271072  99.912  -74.742  47.123  1
271073  99.946  -74.753  47.092  1
271074  99.979  -74.769  47.063  1
271075  100.012  -74.784  47.035  1
271076  100.046  -74.799  47.008  1
271077  100.079  -74.813  46.981  1
271078  100.113  -74.828  46.954  1
271079  100.146  -74.844  46.927  1
271080  100.180  -74.858  46.902  1
271081  100.213  -74.873  46.879  1
271082  100.247  -74.888  46.856  1
271083  100.276  -74.913  46.833  1
271084  100.301  -74.925  46.808  1
271085  100.326  -74.938  46.780  1
271086  100.351  -74.950  46.752  1
271087  100.375  -74.963  46.724  1
271088  100.401  -74.975  46.699  1
271089  100.425  -74.988  46.672  1
271090  100.450  -75.000  46.645  1
271091  100.475  -75.012  46.618  1
271092  100.501  -75.026  46.589  1
271093  100.530  -75.042  46.562  1
271094  100.553  -75.058  46.534  1
271095  100.571  -75.075  46.507  1
271096  100.590  -75.091  46.479  1
271097  100.609  -75.107  46.451  1
271098  100.627  -75.123  46.422  1
271099  100.655  -75.134  46.393  1
271100  100.682  -75.145  46.363  1
271101  100.709  -75.155  46.336  1
271102  100.737  -75.166  46.308  1
271103  100.764  -75.176  46.281  1
271104  100.791  -75.188  46.255  1
271105  100.819  -75.194  46.228  1
271106  100.846  -75.189  46.200  1
271107  100.882  -75.185  46.171  1
271108  100.925  -75.182  46.142  1
271109  100.962  -75.185  46.114  1
271110  100.986  -75.201  46.085  1
271111  101.010  -75.218  46.056  1
271112  101.035  -75.234  46.026  1
271113  101.059  -75.250  45.994  1
271114  101.083  -75.266  45.962  1
271115  101.107  -75.283  45.929  1
271116  101.131  -75.298  45.896  1
271117  101.155  -75.302  45.863  1
271118  101.176  -75.301  45.830  1
271119  101.198  -75.299  45.797  1
271120  101.226  -75.308  45.765  1
271121  101.260  -75.327  45.733  1
271122  101.294  -75.346  45.699  1
271123  101.329  -75.366  45.666  1
271124  101.363  -75.386  45.633  1
271125  101.398  -75.405  45.601  1
271126  101.431  -75.420  45.568  1
271127  101.465  -75.436  45.536  1
271128  101.499  -75.452  45.506  1
271129  101.533  -75.467  45.475  1
271130  101.566  -75.483  45.445  1
271131  101.600  -75.499  45.414  1
271132  101.639  -75.529  45.385  1
271133  101.679  -75.561  45.356  1
271134  101.734  -75.599  45.327  1
271135  101.754  -75.611  45.298  1
271136  101.761  -75.614  45.271  1
271137  101.780  -75.627  45.243  1
271138  101.798  -75.627  45.215  1
271139  101.815  -75.628  45.188  1
271140  101.833  -75.629  45.162  1
271141  101.850  -75.630  45.136  1
271142  101.868  -75.630  45.110  1
271143  101.885  -75.630  45.084  1
271144  101.902  -75.631  45.059  1
271145  101.920  -75.631  45.034  1
271146  101.938  -75.632  45.009  1
271147  101.955  -75.633  44.984  1
271148  101.972  -75.633  44.960  1
271149  101.990  -75.634  44.936  1
271499  92.265  -73.208  54.770  1
271500  92.295  -73.219  54.759  1
271501  92.326  -73.229  54.746  1
271502  92.357  -73.239  54.734  1
271503  92.387  -73.250  54.723  1
271504  92.418  -73.260  54.711  1
271505  92.449  -73.271  54.699  1
271506  92.479  -73.280  54.687  1
271507  92.510  -73.291  54.677  1
271508  92.541  -73.302  54.666  1
271509  92.571  -73.311  54.655  1
271510  92.602  -73.322  54.645  1
271511  92.633  -73.333  54.636  1
271512  92.663  -73.343  54.627  1
271513  92.694  -73.353  54.619  1
271514  92.732  -73.364  54.612  1
271515  92.775  -73.375  54.605  1
271516  92.818  -73.386  54.600  1
271517  92.861  -73.397  54.597  1
271518  92.904  -73.408  54.595  1
271519  92.947  -73.419  54.594  1
271520  92.990  -73.430  54.593  1
271521  93.033  -73.441  54.593  1
271522  93.076  -73.452  54.592  1
271523  93.105  -73.449  54.590  1
271524  93.127  -73.441  54.590  1
271525  93.149  -73.433  54.589  1
271526  93.171  -73.424  54.588  1
271527  93.194  -73.415  54.588  1
271528  93.233  -73.427  54.587  1
271529  93.274  -73.442  54.585  1
271530  93.312  -73.456  54.581  1
271531  93.344  -73.468  54.579  1
271532  93.376  -73.480  54.575  1
271533  93.409  -73.492  54.570  1
271534  93.441  -73.504  54.564  1
271535  93.463  -73.512  54.557  1
271536  93.484  -73.515  54.546  1
271537  93.505  -73.518  54.533  1
271538  93.526  -73.520  54.520  1
271539  93.547  -73.522  54.506  1
271540  93.568  -73.524  54.493  1
271541  93.589  -73.524  54.481  1
271542  93.609  -73.521  54.469  1
271543  93.629  -73.519  54.454  1
271544  93.649  -73.518  54.440  1
271545  93.669  -73.515  54.427  1
271546  93.689  -73.513  54.413  1
271547  93.709  -73.511  54.399  1
271548  93.729  -73.509  54.387  1
271549  93.749  -73.506  54.370  1
271550  93.769  -73.504  54.351  1
271551  93.789  -73.502  54.333  1
271552  93.809  -73.499  54.312  1
271553  93.828  -73.494  54.291  1
271554  93.847  -73.489  54.271  1
271555  93.866  -73.484  54.251  1
271556  93.885  -73.478  54.227  1
271557  93.903  -73.473  54.204  1
271558  93.922  -73.468  54.181  1
271559  93.941  -73.463  54.158  1
271560  93.960  -73.458  54.138  1
271561  93.979  -73.452  54.116  1
271562  93.998  -73.447  54.094  1
271563  94.016  -73.442  54.069  1
271564  94.035  -73.437  54.046  1
271565  94.054  -73.431  54.022  1
271566  94.073  -73.426  53.998  1
271567  94.095  -73.428  53.974  1
271568  94.121  -73.443  53.950  1
271569  94.147  -73.456  53.925  1
271570  94.173  -73.463  53.898  1
271571  94.199  -73.470  53.871  1
271572  94.224  -73.477  53.845  1
271573  94.250  -73.485  53.819  1
271574  94.276  -73.492  53.794  1
271575  94.301  -73.499  53.769  1
271576  94.328  -73.507  53.742  1
271577  94.353  -73.515  53.715  1
271578  94.379  -73.521  53.688  1
271579  94.405  -73.529  53.660  1
271580  94.430  -73.537  53.632  1
271581  94.456  -73.543  53.605  1
271582  94.482  -73.551  53.578  1
271583  94.507  -73.559  53.549  1
271584  94.533  -73.566  53.522  1
271585  94.559  -73.573  53.496  1
271586  94.585  -73.581  53.470  1
271587  94.611  -73.588  53.444  1
271588  94.636  -73.596  53.420  1
271589  94.662  -73.603  53.396  1
271590  94.688  -73.610  53.374  1
271591  94.713  -73.618  53.353  1
271592  94.724  -73.618  53.330  1
271593  94.731  -73.617  53.308  1
271594  94.738  -73.616  53.284  1
271595  94.757  -73.620  53.260  1
271596  94.777  -73.624  53.233  1
271597  94.797  -73.628  53.204  1
271598  94.838  -73.618  53.174  1
271599  94.878  -73.610  53.143  1
271600  94.892  -73.623  53.111  1
271601  94.906  -73.637  53.076  1
271602  94.921  -73.650  53.042  1
271603  94.935  -73.663  53.007  1
271604  94.950  -73.677  52.972  1
271605  94.969  -73.684  52.936  1
271606  94.994  -73.686  52.901  1
271607  95.020  -73.688  52.866  1
271608  95.045  -73.690  52.833  1
271609  95.070  -73.692  52.800  1
271610  95.094  -73.683  52.768  1
271611  95.116  -73.654  52.737  1
271612  95.138  -73.626  52.706  1
271613  95.160  -73.597  52.675  1
271614  95.202  -73.603  52.645  1
271615  95.245  -73.609  52.614  1
271616  95.288  -73.616  52.584  1
271617  95.331  -73.623  52.553  1
271618  95.367  -73.634  52.523  1
271619  95.399  -73.649  52.491  1
271620  95.431  -73.663  52.459  1
271621  95.463  -73.678  52.425  1
271622  95.495  -73.692  52.393  1
271623  95.527  -73.706  52.362  1
271624  95.554  -73.697  52.333  1
271625  95.580  -73.685  52.305  1
271626  95.607  -73.673  52.277  1
271627  95.633  -73.662  52.250  1
271628  95.660  -73.650  52.223  1
271629  95.686  -73.637  52.199  1
271630  95.712  -73.626  52.173  1
271631  95.751  -73.614  52.146  1
271632  95.791  -73.603  52.116  1
271633  95.831  -73.592  52.085  1
271634  95.864  -73.599  52.054  1
271635  95.894  -73.612  52.023  1
271636  95.923  -73.625  51.992  1
271637  95.953  -73.639  51.960  1
271638  95.983  -73.652  51.928  1
271639  96.013  -73.665  51.896  1
271640  96.048  -73.669  51.861  1
271641  96.085  -73.668  51.826  1
271642  96.104  -73.666  51.791  1
271643  96.117  -73.657  51.757  1
271644  96.133  -73.644  51.723  1
271645  96.145  -73.632  51.688  1
271646  96.136  -73.632  51.653  1
271647  96.143  -73.635  51.620  1
271648  96.179  -73.646  51.587  1
271649  96.226  -73.666  51.554  1
271650  96.273  -73.687  51.521  1
271651  96.320  -73.706  51.488  1
271652  96.342  -73.716  51.456  1
271653  96.364  -73.725  51.424  1
271654  96.386  -73.734  51.393  1
271655  96.407  -73.742  51.362  1
271656  96.429  -73.751  51.331  1
271657  96.450  -73.760  51.302  1
271658  96.472  -73.769  51.272  1
271659  96.493  -73.778  51.242  1
271660  96.515  -73.787  51.212  1
271661  96.537  -73.796  51.184  1
271662  96.553  -73.796  51.157  1
271663  96.567  -73.791  51.129  1
271664  96.621  -73.789  51.104  1
271665  96.658  -73.792  51.080  1
271666  96.691  -73.789  51.059  1
271667  96.726  -73.786  51.038  1
271668  96.759  -73.782  51.019  1
271669  96.793  -73.779  51.000  1
271670  96.836  -73.785  50.984  1
271671  96.855  -73.799  50.968  1
271672  96.866  -73.815  50.953  1
271673  96.878  -73.831  50.941  1
271674  96.907  -73.843  50.930  1
271675  96.937  -73.856  50.921  1
271676  96.969  -73.869  50.913  1
271677  97.004  -73.885  50.907  1
271678  97.037  -73.881  50.901  1
271679  97.069  -73.869  50.898  1
271680  97.101  -73.859  50.895  1
271681  97.133  -73.848  50.895  1
271682  97.165  -73.837  50.895  1
271683  97.197  -73.826  50.895  1
271684  97.227  -73.815  50.895  1
271685  97.250  -73.812  50.890  1
271686  97.270  -73.818  50.887  1
271687  97.289  -73.823  50.884  1
271688  97.308  -73.829  50.879  1
271689  97.328  -73.835  50.870  1
271690  97.347  -73.841  50.863  1
271691  97.367  -73.846  50.857  1
271692  97.386  -73.852  50.849  1
271693  97.406  -73.857  50.842  1
271694  97.425  -73.863  50.834  1
271695  97.445  -73.869  50.823  1
271696  97.474  -73.874  50.807  1
271697  97.514  -73.879  50.781  1
271698  97.554  -73.885  50.748  1
271699  97.594  -73.889  50.710  1
271700  97.634  -73.894  50.667  1
271701  97.674  -73.900  50.623  1
271702  97.714  -73.904  50.574  1
271703  97.754  -73.910  50.524  1
271704  97.788  -73.919  50.475  1
271705  97.814  -73.937  50.429  1
271706  97.841  -73.954  50.382  1
271707  97.867  -73.971  50.335  1
271708  97.893  -73.988  50.289  1
271709  97.920  -74.004  50.244  1
271710  97.946  -74.022  50.198  1
271711  97.986  -74.033  50.149  1
271712  98.027  -74.043  50.099  1
271713  98.069  -74.054  50.043  1
271714  98.101  -74.065  49.986  1
271715  98.128  -74.076  49.926  1
271716  98.156  -74.088  49.863  1
271717  98.183  -74.099  49.799  1
271718  98.210  -74.111  49.734  1
271719  98.237  -74.122  49.670  1
271720  98.265  -74.134  49.605  1
271721  98.292  -74.145  49.540  1
271722  98.319  -74.157  49.476  1
271723  98.347  -74.168  49.414  1
271724  98.368  -74.181  49.355  1
271725  98.397  -74.179  49.300  1
271726  98.423  -74.191  49.244  1
271727  98.449  -74.201  49.187  1
271728  98.503  -74.193  49.129  1
271729  98.557  -74.225  49.070  1
271730  98.593  -74.248  49.011  1
271731  98.629  -74.271  48.954  1
271732  98.665  -74.295  48.900  1
271733  98.693  -74.313  48.849  1
271734  98.720  -74.330  48.801  1
271735  98.745  -74.355  48.751  1
271736  98.772  -74.365  48.700  1
271737  98.802  -74.373  48.650  1
271738  98.833  -74.380  48.600  1
271739  98.863  -74.387  48.550  1
271740  98.894  -74.395  48.498  1
271741  98.924  -74.402  48.447  1
271742  98.956  -74.410  48.395  1
271743  98.988  -74.416  48.342  1
271744  99.020  -74.421  48.291  1
271745  99.053  -74.426  48.239  1
271746  99.085  -74.430  48.188  1
271747  99.117  -74.436  48.137  1
271748  99.149  -74.440  48.087  1
271749  99.179  -74.450  48.039  1
271750  99.203  -74.471  47.992  1
271751  99.227  -74.492  47.946  1
271752  99.252  -74.512  47.901  1
271753  99.276  -74.533  47.856  1
271754  99.300  -74.553  47.811  1
271755  99.338  -74.569  47.767  1
271756  99.379  -74.584  47.725  1
271757  99.420  -74.599  47.684  1
271758  99.457  -74.612  47.644  1
271759  99.487  -74.620  47.605  1
271760  99.516  -74.628  47.567  1
271761  99.546  -74.637  47.529  1
271762  99.576  -74.645  47.494  1
271763  99.606  -74.653  47.458  1
271764  99.636  -74.662  47.421  1
271765  99.665  -74.671  47.385  1
271766  99.695  -74.679  47.348  1
271767  99.724  -74.687  47.312  1
271768  99.752  -74.693  47.276  1
271769  99.784  -74.702  47.244  1
271770  99.822  -74.712  47.211  1
271771  99.856  -74.713  47.179  1
271772  99.890  -74.714  47.148  1
271773  99.924  -74.725  47.117  1
271774  99.957  -74.740  47.086  1
271775  99.991  -74.756  47.057  1
271776  100.024  -74.770  47.029  1
271777  100.057  -74.785  47.002  1
271778  100.091  -74.800  46.975  1
271779  100.124  -74.815  46.948  1
271780  100.157  -74.830  46.922  1
271781  100.191  -74.845  46.897  1
271782  100.224  -74.859  46.874  1
271783  100.258  -74.874  46.850  1
271784  100.286  -74.885  46.827  1
271785  100.311  -74.895  46.801  1
271786  100.336  -74.907  46.773  1
271787  100.361  -74.919  46.744  1
271788  100.385  -74.932  46.716  1
271789  100.411  -74.944  46.691  1
271790  100.435  -74.957  46.663  1
271791  100.460  -74.969  46.636  1
271792  100.485  -74.982  46.609  1
271793  100.510  -74.994  46.580  1
271794  100.536  -75.007  46.552  1
271795  100.564  -75.023  46.524  1
271796  100.583  -75.040  46.497  1
271797  100.602  -75.056  46.468  1
271798  100.621  -75.072  46.440  1
271799  100.645  -75.085  46.411  1
271800  100.673  -75.095  46.383  1
271801  100.700  -75.106  46.354  1
271802  100.727  -75.116  46.325  1
271803  100.755  -75.127  46.297  1
271804  100.782  -75.138  46.271  1
271805  100.809  -75.149  46.246  1
271806  100.837  -75.155  46.219  1
271807  100.864  -75.150  46.190  1
271808  100.907  -75.148  46.161  1
271809  100.944  -75.151  46.132  1
271810  100.968  -75.167  46.103  1
271811  100.992  -75.183  46.073  1
271812  101.016  -75.199  46.043  1
271813  101.040  -75.215  46.013  1
271814  101.064  -75.232  45.981  1
271815  101.092  -75.245  45.948  1
271816  101.121  -75.257  45.916  1
271817  101.149  -75.269  45.882  1
271818  101.173  -75.271  45.848  1
271819  101.195  -75.270  45.814  1
271820  101.220  -75.275  45.780  1
271821  101.255  -75.295  45.748  1
271822  101.289  -75.314  45.715  1
271823  101.324  -75.333  45.683  1
271824  101.358  -75.352  45.650  1
271825  101.393  -75.372  45.618  1
271826  101.427  -75.392  45.586  1
271827  101.462  -75.411  45.554  1
271828  101.496  -75.430  45.522  1
271829  101.531  -75.450  45.492  1
271830  101.565  -75.467  45.461  1
271831  101.599  -75.483  45.430  1
271832  101.632  -75.499  45.400  1
271833  101.666  -75.514  45.370  1
271834  101.705  -75.546  45.341  1
271835  101.750  -75.577  45.312  1
271836  101.759  -75.581  45.283  1
271837  101.778  -75.587  45.256  1
271838  101.795  -75.587  45.228  1
271839  101.813  -75.588  45.200  1
271840  101.830  -75.589  45.172  1
271841  101.847  -75.589  45.146  1
271842  101.865  -75.590  45.120  1
271843  101.883  -75.590  45.094  1
271844  101.900  -75.591  45.068  1
271845  101.917  -75.591  45.043  1
271846  101.935  -75.592  45.018  1
271847  101.952  -75.593  44.993  1
271848  101.970  -75.593  44.967  1
271849  101.987  -75.593  44.944  1
272200  92.261  -73.179  54.777  1
272201  92.291  -73.189  54.766  1
272202  92.322  -73.200  54.753  1
272203  92.353  -73.210  54.740  1
272204  92.383  -73.221  54.727  1
272205  92.414  -73.231  54.715  1
272206  92.444  -73.241  54.702  1
272207  92.475  -73.252  54.691  1
272208  92.506  -73.262  54.679  1
272209  92.536  -73.272  54.668  1
272210  92.567  -73.283  54.657  1
272211  92.598  -73.293  54.646  1
272212  92.629  -73.303  54.636  1
272213  92.659  -73.314  54.627  1
272214  92.690  -73.324  54.618  1
272215  92.729  -73.335  54.611  1
272216  92.772  -73.346  54.604  1
272217  92.815  -73.357  54.599  1
272218  92.858  -73.368  54.595  1
272219  92.901  -73.379  54.593  1
272220  92.944  -73.390  54.592  1
272221  92.987  -73.401  54.591  1
272222  93.029  -73.412  54.591  1
272223  93.072  -73.423  54.589  1
272224  93.115  -73.434  54.587  1
272225  93.138  -73.425  54.585  1
272226  93.160  -73.417  54.583  1
272227  93.183  -73.409  54.582  1
272228  93.205  -73.400  54.580  1
272229  93.242  -73.410  54.579  1
272230  93.283  -73.424  54.575  1
272231  93.324  -73.438  54.571  1
272232  93.360  -73.451  54.568  1
272233  93.392  -73.463  54.564  1
272234  93.424  -73.476  54.558  1
272235  93.452  -73.487  54.551  1
272236  93.471  -73.493  54.543  1
272237  93.491  -73.496  54.531  1
272238  93.512  -73.499  54.518  1
272239  93.534  -73.501  54.505  1
272240  93.555  -73.503  54.492  1
272241  93.575  -73.503  54.478  1
272242  93.595  -73.500  54.467  1
272243  93.615  -73.498  54.454  1
272244  93.635  -73.496  54.439  1
272245  93.655  -73.493  54.425  1
272246  93.675  -73.491  54.411  1
272247  93.695  -73.489  54.397  1
272248  93.715  -73.487  54.382  1
272249  93.735  -73.484  54.368  1
272250  93.755  -73.481  54.351  1
272251  93.774  -73.475  54.332  1
272252  93.792  -73.470  54.313  1
272253  93.812  -73.465  54.291  1
272254  93.830  -73.460  54.270  1
272255  93.849  -73.455  54.250  1
272256  93.868  -73.449  54.229  1
272257  93.887  -73.444  54.205  1
272258  93.906  -73.439  54.181  1
272259  93.924  -73.434  54.158  1
272260  93.943  -73.428  54.135  1
272261  93.962  -73.423  54.114  1
272262  93.981  -73.418  54.091  1
272263  94.000  -73.413  54.068  1
272264  94.018  -73.408  54.043  1
272265  94.038  -73.402  54.020  1
272266  94.056  -73.397  53.996  1
272267  94.075  -73.392  53.972  1
272268  94.094  -73.387  53.948  1
272269  94.119  -73.398  53.923  1
272270  94.145  -73.412  53.898  1
272271  94.172  -73.426  53.871  1
272272  94.198  -73.433  53.846  1
272273  94.223  -73.440  53.820  1
272274  94.249  -73.448  53.795  1
272275  94.275  -73.455  53.770  1
272276  94.300  -73.462  53.744  1
272277  94.326  -73.470  53.717  1
272278  94.352  -73.477  53.691  1
272279  94.378  -73.484  53.664  1
272280  94.403  -73.492  53.636  1
272281  94.429  -73.499  53.609  1
272282  94.455  -73.507  53.582  1
272283  94.481  -73.514  53.556  1
272284  94.506  -73.521  53.528  1
272285  94.532  -73.529  53.501  1
272286  94.558  -73.536  53.475  1
272287  94.583  -73.543  53.450  1
272288  94.609  -73.551  53.425  1
272289  94.635  -73.559  53.400  1
272290  94.661  -73.565  53.377  1
272291  94.687  -73.573  53.354  1
272292  94.712  -73.581  53.333  1
272293  94.735  -73.587  53.311  1
272294  94.742  -73.585  53.287  1
272295  94.749  -73.584  53.263  1
272296  94.760  -73.585  53.237  1
272297  94.780  -73.589  53.211  1
272298  94.801  -73.593  53.182  1
272299  94.821  -73.598  53.152  1
272300  94.859  -73.590  53.122  1
272301  94.899  -73.581  53.089  1
272302  94.914  -73.594  53.055  1
272303  94.928  -73.607  53.021  1
272304  94.943  -73.621  52.987  1
272305  94.957  -73.634  52.952  1
272306  94.972  -73.647  52.918  1
272307  94.986  -73.660  52.884  1
272308  95.004  -73.669  52.850  1
272309  95.030  -73.672  52.817  1
272310  95.055  -73.673  52.785  1
272311  95.079  -73.675  52.753  1
272312  95.104  -73.666  52.722  1
272313  95.126  -73.637  52.692  1
272314  95.148  -73.609  52.662  1
272315  95.184  -73.605  52.631  1
272316  95.227  -73.612  52.601  1
272317  95.270  -73.618  52.572  1
272318  95.313  -73.625  52.543  1
272319  95.356  -73.633  52.514  1
272320  95.399  -73.640  52.483  1
272321  95.438  -73.650  52.451  1
272322  95.469  -73.664  52.419  1
272323  95.501  -73.678  52.388  1
272324  95.532  -73.685  52.359  1
272325  95.558  -73.673  52.332  1
272326  95.585  -73.661  52.304  1
272327  95.611  -73.650  52.277  1
272328  95.638  -73.634  52.251  1
272329  95.666  -73.612  52.225  1
272330  95.693  -73.590  52.201  1
272331  95.721  -73.568  52.175  1
272332  95.753  -73.550  52.148  1
272333  95.792  -73.542  52.119  1
272334  95.822  -73.556  52.089  1
272335  95.851  -73.568  52.059  1
272336  95.881  -73.581  52.029  1
272337  95.911  -73.595  51.999  1
272338  95.941  -73.608  51.967  1
272339  95.971  -73.622  51.935  1
272340  96.001  -73.634  51.903  1
272341  96.035  -73.639  51.868  1
272342  96.072  -73.639  51.834  1
272343  96.108  -73.639  51.799  1
272344  96.117  -73.636  51.764  1
272345  96.131  -73.626  51.729  1
272346  96.148  -73.612  51.694  1
272347  96.141  -73.612  51.660  1
272348  96.143  -73.614  51.627  1
272349  96.190  -73.634  51.593  1
272350  96.237  -73.654  51.559  1
272351  96.285  -73.675  51.526  1
272352  96.331  -73.695  51.493  1
272353  96.361  -73.707  51.461  1
272354  96.382  -73.716  51.429  1
272355  96.404  -73.725  51.397  1
272356  96.426  -73.734  51.367  1
272357  96.447  -73.743  51.336  1
272358  96.469  -73.751  51.306  1
272359  96.490  -73.760  51.276  1
272360  96.512  -73.769  51.246  1
272361  96.526  -73.766  51.216  1
272362  96.539  -73.760  51.188  1
272363  96.552  -73.754  51.161  1
272364  96.576  -73.748  51.135  1
272365  96.648  -73.741  51.109  1
272366  96.689  -73.751  51.084  1
272367  96.727  -73.757  51.062  1
272368  96.761  -73.754  51.040  1
272369  96.795  -73.751  51.021  1
272370  96.831  -73.750  51.002  1
272371  96.876  -73.756  50.985  1
272372  96.920  -73.762  50.969  1
272373  96.934  -73.777  50.954  1
272374  96.945  -73.793  50.942  1
272375  96.957  -73.810  50.931  1
272376  96.968  -73.825  50.921  1
272377  96.979  -73.841  50.913  1
272378  96.996  -73.848  50.906  1
272379  97.028  -73.839  50.900  1
272380  97.061  -73.829  50.896  1
272381  97.092  -73.820  50.892  1
272382  97.124  -73.810  50.891  1
272383  97.157  -73.801  50.890  1
272384  97.189  -73.792  50.888  1
272385  97.221  -73.785  50.887  1
272386  97.240  -73.788  50.885  1
272387  97.259  -73.794  50.882  1
272388  97.279  -73.799  50.880  1
272389  97.298  -73.805  50.876  1
272390  97.318  -73.810  50.868  1
272391  97.337  -73.816  50.860  1
272392  97.357  -73.822  50.853  1
272393  97.376  -73.828  50.846  1
272394  97.396  -73.833  50.839  1
272395  97.416  -73.839  50.832  1
272396  97.441  -73.844  50.822  1
272397  97.480  -73.849  50.807  1
272398  97.521  -73.854  50.783  1
272399  97.561  -73.860  50.751  1
272400  97.600  -73.865  50.714  1
272401  97.641  -73.869  50.671  1
272402  97.680  -73.875  50.627  1
272403  97.721  -73.880  50.578  1
272404  97.760  -73.885  50.527  1
272405  97.800  -73.891  50.476  1
272406  97.826  -73.907  50.428  1
272407  97.853  -73.925  50.380  1
272408  97.879  -73.941  50.333  1
272409  97.905  -73.958  50.289  1
272410  97.932  -73.976  50.240  1
272411  97.962  -73.991  50.191  1
272412  98.003  -74.001  50.140  1
272413  98.045  -74.011  50.088  1
272414  98.087  -74.022  50.031  1
272415  98.129  -74.032  49.972  1
272416  98.169  -74.043  49.911  1
272417  98.197  -74.054  49.847  1
272418  98.224  -74.066  49.782  1
272419  98.251  -74.077  49.717  1
272420  98.279  -74.089  49.652  1
272421  98.306  -74.100  49.589  1
272422  98.334  -74.112  49.525  1
272423  98.364  -74.124  49.459  1
272424  98.370  -74.134  49.396  1
272425  98.375  -74.146  49.335  1
272426  98.416  -74.154  49.279  1
272427  98.450  -74.133  49.222  1
272428  98.480  -74.129  49.166  1
272429  98.508  -74.139  49.108  1
272430  98.566  -74.163  49.050  1
272431  98.610  -74.206  48.992  1
272432  98.646  -74.230  48.937  1
272433  98.677  -74.249  48.884  1
272434  98.704  -74.270  48.833  1
272435  98.727  -74.298  48.785  1
272436  98.751  -74.327  48.736  1
272437  98.774  -74.334  48.686  1
272438  98.804  -74.341  48.636  1
272439  98.835  -74.349  48.586  1
272440  98.865  -74.355  48.536  1
272441  98.896  -74.363  48.485  1
272442  98.927  -74.371  48.434  1
272443  98.959  -74.380  48.382  1
272444  98.992  -74.389  48.330  1
272445  99.024  -74.395  48.278  1
272446  99.057  -74.399  48.226  1
272447  99.089  -74.405  48.175  1
272448  99.121  -74.409  48.125  1
272449  99.153  -74.415  48.075  1
272450  99.184  -74.422  48.028  1
272451  99.208  -74.443  47.981  1
272452  99.232  -74.463  47.935  1
272453  99.257  -74.483  47.891  1
272454  99.281  -74.505  47.845  1
272455  99.312  -74.523  47.801  1
272456  99.353  -74.537  47.758  1
272457  99.394  -74.552  47.716  1
272458  99.435  -74.567  47.675  1
272459  99.475  -74.581  47.635  1
272460  99.505  -74.590  47.597  1
272461  99.535  -74.598  47.559  1
272462  99.564  -74.607  47.521  1
272463  99.594  -74.615  47.487  1
272464  99.624  -74.624  47.451  1
272465  99.654  -74.632  47.415  1
272466  99.684  -74.640  47.378  1
272467  99.713  -74.649  47.342  1
272468  99.743  -74.657  47.306  1
272469  99.773  -74.665  47.271  1
272470  99.802  -74.674  47.238  1
272471  99.833  -74.682  47.205  1
272472  99.868  -74.686  47.174  1
272473  99.902  -74.697  47.142  1
272474  99.935  -74.712  47.111  1
272475  99.969  -74.727  47.080  1
272476  100.002  -74.742  47.051  1
272477  100.036  -74.756  47.024  1
272478  100.069  -74.771  46.996  1
272479  100.102  -74.785  46.970  1
272480  100.136  -74.800  46.943  1
272481  100.169  -74.814  46.917  1
272482  100.203  -74.828  46.891  1
272483  100.236  -74.844  46.868  1
272484  100.269  -74.858  46.845  1
272485  100.294  -74.867  46.821  1
272486  100.320  -74.877  46.795  1
272487  100.345  -74.887  46.766  1
272488  100.370  -74.896  46.738  1
272489  100.395  -74.906  46.709  1
272490  100.420  -74.915  46.682  1
272491  100.445  -74.926  46.655  1
272492  100.470  -74.938  46.628  1
272493  100.495  -74.950  46.599  1
272494  100.520  -74.963  46.571  1
272495  100.545  -74.975  46.542  1
272496  100.570  -74.988  46.514  1
272497  100.595  -75.004  46.486  1
272498  100.614  -75.021  46.458  1
272499  100.635  -75.035  46.429  1
272500  100.662  -75.046  46.400  1
272501  100.690  -75.057  46.371  1
272502  100.717  -75.067  46.341  1
272503  100.745  -75.078  46.314  1
272504  100.772  -75.088  46.287  1
272505  100.799  -75.100  46.260  1
272506  100.827  -75.110  46.235  1
272507  100.854  -75.116  46.208  1
272508  100.889  -75.112  46.180  1
272509  100.925  -75.116  46.151  1
272510  100.949  -75.132  46.121  1
272511  100.973  -75.148  46.091  1
272512  100.997  -75.165  46.060  1
272513  101.025  -75.178  46.029  1
272514  101.053  -75.190  45.999  1
272515  101.082  -75.203  45.966  1
272516  101.111  -75.215  45.934  1
272517  101.140  -75.227  45.902  1
272518  101.169  -75.239  45.868  1
272519  101.191  -75.240  45.834  1
272520  101.215  -75.242  45.799  1
272521  101.250  -75.261  45.764  1
272522  101.284  -75.281  45.731  1
272523  101.319  -75.301  45.698  1
272524  101.353  -75.320  45.667  1
272525  101.388  -75.339  45.635  1
272526  101.422  -75.359  45.602  1
272527  101.457  -75.378  45.571  1
272528  101.491  -75.398  45.539  1
272529  101.526  -75.417  45.508  1
272530  101.560  -75.436  45.477  1
272531  101.595  -75.456  45.446  1
272532  101.629  -75.475  45.415  1
272533  101.663  -75.495  45.385  1
272534  101.698  -75.514  45.356  1
272535  101.732  -75.531  45.326  1
272536  101.758  -75.546  45.297  1
272537  101.775  -75.547  45.268  1
272538  101.793  -75.547  45.240  1
272539  101.810  -75.548  45.212  1
272540  101.828  -75.549  45.184  1
272541  101.845  -75.549  45.156  1
272542  101.863  -75.549  45.130  1
272543  101.880  -75.550  45.104  1
272544  101.898  -75.550  45.078  1
272545  101.915  -75.551  45.053  1
272546  101.933  -75.552  45.028  1
272547  101.950  -75.552  45.002  1
272548  101.967  -75.552  44.977  1
272549  101.985  -75.553  44.952  1
272550  102.003  -75.554  44.927  1
272901  92.257  -73.150  54.784  1
272902  92.287  -73.161  54.771  1
272903  92.317  -73.170  54.759  1
272904  92.348  -73.181  54.746  1
272905  92.379  -73.191  54.733  1
272906  92.410  -73.202  54.720  1
272907  92.440  -73.212  54.707  1
272908  92.471  -73.222  54.695  1
272909  92.502  -73.233  54.683  1
272910  92.532  -73.243  54.670  1
272911  92.563  -73.253  54.659  1
272912  92.593  -73.264  54.648  1
272913  92.624  -73.274  54.636  1
272914  92.655  -73.284  54.627  1
272915  92.686  -73.295  54.618  1
272916  92.726  -73.305  54.610  1
272917  92.769  -73.317  54.604  1
272918  92.812  -73.327  54.598  1
272919  92.855  -73.339  54.594  1
272920  92.898  -73.349  54.591  1
272921  92.940  -73.361  54.590  1
272922  92.984  -73.371  54.589  1
272923  93.026  -73.383  54.588  1
272924  93.069  -73.393  54.586  1
272925  93.112  -73.405  54.582  1
272926  93.149  -73.410  54.579  1
272927  93.171  -73.401  54.576  1
272928  93.194  -73.393  54.575  1
272929  93.216  -73.384  54.573  1
272930  93.252  -73.393  54.570  1
272931  93.293  -73.407  54.566  1
272932  93.334  -73.421  54.562  1
272933  93.374  -73.435  54.558  1
272934  93.408  -73.447  54.554  1
272935  93.440  -73.459  54.549  1
272936  93.460  -73.468  54.542  1
272937  93.478  -73.474  54.534  1
272938  93.499  -73.477  54.520  1
272939  93.520  -73.480  54.506  1
272940  93.541  -73.482  54.491  1
272941  93.561  -73.481  54.478  1
272942  93.581  -73.478  54.465  1
272943  93.602  -73.476  54.453  1
272944  93.622  -73.474  54.440  1
272945  93.642  -73.471  54.424  1
272946  93.661  -73.469  54.409  1
272947  93.682  -73.467  54.395  1
272948  93.701  -73.462  54.380  1
272949  93.719  -73.457  54.365  1
272950  93.738  -73.452  54.351  1
272951  93.757  -73.446  54.333  1
272952  93.776  -73.441  54.313  1
272953  93.795  -73.436  54.293  1
272954  93.814  -73.430  54.271  1
272955  93.833  -73.425  54.250  1
272956  93.851  -73.420  54.229  1
272957  93.870  -73.415  54.207  1
272958  93.889  -73.410  54.183  1
272959  93.908  -73.405  54.159  1
272960  93.927  -73.399  54.135  1
272961  93.945  -73.394  54.112  1
272962  93.965  -73.389  54.089  1
272963  93.983  -73.383  54.066  1
272964  94.002  -73.378  54.043  1
272965  94.021  -73.373  54.018  1
272966  94.040  -73.368  53.994  1
272967  94.059  -73.363  53.970  1
272968  94.077  -73.358  53.946  1
272969  94.097  -73.352  53.922  1
272970  94.117  -73.352  53.897  1
272971  94.144  -73.367  53.872  1
272972  94.170  -73.381  53.846  1
272973  94.196  -73.396  53.820  1
272974  94.222  -73.403  53.795  1
272975  94.248  -73.411  53.770  1
272976  94.274  -73.418  53.745  1
272977  94.299  -73.425  53.720  1
272978  94.325  -73.433  53.694  1
272979  94.351  -73.440  53.667  1
272980  94.377  -73.447  53.640  1
272981  94.402  -73.455  53.613  1
272982  94.428  -73.462  53.587  1
272983  94.454  -73.470  53.561  1
272984  94.479  -73.477  53.534  1
272985  94.505  -73.484  53.507  1
272986  94.531  -73.492  53.481  1
272987  94.557  -73.499  53.455  1
272988  94.582  -73.506  53.430  1
272989  94.608  -73.514  53.405  1
272990  94.634  -73.521  53.382  1
272991  94.660  -73.528  53.359  1
272992  94.685  -73.536  53.336  1
272993  94.711  -73.543  53.315  1
272994  94.737  -73.550  53.291  1
272995  94.753  -73.553  53.267  1
272996  94.760  -73.553  53.243  1
272997  94.767  -73.552  53.218  1
272998  94.783  -73.554  53.191  1
272999  94.804  -73.559  53.162  1
273000  94.824  -73.563  53.132  1
273001  94.845  -73.568  53.102  1
273002  94.881  -73.561  53.069  1
273003  94.921  -73.551  53.037  1
273004  94.936  -73.565  53.004  1
273005  94.950  -73.578  52.970  1
273006  94.965  -73.591  52.936  1
273007  94.979  -73.605  52.902  1
273008  94.993  -73.618  52.868  1
273009  95.008  -73.631  52.835  1
273010  95.022  -73.644  52.802  1
273011  95.039  -73.655  52.770  1
273012  95.064  -73.656  52.739  1
273013  95.090  -73.659  52.709  1
273014  95.114  -73.650  52.679  1
273015  95.136  -73.622  52.649  1
273016  95.166  -73.607  52.619  1
273017  95.209  -73.614  52.589  1
273018  95.252  -73.622  52.561  1
273019  95.296  -73.628  52.534  1
273020  95.338  -73.635  52.505  1
273021  95.382  -73.642  52.474  1
273022  95.424  -73.649  52.444  1
273023  95.467  -73.656  52.413  1
273024  95.508  -73.665  52.384  1
273025  95.536  -73.661  52.357  1
273026  95.563  -73.640  52.332  1
273027  95.591  -73.618  52.305  1
273028  95.618  -73.597  52.278  1
273029  95.645  -73.576  52.252  1
273030  95.672  -73.556  52.227  1
273031  95.699  -73.537  52.201  1
273032  95.726  -73.517  52.176  1
273033  95.753  -73.502  52.149  1
273034  95.779  -73.512  52.121  1
273035  95.809  -73.524  52.094  1
273036  95.839  -73.538  52.065  1
273037  95.869  -73.551  52.035  1
273038  95.899  -73.565  52.005  1
273039  95.929  -73.578  51.974  1
273040  95.959  -73.590  51.943  1
273041  95.988  -73.604  51.910  1
273042  96.022  -73.610  51.876  1
273043  96.058  -73.609  51.841  1
273044  96.095  -73.609  51.806  1
273045  96.121  -73.609  51.771  1
273046  96.130  -73.606  51.735  1
273047  96.145  -73.595  51.700  1
273048  96.144  -73.590  51.667  1
273049  96.164  -73.603  51.634  1
273050  96.203  -73.622  51.600  1
273051  96.248  -73.643  51.566  1
273052  96.296  -73.662  51.533  1
273053  96.342  -73.683  51.500  1
273054  96.379  -73.698  51.467  1
273055  96.400  -73.707  51.435  1
273056  96.422  -73.716  51.403  1
273057  96.444  -73.725  51.372  1
273058  96.465  -73.734  51.342  1
273059  96.486  -73.742  51.311  1
273060  96.499  -73.736  51.281  1
273061  96.512  -73.730  51.251  1
273062  96.525  -73.725  51.221  1
273063  96.538  -73.719  51.193  1
273064  96.551  -73.713  51.166  1
273065  96.593  -73.706  51.140  1
273066  96.669  -73.697  51.113  1
273067  96.716  -73.703  51.089  1
273068  96.757  -73.714  51.065  1
273069  96.797  -73.722  51.044  1
273070  96.830  -73.719  51.025  1
273071  96.870  -73.722  51.005  1
273072  96.914  -73.727  50.986  1
273073  96.959  -73.734  50.970  1
273074  96.965  -73.738  50.954  1
273075  96.959  -73.753  50.943  1
273076  96.953  -73.768  50.932  1
273077  96.947  -73.783  50.922  1
273078  96.964  -73.796  50.913  1
273079  96.994  -73.808  50.906  1
273080  97.022  -73.812  50.900  1
273081  97.053  -73.803  50.895  1
273082  97.086  -73.794  50.890  1
273083  97.117  -73.784  50.887  1
273084  97.150  -73.775  50.885  1
273085  97.182  -73.766  50.883  1
273086  97.216  -73.763  50.880  1
273087  97.244  -73.764  50.879  1
273088  97.249  -73.769  50.878  1
273089  97.269  -73.775  50.876  1
273090  97.289  -73.781  50.873  1
273091  97.308  -73.786  50.865  1
273092  97.327  -73.792  50.858  1
273093  97.347  -73.797  50.850  1
273094  97.367  -73.803  50.844  1
273095  97.386  -73.809  50.838  1
273096  97.407  -73.814  50.831  1
273097  97.447  -73.819  50.821  1
273098  97.488  -73.825  50.805  1
273099  97.527  -73.829  50.781  1
273100  97.568  -73.835  50.750  1
273101  97.607  -73.840  50.713  1
273102  97.647  -73.844  50.672  1
273103  97.687  -73.850  50.627  1
273104  97.727  -73.855  50.578  1
273105  97.768  -73.860  50.527  1
273106  97.807  -73.865  50.476  1
273107  97.838  -73.879  50.427  1
273108  97.864  -73.895  50.378  1
273109  97.891  -73.912  50.332  1
273110  97.917  -73.929  50.287  1
273111  97.943  -73.946  50.236  1
273112  97.980  -73.959  50.184  1
273113  98.021  -73.969  50.131  1
273114  98.063  -73.980  50.077  1
273115  98.104  -73.990  50.019  1
273116  98.146  -74.001  49.958  1
273117  98.187  -74.011  49.896  1
273118  98.229  -74.021  49.832  1
273119  98.266  -74.032  49.765  1
273120  98.293  -74.044  49.699  1
273121  98.320  -74.055  49.635  1
273122  98.347  -74.067  49.571  1
273123  98.386  -74.081  49.509  1
273124  98.382  -74.089  49.443  1
273125  98.376  -74.098  49.378  1
273126  98.381  -74.111  49.316  1
273127  98.428  -74.140  49.259  1
273128  98.464  -74.127  49.201  1
273129  98.499  -74.107  49.145  1
273130  98.533  -74.085  49.088  1
273131  98.573  -74.095  49.030  1
273132  98.625  -74.157  48.974  1
273133  98.662  -74.186  48.919  1
273134  98.686  -74.212  48.867  1
273135  98.710  -74.241  48.816  1
273136  98.733  -74.269  48.769  1
273137  98.757  -74.298  48.720  1
273138  98.780  -74.317  48.671  1
273139  98.806  -74.310  48.622  1
273140  98.836  -74.317  48.572  1
273141  98.867  -74.324  48.522  1
273142  98.898  -74.332  48.472  1
273143  98.931  -74.341  48.422  1
273144  98.963  -74.350  48.370  1
273145  98.996  -74.359  48.318  1
273146  99.028  -74.368  48.266  1
273147  99.061  -74.373  48.214  1
273148  99.093  -74.378  48.163  1
273149  99.125  -74.383  48.113  1
273150  99.157  -74.388  48.064  1
273151  99.189  -74.393  48.017  1
273152  99.213  -74.414  47.970  1
273153  99.238  -74.435  47.925  1
273154  99.262  -74.455  47.881  1
273155  99.286  -74.476  47.836  1
273156  99.327  -74.491  47.793  1
273157  99.368  -74.505  47.750  1
273158  99.409  -74.521  47.708  1
273159  99.449  -74.535  47.668  1
273160  99.491  -74.550  47.628  1
273161  99.523  -74.560  47.589  1
273162  99.553  -74.568  47.552  1
273163  99.582  -74.577  47.515  1
273164  99.612  -74.585  47.480  1
273165  99.642  -74.593  47.445  1
273166  99.672  -74.602  47.409  1
273167  99.702  -74.610  47.373  1
273168  99.731  -74.619  47.336  1
273169  99.761  -74.628  47.300  1
273170  99.791  -74.636  47.265  1
273171  99.821  -74.644  47.231  1
273172  99.851  -74.653  47.200  1
273173  99.894  -74.663  47.168  1
273174  99.913  -74.682  47.137  1
273175  99.946  -74.697  47.105  1
273176  99.980  -74.712  47.074  1
273177  100.013  -74.726  47.046  1
273178  100.047  -74.740  47.018  1
273179  100.080  -74.755  46.991  1
273180  100.114  -74.769  46.965  1
273181  100.147  -74.784  46.938  1
273182  100.181  -74.798  46.912  1
273183  100.214  -74.812  46.886  1
273184  100.248  -74.827  46.863  1
273185  100.278  -74.840  46.840  1
273186  100.303  -74.849  46.815  1
273187  100.329  -74.859  46.787  1
273188  100.354  -74.869  46.759  1
273189  100.379  -74.878  46.729  1
273190  100.404  -74.888  46.701  1
273191  100.429  -74.897  46.674  1
273192  100.454  -74.907  46.646  1
273193  100.479  -74.916  46.618  1
273194  100.504  -74.925  46.589  1
273195  100.530  -74.935  46.561  1
273196  100.555  -74.945  46.532  1
273197  100.579  -74.957  46.503  1
273198  100.605  -74.970  46.476  1
273199  100.626  -74.986  46.448  1
273200  100.653  -74.997  46.419  1
273201  100.681  -75.007  46.390  1
273202  100.708  -75.018  46.360  1
273203  100.735  -75.029  46.330  1
273204  100.763  -75.039  46.303  1
273205  100.790  -75.050  46.276  1
273206  100.817  -75.061  46.249  1
273207  100.845  -75.072  46.224  1
273208  100.872  -75.078  46.198  1
273209  100.906  -75.082  46.169  1
273210  100.930  -75.098  46.140  1
273211  100.958  -75.111  46.109  1
273212  100.986  -75.124  46.079  1
273213  101.015  -75.136  46.048  1
273214  101.044  -75.148  46.016  1
273215  101.073  -75.160  45.985  1
273216  101.102  -75.173  45.952  1
273217  101.130  -75.185  45.920  1
273218  101.159  -75.198  45.887  1
273219  101.188  -75.210  45.853  1
273220  101.210  -75.210  45.820  1
273221  101.245  -75.229  45.785  1
273222  101.279  -75.248  45.749  1
273223  101.314  -75.267  45.714  1
273224  101.348  -75.287  45.681  1
273225  101.383  -75.307  45.650  1
273226  101.417  -75.326  45.618  1
273227  101.452  -75.345  45.587  1
273228  101.486  -75.365  45.555  1
273229  101.520  -75.384  45.524  1
273230  101.555  -75.404  45.493  1
273231  101.589  -75.422  45.462  1
273232  101.622  -75.441  45.431  1
273233  101.656  -75.459  45.401  1
273234  101.689  -75.478  45.371  1
273235  101.723  -75.496  45.341  1
273236  101.755  -75.508  45.312  1
273237  101.773  -75.506  45.283  1
273238  101.790  -75.507  45.254  1
273239  101.808  -75.508  45.226  1
273240  101.825  -75.508  45.197  1
273241  101.843  -75.508  45.170  1
273242  101.860  -75.509  45.142  1
273243  101.878  -75.510  45.114  1
273244  101.895  -75.510  45.089  1
273245  101.912  -75.511  45.063  1
273246  101.930  -75.511  45.037  1
273247  101.948  -75.512  45.011  1
273248  101.965  -75.512  44.986  1
273249  101.982  -75.513  44.961  1
273250  102.000  -75.514  44.936  1
273602  92.252  -73.120  54.791  1
273603  92.283  -73.131  54.778  1
273604  92.313  -73.142  54.765  1
273605  92.344  -73.152  54.752  1
273606  92.375  -73.162  54.738  1
273607  92.406  -73.173  54.725  1
273608  92.436  -73.183  54.712  1
273609  92.467  -73.193  54.699  1
273610  92.497  -73.203  54.686  1
273611  92.528  -73.214  54.673  1
273612  92.559  -73.224  54.661  1
273613  92.589  -73.234  54.650  1
273614  92.620  -73.245  54.638  1
273615  92.651  -73.255  54.628  1
273616  92.682  -73.265  54.618  1
273617  92.723  -73.277  54.610  1
273618  92.766  -73.287  54.603  1
273619  92.808  -73.299  54.598  1
273620  92.852  -73.309  54.594  1
273621  92.895  -73.321  54.591  1
273622  92.937  -73.331  54.589  1
273623  92.980  -73.343  54.586  1
273624  93.023  -73.353  54.584  1
273625  93.066  -73.365  54.581  1
273626  93.109  -73.375  54.577  1
273627  93.152  -73.387  54.572  1
273628  93.183  -73.386  54.569  1
273629  93.205  -73.377  54.567  1
273630  93.227  -73.368  54.564  1
273631  93.262  -73.375  54.562  1
273632  93.302  -73.390  54.557  1
273633  93.343  -73.403  54.553  1
273634  93.384  -73.418  54.549  1
273635  93.423  -73.431  54.544  1
273636  93.449  -73.441  54.539  1
273637  93.468  -73.448  54.532  1
273638  93.486  -73.456  54.525  1
273639  93.506  -73.459  54.510  1
273640  93.528  -73.461  54.494  1
273641  93.548  -73.459  54.479  1
273642  93.568  -73.457  54.465  1
273643  93.588  -73.455  54.452  1
273644  93.608  -73.452  54.439  1
273645  93.627  -73.449  54.426  1
273646  93.646  -73.443  54.410  1
273647  93.665  -73.438  54.394  1
273648  93.684  -73.433  54.379  1
273649  93.703  -73.427  54.364  1
273650  93.721  -73.422  54.348  1
273651  93.741  -73.417  54.332  1
273652  93.759  -73.412  54.313  1
273653  93.778  -73.407  54.293  1
273654  93.797  -73.402  54.272  1
273655  93.816  -73.396  54.250  1
273656  93.835  -73.391  54.228  1
273657  93.853  -73.386  54.207  1
273658  93.872  -73.380  54.185  1
273659  93.891  -73.375  54.160  1
273660  93.910  -73.370  54.135  1
273661  93.929  -73.365  54.112  1
273662  93.948  -73.360  54.088  1
273663  93.967  -73.355  54.065  1
273664  93.985  -73.349  54.041  1
273665  94.004  -73.344  54.018  1
273666  94.023  -73.339  53.994  1
273667  94.042  -73.333  53.969  1
273668  94.061  -73.328  53.945  1
273669  94.080  -73.324  53.921  1
273670  94.099  -73.318  53.896  1
273671  94.117  -73.313  53.872  1
273672  94.142  -73.322  53.848  1
273673  94.168  -73.336  53.822  1
273674  94.195  -73.351  53.796  1
273675  94.221  -73.365  53.770  1
273676  94.247  -73.374  53.745  1
273677  94.272  -73.380  53.721  1
273678  94.298  -73.388  53.697  1
273679  94.324  -73.396  53.671  1
273680  94.350  -73.403  53.644  1
273681  94.376  -73.410  53.618  1
273685  94.478  -73.440  53.514  1
273686  94.504  -73.447  53.487  1
273687  94.530  -73.455  53.462  1
273688  94.555  -73.462  53.436  1
273689  94.581  -73.469  53.410  1
273690  94.607  -73.477  53.386  1
273691  94.633  -73.484  53.363  1
273692  94.659  -73.491  53.341  1
273693  94.684  -73.499  53.318  1
273694  94.710  -73.506  53.296  1
273695  94.736  -73.514  53.272  1
273696  94.761  -73.521  53.248  1
273697  94.770  -73.521  53.223  1
273698  94.777  -73.520  53.198  1
273699  94.786  -73.519  53.172  1
273700  94.807  -73.524  53.143  1
273701  94.827  -73.528  53.113  1
273702  94.848  -73.533  53.083  1
273703  94.868  -73.537  53.051  1
273704  94.902  -73.532  53.019  1
273705  94.943  -73.521  52.986  1
273706  94.958  -73.535  52.954  1
273707  94.972  -73.549  52.920  1
273708  94.986  -73.562  52.887  1
273709  95.001  -73.575  52.854  1
273710  95.015  -73.588  52.821  1
273711  95.030  -73.602  52.788  1
273712  95.044  -73.615  52.757  1
273713  95.058  -73.628  52.727  1
273714  95.074  -73.640  52.697  1
273715  95.100  -73.642  52.668  1
273716  95.124  -73.634  52.637  1
273717  95.148  -73.609  52.608  1
273718  95.191  -73.617  52.579  1
273719  95.235  -73.624  52.551  1
273720  95.277  -73.631  52.524  1
273721  95.321  -73.637  52.495  1
273722  95.364  -73.644  52.466  1
273723  95.408  -73.647  52.436  1
273724  95.455  -73.637  52.407  1
273725  95.502  -73.629  52.379  1
273726  95.534  -73.628  52.354  1
273727  95.561  -73.609  52.331  1
273728  95.588  -73.590  52.305  1
273729  95.615  -73.570  52.278  1
273730  95.642  -73.550  52.253  1
273731  95.669  -73.530  52.228  1
273732  95.695  -73.510  52.202  1
273733  95.722  -73.490  52.177  1
273734  95.750  -73.478  52.152  1
273735  95.775  -73.494  52.126  1
273736  95.797  -73.494  52.099  1
273737  95.827  -73.507  52.071  1
273738  95.857  -73.521  52.042  1
273739  95.887  -73.534  52.013  1
273740  95.916  -73.547  51.982  1
273741  95.946  -73.560  51.950  1
273742  95.976  -73.574  51.918  1
273743  96.009  -73.581  51.885  1
273744  96.045  -73.581  51.848  1
273745  96.082  -73.581  51.813  1
273746  96.118  -73.581  51.778  1
273747  96.135  -73.578  51.743  1
273748  96.144  -73.575  51.709  1
273749  96.153  -73.571  51.675  1
273750  96.191  -73.591  51.642  1
273751  96.230  -73.611  51.608  1
273752  96.268  -73.631  51.575  1
273753  96.307  -73.651  51.542  1
273754  96.354  -73.671  51.509  1
273755  96.397  -73.690  51.475  1
273756  96.418  -73.698  51.443  1
273757  96.440  -73.707  51.411  1
273758  96.459  -73.712  51.380  1
273759  96.472  -73.706  51.348  1
273760  96.485  -73.700  51.317  1
273761  96.498  -73.694  51.287  1
273762  96.511  -73.688  51.258  1
273763  96.524  -73.683  51.228  1
273764  96.536  -73.677  51.200  1
273765  96.549  -73.671  51.172  1
273766  96.611  -73.662  51.145  1
273767  96.686  -73.653  51.118  1
273768  96.743  -73.656  51.094  1
273769  96.784  -73.666  51.070  1
273770  96.825  -73.677  51.048  1
273771  96.866  -73.687  51.029  1
273772  96.905  -73.699  51.008  1
273773  96.943  -73.714  50.989  1
273774  96.955  -73.689  50.972  1
273775  96.940  -73.626  50.957  1
273776  96.914  -73.709  50.944  1
273777  96.908  -73.724  50.933  1
273778  96.934  -73.736  50.924  1
273779  96.963  -73.749  50.914  1
273780  96.992  -73.761  50.907  1
273781  97.022  -73.773  50.900  1
273782  97.049  -73.772  50.894  1
273783  97.079  -73.767  50.889  1
273784  97.111  -73.757  50.885  1
273785  97.143  -73.748  50.881  1
273786  97.175  -73.739  50.878  1
273787  97.210  -73.741  50.874  1
273788  97.244  -73.741  50.873  1
273789  97.252  -73.745  50.873  1
273790  97.259  -73.750  50.872  1
273791  97.279  -73.756  50.869  1
273792  97.298  -73.762  50.862  1
273793  97.317  -73.767  50.856  1
273794  97.337  -73.773  50.849  1
273795  97.357  -73.778  50.845  1
273796  97.376  -73.785  50.839  1
273797  97.414  -73.790  50.831  1
273798  97.454  -73.794  50.820  1
273799  97.494  -73.800  50.802  1
273800  97.534  -73.805  50.776  1
273801  97.574  -73.810  50.744  1
273802  97.614  -73.815  50.708  1
273803  97.654  -73.820  50.667  1
273804  97.694  -73.825  50.622  1
273805  97.734  -73.830  50.574  1
273806  97.774  -73.835  50.524  1
273807  97.814  -73.840  50.474  1
273808  97.850  -73.849  50.424  1
273809  97.876  -73.866  50.376  1
273810  97.902  -73.883  50.330  1
273811  97.929  -73.900  50.284  1
273812  97.955  -73.917  50.232  1
273813  97.997  -73.927  50.177  1
273814  98.039  -73.938  50.121  1
273815  98.080  -73.948  50.064  1
273816  98.122  -73.959  50.005  1
273817  98.164  -73.969  49.944  1
273818  98.206  -73.979  49.880  1
273819  98.247  -73.990  49.816  1
273820  98.289  -74.000  49.749  1
273821  98.331  -74.010  49.683  1
273822  98.369  -74.023  49.618  1
273823  98.400  -74.037  49.552  1
273824  98.394  -74.045  49.490  1
273825  98.388  -74.054  49.426  1
273826  98.382  -74.062  49.363  1
273827  98.388  -74.075  49.302  1
273828  98.435  -74.104  49.241  1
273829  98.479  -74.122  49.182  1
273830  98.512  -74.101  49.125  1
273831  98.547  -74.079  49.069  1
273832  98.591  -74.092  49.011  1
273833  98.640  -74.137  48.956  1
273834  98.674  -74.157  48.902  1
273835  98.692  -74.183  48.849  1
273836  98.716  -74.212  48.800  1
273837  98.739  -74.240  48.753  1
273838  98.763  -74.269  48.705  1
273839  98.786  -74.298  48.657  1
273840  98.807  -74.278  48.608  1
273841  98.838  -74.286  48.559  1
273842  98.869  -74.293  48.509  1
273843  98.902  -74.302  48.459  1
273844  98.934  -74.311  48.409  1
273845  98.967  -74.320  48.357  1
273846  99.000  -74.329  48.306  1
273847  99.032  -74.337  48.254  1
273848  99.065  -74.346  48.203  1
273849  99.097  -74.352  48.153  1
273850  99.129  -74.357  48.104  1
273851  99.161  -74.361  48.055  1
273852  99.194  -74.367  48.008  1
273853  99.219  -74.386  47.962  1
273854  99.243  -74.406  47.916  1
273855  99.267  -74.427  47.871  1
273856  99.300  -74.444  47.827  1
273857  99.342  -74.459  47.784  1
273858  99.382  -74.474  47.742  1
273859  99.424  -74.489  47.700  1
273860  99.465  -74.503  47.660  1
273861  99.505  -74.518  47.620  1
273862  99.541  -74.530  47.582  1
273863  99.571  -74.538  47.545  1
273864  99.600  -74.546  47.509  1
273865  99.630  -74.555  47.474  1
273866  99.660  -74.564  47.438  1
273867  99.690  -74.572  47.402  1
273868  99.720  -74.581  47.365  1
273869  99.750  -74.589  47.329  1
273870  99.779  -74.597  47.293  1
273871  99.809  -74.606  47.258  1
273872  99.842  -74.614  47.225  1
273873  99.905  -74.619  47.194  1
273874  99.969  -74.624  47.163  1
273875  99.987  -74.644  47.131  1
273876  100.001  -74.665  47.100  1
273877  100.015  -74.687  47.069  1
273878  100.029  -74.708  47.040  1
273879  100.059  -74.724  47.013  1
273880  100.092  -74.738  46.986  1
273881  100.126  -74.753  46.960  1
273882  100.159  -74.767  46.933  1
273883  100.192  -74.782  46.907  1
273884  100.226  -74.797  46.881  1
273885  100.259  -74.811  46.858  1
273886  100.287  -74.822  46.834  1
273887  100.312  -74.831  46.808  1
273888  100.337  -74.841  46.780  1
273889  100.362  -74.850  46.751  1
273890  100.388  -74.860  46.721  1
273891  100.413  -74.869  46.692  1
273892  100.437  -74.879  46.666  1
273893  100.463  -74.888  46.637  1
273894  100.488  -74.898  46.608  1
273895  100.513  -74.908  46.579  1
273896  100.538  -74.917  46.550  1
273897  100.563  -74.927  46.521  1
273898  100.591  -74.935  46.493  1
273899  100.617  -74.942  46.465  1
273900  100.643  -74.950  46.437  1
273901  100.668  -74.959  46.409  1
273902  100.696  -74.969  46.380  1
273903  100.723  -74.980  46.350  1
273904  100.751  -74.991  46.319  1
273905  100.779  -75.001  46.292  1
273906  100.807  -75.012  46.266  1
273907  100.834  -75.022  46.239  1
273908  100.861  -75.033  46.213  1
273909  100.890  -75.045  46.187  1
273910  100.919  -75.057  46.158  1
273911  100.948  -75.069  46.127  1
273912  100.977  -75.082  46.097  1
273913  101.005  -75.094  46.067  1
273914  101.034  -75.107  46.036  1
273915  101.063  -75.119  46.004  1
273916  101.092  -75.131  45.971  1
273917  101.121  -75.143  45.938  1
273918  101.149  -75.156  45.907  1
273919  101.178  -75.168  45.875  1
273920  101.206  -75.179  45.841  1
273921  101.240  -75.196  45.806  1
273922  101.274  -75.216  45.770  1
273923  101.308  -75.234  45.734  1
273924  101.341  -75.253  45.698  1
273925  101.375  -75.271  45.666  1
273926  101.409  -75.290  45.634  1
273927  101.443  -75.308  45.602  1
273928  101.476  -75.327  45.570  1
273929  101.510  -75.345  45.539  1
273930  101.543  -75.364  45.509  1
273931  101.577  -75.383  45.478  1
273932  101.611  -75.401  45.447  1
273933  101.644  -75.420  45.417  1
273934  101.678  -75.438  45.387  1
273935  101.712  -75.457  45.357  1
273936  101.745  -75.474  45.327  1
273937  101.770  -75.466  45.298  1
273938  101.788  -75.467  45.268  1
273939  101.805  -75.467  45.240  1
273940  101.823  -75.467  45.211  1
273941  101.840  -75.468  45.183  1
273942  101.857  -75.469  45.155  1
273943  101.875  -75.470  45.127  1
273944  101.893  -75.470  45.099  1
273945  101.910  -75.471  45.073  1
273946  101.927  -75.471  45.048  1
273947  101.945  -75.471  45.022  1
273948  101.962  -75.472  44.995  1
273949  101.980  -75.473  44.970  1
273950  101.997  -75.474  44.945  1
273951  102.015  -75.474  44.920  1
274305  92.309  -73.112  54.771  1
274306  92.340  -73.123  54.757  1
274307  92.371  -73.133  54.744  1
274308  92.402  -73.143  54.730  1
274309  92.432  -73.154  54.717  1
274310  92.462  -73.164  54.704  1
274311  92.493  -73.174  54.689  1
274312  92.524  -73.185  54.676  1
274313  92.555  -73.195  54.664  1
274314  92.585  -73.205  54.653  1
274315  92.616  -73.216  54.640  1
274316  92.647  -73.226  54.630  1
274317  92.677  -73.236  54.620  1
274318  92.720  -73.247  54.611  1
274319  92.763  -73.258  54.603  1
274320  92.805  -73.269  54.597  1
274321  92.848  -73.280  54.592  1
274322  92.891  -73.291  54.589  1
274323  92.934  -73.302  54.587  1
274324  92.977  -73.313  54.582  1
274325  93.020  -73.324  54.578  1
274326  93.063  -73.335  54.574  1
274327  93.106  -73.346  54.569  1
274328  93.148  -73.357  54.565  1
274329  93.192  -73.368  54.561  1
274330  93.216  -73.362  54.557  1
274331  93.238  -73.353  54.554  1
274332  93.271  -73.358  54.552  1
274333  93.312  -73.372  54.547  1
274334  93.353  -73.386  54.542  1
274335  93.394  -73.400  54.538  1
274336  93.431  -73.413  54.534  1
274337  93.455  -73.421  54.528  1
274338  93.475  -73.429  54.522  1
274339  93.493  -73.436  54.516  1
274340  93.514  -73.440  54.501  1
274341  93.534  -73.437  54.484  1
274342  93.554  -73.435  54.468  1
274343  93.573  -73.430  54.453  1
274344  93.592  -73.424  54.439  1
274345  93.611  -73.419  54.426  1
274346  93.630  -73.414  54.413  1
274347  93.648  -73.409  54.396  1
274348  93.667  -73.404  54.379  1
274349  93.686  -73.399  54.363  1
274350  93.705  -73.393  54.347  1
274351  93.724  -73.388  54.330  1
274352  93.743  -73.383  54.314  1
274353  93.762  -73.377  54.294  1
274354  93.780  -73.372  54.273  1
274355  93.799  -73.367  54.252  1
274356  93.818  -73.362  54.229  1
274357  93.837  -73.357  54.207  1
274358  93.856  -73.352  54.185  1
274359  93.874  -73.346  54.162  1
274360  93.894  -73.341  54.137  1
274361  93.912  -73.336  54.112  1
274362  93.931  -73.330  54.088  1
274363  93.950  -73.325  54.064  1
274364  93.969  -73.320  54.041  1
274365  93.988  -73.315  54.018  1
274366  94.006  -73.310  53.994  1
274367  94.026  -73.305  53.970  1
274368  94.044  -73.299  53.945  1
274369  94.063  -73.294  53.920  1
274370  94.082  -73.289  53.896  1
274371  94.101  -73.283  53.872  1
274372  94.120  -73.278  53.848  1
274373  94.140  -73.277  53.824  1
274374  94.166  -73.291  53.798  1
274375  94.193  -73.305  53.773  1
274376  94.219  -73.320  53.747  1
274377  94.246  -73.334  53.723  1
274378  94.271  -73.343  53.698  1
274379  94.297  -73.351  53.674  1
274380  94.323  -73.358  53.648  1
274389  94.554  -73.424  53.418  1
274390  94.580  -73.432  53.393  1
274391  94.606  -73.440  53.368  1
274392  94.631  -73.447  53.345  1
274393  94.657  -73.454  53.322  1
274394  94.683  -73.462  53.300  1
274395  94.709  -73.469  53.277  1
274396  94.735  -73.477  53.254  1
274397  94.760  -73.484  53.230  1
274398  94.781  -73.489  53.205  1
274399  94.788  -73.488  53.178  1
274400  94.795  -73.487  53.152  1
274401  94.810  -73.489  53.124  1
274402  94.830  -73.493  53.095  1
274403  94.851  -73.498  53.065  1
274404  94.872  -73.503  53.033  1
274405  94.892  -73.506  53.001  1
274406  94.923  -73.503  52.969  1
274407  94.965  -73.493  52.937  1
274408  94.979  -73.506  52.904  1
274409  94.994  -73.519  52.872  1
274410  95.008  -73.532  52.840  1
274411  95.023  -73.546  52.807  1
274412  95.037  -73.559  52.775  1
274413  95.051  -73.572  52.744  1
274414  95.066  -73.586  52.715  1
274415  95.080  -73.599  52.686  1
274416  95.095  -73.612  52.657  1
274417  95.110  -73.625  52.627  1
274418  95.134  -73.617  52.598  1
274419  95.174  -73.619  52.569  1
274420  95.217  -73.626  52.542  1
274421  95.262  -73.624  52.514  1
274422  95.309  -73.615  52.487  1
274423  95.356  -73.606  52.459  1
274424  95.403  -73.597  52.430  1
274425  95.450  -73.588  52.402  1
274426  95.497  -73.580  52.376  1
274427  95.530  -73.578  52.352  1
274428  95.558  -73.579  52.329  1
274429  95.585  -73.563  52.304  1
274430  95.612  -73.543  52.278  1
274431  95.638  -73.523  52.253  1
274432  95.665  -73.503  52.228  1
274433  95.692  -73.484  52.203  1
274434  95.719  -73.464  52.179  1
274435  95.747  -73.455  52.156  1
274436  95.777  -73.484  52.131  1
274437  95.798  -73.484  52.105  1
274438  95.819  -73.484  52.077  1
274439  95.844  -73.490  52.049  1
274440  95.874  -73.503  52.020  1
274441  95.904  -73.516  51.989  1
274442  95.934  -73.530  51.957  1
274443  95.964  -73.543  51.926  1
274444  95.996  -73.552  51.892  1
274445  96.032  -73.552  51.856  1
274446  96.069  -73.551  51.821  1
274447  96.105  -73.551  51.786  1
274448  96.139  -73.551  51.752  1
274449  96.148  -73.547  51.717  1
274450  96.164  -73.552  51.683  1
274451  96.205  -73.573  51.650  1
274452  96.247  -73.595  51.616  1
274453  96.289  -73.616  51.584  1
274454  96.331  -73.638  51.551  1
274455  96.373  -73.659  51.518  1
274456  96.411  -73.679  51.484  1
274457  96.432  -73.681  51.452  1
274458  96.445  -73.675  51.420  1
274459  96.458  -73.670  51.389  1
274460  96.471  -73.664  51.358  1
274461  96.483  -73.659  51.326  1
274462  96.497  -73.653  51.295  1
274463  96.510  -73.647  51.265  1
274464  96.522  -73.641  51.235  1
274465  96.535  -73.635  51.207  1
274466  96.554  -73.629  51.180  1
274467  96.629  -73.620  51.152  1
274468  96.704  -73.611  51.126  1
274469  96.761  -73.622  51.101  1
274470  96.808  -73.642  51.077  1
274471  96.849  -73.660  51.055  1
274472  96.888  -73.678  51.035  1
274473  96.928  -73.694  51.014  1
274474  96.942  -73.674  50.995  1
274475  96.928  -73.611  50.977  1
274476  96.913  -73.547  50.961  1
274477  96.892  -73.594  50.949  1
274478  96.901  -73.684  50.938  1
274479  96.932  -73.689  50.928  1
274480  96.961  -73.701  50.918  1
274481  96.991  -73.713  50.909  1
274482  97.020  -73.726  50.901  1
274483  97.049  -73.738  50.894  1
274484  97.077  -73.734  50.889  1
274485  97.104  -73.731  50.886  1
274486  97.136  -73.722  50.882  1
274487  97.169  -73.717  50.878  1
274488  97.204  -73.719  50.873  1
274489  97.238  -73.720  50.871  1
274490  97.263  -73.722  50.870  1
274491  97.260  -73.727  50.869  1
274492  97.268  -73.731  50.866  1
274493  97.288  -73.738  50.861  1
274494  97.308  -73.743  50.854  1
274495  97.327  -73.749  50.846  1
274496  97.347  -73.754  50.840  1
274497  97.381  -73.760  50.834  1
274498  97.421  -73.765  50.826  1
274499  97.461  -73.770  50.813  1
274500  97.501  -73.775  50.795  1
274501  97.541  -73.780  50.768  1
274502  97.581  -73.785  50.737  1
274503  97.621  -73.790  50.701  1
274504  97.661  -73.795  50.661  1
274505  97.701  -73.800  50.618  1
274506  97.741  -73.805  50.571  1
274507  97.781  -73.810  50.522  1
274508  97.821  -73.816  50.472  1
274509  97.861  -73.820  50.422  1
274510  97.888  -73.837  50.374  1
274511  97.915  -73.854  50.328  1
274512  97.941  -73.871  50.281  1
274513  97.973  -73.885  50.226  1
274514  98.015  -73.896  50.169  1
274515  98.057  -73.906  50.110  1
274516  98.098  -73.916  50.050  1
274517  98.140  -73.927  49.990  1
274518  98.181  -73.937  49.929  1
274519  98.223  -73.948  49.866  1
274520  98.265  -73.958  49.801  1
274521  98.303  -73.966  49.736  1
274522  98.340  -73.974  49.671  1
274523  98.409  -73.995  49.605  1
274524  98.406  -74.001  49.539  1
274525  98.400  -74.009  49.475  1
274526  98.394  -74.017  49.412  1
274527  98.388  -74.026  49.350  1
274528  98.394  -74.039  49.289  1
274529  98.441  -74.069  49.228  1
274530  98.488  -74.098  49.167  1
274531  98.526  -74.095  49.109  1
274532  98.561  -74.074  49.052  1
274533  98.610  -74.098  48.996  1
274534  98.665  -74.144  48.941  1
274535  98.701  -74.133  48.887  1
274536  98.714  -74.159  48.835  1
274537  98.728  -74.185  48.786  1
274538  98.745  -74.212  48.739  1
274539  98.769  -74.240  48.691  1
274540  98.792  -74.269  48.643  1
274541  98.813  -74.259  48.594  1
274542  98.840  -74.254  48.546  1
274543  98.873  -74.263  48.496  1
274544  98.906  -74.272  48.447  1
274545  98.938  -74.280  48.397  1
274546  98.971  -74.289  48.345  1
274547  99.003  -74.299  48.294  1
274548  99.036  -74.308  48.243  1
274549  99.069  -74.316  48.192  1
274550  99.101  -74.325  48.143  1
274551  99.133  -74.330  48.094  1
274552  99.165  -74.336  48.045  1
274553  99.198  -74.340  47.999  1
274554  99.224  -74.358  47.953  1
274555  99.248  -74.378  47.907  1
274556  99.275  -74.398  47.862  1
274557  99.315  -74.413  47.819  1
274558  99.356  -74.427  47.776  1
274559  99.398  -74.442  47.734  1
274560  99.438  -74.457  47.693  1
274561  99.479  -74.471  47.653  1
274562  99.520  -74.487  47.614  1
274563  99.559  -74.499  47.575  1
274564  99.589  -74.508  47.538  1
274565  99.619  -74.517  47.502  1
274566  99.648  -74.525  47.468  1
274567  99.678  -74.534  47.432  1
274568  99.708  -74.542  47.395  1
274569  99.738  -74.550  47.358  1
274570  99.768  -74.559  47.322  1
274571  99.797  -74.567  47.287  1
274572  99.839  -74.574  47.251  1
274573  99.903  -74.580  47.219  1
274574  99.966  -74.584  47.188  1
274575  100.030  -74.590  47.157  1
274576  100.057  -74.604  47.125  1
274577  100.079  -74.625  47.095  1
274578  100.093  -74.646  47.064  1
274579  100.108  -74.668  47.035  1
274580  100.122  -74.689  47.008  1
274581  100.136  -74.711  46.982  1
274582  100.150  -74.732  46.955  1
274583  100.171  -74.751  46.928  1
274584  100.204  -74.766  46.902  1
274585  100.238  -74.780  46.877  1
274586  100.270  -74.794  46.853  1
274587  100.295  -74.803  46.828  1
274588  100.321  -74.813  46.801  1
274589  100.346  -74.823  46.772  1
274590  100.371  -74.832  46.743  1
274591  100.396  -74.842  46.713  1
274592  100.422  -74.850  46.684  1
274593  100.450  -74.858  46.656  1
274594  100.476  -74.866  46.628  1
274595  100.503  -74.873  46.599  1
274596  100.530  -74.881  46.569  1
274597  100.557  -74.888  46.541  1
274598  100.583  -74.897  46.512  1
274599  100.611  -74.904  46.484  1
274600  100.637  -74.912  46.456  1
274601  100.665  -74.919  46.427  1
274602  100.687  -74.926  46.398  1
274603  100.708  -74.932  46.370  1
274604  100.735  -74.943  46.341  1
274605  100.763  -74.954  46.310  1
274606  100.790  -74.964  46.282  1
274607  100.818  -74.975  46.255  1
274608  100.845  -74.985  46.228  1
274609  100.874  -74.997  46.203  1
274610  100.908  -75.018  46.175  1
274611  100.938  -75.033  46.145  1
274612  100.967  -75.045  46.114  1
274613  100.996  -75.057  46.084  1
274614  101.025  -75.069  46.054  1
274615  101.053  -75.082  46.022  1
274616  101.082  -75.094  45.990  1
274617  101.111  -75.106  45.958  1
274618  101.140  -75.118  45.925  1
274619  101.169  -75.130  45.893  1
274620  101.197  -75.142  45.860  1
274621  101.229  -75.157  45.826  1
274622  101.263  -75.176  45.791  1
274623  101.296  -75.195  45.754  1
274624  101.330  -75.214  45.718  1
274625  101.364  -75.232  45.682  1
274626  101.398  -75.250  45.650  1
274627  101.431  -75.269  45.618  1
274628  101.465  -75.287  45.586  1
274629  101.498  -75.306  45.554  1
274630  101.532  -75.324  45.523  1
274631  101.566  -75.343  45.493  1
274632  101.600  -75.361  45.463  1
274633  101.633  -75.380  45.433  1
274634  101.667  -75.398  45.403  1
274635  101.700  -75.417  45.373  1
274636  101.734  -75.436  45.343  1
274637  101.764  -75.435  45.313  1
274638  101.785  -75.427  45.284  1
274639  101.802  -75.427  45.254  1
274640  101.820  -75.427  45.225  1
274641  101.838  -75.428  45.197  1
274642  101.855  -75.429  45.168  1
274643  101.873  -75.430  45.139  1
274644  101.890  -75.430  45.111  1
274645  101.907  -75.430  45.085  1
274646  101.925  -75.431  45.058  1
274647  101.943  -75.431  45.032  1
274648  101.960  -75.432  45.006  1
274649  101.977  -75.433  44.980  1
274650  101.995  -75.433  44.954  1
274651  102.012  -75.433  44.929  1
275008  92.366  -73.104  54.750  1
275009  92.397  -73.114  54.736  1
275010  92.428  -73.124  54.722  1
275011  92.458  -73.135  54.708  1
275012  92.489  -73.145  54.694  1
275013  92.520  -73.155  54.680  1
275014  92.551  -73.166  54.668  1
275015  92.581  -73.176  54.656  1
275016  92.612  -73.186  54.643  1
275017  92.642  -73.197  54.631  1
275018  92.673  -73.207  54.621  1
275019  92.716  -73.218  54.611  1
275020  92.759  -73.229  54.603  1
275021  92.802  -73.240  54.595  1
275022  92.845  -73.251  54.589  1
275023  92.888  -73.262  54.585  1
275024  92.931  -73.273  54.582  1
275025  92.974  -73.284  54.576  1
275026  93.017  -73.295  54.571  1
275027  93.060  -73.306  54.566  1
275028  93.102  -73.317  54.561  1
275029  93.145  -73.328  54.556  1
275030  93.188  -73.339  54.552  1
275031  93.227  -73.346  54.548  1
275032  93.249  -73.337  54.544  1
275033  93.281  -73.340  54.541  1
275034  93.322  -73.355  54.536  1
275035  93.362  -73.368  54.531  1
275036  93.399  -73.381  54.525  1
275037  93.423  -73.390  54.520  1
275038  93.447  -73.399  54.514  1
275039  93.472  -73.407  54.507  1
275040  93.497  -73.415  54.500  1
275041  93.519  -73.411  54.486  1
275042  93.538  -73.405  54.471  1
275043  93.556  -73.401  54.455  1
275044  93.575  -73.396  54.440  1
275045  93.594  -73.390  54.426  1
275046  93.613  -73.385  54.413  1
275047  93.632  -73.380  54.399  1
275048  93.651  -73.374  54.381  1
275049  93.670  -73.369  54.364  1
275050  93.688  -73.364  54.347  1
275051  93.707  -73.358  54.330  1
275052  93.726  -73.354  54.312  1
275053  93.745  -73.349  54.295  1
275054  93.764  -73.343  54.275  1
275055  93.783  -73.338  54.253  1
275056  93.801  -73.333  54.232  1
275057  93.820  -73.327  54.209  1
275058  93.839  -73.322  54.185  1
275059  93.858  -73.317  54.162  1
275060  93.877  -73.312  54.140  1
275061  93.896  -73.307  54.114  1
275062  93.915  -73.302  54.089  1
275063  93.933  -73.296  54.065  1
275064  93.952  -73.291  54.040  1
275065  93.971  -73.286  54.017  1
275066  93.990  -73.280  53.994  1
275067  94.009  -73.275  53.971  1
275068  94.028  -73.271  53.946  1
275069  94.047  -73.265  53.921  1
275070  94.065  -73.260  53.896  1
275071  94.084  -73.255  53.872  1
275072  94.103  -73.249  53.848  1
275073  94.122  -73.244  53.825  1
275074  94.141  -73.239  53.800  1
275075  94.165  -73.246  53.774  1
275076  94.191  -73.261  53.749  1
275077  94.217  -73.275  53.725  1
275078  94.244  -73.289  53.700  1
275079  94.270  -73.303  53.676  1
275091  94.579  -73.395  53.376  1
275092  94.605  -73.402  53.350  1
275093  94.630  -73.410  53.328  1
275094  94.656  -73.417  53.305  1
275095  94.682  -73.424  53.281  1
275096  94.707  -73.432  53.258  1
275097  94.734  -73.440  53.236  1
275098  94.759  -73.446  53.212  1
275099  94.785  -73.454  53.187  1
275100  94.799  -73.456  53.161  1
275101  94.806  -73.456  53.134  1
275102  94.813  -73.454  53.106  1
275103  94.833  -73.459  53.077  1
275104  94.854  -73.463  53.048  1
275105  94.875  -73.468  53.016  1
275106  94.895  -73.471  52.985  1
275107  94.915  -73.476  52.954  1
275108  94.944  -73.474  52.923  1
275109  94.987  -73.463  52.890  1
275110  95.001  -73.477  52.859  1
275111  95.016  -73.490  52.827  1
275112  95.030  -73.503  52.795  1
275113  95.045  -73.516  52.764  1
275114  95.059  -73.530  52.734  1
275115  95.073  -73.543  52.704  1
275116  95.088  -73.556  52.675  1
275117  95.102  -73.570  52.647  1
275118  95.117  -73.583  52.618  1
275119  95.131  -73.597  52.589  1
275120  95.164  -73.592  52.561  1
275121  95.210  -73.584  52.533  1
275122  95.257  -73.575  52.506  1
275123  95.305  -73.565  52.480  1
275124  95.351  -73.557  52.453  1
275125  95.398  -73.548  52.426  1
275126  95.446  -73.539  52.399  1
275127  95.492  -73.531  52.373  1
275128  95.525  -73.529  52.350  1
275129  95.553  -73.530  52.327  1
275130  95.581  -73.531  52.302  1
275131  95.608  -73.517  52.277  1
275132  95.635  -73.496  52.252  1
275133  95.662  -73.477  52.228  1
275134  95.689  -73.457  52.204  1
275135  95.716  -73.437  52.181  1
275136  95.744  -73.431  52.160  1
275137  95.774  -73.464  52.137  1
275138  95.799  -73.474  52.110  1
275139  95.820  -73.474  52.083  1
275140  95.842  -73.474  52.056  1
275141  95.863  -73.474  52.027  1
275142  95.892  -73.486  51.996  1
275143  95.921  -73.499  51.964  1
275144  95.952  -73.512  51.932  1
275145  95.983  -73.522  51.898  1
275146  96.020  -73.522  51.863  1
275147  96.056  -73.522  51.829  1
275148  96.092  -73.522  51.794  1
275149  96.129  -73.522  51.760  1
275150  96.151  -73.522  51.726  1
275151  96.158  -73.523  51.692  1
275152  96.200  -73.544  51.658  1
275153  96.242  -73.565  51.625  1
275154  96.284  -73.587  51.593  1
275155  96.325  -73.609  51.561  1
275156  96.368  -73.631  51.527  1
275157  96.408  -73.637  51.494  1
275158  96.426  -73.635  51.462  1
275159  96.444  -73.634  51.430  1
275160  96.456  -73.628  51.399  1
275161  96.469  -73.622  51.368  1
275162  96.482  -73.617  51.336  1
275163  96.495  -73.611  51.304  1
275164  96.508  -73.605  51.274  1
275165  96.521  -73.600  51.244  1
275166  96.534  -73.593  51.217  1
275167  96.572  -73.587  51.189  1
275168  96.647  -73.578  51.161  1
275169  96.705  -73.583  51.135  1
275170  96.752  -73.602  51.110  1
275171  96.802  -73.625  51.086  1
275172  96.852  -73.647  51.063  1
275173  96.902  -73.669  51.042  1
275174  96.933  -73.672  51.021  1
275175  96.924  -73.628  51.001  1
275176  96.914  -73.584  50.984  1
275177  96.905  -73.540  50.967  1
275178  96.897  -73.575  50.954  1
275179  96.907  -73.658  50.943  1
275180  96.929  -73.668  50.932  1
275181  96.957  -73.672  50.922  1
275182  96.987  -73.675  50.912  1
275183  97.019  -73.678  50.903  1
275184  97.048  -73.691  50.896  1
275185  97.077  -73.699  50.891  1
275186  97.104  -73.695  50.887  1
275187  97.134  -73.692  50.884  1
275188  97.163  -73.695  50.879  1
275189  97.198  -73.697  50.874  1
275190  97.233  -73.698  50.870  1
275191  97.267  -73.699  50.867  1
275192  97.271  -73.703  50.864  1
275193  97.267  -73.708  50.861  1
275194  97.278  -73.713  50.855  1
275195  97.298  -73.719  50.847  1
275196  97.317  -73.725  50.839  1
275197  97.348  -73.730  50.832  1
275198  97.388  -73.734  50.825  1
275199  97.428  -73.740  50.817  1
275200  97.468  -73.745  50.804  1
275201  97.508  -73.750  50.787  1
275202  97.548  -73.755  50.761  1
275203  97.588  -73.760  50.730  1
275204  97.628  -73.766  50.695  1
275205  97.668  -73.770  50.656  1
275206  97.708  -73.775  50.614  1
275207  97.748  -73.781  50.568  1
275208  97.788  -73.785  50.519  1
275209  97.828  -73.791  50.469  1
275210  97.868  -73.796  50.419  1
275211  97.900  -73.807  50.372  1
275212  97.926  -73.825  50.325  1
275213  97.953  -73.841  50.276  1
275214  97.991  -73.854  50.221  1
275215  98.032  -73.864  50.162  1
275216  98.074  -73.874  50.101  1
275217  98.115  -73.885  50.039  1
275218  98.157  -73.895  49.977  1
275219  98.199  -73.906  49.916  1
275220  98.237  -73.914  49.853  1
275221  98.274  -73.921  49.789  1
275222  98.310  -73.929  49.726  1
275223  98.361  -73.939  49.660  1
275224  98.397  -73.970  49.594  1
275225  98.405  -73.973  49.527  1
275226  98.406  -73.973  49.462  1
275227  98.400  -73.982  49.400  1
275228  98.394  -73.990  49.338  1
275229  98.401  -74.004  49.276  1
275230  98.448  -74.033  49.215  1
275231  98.495  -74.063  49.155  1
275232  98.541  -74.089  49.095  1
275233  98.578  -74.077  49.037  1
275234  98.638  -74.123  48.981  1
275235  98.685  -74.131  48.926  1
275236  98.724  -74.114  48.873  1
275237  98.740  -74.136  48.822  1
275238  98.754  -74.162  48.773  1
275239  98.768  -74.188  48.725  1
275240  98.781  -74.214  48.678  1
275241  98.798  -74.240  48.630  1
275242  98.820  -74.245  48.582  1
275243  98.854  -74.230  48.533  1
275244  98.880  -74.234  48.484  1
275245  98.909  -74.242  48.435  1
275246  98.942  -74.251  48.385  1
275247  98.975  -74.259  48.334  1
275248  99.007  -74.268  48.283  1
275249  99.040  -74.277  48.232  1
275250  99.072  -74.286  48.181  1
275251  99.105  -74.295  48.132  1
275252  99.138  -74.304  48.083  1
275253  99.170  -74.309  48.035  1
275254  99.202  -74.314  47.990  1
275255  99.229  -74.329  47.944  1
275256  99.253  -74.349  47.899  1
275257  99.289  -74.366  47.854  1
275258  99.331  -74.381  47.811  1
275259  99.371  -74.396  47.768  1
275260  99.412  -74.410  47.726  1
275261  99.453  -74.425  47.686  1
275262  99.494  -74.440  47.647  1
275263  99.535  -74.455  47.608  1
275264  99.576  -74.469  47.569  1
275265  99.607  -74.478  47.531  1
275266  99.637  -74.487  47.494  1
275267  99.666  -74.495  47.460  1
275268  99.696  -74.503  47.424  1
275269  99.726  -74.512  47.387  1
275270  99.756  -74.521  47.351  1
275271  99.786  -74.529  47.315  1
275272  99.837  -74.535  47.279  1
275273  99.900  -74.540  47.245  1
275274  99.964  -74.545  47.214  1
275275  100.000  -74.552  47.183  1
275276  100.031  -74.559  47.152  1
275277  100.060  -74.568  47.120  1
275278  100.081  -74.590  47.089  1
275279  100.103  -74.611  47.060  1
275280  100.125  -74.631  47.031  1
275281  100.146  -74.653  47.004  1
275282  100.168  -74.673  46.977  1
275283  100.190  -74.694  46.950  1
275284  100.212  -74.715  46.923  1
275285  100.233  -74.736  46.898  1
275286  100.255  -74.757  46.872  1
275287  100.280  -74.772  46.848  1
275288  100.308  -74.781  46.822  1
275289  100.335  -74.789  46.794  1
275290  100.362  -74.797  46.764  1
275291  100.388  -74.804  46.734  1
275292  100.416  -74.812  46.705  1
275293  100.442  -74.820  46.676  1
275294  100.470  -74.828  46.647  1
275295  100.496  -74.835  46.618  1
275296  100.523  -74.843  46.589  1
275297  100.550  -74.850  46.560  1
275298  100.577  -74.858  46.532  1
275299  100.604  -74.866  46.502  1
275300  100.631  -74.874  46.474  1
275301  100.657  -74.881  46.446  1
275302  100.685  -74.889  46.417  1
275303  100.710  -74.897  46.389  1
275304  100.732  -74.903  46.360  1
275305  100.753  -74.910  46.331  1
275306  100.774  -74.916  46.301  1
275307  100.802  -74.927  46.275  1
275308  100.830  -74.938  46.247  1
275309  100.857  -74.948  46.220  1
275310  100.891  -74.969  46.193  1
275311  100.924  -74.988  46.163  1
275312  100.957  -75.009  46.132  1
275313  100.986  -75.022  46.101  1
275314  101.015  -75.034  46.071  1
275315  101.044  -75.046  46.040  1
275316  101.073  -75.057  46.008  1
275317  101.102  -75.069  45.976  1
275318  101.130  -75.082  45.944  1
275319  101.159  -75.094  45.911  1
275320  101.188  -75.106  45.878  1
275321  101.217  -75.118  45.845  1
275322  101.251  -75.135  45.810  1
275323  101.285  -75.155  45.774  1
275324  101.319  -75.173  45.738  1
275325  101.352  -75.192  45.701  1
275326  101.386  -75.210  45.666  1
275327  101.420  -75.229  45.635  1
275328  101.454  -75.248  45.603  1
275329  101.487  -75.267  45.570  1
275330  101.521  -75.285  45.539  1
275331  101.555  -75.304  45.507  1
275332  101.588  -75.322  45.476  1
275333  101.622  -75.340  45.446  1
275334  101.656  -75.359  45.418  1
275335  101.689  -75.377  45.389  1
275336  101.723  -75.396  45.359  1
275337  101.754  -75.401  45.329  1
275338  101.783  -75.395  45.299  1
275339  101.801  -75.387  45.269  1
275340  101.818  -75.387  45.239  1
275341  101.835  -75.388  45.211  1
275342  101.853  -75.389  45.183  1
275343  101.870  -75.389  45.153  1
275344  101.888  -75.389  45.125  1
275345  101.905  -75.390  45.097  1
275346  101.922  -75.391  45.070  1
275347  101.940  -75.391  45.044  1
275348  101.957  -75.392  45.017  1
275349  101.975  -75.392  44.991  1
275350  101.992  -75.392  44.965  1
275351  102.010  -75.393  44.939  1
275352  102.027  -75.394  44.914  1
275710  92.393  -73.085  54.742  1
275711  92.424  -73.095  54.727  1
275712  92.454  -73.105  54.713  1
275713  92.485  -73.116  54.699  1
275714  92.516  -73.126  54.685  1
275715  92.546  -73.136  54.671  1
275716  92.577  -73.147  54.657  1
275717  92.607  -73.157  54.645  1
275718  92.638  -73.167  54.633  1
275719  92.670  -73.178  54.622  1
275720  92.713  -73.189  54.612  1
275721  92.756  -73.200  54.603  1
275722  92.799  -73.211  54.593  1
275723  92.842  -73.222  54.585  1
275724  92.885  -73.233  54.579  1
275725  92.928  -73.244  54.573  1
275726  92.971  -73.255  54.568  1
275727  93.013  -73.266  54.563  1
275728  93.056  -73.277  54.558  1
275729  93.099  -73.288  54.552  1
275730  93.142  -73.299  54.547  1
275731  93.185  -73.310  54.542  1
275732  93.228  -73.321  54.538  1
275733  93.260  -73.322  54.533  1
275734  93.290  -73.323  54.530  1
275735  93.331  -73.337  54.525  1
275736  93.366  -73.349  54.519  1
275737  93.391  -73.358  54.512  1
275738  93.415  -73.367  54.505  1
275739  93.439  -73.373  54.498  1
275740  93.464  -73.379  54.491  1
275741  93.491  -73.383  54.483  1
275742  93.518  -73.377  54.470  1
275743  93.540  -73.371  54.455  1
275744  93.559  -73.366  54.441  1
275745  93.577  -73.361  54.426  1
275746  93.596  -73.355  54.412  1
275747  93.615  -73.351  54.399  1
275748  93.634  -73.346  54.384  1
275749  93.653  -73.340  54.366  1
275750  93.672  -73.335  54.349  1
275751  93.691  -73.330  54.331  1
275752  93.709  -73.324  54.313  1
275753  93.728  -73.319  54.294  1
275754  93.747  -73.314  54.276  1
275755  93.766  -73.309  54.256  1
275756  93.785  -73.304  54.234  1
275757  93.803  -73.299  54.211  1
275758  93.823  -73.293  54.187  1
275759  93.841  -73.288  54.164  1
275760  93.860  -73.283  54.140  1
275761  93.879  -73.277  54.117  1
275762  93.898  -73.272  54.092  1
275763  93.917  -73.267  54.067  1
275764  93.935  -73.262  54.042  1
275765  93.955  -73.257  54.017  1
275766  93.973  -73.252  53.994  1
275767  93.992  -73.246  53.971  1
275768  94.011  -73.241  53.946  1
275769  94.030  -73.236  53.921  1
275770  94.049  -73.230  53.897  1
275771  94.067  -73.225  53.873  1
275772  94.086  -73.221  53.849  1
275773  94.105  -73.215  53.826  1
275774  94.124  -73.210  53.802  1
275775  94.143  -73.205  53.776  1
275776  94.163  -73.201  53.750  1
275777  94.189  -73.215  53.726  1
275778  94.215  -73.230  53.702  1
275779  94.242  -73.244  53.678  1
275795  94.655  -73.380  53.288  1
275796  94.681  -73.387  53.264  1
275797  94.706  -73.395  53.241  1
275798  94.732  -73.402  53.218  1
275799  94.758  -73.409  53.194  1
275800  94.783  -73.417  53.169  1
275801  94.810  -73.424  53.143  1
275802  94.817  -73.424  53.116  1
275803  94.824  -73.422  53.089  1
275804  94.836  -73.424  53.060  1
275805  94.857  -73.428  53.031  1
275806  94.878  -73.433  53.001  1
275807  94.898  -73.437  52.970  1
275808  94.918  -73.441  52.939  1
275809  94.939  -73.446  52.908  1
275810  94.966  -73.446  52.876  1
275811  95.008  -73.434  52.845  1
275812  95.023  -73.447  52.815  1
275813  95.038  -73.460  52.784  1
275814  95.052  -73.474  52.753  1
275815  95.066  -73.487  52.723  1
275816  95.081  -73.500  52.694  1
275817  95.095  -73.514  52.666  1
275818  95.110  -73.527  52.638  1
275819  95.124  -73.540  52.609  1
275820  95.138  -73.553  52.581  1
275821  95.158  -73.558  52.553  1
275822  95.204  -73.534  52.526  1
275823  95.253  -73.525  52.500  1
275824  95.300  -73.516  52.475  1
275825  95.346  -73.508  52.449  1
275826  95.394  -73.499  52.421  1
275827  95.441  -73.490  52.394  1
275828  95.487  -73.481  52.370  1
275829  95.520  -73.480  52.346  1
275830  95.548  -73.481  52.323  1
275831  95.576  -73.481  52.299  1
275832  95.605  -73.482  52.275  1
275833  95.632  -73.470  52.251  1
275834  95.659  -73.450  52.227  1
275835  95.685  -73.430  52.205  1
275836  95.712  -73.411  52.183  1
275837  95.741  -73.408  52.161  1
275838  95.771  -73.440  52.139  1
275839  95.800  -73.464  52.115  1
275840  95.822  -73.464  52.088  1
275841  95.843  -73.464  52.061  1
275842  95.864  -73.465  52.032  1
275843  95.885  -73.465  52.001  1
275844  95.909  -73.468  51.970  1
275845  95.939  -73.482  51.938  1
275846  95.970  -73.493  51.904  1
275847  96.007  -73.493  51.870  1
275848  96.043  -73.493  51.836  1
275849  96.079  -73.493  51.802  1
275850  96.115  -73.496  51.768  1
275851  96.151  -73.497  51.734  1
275852  96.160  -73.497  51.700  1
275853  96.195  -73.515  51.668  1
275854  96.237  -73.537  51.636  1
275855  96.278  -73.558  51.603  1
275856  96.320  -73.580  51.571  1
275857  96.366  -73.585  51.538  1
275858  96.398  -73.586  51.505  1
275859  96.415  -73.584  51.473  1
275860  96.433  -73.583  51.441  1
275861  96.450  -73.581  51.409  1
275862  96.467  -73.581  51.377  1
275863  96.481  -73.575  51.346  1
275864  96.494  -73.569  51.315  1
275865  96.507  -73.563  51.284  1
275866  96.520  -73.558  51.255  1
275867  96.533  -73.552  51.228  1
275868  96.590  -73.543  51.200  1
275869  96.651  -73.546  51.172  1
275870  96.695  -73.563  51.146  1
275871  96.742  -73.583  51.120  1
275872  96.792  -73.605  51.096  1
275873  96.842  -73.627  51.073  1
275874  96.892  -73.650  51.050  1
275875  96.920  -73.661  51.029  1
275876  96.921  -73.651  51.009  1
275877  96.920  -73.630  50.991  1
275878  96.911  -73.586  50.975  1
275879  96.902  -73.555  50.961  1
275880  96.913  -73.632  50.949  1
275881  96.935  -73.642  50.938  1
275882  96.955  -73.652  50.926  1
275883  96.980  -73.659  50.917  1
275884  97.012  -73.661  50.908  1
275885  97.043  -73.663  50.900  1
275886  97.074  -73.666  50.894  1
275887  97.117  -73.660  50.890  1
275888  97.156  -73.657  50.886  1
275889  97.192  -73.656  50.881  1
275890  97.209  -73.666  50.876  1
275891  97.227  -73.676  50.869  1
275892  97.261  -73.678  50.863  1
275893  97.282  -73.680  50.857  1
275894  97.279  -73.684  50.851  1
275895  97.276  -73.689  50.845  1
275896  97.288  -73.694  50.837  1
275897  97.315  -73.700  50.827  1
275898  97.355  -73.705  50.818  1
275899  97.395  -73.710  50.812  1
275900  97.435  -73.715  50.804  1
275901  97.475  -73.720  50.794  1
275902  97.515  -73.725  50.777  1
275903  97.555  -73.730  50.753  1
275904  97.595  -73.735  50.725  1
275905  97.635  -73.741  50.691  1
275906  97.675  -73.746  50.652  1
275907  97.715  -73.750  50.611  1
275908  97.755  -73.756  50.565  1
275909  97.795  -73.761  50.515  1
275910  97.835  -73.766  50.464  1
275911  97.875  -73.771  50.415  1
275912  97.912  -73.778  50.368  1
275913  97.938  -73.795  50.321  1
275914  97.967  -73.812  50.271  1
275915  98.008  -73.822  50.217  1
275916  98.050  -73.832  50.157  1
275917  98.092  -73.843  50.095  1
275918  98.134  -73.853  50.031  1
275919  98.172  -73.861  49.967  1
275920  98.208  -73.869  49.906  1
275921  98.244  -73.875  49.845  1
275922  98.281  -73.883  49.783  1
275923  98.317  -73.891  49.719  1
275924  98.383  -73.906  49.651  1
275925  98.385  -73.942  49.583  1
275926  98.390  -73.960  49.516  1
275927  98.401  -73.950  49.452  1
275928  98.406  -73.945  49.390  1
275929  98.401  -73.954  49.327  1
275930  98.407  -73.967  49.264  1
275931  98.454  -73.998  49.204  1
275932  98.501  -74.027  49.143  1
275933  98.548  -74.057  49.084  1
275934  98.597  -74.080  49.026  1
275935  98.650  -74.096  48.968  1
275936  98.703  -74.113  48.912  1
275937  98.744  -74.101  48.859  1
275938  98.767  -74.113  48.809  1
275939  98.780  -74.139  48.760  1
275940  98.794  -74.164  48.712  1
275941  98.807  -74.190  48.664  1
275942  98.820  -74.216  48.617  1
275943  98.836  -74.234  48.569  1
275944  98.872  -74.227  48.520  1
275945  98.908  -74.214  48.472  1
275946  98.934  -74.220  48.423  1
275947  98.960  -74.226  48.374  1
275948  98.987  -74.233  48.324  1
275949  99.013  -74.239  48.274  1
275950  99.043  -74.247  48.222  1
275951  99.076  -74.256  48.171  1
275952  99.109  -74.265  48.122  1
275953  99.141  -74.273  48.074  1
275954  99.174  -74.283  48.027  1
275955  99.206  -74.288  47.981  1
275956  99.234  -74.301  47.936  1
275957  99.263  -74.320  47.891  1
275958  99.304  -74.334  47.847  1
275959  99.345  -74.349  47.803  1
275960  99.386  -74.364  47.760  1
275961  99.427  -74.378  47.718  1
275962  99.468  -74.393  47.678  1
275963  99.509  -74.408  47.638  1
275964  99.550  -74.423  47.599  1
275965  99.591  -74.437  47.560  1
275966  99.625  -74.448  47.522  1
275967  99.655  -74.456  47.485  1
275968  99.685  -74.465  47.450  1
275969  99.714  -74.474  47.414  1
275970  99.744  -74.482  47.378  1
275971  99.774  -74.490  47.343  1
275972  99.834  -74.496  47.308  1
275973  99.898  -74.501  47.272  1
275974  99.938  -74.507  47.238  1
275975  99.969  -74.514  47.206  1
275976  100.000  -74.521  47.176  1
275977  100.031  -74.528  47.145  1
275978  100.061  -74.535  47.114  1
275979  100.084  -74.554  47.084  1
275980  100.106  -74.575  47.054  1
275981  100.127  -74.596  47.027  1
275982  100.149  -74.617  46.999  1
275983  100.171  -74.638  46.972  1
275984  100.192  -74.659  46.945  1
275985  100.214  -74.680  46.919  1
275986  100.236  -74.700  46.892  1
275987  100.258  -74.722  46.867  1
275988  100.286  -74.730  46.842  1
275989  100.317  -74.737  46.815  1
275990  100.347  -74.750  46.786  1
275991  100.378  -74.762  46.757  1
275992  100.409  -74.774  46.726  1
275993  100.436  -74.781  46.696  1
275994  100.463  -74.790  46.667  1
275995  100.490  -74.797  46.638  1
275996  100.516  -74.805  46.608  1
275997  100.543  -74.812  46.579  1
275998  100.570  -74.820  46.551  1
275999  100.597  -74.828  46.523  1
276000  100.624  -74.835  46.493  1
276001  100.651  -74.844  46.464  1
276002  100.678  -74.851  46.436  1
276003  100.705  -74.859  46.408  1
276004  100.732  -74.866  46.380  1
276005  100.754  -74.873  46.351  1
276006  100.775  -74.879  46.322  1
276007  100.796  -74.886  46.293  1
276008  100.818  -74.892  46.268  1
276009  100.841  -74.900  46.241  1
276010  100.874  -74.919  46.213  1
276011  100.907  -74.939  46.182  1
276012  100.940  -74.959  46.150  1
276013  100.973  -74.979  46.118  1
276014  101.005  -74.997  46.087  1
276015  101.034  -75.010  46.056  1
276016  101.063  -75.022  46.025  1
276017  101.092  -75.034  45.993  1
276018  101.121  -75.046  45.961  1
276019  101.149  -75.058  45.929  1
276020  101.178  -75.070  45.896  1
276021  101.207  -75.082  45.863  1
276022  101.236  -75.095  45.828  1
276023  101.272  -75.114  45.793  1
276024  101.308  -75.134  45.757  1
276025  101.341  -75.153  45.721  1
276026  101.375  -75.171  45.685  1
276027  101.409  -75.190  45.650  1
276028  101.443  -75.208  45.618  1
276029  101.476  -75.226  45.586  1
276030  101.510  -75.245  45.555  1
276031  101.543  -75.264  45.524  1
276032  101.577  -75.283  45.493  1
276033  101.611  -75.301  45.462  1
276034  101.644  -75.320  45.432  1
276035  101.678  -75.338  45.403  1
276036  101.712  -75.357  45.375  1
276037  101.744  -75.367  45.345  1
276038  101.773  -75.361  45.315  1
276039  101.802  -75.357  45.285  1
276040  101.815  -75.347  45.255  1
276041  101.833  -75.348  45.226  1
276042  101.850  -75.348  45.197  1
276043  101.868  -75.348  45.168  1
276044  101.885  -75.349  45.139  1
276045  101.903  -75.350  45.111  1
276046  101.920  -75.350  45.083  1
276047  101.938  -75.351  45.056  1
276048  101.955  -75.352  45.029  1
276049  101.972  -75.352  45.003  1
276050  101.990  -75.352  44.976  1
276051  102.007  -75.353  44.950  1
276052  102.025  -75.354  44.924  1
276412  92.420  -73.066  54.732  1
276413  92.450  -73.076  54.718  1
276414  92.481  -73.086  54.703  1
276415  92.511  -73.097  54.688  1
276416  92.542  -73.108  54.674  1
276417  92.573  -73.117  54.660  1
276418  92.603  -73.128  54.646  1
276419  92.634  -73.139  54.634  1
276420  92.667  -73.148  54.622  1
276421  92.710  -73.160  54.611  1
276422  92.753  -73.170  54.601  1
276423  92.796  -73.182  54.591  1
276424  92.839  -73.192  54.582  1
276425  92.881  -73.204  54.574  1
276426  92.924  -73.214  54.566  1
276427  92.968  -73.226  54.560  1
276428  93.010  -73.236  54.555  1
276429  93.053  -73.248  54.550  1
276430  93.096  -73.258  54.543  1
276431  93.139  -73.270  54.538  1
276432  93.182  -73.280  54.533  1
276433  93.225  -73.292  54.528  1
276434  93.268  -73.302  54.524  1
276435  93.300  -73.305  54.519  1
276436  93.334  -73.317  54.513  1
276437  93.358  -73.325  54.506  1
276438  93.382  -73.330  54.498  1
276439  93.407  -73.336  54.490  1
276440  93.431  -73.343  54.481  1
276441  93.456  -73.349  54.473  1
276442  93.487  -73.349  54.464  1
276443  93.513  -73.343  54.452  1
276444  93.539  -73.337  54.439  1
276445  93.561  -73.332  54.425  1
276446  93.580  -73.327  54.412  1
276447  93.599  -73.321  54.398  1
276448  93.618  -73.316  54.384  1
276449  93.636  -73.311  54.369  1
276450  93.655  -73.305  54.351  1
276451  93.674  -73.301  54.333  1
276452  93.693  -73.296  54.314  1
276453  93.712  -73.290  54.295  1
276459  93.825  -73.259  54.167  1
276460  93.844  -73.254  54.143  1
276461  93.862  -73.249  54.119  1
276462  93.882  -73.243  54.095  1
276463  93.900  -73.238  54.070  1
276464  93.919  -73.233  54.045  1
276465  93.938  -73.227  54.020  1
276466  93.957  -73.222  53.995  1
276467  93.976  -73.217  53.971  1
276468  93.994  -73.212  53.948  1
276469  94.013  -73.207  53.924  1
276470  94.032  -73.202  53.899  1
276471  94.051  -73.196  53.875  1
276472  94.070  -73.191  53.851  1
276473  94.088  -73.186  53.827  1
276474  94.108  -73.180  53.803  1
276475  94.126  -73.175  53.780  1
276476  94.145  -73.170  53.755  1
276477  94.164  -73.165  53.730  1
276478  94.187  -73.170  53.706  1
276500  94.757  -73.372  53.177  1
276501  94.782  -73.380  53.151  1
276502  94.808  -73.387  53.125  1
276503  94.828  -73.392  53.100  1
276504  94.835  -73.390  53.072  1
276505  94.842  -73.390  53.044  1
276506  94.860  -73.393  53.015  1
276507  94.881  -73.398  52.985  1
276508  94.901  -73.402  52.955  1
276509  94.922  -73.406  52.925  1
276510  94.942  -73.411  52.894  1
276511  94.963  -73.415  52.863  1
276512  94.987  -73.417  52.833  1
276513  95.030  -73.405  52.803  1
276514  95.045  -73.418  52.772  1
276515  95.059  -73.431  52.743  1
276516  95.074  -73.444  52.714  1
276517  95.089  -73.458  52.685  1
276518  95.103  -73.471  52.657  1
276519  95.117  -73.484  52.629  1
276520  95.131  -73.498  52.601  1
276521  95.146  -73.511  52.573  1
276522  95.161  -73.524  52.546  1
276523  95.198  -73.493  52.520  1
276524  95.245  -73.474  52.494  1
276525  95.294  -73.467  52.469  1
276526  95.342  -73.459  52.443  1
276527  95.389  -73.449  52.416  1
276528  95.436  -73.441  52.390  1
276529  95.483  -73.432  52.365  1
276530  95.515  -73.431  52.342  1
276531  95.543  -73.432  52.320  1
276532  95.571  -73.433  52.296  1
276533  95.600  -73.434  52.272  1
276534  95.628  -73.434  52.249  1
276535  95.656  -73.424  52.226  1
276536  95.682  -73.404  52.204  1
276537  95.709  -73.384  52.183  1
276538  95.738  -73.384  52.162  1
276539  95.768  -73.417  52.141  1
276540  95.800  -73.449  52.118  1
276541  95.823  -73.454  52.092  1
276542  95.844  -73.454  52.065  1
276543  95.865  -73.454  52.036  1
276544  95.887  -73.455  52.006  1
276545  95.908  -73.455  51.974  1
276546  95.929  -73.455  51.942  1
276547  95.957  -73.464  51.909  1
276548  95.993  -73.464  51.875  1
276549  96.029  -73.466  51.842  1
276550  96.065  -73.468  51.809  1
276551  96.101  -73.470  51.777  1
276552  96.136  -73.471  51.742  1
276553  96.162  -73.473  51.709  1
276554  96.189  -73.486  51.677  1
276555  96.231  -73.507  51.645  1
276556  96.273  -73.529  51.613  1
276557  96.319  -73.534  51.581  1
276558  96.366  -73.536  51.548  1
276559  96.387  -73.534  51.516  1
276560  96.404  -73.534  51.484  1
276561  96.422  -73.532  51.452  1
276562  96.440  -73.531  51.420  1
276563  96.457  -73.529  51.389  1
276564  96.474  -73.528  51.358  1
276565  96.491  -73.527  51.327  1
276566  96.506  -73.521  51.297  1
276567  96.518  -73.516  51.268  1
276568  96.532  -73.510  51.240  1
276569  96.597  -73.510  51.212  1
276570  96.641  -73.527  51.185  1
276571  96.685  -73.543  51.158  1
276572  96.733  -73.563  51.132  1
276573  96.783  -73.586  51.107  1
276574  96.833  -73.608  51.084  1
276575  96.881  -73.633  51.061  1
276576  96.904  -73.641  51.039  1
276577  96.905  -73.632  51.019  1
276578  96.906  -73.622  51.001  1
276579  96.909  -73.611  50.984  1
276580  96.907  -73.587  50.969  1
276581  96.920  -73.606  50.956  1
276582  96.941  -73.616  50.944  1
276583  96.961  -73.625  50.932  1
276584  96.982  -73.635  50.922  1
276585  97.004  -73.644  50.912  1
276586  97.035  -73.647  50.903  1
276587  97.075  -73.644  50.896  1
276588  97.124  -73.635  50.891  1
276589  97.174  -73.625  50.886  1
276590  97.217  -73.620  50.881  1
276591  97.244  -73.624  50.876  1
276592  97.261  -73.634  50.868  1
276593  97.278  -73.644  50.860  1
276594  97.292  -73.657  50.852  1
276595  97.288  -73.662  50.843  1
276596  97.285  -73.666  50.834  1
276597  97.282  -73.672  50.824  1
276598  97.321  -73.673  50.815  1
276599  97.362  -73.680  50.805  1
276600  97.401  -73.685  50.799  1
276601  97.442  -73.691  50.792  1
276602  97.481  -73.695  50.782  1
276603  97.522  -73.700  50.769  1
276604  97.562  -73.706  50.748  1
276605  97.602  -73.710  50.720  1
276606  97.642  -73.716  50.687  1
276607  97.681  -73.721  50.650  1
276608  97.722  -73.725  50.607  1
276609  97.761  -73.731  50.560  1
276610  97.802  -73.736  50.511  1
276611  97.842  -73.741  50.461  1
276612  97.881  -73.746  50.411  1
276613  97.922  -73.751  50.364  1
276614  97.950  -73.766  50.316  1
276615  97.985  -73.780  50.267  1
276616  98.026  -73.790  50.211  1
276617  98.068  -73.800  50.151  1
276618  98.106  -73.809  50.088  1
276619  98.142  -73.816  50.024  1
276620  98.178  -73.823  49.960  1
276621  98.215  -73.831  49.899  1
276622  98.251  -73.838  49.838  1
276623  98.288  -73.845  49.774  1
276624  98.324  -73.852  49.707  1
276625  98.371  -73.879  49.639  1
276626  98.373  -73.914  49.573  1
276627  98.376  -73.947  49.509  1
276628  98.387  -73.937  49.446  1
276629  98.397  -73.926  49.381  1
276630  98.407  -73.918  49.316  1
276631  98.414  -73.932  49.252  1
276632  98.460  -73.961  49.192  1
276633  98.532  -74.008  49.132  1
276634  98.590  -74.038  49.073  1
276635  98.629  -74.049  49.016  1
276636  98.667  -74.060  48.957  1
276637  98.713  -74.074  48.900  1
276638  98.765  -74.089  48.845  1
276639  98.793  -74.090  48.794  1
276640  98.807  -74.116  48.745  1
276641  98.820  -74.142  48.697  1
276642  98.823  -74.164  48.650  1
276643  98.827  -74.187  48.604  1
276644  98.851  -74.202  48.557  1
276645  98.888  -74.213  48.509  1
276646  98.927  -74.211  48.461  1
276647  98.961  -74.200  48.413  1
276648  98.987  -74.207  48.364  1
276649  99.014  -74.213  48.314  1
276650  99.040  -74.219  48.264  1
276651  99.067  -74.225  48.213  1
276652  99.093  -74.232  48.162  1
276653  99.120  -74.238  48.113  1
276654  99.146  -74.244  48.065  1
276655  99.178  -74.252  48.018  1
276656  99.210  -74.261  47.972  1
276657  99.239  -74.272  47.927  1
276658  99.278  -74.288  47.884  1
276659  99.319  -74.302  47.840  1
276660  99.360  -74.317  47.796  1
276661  99.401  -74.332  47.752  1
276662  99.442  -74.346  47.710  1
276663  99.483  -74.361  47.669  1
276664  99.524  -74.376  47.629  1
276665  99.565  -74.391  47.591  1
276666  99.606  -74.405  47.552  1
276667  99.643  -74.418  47.514  1
276668  99.673  -74.427  47.477  1
276669  99.703  -74.435  47.441  1
276670  99.732  -74.443  47.405  1
276671  99.769  -74.451  47.370  1
276672  99.832  -74.456  47.335  1
276673  99.876  -74.462  47.300  1
276674  99.907  -74.469  47.265  1
276675  99.938  -74.476  47.231  1
276676  99.969  -74.483  47.199  1
276677  99.999  -74.490  47.169  1
276678  100.030  -74.497  47.138  1
276679  100.061  -74.504  47.107  1
276680  100.086  -74.518  47.078  1
276681  100.108  -74.540  47.049  1
276682  100.130  -74.561  47.021  1
276683  100.151  -74.581  46.995  1
276684  100.173  -74.603  46.967  1
276685  100.195  -74.623  46.940  1
276686  100.216  -74.644  46.913  1
276687  100.238  -74.665  46.887  1
276688  100.260  -74.685  46.861  1
276689  100.291  -74.689  46.835  1
276690  100.322  -74.693  46.807  1
276691  100.353  -74.702  46.778  1
276692  100.384  -74.714  46.750  1
276693  100.414  -74.726  46.718  1
276694  100.444  -74.738  46.687  1
276695  100.475  -74.750  46.657  1
276696  100.506  -74.762  46.628  1
276697  100.537  -74.775  46.599  1
276698  100.563  -74.782  46.570  1
276699  100.591  -74.790  46.541  1
276700  100.617  -74.797  46.512  1
276701  100.644  -74.805  46.482  1
276702  100.671  -74.813  46.454  1
276703  100.698  -74.821  46.426  1
276704  100.725  -74.828  46.399  1
276705  100.752  -74.836  46.371  1
276706  100.777  -74.844  46.343  1
276707  100.798  -74.850  46.314  1
276708  100.820  -74.856  46.286  1
276709  100.841  -74.863  46.261  1
276710  100.862  -74.872  46.233  1
276711  100.890  -74.889  46.203  1
276712  100.923  -74.910  46.170  1
276713  100.957  -74.929  46.135  1
276714  100.990  -74.950  46.103  1
276715  101.023  -74.970  46.071  1
276716  101.054  -74.985  46.040  1
276717  101.082  -74.997  46.009  1
276718  101.111  -75.010  45.977  1
276719  101.140  -75.022  45.945  1
276720  101.169  -75.034  45.914  1
276721  101.198  -75.046  45.879  1
276722  101.227  -75.058  45.846  1
276723  101.255  -75.070  45.811  1
276724  101.293  -75.092  45.775  1
276725  101.330  -75.113  45.739  1
276726  101.364  -75.132  45.703  1
276727  101.397  -75.150  45.668  1
276728  101.431  -75.169  45.634  1
276729  101.465  -75.187  45.602  1
276730  101.498  -75.206  45.571  1
276731  101.532  -75.224  45.539  1
276732  101.566  -75.243  45.509  1
276733  101.600  -75.261  45.478  1
276734  101.633  -75.280  45.448  1
276735  101.667  -75.298  45.418  1
276736  101.700  -75.317  45.389  1
276737  101.734  -75.333  45.360  1
276738  101.763  -75.327  45.331  1
276739  101.792  -75.323  45.301  1
276740  101.815  -75.311  45.271  1
276741  101.830  -75.308  45.242  1
276742  101.848  -75.308  45.212  1
276743  101.865  -75.308  45.183  1
276744  101.883  -75.309  45.154  1
276745  101.900  -75.310  45.125  1
276746  101.917  -75.310  45.097  1
276747  101.935  -75.311  45.070  1
276748  101.953  -75.311  45.041  1
276749  101.970  -75.311  45.014  1
276750  101.987  -75.312  44.988  1
276751  102.005  -75.313  44.962  1
276752  102.022  -75.314  44.935  1
276753  102.040  -75.314  44.909  1
277113  92.415  -73.037  54.737  1
277114  92.446  -73.047  54.722  1
277115  92.477  -73.058  54.707  1
277116  92.507  -73.068  54.692  1
277117  92.538  -73.078  54.677  1
277118  92.569  -73.089  54.663  1
277119  92.599  -73.098  54.648  1
277120  92.630  -73.109  54.635  1
277121  92.664  -73.120  54.623  1
277122  92.707  -73.130  54.611  1
277123  92.749  -73.142  54.600  1
277124  92.792  -73.152  54.589  1
277125  92.836  -73.164  54.578  1
277126  92.878  -73.174  54.569  1
277127  92.921  -73.186  54.561  1
277128  92.964  -73.196  54.554  1
277129  93.007  -73.208  54.548  1
277130  93.050  -73.218  54.542  1
277131  93.093  -73.230  54.535  1
277132  93.136  -73.240  54.529  1
277133  93.179  -73.252  54.523  1
277134  93.221  -73.262  54.517  1
277135  93.264  -73.274  54.513  1
277136  93.301  -73.283  54.508  1
277137  93.326  -73.289  54.501  1
277138  93.350  -73.295  54.493  1
277139  93.374  -73.300  54.485  1
277140  93.399  -73.306  54.476  1
277141  93.423  -73.312  54.467  1
277142  93.448  -73.318  54.458  1
277143  93.482  -73.314  54.450  1
277144  93.508  -73.309  54.438  1
277145  93.534  -73.303  54.425  1
277146  93.560  -73.298  54.412  1
277147  93.582  -73.293  54.398  1
277148  93.601  -73.287  54.385  1
277149  93.620  -73.282  54.371  1
277150  93.638  -73.277  54.355  1
277151  93.657  -73.271  54.336  1
277152  93.676  -73.266  54.316  1
277153  93.695  -73.261  54.297  1
277154  93.714  -73.256  54.279  1
277204  94.833  -73.357  53.082  1
277205  94.845  -73.359  53.055  1
277206  94.852  -73.358  53.027  1
277207  94.863  -73.358  52.999  1
277208  94.884  -73.363  52.970  1
277209  94.904  -73.367  52.940  1
277210  94.925  -73.371  52.910  1
277211  94.945  -73.376  52.880  1
277212  94.966  -73.380  52.852  1
277213  94.986  -73.385  52.822  1
277214  95.008  -73.388  52.792  1
277215  95.051  -73.377  52.762  1
277216  95.067  -73.388  52.733  1
277217  95.082  -73.402  52.705  1
277218  95.096  -73.415  52.677  1
277219  95.110  -73.428  52.649  1
277220  95.125  -73.442  52.622  1
277221  95.139  -73.455  52.594  1
277222  95.154  -73.468  52.566  1
277223  95.168  -73.481  52.540  1
277224  95.194  -73.473  52.513  1
277225  95.238  -73.428  52.488  1
277226  95.285  -73.416  52.462  1
277227  95.334  -73.408  52.435  1
277228  95.383  -73.400  52.410  1
277229  95.431  -73.392  52.385  1
277230  95.478  -73.383  52.360  1
277231  95.510  -73.382  52.338  1
277232  95.538  -73.383  52.315  1
277233  95.566  -73.383  52.292  1
277234  95.595  -73.384  52.269  1
277235  95.623  -73.385  52.246  1
277236  95.651  -73.386  52.224  1
277237  95.679  -73.377  52.203  1
277238  95.706  -73.358  52.182  1
277239  95.735  -73.361  52.161  1
277240  95.765  -73.393  52.141  1
277241  95.800  -73.417  52.120  1
277242  95.837  -73.428  52.095  1
277243  95.858  -73.429  52.067  1
277244  95.879  -73.429  52.039  1
277245  95.900  -73.430  52.009  1
277246  95.920  -73.430  51.977  1
277247  95.942  -73.430  51.945  1
277248  95.962  -73.431  51.913  1
277249  95.988  -73.436  51.880  1
277250  96.015  -73.440  51.848  1
277251  96.051  -73.442  51.815  1
277252  96.087  -73.444  51.784  1
277253  96.122  -73.446  51.751  1
277254  96.158  -73.448  51.718  1
277255  96.184  -73.456  51.686  1
277256  96.226  -73.478  51.654  1
277257  96.272  -73.482  51.623  1
277258  96.319  -73.484  51.591  1
277259  96.359  -73.485  51.559  1
277260  96.377  -73.484  51.526  1
277261  96.394  -73.482  51.495  1
277262  96.411  -73.481  51.463  1
277263  96.429  -73.480  51.431  1
277264  96.446  -73.478  51.400  1
277265  96.463  -73.477  51.370  1
277266  96.481  -73.475  51.340  1
277267  96.499  -73.474  51.310  1
277268  96.516  -73.473  51.281  1
277269  96.543  -73.473  51.253  1
277270  96.587  -73.490  51.225  1
277271  96.631  -73.507  51.198  1
277272  96.675  -73.524  51.171  1
277273  96.723  -73.544  51.145  1
277274  96.773  -73.566  51.120  1
277275  96.822  -73.590  51.096  1
277276  96.869  -73.616  51.074  1
277277  96.889  -73.622  51.051  1
277278  96.890  -73.613  51.030  1
277279  96.890  -73.604  51.012  1
277280  96.892  -73.593  50.994  1
277281  96.895  -73.582  50.979  1
277282  96.929  -73.568  50.965  1
277283  96.949  -73.579  50.952  1
277284  96.969  -73.591  50.939  1
277285  96.990  -73.603  50.928  1
277286  97.011  -73.614  50.917  1
277287  97.043  -73.625  50.908  1
277288  97.091  -73.617  50.900  1
277289  97.139  -73.608  50.894  1
277290  97.186  -73.600  50.888  1
277291  97.234  -73.590  50.881  1
277292  97.279  -73.584  50.876  1
277293  97.339  -73.596  50.868  1
277294  97.315  -73.618  50.859  1
277295  97.293  -73.637  50.850  1
277296  97.289  -73.642  50.839  1
277297  97.283  -73.648  50.827  1
277298  97.291  -73.653  50.816  1
277299  97.329  -73.649  50.807  1
277300  97.368  -73.646  50.797  1
277301  97.407  -73.647  50.790  1
277302  97.447  -73.654  50.783  1
277303  97.488  -73.661  50.775  1
277304  97.527  -73.668  50.763  1
277305  97.568  -73.675  50.743  1
277306  97.608  -73.681  50.716  1
277307  97.648  -73.688  50.683  1
277308  97.688  -73.695  50.646  1
277309  97.728  -73.701  50.603  1
277310  97.769  -73.706  50.556  1
277311  97.808  -73.711  50.506  1
277312  97.849  -73.716  50.457  1
277313  97.888  -73.721  50.407  1
277314  97.928  -73.726  50.359  1
277315  97.962  -73.737  50.311  1
277316  98.002  -73.748  50.261  1
277317  98.040  -73.756  50.203  1
277318  98.077  -73.763  50.142  1
277319  98.113  -73.771  50.079  1
277320  98.149  -73.778  50.015  1
277321  98.185  -73.785  49.951  1
277322  98.222  -73.792  49.890  1
277323  98.258  -73.800  49.828  1
277324  98.295  -73.807  49.762  1
277325  98.342  -73.817  49.695  1
277326  98.360  -73.850  49.628  1
277327  98.362  -73.886  49.564  1
277328  98.364  -73.922  49.502  1
277329  98.372  -73.924  49.439  1
277330  98.383  -73.913  49.372  1
277331  98.393  -73.904  49.305  1
277332  98.429  -73.925  49.240  1
277333  98.533  -73.970  49.180  1
277334  98.589  -73.998  49.121  1
277335  98.628  -74.010  49.063  1
277336  98.667  -74.021  49.006  1
277337  98.705  -74.032  48.947  1
277338  98.744  -74.043  48.889  1
277339  98.783  -74.054  48.834  1
277340  98.820  -74.067  48.781  1
277341  98.825  -74.090  48.731  1
277342  98.827  -74.113  48.683  1
277343  98.830  -74.136  48.637  1
277344  98.833  -74.159  48.591  1
277345  98.865  -74.171  48.544  1
277346  98.903  -74.181  48.497  1
277347  98.942  -74.192  48.450  1
277348  98.981  -74.195  48.403  1
277349  99.014  -74.186  48.354  1
277350  99.041  -74.192  48.304  1
277351  99.067  -74.199  48.254  1
277352  99.093  -74.205  48.204  1
277353  99.120  -74.211  48.153  1
277354  99.146  -74.217  48.105  1
277355  99.173  -74.223  48.057  1
277356  99.199  -74.230  48.008  1
277357  99.226  -74.236  47.962  1
277358  99.249  -74.245  47.919  1
277359  99.292  -74.257  47.876  1
277360  99.334  -74.270  47.832  1
277361  99.375  -74.286  47.789  1
277362  99.416  -74.300  47.746  1
277363  99.457  -74.315  47.703  1
277364  99.498  -74.330  47.662  1
277365  99.539  -74.344  47.622  1
277366  99.580  -74.359  47.583  1
277367  99.621  -74.374  47.545  1
277368  99.661  -74.388  47.507  1
277369  99.691  -74.396  47.469  1
277370  99.721  -74.405  47.433  1
277371  99.766  -74.411  47.398  1
277372  99.815  -74.418  47.363  1
277373  99.845  -74.424  47.328  1
277374  99.876  -74.432  47.292  1
277375  99.907  -74.439  47.258  1
277376  99.937  -74.446  47.225  1
277377  99.968  -74.452  47.193  1
277378  99.999  -74.459  47.162  1
277379  100.030  -74.467  47.132  1
277380  100.060  -74.474  47.103  1
277381  100.089  -74.483  47.073  1
277382  100.111  -74.504  47.044  1
277383  100.132  -74.525  47.016  1
277384  100.154  -74.546  46.990  1
277385  100.176  -74.567  46.962  1
277386  100.197  -74.588  46.935  1
277387  100.219  -74.609  46.907  1
277388  100.241  -74.630  46.880  1
277389  100.266  -74.645  46.853  1
277390  100.296  -74.649  46.827  1
277391  100.327  -74.653  46.799  1
277392  100.358  -74.656  46.770  1
277393  100.389  -74.666  46.740  1
277394  100.419  -74.678  46.709  1
277395  100.450  -74.690  46.677  1
277396  100.481  -74.703  46.647  1
277397  100.511  -74.715  46.618  1
277398  100.542  -74.727  46.589  1
277399  100.572  -74.739  46.560  1
277400  100.603  -74.751  46.531  1
277401  100.634  -74.763  46.501  1
277402  100.665  -74.775  46.472  1
277403  100.691  -74.783  46.444  1
277404  100.718  -74.791  46.416  1
277405  100.745  -74.798  46.389  1
277406  100.772  -74.806  46.362  1
277407  100.798  -74.813  46.334  1
277408  100.821  -74.820  46.307  1
277409  100.842  -74.827  46.279  1
277410  100.862  -74.834  46.252  1
277411  100.886  -74.847  46.223  1
277412  100.913  -74.864  46.191  1
277413  100.940  -74.881  46.158  1
277414  100.973  -74.900  46.122  1
277415  101.006  -74.920  46.088  1
277416  101.039  -74.941  46.056  1
277417  101.072  -74.960  46.024  1
277418  101.102  -74.973  45.993  1
277419  101.130  -74.985  45.961  1
277420  101.159  -74.997  45.929  1
277421  101.188  -75.010  45.897  1
277422  101.217  -75.022  45.862  1
277423  101.246  -75.034  45.828  1
277424  101.276  -75.048  45.793  1
277425  101.315  -75.070  45.757  1
277426  101.352  -75.092  45.722  1
277427  101.386  -75.110  45.686  1
277428  101.420  -75.129  45.651  1
277429  101.454  -75.148  45.618  1
277430  101.487  -75.166  45.586  1
277431  101.521  -75.185  45.555  1
277432  101.554  -75.203  45.525  1
277433  101.588  -75.222  45.494  1
277434  101.622  -75.240  45.463  1
277435  101.656  -75.259  45.432  1
277436  101.689  -75.277  45.403  1
277437  101.723  -75.296  45.375  1
277438  101.753  -75.293  45.346  1
277439  101.782  -75.289  45.316  1
277440  101.811  -75.283  45.287  1
277441  101.828  -75.267  45.257  1
277442  101.845  -75.267  45.227  1
277443  101.863  -75.268  45.197  1
277444  101.880  -75.269  45.169  1
277445  101.898  -75.270  45.141  1
277446  101.915  -75.270  45.113  1
277447  101.933  -75.270  45.084  1
277448  101.950  -75.271  45.056  1
277449  101.967  -75.271  45.028  1
277450  101.985  -75.272  45.001  1
277451  102.003  -75.273  44.974  1
277452  102.020  -75.273  44.947  1
277453  102.037  -75.273  44.921  1
277814  92.411  -73.007  54.742  1
277815  92.442  -73.018  54.726  1
277816  92.473  -73.028  54.710  1
277817  92.503  -73.039  54.695  1
277818  92.534  -73.049  54.680  1
277819  92.564  -73.059  54.665  1
277820  92.595  -73.070  54.650  1
277821  92.626  -73.080  54.637  1
277822  92.661  -73.090  54.623  1
277823  92.704  -73.101  54.610  1
277824  92.746  -73.112  54.599  1
277825  92.789  -73.123  54.587  1
277826  92.832  -73.134  54.576  1
277827  92.875  -73.145  54.565  1
277828  92.918  -73.156  54.556  1
277829  92.961  -73.167  54.548  1
277830  93.004  -73.178  54.541  1
277831  93.047  -73.189  54.535  1
277832  93.089  -73.200  54.529  1
277833  93.132  -73.211  54.522  1
277834  93.176  -73.222  54.515  1
277835  93.218  -73.233  54.508  1
277836  93.261  -73.244  54.503  1
277837  93.293  -73.252  54.497  1
277838  93.318  -73.258  54.490  1
277839  93.342  -73.264  54.481  1
277840  93.366  -73.270  54.472  1
277841  93.391  -73.276  54.464  1
277842  93.415  -73.282  54.455  1
277843  93.440  -73.288  54.446  1
277844  93.478  -73.281  54.437  1
277845  93.503  -73.275  54.425  1
277846  93.529  -73.270  54.412  1
277847  93.555  -73.264  54.399  1
277848  93.581  -73.258  54.385  1
277849  93.603  -73.252  54.371  1
277850  93.622  -73.248  54.357  1
277851  93.641  -73.242  54.341  1
277852  93.659  -73.237  54.321  1
277853  93.679  -73.232  54.301  1
277854  93.697  -73.227  54.282  1
277908  94.871  -73.325  52.984  1
277909  94.887  -73.328  52.955  1
277910  94.907  -73.332  52.926  1
277911  94.928  -73.336  52.897  1
277912  94.948  -73.341  52.868  1
277913  94.969  -73.346  52.839  1
277914  94.989  -73.350  52.810  1
277915  95.010  -73.354  52.781  1
277916  95.030  -73.358  52.752  1
277917  95.072  -73.348  52.724  1
277918  95.089  -73.359  52.696  1
277919  95.103  -73.372  52.669  1
277920  95.118  -73.386  52.642  1
277921  95.132  -73.399  52.614  1
277922  95.146  -73.412  52.587  1
277923  95.161  -73.425  52.560  1
277924  95.175  -73.439  52.534  1
277925  95.190  -73.452  52.508  1
277926  95.234  -73.409  52.482  1
277927  95.278  -73.365  52.456  1
277928  95.326  -73.357  52.431  1
277929  95.375  -73.349  52.405  1
277930  95.423  -73.341  52.379  1
277931  95.473  -73.340  52.355  1
277932  95.506  -73.338  52.332  1
277933  95.533  -73.336  52.310  1
277934  95.561  -73.334  52.287  1
277935  95.590  -73.335  52.265  1
277936  95.618  -73.336  52.243  1
277937  95.647  -73.336  52.221  1
277938  95.675  -73.337  52.200  1
277939  95.702  -73.331  52.180  1
277940  95.732  -73.337  52.160  1
277941  95.767  -73.356  52.140  1
277942  95.806  -73.368  52.118  1
277943  95.843  -73.380  52.095  1
277944  95.881  -73.392  52.068  1
277945  95.902  -73.393  52.040  1
277946  95.923  -73.393  52.011  1
277947  95.944  -73.393  51.981  1
277948  95.965  -73.394  51.950  1
277949  95.985  -73.394  51.918  1
277950  96.012  -73.399  51.886  1
277951  96.038  -73.403  51.854  1
277952  96.064  -73.408  51.824  1
277953  96.091  -73.412  51.792  1
277954  96.118  -73.418  51.760  1
277955  96.145  -73.422  51.728  1
277956  96.179  -73.427  51.696  1
277957  96.225  -73.430  51.665  1
277958  96.272  -73.432  51.633  1
277959  96.319  -73.434  51.601  1
277960  96.348  -73.434  51.569  1
277961  96.366  -73.433  51.537  1
277962  96.383  -73.431  51.506  1
277963  96.400  -73.430  51.474  1
277964  96.418  -73.428  51.442  1
277965  96.436  -73.427  51.412  1
277966  96.453  -73.426  51.383  1
277967  96.470  -73.424  51.353  1
277968  96.489  -73.427  51.324  1
277969  96.516  -73.449  51.296  1
277970  96.541  -73.459  51.268  1
277971  96.577  -73.470  51.240  1
277972  96.621  -73.487  51.213  1
277973  96.665  -73.504  51.186  1
277974  96.714  -73.524  51.160  1
277975  96.763  -73.547  51.134  1
277976  96.811  -73.574  51.109  1
277977  96.858  -73.600  51.087  1
277978  96.874  -73.603  51.063  1
277979  96.875  -73.593  51.042  1
277980  96.875  -73.584  51.023  1
277981  96.876  -73.576  51.005  1
277982  96.886  -73.563  50.989  1
277983  96.926  -73.543  50.974  1
277984  96.960  -73.532  50.960  1
277985  96.980  -73.544  50.946  1
277986  97.025  -73.555  50.934  1
277987  97.066  -73.568  50.924  1
277988  97.100  -73.584  50.913  1
277989  97.147  -73.586  50.904  1
277990  97.185  -73.582  50.898  1
277991  97.224  -73.578  50.890  1
277992  97.262  -73.573  50.882  1
277993  97.345  -73.562  50.875  1
277994  97.338  -73.581  50.868  1
277995  97.309  -73.604  50.861  1
277996  97.294  -73.618  50.852  1
277997  97.287  -73.624  50.839  1
277998  97.273  -73.634  50.824  1
277999  97.299  -73.634  50.812  1
278000  97.337  -73.630  50.803  1
278001  97.376  -73.627  50.794  1
278002  97.415  -73.623  50.786  1
278003  97.453  -73.620  50.779  1
278004  97.493  -73.621  50.770  1
278005  97.532  -73.628  50.757  1
278006  97.573  -73.634  50.738  1
278007  97.613  -73.641  50.711  1
278008  97.653  -73.648  50.679  1
278009  97.693  -73.655  50.641  1
278010  97.734  -73.662  50.598  1
278011  97.774  -73.669  50.551  1
278012  97.814  -73.676  50.502  1
278013  97.854  -73.683  50.453  1
278014  97.894  -73.690  50.402  1
278015  97.935  -73.697  50.353  1
278016  97.974  -73.709  50.303  1
278017  98.011  -73.711  50.252  1
278018  98.047  -73.719  50.193  1
278019  98.084  -73.725  50.131  1
278020  98.120  -73.733  50.068  1
278021  98.156  -73.740  50.004  1
278022  98.193  -73.747  49.939  1
278023  98.229  -73.754  49.876  1
278024  98.265  -73.762  49.813  1
278025  98.301  -73.769  49.747  1
278026  98.346  -73.786  49.681  1
278027  98.348  -73.822  49.618  1
278028  98.350  -73.859  49.555  1
278029  98.352  -73.894  49.493  1
278030  98.358  -73.911  49.429  1
278031  98.368  -73.901  49.362  1
278032  98.364  -73.914  49.295  1
278033  98.500  -73.948  49.230  1
278034  98.571  -73.961  49.171  1
278035  98.604  -73.973  49.112  1
278036  98.640  -73.985  49.053  1
278037  98.675  -73.996  48.994  1
278038  98.711  -74.008  48.937  1
278039  98.747  -74.020  48.880  1
278040  98.783  -74.031  48.824  1
278041  98.827  -74.040  48.771  1
278042  98.831  -74.062  48.719  1
278043  98.834  -74.085  48.672  1
278044  98.837  -74.107  48.624  1
278045  98.843  -74.129  48.577  1
278046  98.880  -74.139  48.530  1
278047  98.918  -74.150  48.484  1
278048  98.955  -74.160  48.439  1
278049  98.995  -74.172  48.393  1
278050  99.035  -74.180  48.344  1
278051  99.068  -74.173  48.295  1
278052  99.094  -74.179  48.245  1
278053  99.121  -74.185  48.194  1
278054  99.147  -74.191  48.145  1
278055  99.173  -74.198  48.096  1
278056  99.200  -74.204  48.048  1
278057  99.226  -74.210  48.001  1
278058  99.238  -74.218  47.955  1
278059  99.252  -74.229  47.911  1
278060  99.295  -74.240  47.868  1
278061  99.338  -74.252  47.824  1
278062  99.381  -74.264  47.781  1
278063  99.425  -74.277  47.738  1
278064  99.468  -74.288  47.696  1
278065  99.511  -74.300  47.655  1
278066  99.554  -74.312  47.615  1
278067  99.595  -74.327  47.576  1
278068  99.636  -74.342  47.537  1
278069  99.677  -74.357  47.499  1
278070  99.709  -74.367  47.461  1
278071  99.753  -74.373  47.426  1
278072  99.783  -74.380  47.390  1
278073  99.814  -74.387  47.355  1
278074  99.845  -74.394  47.321  1
278075  99.875  -74.401  47.285  1
278076  99.906  -74.408  47.251  1
278077  99.937  -74.415  47.218  1
278078  99.968  -74.422  47.187  1
278079  99.998  -74.429  47.156  1
278080  100.028  -74.436  47.126  1
278081  100.059  -74.443  47.097  1
278082  100.090  -74.450  47.068  1
278083  100.113  -74.469  47.039  1
278084  100.135  -74.490  47.011  1
278085  100.156  -74.511  46.984  1
278086  100.178  -74.531  46.957  1
278087  100.200  -74.552  46.929  1
278088  100.221  -74.574  46.901  1
278089  100.243  -74.594  46.873  1
278090  100.271  -74.604  46.845  1
278091  100.301  -74.608  46.819  1
278092  100.333  -74.612  46.791  1
278093  100.363  -74.615  46.761  1
278094  100.394  -74.619  46.731  1
278095  100.425  -74.631  46.699  1
278096  100.456  -74.643  46.667  1
278097  100.486  -74.655  46.637  1
278098  100.517  -74.667  46.608  1
278099  100.548  -74.679  46.579  1
278100  100.578  -74.691  46.549  1
278101  100.609  -74.703  46.520  1
278102  100.639  -74.715  46.490  1
278103  100.670  -74.728  46.461  1
278104  100.701  -74.740  46.433  1
278105  100.731  -74.752  46.406  1
278106  100.762  -74.764  46.378  1
278107  100.792  -74.775  46.351  1
278108  100.819  -74.783  46.326  1
278109  100.844  -74.791  46.300  1
278110  100.864  -74.798  46.272  1
278111  100.884  -74.808  46.243  1
278112  100.909  -74.822  46.211  1
278113  100.936  -74.839  46.178  1
278114  100.964  -74.855  46.145  1
278115  100.991  -74.872  46.110  1
278116  101.022  -74.891  46.076  1
278117  101.055  -74.911  46.042  1
278118  101.089  -74.931  46.009  1
278119  101.121  -74.949  45.977  1
278120  101.150  -74.961  45.945  1
278121  101.179  -74.973  45.912  1
278122  101.207  -74.985  45.879  1
278123  101.236  -74.997  45.845  1
278124  101.265  -75.010  45.810  1
278125  101.298  -75.026  45.774  1
278126  101.337  -75.049  45.739  1
278127  101.375  -75.071  45.704  1
278128  101.409  -75.089  45.669  1
278129  101.443  -75.108  45.635  1
278130  101.476  -75.126  45.602  1
278131  101.510  -75.145  45.570  1
278132  101.543  -75.163  45.539  1
278133  101.577  -75.182  45.509  1
278134  101.611  -75.201  45.478  1
278135  101.644  -75.220  45.448  1
278136  101.678  -75.238  45.418  1
278137  101.711  -75.256  45.388  1
278138  101.742  -75.259  45.359  1
278139  101.771  -75.254  45.331  1
278140  101.801  -75.249  45.302  1
278141  101.830  -75.245  45.272  1
278142  101.843  -75.227  45.243  1
278143  101.860  -75.228  45.213  1
278144  101.878  -75.229  45.184  1
278145  101.895  -75.229  45.155  1
278146  101.912  -75.229  45.127  1
278147  101.930  -75.230  45.099  1
278148  101.948  -75.231  45.070  1
278149  101.965  -75.231  45.042  1
278150  101.982  -75.232  45.014  1
278151  102.000  -75.232  44.987  1
278152  102.017  -75.232  44.960  1
278153  102.035  -75.233  44.933  1
278154  102.052  -75.234  44.906  1
278515  92.407  -72.979  54.746  1
278516  92.438  -72.989  54.730  1
278517  92.469  -72.999  54.714  1
278518  92.499  -73.009  54.699  1
278519  92.529  -73.020  54.683  1
278520  92.560  -73.030  54.667  1
278521  92.591  -73.040  54.653  1
278522  92.622  -73.051  54.638  1
278523  92.657  -73.061  54.624  1
278524  92.700  -73.073  54.611  1
278525  92.743  -73.083  54.598  1
278526  92.786  -73.095  54.586  1
278527  92.829  -73.105  54.574  1
278528  92.872  -73.117  54.563  1
278529  92.915  -73.127  54.554  1
278530  92.957  -73.139  54.545  1
278531  93.001  -73.149  54.537  1
278532  93.044  -73.160  54.531  1
278533  93.086  -73.171  54.522  1
278534  93.129  -73.182  54.514  1
278535  93.172  -73.193  54.506  1
278536  93.215  -73.204  54.501  1
278537  93.258  -73.215  54.494  1
278538  93.285  -73.222  54.487  1
278539  93.309  -73.228  54.479  1
278540  93.334  -73.234  54.471  1
278541  93.358  -73.240  54.461  1
278542  93.383  -73.246  54.452  1
278543  93.407  -73.252  54.444  1
278544  93.435  -73.255  54.434  1
278545  93.473  -73.247  54.425  1
278546  93.498  -73.241  54.413  1
278547  93.524  -73.236  54.400  1
278548  93.550  -73.230  54.386  1
278549  93.576  -73.224  54.372  1
278550  93.602  -73.218  54.357  1
278551  93.624  -73.213  54.342  1
278552  93.643  -73.208  54.326  1
278553  93.662  -73.203  54.306  1
278554  93.681  -73.198  54.287  1
278611  94.910  -73.297  52.912  1
278612  94.931  -73.302  52.884  1
278613  94.951  -73.306  52.856  1
278614  94.972  -73.311  52.827  1
278615  94.992  -73.315  52.799  1
278616  95.013  -73.319  52.770  1
278617  95.034  -73.324  52.742  1
278618  95.054  -73.328  52.714  1
278619  95.093  -73.319  52.687  1
278620  95.111  -73.330  52.661  1
278621  95.125  -73.343  52.634  1
278622  95.139  -73.356  52.607  1
278623  95.154  -73.370  52.581  1
278624  95.169  -73.383  52.554  1
278625  95.183  -73.396  52.529  1
278626  95.197  -73.409  52.503  1
278627  95.230  -73.388  52.477  1
278628  95.274  -73.343  52.452  1
278629  95.319  -73.307  52.426  1
278630  95.369  -73.308  52.400  1
278631  95.418  -73.309  52.374  1
278632  95.468  -73.311  52.350  1
278633  95.503  -73.309  52.327  1
278634  95.531  -73.308  52.305  1
278635  95.559  -73.305  52.283  1
278636  95.587  -73.303  52.261  1
278637  95.615  -73.302  52.239  1
278638  95.643  -73.299  52.218  1
278639  95.671  -73.298  52.197  1
278640  95.699  -73.296  52.177  1
278641  95.735  -73.297  52.158  1
278642  95.773  -73.308  52.138  1
278643  95.811  -73.320  52.117  1
278644  95.849  -73.332  52.094  1
278645  95.888  -73.344  52.069  1
278646  95.925  -73.355  52.041  1
278647  95.946  -73.356  52.014  1
278648  95.967  -73.356  51.985  1
278649  95.988  -73.357  51.955  1
278650  96.009  -73.358  51.925  1
278651  96.034  -73.362  51.894  1
278652  96.061  -73.366  51.863  1
278653  96.088  -73.371  51.833  1
278654  96.114  -73.375  51.802  1
278655  96.141  -73.380  51.770  1
278656  96.167  -73.383  51.738  1
278657  96.185  -73.379  51.706  1
278658  96.226  -73.380  51.674  1
278659  96.272  -73.383  51.643  1
278660  96.319  -73.384  51.611  1
278661  96.337  -73.383  51.579  1
278662  96.355  -73.381  51.548  1
278663  96.373  -73.380  51.517  1
278664  96.390  -73.379  51.486  1
278665  96.407  -73.377  51.455  1
278666  96.425  -73.376  51.425  1
278667  96.445  -73.381  51.396  1
278668  96.471  -73.404  51.368  1
278669  96.498  -73.427  51.340  1
278670  96.525  -73.449  51.311  1
278671  96.550  -73.452  51.283  1
278672  96.575  -73.456  51.255  1
278673  96.611  -73.467  51.228  1
278674  96.655  -73.484  51.201  1
278675  96.704  -73.506  51.174  1
278676  96.752  -73.531  51.149  1
278677  96.799  -73.557  51.124  1
278678  96.847  -73.583  51.100  1
278679  96.859  -73.583  51.077  1
278680  96.860  -73.575  51.055  1
278681  96.860  -73.565  51.036  1
278682  96.857  -73.551  51.017  1
278683  96.873  -73.515  51.000  1
278684  96.913  -73.496  50.985  1
278685  96.959  -73.493  50.971  1
278686  97.000  -73.506  50.955  1
278687  97.035  -73.520  50.943  1
278688  97.070  -73.534  50.931  1
278689  97.104  -73.549  50.919  1
278690  97.160  -73.568  50.910  1
278691  97.208  -73.568  50.902  1
278692  97.246  -73.563  50.894  1
278693  97.319  -73.556  50.886  1
278694  97.307  -73.541  50.880  1
278695  97.314  -73.565  50.873  1
278696  97.303  -73.590  50.867  1
278697  97.292  -73.600  50.858  1
278698  97.277  -73.609  50.845  1
278699  97.269  -73.618  50.828  1
278700  97.308  -73.615  50.815  1
278701  97.346  -73.611  50.804  1
278702  97.385  -73.608  50.795  1
278703  97.423  -73.604  50.786  1
278704  97.462  -73.601  50.777  1
278705  97.500  -73.597  50.766  1
278706  97.539  -73.594  50.751  1
278707  97.578  -73.594  50.729  1
278708  97.618  -73.602  50.702  1
278709  97.658  -73.609  50.670  1
278710  97.699  -73.615  50.633  1
278711  97.739  -73.622  50.590  1
278712  97.779  -73.629  50.543  1
278713  97.819  -73.636  50.495  1
278714  97.859  -73.643  50.445  1
278715  97.899  -73.650  50.395  1
278716  97.940  -73.657  50.344  1
278717  97.978  -73.681  50.293  1
278718  98.016  -73.697  50.239  1
278719  98.054  -73.691  50.179  1
278720  98.090  -73.687  50.116  1
278721  98.127  -73.694  50.052  1
278722  98.163  -73.702  49.988  1
278723  98.200  -73.709  49.924  1
278724  98.236  -73.716  49.861  1
278725  98.272  -73.723  49.798  1
278726  98.308  -73.731  49.734  1
278727  98.335  -73.759  49.669  1
278728  98.337  -73.794  49.608  1
278729  98.339  -73.831  49.546  1
278730  98.341  -73.866  49.483  1
278731  98.343  -73.898  49.418  1
278732  98.348  -73.893  49.351  1
278733  98.447  -73.921  49.285  1
278734  98.510  -73.929  49.221  1
278735  98.574  -73.938  49.161  1
278736  98.594  -73.951  49.101  1
278737  98.630  -73.963  49.043  1
278738  98.666  -73.975  48.985  1
278739  98.702  -73.986  48.928  1
278740  98.737  -73.998  48.871  1
278741  98.773  -74.010  48.817  1
278742  98.828  -74.020  48.763  1
278743  98.838  -74.033  48.710  1
278744  98.841  -74.057  48.661  1
278745  98.844  -74.079  48.613  1
278746  98.858  -74.098  48.565  1
278747  98.895  -74.108  48.518  1
278748  98.933  -74.119  48.472  1
278749  98.971  -74.129  48.427  1
278750  99.008  -74.139  48.381  1
278751  99.048  -74.151  48.334  1
278752  99.089  -74.164  48.285  1
278753  99.121  -74.158  48.236  1
278754  99.148  -74.164  48.186  1
278755  99.174  -74.171  48.137  1
278756  99.200  -74.177  48.088  1
278757  99.227  -74.183  48.040  1
278758  99.237  -74.192  47.993  1
278759  99.242  -74.202  47.948  1
278760  99.254  -74.212  47.904  1
278761  99.297  -74.224  47.860  1
278762  99.341  -74.236  47.817  1
278763  99.384  -74.248  47.774  1
278764  99.427  -74.260  47.731  1
278765  99.471  -74.271  47.689  1
278766  99.514  -74.283  47.648  1
278767  99.557  -74.295  47.608  1
278768  99.600  -74.307  47.569  1
278769  99.644  -74.319  47.530  1
278770  99.695  -74.330  47.492  1
278771  99.721  -74.336  47.454  1
278772  99.752  -74.342  47.419  1
278773  99.783  -74.349  47.383  1
278774  99.814  -74.356  47.348  1
278775  99.844  -74.363  47.314  1
278776  99.875  -74.371  47.279  1
278777  99.906  -74.377  47.245  1
278778  99.936  -74.384  47.213  1
278779  99.967  -74.391  47.181  1
278780  99.997  -74.398  47.151  1
278781  100.028  -74.405  47.121  1
278782  100.059  -74.412  47.092  1
278783  100.089  -74.419  47.062  1
278784  100.116  -74.433  47.034  1
278785  100.137  -74.454  47.006  1
278786  100.159  -74.475  46.979  1
278787  100.181  -74.496  46.951  1
278788  100.202  -74.517  46.922  1
278789  100.224  -74.538  46.894  1
278790  100.246  -74.559  46.865  1
278791  100.276  -74.563  46.837  1
278792  100.307  -74.568  46.811  1
278793  100.338  -74.571  46.783  1
278794  100.369  -74.575  46.753  1
278795  100.400  -74.579  46.721  1
278796  100.430  -74.583  46.689  1
278797  100.461  -74.595  46.657  1
278798  100.492  -74.607  46.626  1
278799  100.522  -74.619  46.597  1
278800  100.553  -74.631  46.568  1
278801  100.583  -74.643  46.538  1
278802  100.614  -74.656  46.509  1
278803  100.645  -74.668  46.480  1
278804  100.676  -74.680  46.450  1
278805  100.706  -74.692  46.421  1
278806  100.737  -74.704  46.394  1
278807  100.767  -74.716  46.367  1
278808  100.798  -74.728  46.340  1
278809  100.829  -74.740  46.316  1
278810  100.864  -74.760  46.290  1
278811  100.886  -74.772  46.261  1
278812  100.905  -74.781  46.231  1
278813  100.932  -74.797  46.198  1
278814  100.960  -74.813  46.164  1
278815  100.987  -74.830  46.129  1
278816  101.014  -74.847  46.095  1
278817  101.042  -74.863  46.060  1
278818  101.072  -74.881  46.026  1
278819  101.105  -74.902  45.992  1
278820  101.138  -74.922  45.960  1
278821  101.169  -74.937  45.928  1
278822  101.198  -74.949  45.895  1
278823  101.227  -74.961  45.861  1
278824  101.255  -74.973  45.826  1
278825  101.284  -74.985  45.791  1
278826  101.320  -75.004  45.755  1
278827  101.358  -75.027  45.721  1
278828  101.397  -75.050  45.686  1
278829  101.431  -75.069  45.653  1
278830  101.465  -75.087  45.619  1
278831  101.498  -75.105  45.586  1
278832  101.532  -75.124  45.555  1
278833  101.566  -75.142  45.524  1
278834  101.599  -75.161  45.493  1
278835  101.633  -75.179  45.462  1
278836  101.667  -75.198  45.433  1
278837  101.700  -75.217  45.403  1
278838  101.732  -75.225  45.374  1
278839  101.761  -75.220  45.345  1
278840  101.790  -75.215  45.317  1
278841  101.820  -75.210  45.287  1
278842  101.849  -75.205  45.258  1
278843  101.858  -75.188  45.228  1
278844  101.875  -75.189  45.199  1
278845  101.893  -75.189  45.170  1
278846  101.910  -75.189  45.142  1
278847  101.927  -75.190  45.113  1
278848  101.945  -75.191  45.084  1
278849  101.962  -75.191  45.056  1
278850  101.980  -75.192  45.027  1
278851  101.997  -75.192  45.000  1
278852  102.015  -75.192  44.973  1
278853  102.032  -75.193  44.946  1
278854  102.050  -75.194  44.919  1
279217  92.433  -72.960  54.735  1
279218  92.464  -72.970  54.718  1
279219  92.495  -72.980  54.702  1
279220  92.525  -72.991  54.686  1
279221  92.556  -73.001  54.670  1
279222  92.587  -73.011  54.655  1
279223  92.618  -73.022  54.640  1
279224  92.654  -73.032  54.625  1
279225  92.697  -73.043  54.612  1
279226  92.740  -73.054  54.599  1
279227  92.783  -73.065  54.585  1
279228  92.826  -73.076  54.572  1
279229  92.869  -73.087  54.561  1
279230  92.912  -73.098  54.552  1
279231  92.954  -73.109  54.542  1
279232  92.997  -73.120  54.533  1
279233  93.040  -73.131  54.526  1
279234  93.083  -73.142  54.517  1
279235  93.126  -73.153  54.508  1
279236  93.169  -73.164  54.500  1
279237  93.212  -73.175  54.493  1
279238  93.252  -73.186  54.486  1
279239  93.277  -73.192  54.479  1
279240  93.301  -73.198  54.471  1
279241  93.326  -73.204  54.462  1
279242  93.350  -73.210  54.452  1
279243  93.375  -73.215  54.443  1
279244  93.399  -73.221  54.433  1
279245  93.432  -73.221  54.424  1
279246  93.468  -73.213  54.415  1
279247  93.494  -73.208  54.402  1
279248  93.519  -73.202  54.388  1
279249  93.545  -73.196  54.374  1
279250  93.571  -73.190  54.359  1
279251  93.596  -73.185  54.344  1
279252  93.623  -73.179  54.329  1
279253  93.645  -73.174  54.313  1
279254  93.664  -73.168  54.293  1
279314  94.955  -73.271  52.843  1
279315  94.975  -73.276  52.815  1
279316  94.995  -73.280  52.788  1
279317  95.016  -73.284  52.760  1
279318  95.037  -73.289  52.733  1
279319  95.057  -73.293  52.706  1
279320  95.077  -73.298  52.679  1
279321  95.114  -73.290  52.653  1
279322  95.133  -73.300  52.627  1
279323  95.147  -73.314  52.601  1
279324  95.162  -73.327  52.575  1
279325  95.176  -73.340  52.549  1
279326  95.190  -73.353  52.523  1
279327  95.205  -73.367  52.497  1
279328  95.226  -73.368  52.472  1
279329  95.270  -73.323  52.448  1
279330  95.314  -73.279  52.422  1
279331  95.364  -73.280  52.396  1
279332  95.413  -73.281  52.370  1
279333  95.462  -73.283  52.345  1
279334  95.498  -73.280  52.323  1
279335  95.528  -73.279  52.301  1
279336  95.556  -73.277  52.279  1
279337  95.585  -73.274  52.257  1
279338  95.612  -73.273  52.236  1
279339  95.640  -73.271  52.214  1
279340  95.668  -73.269  52.194  1
279341  95.696  -73.267  52.175  1
279342  95.733  -73.277  52.156  1
279343  95.773  -73.280  52.137  1
279344  95.817  -73.274  52.116  1
279345  95.855  -73.283  52.093  1
279346  95.894  -73.296  52.069  1
279347  95.932  -73.308  52.043  1
279348  95.969  -73.319  52.017  1
279349  95.990  -73.320  51.990  1
279350  96.011  -73.320  51.962  1
279351  96.032  -73.321  51.932  1
279352  96.057  -73.324  51.903  1
279353  96.084  -73.329  51.873  1
279354  96.110  -73.333  51.844  1
279355  96.137  -73.338  51.813  1
279356  96.163  -73.339  51.781  1
279357  96.189  -73.328  51.749  1
279358  96.201  -73.328  51.716  1
279359  96.226  -73.330  51.685  1
279360  96.272  -73.333  51.653  1
279361  96.310  -73.333  51.622  1
279362  96.327  -73.332  51.590  1
279363  96.344  -73.330  51.559  1
279364  96.362  -73.329  51.528  1
279365  96.379  -73.328  51.498  1
279366  96.400  -73.336  51.469  1
279367  96.427  -73.358  51.439  1
279368  96.454  -73.381  51.411  1
279369  96.480  -73.404  51.383  1
279370  96.508  -73.427  51.355  1
279371  96.534  -73.442  51.327  1
279372  96.559  -73.446  51.299  1
279373  96.584  -73.449  51.271  1
279374  96.609  -73.452  51.244  1
279375  96.646  -73.464  51.217  1
279376  96.693  -73.488  51.190  1
279377  96.741  -73.514  51.165  1
279378  96.788  -73.540  51.140  1
279379  96.835  -73.566  51.116  1
279380  96.843  -73.564  51.092  1
279381  96.844  -73.555  51.070  1
279382  96.823  -73.511  51.049  1
279383  96.812  -73.457  51.030  1
279384  96.855  -73.444  51.012  1
279385  96.903  -73.455  50.996  1
279386  96.953  -73.465  50.981  1
279387  96.996  -73.477  50.966  1
279388  97.035  -73.488  50.952  1
279389  97.073  -73.500  50.939  1
279390  97.108  -73.515  50.926  1
279391  97.143  -73.529  50.916  1
279392  97.230  -73.553  50.907  1
279393  97.268  -73.549  50.899  1
279394  97.279  -73.532  50.891  1
279395  97.272  -73.526  50.884  1
279396  97.280  -73.550  50.878  1
279397  97.295  -73.575  50.872  1
279398  97.282  -73.585  50.865  1
279399  97.267  -73.595  50.853  1
279400  97.278  -73.599  50.836  1
279401  97.316  -73.595  50.822  1
279402  97.355  -73.592  50.809  1
279403  97.393  -73.589  50.797  1
279404  97.432  -73.585  50.785  1
279405  97.470  -73.582  50.772  1
279406  97.509  -73.578  50.757  1
279407  97.547  -73.575  50.740  1
279408  97.586  -73.571  50.717  1
279409  97.624  -73.568  50.690  1
279410  97.663  -73.568  50.657  1
279411  97.704  -73.575  50.621  1
279412  97.744  -73.582  50.580  1
279413  97.784  -73.589  50.533  1
279414  97.824  -73.596  50.485  1
279415  97.864  -73.603  50.435  1
279416  97.904  -73.609  50.384  1
279417  97.943  -73.629  50.333  1
279418  97.982  -73.653  50.279  1
279419  98.020  -73.676  50.224  1
279420  98.058  -73.684  50.163  1
279421  98.095  -73.679  50.100  1
279422  98.133  -73.675  50.036  1
279423  98.170  -73.669  49.972  1
279424  98.206  -73.671  49.909  1
279425  98.243  -73.678  49.846  1
279426  98.279  -73.685  49.783  1
279427  98.320  -73.694  49.720  1
279428  98.322  -73.731  49.656  1
279429  98.324  -73.767  49.596  1
279430  98.326  -73.803  49.535  1
279431  98.329  -73.839  49.472  1
279432  98.331  -73.875  49.406  1
279433  98.381  -73.890  49.340  1
279434  98.444  -73.898  49.275  1
279435  98.507  -73.907  49.213  1
279436  98.571  -73.915  49.151  1
279437  98.596  -73.928  49.091  1
279438  98.621  -73.941  49.033  1
279439  98.656  -73.953  48.976  1
279440  98.692  -73.964  48.919  1
279441  98.727  -73.976  48.864  1
279442  98.781  -73.998  48.810  1
279443  98.830  -73.999  48.756  1
279444  98.844  -74.005  48.703  1
279445  98.847  -74.028  48.652  1
279446  98.850  -74.051  48.602  1
279447  98.872  -74.067  48.554  1
279448  98.910  -74.077  48.507  1
279449  98.948  -74.087  48.462  1
279450  98.985  -74.098  48.416  1
279451  99.023  -74.107  48.371  1
279452  99.061  -74.117  48.323  1
279453  99.101  -74.130  48.275  1
279454  99.142  -74.144  48.227  1
279455  99.174  -74.145  48.178  1
279456  99.201  -74.151  48.129  1
279457  99.227  -74.157  48.079  1
279458  99.236  -74.166  48.031  1
279459  99.241  -74.176  47.985  1
279460  99.246  -74.186  47.941  1
279461  99.257  -74.195  47.896  1
279462  99.300  -74.208  47.853  1
279463  99.343  -74.220  47.810  1
279464  99.386  -74.231  47.767  1
279465  99.430  -74.243  47.724  1
279466  99.473  -74.255  47.682  1
279467  99.516  -74.267  47.642  1
279468  99.564  -74.278  47.601  1
279469  99.625  -74.286  47.563  1
279470  99.685  -74.295  47.524  1
279471  99.707  -74.302  47.485  1
279472  99.730  -74.309  47.449  1
279473  99.755  -74.313  47.412  1
279474  99.782  -74.318  47.377  1
279475  99.813  -74.326  47.343  1
279476  99.844  -74.333  47.309  1
279477  99.874  -74.339  47.274  1
279478  99.905  -74.346  47.241  1
279479  99.935  -74.354  47.208  1
279480  99.966  -74.361  47.176  1
279481  99.997  -74.368  47.147  1
279482  100.028  -74.374  47.117  1
279483  100.058  -74.381  47.087  1
279484  100.089  -74.389  47.058  1
279485  100.118  -74.398  47.030  1
279486  100.140  -74.419  47.002  1
279487  100.161  -74.440  46.974  1
279488  100.183  -74.461  46.946  1
279489  100.205  -74.481  46.917  1
279490  100.226  -74.502  46.888  1
279491  100.251  -74.519  46.859  1
279492  100.281  -74.523  46.830  1
279493  100.312  -74.527  46.803  1
279494  100.343  -74.530  46.774  1
279495  100.374  -74.534  46.743  1
279496  100.405  -74.538  46.712  1
279497  100.436  -74.542  46.679  1
279498  100.467  -74.547  46.647  1
279499  100.497  -74.559  46.616  1
279500  100.528  -74.571  46.586  1
279501  100.558  -74.584  46.557  1
279502  100.589  -74.596  46.528  1
279503  100.620  -74.608  46.498  1
279504  100.650  -74.620  46.468  1
279505  100.681  -74.632  46.439  1
279506  100.711  -74.644  46.410  1
279507  100.742  -74.656  46.382  1
279508  100.773  -74.668  46.355  1
279509  100.804  -74.681  46.328  1
279510  100.834  -74.693  46.304  1
279511  100.882  -74.729  46.278  1
279512  100.907  -74.744  46.248  1
279513  100.928  -74.755  46.217  1
279514  100.956  -74.772  46.185  1
279515  100.983  -74.788  46.150  1
279516  101.010  -74.805  46.115  1
279517  101.038  -74.822  46.080  1
279518  101.065  -74.838  46.044  1
279519  101.092  -74.855  46.009  1
279520  101.121  -74.872  45.976  1
279521  101.155  -74.892  45.943  1
279522  101.188  -74.913  45.911  1
279523  101.217  -74.925  45.878  1
279524  101.246  -74.937  45.844  1
279525  101.275  -74.949  45.807  1
279526  101.304  -74.961  45.772  1
279527  101.341  -74.983  45.737  1
279528  101.379  -75.005  45.703  1
279529  101.418  -75.028  45.669  1
279530  101.454  -75.048  45.636  1
279531  101.487  -75.066  45.603  1
279532  101.521  -75.085  45.571  1
279533  101.554  -75.103  45.540  1
279534  101.588  -75.122  45.509  1
279535  101.622  -75.140  45.478  1
279536  101.656  -75.159  45.447  1
279537  101.689  -75.177  45.418  1
279538  101.722  -75.191  45.388  1
279539  101.751  -75.186  45.359  1
279540  101.780  -75.181  45.331  1
279541  101.810  -75.176  45.302  1
279542  101.839  -75.171  45.273  1
279543  101.863  -75.160  45.244  1
279544  101.873  -75.148  45.215  1
279545  101.890  -75.148  45.185  1
279546  101.908  -75.149  45.156  1
279547  101.925  -75.150  45.127  1
279548  101.943  -75.150  45.099  1
279549  101.960  -75.151  45.070  1
279550  101.977  -75.151  45.042  1
279551  101.995  -75.152  45.014  1
279552  102.013  -75.152  44.986  1
279553  102.030  -75.153  44.959  1
279554  102.047  -75.154  44.931  1
279555  102.065  -75.154  44.904  1
279918  92.429  -72.930  54.739  1
279919  92.460  -72.941  54.723  1
279920  92.491  -72.951  54.707  1
279921  92.521  -72.961  54.690  1
279922  92.552  -72.972  54.673  1
279923  92.582  -72.982  54.657  1
279924  92.613  -72.992  54.642  1
279925  92.651  -73.003  54.628  1
279926  92.694  -73.014  54.613  1
279927  92.737  -73.025  54.599  1
279928  92.780  -73.036  54.585  1
279929  92.823  -73.047  54.571  1
279930  92.865  -73.058  54.560  1
279931  92.908  -73.069  54.549  1
279932  92.951  -73.080  54.539  1
279933  92.994  -73.091  54.529  1
279934  93.037  -73.102  54.521  1
279935  93.080  -73.113  54.512  1
279936  93.123  -73.124  54.503  1
279937  93.165  -73.135  54.495  1
279938  93.209  -73.146  54.487  1
279939  93.244  -73.155  54.480  1
279940  93.269  -73.161  54.472  1
279941  93.293  -73.167  54.464  1
279942  93.318  -73.174  54.454  1
279943  93.342  -73.180  54.444  1
279944  93.367  -73.185  54.434  1
279945  93.391  -73.191  54.423  1
279946  93.430  -73.186  54.414  1
279947  93.463  -73.179  54.404  1
279948  93.489  -73.174  54.391  1
279949  93.514  -73.167  54.377  1
279950  93.540  -73.162  54.362  1
279951  93.566  -73.157  54.347  1
279952  93.592  -73.151  54.331  1
279953  93.618  -73.145  54.316  1
279954  93.643  -73.139  54.299  1
279955  93.666  -73.134  54.279  1
280017  94.998  -73.246  52.778  1
280018  95.019  -73.249  52.751  1
280019  95.040  -73.254  52.725  1
280020  95.060  -73.258  52.698  1
280021  95.080  -73.263  52.672  1
280022  95.101  -73.267  52.646  1
280023  95.135  -73.261  52.621  1
280024  95.155  -73.271  52.596  1
280025  95.169  -73.284  52.570  1
280026  95.183  -73.298  52.544  1
280027  95.198  -73.311  52.518  1
280028  95.212  -73.324  52.493  1
280029  95.227  -73.337  52.468  1
280030  95.266  -73.303  52.443  1
280031  95.310  -73.258  52.418  1
280032  95.358  -73.251  52.392  1
280033  95.408  -73.253  52.367  1
280034  95.455  -73.254  52.342  1
280035  95.492  -73.252  52.318  1
280036  95.526  -73.249  52.296  1
280037  95.554  -73.248  52.274  1
280038  95.582  -73.246  52.253  1
280039  95.610  -73.244  52.232  1
280040  95.638  -73.242  52.211  1
280041  95.666  -73.240  52.191  1
280042  95.695  -73.240  52.172  1
280043  95.733  -73.252  52.154  1
280044  95.771  -73.263  52.135  1
280045  95.812  -73.264  52.115  1
280046  95.855  -73.258  52.094  1
280047  95.898  -73.252  52.071  1
280048  95.938  -73.259  52.045  1
280049  95.976  -73.271  52.020  1
280050  96.013  -73.283  51.995  1
280051  96.034  -73.283  51.970  1
280052  96.055  -73.283  51.942  1
280053  96.080  -73.287  51.913  1
280054  96.107  -73.292  51.884  1
280055  96.133  -73.296  51.855  1
280056  96.160  -73.293  51.824  1
280057  96.186  -73.283  51.792  1
280058  96.210  -73.275  51.760  1
280059  96.217  -73.278  51.728  1
280060  96.226  -73.281  51.696  1
280061  96.272  -73.283  51.664  1
280062  96.299  -73.282  51.633  1
280063  96.316  -73.281  51.602  1
280064  96.333  -73.280  51.571  1
280065  96.356  -73.291  51.541  1
280066  96.383  -73.314  51.512  1
280067  96.409  -73.336  51.484  1
280068  96.436  -73.358  51.454  1
280069  96.463  -73.381  51.426  1
280070  96.490  -73.404  51.398  1
280071  96.517  -73.427  51.369  1
280072  96.542  -73.435  51.343  1
280073  96.568  -73.439  51.316  1
280074  96.593  -73.443  51.289  1
280075  96.617  -73.446  51.261  1
280076  96.639  -73.440  51.235  1
280077  96.682  -73.471  51.207  1
280078  96.729  -73.497  51.181  1
280079  96.776  -73.524  51.157  1
280080  96.823  -73.550  51.133  1
280081  96.828  -73.544  51.108  1
280082  96.789  -73.471  51.085  1
280083  96.751  -73.399  51.063  1
280084  96.799  -73.405  51.043  1
280085  96.849  -73.416  51.025  1
280086  96.897  -73.426  51.008  1
280087  96.946  -73.437  50.992  1
280088  96.992  -73.448  50.976  1
280089  97.030  -73.459  50.961  1
280090  97.069  -73.471  50.947  1
280091  97.108  -73.484  50.934  1
280092  97.147  -73.496  50.924  1
280093  97.182  -73.509  50.914  1
280094  97.251  -73.524  50.905  1
280095  97.240  -73.509  50.896  1
280096  97.236  -73.511  50.888  1
280097  97.259  -73.535  50.882  1
280098  97.283  -73.560  50.878  1
280099  97.272  -73.571  50.872  1
280100  97.257  -73.581  50.862  1
280101  97.286  -73.580  50.848  1
280102  97.324  -73.576  50.832  1
280103  97.363  -73.573  50.816  1
280104  97.401  -73.569  50.800  1
280105  97.440  -73.566  50.784  1
280106  97.478  -73.562  50.766  1
280107  97.517  -73.559  50.746  1
280108  97.556  -73.556  50.726  1
280109  97.594  -73.553  50.702  1
280110  97.633  -73.550  50.674  1
280111  97.671  -73.546  50.642  1
280112  97.710  -73.543  50.606  1
280113  97.749  -73.542  50.566  1
280114  97.789  -73.549  50.521  1
280115  97.829  -73.556  50.472  1
280116  97.869  -73.562  50.423  1
280117  97.909  -73.578  50.371  1
280118  97.947  -73.601  50.318  1
280119  97.986  -73.625  50.263  1
280120  98.024  -73.647  50.206  1
280121  98.062  -73.671  50.143  1
280122  98.100  -73.672  50.081  1
280123  98.137  -73.667  50.018  1
280124  98.174  -73.662  49.956  1
280125  98.212  -73.657  49.893  1
280126  98.249  -73.652  49.831  1
280127  98.286  -73.647  49.768  1
280128  98.309  -73.667  49.704  1
280129  98.314  -73.703  49.642  1
280130  98.322  -73.739  49.582  1
280131  98.331  -73.775  49.521  1
280132  98.338  -73.812  49.458  1
280133  98.347  -73.847  49.393  1
280134  98.381  -73.866  49.330  1
280135  98.441  -73.875  49.266  1
280136  98.504  -73.883  49.203  1
280137  98.567  -73.891  49.142  1
280138  98.605  -73.904  49.083  1
280139  98.612  -73.919  49.026  1
280140  98.646  -73.931  48.969  1
280141  98.682  -73.943  48.913  1
280142  98.718  -73.954  48.857  1
280143  98.802  -73.994  48.802  1
280144  98.831  -73.979  48.748  1
280145  98.851  -73.977  48.695  1
280146  98.854  -74.000  48.644  1
280147  98.857  -74.023  48.595  1
280148  98.887  -74.035  48.546  1
280149  98.925  -74.045  48.499  1
280150  98.962  -74.056  48.453  1
280151  99.000  -74.066  48.407  1
280152  99.038  -74.076  48.361  1
280153  99.075  -74.086  48.313  1
280154  99.113  -74.096  48.266  1
280155  99.154  -74.110  48.218  1
280156  99.196  -74.123  48.168  1
280157  99.228  -74.130  48.119  1
280158  99.235  -74.140  48.072  1
280159  99.240  -74.150  48.024  1
280160  99.245  -74.160  47.978  1
280161  99.251  -74.169  47.934  1
280162  99.259  -74.179  47.890  1
280163  99.302  -74.191  47.846  1
280164  99.346  -74.203  47.804  1
280165  99.389  -74.215  47.761  1
280166  99.432  -74.226  47.718  1
280167  99.493  -74.236  47.676  1
280168  99.554  -74.244  47.636  1
280169  99.615  -74.252  47.596  1
280170  99.672  -74.261  47.557  1
280171  99.695  -74.268  47.518  1
280172  99.717  -74.275  47.480  1
280173  99.740  -74.282  47.443  1
280174  99.764  -74.286  47.408  1
280175  99.788  -74.291  47.373  1
280176  99.812  -74.295  47.338  1
280177  99.843  -74.302  47.305  1
280178  99.873  -74.309  47.270  1
280179  99.904  -74.316  47.236  1
280180  99.935  -74.323  47.204  1
280181  99.966  -74.330  47.173  1
280182  99.996  -74.337  47.143  1
280183  100.027  -74.344  47.113  1
280184  100.058  -74.351  47.083  1
280185  100.088  -74.358  47.054  1
280186  100.119  -74.364  47.026  1
280187  100.142  -74.383  46.997  1
280188  100.164  -74.405  46.969  1
280189  100.186  -74.425  46.940  1
280190  100.207  -74.446  46.910  1
280191  100.229  -74.467  46.881  1
280192  100.256  -74.478  46.851  1
280193  100.286  -74.482  46.823  1
280194  100.318  -74.486  46.796  1
280195  100.348  -74.490  46.766  1
280196  100.379  -74.493  46.734  1
280197  100.410  -74.497  46.703  1
280198  100.441  -74.501  46.670  1
280199  100.472  -74.505  46.637  1
280200  100.503  -74.512  46.606  1
280201  100.533  -74.524  46.576  1
280202  100.564  -74.536  46.547  1
280203  100.595  -74.548  46.517  1
280204  100.625  -74.560  46.487  1
280205  100.656  -74.572  46.457  1
280206  100.686  -74.584  46.428  1
280207  100.717  -74.596  46.399  1
280208  100.748  -74.609  46.371  1
280209  100.778  -74.621  46.343  1
280210  100.809  -74.633  46.315  1
280211  100.844  -74.651  46.290  1
280212  100.901  -74.699  46.263  1
280213  100.928  -74.717  46.234  1
280214  100.952  -74.730  46.203  1
280215  100.979  -74.747  46.170  1
280216  101.006  -74.763  46.136  1
280217  101.034  -74.779  46.102  1
280218  101.061  -74.796  46.065  1
280219  101.088  -74.812  46.028  1
280220  101.116  -74.829  45.993  1
280221  101.143  -74.846  45.959  1
280222  101.171  -74.863  45.927  1
280223  101.204  -74.883  45.895  1
280224  101.236  -74.901  45.861  1
280225  101.265  -74.913  45.827  1
280226  101.294  -74.925  45.789  1
280227  101.324  -74.938  45.754  1
280228  101.362  -74.961  45.720  1
280229  101.401  -74.984  45.686  1
280230  101.440  -75.006  45.653  1
280231  101.476  -75.026  45.619  1
280232  101.510  -75.045  45.587  1
280233  101.543  -75.063  45.555  1
280234  101.577  -75.082  45.524  1
280235  101.611  -75.101  45.495  1
280236  101.644  -75.119  45.464  1
280237  101.678  -75.138  45.434  1
280238  101.711  -75.156  45.404  1
280239  101.741  -75.152  45.374  1
280240  101.770  -75.147  45.345  1
280241  101.799  -75.142  45.316  1
280242  101.829  -75.137  45.287  1
280243  101.858  -75.132  45.258  1
280244  101.871  -75.109  45.229  1
280245  101.888  -75.108  45.200  1
280246  101.905  -75.109  45.171  1
280247  101.922  -75.110  45.143  1
280248  101.940  -75.110  45.114  1
280249  101.958  -75.110  45.085  1
280250  101.975  -75.111  45.056  1
280251  101.992  -75.111  45.028  1
280252  102.010  -75.112  45.000  1
280253  102.027  -75.113  44.972  1
280254  102.045  -75.113  44.945  1
280255  102.062  -75.113  44.917  1
280619  92.425  -72.901  54.743  1
280620  92.456  -72.911  54.727  1
280621  92.487  -72.922  54.711  1
280622  92.517  -72.932  54.694  1
280623  92.548  -72.942  54.677  1
280624  92.578  -72.953  54.660  1
280625  92.609  -72.963  54.644  1
280626  92.648  -72.974  54.629  1
280627  92.691  -72.985  54.614  1
280628  92.733  -72.996  54.600  1
280629  92.776  -73.007  54.586  1
280630  92.819  -73.018  54.571  1
280631  92.862  -73.029  54.559  1
280632  92.905  -73.040  54.548  1
280633  92.948  -73.051  54.537  1
280634  92.991  -73.062  54.528  1
280635  93.034  -73.073  54.519  1
280636  93.077  -73.084  54.509  1
280637  93.120  -73.095  54.499  1
280638  93.162  -73.106  54.490  1
280639  93.205  -73.117  54.482  1
280640  93.236  -73.125  54.474  1
280641  93.261  -73.131  54.466  1
280642  93.285  -73.137  54.457  1
280643  93.309  -73.143  54.445  1
280644  93.334  -73.149  54.436  1
280645  93.358  -73.155  54.425  1
280646  93.383  -73.161  54.414  1
280647  93.428  -73.152  54.404  1
280648  93.458  -73.145  54.392  1
280649  93.484  -73.139  54.380  1
280650  93.509  -73.134  54.366  1
280651  93.536  -73.128  54.351  1
280652  93.561  -73.123  54.335  1
280653  93.587  -73.117  54.319  1
280654  93.613  -73.111  54.303  1
280655  93.638  -73.105  54.286  1
280720  95.043  -73.219  52.717  1
280721  95.063  -73.224  52.691  1
280722  95.084  -73.228  52.665  1
280723  95.104  -73.232  52.640  1
280724  95.125  -73.236  52.615  1
280725  95.157  -73.233  52.590  1
280726  95.176  -73.242  52.565  1
280727  95.191  -73.255  52.539  1
280728  95.205  -73.268  52.513  1
280729  95.219  -73.281  52.488  1
280730  95.234  -73.295  52.464  1
280731  95.262  -73.283  52.439  1
280732  95.306  -73.238  52.413  1
280733  95.353  -73.223  52.388  1
280734  95.403  -73.224  52.363  1
280735  95.449  -73.225  52.338  1
280736  95.485  -73.223  52.314  1
280737  95.522  -73.221  52.292  1
280738  95.551  -73.219  52.271  1
280739  95.580  -73.217  52.249  1
280740  95.608  -73.215  52.228  1
280741  95.635  -73.213  52.208  1
280742  95.664  -73.211  52.189  1
280743  95.695  -73.214  52.171  1
280744  95.733  -73.226  52.152  1
280745  95.771  -73.237  52.134  1
280746  95.809  -73.249  52.115  1
280747  95.851  -73.247  52.094  1
280748  95.894  -73.241  52.072  1
280749  95.937  -73.235  52.049  1
280750  95.980  -73.229  52.025  1
280751  96.020  -73.235  52.001  1
280752  96.057  -73.246  51.977  1
280753  96.079  -73.247  51.951  1
280754  96.103  -73.250  51.924  1
280755  96.129  -73.255  51.895  1
280756  96.156  -73.249  51.865  1
280757  96.182  -73.239  51.834  1
280758  96.208  -73.229  51.803  1
280759  96.226  -73.225  51.771  1
280760  96.232  -73.228  51.739  1
280761  96.239  -73.230  51.706  1
280762  96.270  -73.233  51.675  1
280763  96.288  -73.231  51.645  1
280764  96.312  -73.246  51.615  1
280765  96.338  -73.268  51.585  1
280766  96.365  -73.291  51.556  1
280767  96.392  -73.314  51.527  1
280768  96.418  -73.336  51.499  1
280769  96.446  -73.358  51.471  1
280770  96.472  -73.381  51.442  1
280771  96.499  -73.404  51.415  1
280772  96.526  -73.425  51.387  1
280773  96.551  -73.428  51.361  1
280774  96.576  -73.432  51.334  1
280775  96.601  -73.436  51.307  1
280776  96.608  -73.415  51.279  1
280777  96.637  -73.408  51.251  1
280778  96.677  -73.452  51.225  1
280779  96.723  -73.479  51.199  1
280780  96.768  -73.506  51.173  1
280781  96.812  -73.525  51.149  1
280782  96.794  -73.474  51.123  1
280783  96.768  -73.415  51.099  1
280784  96.758  -73.373  51.077  1
280785  96.793  -73.377  51.056  1
280786  96.842  -73.387  51.037  1
280787  96.891  -73.398  51.020  1
280788  96.940  -73.409  51.003  1
280789  96.987  -73.419  50.985  1
280790  97.026  -73.430  50.969  1
280791  97.065  -73.443  50.955  1
280792  97.104  -73.455  50.942  1
280793  97.142  -73.467  50.931  1
280794  97.181  -73.478  50.921  1
280795  97.197  -73.479  50.911  1
280796  97.206  -73.474  50.902  1
280797  97.223  -73.496  50.894  1
280798  97.247  -73.520  50.886  1
280799  97.271  -73.545  50.881  1
280800  97.262  -73.556  50.877  1
280801  97.256  -73.564  50.871  1
280802  97.295  -73.561  50.859  1
280803  97.333  -73.557  50.845  1
280804  97.372  -73.554  50.830  1
280805  97.410  -73.550  50.813  1
280806  97.449  -73.547  50.792  1
280807  97.487  -73.543  50.768  1
280808  97.526  -73.540  50.743  1
280809  97.564  -73.537  50.715  1
280810  97.603  -73.534  50.686  1
280811  97.641  -73.530  50.655  1
280812  97.680  -73.527  50.622  1
280813  97.718  -73.523  50.587  1
280814  97.757  -73.520  50.548  1
280815  97.795  -73.517  50.503  1
280816  97.834  -73.516  50.455  1
280817  97.874  -73.526  50.405  1
280818  97.913  -73.550  50.353  1
280819  97.951  -73.572  50.297  1
280820  97.989  -73.596  50.241  1
280821  98.028  -73.619  50.183  1
280822  98.066  -73.643  50.121  1
280823  98.104  -73.665  50.059  1
280824  98.142  -73.659  49.997  1
280825  98.179  -73.655  49.936  1
280826  98.216  -73.650  49.876  1
280827  98.253  -73.645  49.816  1
280828  98.291  -73.640  49.755  1
280829  98.322  -73.640  49.692  1
280830  98.330  -73.675  49.628  1
280831  98.338  -73.712  49.567  1
280832  98.346  -73.748  49.506  1
280833  98.354  -73.785  49.443  1
280834  98.368  -73.817  49.380  1
280835  98.398  -73.840  49.318  1
280836  98.439  -73.852  49.256  1
280837  98.501  -73.860  49.194  1
280838  98.564  -73.869  49.132  1
280839  98.615  -73.879  49.073  1
280840  98.621  -73.894  49.016  1
280841  98.637  -73.910  48.959  1
280842  98.672  -73.921  48.903  1
280843  98.708  -73.932  48.847  1
280844  98.803  -73.973  48.793  1
280845  98.832  -73.958  48.740  1
280846  98.858  -73.948  48.687  1
280847  98.861  -73.972  48.637  1
280848  98.864  -73.994  48.586  1
280849  98.902  -74.004  48.537  1
280850  98.940  -74.014  48.490  1
280851  98.978  -74.025  48.444  1
280852  99.015  -74.035  48.398  1
280853  99.053  -74.045  48.351  1
280854  99.090  -74.055  48.304  1
280855  99.128  -74.065  48.257  1
280856  99.166  -74.076  48.208  1
280857  99.207  -74.089  48.159  1
280858  99.240  -74.114  48.111  1
280859  99.252  -74.135  48.064  1
280860  99.250  -74.138  48.017  1
280861  99.250  -74.143  47.972  1
280862  99.255  -74.153  47.928  1
280863  99.262  -74.163  47.884  1
280864  99.305  -74.174  47.840  1
280865  99.361  -74.184  47.797  1
280866  99.422  -74.192  47.754  1
280867  99.483  -74.201  47.711  1
280868  99.544  -74.210  47.670  1
280869  99.605  -74.218  47.630  1
280870  99.659  -74.226  47.590  1
280871  99.682  -74.233  47.551  1
280872  99.704  -74.241  47.513  1
280873  99.727  -74.248  47.475  1
280874  99.750  -74.255  47.438  1
280875  99.774  -74.261  47.403  1
280876  99.798  -74.264  47.369  1
280877  99.822  -74.269  47.334  1
280878  99.846  -74.273  47.301  1
280879  99.873  -74.278  47.267  1
280880  99.904  -74.285  47.233  1
280881  99.934  -74.292  47.200  1
280882  99.965  -74.299  47.169  1
280883  99.996  -74.306  47.139  1
280884  100.027  -74.313  47.109  1
280885  100.057  -74.320  47.079  1
280886  100.087  -74.327  47.050  1
280887  100.118  -74.334  47.021  1
280888  100.144  -74.348  46.992  1
280889  100.166  -74.369  46.963  1
280890  100.188  -74.389  46.934  1
280891  100.210  -74.411  46.904  1
280892  100.231  -74.432  46.873  1
280893  100.261  -74.438  46.843  1
280894  100.292  -74.442  46.815  1
280895  100.323  -74.446  46.789  1
280896  100.354  -74.449  46.758  1
280897  100.385  -74.453  46.726  1
280898  100.415  -74.457  46.693  1
280899  100.446  -74.461  46.660  1
280900  100.477  -74.465  46.627  1
280901  100.508  -74.468  46.596  1
280902  100.539  -74.476  46.567  1
280903  100.569  -74.488  46.537  1
280904  100.600  -74.500  46.506  1
280905  100.631  -74.512  46.476  1
280906  100.662  -74.524  46.446  1
280907  100.692  -74.537  46.416  1
280908  100.722  -74.549  46.386  1
280909  100.753  -74.561  46.358  1
280910  100.784  -74.573  46.331  1
280911  100.815  -74.585  46.303  1
280912  100.862  -74.620  46.276  1
280913  100.918  -74.668  46.248  1
280914  100.950  -74.690  46.219  1
280915  100.975  -74.704  46.189  1
280916  101.002  -74.721  46.155  1
280917  101.030  -74.737  46.121  1
280918  101.057  -74.754  46.086  1
280919  101.084  -74.771  46.049  1
280920  101.112  -74.787  46.013  1
280921  101.139  -74.804  45.977  1
280922  101.166  -74.821  45.943  1
280923  101.194  -74.838  45.911  1
280924  101.221  -74.854  45.878  1
280925  101.254  -74.874  45.844  1
280926  101.284  -74.889  45.809  1
280927  101.313  -74.901  45.772  1
280928  101.345  -74.917  45.737  1
280929  101.384  -74.939  45.704  1
280930  101.423  -74.962  45.671  1
280931  101.462  -74.985  45.638  1
280932  101.498  -75.005  45.605  1
280933  101.532  -75.024  45.572  1
280934  101.565  -75.042  45.541  1
280935  101.599  -75.061  45.510  1
280936  101.633  -75.079  45.480  1
280937  101.667  -75.098  45.450  1
280938  101.700  -75.116  45.420  1
280939  101.731  -75.118  45.391  1
280940  101.760  -75.113  45.361  1
280941  101.789  -75.108  45.332  1
280942  101.818  -75.103  45.303  1
280943  101.847  -75.098  45.274  1
280944  101.877  -75.093  45.245  1
280945  101.885  -75.068  45.215  1
280946  101.903  -75.069  45.186  1
280947  101.920  -75.069  45.158  1
280948  101.938  -75.069  45.129  1
280949  101.955  -75.070  45.101  1
280950  101.972  -75.071  45.072  1
280951  101.990  -75.071  45.043  1
280952  102.007  -75.072  45.015  1
280953  102.025  -75.073  44.987  1
280954  102.042  -75.073  44.959  1
280955  102.060  -75.073  44.930  1
280956  102.077  -75.074  44.903  1
281320  92.421  -72.872  54.748  1
281321  92.451  -72.882  54.731  1
281322  92.482  -72.892  54.714  1
281323  92.513  -72.903  54.698  1
281324  92.544  -72.913  54.680  1
281325  92.574  -72.923  54.663  1
281326  92.605  -72.934  54.646  1
281327  92.645  -72.945  54.630  1
281328  92.688  -72.956  54.615  1
281329  92.730  -72.967  54.601  1
281330  92.773  -72.978  54.586  1
281331  92.816  -72.989  54.572  1
281332  92.859  -73.000  54.558  1
281333  92.902  -73.011  54.547  1
281334  92.945  -73.022  54.536  1
281335  92.988  -73.032  54.525  1
281336  93.030  -73.044  54.516  1
281337  93.073  -73.054  54.506  1
281338  93.117  -73.066  54.495  1
281339  93.159  -73.076  54.485  1
281340  93.201  -73.087  54.477  1
281341  93.228  -73.095  54.468  1
281342  93.253  -73.101  54.460  1
281343  93.277  -73.107  54.451  1
281344  93.301  -73.113  54.439  1
281345  93.326  -73.119  54.428  1
281346  93.350  -73.124  54.416  1
281347  93.378  -73.128  54.405  1
281348  93.426  -73.117  54.395  1
281349  93.453  -73.111  54.383  1
281350  93.479  -73.105  54.369  1
281351  93.505  -73.100  54.355  1
281352  93.531  -73.095  54.340  1
281353  93.556  -73.089  54.323  1
281354  93.582  -73.083  54.306  1
281355  93.608  -73.077  54.290  1
281421  95.046  -73.184  52.709  1
281422  95.066  -73.189  52.684  1
281423  95.087  -73.193  52.659  1
281424  95.107  -73.197  52.634  1
281425  95.128  -73.202  52.610  1
281426  95.148  -73.206  52.585  1
281427  95.178  -73.204  52.559  1
281428  95.198  -73.212  52.534  1
281429  95.213  -73.225  52.508  1
281430  95.227  -73.239  52.483  1
281431  95.242  -73.252  52.458  1
281432  95.258  -73.262  52.434  1
281433  95.302  -73.218  52.409  1
281434  95.348  -73.195  52.384  1
281435  95.398  -73.196  52.359  1
281436  95.443  -73.196  52.334  1
281437  95.479  -73.195  52.310  1
281438  95.516  -73.192  52.288  1
281439  95.549  -73.190  52.267  1
281440  95.577  -73.188  52.246  1
281441  95.605  -73.186  52.225  1
281442  95.633  -73.184  52.206  1
281443  95.661  -73.183  52.187  1
281444  95.695  -73.189  52.169  1
281445  95.734  -73.201  52.151  1
281446  95.771  -73.212  52.134  1
281447  95.810  -73.224  52.116  1
281448  95.847  -73.235  52.095  1
281449  95.890  -73.231  52.074  1
281450  95.933  -73.224  52.053  1
281451  95.976  -73.218  52.031  1
281452  96.019  -73.212  52.008  1
281453  96.062  -73.206  51.985  1
281454  96.102  -73.210  51.961  1
281455  96.126  -73.213  51.935  1
281456  96.152  -73.204  51.906  1
281457  96.178  -73.194  51.875  1
281458  96.204  -73.184  51.844  1
281459  96.231  -73.174  51.812  1
281460  96.241  -73.174  51.780  1
281461  96.248  -73.177  51.749  1
281462  96.255  -73.180  51.717  1
281463  96.269  -73.196  51.686  1
281464  96.294  -73.223  51.657  1
281465  96.321  -73.246  51.628  1
281466  96.347  -73.268  51.599  1
281467  96.374  -73.291  51.571  1
281468  96.401  -73.313  51.543  1
281469  96.428  -73.336  51.515  1
281470  96.455  -73.358  51.487  1
281471  96.481  -73.381  51.459  1
281472  96.508  -73.404  51.432  1
281473  96.534  -73.418  51.406  1
281474  96.559  -73.421  51.379  1
281475  96.584  -73.424  51.352  1
281476  96.585  -73.393  51.325  1
281477  96.607  -73.361  51.298  1
281478  96.635  -73.377  51.269  1
281479  96.671  -73.434  51.243  1
281480  96.717  -73.460  51.216  1
281481  96.762  -73.487  51.190  1
281482  96.798  -73.481  51.165  1
281483  96.797  -73.443  51.138  1
281484  96.771  -73.384  51.113  1
281485  96.771  -73.353  51.090  1
281486  96.802  -73.355  51.069  1
281487  96.836  -73.358  51.050  1
281488  96.885  -73.369  51.032  1
281489  96.934  -73.380  51.014  1
281490  96.983  -73.390  50.996  1
281491  97.022  -73.402  50.979  1
281492  97.061  -73.414  50.964  1
281493  97.099  -73.426  50.951  1
281494  97.138  -73.438  50.938  1
281495  97.166  -73.445  50.928  1
281496  97.186  -73.448  50.918  1
281497  97.195  -73.448  50.909  1
281498  97.214  -73.478  50.900  1
281499  97.235  -73.505  50.892  1
281500  97.259  -73.530  50.887  1
281501  97.252  -73.542  50.882  1
281502  97.264  -73.545  50.878  1
281503  97.303  -73.542  50.868  1
281504  97.342  -73.538  50.856  1
281505  97.380  -73.535  50.841  1
281506  97.419  -73.531  50.823  1
281507  97.457  -73.528  50.799  1
281508  97.496  -73.524  50.772  1
281509  97.534  -73.521  50.742  1
281510  97.573  -73.518  50.710  1
281511  97.611  -73.515  50.676  1
281512  97.650  -73.511  50.642  1
281513  97.688  -73.508  50.607  1
281514  97.727  -73.504  50.571  1
281515  97.766  -73.499  50.531  1
281516  97.804  -73.487  50.486  1
281517  97.843  -73.475  50.437  1
281518  97.886  -73.489  50.387  1
281519  97.916  -73.521  50.333  1
281520  97.955  -73.544  50.277  1
281521  97.993  -73.568  50.220  1
281522  98.031  -73.591  50.162  1
281523  98.070  -73.614  50.101  1
281524  98.108  -73.637  50.040  1
281525  98.146  -73.652  49.980  1
281526  98.183  -73.647  49.920  1
281527  98.221  -73.642  49.861  1
281528  98.258  -73.637  49.802  1
281529  98.295  -73.631  49.741  1
281530  98.334  -73.618  49.678  1
281531  98.346  -73.649  49.614  1
281532  98.354  -73.684  49.552  1
281533  98.362  -73.721  49.490  1
281534  98.370  -73.757  49.428  1
281535  98.388  -73.788  49.367  1
281536  98.415  -73.813  49.306  1
281537  98.455  -73.825  49.245  1
281538  98.498  -73.838  49.184  1
281539  98.561  -73.846  49.124  1
281540  98.624  -73.854  49.064  1
281541  98.631  -73.870  49.006  1
281542  98.637  -73.886  48.949  1
281543  98.662  -73.899  48.892  1
281544  98.725  -73.927  48.837  1
281545  98.805  -73.953  48.783  1
281546  98.834  -73.938  48.731  1
281547  98.862  -73.923  48.679  1
281548  98.867  -73.943  48.629  1
281549  98.879  -73.963  48.579  1
281550  98.917  -73.973  48.529  1
281551  98.954  -73.983  48.482  1
281552  98.992  -73.993  48.436  1
281553  99.030  -74.004  48.389  1
281554  99.067  -74.013  48.343  1
281555  99.105  -74.023  48.297  1
281556  99.143  -74.034  48.249  1
281557  99.181  -74.044  48.200  1
281558  99.219  -74.055  48.151  1
281559  99.246  -74.088  48.105  1
281560  99.271  -74.126  48.057  1
281561  99.286  -74.151  48.011  1
281562  99.284  -74.142  47.966  1
281563  99.283  -74.127  47.921  1
281564  99.290  -74.142  47.878  1
281565  99.351  -74.150  47.834  1
281566  99.412  -74.158  47.790  1
281567  99.473  -74.167  47.748  1
281568  99.534  -74.176  47.705  1
281569  99.594  -74.184  47.665  1
281570  99.646  -74.192  47.625  1
281571  99.668  -74.199  47.584  1
281572  99.692  -74.207  47.546  1
281573  99.714  -74.214  47.508  1
281574  99.737  -74.220  47.470  1
281575  99.760  -74.228  47.432  1
281576  99.783  -74.234  47.399  1
281577  99.807  -74.239  47.365  1
281578  99.832  -74.242  47.331  1
281579  99.856  -74.247  47.298  1
281580  99.880  -74.251  47.264  1
281581  99.905  -74.255  47.230  1
281582  99.934  -74.261  47.197  1
281583  99.965  -74.268  47.166  1
281584  99.995  -74.276  47.135  1
281585  100.025  -74.283  47.105  1
281586  100.056  -74.289  47.074  1
281587  100.087  -74.296  47.044  1
281588  100.118  -74.303  47.014  1
281589  100.147  -74.312  46.985  1
281590  100.168  -74.333  46.956  1
281591  100.190  -74.355  46.926  1
281592  100.212  -74.375  46.896  1
281593  100.235  -74.393  46.865  1
281594  100.266  -74.397  46.836  1
281595  100.297  -74.401  46.807  1
281596  100.328  -74.405  46.780  1
281597  100.359  -74.408  46.749  1
281598  100.390  -74.412  46.717  1
281599  100.421  -74.416  46.684  1
281600  100.452  -74.420  46.650  1
281601  100.482  -74.424  46.617  1
281602  100.513  -74.427  46.586  1
281603  100.544  -74.431  46.555  1
281604  100.575  -74.440  46.526  1
281605  100.606  -74.452  46.496  1
281606  100.636  -74.465  46.465  1
281607  100.667  -74.477  46.435  1
281608  100.697  -74.489  46.405  1
281609  100.728  -74.501  46.375  1
281610  100.759  -74.513  46.346  1
281611  100.789  -74.525  46.318  1
281612  100.823  -74.542  46.290  1
281613  100.880  -74.590  46.262  1
281614  100.936  -74.637  46.234  1
281615  100.971  -74.662  46.205  1
281616  100.998  -74.679  46.174  1
281617  101.025  -74.696  46.140  1
281618  101.053  -74.712  46.106  1
281619  101.080  -74.729  46.070  1
281620  101.108  -74.746  46.034  1
281621  101.135  -74.762  45.998  1
281622  101.162  -74.778  45.963  1
281623  101.190  -74.795  45.928  1
281624  101.217  -74.812  45.895  1
281625  101.244  -74.828  45.861  1
281626  101.271  -74.845  45.826  1
281627  101.304  -74.865  45.792  1
281628  101.332  -74.877  45.755  1
281629  101.367  -74.895  45.721  1
281630  101.406  -74.918  45.688  1
281631  101.445  -74.940  45.656  1
281632  101.483  -74.963  45.624  1
281633  101.521  -74.985  45.590  1
281634  101.554  -75.003  45.558  1
281635  101.588  -75.021  45.527  1
281636  101.622  -75.040  45.496  1
281637  101.656  -75.058  45.467  1
281638  101.689  -75.077  45.437  1
281639  101.721  -75.084  45.407  1
281640  101.750  -75.079  45.378  1
281641  101.779  -75.074  45.348  1
281642  101.808  -75.069  45.319  1
281643  101.837  -75.064  45.290  1
281644  101.867  -75.059  45.261  1
281645  101.896  -75.054  45.232  1
281646  101.900  -75.029  45.202  1
281647  101.917  -75.029  45.173  1
281648  101.935  -75.029  45.145  1
281649  101.953  -75.030  45.116  1
281650  101.970  -75.031  45.087  1
281651  101.987  -75.031  45.059  1
281652  102.005  -75.032  45.030  1
281653  102.022  -75.032  45.002  1
281654  102.040  -75.032  44.973  1
281655  102.057  -75.033  44.944  1
281656  102.075  -75.034  44.916  1
282022  92.447  -72.853  54.734  1
282023  92.478  -72.863  54.717  1
282024  92.509  -72.874  54.700  1
282025  92.540  -72.884  54.683  1
282026  92.570  -72.895  54.666  1
282027  92.601  -72.904  54.649  1
282028  92.641  -72.916  54.632  1
282029  92.684  -72.926  54.617  1
282030  92.727  -72.938  54.602  1
282031  92.770  -72.948  54.587  1
282032  92.813  -72.960  54.571  1
282033  92.856  -72.970  54.557  1
282034  92.899  -72.982  54.545  1
282035  92.941  -72.992  54.534  1
282036  92.985  -73.004  54.523  1
282037  93.027  -73.014  54.513  1
282038  93.070  -73.026  54.503  1
282039  93.113  -73.036  54.492  1
282040  93.156  -73.048  54.482  1
282041  93.194  -73.058  54.471  1
282042  93.220  -73.065  54.462  1
282043  93.245  -73.070  54.454  1
282044  93.269  -73.076  54.445  1
282045  93.293  -73.083  54.432  1
282046  93.318  -73.089  54.420  1
282047  93.342  -73.094  54.408  1
282048  93.376  -73.093  54.397  1
282049  93.422  -73.083  54.386  1
282050  93.448  -73.077  54.374  1
282051  93.474  -73.072  54.360  1
282052  93.500  -73.066  54.344  1
282053  93.525  -73.061  54.328  1
282054  93.551  -73.054  54.312  1
282055  93.577  -73.049  54.295  1
282122  95.049  -73.149  52.701  1
282123  95.069  -73.154  52.676  1
282124  95.090  -73.158  52.651  1
282125  95.110  -73.162  52.627  1
282126  95.131  -73.167  52.603  1
282127  95.151  -73.171  52.578  1
282128  95.172  -73.176  52.554  1
282129  95.199  -73.175  52.529  1
282130  95.220  -73.183  52.504  1
282131  95.235  -73.196  52.479  1
282132  95.249  -73.209  52.454  1
282133  95.263  -73.223  52.429  1
282134  95.298  -73.198  52.404  1
282135  95.343  -73.166  52.379  1
282136  95.393  -73.168  52.354  1
282137  95.436  -73.167  52.329  1
282138  95.473  -73.166  52.305  1
282139  95.510  -73.164  52.284  1
282140  95.546  -73.161  52.263  1
282141  95.574  -73.159  52.243  1
282142  95.603  -73.158  52.223  1
282143  95.630  -73.155  52.204  1
282144  95.659  -73.154  52.185  1
282145  95.695  -73.164  52.167  1
282146  95.734  -73.175  52.151  1
282147  95.771  -73.186  52.134  1
282148  95.810  -73.199  52.116  1
282149  95.847  -73.210  52.097  1
282150  95.886  -73.221  52.077  1
282151  95.929  -73.214  52.058  1
282152  95.972  -73.208  52.036  1
282153  96.015  -73.202  52.015  1
282154  96.058  -73.195  51.993  1
282155  96.101  -73.189  51.970  1
282156  96.136  -73.175  51.944  1
282157  96.168  -73.158  51.916  1
282158  96.200  -73.139  51.885  1
282159  96.227  -73.130  51.853  1
282160  96.250  -73.121  51.821  1
282161  96.252  -73.130  51.789  1
282162  96.249  -73.145  51.758  1
282163  96.246  -73.161  51.728  1
282164  96.272  -73.178  51.698  1
282165  96.316  -73.195  51.669  1
282166  96.342  -73.226  51.642  1
282167  96.362  -73.261  51.614  1
282168  96.384  -73.290  51.586  1
282169  96.410  -73.313  51.559  1
282170  96.437  -73.336  51.531  1
282171  96.464  -73.358  51.504  1
282172  96.490  -73.381  51.477  1
282173  96.517  -73.404  51.451  1
282174  96.543  -73.412  51.425  1
282175  96.559  -73.403  51.397  1
282176  96.560  -73.372  51.371  1
282177  96.567  -73.341  51.345  1
282178  96.607  -73.324  51.317  1
282179  96.633  -73.346  51.288  1
282180  96.665  -73.415  51.262  1
282181  96.711  -73.442  51.234  1
282182  96.750  -73.449  51.206  1
282183  96.783  -73.437  51.180  1
282184  96.800  -73.412  51.153  1
282185  96.774  -73.353  51.127  1
282186  96.785  -73.333  51.104  1
282187  96.816  -73.336  51.082  1
282188  96.847  -73.338  51.062  1
282189  96.879  -73.341  51.044  1
282190  96.928  -73.351  51.026  1
282191  96.976  -73.362  51.007  1
282192  97.018  -73.373  50.990  1
282193  97.056  -73.385  50.974  1
282194  97.095  -73.397  50.960  1
282195  97.124  -73.405  50.947  1
282196  97.152  -73.412  50.936  1
282197  97.175  -73.416  50.926  1
282198  97.188  -73.429  50.917  1
282199  97.206  -73.459  50.908  1
282200  97.224  -73.490  50.899  1
282201  97.247  -73.515  50.892  1
282202  97.242  -73.528  50.887  1
282203  97.273  -73.526  50.884  1
282204  97.312  -73.523  50.876  1
282205  97.350  -73.519  50.863  1
282206  97.389  -73.516  50.848  1
282207  97.427  -73.512  50.829  1
282208  97.466  -73.509  50.804  1
282209  97.504  -73.506  50.774  1
282210  97.543  -73.503  50.742  1
282211  97.581  -73.499  50.708  1
282212  97.620  -73.490  50.671  1
282213  97.659  -73.478  50.634  1
282214  97.698  -73.465  50.596  1
282215  97.736  -73.452  50.558  1
282216  97.775  -73.440  50.517  1
282217  97.814  -73.427  50.470  1
282218  97.855  -73.441  50.419  1
282219  97.898  -73.455  50.367  1
282220  97.944  -73.466  50.313  1
282221  97.974  -73.498  50.257  1
282222  97.999  -73.537  50.200  1
282223  98.035  -73.562  50.143  1
282224  98.074  -73.586  50.085  1
282225  98.112  -73.609  50.025  1
282226  98.150  -73.633  49.966  1
282227  98.188  -73.640  49.907  1
282228  98.225  -73.635  49.847  1
282229  98.263  -73.630  49.787  1
282230  98.301  -73.622  49.725  1
282231  98.340  -73.608  49.663  1
282232  98.362  -73.622  49.601  1
282233  98.370  -73.658  49.537  1
282234  98.378  -73.694  49.474  1
282235  98.386  -73.730  49.413  1
282236  98.409  -73.758  49.353  1
282237  98.435  -73.783  49.292  1
282238  98.472  -73.799  49.233  1
282239  98.513  -73.812  49.174  1
282240  98.558  -73.823  49.115  1
282241  98.621  -73.832  49.056  1
282242  98.640  -73.846  48.997  1
282243  98.647  -73.862  48.939  1
282244  98.653  -73.878  48.883  1
282245  98.754  -73.929  48.827  1
282246  98.806  -73.932  48.773  1
282247  98.835  -73.917  48.721  1
282248  98.864  -73.903  48.671  1
282249  98.874  -73.915  48.621  1
282250  98.894  -73.932  48.572  1
282251  98.932  -73.941  48.524  1
282252  98.970  -73.951  48.477  1
282253  99.007  -73.962  48.430  1
282254  99.045  -73.972  48.384  1
282255  99.082  -73.982  48.339  1
282256  99.120  -73.992  48.291  1
282257  99.157  -74.002  48.243  1
282258  99.196  -74.013  48.194  1
282259  99.224  -74.026  48.145  1
282260  99.245  -74.056  48.099  1
282261  99.272  -74.085  48.051  1
282262  99.349  -74.068  48.005  1
282263  99.323  -74.064  47.960  1
282264  99.332  -74.085  47.917  1
282265  99.343  -74.115  47.872  1
282266  99.402  -74.124  47.829  1
282267  99.463  -74.132  47.785  1
282268  99.523  -74.142  47.742  1
282269  99.584  -74.150  47.701  1
282270  99.633  -74.158  47.660  1
282271  99.656  -74.165  47.620  1
282272  99.679  -74.172  47.579  1
282273  99.702  -74.179  47.541  1
282274  99.724  -74.186  47.503  1
282275  99.747  -74.193  47.466  1
282276  99.770  -74.201  47.428  1
282277  99.793  -74.208  47.394  1
282278  99.817  -74.212  47.360  1
282279  99.841  -74.216  47.327  1
282280  99.865  -74.220  47.293  1
282281  99.890  -74.225  47.260  1
282282  99.914  -74.229  47.226  1
282283  99.938  -74.233  47.193  1
282284  99.964  -74.238  47.162  1
282285  99.994  -74.245  47.131  1
282286  100.025  -74.252  47.100  1
282287  100.056  -74.259  47.069  1
282288  100.086  -74.266  47.038  1
282289  100.117  -74.273  47.007  1
282290  100.148  -74.280  46.977  1
282291  100.171  -74.298  46.948  1
282292  100.193  -74.319  46.918  1
282293  100.214  -74.340  46.888  1
282294  100.241  -74.352  46.858  1
282295  100.271  -74.356  46.828  1
282296  100.302  -74.360  46.798  1
282297  100.333  -74.364  46.771  1
282298  100.364  -74.368  46.740  1
282299  100.395  -74.371  46.707  1
282300  100.426  -74.375  46.674  1
282301  100.457  -74.379  46.640  1
282302  100.488  -74.383  46.606  1
282303  100.519  -74.386  46.575  1
282304  100.550  -74.390  46.544  1
282305  100.580  -74.394  46.515  1
282306  100.611  -74.405  46.484  1
282307  100.642  -74.417  46.454  1
282308  100.672  -74.429  46.424  1
282309  100.703  -74.441  46.393  1
282310  100.734  -74.453  46.363  1
282311  100.764  -74.465  46.334  1
282312  100.795  -74.477  46.305  1
282313  100.841  -74.512  46.277  1
282314  100.898  -74.559  46.249  1
282315  100.955  -74.607  46.220  1
282316  100.994  -74.637  46.190  1
282317  101.022  -74.654  46.159  1
282318  101.049  -74.671  46.125  1
282319  101.076  -74.687  46.090  1
282320  101.104  -74.703  46.055  1
282321  101.131  -74.720  46.019  1
282322  101.158  -74.737  45.984  1
282323  101.186  -74.753  45.950  1
282324  101.213  -74.770  45.915  1
282325  101.240  -74.787  45.880  1
282326  101.267  -74.803  45.845  1
282327  101.295  -74.820  45.810  1
282328  101.322  -74.837  45.776  1
282329  101.351  -74.853  45.740  1
282330  101.389  -74.873  45.706  1
282331  101.427  -74.896  45.674  1
282332  101.466  -74.919  45.642  1
282333  101.504  -74.941  45.609  1
282334  101.543  -74.963  45.577  1
282335  101.577  -74.982  45.545  1
282336  101.611  -75.001  45.514  1
282337  101.644  -75.019  45.483  1
282338  101.678  -75.038  45.454  1
282339  101.710  -75.050  45.424  1
282340  101.740  -75.044  45.394  1
282341  101.769  -75.040  45.364  1
282342  101.798  -75.035  45.334  1
282343  101.827  -75.030  45.305  1
282344  101.856  -75.025  45.276  1
282345  101.886  -75.020  45.247  1
282346  101.911  -75.011  45.218  1
282347  101.915  -74.988  45.189  1
282348  101.933  -74.989  45.160  1
282349  101.950  -74.990  45.131  1
282350  101.968  -74.990  45.103  1
282351  101.985  -74.991  45.074  1
282352  102.003  -74.991  45.045  1
282353  102.020  -74.992  45.017  1
282354  102.037  -74.992  44.989  1
282355  102.055  -74.993  44.960  1
282356  102.072  -74.994  44.931  1
282357  102.090  -74.994  44.903  1
282723  92.443  -72.824  54.738  1
282724  92.474  -72.834  54.721  1
282725  92.505  -72.844  54.703  1
282726  92.535  -72.855  54.686  1
282727  92.566  -72.865  54.669  1
282728  92.596  -72.876  54.652  1
282729  92.638  -72.886  54.635  1
282730  92.681  -72.898  54.619  1
282731  92.724  -72.908  54.604  1
282732  92.767  -72.920  54.589  1
282733  92.809  -72.930  54.573  1
282734  92.853  -72.942  54.559  1
282735  92.896  -72.952  54.546  1
282736  92.938  -72.963  54.535  1
282737  92.981  -72.974  54.523  1
282738  93.024  -72.985  54.513  1
282739  93.067  -72.996  54.501  1
282740  93.110  -73.007  54.490  1
282741  93.153  -73.018  54.478  1
282742  93.186  -73.028  54.468  1
282743  93.212  -73.035  54.458  1
282744  93.236  -73.040  54.449  1
282745  93.261  -73.046  54.438  1
282746  93.285  -73.052  54.425  1
282747  93.310  -73.058  54.413  1
282748  93.334  -73.064  54.401  1
282749  93.374  -73.059  54.389  1
282750  93.418  -73.049  54.377  1
282751  93.443  -73.044  54.365  1
282752  93.469  -73.038  54.351  1
282753  93.495  -73.032  54.335  1
282754  93.520  -73.026  54.318  1
282755  93.547  -73.021  54.301  1
282756  93.572  -73.015  54.284  1
282823  95.052  -73.114  52.693  1
282824  95.072  -73.119  52.669  1
282825  95.093  -73.123  52.644  1
282826  95.113  -73.127  52.620  1
282827  95.134  -73.132  52.597  1
282828  95.155  -73.136  52.573  1
282829  95.175  -73.141  52.548  1
282830  95.195  -73.145  52.524  1
282831  95.220  -73.146  52.498  1
282832  95.242  -73.153  52.474  1
282833  95.256  -73.167  52.449  1
282834  95.271  -73.180  52.424  1
282835  95.294  -73.177  52.399  1
282836  95.338  -73.138  52.374  1
282837  95.388  -73.139  52.349  1
282838  95.430  -73.139  52.324  1
282839  95.466  -73.137  52.301  1
282840  95.503  -73.135  52.280  1
282841  95.540  -73.133  52.260  1
282842  95.572  -73.130  52.240  1
282843  95.600  -73.129  52.220  1
282844  95.628  -73.126  52.202  1
282845  95.658  -73.126  52.183  1
282846  95.695  -73.138  52.166  1
282847  95.734  -73.150  52.151  1
282848  95.771  -73.161  52.134  1
282849  95.810  -73.173  52.117  1
282850  95.847  -73.184  52.099  1
282851  95.886  -73.196  52.080  1
282852  95.924  -73.204  52.061  1
282853  95.968  -73.198  52.041  1
282854  96.011  -73.192  52.020  1
282855  96.053  -73.186  52.000  1
282856  96.096  -73.179  51.977  1
282857  96.128  -73.161  51.950  1
282858  96.160  -73.143  51.921  1
282859  96.192  -73.126  51.891  1
282860  96.224  -73.105  51.860  1
282861  96.247  -73.085  51.828  1
282862  96.243  -73.112  51.796  1
282863  96.240  -73.128  51.766  1
282864  96.237  -73.144  51.738  1
282865  96.273  -73.161  51.710  1
282866  96.317  -73.179  51.682  1
282867  96.361  -73.196  51.655  1
282868  96.395  -73.221  51.629  1
282869  96.414  -73.255  51.602  1
282870  96.434  -73.290  51.575  1
282871  96.453  -73.324  51.549  1
282872  96.473  -73.358  51.523  1
282873  96.500  -73.381  51.496  1
282874  96.526  -73.401  51.470  1
282875  96.535  -73.382  51.443  1
282876  96.536  -73.352  51.417  1
282877  96.537  -73.321  51.390  1
282878  96.573  -73.287  51.363  1
282879  96.605  -73.292  51.334  1
282880  96.631  -73.316  51.306  1
282881  96.661  -73.391  51.278  1
282882  96.703  -73.417  51.250  1
282883  96.736  -73.405  51.221  1
282884  96.769  -73.393  51.194  1
282885  96.802  -73.380  51.167  1
282886  96.778  -73.323  51.142  1
282887  96.798  -73.314  51.118  1
282888  96.829  -73.316  51.095  1
282889  96.860  -73.318  51.074  1
282890  96.891  -73.321  51.055  1
282891  96.923  -73.323  51.037  1
282892  96.970  -73.333  51.019  1
282893  97.014  -73.344  51.001  1
282894  97.052  -73.356  50.985  1
282895  97.082  -73.365  50.970  1
282896  97.109  -73.371  50.958  1
282897  97.137  -73.378  50.946  1
282898  97.163  -73.385  50.934  1
282899  97.180  -73.410  50.923  1
282900  97.197  -73.441  50.914  1
282901  97.215  -73.471  50.903  1
282902  97.236  -73.499  50.895  1
282903  97.243  -73.510  50.889  1
282904  97.282  -73.507  50.885  1
282905  97.320  -73.503  50.874  1
282906  97.359  -73.500  50.861  1
282907  97.397  -73.496  50.845  1
282908  97.436  -73.493  50.827  1
282909  97.474  -73.481  50.803  1
282910  97.513  -73.468  50.774  1
282911  97.552  -73.456  50.742  1
282912  97.591  -73.443  50.708  1
282913  97.630  -73.431  50.668  1
282914  97.668  -73.418  50.628  1
282915  97.707  -73.406  50.587  1
282916  97.746  -73.393  50.545  1
282917  97.785  -73.380  50.501  1
282918  97.825  -73.392  50.453  1
282919  97.867  -73.408  50.401  1
282920  97.911  -73.421  50.348  1
282921  97.956  -73.433  50.293  1
282922  98.002  -73.443  50.238  1
282923  98.034  -73.473  50.182  1
282924  98.059  -73.512  50.125  1
282925  98.083  -73.551  50.066  1
282926  98.116  -73.581  50.008  1
282927  98.154  -73.604  49.949  1
282928  98.193  -73.628  49.890  1
282929  98.230  -73.628  49.830  1
282930  98.267  -73.622  49.770  1
282931  98.306  -73.611  49.709  1
282932  98.345  -73.598  49.647  1
282933  98.378  -73.594  49.586  1
282934  98.385  -73.631  49.523  1
282935  98.393  -73.666  49.461  1
282936  98.403  -73.703  49.400  1
282937  98.429  -73.728  49.339  1
282938  98.456  -73.753  49.279  1
282939  98.489  -73.773  49.220  1
282940  98.530  -73.785  49.161  1
282941  98.571  -73.797  49.104  1
282942  98.618  -73.809  49.047  1
282943  98.649  -73.821  48.989  1
282944  98.656  -73.837  48.931  1
282945  98.704  -73.877  48.874  1
282946  98.779  -73.927  48.819  1
282947  98.807  -73.912  48.766  1
282948  98.836  -73.897  48.714  1
282949  98.865  -73.882  48.664  1
282950  98.880  -73.886  48.616  1
282951  98.909  -73.900  48.567  1
282952  98.946  -73.910  48.519  1
282953  98.984  -73.920  48.473  1
282954  99.022  -73.931  48.427  1
282955  99.060  -73.941  48.381  1
282956  99.104  -73.955  48.334  1
282957  99.139  -73.964  48.286  1
282958  99.169  -73.971  48.237  1
282959  99.200  -73.979  48.188  1
282960  99.224  -74.001  48.140  1
282961  99.245  -74.031  48.093  1
282962  99.273  -74.055  48.046  1
282963  99.312  -74.061  48.000  1
282964  99.359  -74.034  47.955  1
282965  99.385  -74.059  47.911  1
282966  99.397  -74.088  47.867  1
282967  99.453  -74.098  47.823  1
282968  99.514  -74.107  47.780  1
282969  99.575  -74.116  47.738  1
282970  99.620  -74.123  47.696  1
282971  99.643  -74.131  47.655  1
282972  99.666  -74.138  47.615  1
282973  99.689  -74.145  47.575  1
282974  99.711  -74.152  47.537  1
282975  99.734  -74.159  47.499  1
282976  99.757  -74.167  47.461  1
282977  99.780  -74.173  47.424  1
282978  99.803  -74.180  47.389  1
282979  99.827  -74.186  47.356  1
282980  99.851  -74.190  47.322  1
282981  99.875  -74.194  47.288  1
282982  99.899  -74.198  47.256  1
282983  99.923  -74.202  47.223  1
282984  99.948  -74.207  47.189  1
282985  99.972  -74.211  47.157  1
282986  99.996  -74.215  47.126  1
282987  100.025  -74.221  47.094  1
282988  100.055  -74.228  47.063  1
282989  100.086  -74.235  47.031  1
282990  100.117  -74.242  46.999  1
282991  100.147  -74.249  46.969  1
282992  100.174  -74.263  46.940  1
282993  100.195  -74.283  46.910  1
282994  100.217  -74.305  46.880  1
282995  100.246  -74.312  46.850  1
282996  100.277  -74.316  46.819  1
282997  100.308  -74.320  46.789  1
282998  100.339  -74.324  46.761  1
282999  100.369  -74.327  46.730  1
283000  100.400  -74.331  46.697  1
283001  100.431  -74.335  46.663  1
283002  100.462  -74.339  46.629  1
283003  100.493  -74.342  46.595  1
283004  100.524  -74.346  46.564  1
283005  100.555  -74.350  46.534  1
283006  100.585  -74.354  46.504  1
283007  100.617  -74.358  46.472  1
283008  100.647  -74.369  46.441  1
283009  100.678  -74.381  46.411  1
283010  100.708  -74.393  46.380  1
283011  100.739  -74.405  46.350  1
283012  100.770  -74.418  46.321  1
283013  100.802  -74.433  46.292  1
283014  100.859  -74.480  46.263  1
283015  100.916  -74.528  46.234  1
283016  100.973  -74.577  46.206  1
283017  101.015  -74.609  46.176  1
283018  101.041  -74.625  46.145  1
283019  101.068  -74.641  46.110  1
283020  101.095  -74.657  46.074  1
283021  101.122  -74.674  46.038  1
283022  101.149  -74.690  46.002  1
283023  101.176  -74.706  45.968  1
283024  101.203  -74.722  45.934  1
283025  101.230  -74.738  45.899  1
283026  101.257  -74.754  45.864  1
283027  101.284  -74.771  45.828  1
283028  101.311  -74.787  45.794  1
283029  101.338  -74.803  45.759  1
283030  101.364  -74.820  45.725  1
283031  101.410  -74.852  45.692  1
283032  101.449  -74.874  45.660  1
283033  101.487  -74.897  45.628  1
283034  101.526  -74.919  45.595  1
283035  101.565  -74.941  45.564  1
283036  101.599  -74.960  45.532  1
283037  101.633  -74.979  45.501  1
283038  101.667  -74.997  45.471  1
283039  101.700  -75.016  45.441  1
283040  101.730  -75.010  45.411  1
283041  101.759  -75.006  45.381  1
283042  101.788  -75.001  45.350  1
283043  101.817  -74.996  45.320  1
283044  101.846  -74.991  45.292  1
283045  101.876  -74.986  45.263  1
283046  101.905  -74.982  45.234  1
283047  101.919  -74.960  45.204  1
283048  101.930  -74.949  45.175  1
283049  101.948  -74.950  45.147  1
283050  101.965  -74.950  45.118  1
283051  101.982  -74.950  45.090  1
283052  102.000  -74.951  45.061  1
283053  102.018  -74.952  45.032  1
283054  102.035  -74.952  45.004  1
283055  102.052  -74.953  44.976  1
283056  102.070  -74.954  44.946  1
283057  102.087  -74.954  44.917  1
283425  92.470  -72.805  54.725  1
283426  92.500  -72.815  54.707  1
283427  92.531  -72.826  54.689  1
283428  92.562  -72.836  54.672  1
283429  92.592  -72.846  54.655  1
283430  92.635  -72.857  54.638  1
283431  92.678  -72.868  54.621  1
283432  92.721  -72.879  54.606  1
283433  92.764  -72.890  54.591  1
283434  92.806  -72.901  54.575  1
283435  92.849  -72.912  54.561  1
283436  92.892  -72.923  54.548  1
283437  92.935  -72.934  54.535  1
283438  92.978  -72.945  54.523  1
283439  93.021  -72.956  54.513  1
283440  93.064  -72.967  54.500  1
283441  93.107  -72.978  54.488  1
283442  93.149  -72.989  54.476  1
283443  93.179  -72.998  54.465  1
283444  93.204  -73.004  54.455  1
283445  93.228  -73.010  54.445  1
283446  93.253  -73.016  54.434  1
283447  93.277  -73.022  54.421  1
283448  93.302  -73.028  54.408  1
283449  93.326  -73.033  54.395  1
283450  93.371  -73.024  54.381  1
283451  93.413  -73.015  54.369  1
283452  93.438  -73.010  54.356  1
283453  93.464  -73.004  54.342  1
283454  93.490  -72.998  54.326  1
283524  95.055  -73.079  52.686  1
283525  95.075  -73.084  52.661  1
283526  95.096  -73.089  52.638  1
283527  95.116  -73.092  52.614  1
283528  95.137  -73.097  52.591  1
283529  95.158  -73.101  52.567  1
283530  95.178  -73.106  52.543  1
283531  95.198  -73.111  52.518  1
283532  95.219  -73.114  52.492  1
283533  95.242  -73.117  52.468  1
283534  95.264  -73.124  52.444  1
283535  95.278  -73.137  52.419  1
283536  95.293  -73.151  52.394  1
283537  95.334  -73.113  52.369  1
283538  95.383  -73.111  52.344  1
283539  95.423  -73.111  52.320  1
283540  95.460  -73.108  52.298  1
283541  95.497  -73.106  52.277  1
283542  95.533  -73.104  52.257  1
283543  95.569  -73.101  52.237  1
283544  95.598  -73.100  52.218  1
283545  95.626  -73.098  52.199  1
283546  95.658  -73.101  52.182  1
283547  95.695  -73.113  52.166  1
283548  95.734  -73.124  52.151  1
283549  95.772  -73.136  52.135  1
283550  95.810  -73.148  52.118  1
283551  95.848  -73.159  52.101  1
283552  95.886  -73.170  52.083  1
283553  95.924  -73.182  52.064  1
283554  95.963  -73.188  52.045  1
283555  96.007  -73.181  52.026  1
283556  96.049  -73.175  52.005  1
283557  96.088  -73.164  51.982  1
283558  96.120  -73.147  51.955  1
283559  96.153  -73.129  51.926  1
283560  96.182  -73.103  51.897  1
283561  96.209  -73.072  51.865  1
283562  96.238  -73.042  51.834  1
283563  96.234  -73.090  51.804  1
283564  96.230  -73.111  51.776  1
283565  96.231  -73.126  51.748  1
283566  96.274  -73.144  51.721  1
283567  96.318  -73.162  51.695  1
283568  96.362  -73.180  51.669  1
283569  96.406  -73.197  51.643  1
283570  96.448  -73.216  51.618  1
283571  96.467  -73.250  51.592  1
283572  96.487  -73.285  51.567  1
283573  96.501  -73.326  51.541  1
283574  96.515  -73.367  51.515  1
283575  96.513  -73.358  51.488  1
283576  96.512  -73.330  51.462  1
283577  96.513  -73.300  51.436  1
283578  96.533  -73.267  51.409  1
283579  96.576  -73.239  51.381  1
283580  96.603  -73.260  51.352  1
283581  96.630  -73.285  51.323  1
283582  96.659  -73.360  51.293  1
283583  96.689  -73.373  51.265  1
283584  96.722  -73.361  51.237  1
283585  96.755  -73.349  51.209  1
283586  96.788  -73.336  51.183  1
283587  96.781  -73.293  51.157  1
283588  96.811  -73.294  51.132  1
283589  96.842  -73.296  51.108  1
283590  96.873  -73.299  51.086  1
283591  96.904  -73.301  51.067  1
283592  96.936  -73.303  51.048  1
283593  96.967  -73.305  51.030  1
283594  97.010  -73.315  51.012  1
283595  97.040  -73.324  50.995  1
283596  97.068  -73.331  50.981  1
283597  97.094  -73.336  50.969  1
283598  97.120  -73.341  50.956  1
283599  97.154  -73.357  50.943  1
283600  97.173  -73.388  50.930  1
283601  97.190  -73.421  50.920  1
283602  97.208  -73.452  50.907  1
283603  97.225  -73.484  50.897  1
283604  97.252  -73.491  50.888  1
283605  97.290  -73.485  50.880  1
283606  97.329  -73.472  50.868  1
283607  97.368  -73.459  50.855  1
283608  97.406  -73.447  50.841  1
283609  97.446  -73.434  50.823  1
283610  97.485  -73.422  50.799  1
283611  97.523  -73.409  50.770  1
283612  97.562  -73.396  50.738  1
283613  97.601  -73.384  50.702  1
283614  97.640  -73.371  50.660  1
283615  97.678  -73.359  50.617  1
283616  97.717  -73.346  50.573  1
283617  97.756  -73.334  50.529  1
283618  97.796  -73.342  50.483  1
283619  97.838  -73.358  50.434  1
283620  97.879  -73.374  50.382  1
283621  97.923  -73.387  50.329  1
283622  97.968  -73.399  50.275  1
283623  98.014  -73.410  50.220  1
283624  98.060  -73.421  50.164  1
283625  98.093  -73.448  50.108  1
283626  98.118  -73.487  50.049  1
283627  98.143  -73.526  49.991  1
283628  98.167  -73.565  49.932  1
283629  98.196  -73.600  49.872  1
283630  98.235  -73.620  49.813  1
283631  98.272  -73.614  49.754  1
283632  98.311  -73.601  49.693  1
283633  98.350  -73.587  49.631  1
283634  98.388  -73.575  49.570  1
283635  98.402  -73.603  49.508  1
283636  98.410  -73.640  49.447  1
283637  98.423  -73.672  49.387  1
283638  98.450  -73.698  49.327  1
283639  98.477  -73.723  49.267  1
283640  98.506  -73.747  49.208  1
283641  98.547  -73.759  49.150  1
283642  98.588  -73.771  49.093  1
283643  98.629  -73.783  49.036  1
283644  98.673  -73.799  48.980  1
283645  98.724  -73.816  48.923  1
283646  98.776  -73.833  48.866  1
283647  98.806  -73.854  48.812  1
283648  98.818  -73.872  48.760  1
283649  98.838  -73.876  48.709  1
283650  98.866  -73.862  48.660  1
283651  98.887  -73.858  48.611  1
283652  98.924  -73.869  48.563  1
283653  98.961  -73.879  48.515  1
283654  99.006  -73.894  48.470  1
283655  99.051  -73.907  48.425  1
283656  99.081  -73.915  48.378  1
283657  99.112  -73.922  48.330  1
283658  99.143  -73.929  48.281  1
283659  99.174  -73.937  48.232  1
283660  99.204  -73.946  48.183  1
283661  99.225  -73.976  48.135  1
283662  99.249  -74.003  48.087  1
283663  99.289  -74.017  48.041  1
283664  99.330  -74.031  47.995  1
283665  99.367  -74.015  47.951  1
283666  99.439  -74.032  47.906  1
283667  99.450  -74.061  47.862  1
283668  99.504  -74.073  47.819  1
283669  99.565  -74.082  47.776  1
283670  99.608  -74.089  47.734  1
283671  99.630  -74.096  47.692  1
283672  99.653  -74.104  47.651  1
283673  99.676  -74.111  47.611  1
283674  99.699  -74.118  47.571  1
283675  99.721  -74.125  47.533  1
283676  99.744  -74.132  47.495  1
283677  99.767  -74.139  47.457  1
283678  99.790  -74.146  47.420  1
283679  99.812  -74.153  47.385  1
283680  99.836  -74.160  47.351  1
283681  99.860  -74.164  47.317  1
283682  99.885  -74.168  47.284  1
283683  99.909  -74.172  47.252  1
283684  99.933  -74.176  47.218  1
283685  99.957  -74.180  47.184  1
283686  99.982  -74.185  47.151  1
283687  100.006  -74.189  47.119  1
283688  100.030  -74.193  47.087  1
283689  100.055  -74.198  47.056  1
283690  100.085  -74.205  47.024  1
283691  100.116  -74.211  46.992  1
283692  100.146  -74.218  46.962  1
283693  100.176  -74.227  46.931  1
283694  100.198  -74.248  46.901  1
283695  100.220  -74.267  46.870  1
283696  100.251  -74.271  46.840  1
283697  100.282  -74.275  46.809  1
283698  100.313  -74.279  46.779  1
283699  100.344  -74.283  46.750  1
283700  100.374  -74.286  46.719  1
283701  100.406  -74.290  46.686  1
283702  100.436  -74.294  46.652  1
283703  100.467  -74.298  46.619  1
283704  100.498  -74.302  46.585  1
283705  100.529  -74.305  46.553  1
283706  100.560  -74.309  46.523  1
283707  100.591  -74.313  46.492  1
283708  100.622  -74.317  46.461  1
283709  100.652  -74.321  46.431  1
283710  100.683  -74.333  46.400  1
283711  100.714  -74.346  46.367  1
283712  100.745  -74.358  46.338  1
283713  100.775  -74.370  46.308  1
283714  100.821  -74.402  46.279  1
283715  100.878  -74.450  46.249  1
283716  100.934  -74.498  46.221  1
283717  100.973  -74.527  46.192  1
283718  101.011  -74.555  46.162  1
283719  101.047  -74.581  46.130  1
283720  101.074  -74.597  46.095  1
283721  101.101  -74.614  46.059  1
283722  101.128  -74.630  46.023  1
283723  101.155  -74.646  45.987  1
283724  101.182  -74.662  45.952  1
283725  101.209  -74.678  45.917  1
283726  101.236  -74.694  45.883  1
283727  101.263  -74.711  45.848  1
283728  101.289  -74.727  45.813  1
283729  101.317  -74.743  45.778  1
283730  101.343  -74.759  45.744  1
283731  101.371  -74.781  45.710  1
283732  101.397  -74.816  45.678  1
283733  101.470  -74.853  45.647  1
283734  101.509  -74.875  45.615  1
283735  101.548  -74.897  45.582  1
283736  101.587  -74.920  45.551  1
283737  101.622  -74.940  45.519  1
283738  101.656  -74.958  45.488  1
283739  101.689  -74.977  45.459  1
283740  101.719  -74.976  45.428  1
283741  101.748  -74.972  45.398  1
283742  101.777  -74.966  45.368  1
283743  101.807  -74.962  45.337  1
283744  101.836  -74.957  45.307  1
283745  101.865  -74.952  45.278  1
283746  101.894  -74.947  45.250  1
283747  101.923  -74.942  45.221  1
283748  101.927  -74.909  45.191  1
283749  101.945  -74.910  45.162  1
283750  101.963  -74.910  45.133  1
283751  101.980  -74.910  45.105  1
283752  101.997  -74.911  45.076  1
283753  102.015  -74.911  45.048  1
283754  102.032  -74.912  45.019  1
283755  102.050  -74.913  44.991  1
283756  102.067  -74.913  44.963  1
283757  102.085  -74.913  44.933  1
283758  102.102  -74.914  44.904  1
284127  92.496  -72.786  54.711  1
284128  92.527  -72.797  54.693  1
284129  92.558  -72.807  54.676  1
284130  92.589  -72.817  54.659  1
284131  92.632  -72.828  54.642  1
284132  92.674  -72.839  54.625  1
284133  92.717  -72.850  54.610  1
284134  92.761  -72.861  54.595  1
284135  92.803  -72.872  54.578  1
284136  92.846  -72.883  54.563  1
284137  92.889  -72.894  54.549  1
284138  92.932  -72.905  54.536  1
284139  92.975  -72.916  54.523  1
284140  93.018  -72.927  54.513  1
284141  93.061  -72.938  54.500  1
284142  93.103  -72.949  54.487  1
284143  93.143  -72.960  54.475  1
284144  93.171  -72.968  54.463  1
284145  93.196  -72.974  54.452  1
284146  93.220  -72.979  54.441  1
284147  93.245  -72.985  54.430  1
284148  93.269  -72.992  54.416  1
284149  93.294  -72.998  54.403  1
284150  93.322  -73.001  54.389  1
284151  93.369  -72.990  54.375  1
284225  95.058  -73.045  52.679  1
284226  95.078  -73.049  52.655  1
284227  95.099  -73.054  52.631  1
284228  95.119  -73.058  52.608  1
284229  95.140  -73.062  52.586  1
284230  95.161  -73.067  52.563  1
284231  95.181  -73.071  52.539  1
284232  95.201  -73.076  52.514  1
284233  95.222  -73.079  52.488  1
284234  95.243  -73.084  52.465  1
284235  95.263  -73.089  52.440  1
284236  95.286  -73.095  52.415  1
284237  95.300  -73.108  52.390  1
284238  95.330  -73.092  52.365  1
284239  95.378  -73.083  52.340  1
284240  95.417  -73.082  52.317  1
284241  95.454  -73.079  52.296  1
284242  95.490  -73.077  52.275  1
284243  95.527  -73.075  52.255  1
284244  95.564  -73.073  52.235  1
284245  95.595  -73.071  52.216  1
284246  95.623  -73.069  52.198  1
284247  95.658  -73.076  52.182  1
284248  95.696  -73.087  52.167  1
284249  95.734  -73.099  52.151  1
284250  95.772  -73.111  52.136  1
284251  95.810  -73.122  52.120  1
284252  95.848  -73.133  52.104  1
284253  95.886  -73.145  52.087  1
284254  95.924  -73.157  52.068  1
284255  95.962  -73.168  52.049  1
284256  96.003  -73.171  52.030  1
284257  96.045  -73.165  52.009  1
284258  96.080  -73.150  51.986  1
284259  96.112  -73.131  51.958  1
284260  96.140  -73.101  51.930  1
284261  96.168  -73.070  51.902  1
284262  96.196  -73.039  51.870  1
284263  96.224  -73.009  51.840  1
284264  96.227  -73.041  51.813  1
284265  96.220  -73.094  51.786  1
284266  96.232  -73.110  51.760  1
284267  96.275  -73.127  51.733  1
284268  96.319  -73.145  51.707  1
284269  96.366  -73.163  51.682  1
284270  96.415  -73.181  51.658  1
284271  96.465  -73.200  51.633  1
284272  96.477  -73.240  51.609  1
284273  96.490  -73.281  51.585  1
284274  96.504  -73.323  51.559  1
284275  96.503  -73.313  51.533  1
284276  96.498  -73.293  51.507  1
284277  96.493  -73.272  51.480  1
284278  96.493  -73.248  51.454  1
284279  96.539  -73.214  51.426  1
284280  96.574  -73.208  51.398  1
284281  96.601  -73.228  51.368  1
284282  96.628  -73.255  51.338  1
284283  96.630  -73.254  51.308  1
284284  96.632  -73.252  51.279  1
284285  96.677  -73.268  51.252  1
284286  96.731  -73.289  51.225  1
284287  96.774  -73.293  51.198  1
284288  96.793  -73.271  51.172  1
284289  96.824  -73.274  51.146  1
284290  96.856  -73.277  51.121  1
284291  96.887  -73.279  51.099  1
284292  96.918  -73.280  51.079  1
284293  96.949  -73.281  51.060  1
284294  96.979  -73.282  51.041  1
284295  97.002  -73.282  51.022  1
284296  97.022  -73.283  51.006  1
284297  97.048  -73.289  50.992  1
284298  97.075  -73.293  50.979  1
284299  97.107  -73.308  50.966  1
284300  97.146  -73.331  50.952  1
284301  97.168  -73.362  50.937  1
284302  97.185  -73.393  50.925  1
284303  97.202  -73.426  50.912  1
284304  97.238  -73.449  50.898  1
284305  97.261  -73.438  50.885  1
284306  97.300  -73.425  50.874  1
284307  97.339  -73.413  50.861  1
284308  97.378  -73.400  50.848  1
284309  97.417  -73.387  50.834  1
284310  97.455  -73.375  50.816  1
284311  97.494  -73.362  50.792  1
284312  97.533  -73.350  50.763  1
284313  97.572  -73.337  50.730  1
284314  97.610  -73.324  50.692  1
284315  97.649  -73.312  50.648  1
284316  97.688  -73.299  50.602  1
284317  97.727  -73.287  50.556  1
284318  97.767  -73.292  50.510  1
284319  97.808  -73.308  50.463  1
284320  97.850  -73.324  50.414  1
284321  97.890  -73.341  50.362  1
284322  97.935  -73.354  50.310  1
284323  97.980  -73.365  50.258  1
284324  98.026  -73.376  50.203  1
284325  98.072  -73.387  50.148  1
284326  98.117  -73.399  50.093  1
284327  98.153  -73.423  50.034  1
284328  98.177  -73.462  49.975  1
284329  98.202  -73.501  49.915  1
284330  98.227  -73.540  49.854  1
284331  98.251  -73.580  49.796  1
284332  98.277  -73.603  49.738  1
284333  98.316  -73.590  49.677  1
284334  98.355  -73.578  49.614  1
284335  98.394  -73.565  49.553  1
284336  98.417  -73.576  49.493  1
284337  98.425  -73.612  49.433  1
284338  98.443  -73.643  49.375  1
284339  98.470  -73.668  49.316  1
284340  98.497  -73.694  49.257  1
284341  98.524  -73.719  49.198  1
284342  98.563  -73.732  49.140  1
284343  98.604  -73.744  49.083  1
284344  98.649  -73.751  49.026  1
284345  98.728  -73.709  48.970  1
284346  98.780  -73.727  48.915  1
284347  98.829  -73.744  48.860  1
284348  98.839  -73.767  48.807  1
284349  98.849  -73.790  48.756  1
284350  98.861  -73.810  48.705  1
284351  98.881  -73.813  48.656  1
284352  98.911  -73.830  48.608  1
284353  98.954  -73.847  48.560  1
284354  98.993  -73.858  48.513  1
284355  99.024  -73.866  48.469  1
284356  99.055  -73.872  48.422  1
284357  99.086  -73.880  48.374  1
284358  99.117  -73.888  48.325  1
284359  99.148  -73.894  48.277  1
284360  99.179  -73.902  48.227  1
284361  99.205  -73.921  48.178  1
284362  99.225  -73.951  48.129  1
284363  99.265  -73.965  48.082  1
284364  99.306  -73.979  48.036  1
284365  99.347  -73.992  47.991  1
284366  99.387  -74.007  47.946  1
284367  99.454  -74.011  47.902  1
284368  99.504  -74.035  47.857  1
284369  99.555  -74.048  47.814  1
284370  99.594  -74.055  47.772  1
284371  99.617  -74.062  47.731  1
284372  99.640  -74.070  47.688  1
284373  99.663  -74.076  47.647  1
284374  99.686  -74.083  47.607  1
284375  99.709  -74.091  47.568  1
284376  99.731  -74.098  47.530  1
284377  99.754  -74.104  47.492  1
284378  99.777  -74.112  47.454  1
284379  99.800  -74.119  47.417  1
284380  99.823  -74.126  47.382  1
284381  99.845  -74.133  47.348  1
284382  99.870  -74.138  47.314  1
284383  99.894  -74.142  47.280  1
284384  99.918  -74.146  47.247  1
284385  99.942  -74.150  47.213  1
284386  99.967  -74.154  47.179  1
284387  99.991  -74.158  47.145  1
284388  100.015  -74.163  47.113  1
284389  100.040  -74.167  47.080  1
284390  100.064  -74.171  47.048  1
284391  100.088  -74.175  47.016  1
284392  100.115  -74.181  46.984  1
284393  100.146  -74.188  46.953  1
284394  100.177  -74.195  46.923  1
284395  100.200  -74.213  46.893  1
284396  100.225  -74.226  46.862  1
284397  100.256  -74.230  46.831  1
284398  100.287  -74.234  46.800  1
284399  100.318  -74.238  46.769  1
284400  100.349  -74.242  46.740  1
284401  100.380  -74.245  46.709  1
284402  100.411  -74.250  46.676  1
284403  100.442  -74.254  46.642  1
284404  100.473  -74.258  46.608  1
284405  100.503  -74.261  46.575  1
284406  100.535  -74.265  46.543  1
284407  100.565  -74.269  46.512  1
284408  100.596  -74.273  46.480  1
284409  100.627  -74.277  46.450  1
284410  100.658  -74.280  46.419  1
284411  100.689  -74.286  46.388  1
284412  100.719  -74.298  46.355  1
284413  100.750  -74.310  46.326  1
284414  100.782  -74.324  46.297  1
284415  100.839  -74.372  46.267  1
284416  100.892  -74.416  46.237  1
284417  100.930  -74.443  46.208  1
284418  100.968  -74.471  46.178  1
284419  101.005  -74.499  46.147  1
284420  101.043  -74.527  46.115  1
284421  101.080  -74.554  46.080  1
284422  101.107  -74.570  46.044  1
284423  101.134  -74.586  46.008  1
284424  101.161  -74.603  45.972  1
284425  101.188  -74.618  45.936  1
284426  101.214  -74.634  45.901  1
284427  101.242  -74.651  45.866  1
284428  101.268  -74.667  45.831  1
284429  101.296  -74.683  45.797  1
284430  101.322  -74.700  45.763  1
284431  101.349  -74.715  45.729  1
284432  101.376  -74.741  45.695  1
284433  101.403  -74.775  45.665  1
284434  101.429  -74.810  45.634  1
284435  101.516  -74.849  45.602  1
284436  101.569  -74.875  45.570  1
284437  101.608  -74.898  45.538  1
284438  101.644  -74.919  45.506  1
284439  101.678  -74.937  45.475  1
284440  101.709  -74.942  45.445  1
284441  101.738  -74.938  45.414  1
284442  101.767  -74.932  45.384  1
284443  101.796  -74.928  45.354  1
284444  101.826  -74.922  45.324  1
284445  101.855  -74.918  45.294  1
284446  101.884  -74.913  45.265  1
284447  101.913  -74.908  45.236  1
284448  101.943  -74.903  45.208  1
284449  101.943  -74.869  45.178  1
284450  101.960  -74.869  45.149  1
284451  101.977  -74.870  45.120  1
284452  101.995  -74.871  45.091  1
284453  102.013  -74.871  45.063  1
284454  102.030  -74.872  45.034  1
284455  102.047  -74.872  45.006  1
284456  102.065  -74.872  44.977  1
284457  102.082  -74.873  44.949  1
284458  102.100  -74.874  44.919  1
284830  92.554  -72.778  54.681  1
284831  92.585  -72.788  54.663  1
284832  92.629  -72.799  54.646  1
284833  92.671  -72.810  54.629  1
284834  92.714  -72.821  54.614  1
284835  92.757  -72.832  54.598  1
284836  92.800  -72.843  54.581  1
284837  92.843  -72.854  54.566  1
284838  92.886  -72.865  54.552  1
284839  92.929  -72.876  54.539  1
284840  92.972  -72.887  54.526  1
284841  93.014  -72.898  54.514  1
284842  93.057  -72.909  54.500  1
284843  93.100  -72.920  54.486  1
284844  93.136  -72.929  54.474  1
284845  93.163  -72.938  54.461  1
284846  93.188  -72.944  54.450  1
284847  93.212  -72.949  54.438  1
284848  93.236  -72.955  54.426  1
284849  93.261  -72.961  54.412  1
284925  95.040  -73.005  52.695  1
284926  95.061  -73.010  52.673  1
284927  95.082  -73.014  52.649  1
284928  95.102  -73.019  52.626  1
284929  95.122  -73.023  52.603  1
284930  95.143  -73.027  52.581  1
284931  95.164  -73.032  52.558  1
284932  95.184  -73.036  52.534  1
284933  95.204  -73.041  52.510  1
284934  95.225  -73.045  52.485  1
284935  95.246  -73.049  52.461  1
284936  95.266  -73.054  52.437  1
284937  95.287  -73.058  52.412  1
284938  95.308  -73.065  52.387  1
284939  95.326  -73.072  52.362  1
284940  95.373  -73.054  52.337  1
284941  95.411  -73.053  52.314  1
284942  95.448  -73.051  52.293  1
284943  95.484  -73.048  52.272  1
284944  95.521  -73.046  52.253  1
284945  95.557  -73.045  52.234  1
284946  95.593  -73.042  52.215  1
284947  95.621  -73.040  52.199  1
284948  95.658  -73.051  52.182  1
284949  95.696  -73.062  52.167  1
284950  95.734  -73.073  52.152  1
284951  95.772  -73.085  52.136  1
284952  95.810  -73.097  52.121  1
284953  95.848  -73.108  52.105  1
284954  95.886  -73.120  52.089  1
284955  95.924  -73.131  52.071  1
284956  95.962  -73.142  52.053  1
284957  96.000  -73.155  52.034  1
284958  96.040  -73.154  52.014  1
284959  96.070  -73.129  51.989  1
284960  96.098  -73.098  51.962  1
284961  96.126  -73.068  51.934  1
284962  96.154  -73.038  51.905  1
284963  96.182  -73.007  51.877  1
284964  96.210  -72.976  51.849  1
284965  96.220  -72.992  51.823  1
284966  96.214  -73.045  51.797  1
284967  96.245  -73.088  51.772  1
284968  96.293  -73.113  51.747  1
284969  96.342  -73.132  51.723  1
284970  96.391  -73.150  51.699  1
284971  96.441  -73.168  51.674  1
284972  96.475  -73.194  51.650  1
284973  96.480  -73.237  51.626  1
284974  96.493  -73.279  51.602  1
284975  96.491  -73.268  51.577  1
284976  96.486  -73.248  51.551  1
284977  96.482  -73.230  51.525  1
284978  96.479  -73.220  51.497  1
284979  96.508  -73.193  51.470  1
284980  96.549  -73.163  51.441  1
284981  96.584  -73.160  51.411  1
284982  96.615  -73.176  51.382  1
284983  96.645  -73.192  51.352  1
284984  96.649  -73.188  51.323  1
284985  96.636  -73.170  51.295  1
284986  96.653  -73.171  51.267  1
284987  96.716  -73.199  51.240  1
284988  96.780  -73.227  51.213  1
284989  96.799  -73.245  51.186  1
284990  96.835  -73.246  51.159  1
284991  96.867  -73.246  51.135  1
284992  96.897  -73.247  51.113  1
284993  96.928  -73.248  51.092  1
284994  96.959  -73.249  51.072  1
284995  96.986  -73.249  51.051  1
284996  97.001  -73.248  51.032  1
284997  97.016  -73.247  51.016  1
284998  97.031  -73.247  51.001  1
284999  97.062  -73.260  50.987  1
285000  97.099  -73.283  50.975  1
285001  97.138  -73.305  50.961  1
285002  97.162  -73.334  50.946  1
285003  97.179  -73.367  50.933  1
285004  97.217  -73.390  50.919  1
285005  97.261  -73.390  50.903  1
285006  97.275  -73.378  50.887  1
285007  97.310  -73.366  50.872  1
285008  97.349  -73.353  50.858  1
285009  97.387  -73.341  50.843  1
285010  97.426  -73.328  50.826  1
285011  97.465  -73.315  50.807  1
285012  97.504  -73.303  50.780  1
285013  97.543  -73.290  50.750  1
285014  97.582  -73.278  50.715  1
285015  97.620  -73.265  50.676  1
285016  97.659  -73.252  50.630  1
285017  97.698  -73.240  50.581  1
285018  97.738  -73.242  50.532  1
285019  97.779  -73.258  50.483  1
285020  97.820  -73.275  50.437  1
285021  97.861  -73.291  50.388  1
285022  97.902  -73.308  50.337  1
285023  97.947  -73.320  50.286  1
285024  97.993  -73.331  50.236  1
285025  98.038  -73.343  50.183  1
285026  98.084  -73.354  50.130  1
285027  98.129  -73.365  50.076  1
285028  98.175  -73.376  50.017  1
285029  98.213  -73.398  49.957  1
285030  98.237  -73.437  49.897  1
285031  98.262  -73.477  49.836  1
285032  98.286  -73.515  49.778  1
285033  98.307  -73.545  49.719  1
285034  98.326  -73.571  49.659  1
285035  98.360  -73.568  49.598  1
285036  98.399  -73.554  49.538  1
285037  98.433  -73.549  49.480  1
285038  98.441  -73.585  49.422  1
285039  98.464  -73.612  49.364  1
285040  98.491  -73.638  49.306  1
285041  98.517  -73.663  49.249  1
285042  98.544  -73.689  49.190  1
285043  98.580  -73.706  49.132  1
285044  98.621  -73.719  49.075  1
285045  98.703  -73.666  49.020  1
285046  98.784  -73.621  48.965  1
285047  98.835  -73.638  48.911  1
285048  98.863  -73.659  48.856  1
285049  98.873  -73.681  48.804  1
285050  98.883  -73.704  48.752  1
285051  98.893  -73.727  48.702  1
285052  98.935  -73.752  48.653  1
285053  98.998  -73.776  48.606  1
285054  98.968  -73.811  48.559  1
285055  98.998  -73.823  48.512  1
285056  99.029  -73.831  48.466  1
285057  99.060  -73.838  48.418  1
285058  99.091  -73.845  48.369  1
285059  99.122  -73.853  48.321  1
285060  99.153  -73.860  48.271  1
285061  99.184  -73.867  48.222  1
285062  99.205  -73.896  48.174  1
285063  99.241  -73.913  48.125  1
285064  99.282  -73.927  48.078  1
285065  99.323  -73.941  48.032  1
285066  99.363  -73.954  47.987  1
285067  99.404  -73.968  47.942  1
285068  99.471  -73.988  47.898  1
285069  99.544  -74.010  47.854  1
285070  99.582  -74.021  47.811  1
285071  99.605  -74.028  47.769  1
285072  99.627  -74.035  47.727  1
285073  99.650  -74.042  47.685  1
285074  99.673  -74.049  47.645  1
285075  99.696  -74.056  47.605  1
285076  99.718  -74.064  47.566  1
285077  99.742  -74.070  47.527  1
285078  99.764  -74.078  47.489  1
285079  99.787  -74.085  47.451  1
285080  99.810  -74.092  47.414  1
285081  99.833  -74.099  47.379  1
285082  99.855  -74.106  47.344  1
285083  99.879  -74.111  47.310  1
285084  99.904  -74.115  47.275  1
285085  99.928  -74.120  47.242  1
285086  99.952  -74.123  47.207  1
285087  99.976  -74.128  47.173  1
285088  100.000  -74.132  47.139  1
285089  100.025  -74.136  47.106  1
285090  100.049  -74.141  47.073  1
285091  100.073  -74.145  47.041  1
285092  100.098  -74.149  47.008  1
285093  100.122  -74.153  46.975  1
285094  100.146  -74.157  46.945  1
285095  100.176  -74.164  46.914  1
285096  100.203  -74.177  46.884  1
285097  100.231  -74.186  46.853  1
285098  100.262  -74.190  46.822  1
285099  100.292  -74.194  46.790  1
285100  100.324  -74.198  46.759  1
285101  100.354  -74.201  46.730  1
285102  100.385  -74.205  46.699  1
285103  100.416  -74.209  46.667  1
285104  100.447  -74.213  46.632  1
285105  100.478  -74.217  46.598  1
285106  100.509  -74.220  46.564  1
285107  100.540  -74.224  46.532  1
285108  100.570  -74.228  46.501  1
285109  100.602  -74.232  46.469  1
285110  100.632  -74.236  46.439  1
285111  100.663  -74.239  46.408  1
285112  100.694  -74.243  46.376  1
285113  100.725  -74.250  46.345  1
285114  100.756  -74.262  46.316  1
285115  100.800  -74.293  46.288  1
285116  100.848  -74.332  46.258  1
285117  100.886  -74.360  46.228  1
285118  100.924  -74.387  46.196  1
285119  100.962  -74.415  46.164  1
285120  100.999  -74.443  46.131  1
285121  101.037  -74.471  46.098  1
285122  101.075  -74.499  46.063  1
285123  101.113  -74.526  46.028  1
285124  101.140  -74.543  45.992  1
285125  101.167  -74.559  45.957  1
285126  101.193  -74.574  45.920  1
285127  101.220  -74.591  45.886  1
285128  101.247  -74.607  45.851  1
285129  101.274  -74.623  45.816  1
285130  101.301  -74.640  45.783  1
285131  101.328  -74.656  45.750  1
285132  101.355  -74.671  45.716  1
285133  101.382  -74.701  45.683  1
285134  101.409  -74.736  45.652  1
285135  101.435  -74.771  45.621  1
285136  101.462  -74.806  45.589  1
285137  101.560  -74.845  45.557  1
285138  101.629  -74.876  45.526  1
285139  101.667  -74.897  45.494  1
285140  101.699  -74.908  45.462  1
285141  101.728  -74.903  45.432  1
285142  101.757  -74.898  45.402  1
285143  101.786  -74.894  45.372  1
285144  101.816  -74.888  45.342  1
285145  101.845  -74.884  45.312  1
285146  101.874  -74.879  45.282  1
285147  101.903  -74.874  45.252  1
285148  101.933  -74.869  45.224  1
285149  101.959  -74.861  45.195  1
285150  101.958  -74.829  45.166  1
285151  101.975  -74.830  45.136  1
285152  101.992  -74.831  45.107  1
285153  102.010  -74.831  45.077  1
285154  102.027  -74.831  45.050  1
285155  102.045  -74.832  45.021  1
285156  102.062  -74.832  44.992  1
285157  102.080  -74.833  44.964  1
285158  102.097  -74.834  44.935  1
285159  102.115  -74.834  44.906  1
285626  95.043  -72.970  52.689  1
285627  95.064  -72.975  52.666  1
285628  95.085  -72.979  52.642  1
285629  95.105  -72.984  52.620  1
285630  95.125  -72.988  52.599  1
285631  95.146  -72.992  52.576  1
285632  95.167  -72.997  52.553  1
285633  95.187  -73.001  52.530  1
285634  95.207  -73.006  52.506  1
285635  95.228  -73.010  52.482  1
285636  95.249  -73.014  52.458  1
285637  95.269  -73.019  52.434  1
285638  95.290  -73.023  52.409  1
285639  95.310  -73.028  52.384  1
285640  95.330  -73.036  52.359  1
285641  95.368  -73.026  52.334  1
285642  95.404  -73.024  52.311  1
285643  95.441  -73.022  52.290  1
285644  95.478  -73.020  52.270  1
285645  95.514  -73.018  52.251  1
285646  95.551  -73.016  52.232  1
285647  95.588  -73.014  52.214  1
285648  95.620  -73.014  52.198  1
285649  95.658  -73.025  52.182  1
285650  95.696  -73.036  52.166  1
285651  95.734  -73.048  52.151  1
285652  95.772  -73.060  52.136  1
285653  95.810  -73.071  52.121  1
285654  95.848  -73.083  52.105  1
285655  95.887  -73.093  52.090  1
285656  95.926  -73.104  52.072  1
285657  95.965  -73.114  52.055  1
285658  96.004  -73.123  52.037  1
285659  96.031  -73.136  52.017  1
285660  96.057  -73.107  51.991  1
285661  96.085  -73.070  51.965  1
285662  96.113  -73.036  51.938  1
285663  96.141  -73.005  51.910  1
285664  96.169  -72.975  51.883  1
285665  96.197  -72.944  51.858  1
285666  96.213  -72.942  51.833  1
285667  96.238  -72.986  51.808  1
285668  96.283  -73.025  51.784  1
285669  96.327  -73.064  51.760  1
285670  96.371  -73.102  51.737  1
285671  96.416  -73.137  51.714  1
285672  96.466  -73.155  51.690  1
285673  96.477  -73.192  51.666  1
285674  96.482  -73.235  51.643  1
285675  96.480  -73.224  51.619  1
285676  96.477  -73.210  51.593  1
285677  96.474  -73.199  51.567  1
285678  96.472  -73.189  51.540  1
285679  96.482  -73.171  51.512  1
285680  96.524  -73.137  51.484  1
285681  96.554  -73.139  51.454  1
285682  96.582  -73.145  51.424  1
285683  96.625  -73.133  51.395  1
285684  96.664  -73.131  51.365  1
285685  96.694  -73.148  51.336  1
285686  96.681  -73.131  51.308  1
285687  96.723  -73.146  51.280  1
285688  96.771  -73.172  51.253  1
285689  96.782  -73.193  51.226  1
285690  96.796  -73.212  51.199  1
285691  96.833  -73.213  51.173  1
285692  96.871  -73.214  51.149  1
285693  96.908  -73.214  51.126  1
285694  96.939  -73.214  51.105  1
285695  96.969  -73.215  51.084  1
285696  96.985  -73.215  51.062  1
285697  97.001  -73.215  51.043  1
285698  97.022  -73.218  51.026  1
285699  97.042  -73.221  51.010  1
285700  97.066  -73.234  50.996  1
285701  97.092  -73.258  50.983  1
285702  97.130  -73.280  50.969  1
285703  97.157  -73.308  50.955  1
285704  97.196  -73.329  50.940  1
285705  97.261  -73.338  50.924  1
285706  97.283  -73.330  50.906  1
285707  97.297  -73.318  50.887  1
285708  97.320  -73.306  50.870  1
285709  97.359  -73.294  50.854  1
285710  97.397  -73.281  50.837  1
285711  97.436  -73.269  50.817  1
285712  97.475  -73.256  50.795  1
285713  97.514  -73.243  50.766  1
285714  97.552  -73.231  50.734  1
285715  97.591  -73.218  50.697  1
285716  97.630  -73.206  50.655  1
285717  97.669  -73.193  50.608  1
285718  97.709  -73.192  50.558  1
285719  97.750  -73.209  50.507  1
285720  97.791  -73.225  50.457  1
285721  97.832  -73.242  50.410  1
285722  97.873  -73.258  50.360  1
285723  97.914  -73.274  50.310  1
285724  97.959  -73.286  50.261  1
285725  98.005  -73.298  50.212  1
285726  98.050  -73.309  50.162  1
285727  98.096  -73.320  50.110  1
285728  98.141  -73.331  50.056  1
285729  98.187  -73.343  49.998  1
285730  98.233  -73.354  49.939  1
285731  98.272  -73.373  49.878  1
285732  98.297  -73.412  49.817  1
285733  98.321  -73.452  49.759  1
285734  98.341  -73.478  49.700  1
285735  98.360  -73.503  49.641  1
285736  98.380  -73.529  49.581  1
285737  98.404  -73.544  49.522  1
285738  98.443  -73.531  49.465  1
285739  98.458  -73.557  49.409  1
285740  98.485  -73.583  49.352  1
285741  98.511  -73.608  49.296  1
285742  98.538  -73.634  49.239  1
285743  98.565  -73.659  49.181  1
285744  98.597  -73.680  49.123  1
285745  98.665  -73.649  49.067  1
285746  98.757  -73.580  49.013  1
285747  98.839  -73.532  48.959  1
285748  98.886  -73.550  48.905  1
285749  98.896  -73.572  48.852  1
285750  98.906  -73.595  48.800  1
285751  98.906  -73.625  48.749  1
285752  98.885  -73.670  48.699  1
285753  98.963  -73.701  48.650  1
285754  99.013  -73.714  48.603  1
285755  98.994  -73.744  48.556  1
285756  99.007  -73.770  48.510  1
285757  99.034  -73.793  48.462  1
285758  99.065  -73.803  48.413  1
285759  99.095  -73.810  48.365  1
285760  99.127  -73.818  48.316  1
285761  99.157  -73.825  48.266  1
285762  99.185  -73.841  48.218  1
285763  99.217  -73.861  48.169  1
285764  99.258  -73.875  48.121  1
285765  99.299  -73.888  48.074  1
285766  99.351  -73.905  48.028  1
285767  99.419  -73.926  47.983  1
285768  99.468  -73.944  47.939  1
285769  99.510  -73.960  47.895  1
285770  99.552  -73.976  47.852  1
285771  99.592  -73.985  47.809  1
285772  99.616  -73.999  47.766  1
285773  99.637  -74.007  47.724  1
285774  99.660  -74.015  47.683  1
285775  99.683  -74.022  47.643  1
285776  99.706  -74.029  47.603  1
285777  99.728  -74.036  47.564  1
285778  99.751  -74.043  47.524  1
285779  99.774  -74.051  47.486  1
285780  99.797  -74.057  47.448  1
285781  99.820  -74.065  47.411  1
285782  99.843  -74.072  47.376  1
285783  99.865  -74.079  47.341  1
285784  99.889  -74.085  47.306  1
285785  99.913  -74.089  47.270  1
285786  99.937  -74.093  47.236  1
285787  99.962  -74.098  47.201  1
285788  99.986  -74.101  47.167  1
285789  100.010  -74.106  47.133  1
285790  100.034  -74.110  47.099  1
285791  100.059  -74.114  47.066  1
285792  100.083  -74.118  47.034  1
285793  100.107  -74.123  47.001  1
285794  100.131  -74.127  46.968  1
285795  100.155  -74.131  46.936  1
285796  100.180  -74.136  46.905  1
285797  100.205  -74.142  46.875  1
285798  100.236  -74.145  46.844  1
285799  100.267  -74.149  46.812  1
285800  100.298  -74.153  46.780  1
285801  100.329  -74.157  46.748  1
285802  100.359  -74.161  46.719  1
285803  100.391  -74.164  46.689  1
285804  100.421  -74.168  46.657  1
285805  100.452  -74.172  46.623  1
285806  100.483  -74.176  46.587  1
285807  100.514  -74.179  46.553  1
285808  100.545  -74.183  46.521  1
285809  100.576  -74.187  46.491  1
285810  100.607  -74.191  46.459  1
285811  100.637  -74.195  46.428  1
285812  100.668  -74.198  46.397  1
285813  100.699  -74.202  46.366  1
285814  100.731  -74.206  46.336  1
285815  100.762  -74.215  46.307  1
285816  100.804  -74.248  46.278  1
285817  100.842  -74.276  46.248  1
285818  100.880  -74.304  46.217  1
285819  100.918  -74.331  46.183  1
285820  100.956  -74.359  46.149  1
285821  100.993  -74.387  46.115  1
285822  101.032  -74.415  46.081  1
285823  101.069  -74.443  46.047  1
285824  101.107  -74.470  46.012  1
285825  101.145  -74.498  45.977  1
285826  101.173  -74.515  45.942  1
285827  101.199  -74.531  45.906  1
285828  101.227  -74.547  45.871  1
285829  101.253  -74.563  45.837  1
285830  101.280  -74.580  45.803  1
285831  101.307  -74.596  45.770  1
285832  101.334  -74.612  45.737  1
285833  101.361  -74.628  45.704  1
285834  101.388  -74.662  45.671  1
285835  101.414  -74.697  45.640  1
285836  101.441  -74.731  45.608  1
285837  101.468  -74.766  45.577  1
285838  101.504  -74.801  45.546  1
285839  101.603  -74.841  45.514  1
285840  101.688  -74.874  45.482  1
285841  101.717  -74.869  45.451  1
285842  101.747  -74.864  45.420  1
285843  101.776  -74.859  45.391  1
285844  101.806  -74.854  45.360  1
285845  101.835  -74.850  45.330  1
285846  101.864  -74.845  45.301  1
285847  101.893  -74.840  45.270  1
285848  101.922  -74.835  45.241  1
285849  101.952  -74.830  45.212  1
285850  101.967  -74.809  45.183  1
285851  101.973  -74.790  45.154  1
285852  101.990  -74.790  45.125  1
285853  102.007  -74.791  45.095  1
285854  102.025  -74.791  45.065  1
285855  102.042  -74.792  45.037  1
285856  102.060  -74.792  45.009  1
285857  102.078  -74.793  44.981  1
285858  102.095  -74.794  44.951  1
285859  102.112  -74.794  44.922  1
286327  95.049  -72.937  52.683  1
286328  95.067  -72.940  52.660  1
286329  95.088  -72.945  52.637  1
286330  95.108  -72.949  52.614  1
286331  95.128  -72.953  52.593  1
286332  95.149  -72.957  52.571  1
286333  95.170  -72.962  52.548  1
286334  95.190  -72.967  52.525  1
286335  95.211  -72.971  52.502  1
286336  95.231  -72.975  52.479  1
286337  95.252  -72.979  52.455  1
286338  95.272  -72.984  52.431  1
286339  95.293  -72.989  52.406  1
286340  95.313  -72.993  52.381  1
286341  95.334  -72.997  52.356  1
286342  95.361  -72.998  52.331  1
286343  95.398  -72.995  52.308  1
286344  95.435  -72.993  52.287  1
286345  95.471  -72.992  52.267  1
286346  95.508  -72.989  52.248  1
286347  95.546  -72.988  52.229  1
286348  95.586  -72.986  52.213  1
286349  95.622  -72.985  52.195  1
286350  95.661  -72.995  52.178  1
286351  95.700  -73.005  52.162  1
286352  95.740  -73.015  52.147  1
286353  95.778  -73.026  52.133  1
286354  95.818  -73.036  52.119  1
286355  95.856  -73.046  52.104  1
286356  95.896  -73.056  52.088  1
286357  95.935  -73.067  52.072  1
286358  95.974  -73.076  52.056  1
286359  96.007  -73.088  52.038  1
286360  96.025  -73.101  52.018  1
286361  96.046  -73.105  51.993  1
286362  96.074  -73.070  51.967  1
286363  96.101  -73.034  51.941  1
286364  96.129  -72.998  51.915  1
286365  96.157  -72.962  51.890  1
286366  96.184  -72.926  51.866  1
286367  96.213  -72.898  51.842  1
286368  96.255  -72.931  51.819  1
286369  96.298  -72.970  51.798  1
286370  96.341  -73.009  51.774  1
286371  96.385  -73.048  51.751  1
286372  96.428  -73.087  51.728  1
286373  96.471  -73.126  51.706  1
286374  96.477  -73.180  51.682  1
286375  96.472  -73.189  51.658  1
286376  96.469  -73.179  51.634  1
286377  96.467  -73.168  51.608  1
286378  96.464  -73.158  51.582  1
286379  96.461  -73.147  51.554  1
286380  96.499  -73.116  51.526  1
286381  96.531  -73.108  51.496  1
286382  96.559  -73.115  51.466  1
286383  96.587  -73.122  51.436  1
286384  96.623  -73.118  51.407  1
286385  96.667  -73.106  51.378  1
286386  96.710  -73.095  51.349  1
286387  96.730  -73.092  51.320  1
286388  96.759  -73.116  51.291  1
286389  96.769  -73.137  51.265  1
286390  96.780  -73.158  51.238  1
286391  96.792  -73.179  51.211  1
286392  96.829  -73.180  51.186  1
286393  96.868  -73.180  51.163  1
286394  96.905  -73.181  51.140  1
286395  96.943  -73.182  51.118  1
286396  96.975  -73.186  51.097  1
286397  96.995  -73.189  51.074  1
286398  97.016  -73.192  51.054  1
286399  97.036  -73.195  51.036  1
286400  97.057  -73.198  51.019  1
286401  97.079  -73.207  51.004  1
286402  97.105  -73.230  50.990  1
286403  97.131  -73.254  50.977  1
286404  97.174  -73.270  50.962  1
286405  97.240  -73.278  50.946  1
286406  97.291  -73.282  50.929  1
286407  97.305  -73.270  50.908  1
286408  97.319  -73.258  50.887  1
286409  97.333  -73.247  50.868  1
286410  97.368  -73.234  50.850  1
286411  97.407  -73.222  50.830  1
286412  97.446  -73.209  50.807  1
286413  97.485  -73.197  50.783  1
286414  97.524  -73.184  50.750  1
286415  97.563  -73.171  50.716  1
286416  97.601  -73.159  50.677  1
286417  97.640  -73.146  50.633  1
286418  97.679  -73.142  50.584  1
286419  97.721  -73.159  50.534  1
286420  97.761  -73.175  50.483  1
286421  97.803  -73.192  50.432  1
286422  97.844  -73.208  50.383  1
286423  97.885  -73.224  50.332  1
286424  97.926  -73.240  50.283  1
286425  97.971  -73.252  50.234  1
286426  98.017  -73.264  50.187  1
286427  98.062  -73.275  50.139  1
286428  98.108  -73.286  50.088  1
286429  98.153  -73.298  50.036  1
286430  98.199  -73.309  49.978  1
286431  98.245  -73.320  49.919  1
286432  98.290  -73.331  49.859  1
286433  98.332  -73.348  49.799  1
286434  98.356  -73.386  49.740  1
286435  98.375  -73.411  49.681  1
286436  98.394  -73.437  49.623  1
286437  98.414  -73.462  49.564  1
286438  98.433  -73.487  49.506  1
286439  98.452  -73.512  49.450  1
286440  98.478  -73.528  49.395  1
286441  98.505  -73.553  49.340  1
286442  98.532  -73.578  49.286  1
286443  98.559  -73.603  49.227  1
286444  98.587  -73.627  49.170  1
286445  98.627  -73.631  49.114  1
286446  98.719  -73.563  49.059  1
286447  98.811  -73.494  49.004  1
286448  98.895  -73.443  48.951  1
286449  98.920  -73.464  48.899  1
286450  98.921  -73.493  48.846  1
286451  98.901  -73.537  48.796  1
286452  98.880  -73.582  48.746  1
286453  98.860  -73.627  48.698  1
286454  98.950  -73.646  48.649  1
286455  99.000  -73.659  48.601  1
286456  99.049  -73.671  48.553  1
286457  99.018  -73.706  48.506  1
286458  99.046  -73.729  48.458  1
286459  99.073  -73.752  48.408  1
286460  99.100  -73.775  48.359  1
286461  99.131  -73.783  48.311  1
286462  99.162  -73.791  48.261  1
286463  99.194  -73.809  48.213  1
286464  99.234  -73.822  48.164  1
286465  99.298  -73.842  48.117  1
286466  99.339  -73.859  48.070  1
286467  99.381  -73.875  48.024  1
286468  99.423  -73.891  47.979  1
286469  99.465  -73.907  47.935  1
286470  99.506  -73.923  47.891  1
286471  99.548  -73.939  47.848  1
286472  99.588  -73.951  47.806  1
286473  99.628  -73.956  47.764  1
286474  99.660  -73.965  47.723  1
286475  99.673  -73.985  47.681  1
286476  99.693  -73.995  47.640  1
286477  99.716  -74.002  47.600  1
286478  99.738  -74.009  47.560  1
286479  99.761  -74.016  47.522  1
286480  99.784  -74.023  47.484  1
286481  99.807  -74.030  47.445  1
286482  99.830  -74.038  47.407  1
286483  99.852  -74.045  47.371  1
286484  99.875  -74.051  47.335  1
286485  99.898  -74.059  47.300  1
286486  99.922  -74.063  47.264  1
286487  99.947  -74.067  47.229  1
286488  99.971  -74.071  47.193  1
286489  99.995  -74.076  47.159  1
286490  100.019  -74.079  47.125  1
286491  100.044  -74.084  47.091  1
286492  100.068  -74.088  47.058  1
286493  100.092  -74.092  47.024  1
286494  100.117  -74.096  46.991  1
286495  100.141  -74.101  46.959  1
286496  100.165  -74.104  46.928  1
286497  100.194  -74.111  46.897  1
286498  100.226  -74.117  46.867  1
286499  100.257  -74.121  46.835  1
286500  100.287  -74.125  46.803  1
286501  100.318  -74.128  46.770  1
286502  100.349  -74.132  46.739  1
286503  100.379  -74.136  46.710  1
286504  100.410  -74.139  46.680  1
286505  100.441  -74.142  46.647  1
286506  100.472  -74.146  46.613  1
286507  100.502  -74.150  46.577  1
286508  100.533  -74.153  46.543  1
286509  100.563  -74.157  46.511  1
286510  100.594  -74.161  46.481  1
286511  100.625  -74.164  46.450  1
286512  100.655  -74.167  46.418  1
286513  100.686  -74.171  46.387  1
286514  100.717  -74.175  46.356  1
286515  100.747  -74.177  46.326  1
286516  100.775  -74.183  46.297  1
286517  100.805  -74.199  46.267  1
286518  100.836  -74.220  46.236  1
286519  100.874  -74.247  46.205  1
286520  100.912  -74.275  46.170  1
286521  100.950  -74.303  46.134  1
286522  100.988  -74.330  46.100  1
286523  101.025  -74.358  46.065  1
286524  101.063  -74.386  46.031  1
286525  101.101  -74.414  45.997  1
286526  101.139  -74.442  45.962  1
286527  101.177  -74.470  45.927  1
286528  101.205  -74.487  45.892  1
286529  101.232  -74.503  45.857  1
286530  101.259  -74.520  45.823  1
286531  101.286  -74.536  45.790  1
286532  101.313  -74.552  45.757  1
286533  101.340  -74.568  45.724  1
286534  101.367  -74.587  45.691  1
286535  101.393  -74.622  45.659  1
286536  101.420  -74.657  45.628  1
286537  101.447  -74.691  45.597  1
286538  101.474  -74.726  45.566  1
286539  101.575  -74.766  45.535  1
286540  101.653  -74.798  45.503  1
286541  101.699  -74.820  45.471  1
286542  101.737  -74.830  45.440  1
286543  101.766  -74.825  45.409  1
286544  101.795  -74.820  45.380  1
286545  101.824  -74.816  45.349  1
286546  101.853  -74.811  45.319  1
286547  101.883  -74.806  45.290  1
286548  101.912  -74.801  45.258  1
286549  101.941  -74.796  45.229  1
286550  101.970  -74.791  45.201  1
286551  101.975  -74.758  45.172  1
286552  101.987  -74.750  45.142  1
286553  102.005  -74.750  45.113  1
286554  102.023  -74.751  45.083  1
286555  102.040  -74.751  45.054  1
286556  102.057  -74.752  45.025  1
286557  102.075  -74.753  44.997  1
286558  102.092  -74.753  44.968  1
286559  102.110  -74.753  44.939  1
286560  102.127  -74.754  44.910  1
287028  95.060  -72.905  52.677  1
287029  95.070  -72.905  52.654  1
287030  95.091  -72.910  52.631  1
287031  95.111  -72.914  52.609  1
287032  95.132  -72.918  52.587  1
287033  95.152  -72.923  52.565  1
287034  95.173  -72.927  52.544  1
287035  95.193  -72.932  52.521  1
287036  95.214  -72.936  52.498  1
287037  95.234  -72.940  52.475  1
287038  95.255  -72.945  52.452  1
287039  95.275  -72.949  52.428  1
287040  95.296  -72.954  52.403  1
287041  95.316  -72.958  52.378  1
287042  95.337  -72.962  52.353  1
287043  95.365  -72.970  52.329  1
287044  95.410  -72.974  52.305  1
287045  95.449  -72.973  52.284  1
287046  95.488  -72.972  52.264  1
287047  95.528  -72.971  52.244  1
287048  95.567  -72.970  52.225  1
287049  95.606  -72.969  52.208  1
287050  95.633  -72.952  52.190  1
287051  95.670  -72.958  52.174  1
287052  95.709  -72.968  52.157  1
287053  95.749  -72.978  52.141  1
287054  95.788  -72.989  52.128  1
287055  95.827  -72.998  52.113  1
287056  95.866  -73.009  52.099  1
287057  95.905  -73.019  52.084  1
287058  95.944  -73.029  52.069  1
287059  95.982  -73.039  52.052  1
287060  96.001  -73.053  52.035  1
287061  96.020  -73.067  52.015  1
287062  96.039  -73.080  51.992  1
287063  96.062  -73.069  51.968  1
287064  96.090  -73.032  51.944  1
287065  96.117  -72.997  51.921  1
287066  96.145  -72.961  51.898  1
287067  96.173  -72.926  51.874  1
287068  96.201  -72.894  51.852  1
287069  96.235  -72.898  51.830  1
287070  96.276  -72.927  51.809  1
287071  96.319  -72.966  51.787  1
287072  96.363  -73.005  51.764  1
287073  96.406  -73.044  51.741  1
287074  96.449  -73.083  51.719  1
287075  96.467  -73.132  51.696  1
287076  96.461  -73.148  51.673  1
287077  96.459  -73.137  51.649  1
287078  96.456  -73.126  51.623  1
287079  96.453  -73.116  51.596  1
287080  96.473  -73.094  51.567  1
287081  96.509  -73.077  51.537  1
287082  96.537  -73.084  51.509  1
287083  96.565  -73.091  51.480  1
287084  96.592  -73.098  51.451  1
287085  96.621  -73.103  51.421  1
287086  96.665  -73.092  51.392  1
287087  96.708  -73.079  51.364  1
287088  96.747  -73.070  51.334  1
287089  96.757  -73.082  51.304  1
287090  96.768  -73.103  51.277  1
287091  96.779  -73.124  51.251  1
287092  96.789  -73.145  51.225  1
287093  96.826  -73.147  51.200  1
287094  96.864  -73.148  51.177  1
287095  96.901  -73.148  51.154  1
287096  96.943  -73.153  51.132  1
287097  96.982  -73.160  51.110  1
287098  97.010  -73.165  51.087  1
287099  97.030  -73.168  51.066  1
287100  97.051  -73.171  51.047  1
287101  97.072  -73.174  51.030  1
287102  97.093  -73.180  51.013  1
287103  97.118  -73.203  50.998  1
287104  97.145  -73.227  50.983  1
287105  97.195  -73.229  50.968  1
287106  97.262  -73.236  50.952  1
287107  97.306  -73.227  50.931  1
287108  97.327  -73.210  50.910  1
287109  97.341  -73.199  50.888  1
287110  97.355  -73.187  50.866  1
287111  97.378  -73.175  50.844  1
287112  97.417  -73.162  50.820  1
287113  97.456  -73.150  50.794  1
287114  97.495  -73.137  50.766  1
287115  97.533  -73.125  50.731  1
287116  97.572  -73.112  50.694  1
287117  97.611  -73.099  50.655  1
287118  97.650  -73.093  50.610  1
287119  97.691  -73.109  50.560  1
287120  97.732  -73.126  50.510  1
287121  97.774  -73.142  50.459  1
287122  97.815  -73.158  50.409  1
287123  97.856  -73.174  50.357  1
287124  97.897  -73.191  50.306  1
287125  97.938  -73.207  50.255  1
287126  97.983  -73.219  50.207  1
287127  98.029  -73.230  50.160  1
287128  98.074  -73.242  50.113  1
287129  98.120  -73.252  50.064  1
287130  98.165  -73.264  50.011  1
287131  98.211  -73.275  49.954  1
287132  98.257  -73.286  49.896  1
287133  98.302  -73.298  49.838  1
287134  98.348  -73.309  49.781  1
287135  98.387  -73.324  49.724  1
287136  98.414  -73.347  49.667  1
287137  98.435  -73.374  49.608  1
287138  98.456  -73.400  49.548  1
287139  98.477  -73.427  49.490  1
287140  98.498  -73.453  49.435  1
287141  98.518  -73.480  49.380  1
287142  98.545  -73.504  49.326  1
287143  98.574  -73.528  49.271  1
287144  98.590  -73.559  49.216  1
287145  98.596  -73.590  49.162  1
287146  98.687  -73.528  49.107  1
287147  98.777  -73.465  49.053  1
287148  98.867  -73.402  48.999  1
287149  98.936  -73.359  48.947  1
287150  98.916  -73.404  48.895  1
287151  98.896  -73.449  48.843  1
287152  98.875  -73.494  48.793  1
287153  98.855  -73.539  48.744  1
287154  98.877  -73.578  48.695  1
287155  98.936  -73.591  48.646  1
287156  98.986  -73.603  48.596  1
287157  99.035  -73.615  48.548  1
287158  99.046  -73.638  48.500  1
287159  99.057  -73.665  48.452  1
287160  99.084  -73.687  48.404  1
287161  99.112  -73.711  48.355  1
287162  99.139  -73.734  48.306  1
287163  99.169  -73.757  48.256  1
287164  99.210  -73.774  48.208  1
287165  99.252  -73.790  48.160  1
287166  99.294  -73.806  48.112  1
287167  99.336  -73.822  48.065  1
287168  99.377  -73.838  48.020  1
287169  99.419  -73.854  47.975  1
287170  99.461  -73.870  47.931  1
287171  99.502  -73.886  47.888  1
287172  99.544  -73.903  47.845  1
287173  99.585  -73.915  47.803  1
287174  99.625  -73.921  47.761  1
287175  99.664  -73.926  47.719  1
287176  99.703  -73.932  47.678  1
287177  99.717  -73.951  47.638  1
287178  99.729  -73.970  47.597  1
287179  99.749  -73.982  47.557  1
287180  99.771  -73.989  47.518  1
287181  99.794  -73.996  47.479  1
287182  99.817  -74.003  47.440  1
287183  99.840  -74.010  47.402  1
287184  99.862  -74.017  47.364  1
287185  99.886  -74.025  47.328  1
287186  99.908  -74.032  47.292  1
287187  99.932  -74.036  47.256  1
287188  99.956  -74.041  47.220  1
287189  99.981  -74.045  47.185  1
287190  100.005  -74.049  47.150  1
287191  100.029  -74.054  47.115  1
287192  100.053  -74.057  47.082  1
287193  100.077  -74.062  47.048  1
287194  100.102  -74.066  47.015  1
287195  100.126  -74.070  46.981  1
287196  100.153  -74.075  46.949  1
287197  100.185  -74.082  46.919  1
287198  100.217  -74.089  46.889  1
287199  100.249  -74.095  46.859  1
287200  100.280  -74.100  46.826  1
287201  100.311  -74.104  46.793  1
287202  100.342  -74.107  46.761  1
287203  100.372  -74.111  46.729  1
287204  100.403  -74.114  46.701  1
287205  100.434  -74.118  46.670  1
287206  100.465  -74.121  46.637  1
287207  100.495  -74.125  46.602  1
287208  100.526  -74.129  46.567  1
287209  100.557  -74.132  46.533  1
287210  100.587  -74.136  46.501  1
287211  100.618  -74.139  46.470  1
287212  100.649  -74.143  46.441  1
287213  100.680  -74.146  46.408  1
287214  100.709  -74.149  46.377  1
287215  100.738  -74.151  46.346  1
287216  100.766  -74.152  46.316  1
287217  100.794  -74.160  46.286  1
287218  100.824  -74.176  46.255  1
287219  100.853  -74.192  46.223  1
287220  100.882  -74.209  46.190  1
287221  100.911  -74.226  46.155  1
287222  100.944  -74.247  46.120  1
287223  100.982  -74.274  46.085  1
287224  101.019  -74.302  46.051  1
287225  101.057  -74.330  46.016  1
287226  101.095  -74.358  45.981  1
287227  101.133  -74.386  45.947  1
287228  101.171  -74.414  45.911  1
287229  101.209  -74.441  45.877  1
287230  101.238  -74.460  45.843  1
287231  101.265  -74.476  45.810  1
287232  101.292  -74.492  45.776  1
287233  101.319  -74.508  45.744  1
287234  101.346  -74.524  45.712  1
287235  101.373  -74.548  45.679  1
287236  101.399  -74.583  45.646  1
287237  101.426  -74.617  45.616  1
287238  101.454  -74.652  45.585  1
287239  101.556  -74.692  45.554  1
287240  101.616  -74.718  45.523  1
287241  101.661  -74.740  45.491  1
287242  101.706  -74.762  45.459  1
287243  101.751  -74.784  45.429  1
287244  101.785  -74.786  45.398  1
287245  101.814  -74.781  45.368  1
287246  101.843  -74.777  45.338  1
287247  101.873  -74.772  45.308  1
287248  101.902  -74.767  45.278  1
287249  101.931  -74.762  45.247  1
287250  101.960  -74.757  45.218  1
287251  101.989  -74.752  45.189  1
287252  101.985  -74.709  45.160  1
287253  102.003  -74.710  45.131  1
287254  102.020  -74.711  45.101  1
287255  102.037  -74.711  45.072  1
287256  102.055  -74.712  45.043  1
287257  102.073  -74.712  45.014  1
287258  102.090  -74.713  44.985  1
287259  102.107  -74.713  44.956  1
287260  102.125  -74.714  44.927  1
287261  102.142  -74.715  44.898  1
287729  95.070  -72.873  52.671  1
287730  95.077  -72.872  52.648  1
287731  95.094  -72.875  52.626  1
287732  95.114  -72.879  52.603  1
287733  95.135  -72.883  52.582  1
287734  95.155  -72.888  52.561  1
287735  95.176  -72.892  52.539  1
287736  95.196  -72.897  52.517  1
287737  95.217  -72.901  52.494  1
287738  95.237  -72.905  52.471  1
287739  95.258  -72.910  52.449  1
287740  95.278  -72.914  52.425  1
287741  95.299  -72.919  52.399  1
287742  95.320  -72.923  52.375  1
287743  95.340  -72.927  52.351  1
287744  95.369  -72.935  52.326  1
287745  95.426  -72.952  52.303  1
287746  95.469  -72.955  52.281  1
287747  95.509  -72.954  52.260  1
287748  95.548  -72.953  52.240  1
287749  95.587  -72.952  52.221  1
287750  95.624  -72.948  52.203  1
287751  95.648  -72.926  52.185  1
287752  95.679  -72.921  52.168  1
287753  95.719  -72.931  52.153  1
287754  95.758  -72.941  52.136  1
287755  95.797  -72.951  52.122  1
287756  95.836  -72.961  52.107  1
287757  95.875  -72.972  52.093  1
287758  95.914  -72.982  52.078  1
287759  95.953  -72.992  52.064  1
287760  95.977  -73.004  52.048  1
287761  95.996  -73.018  52.031  1
287762  96.015  -73.032  52.013  1
287763  96.033  -73.045  51.992  1
287764  96.052  -73.059  51.970  1
287765  96.078  -73.032  51.948  1
287766  96.106  -72.996  51.927  1
287767  96.133  -72.960  51.905  1
287768  96.161  -72.924  51.882  1
287769  96.189  -72.890  51.859  1
287770  96.223  -72.894  51.839  1
287771  96.257  -72.897  51.819  1
287772  96.297  -72.923  51.798  1
287773  96.340  -72.962  51.776  1
287774  96.384  -73.001  51.754  1
287775  96.428  -73.040  51.732  1
287776  96.457  -73.085  51.710  1
287777  96.451  -73.106  51.689  1
287778  96.448  -73.095  51.667  1
287779  96.446  -73.085  51.640  1
287780  96.448  -73.072  51.612  1
287781  96.486  -73.047  51.582  1
287782  96.514  -73.054  51.551  1
287783  96.542  -73.061  51.523  1
287784  96.570  -73.067  51.494  1
287785  96.597  -73.074  51.465  1
287786  96.625  -73.081  51.437  1
287787  96.663  -73.076  51.408  1
287788  96.706  -73.064  51.379  1
287789  96.745  -73.054  51.349  1
287790  96.756  -73.058  51.319  1
287791  96.766  -73.068  51.291  1
287792  96.777  -73.089  51.264  1
287793  96.788  -73.111  51.239  1
287794  96.822  -73.114  51.214  1
287795  96.860  -73.115  51.190  1
287796  96.901  -73.119  51.167  1
287797  96.945  -73.125  51.144  1
287798  96.986  -73.132  51.122  1
287799  97.016  -73.139  51.098  1
287800  97.045  -73.145  51.077  1
287801  97.066  -73.148  51.058  1
287802  97.086  -73.151  51.039  1
287803  97.106  -73.154  51.022  1
287804  97.133  -73.177  51.006  1
287805  97.162  -73.196  50.989  1
287806  97.221  -73.192  50.973  1
287807  97.282  -73.192  50.957  1
287808  97.314  -73.177  50.936  1
287809  97.341  -73.156  50.914  1
287810  97.363  -73.139  50.891  1
287811  97.377  -73.127  50.867  1
287812  97.391  -73.115  50.840  1
287813  97.427  -73.103  50.812  1
287814  97.465  -73.090  50.782  1
287815  97.505  -73.078  50.749  1
287816  97.543  -73.065  50.712  1
287817  97.582  -73.053  50.673  1
287818  97.621  -73.043  50.632  1
287819  97.662  -73.060  50.585  1
287820  97.703  -73.076  50.534  1
287821  97.744  -73.092  50.483  1
287822  97.786  -73.108  50.433  1
287823  97.826  -73.125  50.383  1
287824  97.868  -73.141  50.332  1
287825  97.909  -73.157  50.280  1
287826  97.950  -73.174  50.229  1
287827  97.995  -73.185  50.181  1
287828  98.041  -73.196  50.135  1
287829  98.086  -73.208  50.087  1
287830  98.132  -73.219  50.038  1
287831  98.177  -73.230  49.986  1
287832  98.223  -73.242  49.931  1
287833  98.269  -73.252  49.875  1
287834  98.314  -73.264  49.819  1
287835  98.358  -73.268  49.763  1
287836  98.393  -73.287  49.707  1
287837  98.421  -73.311  49.652  1
287838  98.448  -73.335  49.594  1
287839  98.475  -73.359  49.536  1
287840  98.503  -73.383  49.479  1
287841  98.530  -73.406  49.423  1
287842  98.557  -73.430  49.368  1
287843  98.584  -73.454  49.314  1
287844  98.570  -73.507  49.260  1
287845  98.565  -73.549  49.207  1
287846  98.652  -73.489  49.153  1
287847  98.726  -73.441  49.100  1
287848  98.799  -73.393  49.046  1
287849  98.873  -73.346  48.994  1
287850  98.902  -73.336  48.942  1
287851  98.889  -73.363  48.892  1
287852  98.870  -73.405  48.840  1
287853  98.850  -73.450  48.790  1
287854  98.829  -73.496  48.741  1
287855  98.873  -73.524  48.691  1
287856  98.923  -73.536  48.641  1
287857  98.972  -73.548  48.591  1
287858  99.022  -73.560  48.542  1
287859  99.071  -73.573  48.494  1
287860  99.068  -73.600  48.446  1
287861  99.095  -73.624  48.398  1
287862  99.123  -73.647  48.349  1
287863  99.150  -73.670  48.300  1
287864  99.176  -73.706  48.252  1
287865  99.207  -73.737  48.204  1
287866  99.249  -73.753  48.156  1
287867  99.290  -73.769  48.108  1
287868  99.332  -73.785  48.062  1
287869  99.373  -73.801  48.017  1
287870  99.415  -73.818  47.972  1
287871  99.457  -73.834  47.928  1
287872  99.499  -73.850  47.885  1
287873  99.541  -73.866  47.843  1
287874  99.582  -73.880  47.801  1
287875  99.621  -73.885  47.758  1
287876  99.660  -73.891  47.716  1
287877  99.700  -73.897  47.675  1
287878  99.739  -73.902  47.634  1
287879  99.762  -73.916  47.594  1
287880  99.774  -73.936  47.553  1
287881  99.786  -73.956  47.513  1
287882  99.804  -73.969  47.473  1
287883  99.827  -73.976  47.434  1
287884  99.850  -73.983  47.396  1
287885  99.872  -73.990  47.357  1
287886  99.895  -73.998  47.320  1
287887  99.918  -74.004  47.283  1
287888  99.941  -74.010  47.247  1
287889  99.966  -74.014  47.211  1
287890  99.990  -74.019  47.174  1
287891  100.014  -74.023  47.139  1
287892  100.039  -74.027  47.105  1
287893  100.063  -74.031  47.072  1
287894  100.087  -74.035  47.038  1
287895  100.113  -74.040  47.004  1
287896  100.145  -74.047  46.971  1
287897  100.177  -74.053  46.938  1
287898  100.209  -74.060  46.909  1
287899  100.241  -74.067  46.879  1
287900  100.273  -74.073  46.849  1
287901  100.304  -74.079  46.817  1
287902  100.335  -74.082  46.783  1
287903  100.366  -74.085  46.750  1
287904  100.397  -74.089  46.718  1
287905  100.427  -74.093  46.689  1
287906  100.458  -74.097  46.659  1
287907  100.488  -74.100  46.625  1
287908  100.519  -74.104  46.589  1
287909  100.550  -74.107  46.555  1
287910  100.580  -74.111  46.521  1
287911  100.611  -74.114  46.489  1
287912  100.642  -74.118  46.458  1
287913  100.671  -74.120  46.428  1
287914  100.700  -74.122  46.397  1
287915  100.728  -74.123  46.365  1
287916  100.757  -74.125  46.333  1
287917  100.785  -74.126  46.302  1
287918  100.814  -74.136  46.272  1
287919  100.843  -74.153  46.240  1
287920  100.873  -74.169  46.207  1
287921  100.901  -74.186  46.174  1
287922  100.930  -74.202  46.140  1
287923  100.960  -74.219  46.104  1
287924  100.989  -74.235  46.070  1
287925  101.018  -74.252  46.036  1
287926  101.051  -74.273  46.001  1
287927  101.090  -74.302  45.966  1
287928  101.127  -74.330  45.931  1
287929  101.165  -74.357  45.896  1
287930  101.203  -74.385  45.862  1
287931  101.241  -74.413  45.829  1
287932  101.271  -74.432  45.796  1
287933  101.298  -74.449  45.763  1
287934  101.325  -74.465  45.732  1
287935  101.351  -74.480  45.699  1
287936  101.378  -74.508  45.666  1
287937  101.405  -74.543  45.634  1
287938  101.435  -74.577  45.604  1
287939  101.533  -74.616  45.573  1
287940  101.578  -74.638  45.542  1
287941  101.623  -74.660  45.511  1
287942  101.669  -74.682  45.479  1
287943  101.714  -74.704  45.448  1
287944  101.759  -74.726  45.417  1
287945  101.804  -74.747  45.387  1
287946  101.833  -74.743  45.357  1
287947  101.863  -74.737  45.327  1
287948  101.892  -74.733  45.297  1
287949  101.921  -74.728  45.267  1
287950  101.950  -74.723  45.236  1
287951  101.979  -74.718  45.206  1
287952  102.007  -74.712  45.177  1
287953  102.000  -74.670  45.149  1
287954  102.018  -74.671  45.120  1
287955  102.035  -74.671  45.090  1
287956  102.052  -74.671  45.060  1
287957  102.070  -74.672  45.031  1
287958  102.087  -74.672  45.001  1
287959  102.105  -74.673  44.973  1
287960  102.122  -74.674  44.945  1
287961  102.139  -74.675  44.915  1
287962  102.162  -74.675  44.885  1
288430  95.071  -72.837  52.665  1
288431  95.089  -72.841  52.643  1
288432  95.097  -72.840  52.620  1
288433  95.117  -72.844  52.598  1
288434  95.138  -72.848  52.577  1
288435  95.158  -72.853  52.556  1
288436  95.179  -72.857  52.535  1
288437  95.199  -72.862  52.513  1
288438  95.220  -72.866  52.491  1
288439  95.240  -72.870  52.467  1
288440  95.261  -72.875  52.445  1
288441  95.281  -72.879  52.421  1
288442  95.302  -72.884  52.396  1
288443  95.323  -72.888  52.372  1
288444  95.343  -72.892  52.347  1
288445  95.374  -72.901  52.323  1
288446  95.430  -72.918  52.300  1
288447  95.488  -72.935  52.278  1
288448  95.529  -72.936  52.256  1
288449  95.568  -72.935  52.235  1
288450  95.607  -72.934  52.217  1
288451  95.639  -72.923  52.197  1
288452  95.663  -72.901  52.180  1
288453  95.688  -72.884  52.163  1
288454  95.728  -72.894  52.146  1
288455  95.766  -72.904  52.130  1
288456  95.806  -72.914  52.116  1
288457  95.845  -72.924  52.101  1
288458  95.884  -72.935  52.086  1
288459  95.923  -72.945  52.071  1
288460  95.953  -72.957  52.056  1
288461  95.972  -72.970  52.042  1
288462  95.990  -72.983  52.027  1
288463  96.009  -72.997  52.011  1
288464  96.028  -73.011  51.993  1
288465  96.047  -73.024  51.974  1
288466  96.067  -73.031  51.953  1
288467  96.095  -72.995  51.932  1
288468  96.122  -72.959  51.910  1
288469  96.150  -72.923  51.887  1
288470  96.177  -72.888  51.865  1
288471  96.212  -72.890  51.846  1
288472  96.246  -72.893  51.827  1
288473  96.279  -72.897  51.807  1
288474  96.319  -72.920  51.787  1
288475  96.362  -72.958  51.765  1
288476  96.405  -72.998  51.745  1
288477  96.447  -73.037  51.726  1
288478  96.441  -73.064  51.706  1
288479  96.438  -73.054  51.685  1
288480  96.435  -73.043  51.658  1
288481  96.464  -73.017  51.629  1
288482  96.491  -73.023  51.599  1
288483  96.519  -73.029  51.567  1
288484  96.547  -73.037  51.537  1
288485  96.575  -73.044  51.509  1
288486  96.602  -73.051  51.481  1
288487  96.630  -73.058  51.454  1
288488  96.661  -73.061  51.425  1
288489  96.704  -73.049  51.396  1
288490  96.743  -73.039  51.365  1
288491  96.754  -73.043  51.334  1
288492  96.765  -73.047  51.306  1
288493  96.776  -73.054  51.279  1
288494  96.787  -73.076  51.253  1
288495  96.818  -73.081  51.228  1
288496  96.858  -73.084  51.204  1
288497  96.902  -73.091  51.180  1
288498  96.946  -73.098  51.157  1
288499  96.990  -73.105  51.133  1
288500  97.020  -73.111  51.109  1
288501  97.050  -73.118  51.088  1
288502  97.080  -73.124  51.067  1
288503  97.100  -73.127  51.047  1
288504  97.121  -73.130  51.030  1
288505  97.146  -73.149  51.013  1
288506  97.187  -73.160  50.995  1
288507  97.245  -73.156  50.978  1
288508  97.291  -73.145  50.962  1
288509  97.322  -73.126  50.941  1
288510  97.349  -73.105  50.919  1
288511  97.375  -73.086  50.895  1
288512  97.399  -73.067  50.870  1
288513  97.413  -73.055  50.839  1
288514  97.437  -73.044  50.805  1
288515  97.475  -73.031  50.770  1
288516  97.514  -73.018  50.732  1
288517  97.553  -73.006  50.693  1
288518  97.592  -72.993  50.653  1
288519  97.633  -73.010  50.609  1
288520  97.674  -73.026  50.561  1
288521  97.715  -73.042  50.508  1
288522  97.756  -73.058  50.456  1
288523  97.797  -73.075  50.406  1
288524  97.839  -73.091  50.356  1
288525  97.880  -73.108  50.307  1
288526  97.921  -73.123  50.256  1
288527  97.962  -73.140  50.205  1
288528  98.007  -73.152  50.156  1
288529  98.053  -73.163  50.110  1
288530  98.098  -73.174  50.061  1
288531  98.144  -73.185  50.012  1
288532  98.190  -73.196  49.961  1
288533  98.235  -73.208  49.909  1
288534  98.281  -73.219  49.855  1
288535  98.324  -73.221  49.800  1
288536  98.367  -73.224  49.744  1
288537  98.400  -73.248  49.690  1
288538  98.427  -73.276  49.636  1
288539  98.454  -73.300  49.582  1
288540  98.481  -73.324  49.526  1
288541  98.508  -73.347  49.470  1
288542  98.536  -73.371  49.413  1
288543  98.563  -73.395  49.359  1
288544  98.585  -73.418  49.305  1
288545  98.571  -73.477  49.252  1
288546  98.573  -73.491  49.199  1
288547  98.646  -73.443  49.145  1
288548  98.720  -73.396  49.092  1
288549  98.793  -73.348  49.039  1
288550  98.867  -73.300  48.987  1
288551  98.866  -73.317  48.937  1
288552  98.854  -73.343  48.887  1
288553  98.841  -73.369  48.837  1
288554  98.824  -73.407  48.788  1
288555  98.803  -73.452  48.738  1
288556  98.859  -73.468  48.687  1
288557  98.909  -73.481  48.635  1
288558  98.958  -73.493  48.585  1
288559  99.008  -73.506  48.536  1
288560  99.058  -73.518  48.488  1
288561  99.098  -73.532  48.440  1
288562  99.106  -73.559  48.391  1
288563  99.134  -73.583  48.342  1
288564  99.161  -73.610  48.295  1
288565  99.186  -73.650  48.247  1
288566  99.211  -73.690  48.199  1
288567  99.244  -73.716  48.152  1
288568  99.286  -73.732  48.105  1
288569  99.328  -73.749  48.060  1
288570  99.370  -73.765  48.014  1
288571  99.412  -73.781  47.970  1
288572  99.453  -73.797  47.926  1
288573  99.495  -73.813  47.883  1
288574  99.537  -73.829  47.840  1
288575  99.578  -73.845  47.798  1
288576  99.618  -73.850  47.755  1
288577  99.657  -73.857  47.713  1
288578  99.696  -73.862  47.671  1
288579  99.736  -73.867  47.630  1
288580  99.775  -73.872  47.589  1
288581  99.806  -73.882  47.549  1
288582  99.819  -73.902  47.508  1
288583  99.831  -73.922  47.468  1
288584  99.843  -73.941  47.428  1
288585  99.860  -73.956  47.388  1
288586  99.883  -73.963  47.349  1
288587  99.905  -73.970  47.311  1
288588  99.928  -73.977  47.274  1
288589  99.951  -73.984  47.238  1
288590  99.975  -73.988  47.201  1
288591  99.999  -73.992  47.164  1
288592  100.024  -73.997  47.129  1
288593  100.048  -74.001  47.095  1
288594  100.072  -74.005  47.061  1
288595  100.104  -74.011  47.027  1
288596  100.136  -74.018  46.994  1
288597  100.168  -74.025  46.961  1
288598  100.200  -74.031  46.927  1
288599  100.232  -74.038  46.898  1
288600  100.264  -74.045  46.868  1
288601  100.296  -74.051  46.838  1
288602  100.328  -74.057  46.807  1
288603  100.359  -74.061  46.773  1
288604  100.390  -74.064  46.740  1
288605  100.420  -74.068  46.708  1
288606  100.451  -74.072  46.678  1
288607  100.482  -74.076  46.646  1
288608  100.512  -74.079  46.612  1
288609  100.543  -74.082  46.577  1
288610  100.574  -74.086  46.543  1
288611  100.605  -74.090  46.509  1
288612  100.634  -74.092  46.477  1
288613  100.662  -74.094  46.446  1
288614  100.691  -74.095  46.415  1
288615  100.719  -74.097  46.385  1
288616  100.748  -74.098  46.353  1
288617  100.776  -74.100  46.321  1
288618  100.805  -74.101  46.289  1
288619  100.833  -74.113  46.258  1
288620  100.862  -74.129  46.226  1
288621  100.892  -74.145  46.192  1
288622  100.921  -74.162  46.157  1
288623  100.950  -74.179  46.123  1
288624  100.979  -74.195  46.089  1
288625  101.008  -74.211  46.054  1
288626  101.037  -74.228  46.020  1
288627  101.066  -74.245  45.985  1
288628  101.096  -74.261  45.950  1
288629  101.125  -74.277  45.916  1
288630  101.159  -74.301  45.882  1
288631  101.197  -74.329  45.847  1
288632  101.235  -74.357  45.814  1
288633  101.273  -74.384  45.782  1
288634  101.304  -74.405  45.751  1
288635  101.330  -74.421  45.719  1
288636  101.357  -74.437  45.686  1
288637  101.384  -74.468  45.653  1
288638  101.417  -74.504  45.622  1
288639  101.495  -74.536  45.592  1
288640  101.540  -74.558  45.561  1
288641  101.586  -74.580  45.530  1
288642  101.631  -74.602  45.499  1
288643  101.676  -74.624  45.467  1
288644  101.722  -74.646  45.436  1
288645  101.766  -74.668  45.405  1
288646  101.812  -74.690  45.375  1
288647  101.852  -74.703  45.345  1
288648  101.882  -74.699  45.315  1
288649  101.911  -74.693  45.285  1
288650  101.940  -74.689  45.255  1
288651  101.969  -74.684  45.224  1
288652  101.998  -74.679  45.195  1
288653  102.015  -74.660  45.166  1
288654  102.015  -74.631  45.137  1
288655  102.032  -74.631  45.108  1
288656  102.050  -74.631  45.078  1
288657  102.067  -74.632  45.049  1
288658  102.085  -74.632  45.019  1
288659  102.102  -74.633  44.990  1
288660  102.120  -74.634  44.961  1
288661  102.137  -74.634  44.932  1
288662  102.159  -74.635  44.903  1
289131  95.070  -72.800  52.660  1
289132  95.096  -72.807  52.637  1
289133  95.106  -72.807  52.615  1
289134  95.120  -72.810  52.593  1
289135  95.141  -72.813  52.573  1
289136  95.161  -72.818  52.551  1
289137  95.182  -72.823  52.530  1
289138  95.202  -72.827  52.509  1
289139  95.223  -72.832  52.487  1
289140  95.244  -72.835  52.464  1
289141  95.264  -72.840  52.442  1
289142  95.284  -72.844  52.418  1
289143  95.305  -72.849  52.394  1
289144  95.326  -72.854  52.369  1
289145  95.346  -72.857  52.344  1
289146  95.378  -72.866  52.320  1
289147  95.435  -72.884  52.296  1
289148  95.492  -72.901  52.275  1
289149  95.549  -72.918  52.252  1
289150  95.589  -72.917  52.232  1
289151  95.628  -72.916  52.212  1
289152  95.654  -72.898  52.193  1
289153  95.678  -72.876  52.174  1
289154  95.701  -72.855  52.157  1
289155  95.737  -72.857  52.141  1
289156  95.775  -72.866  52.124  1
289157  95.815  -72.877  52.109  1
289158  95.854  -72.887  52.094  1
289159  95.893  -72.898  52.079  1
289160  95.928  -72.908  52.064  1
289161  95.948  -72.922  52.050  1
289162  95.966  -72.935  52.037  1
289163  95.985  -72.949  52.025  1
289164  96.004  -72.963  52.011  1
289165  96.023  -72.976  51.994  1
289166  96.041  -72.990  51.975  1
289167  96.060  -73.004  51.954  1
289168  96.083  -72.994  51.933  1
289169  96.111  -72.958  51.912  1
289170  96.138  -72.922  51.891  1
289171  96.166  -72.886  51.870  1
289172  96.199  -72.886  51.851  1
289173  96.234  -72.890  51.833  1
289174  96.268  -72.893  51.815  1
289175  96.302  -72.897  51.796  1
289176  96.340  -72.915  51.778  1
289177  96.383  -72.954  51.762  1
289178  96.427  -72.993  51.747  1
289179  96.430  -73.023  51.729  1
289180  96.427  -73.012  51.708  1
289181  96.438  -72.995  51.679  1
289182  96.469  -72.992  51.649  1
289183  96.497  -72.999  51.618  1
289184  96.525  -73.006  51.586  1
289185  96.552  -73.013  51.555  1
289186  96.580  -73.020  51.526  1
289187  96.608  -73.026  51.499  1
289188  96.636  -73.034  51.471  1
289189  96.663  -73.041  51.443  1
289190  96.702  -73.034  51.413  1
289191  96.741  -73.024  51.382  1
289192  96.752  -73.028  51.351  1
289193  96.763  -73.032  51.323  1
289194  96.774  -73.036  51.296  1
289195  96.785  -73.042  51.271  1
289196  96.816  -73.050  51.246  1
289197  96.860  -73.057  51.220  1
289198  96.903  -73.064  51.195  1
289199  96.947  -73.070  51.170  1
289200  96.991  -73.077  51.145  1
289201  97.024  -73.084  51.121  1
289202  97.054  -73.091  51.097  1
289203  97.085  -73.097  51.075  1
289204  97.115  -73.104  51.053  1
289205  97.136  -73.107  51.035  1
289206  97.160  -73.123  51.017  1
289207  97.212  -73.123  51.000  1
289208  97.254  -73.111  50.984  1
289209  97.287  -73.092  50.967  1
289210  97.320  -73.073  50.946  1
289211  97.353  -73.054  50.924  1
289212  97.384  -73.035  50.900  1
289213  97.410  -73.014  50.873  1
289214  97.435  -72.995  50.838  1
289215  97.449  -72.984  50.800  1
289216  97.485  -72.972  50.759  1
289217  97.524  -72.959  50.716  1
289218  97.563  -72.946  50.675  1
289219  97.604  -72.960  50.634  1
289220  97.645  -72.976  50.589  1
289221  97.686  -72.992  50.539  1
289222  97.727  -73.009  50.486  1
289223  97.768  -73.025  50.434  1
289224  97.809  -73.042  50.382  1
289225  97.851  -73.058  50.331  1
289226  97.891  -73.074  50.282  1
289227  97.933  -73.090  50.231  1
289228  97.973  -73.107  50.182  1
289229  98.019  -73.118  50.137  1
289230  98.065  -73.129  50.089  1
289231  98.110  -73.140  50.038  1
289232  98.156  -73.152  49.988  1
289233  98.202  -73.163  49.940  1
289234  98.247  -73.171  49.889  1
289235  98.290  -73.174  49.837  1
289236  98.333  -73.177  49.783  1
289237  98.376  -73.180  49.728  1
289238  98.406  -73.208  49.674  1
289239  98.432  -73.240  49.620  1
289240  98.460  -73.264  49.566  1
289241  98.487  -73.288  49.512  1
289242  98.514  -73.311  49.457  1
289243  98.541  -73.336  49.403  1
289244  98.569  -73.359  49.350  1
289245  98.584  -73.385  49.298  1
289246  98.577  -73.444  49.246  1
289247  98.566  -73.446  49.191  1
289248  98.640  -73.398  49.138  1
289249  98.713  -73.350  49.085  1
289250  98.787  -73.302  49.033  1
289251  98.843  -73.270  48.982  1
289252  98.830  -73.296  48.932  1
289253  98.818  -73.323  48.882  1
289254  98.805  -73.349  48.833  1
289255  98.793  -73.375  48.783  1
289256  98.796  -73.401  48.733  1
289257  98.846  -73.413  48.682  1
289258  98.896  -73.425  48.630  1
289259  98.945  -73.437  48.581  1
289260  98.994  -73.450  48.533  1
289261  99.044  -73.462  48.484  1
289262  99.093  -73.474  48.436  1
289263  99.118  -73.495  48.388  1
289264  99.145  -73.518  48.340  1
289265  99.170  -73.555  48.292  1
289266  99.196  -73.594  48.244  1
289267  99.220  -73.634  48.197  1
289268  99.245  -73.674  48.149  1
289269  99.283  -73.696  48.103  1
289270  99.324  -73.712  48.058  1
289271  99.366  -73.728  48.012  1
289272  99.408  -73.744  47.967  1
289273  99.449  -73.760  47.923  1
289274  99.491  -73.776  47.880  1
289275  99.533  -73.793  47.837  1
289276  99.574  -73.809  47.794  1
289277  99.614  -73.816  47.752  1
289278  99.653  -73.821  47.709  1
289279  99.693  -73.827  47.667  1
289280  99.732  -73.832  47.625  1
289281  99.772  -73.838  47.584  1
289282  99.811  -73.843  47.543  1
289283  99.851  -73.849  47.502  1
289284  99.863  -73.868  47.461  1
289285  99.875  -73.888  47.421  1
289286  99.888  -73.908  47.380  1
289287  99.899  -73.928  47.341  1
289288  99.915  -73.943  47.303  1
289289  99.938  -73.950  47.265  1
289290  99.961  -73.957  47.228  1
289291  99.985  -73.962  47.191  1
289292  100.009  -73.966  47.153  1
289293  100.033  -73.970  47.118  1
289294  100.064  -73.976  47.084  1
289295  100.096  -73.983  47.050  1
289296  100.128  -73.989  47.016  1
289297  100.159  -73.996  46.983  1
289298  100.192  -74.003  46.950  1
289299  100.223  -74.009  46.916  1
289300  100.256  -74.016  46.887  1
289301  100.287  -74.022  46.857  1
289302  100.320  -74.029  46.827  1
289303  100.352  -74.035  46.795  1
289304  100.382  -74.040  46.762  1
289305  100.413  -74.043  46.729  1
289306  100.444  -74.047  46.697  1
289307  100.475  -74.051  46.666  1
289308  100.505  -74.054  46.633  1
289309  100.536  -74.057  46.599  1
289310  100.567  -74.061  46.564  1
289311  100.596  -74.064  46.530  1
289312  100.624  -74.065  46.497  1
289313  100.653  -74.067  46.465  1
289314  100.682  -74.068  46.434  1
289315  100.710  -74.070  46.402  1
289316  100.739  -74.071  46.372  1
289317  100.767  -74.073  46.341  1
289318  100.795  -74.074  46.310  1
289319  100.824  -74.076  46.277  1
289320  100.853  -74.089  46.244  1
289321  100.882  -74.106  46.211  1
289322  100.911  -74.122  46.176  1
289323  100.940  -74.139  46.142  1
289324  100.969  -74.155  46.107  1
289325  100.998  -74.172  46.072  1
289326  101.028  -74.188  46.038  1
289327  101.057  -74.205  46.004  1
289328  101.086  -74.221  45.969  1
289329  101.115  -74.238  45.936  1
289330  101.144  -74.254  45.902  1
289331  101.173  -74.270  45.867  1
289332  101.202  -74.287  45.833  1
289333  101.232  -74.304  45.800  1
289334  101.267  -74.328  45.768  1
289335  101.305  -74.356  45.736  1
289336  101.336  -74.377  45.704  1
289337  101.363  -74.394  45.672  1
289338  101.398  -74.430  45.640  1
289339  101.458  -74.456  45.609  1
289340  101.502  -74.477  45.578  1
289341  101.548  -74.499  45.547  1
289342  101.593  -74.521  45.516  1
289343  101.638  -74.543  45.486  1
289344  101.684  -74.565  45.454  1
289345  101.729  -74.587  45.423  1
289346  101.774  -74.609  45.393  1
289347  101.819  -74.631  45.363  1
289348  101.865  -74.653  45.333  1
289349  101.900  -74.659  45.303  1
289350  101.929  -74.655  45.273  1
289351  101.959  -74.650  45.243  1
289352  101.988  -74.645  45.212  1
289353  102.017  -74.640  45.183  1
289354  102.023  -74.608  45.154  1
289355  102.030  -74.590  45.125  1
289356  102.047  -74.591  45.095  1
289357  102.065  -74.592  45.066  1
289358  102.083  -74.592  45.037  1
289359  102.100  -74.593  45.007  1
289360  102.117  -74.593  44.978  1
289361  102.135  -74.593  44.948  1
289362  102.157  -74.595  44.920  1
289363  102.179  -74.596  44.890  1
289832  95.069  -72.763  52.655  1
289833  95.095  -72.770  52.632  1
289834  95.117  -72.776  52.611  1
289835  95.124  -72.775  52.589  1
289836  95.144  -72.779  52.568  1
289837  95.165  -72.783  52.547  1
289838  95.185  -72.788  52.526  1
289839  95.205  -72.792  52.505  1
289840  95.226  -72.797  52.483  1
289841  95.247  -72.801  52.461  1
289842  95.267  -72.805  52.439  1
289843  95.287  -72.810  52.416  1
289844  95.308  -72.814  52.391  1
289845  95.329  -72.819  52.367  1
289846  95.349  -72.823  52.342  1
289847  95.382  -72.832  52.317  1
289848  95.440  -72.849  52.293  1
289849  95.496  -72.866  52.272  1
289850  95.554  -72.885  52.250  1
289851  95.609  -72.899  52.228  1
289852  95.644  -72.894  52.207  1
289853  95.668  -72.873  52.188  1
289854  95.692  -72.851  52.169  1
289855  95.716  -72.829  52.152  1
289856  95.746  -72.819  52.135  1
289857  95.784  -72.829  52.118  1
289858  95.824  -72.840  52.102  1
289859  95.863  -72.850  52.087  1
289860  95.902  -72.860  52.072  1
289861  95.923  -72.873  52.058  1
289862  95.942  -72.887  52.044  1
289863  95.961  -72.901  52.032  1
289864  95.980  -72.914  52.020  1
289865  95.999  -72.928  52.008  1
289866  96.017  -72.942  51.992  1
289867  96.036  -72.955  51.974  1
289868  96.055  -72.969  51.954  1
289869  96.074  -72.982  51.933  1
289870  96.099  -72.957  51.913  1
289871  96.127  -72.921  51.893  1
289872  96.155  -72.885  51.874  1
289873  96.188  -72.882  51.856  1
289874  96.222  -72.886  51.839  1
289875  96.256  -72.889  51.823  1
289876  96.290  -72.893  51.807  1
289877  96.324  -72.897  51.792  1
289878  96.361  -72.911  51.780  1
289879  96.404  -72.951  51.767  1
289880  96.419  -72.982  51.751  1
289881  96.417  -72.971  51.729  1
289882  96.447  -72.961  51.701  1
289883  96.474  -72.968  51.670  1
289884  96.502  -72.976  51.637  1
289885  96.530  -72.982  51.604  1
289886  96.557  -72.989  51.573  1
289887  96.585  -72.996  51.545  1
289888  96.613  -73.003  51.517  1
289889  96.641  -73.010  51.490  1
289890  96.668  -73.017  51.461  1
289891  96.699  -73.019  51.431  1
289892  96.740  -73.009  51.400  1
289893  96.751  -73.013  51.369  1
289894  96.761  -73.017  51.342  1
289895  96.772  -73.020  51.316  1
289896  96.793  -73.023  51.291  1
289897  96.824  -73.024  51.266  1
289898  96.861  -73.029  51.239  1
289899  96.905  -73.036  51.212  1
289900  96.949  -73.043  51.186  1
289901  96.993  -73.050  51.160  1
289902  97.027  -73.057  51.133  1
289903  97.058  -73.063  51.108  1
289904  97.089  -73.070  51.084  1
289905  97.119  -73.076  51.061  1
289906  97.150  -73.083  51.041  1
289907  97.178  -73.091  51.023  1
289908  97.218  -73.076  51.005  1
289909  97.250  -73.057  50.988  1
289910  97.283  -73.038  50.971  1
289911  97.316  -73.019  50.950  1
289912  97.349  -73.001  50.928  1
289913  97.381  -72.982  50.903  1
289914  97.414  -72.963  50.874  1
289915  97.445  -72.943  50.837  1
289916  97.471  -72.924  50.796  1
289917  97.495  -72.912  50.753  1
289918  97.534  -72.900  50.707  1
289919  97.575  -72.910  50.662  1
289920  97.615  -72.926  50.616  1
289921  97.657  -72.943  50.569  1
289922  97.698  -72.959  50.519  1
289923  97.739  -72.976  50.467  1
289924  97.780  -72.992  50.415  1
289925  97.821  -73.008  50.363  1
289926  97.862  -73.024  50.311  1
289927  97.903  -73.040  50.261  1
289928  97.944  -73.057  50.210  1
289929  97.986  -73.073  50.162  1
289930  98.031  -73.084  50.116  1
289931  98.077  -73.095  50.068  1
289932  98.123  -73.107  50.017  1
289933  98.168  -73.118  49.967  1
289934  98.212  -73.124  49.920  1
289935  98.255  -73.127  49.872  1
289936  98.298  -73.130  49.821  1
289937  98.342  -73.133  49.769  1
289938  98.384  -73.135  49.715  1
289939  98.413  -73.169  49.660  1
289940  98.438  -73.205  49.607  1
289941  98.465  -73.229  49.553  1
289942  98.493  -73.252  49.499  1
289943  98.520  -73.276  49.446  1
289944  98.548  -73.300  49.393  1
289945  98.574  -73.324  49.342  1
289946  98.584  -73.352  49.290  1
289947  98.583  -73.410  49.237  1
289948  98.570  -73.409  49.183  1
289949  98.634  -73.352  49.130  1
289950  98.707  -73.305  49.078  1
289951  98.781  -73.257  49.027  1
289952  98.807  -73.250  48.977  1
289953  98.794  -73.276  48.928  1
289954  98.782  -73.302  48.878  1
289955  98.770  -73.329  48.829  1
289956  98.772  -73.356  48.778  1
289957  98.808  -73.387  48.728  1
289958  98.848  -73.418  48.678  1
289959  98.892  -73.420  48.627  1
289960  98.938  -73.416  48.578  1
289961  98.985  -73.412  48.530  1
289962  99.030  -73.408  48.482  1
289963  99.080  -73.420  48.433  1
289964  99.129  -73.432  48.386  1
289965  99.155  -73.459  48.339  1
289966  99.181  -73.499  48.291  1
289967  99.205  -73.539  48.242  1
289968  99.230  -73.578  48.195  1
289969  99.255  -73.618  48.147  1
289970  99.280  -73.658  48.101  1
289971  99.321  -73.675  48.056  1
289972  99.362  -73.691  48.010  1
289973  99.404  -73.708  47.965  1
289974  99.445  -73.724  47.921  1
289975  99.487  -73.740  47.878  1
289976  99.529  -73.756  47.834  1
289977  99.571  -73.772  47.791  1
289978  99.611  -73.781  47.748  1
289979  99.650  -73.786  47.706  1
289980  99.690  -73.791  47.663  1
289981  99.729  -73.797  47.621  1
289982  99.768  -73.803  47.579  1
289983  99.808  -73.808  47.537  1
289984  99.847  -73.813  47.496  1
289985  99.887  -73.819  47.455  1
289986  99.908  -73.835  47.413  1
289987  99.920  -73.854  47.372  1
289988  99.932  -73.874  47.333  1
289989  99.944  -73.894  47.294  1
289990  99.956  -73.913  47.256  1
289991  99.971  -73.930  47.218  1
289992  99.994  -73.935  47.180  1
289993  100.023  -73.941  47.143  1
289994  100.055  -73.948  47.107  1
289995  100.087  -73.954  47.073  1
289996  100.119  -73.961  47.040  1
289997  100.151  -73.967  47.005  1
289998  100.183  -73.974  46.971  1
289999  100.215  -73.981  46.939  1
290000  100.247  -73.987  46.906  1
290001  100.279  -73.994  46.876  1
290002  100.311  -74.000  46.847  1
290003  100.343  -74.007  46.816  1
290004  100.375  -74.013  46.783  1
290005  100.407  -74.019  46.750  1
290006  100.437  -74.022  46.718  1
290007  100.468  -74.026  46.686  1
290008  100.498  -74.029  46.654  1
290009  100.529  -74.033  46.621  1
290010  100.558  -74.035  46.586  1
290011  100.587  -74.036  46.552  1
290012  100.615  -74.038  46.519  1
290013  100.644  -74.039  46.485  1
290014  100.672  -74.041  46.454  1
290015  100.701  -74.042  46.424  1
290016  100.729  -74.045  46.392  1
290017  100.758  -74.046  46.362  1
290018  100.786  -74.048  46.332  1
290019  100.815  -74.049  46.300  1
290020  100.843  -74.051  46.266  1
290021  100.873  -74.066  46.233  1
290022  100.901  -74.082  46.198  1
290023  100.930  -74.099  46.163  1
290024  100.960  -74.115  46.128  1
290025  100.989  -74.132  46.093  1
290026  101.018  -74.148  46.058  1
290027  101.047  -74.165  46.023  1
290028  101.076  -74.181  45.989  1
290029  101.105  -74.198  45.955  1
290030  101.134  -74.214  45.922  1
290031  101.164  -74.231  45.888  1
290032  101.193  -74.247  45.854  1
290033  101.221  -74.264  45.819  1
290034  101.251  -74.280  45.787  1
290035  101.280  -74.297  45.755  1
290036  101.309  -74.313  45.722  1
290037  101.338  -74.330  45.691  1
290038  101.375  -74.354  45.659  1
290039  101.420  -74.376  45.627  1
290040  101.465  -74.398  45.596  1
290041  101.510  -74.420  45.565  1
290042  101.555  -74.442  45.534  1
290043  101.601  -74.463  45.504  1
290044  101.646  -74.485  45.473  1
290045  101.691  -74.507  45.442  1
290046  101.736  -74.529  45.411  1
290047  101.781  -74.551  45.381  1
290048  101.827  -74.573  45.351  1
290049  101.872  -74.595  45.321  1
290050  101.917  -74.617  45.291  1
290051  101.949  -74.615  45.261  1
290052  101.978  -74.611  45.231  1
290053  102.007  -74.606  45.200  1
290054  102.036  -74.601  45.172  1
290055  102.031  -74.556  45.142  1
290056  102.045  -74.551  45.112  1
290057  102.062  -74.551  45.081  1
290058  102.080  -74.552  45.053  1
290059  102.097  -74.552  45.024  1
290060  102.115  -74.553  44.995  1
290061  102.132  -74.553  44.965  1
290062  102.154  -74.554  44.936  1
290063  102.177  -74.555  44.907  1
290064  102.200  -74.556  44.878  1
290533  95.068  -72.725  52.651  1
290534  95.094  -72.733  52.628  1
290535  95.119  -72.740  52.606  1
290536  95.135  -72.743  52.584  1
290537  95.147  -72.744  52.564  1
290538  95.168  -72.748  52.544  1
290539  95.188  -72.753  52.523  1
290540  95.208  -72.757  52.502  1
290541  95.229  -72.762  52.481  1
290542  95.250  -72.766  52.458  1
290543  95.270  -72.770  52.436  1
290544  95.290  -72.775  52.413  1
290545  95.311  -72.779  52.389  1
290546  95.332  -72.784  52.365  1
290547  95.352  -72.788  52.340  1
290548  95.387  -72.797  52.315  1
290549  95.444  -72.815  52.291  1
290550  95.501  -72.832  52.269  1
290551  95.558  -72.850  52.247  1
290552  95.615  -72.867  52.225  1
290553  95.659  -72.868  52.203  1
290554  95.683  -72.847  52.184  1
290555  95.707  -72.826  52.165  1
290556  95.731  -72.804  52.147  1
290557  95.755  -72.783  52.130  1
290558  95.794  -72.792  52.112  1
290559  95.833  -72.803  52.096  1
290560  95.872  -72.813  52.081  1
290561  95.899  -72.825  52.066  1
290562  95.918  -72.838  52.050  1
290563  95.937  -72.852  52.036  1
290564  95.956  -72.866  52.024  1
290565  95.974  -72.879  52.013  1
290566  95.993  -72.893  52.002  1
290567  96.012  -72.907  51.987  1
290568  96.031  -72.920  51.970  1
290569  96.049  -72.934  51.951  1
290570  96.068  -72.948  51.932  1
290571  96.088  -72.956  51.913  1
290572  96.115  -72.920  51.895  1
290573  96.143  -72.884  51.878  1
290574  96.176  -72.879  51.861  1
290575  96.210  -72.882  51.845  1
290576  96.244  -72.885  51.831  1
290577  96.278  -72.889  51.818  1
290578  96.312  -72.893  51.807  1
290579  96.346  -72.896  51.798  1
290580  96.382  -72.907  51.787  1
290581  96.409  -72.940  51.772  1
290582  96.424  -72.931  51.750  1
290583  96.452  -72.938  51.722  1
290584  96.479  -72.945  51.690  1
290585  96.507  -72.951  51.656  1
290586  96.535  -72.958  51.623  1
290587  96.562  -72.965  51.593  1
290588  96.590  -72.973  51.564  1
290589  96.618  -72.979  51.537  1
290590  96.646  -72.986  51.509  1
290591  96.673  -72.993  51.480  1
290592  96.701  -73.000  51.450  1
290593  96.738  -72.994  51.419  1
290594  96.749  -72.998  51.388  1
290595  96.760  -73.001  51.362  1
290596  96.789  -73.003  51.337  1
290597  96.820  -73.004  51.313  1
290598  96.852  -73.006  51.288  1
290599  96.884  -73.007  51.260  1
290600  96.914  -73.011  51.232  1
290601  96.950  -73.015  51.205  1
290602  96.994  -73.022  51.177  1
290603  97.031  -73.029  51.147  1
290604  97.062  -73.036  51.120  1
290605  97.092  -73.042  51.095  1
290606  97.123  -73.049  51.071  1
290607  97.158  -73.051  51.048  1
290608  97.190  -73.053  51.030  1
290609  97.221  -73.032  51.011  1
290610  97.253  -73.012  50.992  1
290611  97.285  -72.992  50.974  1
290612  97.316  -72.971  50.954  1
290613  97.348  -72.951  50.931  1
290614  97.379  -72.930  50.905  1
290615  97.410  -72.910  50.874  1
290616  97.443  -72.890  50.835  1
290617  97.475  -72.872  50.793  1
290618  97.507  -72.853  50.748  1
290619  97.545  -72.860  50.701  1
290620  97.586  -72.876  50.651  1
290621  97.628  -72.893  50.602  1
290622  97.669  -72.909  50.552  1
290623  97.710  -72.926  50.501  1
290624  97.751  -72.942  50.450  1
290625  97.792  -72.958  50.399  1
290626  97.833  -72.974  50.347  1
290627  97.874  -72.991  50.294  1
290628  97.915  -73.007  50.242  1
290629  97.956  -73.023  50.192  1
290630  97.998  -73.039  50.144  1
290631  98.043  -73.051  50.096  1
290632  98.089  -73.061  50.048  1
290633  98.135  -73.073  49.997  1
290634  98.178  -73.077  49.948  1
290635  98.221  -73.079  49.902  1
290636  98.264  -73.083  49.856  1
290637  98.307  -73.085  49.807  1
290638  98.350  -73.088  49.756  1
290639  98.393  -73.091  49.703  1
290640  98.419  -73.129  49.648  1
290641  98.444  -73.168  49.595  1
290642  98.472  -73.193  49.541  1
290643  98.499  -73.217  49.487  1
290644  98.526  -73.241  49.435  1
290645  98.554  -73.264  49.385  1
290646  98.574  -73.288  49.334  1
290647  98.583  -73.320  49.281  1
290648  98.589  -73.377  49.227  1
290649  98.576  -73.375  49.173  1
290650  98.627  -73.307  49.121  1
290651  98.701  -73.259  49.070  1
290652  98.774  -73.211  49.021  1
290653  98.771  -73.230  48.972  1
290654  98.759  -73.256  48.923  1
290655  98.746  -73.283  48.874  1
290656  98.750  -73.310  48.824  1
290657  98.797  -73.341  48.774  1
290658  98.825  -73.371  48.723  1
290659  98.865  -73.402  48.673  1
290660  98.904  -73.434  48.625  1
290661  98.946  -73.456  48.577  1
290662  98.992  -73.451  48.529  1
290663  99.038  -73.447  48.481  1
290664  99.083  -73.443  48.432  1
290665  99.129  -73.439  48.385  1
290666  99.164  -73.421  48.338  1
290667  99.190  -73.443  48.290  1
290668  99.215  -73.483  48.242  1
290669  99.240  -73.523  48.194  1
290670  99.265  -73.562  48.147  1
290671  99.290  -73.602  48.100  1
290672  99.317  -73.639  48.055  1
290673  99.358  -73.655  48.008  1
290674  99.400  -73.671  47.962  1
290675  99.442  -73.687  47.918  1
290676  99.484  -73.703  47.875  1
290677  99.525  -73.719  47.832  1
290678  99.567  -73.735  47.788  1
290679  99.608  -73.746  47.745  1
290680  99.647  -73.751  47.703  1
290681  99.686  -73.756  47.659  1
290682  99.725  -73.762  47.617  1
290683  99.765  -73.768  47.574  1
290684  99.804  -73.773  47.532  1
290685  99.844  -73.778  47.489  1
290686  99.883  -73.785  47.448  1
290687  99.923  -73.790  47.406  1
290688  99.952  -73.800  47.365  1
290689  99.965  -73.820  47.324  1
290690  99.977  -73.840  47.285  1
290691  99.989  -73.860  47.246  1
290692  100.001  -73.879  47.208  1
290693  100.015  -73.899  47.170  1
290694  100.043  -73.912  47.132  1
290695  100.076  -73.920  47.097  1
290696  100.109  -73.929  47.062  1
290697  100.142  -73.938  47.028  1
290698  100.174  -73.945  46.994  1
290699  100.207  -73.952  46.961  1
290700  100.239  -73.958  46.928  1
290701  100.271  -73.965  46.896  1
290702  100.302  -73.972  46.865  1
290703  100.335  -73.978  46.836  1
290704  100.366  -73.985  46.806  1
290705  100.399  -73.991  46.773  1
290706  100.430  -73.998  46.741  1
290707  100.461  -74.001  46.708  1
290708  100.492  -74.004  46.675  1
290709  100.521  -74.007  46.643  1
290710  100.549  -74.008  46.609  1
290711  100.577  -74.010  46.574  1
290712  100.606  -74.011  46.541  1
290713  100.635  -74.013  46.508  1
290714  100.663  -74.014  46.474  1
290715  100.692  -74.016  46.444  1
290716  100.720  -74.017  46.414  1
290717  100.749  -74.019  46.385  1
290718  100.777  -74.020  46.355  1
290719  100.805  -74.022  46.323  1
290720  100.834  -74.023  46.290  1
290721  100.862  -74.026  46.255  1
290722  100.892  -74.042  46.222  1
290723  100.921  -74.059  46.187  1
290724  100.950  -74.076  46.151  1
290725  100.979  -74.092  46.116  1
290726  101.008  -74.108  46.081  1
290727  101.037  -74.125  46.044  1
290728  101.066  -74.142  46.009  1
290729  101.096  -74.157  45.976  1
290730  101.125  -74.174  45.942  1
290731  101.153  -74.191  45.909  1
290732  101.183  -74.206  45.875  1
290733  101.212  -74.221  45.840  1
290734  101.241  -74.236  45.806  1
290735  101.270  -74.252  45.775  1
290736  101.299  -74.267  45.743  1
290737  101.328  -74.282  45.710  1
290738  101.357  -74.297  45.679  1
290739  101.388  -74.314  45.647  1
290740  101.428  -74.330  45.614  1
290741  101.473  -74.346  45.583  1
290742  101.518  -74.361  45.553  1
290743  101.563  -74.383  45.522  1
290744  101.608  -74.405  45.491  1
290745  101.653  -74.427  45.461  1
290746  101.699  -74.449  45.430  1
290747  101.744  -74.471  45.399  1
290748  101.789  -74.493  45.369  1
290749  101.834  -74.515  45.340  1
290750  101.880  -74.537  45.310  1
290751  101.925  -74.559  45.280  1
290752  101.968  -74.577  45.250  1
290753  101.997  -74.571  45.219  1
290754  102.026  -74.567  45.188  1
290755  102.055  -74.562  45.160  1
290756  102.042  -74.511  45.130  1
290757  102.060  -74.511  45.101  1
290758  102.078  -74.512  45.071  1
290759  102.095  -74.512  45.041  1
290760  102.112  -74.512  45.011  1
290761  102.130  -74.513  44.982  1
290762  102.152  -74.514  44.953  1
290763  102.174  -74.515  44.924  1
290764  102.197  -74.516  44.895  1
290765  102.221  -74.517  44.866  1
291235  95.093  -72.696  52.624  1
291236  95.118  -72.703  52.601  1
291237  95.144  -72.710  52.580  1
291238  95.153  -72.710  52.560  1
291239  95.171  -72.713  52.540  1
291240  95.191  -72.718  52.520  1
291241  95.211  -72.722  52.500  1
291242  95.232  -72.727  52.478  1
291243  95.253  -72.731  52.455  1
291244  95.273  -72.735  52.433  1
291245  95.294  -72.740  52.411  1
291246  95.314  -72.744  52.387  1
291247  95.335  -72.749  52.363  1
291248  95.355  -72.753  52.338  1
291249  95.391  -72.763  52.313  1
291250  95.449  -72.781  52.289  1
291251  95.506  -72.798  52.266  1
291252  95.563  -72.816  52.243  1
291253  95.620  -72.833  52.221  1
291254  95.656  -72.823  52.200  1
291255  95.691  -72.814  52.180  1
291256  95.722  -72.801  52.161  1
291257  95.746  -72.779  52.142  1
291258  95.770  -72.758  52.124  1
291259  95.803  -72.755  52.108  1
291260  95.842  -72.766  52.091  1
291261  95.875  -72.777  52.075  1
291262  95.894  -72.790  52.059  1
291263  95.912  -72.804  52.043  1
291264  95.932  -72.817  52.029  1
291265  95.950  -72.831  52.016  1
291266  95.969  -72.844  52.004  1
291267  95.987  -72.858  51.991  1
291268  96.007  -72.872  51.977  1
291269  96.025  -72.885  51.962  1
291270  96.044  -72.899  51.945  1
291271  96.063  -72.913  51.928  1
291272  96.082  -72.926  51.911  1
291273  96.104  -72.919  51.895  1
291274  96.131  -72.883  51.879  1
291275  96.164  -72.875  51.864  1
291276  96.198  -72.879  51.851  1
291277  96.232  -72.882  51.839  1
291278  96.266  -72.885  51.829  1
291279  96.300  -72.889  51.819  1
291280  96.334  -72.892  51.811  1
291281  96.369  -72.896  51.801  1
291282  96.402  -72.900  51.786  1
291283  96.430  -72.907  51.765  1
291284  96.457  -72.914  51.736  1
291285  96.485  -72.921  51.705  1
291286  96.513  -72.928  51.673  1
291287  96.540  -72.935  51.642  1
291288  96.568  -72.942  51.613  1
291289  96.596  -72.948  51.584  1
291290  96.623  -72.955  51.556  1
291291  96.651  -72.963  51.529  1
291292  96.678  -72.970  51.499  1
291293  96.706  -72.976  51.469  1
291294  96.736  -72.979  51.439  1
291295  96.754  -72.982  51.410  1
291296  96.786  -72.983  51.384  1
291297  96.817  -72.985  51.360  1
291298  96.849  -72.986  51.336  1
291299  96.880  -72.988  51.311  1
291300  96.912  -72.989  51.285  1
291301  96.944  -72.991  51.255  1
291302  96.974  -72.994  51.225  1
291303  97.004  -72.997  51.196  1
291304  97.036  -73.000  51.164  1
291305  97.072  -73.002  51.136  1
291306  97.108  -73.004  51.109  1
291307  97.144  -73.005  51.082  1
291308  97.179  -73.007  51.057  1
291309  97.210  -73.015  51.037  1
291310  97.237  -73.005  51.017  1
291311  97.269  -72.985  50.997  1
291312  97.301  -72.964  50.979  1
291313  97.332  -72.944  50.958  1
291314  97.364  -72.923  50.933  1
291315  97.395  -72.903  50.904  1
291316  97.427  -72.882  50.872  1
291317  97.458  -72.862  50.832  1
291318  97.490  -72.842  50.790  1
291319  97.522  -72.825  50.744  1
291320  97.560  -72.833  50.696  1
291321  97.597  -72.844  50.645  1
291322  97.639  -72.860  50.594  1
291323  97.680  -72.876  50.542  1
291324  97.722  -72.892  50.488  1
291325  97.762  -72.908  50.435  1
291326  97.804  -72.925  50.383  1
291327  97.845  -72.941  50.332  1
291328  97.886  -72.957  50.279  1
291329  97.927  -72.973  50.226  1
291330  97.968  -72.990  50.176  1
291331  98.010  -73.005  50.127  1
291332  98.056  -73.017  50.078  1
291333  98.101  -73.027  50.028  1
291334  98.144  -73.029  49.979  1
291335  98.187  -73.032  49.932  1
291336  98.230  -73.036  49.887  1
291337  98.273  -73.038  49.841  1
291338  98.316  -73.041  49.793  1
291339  98.359  -73.043  49.742  1
291340  98.400  -73.051  49.689  1
291341  98.425  -73.089  49.636  1
291342  98.451  -73.129  49.583  1
291343  98.478  -73.158  49.530  1
291344  98.505  -73.181  49.477  1
291345  98.532  -73.205  49.425  1
291346  98.560  -73.229  49.373  1
291347  98.573  -73.252  49.321  1
291348  98.583  -73.286  49.270  1
291349  98.594  -73.343  49.217  1
291350  98.582  -73.341  49.164  1
291351  98.621  -73.261  49.113  1
291352  98.695  -73.214  49.063  1
291353  98.747  -73.183  49.014  1
291354  98.735  -73.210  48.965  1
291355  98.723  -73.236  48.917  1
291356  98.729  -73.264  48.868  1
291357  98.777  -73.295  48.818  1
291358  98.823  -73.326  48.768  1
291359  98.842  -73.355  48.717  1
291360  98.882  -73.387  48.668  1
291361  98.921  -73.418  48.620  1
291362  98.961  -73.449  48.572  1
291363  99.000  -73.481  48.525  1
291364  99.045  -73.487  48.477  1
291365  99.090  -73.482  48.429  1
291366  99.137  -73.478  48.382  1
291367  99.170  -73.459  48.335  1
291368  99.198  -73.430  48.288  1
291369  99.225  -73.427  48.240  1
291370  99.250  -73.467  48.192  1
291371  99.275  -73.507  48.144  1
291372  99.300  -73.546  48.097  1
291373  99.325  -73.586  48.051  1
291374  99.355  -73.618  48.005  1
291375  99.397  -73.634  47.960  1
291376  99.438  -73.650  47.916  1
291377  99.480  -73.667  47.872  1
291378  99.521  -73.683  47.828  1
291379  99.563  -73.699  47.785  1
291380  99.604  -73.710  47.741  1
291381  99.643  -73.716  47.698  1
291382  99.683  -73.722  47.654  1
291383  99.722  -73.727  47.611  1
291384  99.762  -73.732  47.569  1
291385  99.801  -73.738  47.526  1
291386  99.840  -73.744  47.483  1
291387  99.880  -73.749  47.441  1
291388  99.919  -73.755  47.399  1
291389  99.959  -73.760  47.357  1
291390  99.997  -73.766  47.316  1
291391  100.009  -73.786  47.276  1
291392  100.021  -73.806  47.236  1
291393  100.033  -73.825  47.198  1
291394  100.050  -73.845  47.159  1
291395  100.067  -73.865  47.122  1
291396  100.091  -73.880  47.086  1
291397  100.124  -73.889  47.051  1
291398  100.157  -73.897  47.016  1
291399  100.190  -73.907  46.983  1
291400  100.223  -73.915  46.950  1
291401  100.256  -73.923  46.917  1
291402  100.289  -73.932  46.885  1
291403  100.322  -73.941  46.854  1
291404  100.355  -73.950  46.825  1
291405  100.388  -73.958  46.795  1
291406  100.421  -73.966  46.763  1
291407  100.454  -73.976  46.731  1
291408  100.483  -73.978  46.697  1
291409  100.511  -73.979  46.663  1
291410  100.540  -73.981  46.631  1
291411  100.568  -73.982  46.597  1
291412  100.597  -73.984  46.563  1
291413  100.625  -73.985  46.529  1
291414  100.654  -73.987  46.497  1
291415  100.683  -73.988  46.463  1
291416  100.711  -73.990  46.433  1
291417  100.740  -73.991  46.405  1
291418  100.768  -73.993  46.378  1
291419  100.796  -73.995  46.347  1
291420  100.825  -73.997  46.314  1
291421  100.853  -73.998  46.280  1
291422  100.882  -74.003  46.245  1
291423  100.911  -74.019  46.210  1
291424  100.940  -74.034  46.175  1
291425  100.969  -74.049  46.140  1
291426  100.998  -74.064  46.104  1
291427  101.028  -74.079  46.068  1
291428  101.057  -74.094  46.032  1
291429  101.086  -74.109  45.998  1
291430  101.115  -74.124  45.964  1
291431  101.144  -74.139  45.930  1
291432  101.173  -74.154  45.896  1
291433  101.202  -74.170  45.862  1
291434  101.231  -74.185  45.828  1
291435  101.260  -74.200  45.794  1
291436  101.289  -74.215  45.763  1
291437  101.319  -74.230  45.731  1
291438  101.348  -74.245  45.698  1
291439  101.377  -74.261  45.666  1
291440  101.408  -74.280  45.635  1
291441  101.439  -74.299  45.603  1
291442  101.483  -74.314  45.571  1
291443  101.528  -74.329  45.541  1
291444  101.572  -74.343  45.510  1
291445  101.617  -74.358  45.480  1
291446  101.662  -74.373  45.450  1
291447  101.706  -74.391  45.419  1
291448  101.751  -74.412  45.388  1
291449  101.796  -74.434  45.358  1
291450  101.842  -74.456  45.329  1
291451  101.887  -74.478  45.299  1
291452  101.933  -74.500  45.269  1
291453  101.977  -74.522  45.239  1
291454  102.016  -74.533  45.208  1
291455  102.045  -74.527  45.178  1
291456  102.063  -74.510  45.149  1
291457  102.057  -74.471  45.120  1
291458  102.075  -74.471  45.090  1
291459  102.092  -74.472  45.060  1
291460  102.110  -74.472  45.030  1
291461  102.127  -74.473  45.000  1
291462  102.149  -74.474  44.970  1
291463  102.172  -74.475  44.942  1
291464  102.195  -74.476  44.913  1
291465  102.218  -74.477  44.883  1
291466  102.241  -74.477  44.854  1
291937  95.117  -72.666  52.598  1
291938  95.143  -72.673  52.577  1
291939  95.164  -72.678  52.556  1
291940  95.174  -72.678  52.537  1
291941  95.194  -72.683  52.517  1
291942  95.214  -72.688  52.496  1
291943  95.235  -72.692  52.475  1
291944  95.256  -72.696  52.453  1
291945  95.276  -72.700  52.430  1
291946  95.297  -72.705  52.408  1
291947  95.317  -72.710  52.384  1
291948  95.338  -72.714  52.360  1
291949  95.358  -72.718  52.336  1
291950  95.396  -72.728  52.311  1
291951  95.453  -72.746  52.287  1
291952  95.510  -72.763  52.263  1
291953  95.567  -72.781  52.240  1
291954  95.619  -72.791  52.218  1
291955  95.652  -72.778  52.197  1
291956  95.687  -72.769  52.176  1
291957  95.722  -72.760  52.156  1
291958  95.757  -72.750  52.137  1
291959  95.784  -72.733  52.119  1
291960  95.812  -72.718  52.103  1
291961  95.851  -72.728  52.085  1
291962  95.870  -72.742  52.068  1
291963  95.888  -72.756  52.052  1
291964  95.907  -72.769  52.035  1
291965  95.926  -72.783  52.021  1
291966  95.945  -72.797  52.007  1
291967  95.963  -72.810  51.994  1
291968  95.982  -72.824  51.981  1
291969  96.001  -72.837  51.967  1
291970  96.020  -72.851  51.953  1
291971  96.039  -72.864  51.939  1
291972  96.057  -72.878  51.924  1
291973  96.076  -72.891  51.908  1
291974  96.095  -72.905  51.894  1
291975  96.120  -72.882  51.880  1
291976  96.152  -72.871  51.867  1
291977  96.186  -72.875  51.857  1
291978  96.220  -72.879  51.847  1
291979  96.254  -72.882  51.838  1
291980  96.289  -72.885  51.829  1
291981  96.325  -72.882  51.822  1
291982  96.362  -72.876  51.811  1
291983  96.399  -72.870  51.796  1
291984  96.428  -72.875  51.775  1
291985  96.456  -72.882  51.748  1
291986  96.484  -72.889  51.719  1
291987  96.512  -72.897  51.689  1
291988  96.540  -72.904  51.660  1
291989  96.568  -72.911  51.631  1
291990  96.596  -72.919  51.603  1
291991  96.624  -72.926  51.575  1
291992  96.652  -72.933  51.547  1
291993  96.680  -72.941  51.519  1
291994  96.708  -72.948  51.489  1
291995  96.743  -72.951  51.460  1
291996  96.774  -72.951  51.431  1
291997  96.807  -72.955  51.406  1
291998  96.840  -72.958  51.382  1
291999  96.873  -72.961  51.359  1
292000  96.905  -72.964  51.334  1
292001  96.938  -72.968  51.308  1
292002  96.970  -72.971  51.279  1
292003  97.003  -72.974  51.248  1
292004  97.032  -72.969  51.217  1
292005  97.058  -72.957  51.185  1
292006  97.093  -72.958  51.155  1
292007  97.129  -72.960  51.125  1
292008  97.165  -72.962  51.096  1
292009  97.201  -72.963  51.069  1
292010  97.232  -72.970  51.046  1
292011  97.253  -72.979  51.023  1
292012  97.285  -72.958  51.001  1
292013  97.317  -72.938  50.982  1
292014  97.348  -72.917  50.960  1
292015  97.380  -72.897  50.933  1
292016  97.411  -72.876  50.903  1
292017  97.443  -72.856  50.867  1
292018  97.474  -72.835  50.826  1
292019  97.506  -72.815  50.782  1
292020  97.540  -72.807  50.736  1
292021  97.578  -72.815  50.687  1
292022  97.615  -72.823  50.637  1
292023  97.647  -72.828  50.588  1
292024  97.688  -72.843  50.536  1
292025  97.730  -72.860  50.481  1
292026  97.772  -72.876  50.426  1
292027  97.814  -72.891  50.372  1
292028  97.856  -72.907  50.318  1
292029  97.898  -72.923  50.264  1
292030  97.939  -72.940  50.212  1
292031  97.980  -72.956  50.160  1
292032  98.022  -72.972  50.110  1
292033  98.067  -72.979  50.060  1
292034  98.109  -72.982  50.011  1
292035  98.153  -72.985  49.963  1
292036  98.196  -72.988  49.917  1
292037  98.238  -72.991  49.873  1
292038  98.282  -72.993  49.827  1
292039  98.324  -72.996  49.779  1
292040  98.368  -72.999  49.728  1
292041  98.406  -73.011  49.675  1
292042  98.432  -73.050  49.623  1
292043  98.457  -73.089  49.571  1
292044  98.484  -73.122  49.519  1
292045  98.511  -73.146  49.466  1
292046  98.538  -73.170  49.413  1
292047  98.563  -73.193  49.361  1
292048  98.573  -73.217  49.309  1
292049  98.582  -73.254  49.257  1
292050  98.593  -73.310  49.206  1
292051  98.588  -73.307  49.155  1
292052  98.615  -73.216  49.104  1
292053  98.688  -73.168  49.055  1
292054  98.712  -73.163  49.006  1
292055  98.700  -73.189  48.958  1
292056  98.708  -73.217  48.910  1
292057  98.756  -73.249  48.861  1
292058  98.802  -73.280  48.811  1
292059  98.838  -73.310  48.762  1
292060  98.859  -73.340  48.712  1
292061  98.899  -73.371  48.662  1
292062  98.938  -73.402  48.614  1
292063  98.978  -73.434  48.567  1
292064  99.017  -73.465  48.520  1
292065  99.057  -73.497  48.472  1
292066  99.098  -73.521  48.426  1
292067  99.144  -73.518  48.379  1
292068  99.176  -73.496  48.331  1
292069  99.204  -73.468  48.284  1
292070  99.232  -73.440  48.237  1
292071  99.260  -73.412  48.188  1
292072  99.285  -73.451  48.141  1
292073  99.309  -73.490  48.094  1
292074  99.335  -73.531  48.048  1
292075  99.359  -73.570  48.002  1
292076  99.393  -73.598  47.957  1
292077  99.434  -73.614  47.913  1
292078  99.476  -73.630  47.869  1
292079  99.518  -73.647  47.824  1
292080  99.560  -73.662  47.780  1
292081  99.600  -73.675  47.737  1
292082  99.640  -73.681  47.693  1
292083  99.680  -73.687  47.649  1
292084  99.719  -73.692  47.606  1
292085  99.758  -73.697  47.563  1
292086  99.797  -73.703  47.520  1
292087  99.837  -73.709  47.477  1
292088  99.876  -73.714  47.435  1
292089  99.916  -73.719  47.392  1
292090  99.955  -73.725  47.349  1
292091  99.994  -73.731  47.308  1
292092  100.034  -73.736  47.267  1
292093  100.054  -73.752  47.227  1
292094  100.066  -73.772  47.187  1
292095  100.084  -73.791  47.148  1
292096  100.102  -73.811  47.110  1
292097  100.119  -73.831  47.074  1
292098  100.139  -73.849  47.039  1
292099  100.172  -73.857  47.004  1
292100  100.205  -73.866  46.971  1
292101  100.238  -73.875  46.938  1
292102  100.271  -73.884  46.905  1
292103  100.304  -73.892  46.873  1
292104  100.337  -73.901  46.845  1
292105  100.370  -73.910  46.815  1
292106  100.403  -73.918  46.783  1
292107  100.436  -73.927  46.751  1
292108  100.466  -73.932  46.720  1
292109  100.485  -73.922  46.685  1
292110  100.511  -73.919  46.651  1
292111  100.540  -73.922  46.619  1
292112  100.568  -73.923  46.585  1
292113  100.597  -73.925  46.551  1
292114  100.625  -73.927  46.518  1
292115  100.654  -73.929  46.486  1
292116  100.683  -73.930  46.453  1
292117  100.711  -73.932  46.425  1
292118  100.740  -73.934  46.397  1
292119  100.768  -73.935  46.369  1
292120  100.797  -73.938  46.336  1
292121  100.826  -73.939  46.303  1
292122  100.854  -73.941  46.268  1
292123  100.893  -73.967  46.233  1
292124  100.930  -73.982  46.198  1
292125  100.960  -73.998  46.164  1
292126  100.989  -74.013  46.129  1
292127  101.018  -74.028  46.093  1
292128  101.047  -74.043  46.057  1
292129  101.076  -74.058  46.020  1
292130  101.105  -74.073  45.986  1
292131  101.134  -74.089  45.952  1
292132  101.163  -74.104  45.919  1
292133  101.192  -74.119  45.885  1
292134  101.221  -74.134  45.851  1
292135  101.251  -74.149  45.816  1
292136  101.280  -74.164  45.783  1
292137  101.309  -74.179  45.751  1
292138  101.338  -74.195  45.719  1
292139  101.367  -74.210  45.687  1
292140  101.397  -74.227  45.654  1
292141  101.428  -74.246  45.623  1
292142  101.460  -74.265  45.591  1
292143  101.494  -74.283  45.559  1
292144  101.538  -74.298  45.529  1
292145  101.583  -74.312  45.498  1
292146  101.627  -74.327  45.468  1
292147  101.672  -74.342  45.438  1
292148  101.716  -74.357  45.408  1
292149  101.761  -74.371  45.377  1
292150  101.805  -74.386  45.347  1
292151  101.849  -74.401  45.318  1
292152  101.895  -74.420  45.288  1
292153  101.940  -74.442  45.258  1
292154  101.985  -74.464  45.227  1
292155  102.030  -74.486  45.197  1
292156  102.064  -74.489  45.168  1
292157  102.071  -74.458  45.138  1
292158  102.073  -74.431  45.109  1
292159  102.090  -74.432  45.080  1
292160  102.107  -74.432  45.048  1
292161  102.125  -74.433  45.019  1
292162  102.147  -74.433  44.989  1
292163  102.170  -74.434  44.960  1
292164  102.192  -74.436  44.932  1
292165  102.216  -74.436  44.902  1
292166  102.239  -74.437  44.872  1
292167  102.261  -74.439  44.842  1
292639  95.141  -72.636  52.573  1
292640  95.168  -72.644  52.553  1
292641  95.181  -72.646  52.534  1
292642  95.197  -72.648  52.513  1
292643  95.217  -72.653  52.493  1
292644  95.238  -72.657  52.472  1
292645  95.259  -72.661  52.450  1
292646  95.279  -72.666  52.428  1
292647  95.300  -72.670  52.406  1
292648  95.320  -72.675  52.382  1
292649  95.341  -72.679  52.357  1
292650  95.361  -72.683  52.332  1
292651  95.400  -72.694  52.308  1
292652  95.457  -72.712  52.283  1
292653  95.515  -72.729  52.259  1
292654  95.571  -72.747  52.236  1
292655  95.614  -72.744  52.214  1
292656  95.648  -72.733  52.193  1
292657  95.683  -72.723  52.171  1
292658  95.718  -72.714  52.151  1
292659  95.753  -72.705  52.132  1
292660  95.788  -72.695  52.115  1
292661  95.823  -72.686  52.097  1
292662  95.845  -72.694  52.079  1
292663  95.864  -72.707  52.062  1
292664  95.883  -72.721  52.045  1
292665  95.902  -72.735  52.028  1
292666  95.920  -72.748  52.013  1
292667  95.939  -72.762  51.998  1
292668  95.958  -72.776  51.984  1
292669  95.977  -72.789  51.970  1
292670  95.995  -72.803  51.956  1
292671  96.015  -72.816  51.944  1
292672  96.033  -72.830  51.931  1
292673  96.052  -72.844  51.918  1
292674  96.071  -72.857  51.906  1
292675  96.090  -72.871  51.892  1
292676  96.109  -72.881  51.880  1
292677  96.140  -72.868  51.870  1
292678  96.174  -72.871  51.861  1
292679  96.209  -72.871  51.853  1
292680  96.246  -72.865  51.846  1
292681  96.284  -72.859  51.839  1
292682  96.320  -72.853  51.831  1
292683  96.358  -72.846  51.819  1
292684  96.394  -72.840  51.803  1
292685  96.426  -72.842  51.783  1
292686  96.454  -72.849  51.759  1
292687  96.482  -72.857  51.732  1
292688  96.510  -72.864  51.704  1
292689  96.538  -72.871  51.677  1
292690  96.566  -72.879  51.648  1
292691  96.594  -72.886  51.620  1
292692  96.622  -72.893  51.593  1
292693  96.650  -72.901  51.566  1
292694  96.678  -72.908  51.539  1
292695  96.719  -72.910  51.510  1
292696  96.754  -72.910  51.481  1
292697  96.785  -72.905  51.451  1
292698  96.817  -72.908  51.426  1
292699  96.850  -72.912  51.404  1
292700  96.883  -72.915  51.381  1
292701  96.915  -72.918  51.357  1
292702  96.948  -72.921  51.331  1
292703  96.981  -72.925  51.303  1
292704  97.014  -72.928  51.272  1
292705  97.058  -72.931  51.240  1
292706  97.084  -72.920  51.206  1
292707  97.114  -72.914  51.174  1
292708  97.150  -72.916  51.142  1
292709  97.186  -72.918  51.112  1
292710  97.222  -72.920  51.083  1
292711  97.253  -72.926  51.056  1
292712  97.272  -72.946  51.030  1
292713  97.301  -72.931  51.006  1
292714  97.333  -72.910  50.986  1
292715  97.364  -72.890  50.962  1
292716  97.396  -72.870  50.934  1
292717  97.427  -72.849  50.901  1
292718  97.459  -72.829  50.862  1
292719  97.490  -72.808  50.819  1
292720  97.522  -72.788  50.773  1
292721  97.558  -72.789  50.726  1
292722  97.596  -72.797  50.678  1
292723  97.634  -72.805  50.629  1
292724  97.671  -72.813  50.580  1
292725  97.704  -72.819  50.530  1
292726  97.738  -72.827  50.476  1
292727  97.780  -72.843  50.419  1
292728  97.822  -72.859  50.362  1
292729  97.864  -72.875  50.307  1
292730  97.906  -72.891  50.252  1
292731  97.948  -72.907  50.199  1
292732  97.990  -72.923  50.146  1
292733  98.030  -72.939  50.094  1
292734  98.075  -72.935  50.044  1
292735  98.119  -72.938  49.996  1
292736  98.161  -72.941  49.949  1
292737  98.204  -72.944  49.903  1
292738  98.247  -72.946  49.859  1
292739  98.290  -72.949  49.813  1
292740  98.334  -72.951  49.765  1
292741  98.376  -72.954  49.714  1
292742  98.413  -72.971  49.661  1
292743  98.438  -73.011  49.609  1
292744  98.463  -73.049  49.559  1
292745  98.489  -73.086  49.506  1
292746  98.517  -73.111  49.453  1
292747  98.544  -73.134  49.399  1
292748  98.563  -73.158  49.348  1
292749  98.572  -73.181  49.296  1
292750  98.582  -73.221  49.245  1
292751  98.593  -73.277  49.195  1
292752  98.594  -73.273  49.145  1
292753  98.608  -73.170  49.096  1
292754  98.682  -73.122  49.046  1
292755  98.676  -73.143  48.998  1
292756  98.687  -73.171  48.950  1
292757  98.734  -73.202  48.902  1
292758  98.782  -73.233  48.854  1
292759  98.829  -73.265  48.805  1
292760  98.852  -73.294  48.756  1
292761  98.876  -73.324  48.706  1
292762  98.916  -73.355  48.657  1
292763  98.955  -73.387  48.608  1
292764  98.995  -73.418  48.561  1
292765  99.034  -73.449  48.514  1
292766  99.074  -73.481  48.467  1
292767  99.114  -73.512  48.421  1
292768  99.153  -73.544  48.375  1
292769  99.182  -73.533  48.327  1
292770  99.210  -73.506  48.279  1
292771  99.237  -73.477  48.231  1
292772  99.266  -73.449  48.183  1
292773  99.293  -73.422  48.137  1
292774  99.320  -73.435  48.090  1
292775  99.344  -73.474  48.044  1
292776  99.369  -73.515  47.999  1
292777  99.394  -73.554  47.954  1
292778  99.431  -73.578  47.909  1
292779  99.472  -73.593  47.865  1
292780  99.514  -73.609  47.820  1
292781  99.556  -73.626  47.775  1
292782  99.597  -73.640  47.731  1
292783  99.637  -73.646  47.687  1
292784  99.676  -73.651  47.643  1
292785  99.715  -73.657  47.600  1
292786  99.755  -73.662  47.557  1
292787  99.794  -73.668  47.513  1
292788  99.834  -73.674  47.470  1
292789  99.873  -73.679  47.427  1
292790  99.912  -73.684  47.384  1
292791  99.951  -73.690  47.341  1
292792  99.991  -73.696  47.299  1
292793  100.031  -73.701  47.257  1
292794  100.070  -73.706  47.216  1
292795  100.101  -73.718  47.176  1
292796  100.118  -73.738  47.137  1
292797  100.136  -73.757  47.098  1
292798  100.153  -73.777  47.062  1
292799  100.171  -73.797  47.027  1
292800  100.189  -73.816  46.992  1
292801  100.220  -73.826  46.959  1
292802  100.253  -73.835  46.925  1
292803  100.286  -73.844  46.893  1
292804  100.319  -73.852  46.861  1
292805  100.352  -73.861  46.834  1
292806  100.385  -73.869  46.803  1
292807  100.418  -73.878  46.771  1
292808  100.451  -73.887  46.739  1
292809  100.476  -73.885  46.706  1
292810  100.495  -73.875  46.672  1
292811  100.514  -73.865  46.639  1
292812  100.539  -73.862  46.606  1
292813  100.567  -73.863  46.572  1
292814  100.596  -73.865  46.539  1
292815  100.625  -73.866  46.507  1
292816  100.653  -73.869  46.475  1
292817  100.682  -73.870  46.444  1
292818  100.710  -73.872  46.416  1
292819  100.739  -73.874  46.388  1
292820  100.768  -73.875  46.358  1
292821  100.796  -73.877  46.325  1
292822  100.825  -73.879  46.290  1
292823  100.853  -73.881  46.255  1
292824  100.901  -73.931  46.220  1
292825  100.939  -73.946  46.186  1
292826  100.977  -73.961  46.152  1
292827  101.008  -73.976  46.117  1
292828  101.037  -73.991  46.081  1
292829  101.066  -74.007  46.045  1
292830  101.095  -74.022  46.008  1
292831  101.124  -74.037  45.974  1
292832  101.153  -74.052  45.941  1
292833  101.183  -74.067  45.908  1
292834  101.211  -74.082  45.873  1
292835  101.241  -74.098  45.839  1
292836  101.270  -74.113  45.805  1
292837  101.299  -74.128  45.771  1
292838  101.328  -74.143  45.738  1
292839  101.357  -74.158  45.707  1
292840  101.387  -74.174  45.675  1
292841  101.417  -74.192  45.642  1
292842  101.449  -74.211  45.610  1
292843  101.480  -74.230  45.579  1
292844  101.510  -74.249  45.548  1
292845  101.549  -74.267  45.517  1
292846  101.593  -74.281  45.487  1
292847  101.638  -74.295  45.457  1
292848  101.682  -74.311  45.427  1
292849  101.727  -74.325  45.395  1
292850  101.771  -74.340  45.365  1
292851  101.816  -74.355  45.336  1
292852  101.860  -74.370  45.307  1
292853  101.904  -74.384  45.277  1
292854  101.949  -74.399  45.247  1
292855  101.993  -74.414  45.217  1
292856  102.038  -74.429  45.187  1
292857  102.083  -74.449  45.157  1
292858  102.079  -74.407  45.128  1
292859  102.088  -74.392  45.098  1
292860  102.105  -74.392  45.068  1
292861  102.122  -74.393  45.038  1
292862  102.144  -74.393  45.008  1
292863  102.167  -74.394  44.978  1
292864  102.190  -74.396  44.949  1
292865  102.213  -74.396  44.920  1
292866  102.236  -74.397  44.891  1
292867  102.259  -74.399  44.861  1
292868  102.282  -74.399  44.831  1
293340  95.140  -72.599  52.569  1
293341  95.166  -72.606  52.550  1
293342  95.192  -72.614  52.530  1
293343  95.200  -72.613  52.510  1
293344  95.220  -72.618  52.490  1
293345  95.241  -72.622  52.469  1
293346  95.262  -72.626  52.448  1
293347  95.282  -72.631  52.426  1
293348  95.303  -72.635  52.403  1
293349  95.323  -72.640  52.379  1
293350  95.344  -72.644  52.354  1
293351  95.365  -72.648  52.328  1
293352  95.404  -72.660  52.303  1
293353  95.462  -72.678  52.280  1
293354  95.519  -72.695  52.256  1
293355  95.576  -72.713  52.233  1
293356  95.610  -72.698  52.210  1
293357  95.644  -72.688  52.188  1
293358  95.679  -72.678  52.167  1
293359  95.714  -72.669  52.147  1
293360  95.749  -72.660  52.129  1
293361  95.784  -72.650  52.111  1
293362  95.817  -72.648  52.093  1
293363  95.838  -72.668  52.075  1
293364  95.850  -72.681  52.057  1
293365  95.869  -72.694  52.039  1
293366  95.888  -72.707  52.021  1
293367  95.908  -72.720  52.005  1
293368  95.927  -72.734  51.990  1
293369  95.946  -72.747  51.975  1
293370  95.966  -72.760  51.961  1
293371  95.985  -72.773  51.948  1
293372  96.004  -72.786  51.935  1
293373  96.023  -72.799  51.924  1
293374  96.043  -72.813  51.912  1
293375  96.062  -72.826  51.901  1
293376  96.081  -72.838  51.890  1
293377  96.100  -72.852  51.880  1
293378  96.131  -72.854  51.871  1
293379  96.168  -72.848  51.864  1
293380  96.205  -72.841  51.857  1
293381  96.242  -72.835  51.852  1
293382  96.279  -72.829  51.847  1
293383  96.316  -72.823  51.839  1
293384  96.353  -72.817  51.827  1
293385  96.390  -72.811  51.811  1
293386  96.424  -72.809  51.792  1
293387  96.452  -72.816  51.769  1
293388  96.480  -72.824  51.744  1
293389  96.508  -72.831  51.717  1
293390  96.536  -72.838  51.690  1
293391  96.564  -72.846  51.663  1
293392  96.592  -72.853  51.636  1
293393  96.620  -72.860  51.610  1
293394  96.648  -72.868  51.585  1
293395  96.690  -72.870  51.560  1
293396  96.733  -72.870  51.532  1
293397  96.766  -72.869  51.501  1
293398  96.797  -72.865  51.471  1
293399  96.827  -72.862  51.445  1
293400  96.860  -72.865  51.423  1
293401  96.893  -72.869  51.401  1
293402  96.926  -72.872  51.380  1
293403  96.958  -72.875  51.354  1
293404  96.991  -72.878  51.326  1
293405  97.024  -72.882  51.295  1
293406  97.064  -72.884  51.263  1
293407  97.109  -72.882  51.227  1
293408  97.136  -72.871  51.194  1
293409  97.172  -72.872  51.162  1
293410  97.208  -72.874  51.130  1
293411  97.243  -72.876  51.101  1
293412  97.276  -72.881  51.071  1
293413  97.294  -72.901  51.041  1
293414  97.317  -72.904  51.013  1
293415  97.349  -72.883  50.989  1
293416  97.380  -72.863  50.964  1
293417  97.412  -72.842  50.934  1
293418  97.443  -72.822  50.899  1
293419  97.475  -72.801  50.860  1
293420  97.506  -72.781  50.813  1
293421  97.538  -72.763  50.765  1
293422  97.576  -72.771  50.716  1
293423  97.614  -72.779  50.668  1
293424  97.652  -72.788  50.618  1
293425  97.689  -72.796  50.569  1
293426  97.727  -72.804  50.518  1
293427  97.761  -72.810  50.466  1
293428  97.791  -72.813  50.411  1
293429  97.830  -72.826  50.356  1
293430  97.872  -72.843  50.301  1
293431  97.914  -72.859  50.246  1
293432  97.956  -72.875  50.192  1
293433  97.997  -72.891  50.136  1
293434  98.036  -72.907  50.082  1
293435  98.075  -72.923  50.031  1
293436  98.120  -72.900  49.982  1
293437  98.170  -72.896  49.936  1
293438  98.213  -72.899  49.891  1
293439  98.256  -72.901  49.846  1
293440  98.299  -72.904  49.799  1
293441  98.342  -72.907  49.749  1
293442  98.385  -72.910  49.698  1
293443  98.419  -72.932  49.646  1
293444  98.444  -72.970  49.595  1
293445  98.470  -73.010  49.544  1
293446  98.496  -73.049  49.493  1
293447  98.522  -73.075  49.440  1
293448  98.550  -73.098  49.387  1
293449  98.562  -73.122  49.335  1
293450  98.571  -73.145  49.285  1
293451  98.581  -73.188  49.234  1
293452  98.592  -73.245  49.185  1
293453  98.600  -73.239  49.136  1
293454  98.608  -73.130  49.087  1
293455  98.653  -73.096  49.038  1
293456  98.666  -73.125  48.990  1
293457  98.713  -73.156  48.943  1
293458  98.761  -73.187  48.896  1
293459  98.807  -73.218  48.848  1
293460  98.855  -73.250  48.799  1
293461  98.867  -73.278  48.750  1
293462  98.893  -73.308  48.701  1
293463  98.933  -73.340  48.652  1
293464  98.973  -73.371  48.604  1
293465  99.012  -73.402  48.556  1
293466  99.052  -73.434  48.509  1
293467  99.091  -73.465  48.462  1
293468  99.120  -73.487  48.416  1
293469  99.157  -73.495  48.370  1
293470  99.193  -73.517  48.322  1
293471  99.217  -73.524  48.273  1
293472  99.243  -73.515  48.225  1
293473  99.271  -73.487  48.178  1
293474  99.299  -73.459  48.132  1
293475  99.327  -73.431  48.086  1
293476  99.354  -73.419  48.040  1
293477  99.379  -73.459  47.995  1
293478  99.404  -73.499  47.949  1
293479  99.429  -73.538  47.905  1
293480  99.469  -73.557  47.861  1
293481  99.510  -73.573  47.815  1
293482  99.552  -73.589  47.771  1
293483  99.593  -73.606  47.726  1
293484  99.633  -73.611  47.682  1
293485  99.673  -73.616  47.638  1
293486  99.712  -73.622  47.595  1
293487  99.751  -73.628  47.551  1
293488  99.791  -73.633  47.508  1
293489  99.830  -73.638  47.464  1
293490  99.869  -73.644  47.420  1
293491  99.909  -73.650  47.376  1
293492  99.948  -73.655  47.332  1
293493  99.988  -73.660  47.291  1
293494  100.027  -73.666  47.248  1
293495  100.061  -73.676  47.207  1
293496  100.098  -73.684  47.167  1
293497  100.135  -73.694  47.127  1
293498  100.170  -73.703  47.088  1
293499  100.187  -73.723  47.051  1
293500  100.205  -73.743  47.016  1
293501  100.223  -73.763  46.981  1
293502  100.241  -73.782  46.947  1
293503  100.268  -73.795  46.913  1
293504  100.300  -73.803  46.881  1
293505  100.334  -73.812  46.849  1
293506  100.366  -73.821  46.822  1
293507  100.400  -73.829  46.791  1
293508  100.432  -73.838  46.759  1
293509  100.466  -73.847  46.726  1
293510  100.486  -73.838  46.692  1
293511  100.505  -73.828  46.659  1
293512  100.525  -73.819  46.626  1
293513  100.544  -73.809  46.592  1
293514  100.567  -73.803  46.559  1
293515  100.596  -73.805  46.526  1
293516  100.624  -73.807  46.495  1
293517  100.652  -73.808  46.464  1
293518  100.681  -73.810  46.435  1
293519  100.710  -73.812  46.408  1
293520  100.739  -73.813  46.378  1
293521  100.767  -73.816  46.345  1
293522  100.795  -73.817  46.312  1
293523  100.824  -73.819  46.277  1
293524  100.853  -73.821  46.242  1
293525  100.909  -73.895  46.207  1
293526  100.947  -73.910  46.173  1
293527  100.985  -73.926  46.139  1
293528  101.023  -73.941  46.103  1
293529  101.056  -73.956  46.067  1
293530  101.086  -73.971  46.031  1
293531  101.115  -73.986  45.995  1
293532  101.143  -74.001  45.961  1
293533  101.173  -74.017  45.928  1
293534  101.202  -74.032  45.895  1
293535  101.231  -74.047  45.861  1
293536  101.260  -74.062  45.827  1
293537  101.289  -74.077  45.793  1
293538  101.318  -74.092  45.758  1
293539  101.347  -74.107  45.726  1
293540  101.376  -74.123  45.694  1
293541  101.407  -74.139  45.663  1
293542  101.438  -74.158  45.630  1
293543  101.469  -74.177  45.598  1
293544  101.500  -74.196  45.566  1
293545  101.531  -74.215  45.535  1
293546  101.562  -74.234  45.504  1
293547  101.604  -74.250  45.474  1
293548  101.648  -74.264  45.445  1
293549  101.693  -74.280  45.414  1
293550  101.737  -74.294  45.383  1
293551  101.781  -74.309  45.353  1
293552  101.826  -74.324  45.324  1
293553  101.871  -74.339  45.294  1
293554  101.915  -74.353  45.265  1
293555  101.959  -74.368  45.235  1
293556  102.004  -74.383  45.205  1
293557  102.048  -74.398  45.176  1
293558  102.091  -74.404  45.145  1
293559  102.087  -74.355  45.116  1
293560  102.102  -74.352  45.087  1
293561  102.120  -74.352  45.057  1
293562  102.141  -74.353  45.027  1
293563  102.165  -74.354  44.996  1
293564  102.187  -74.355  44.966  1
293565  102.210  -74.356  44.937  1
293566  102.234  -74.357  44.907  1
293567  102.256  -74.358  44.879  1
293568  102.279  -74.359  44.849  1
293569  102.303  -74.360  44.819  1
294042  95.165  -72.569  52.546  1
294043  95.191  -72.577  52.527  1
294044  95.210  -72.581  52.507  1
294045  95.224  -72.583  52.487  1
294046  95.244  -72.587  52.466  1
294047  95.265  -72.591  52.445  1
294048  95.285  -72.596  52.423  1
294049  95.306  -72.600  52.400  1
294050  95.326  -72.605  52.376  1
294051  95.347  -72.609  52.350  1
294052  95.368  -72.613  52.325  1
294053  95.409  -72.625  52.300  1
294054  95.466  -72.643  52.276  1
294055  95.523  -72.660  52.252  1
294056  95.578  -72.674  52.229  1
294057  95.606  -72.652  52.207  1
294058  95.640  -72.642  52.185  1
294059  95.676  -72.633  52.164  1
294060  95.710  -72.624  52.144  1
294061  95.746  -72.614  52.125  1
294062  95.780  -72.605  52.107  1
294063  95.810  -72.619  52.089  1
294064  95.839  -72.644  52.071  1
294065  95.847  -72.657  52.053  1
294066  95.855  -72.669  52.034  1
294067  95.872  -72.683  52.016  1
294068  95.891  -72.696  51.999  1
294069  95.910  -72.709  51.983  1
294070  95.930  -72.722  51.968  1
294071  95.949  -72.735  51.954  1
294072  95.968  -72.748  51.940  1
294073  95.987  -72.762  51.928  1
294074  96.007  -72.775  51.917  1
294075  96.026  -72.788  51.906  1
294076  96.045  -72.801  51.896  1
294077  96.064  -72.814  51.887  1
294078  96.097  -72.813  51.879  1
294079  96.131  -72.815  51.871  1
294080  96.165  -72.817  51.865  1
294081  96.201  -72.813  51.860  1
294082  96.238  -72.807  51.855  1
294083  96.275  -72.801  51.851  1
294084  96.312  -72.794  51.843  1
294085  96.349  -72.788  51.831  1
294086  96.386  -72.782  51.816  1
294087  96.422  -72.776  51.799  1
294088  96.450  -72.784  51.777  1
294089  96.478  -72.791  51.753  1
294090  96.506  -72.798  51.727  1
294091  96.534  -72.806  51.702  1
294092  96.562  -72.813  51.676  1
294093  96.590  -72.820  51.651  1
294094  96.618  -72.828  51.627  1
294095  96.661  -72.830  51.602  1
294096  96.712  -72.829  51.577  1
294097  96.745  -72.829  51.548  1
294098  96.778  -72.827  51.517  1
294099  96.809  -72.824  51.487  1
294100  96.839  -72.819  51.461  1
294101  96.871  -72.819  51.440  1
294102  96.903  -72.822  51.419  1
294103  96.936  -72.826  51.398  1
294104  96.968  -72.829  51.373  1
294105  97.001  -72.832  51.345  1
294106  97.034  -72.835  51.315  1
294107  97.071  -72.838  51.282  1
294108  97.127  -72.841  51.246  1
294109  97.162  -72.833  51.213  1
294110  97.193  -72.829  51.181  1
294111  97.229  -72.830  51.149  1
294112  97.264  -72.832  51.119  1
294113  97.298  -72.836  51.087  1
294114  97.315  -72.857  51.055  1
294115  97.333  -72.876  51.023  1
294116  97.365  -72.856  50.996  1
294117  97.396  -72.835  50.968  1
294118  97.428  -72.816  50.934  1
294119  97.459  -72.795  50.897  1
294120  97.491  -72.775  50.856  1
294121  97.522  -72.754  50.807  1
294122  97.557  -72.745  50.757  1
294123  97.594  -72.754  50.707  1
294124  97.632  -72.761  50.657  1
294125  97.670  -72.769  50.608  1
294126  97.708  -72.778  50.557  1
294127  97.745  -72.786  50.506  1
294128  97.783  -72.794  50.453  1
294129  97.818  -72.801  50.400  1
294130  97.848  -72.804  50.347  1
294131  97.880  -72.810  50.293  1
294132  97.922  -72.826  50.239  1
294133  97.963  -72.842  50.185  1
294134  98.002  -72.858  50.129  1
294135  98.041  -72.874  50.075  1
294136  98.081  -72.890  50.022  1
294137  98.120  -72.905  49.973  1
294138  98.136  -72.890  49.927  1
294139  98.222  -72.854  49.880  1
294140  98.265  -72.857  49.833  1
294141  98.308  -72.860  49.784  1
294142  98.351  -72.863  49.734  1
294143  98.394  -72.866  49.684  1
294144  98.425  -72.892  49.634  1
294145  98.451  -72.931  49.584  1
294146  98.477  -72.970  49.533  1
294147  98.502  -73.009  49.482  1
294148  98.528  -73.039  49.430  1
294149  98.552  -73.063  49.379  1
294150  98.562  -73.086  49.328  1
294151  98.571  -73.109  49.277  1
294152  98.581  -73.155  49.227  1
294153  98.592  -73.188  49.177  1
294154  98.603  -73.142  49.128  1
294155  98.615  -73.096  49.080  1
294156  98.645  -73.079  49.031  1
294157  98.692  -73.110  48.984  1
294158  98.739  -73.141  48.937  1
294159  98.787  -73.172  48.890  1
294160  98.834  -73.204  48.842  1
294161  98.880  -73.235  48.794  1
294162  98.881  -73.262  48.745  1
294163  98.910  -73.293  48.697  1
294164  98.950  -73.324  48.648  1
294165  98.989  -73.355  48.600  1
294166  99.029  -73.387  48.552  1
294167  99.069  -73.418  48.505  1
294168  99.086  -73.428  48.458  1
294169  99.090  -73.427  48.411  1
294170  99.162  -73.448  48.365  1
294171  99.200  -73.473  48.316  1
294172  99.230  -73.488  48.268  1
294173  99.255  -73.495  48.220  1
294174  99.279  -73.503  48.174  1
294175  99.305  -73.496  48.128  1
294176  99.333  -73.469  48.082  1
294177  99.360  -73.441  48.036  1
294178  99.389  -73.413  47.990  1
294179  99.414  -73.443  47.945  1
294180  99.439  -73.483  47.900  1
294181  99.465  -73.521  47.856  1
294182  99.506  -73.537  47.811  1
294183  99.548  -73.553  47.766  1
294184  99.590  -73.568  47.722  1
294185  99.630  -73.576  47.677  1
294186  99.669  -73.581  47.633  1
294187  99.708  -73.587  47.590  1
294188  99.748  -73.593  47.546  1
294189  99.787  -73.598  47.502  1
294190  99.827  -73.603  47.458  1
294191  99.866  -73.609  47.414  1
294192  99.906  -73.615  47.369  1
294193  99.945  -73.620  47.325  1
294194  99.981  -73.628  47.283  1
294195  100.015  -73.638  47.240  1
294196  100.050  -73.648  47.199  1
294197  100.087  -73.656  47.158  1
294198  100.124  -73.666  47.117  1
294199  100.161  -73.674  47.078  1
294200  100.198  -73.682  47.041  1
294201  100.235  -73.691  47.005  1
294202  100.257  -73.709  46.969  1
294203  100.274  -73.728  46.935  1
294204  100.292  -73.748  46.901  1
294205  100.316  -73.763  46.868  1
294206  100.349  -73.772  46.836  1
294207  100.382  -73.781  46.809  1
294208  100.415  -73.789  46.778  1
294209  100.447  -73.798  46.746  1
294210  100.477  -73.802  46.712  1
294211  100.496  -73.792  46.679  1
294212  100.515  -73.781  46.645  1
294213  100.535  -73.772  46.611  1
294214  100.554  -73.762  46.579  1
294215  100.573  -73.752  46.546  1
294216  100.595  -73.745  46.514  1
294217  100.623  -73.747  46.483  1
294218  100.652  -73.748  46.452  1
294219  100.680  -73.750  46.424  1
294220  100.709  -73.752  46.395  1
294221  100.738  -73.753  46.365  1
294222  100.766  -73.755  46.331  1
294223  100.795  -73.757  46.297  1
294224  100.824  -73.759  46.263  1
294225  100.852  -73.760  46.228  1
294226  100.917  -73.859  46.194  1
294227  100.955  -73.874  46.160  1
294228  100.993  -73.889  46.125  1
294229  101.031  -73.904  46.090  1
294230  101.069  -73.919  46.055  1
294231  101.105  -73.935  46.019  1
294232  101.134  -73.950  45.983  1
294233  101.163  -73.965  45.949  1
294234  101.192  -73.980  45.916  1
294235  101.221  -73.995  45.883  1
294236  101.250  -74.010  45.849  1
294237  101.279  -74.026  45.815  1
294238  101.309  -74.041  45.780  1
294239  101.337  -74.056  45.746  1
294240  101.367  -74.071  45.713  1
294241  101.396  -74.086  45.682  1
294242  101.427  -74.105  45.650  1
294243  101.458  -74.124  45.617  1
294244  101.489  -74.143  45.585  1
294245  101.520  -74.162  45.554  1
294246  101.551  -74.181  45.523  1
294247  101.582  -74.200  45.491  1
294248  101.614  -74.219  45.461  1
294249  101.659  -74.233  45.432  1
294250  101.703  -74.248  45.402  1
294251  101.748  -74.263  45.371  1
294252  101.792  -74.278  45.341  1
294253  101.836  -74.292  45.311  1
294254  101.881  -74.307  45.282  1
294255  101.925  -74.322  45.253  1
294256  101.970  -74.336  45.223  1
294257  102.014  -74.352  45.194  1
294258  102.059  -74.366  45.164  1
294259  102.094  -74.350  45.133  1
294260  102.100  -74.311  45.105  1
294261  102.117  -74.312  45.075  1
294262  102.139  -74.313  45.045  1
294263  102.162  -74.314  45.015  1
294264  102.185  -74.314  44.983  1
294265  102.208  -74.316  44.953  1
294266  102.231  -74.317  44.924  1
294267  102.254  -74.317  44.895  1
294268  102.277  -74.319  44.867  1
294269  102.300  -74.320  44.836  1
294270  102.323  -74.320  44.807  1
294744  95.190  -72.540  52.525  1
294745  95.215  -72.547  52.506  1
294746  95.228  -72.548  52.486  1
294747  95.247  -72.553  52.465  1
294748  95.268  -72.556  52.443  1
294749  95.288  -72.561  52.420  1
294750  95.309  -72.565  52.397  1
294751  95.329  -72.570  52.373  1
294752  95.350  -72.575  52.347  1
294753  95.371  -72.578  52.322  1
294754  95.413  -72.591  52.296  1
294755  95.471  -72.609  52.272  1
294756  95.528  -72.626  52.248  1
294757  95.573  -72.627  52.225  1
294758  95.602  -72.606  52.204  1
294759  95.637  -72.597  52.182  1
294760  95.672  -72.587  52.162  1
294761  95.707  -72.578  52.142  1
294762  95.742  -72.569  52.122  1
294763  95.775  -72.566  52.103  1
294764  95.803  -72.591  52.085  1
294765  95.832  -72.615  52.067  1
294766  95.850  -72.634  52.049  1
294767  95.857  -72.646  52.030  1
294768  95.865  -72.659  52.012  1
294769  95.875  -72.672  51.995  1
294770  95.894  -72.685  51.979  1
294771  95.913  -72.698  51.963  1
294772  95.932  -72.711  51.949  1
294773  95.952  -72.724  51.935  1
294774  95.971  -72.738  51.923  1
294775  95.990  -72.750  51.912  1
294776  96.010  -72.763  51.902  1
294777  96.029  -72.777  51.892  1
294778  96.063  -72.774  51.885  1
294779  96.098  -72.772  51.878  1
294780  96.131  -72.773  51.871  1
294781  96.165  -72.776  51.866  1
294782  96.199  -72.778  51.861  1
294783  96.234  -72.777  51.856  1
294784  96.271  -72.771  51.852  1
294785  96.308  -72.765  51.845  1
294786  96.345  -72.759  51.833  1
294787  96.382  -72.753  51.819  1
294788  96.419  -72.747  51.803  1
294789  96.449  -72.751  51.783  1
294790  96.476  -72.758  51.759  1
294791  96.505  -72.766  51.735  1
294792  96.532  -72.773  51.711  1
294793  96.560  -72.780  51.687  1
294794  96.588  -72.788  51.665  1
294795  96.631  -72.790  51.642  1
294796  96.682  -72.789  51.617  1
294797  96.724  -72.788  51.591  1
294798  96.757  -72.788  51.561  1
294799  96.790  -72.786  51.530  1
294800  96.821  -72.783  51.500  1
294801  96.851  -72.779  51.476  1
294802  96.881  -72.774  51.455  1
294803  96.913  -72.776  51.434  1
294804  96.946  -72.779  51.412  1
294805  96.979  -72.782  51.388  1
294806  97.012  -72.785  51.360  1
294807  97.044  -72.788  51.330  1
294808  97.078  -72.791  51.298  1
294809  97.135  -72.794  51.263  1
294810  97.187  -72.795  51.230  1
294811  97.214  -72.785  51.198  1
294812  97.250  -72.786  51.166  1
294813  97.286  -72.788  51.135  1
294814  97.319  -72.792  51.102  1
294815  97.337  -72.813  51.068  1
294816  97.355  -72.833  51.034  1
294817  97.381  -72.829  51.004  1
294818  97.413  -72.809  50.972  1
294819  97.444  -72.788  50.935  1
294820  97.475  -72.768  50.896  1
294821  97.507  -72.747  50.854  1
294822  97.538  -72.727  50.803  1
294823  97.575  -72.727  50.751  1
294824  97.612  -72.735  50.700  1
294825  97.650  -72.744  50.648  1
294826  97.688  -72.752  50.598  1
294827  97.726  -72.760  50.547  1
294828  97.763  -72.768  50.495  1
294829  97.801  -72.776  50.441  1
294830  97.839  -72.785  50.388  1
294831  97.875  -72.791  50.336  1
294832  97.905  -72.795  50.284  1
294833  97.935  -72.800  50.232  1
294834  97.968  -72.810  50.179  1
294835  98.008  -72.826  50.124  1
294836  98.047  -72.841  50.069  1
294837  98.086  -72.857  50.016  1
294838  98.126  -72.873  49.967  1
294839  98.162  -72.886  49.918  1
294840  98.174  -72.873  49.870  1
294841  98.245  -72.838  49.821  1
294842  98.316  -72.816  49.770  1
294843  98.359  -72.818  49.721  1
294844  98.403  -72.821  49.672  1
294845  98.432  -72.852  49.622  1
294846  98.457  -72.891  49.574  1
294847  98.483  -72.931  49.524  1
294848  98.508  -72.970  49.473  1
294849  98.534  -73.004  49.423  1
294850  98.552  -73.027  49.374  1
294851  98.561  -73.051  49.323  1
294852  98.570  -73.073  49.272  1
294853  98.581  -73.086  49.222  1
294854  98.594  -73.056  49.172  1
294855  98.610  -73.046  49.122  1
294856  98.627  -73.036  49.073  1
294857  98.658  -73.067  49.026  1
294858  98.718  -73.095  48.978  1
294859  98.766  -73.126  48.931  1
294860  98.812  -73.157  48.884  1
294861  98.860  -73.189  48.836  1
294862  98.895  -73.218  48.788  1
294863  98.896  -73.246  48.740  1
294864  98.927  -73.277  48.692  1
294865  98.967  -73.308  48.645  1
294866  99.006  -73.340  48.597  1
294867  99.046  -73.371  48.549  1
294868  99.052  -73.371  48.502  1
294869  99.056  -73.370  48.455  1
294870  99.072  -73.370  48.407  1
294871  99.167  -73.402  48.360  1
294872  99.205  -73.426  48.312  1
294873  99.242  -73.451  48.263  1
294874  99.268  -73.459  48.215  1
294875  99.292  -73.466  48.171  1
294876  99.316  -73.473  48.124  1
294877  99.341  -73.481  48.078  1
294878  99.366  -73.478  48.032  1
294879  99.394  -73.451  47.986  1
294880  99.422  -73.423  47.941  1
294881  99.448  -73.427  47.896  1
294882  99.474  -73.467  47.852  1
294883  99.503  -73.500  47.808  1
294884  99.545  -73.516  47.763  1
294885  99.586  -73.532  47.718  1
294886  99.626  -73.541  47.673  1
294887  99.665  -73.546  47.629  1
294888  99.705  -73.552  47.586  1
294889  99.745  -73.557  47.541  1
294890  99.784  -73.563  47.497  1
294891  99.823  -73.568  47.452  1
294892  99.863  -73.574  47.408  1
294893  99.900  -73.581  47.364  1
294894  99.934  -73.591  47.320  1
294895  99.969  -73.601  47.276  1
294896  100.003  -73.611  47.233  1
294897  100.039  -73.620  47.191  1
294898  100.076  -73.628  47.149  1
294899  100.113  -73.637  47.108  1
294900  100.150  -73.646  47.068  1
294901  100.187  -73.654  47.031  1
294902  100.224  -73.663  46.995  1
294903  100.261  -73.672  46.960  1
294904  100.298  -73.680  46.925  1
294905  100.326  -73.694  46.891  1
294906  100.344  -73.714  46.858  1
294907  100.363  -73.732  46.826  1
294908  100.397  -73.741  46.797  1
294909  100.429  -73.750  46.767  1
294910  100.463  -73.758  46.734  1
294911  100.487  -73.755  46.700  1
294912  100.506  -73.745  46.666  1
294913  100.525  -73.735  46.633  1
294914  100.545  -73.725  46.600  1
294915  100.564  -73.716  46.567  1
294916  100.583  -73.706  46.534  1
294917  100.603  -73.696  46.502  1
294918  100.622  -73.687  46.471  1
294919  100.651  -73.688  46.440  1
294920  100.680  -73.690  46.412  1
294921  100.708  -73.692  46.382  1
294922  100.737  -73.694  46.351  1
294923  100.765  -73.695  46.318  1
294924  100.794  -73.697  46.284  1
294925  100.823  -73.699  46.250  1
294926  100.851  -73.700  46.215  1
294927  100.925  -73.822  46.180  1
294928  100.964  -73.838  46.147  1
294929  101.001  -73.853  46.112  1
294930  101.039  -73.869  46.077  1
294931  101.077  -73.884  46.042  1
294932  101.115  -73.899  46.007  1
294933  101.153  -73.914  45.972  1
294934  101.182  -73.929  45.937  1
294935  101.211  -73.944  45.904  1
294936  101.241  -73.960  45.871  1
294937  101.269  -73.975  45.837  1
294938  101.299  -73.990  45.803  1
294939  101.328  -74.005  45.768  1
294940  101.357  -74.020  45.733  1
294941  101.386  -74.035  45.701  1
294942  101.416  -74.052  45.669  1
294943  101.447  -74.071  45.637  1
294944  101.478  -74.090  45.605  1
294945  101.509  -74.109  45.573  1
294946  101.540  -74.128  45.541  1
294947  101.571  -74.147  45.510  1
294948  101.602  -74.166  45.478  1
294949  101.633  -74.185  45.448  1
294950  101.669  -74.202  45.419  1
294951  101.713  -74.217  45.388  1
294952  101.758  -74.232  45.358  1
294953  101.802  -74.246  45.329  1
294954  101.847  -74.261  45.299  1
294955  101.891  -74.276  45.270  1
294956  101.936  -74.291  45.240  1
294957  101.980  -74.305  45.212  1
294958  102.025  -74.320  45.182  1
294959  102.066  -74.323  45.152  1
294960  102.098  -74.295  45.121  1
294961  102.115  -74.272  45.092  1
294962  102.136  -74.273  45.062  1
294963  102.160  -74.273  45.032  1
294964  102.182  -74.274  45.002  1
294965  102.205  -74.276  44.970  1
294966  102.229  -74.277  44.941  1
294967  102.251  -74.277  44.911  1
294968  102.274  -74.279  44.882  1
294969  102.298  -74.280  44.854  1
294970  102.321  -74.280  44.824  1
294971  102.343  -74.281  44.794  1
295446  95.214  -72.509  52.504  1
295447  95.239  -72.516  52.485  1
295448  95.250  -72.518  52.464  1
295449  95.271  -72.522  52.442  1
295450  95.291  -72.526  52.419  1
295451  95.312  -72.531  52.395  1
295452  95.332  -72.535  52.371  1
295453  95.353  -72.540  52.345  1
295454  95.374  -72.544  52.319  1
295455  95.418  -72.556  52.294  1
295456  95.475  -72.574  52.268  1
295457  95.532  -72.592  52.245  1
295458  95.568  -72.581  52.222  1
295459  95.598  -72.561  52.200  1
295460  95.633  -72.552  52.179  1
295461  95.668  -72.542  52.159  1
295462  95.703  -72.533  52.139  1
295463  95.738  -72.524  52.120  1
295464  95.767  -72.537  52.102  1
295465  95.795  -72.562  52.084  1
295466  95.824  -72.586  52.065  1
295467  95.852  -72.610  52.046  1
295468  95.860  -72.622  52.028  1
295469  95.867  -72.635  52.010  1
295470  95.874  -72.648  51.992  1
295471  95.881  -72.660  51.976  1
295472  95.896  -72.673  51.960  1
295473  95.915  -72.687  51.945  1
295474  95.935  -72.700  51.931  1
295475  95.954  -72.713  51.919  1
295476  95.973  -72.726  51.908  1
295477  95.994  -72.738  51.898  1
295478  96.029  -72.735  51.890  1
295479  96.063  -72.732  51.883  1
295480  96.098  -72.730  51.877  1
295481  96.132  -72.732  51.871  1
295482  96.166  -72.735  51.865  1
295483  96.199  -72.737  51.860  1
295484  96.233  -72.739  51.855  1
295485  96.267  -72.741  51.849  1
295486  96.304  -72.735  51.840  1
295487  96.340  -72.729  51.829  1
295488  96.378  -72.723  51.815  1
295489  96.414  -72.717  51.801  1
295490  96.447  -72.719  51.782  1
295491  96.474  -72.725  51.760  1
295492  96.503  -72.733  51.737  1
295493  96.531  -72.741  51.716  1
295494  96.558  -72.747  51.694  1
295495  96.602  -72.750  51.674  1
295496  96.653  -72.749  51.652  1
295497  96.702  -72.748  51.627  1
295498  96.736  -72.747  51.599  1
295499  96.768  -72.746  51.569  1
295500  96.802  -72.745  51.539  1
295501  96.833  -72.742  51.510  1
295502  96.863  -72.738  51.487  1
295503  96.893  -72.734  51.465  1
295504  96.924  -72.729  51.443  1
295505  96.956  -72.732  51.419  1
295506  96.989  -72.735  51.394  1
295507  97.022  -72.738  51.367  1
295508  97.054  -72.742  51.339  1
295509  97.087  -72.745  51.309  1
295510  97.141  -72.747  51.276  1
295511  97.197  -72.750  51.244  1
295512  97.239  -72.746  51.212  1
295513  97.271  -72.742  51.180  1
295514  97.307  -72.744  51.146  1
295515  97.342  -72.747  51.113  1
295516  97.359  -72.768  51.077  1
295517  97.377  -72.788  51.042  1
295518  97.397  -72.802  51.011  1
295519  97.429  -72.782  50.976  1
295520  97.460  -72.761  50.938  1
295521  97.492  -72.741  50.897  1
295522  97.523  -72.720  50.852  1
295523  97.555  -72.701  50.802  1
295524  97.593  -72.710  50.749  1
295525  97.631  -72.717  50.696  1
295526  97.668  -72.725  50.642  1
295527  97.706  -72.734  50.592  1
295528  97.744  -72.742  50.539  1
295529  97.781  -72.750  50.485  1
295530  97.819  -72.758  50.429  1
295531  97.857  -72.766  50.377  1
295532  97.894  -72.775  50.324  1
295533  97.932  -72.782  50.273  1
295534  97.962  -72.788  50.224  1
295535  97.994  -72.797  50.174  1
295536  98.025  -72.804  50.120  1
295537  98.057  -72.813  50.066  1
295538  98.092  -72.824  50.013  1
295539  98.131  -72.840  49.960  1
295540  98.170  -72.856  49.910  1
295541  98.205  -72.867  49.861  1
295542  98.217  -72.854  49.813  1
295543  98.261  -72.829  49.762  1
295544  98.354  -72.787  49.712  1
295545  98.411  -72.776  49.662  1
295546  98.438  -72.813  49.613  1
295547  98.463  -72.852  49.565  1
295548  98.489  -72.891  49.517  1
295549  98.515  -72.930  49.468  1
295550  98.541  -72.968  49.420  1
295551  98.552  -72.992  49.371  1
295552  98.565  -73.017  49.320  1
295553  98.579  -73.041  49.269  1
295554  98.595  -73.039  49.217  1
295555  98.611  -73.029  49.167  1
295556  98.628  -73.019  49.117  1
295557  98.645  -73.012  49.069  1
295558  98.675  -73.038  49.021  1
295559  98.713  -73.090  48.974  1
295560  98.792  -73.111  48.927  1
295561  98.839  -73.142  48.879  1
295562  98.886  -73.174  48.832  1
295563  98.909  -73.202  48.784  1
295564  98.910  -73.230  48.736  1
295565  98.944  -73.261  48.688  1
295566  98.984  -73.292  48.641  1
295567  99.013  -73.314  48.594  1
295568  99.018  -73.313  48.545  1
295569  99.022  -73.311  48.499  1
295570  99.027  -73.311  48.452  1
295571  99.135  -73.330  48.404  1
295572  99.173  -73.355  48.355  1
295573  99.210  -73.380  48.307  1
295574  99.248  -73.404  48.259  1
295575  99.281  -73.423  48.211  1
295576  99.305  -73.430  48.166  1
295577  99.330  -73.437  48.120  1
295578  99.354  -73.444  48.074  1
295579  99.378  -73.452  48.029  1
295580  99.403  -73.459  47.984  1
295581  99.428  -73.460  47.938  1
295582  99.455  -73.432  47.893  1
295583  99.483  -73.411  47.849  1
295584  99.508  -73.450  47.804  1
295585  99.541  -73.480  47.759  1
295586  99.582  -73.496  47.714  1
295587  99.623  -73.506  47.670  1
295588  99.662  -73.512  47.626  1
295589  99.702  -73.517  47.582  1
295590  99.741  -73.522  47.538  1
295591  99.780  -73.528  47.493  1
295592  99.819  -73.534  47.449  1
295593  99.853  -73.544  47.404  1
295594  99.888  -73.553  47.359  1
295595  99.922  -73.563  47.315  1
295596  99.957  -73.573  47.271  1
295597  99.991  -73.583  47.228  1
295598  100.028  -73.591  47.185  1
295599  100.065  -73.600  47.143  1
295600  100.103  -73.609  47.101  1
295601  100.139  -73.618  47.061  1
295602  100.177  -73.626  47.023  1
295603  100.213  -73.634  46.987  1
295604  100.251  -73.644  46.951  1
295605  100.287  -73.652  46.916  1
295606  100.325  -73.661  46.881  1
295607  100.361  -73.669  46.848  1
295608  100.396  -73.680  46.815  1
295609  100.413  -73.700  46.786  1
295610  100.444  -73.709  46.755  1
295611  100.477  -73.718  46.723  1
295612  100.497  -73.709  46.689  1
295613  100.516  -73.699  46.654  1
295614  100.536  -73.688  46.621  1
295615  100.555  -73.678  46.588  1
295616  100.574  -73.669  46.555  1
295617  100.593  -73.659  46.523  1
295618  100.613  -73.649  46.491  1
295619  100.632  -73.639  46.459  1
295620  100.651  -73.629  46.428  1
295621  100.679  -73.630  46.399  1
295622  100.707  -73.631  46.370  1
295623  100.736  -73.634  46.338  1
295624  100.765  -73.635  46.306  1
295625  100.793  -73.637  46.273  1
295626  100.822  -73.638  46.238  1
295627  100.848  -73.650  46.202  1
295628  100.933  -73.787  46.167  1
295629  100.972  -73.802  46.134  1
295630  101.009  -73.817  46.100  1
295631  101.048  -73.832  46.065  1
295632  101.086  -73.847  46.030  1
295633  101.123  -73.863  45.996  1
295634  101.162  -73.878  45.961  1
295635  101.199  -73.893  45.927  1
295636  101.231  -73.908  45.893  1
295637  101.260  -73.923  45.860  1
295638  101.289  -73.938  45.826  1
295639  101.318  -73.954  45.791  1
295640  101.347  -73.969  45.757  1
295641  101.376  -73.984  45.722  1
295642  101.405  -73.999  45.690  1
295643  101.436  -74.018  45.658  1
295644  101.467  -74.037  45.625  1
295645  101.498  -74.056  45.593  1
295646  101.529  -74.075  45.560  1
295647  101.560  -74.094  45.529  1
295648  101.592  -74.113  45.498  1
295649  101.622  -74.132  45.467  1
295650  101.653  -74.151  45.436  1
295651  101.685  -74.170  45.406  1
295652  101.724  -74.186  45.376  1
295653  101.768  -74.201  45.345  1
295654  101.813  -74.215  45.316  1
295655  101.857  -74.230  45.287  1
295656  101.902  -74.245  45.257  1
295657  101.946  -74.260  45.229  1
295658  101.991  -74.274  45.200  1
295659  102.035  -74.289  45.170  1
295660  102.069  -74.269  45.140  1
295661  102.102  -74.242  45.110  1
295662  102.132  -74.233  45.080  1
295663  102.157  -74.233  45.049  1
295664  102.180  -74.234  45.019  1
295665  102.203  -74.236  44.989  1
295666  102.226  -74.236  44.958  1
295667  102.249  -74.237  44.928  1
295668  102.272  -74.239  44.899  1
295669  102.295  -74.239  44.869  1
295670  102.318  -74.240  44.841  1
295671  102.341  -74.241  44.811  1
295672  102.364  -74.242  44.781  1
296148  95.239  -72.480  52.483  1
296149  95.256  -72.484  52.462  1
296150  95.274  -72.487  52.440  1
296151  95.295  -72.491  52.417  1
296152  95.315  -72.496  52.393  1
296153  95.335  -72.500  52.369  1
296154  95.356  -72.504  52.342  1
296155  95.377  -72.509  52.317  1
296156  95.422  -72.522  52.291  1
296157  95.479  -72.540  52.265  1
296158  95.536  -72.556  52.242  1
296159  95.564  -72.534  52.220  1
296160  95.595  -72.515  52.197  1
296161  95.629  -72.506  52.176  1
296162  95.665  -72.497  52.156  1
296163  95.699  -72.487  52.136  1
296164  95.733  -72.484  52.118  1
296165  95.759  -72.508  52.100  1
296166  95.788  -72.532  52.082  1
296167  95.817  -72.557  52.063  1
296168  95.846  -72.582  52.044  1
296169  95.862  -72.599  52.026  1
296170  95.869  -72.612  52.008  1
296171  95.876  -72.625  51.990  1
296172  95.884  -72.637  51.974  1
296173  95.891  -72.650  51.958  1
296174  95.899  -72.663  51.942  1
296175  95.918  -72.675  51.928  1
296176  95.938  -72.688  51.916  1
296177  95.960  -72.698  51.905  1
296178  95.995  -72.695  51.895  1
296179  96.030  -72.692  51.887  1
296180  96.064  -72.690  51.881  1
296181  96.099  -72.688  51.875  1
296182  96.132  -72.691  51.869  1
296183  96.166  -72.693  51.864  1
296184  96.200  -72.695  51.858  1
296185  96.234  -72.697  51.851  1
296186  96.267  -72.700  51.844  1
296187  96.301  -72.702  51.833  1
296188  96.336  -72.700  51.822  1
296189  96.373  -72.694  51.809  1
296190  96.410  -72.688  51.796  1
296191  96.445  -72.685  51.777  1
296192  96.473  -72.693  51.756  1
296193  96.501  -72.700  51.735  1
296194  96.529  -72.707  51.717  1
296195  96.573  -72.709  51.698  1
296196  96.624  -72.709  51.680  1
296197  96.674  -72.708  51.659  1
296198  96.714  -72.707  51.634  1
296199  96.747  -72.707  51.606  1
296200  96.781  -72.705  51.576  1
296201  96.814  -72.704  51.547  1
296202  96.846  -72.701  51.519  1
296203  96.875  -72.697  51.495  1
296204  96.905  -72.693  51.471  1
296205  96.936  -72.688  51.447  1
296206  96.966  -72.686  51.423  1
296207  96.999  -72.689  51.397  1
296208  97.032  -72.692  51.371  1
296209  97.065  -72.695  51.345  1
296210  97.097  -72.699  51.317  1
296211  97.148  -72.701  51.286  1
296212  97.205  -72.704  51.255  1
296213  97.261  -72.707  51.223  1
296214  97.293  -72.698  51.189  1
296215  97.328  -72.700  51.153  1
296216  97.363  -72.703  51.117  1
296217  97.381  -72.723  51.082  1
296218  97.399  -72.744  51.047  1
296219  97.417  -72.764  51.014  1
296220  97.445  -72.754  50.978  1
296221  97.476  -72.734  50.938  1
296222  97.508  -72.713  50.895  1
296223  97.539  -72.693  50.850  1
296224  97.573  -72.683  50.801  1
296225  97.611  -72.691  50.748  1
296226  97.649  -72.700  50.693  1
296227  97.686  -72.708  50.638  1
296228  97.724  -72.716  50.587  1
296229  97.761  -72.724  50.536  1
296230  97.799  -72.732  50.482  1
296231  97.837  -72.741  50.425  1
296232  97.875  -72.748  50.370  1
296233  97.913  -72.757  50.317  1
296234  97.947  -72.758  50.265  1
296235  97.983  -72.768  50.215  1
296236  98.016  -72.779  50.166  1
296237  98.050  -72.789  50.113  1
296238  98.083  -72.801  50.060  1
296239  98.115  -72.810  50.007  1
296240  98.147  -72.818  49.955  1
296241  98.178  -72.826  49.906  1
296242  98.215  -72.839  49.858  1
296243  98.248  -72.848  49.809  1
296244  98.260  -72.835  49.759  1
296245  98.360  -72.790  49.708  1
296246  98.415  -72.756  49.658  1
296247  98.441  -72.775  49.609  1
296248  98.466  -72.813  49.561  1
296249  98.492  -72.853  49.514  1
296250  98.517  -72.892  49.466  1
296251  98.543  -72.931  49.417  1
296252  98.568  -72.961  49.368  1
296253  98.581  -72.986  49.317  1
296254  98.595  -73.011  49.266  1
296255  98.612  -73.012  49.215  1
296256  98.628  -73.002  49.165  1
296257  98.644  -72.992  49.115  1
296258  98.664  -72.990  49.065  1
296259  98.693  -73.008  49.016  1
296260  98.731  -73.061  48.969  1
296261  98.769  -73.114  48.922  1
296262  98.865  -73.127  48.874  1
296263  98.912  -73.158  48.826  1
296264  98.924  -73.186  48.779  1
296265  98.925  -73.214  48.731  1
296266  98.961  -73.245  48.684  1
296267  98.980  -73.256  48.637  1
296268  98.984  -73.255  48.590  1
296269  98.989  -73.254  48.541  1
296270  98.993  -73.252  48.494  1
296271  98.998  -73.252  48.447  1
296272  99.140  -73.283  48.400  1
296273  99.178  -73.308  48.351  1
296274  99.215  -73.333  48.303  1
296275  99.253  -73.358  48.255  1
296276  99.290  -73.382  48.208  1
296277  99.319  -73.394  48.162  1
296278  99.343  -73.401  48.116  1
296279  99.367  -73.409  48.071  1
296280  99.392  -73.415  48.026  1
296281  99.416  -73.423  47.981  1
296282  99.440  -73.430  47.935  1
296283  99.465  -73.437  47.890  1
296284  99.489  -73.442  47.846  1
296285  99.517  -73.414  47.801  1
296286  99.543  -73.434  47.756  1
296287  99.579  -73.459  47.712  1
296288  99.620  -73.471  47.668  1
296289  99.659  -73.476  47.623  1
296290  99.698  -73.482  47.579  1
296291  99.737  -73.487  47.534  1
296292  99.773  -73.496  47.490  1
296293  99.807  -73.506  47.445  1
296294  99.842  -73.516  47.400  1
296295  99.876  -73.526  47.355  1
296296  99.911  -73.536  47.310  1
296297  99.945  -73.546  47.266  1
296298  99.981  -73.555  47.223  1
296299  100.017  -73.563  47.180  1
296300  100.055  -73.572  47.137  1
296301  100.091  -73.581  47.095  1
296302  100.129  -73.589  47.055  1
296303  100.165  -73.598  47.017  1
296304  100.203  -73.606  46.979  1
296305  100.240  -73.615  46.943  1
296306  100.277  -73.624  46.908  1
296307  100.314  -73.632  46.872  1
296308  100.351  -73.641  46.838  1
296309  100.388  -73.650  46.805  1
296310  100.424  -73.659  46.774  1
296311  100.462  -73.667  46.744  1
296312  100.488  -73.672  46.712  1
296313  100.507  -73.662  46.677  1
296314  100.526  -73.652  46.643  1
296315  100.546  -73.642  46.610  1
296316  100.565  -73.632  46.577  1
296317  100.584  -73.622  46.544  1
296318  100.603  -73.612  46.512  1
296319  100.623  -73.603  46.480  1
296320  100.642  -73.592  46.447  1
296321  100.661  -73.582  46.416  1
296322  100.680  -73.572  46.386  1
296323  100.707  -73.571  46.357  1
296324  100.736  -73.573  46.326  1
296325  100.764  -73.575  46.293  1
296326  100.792  -73.577  46.260  1
296327  100.821  -73.578  46.226  1
296328  100.857  -73.616  46.191  1
296329  100.941  -73.750  46.157  1
296330  100.980  -73.766  46.124  1
296331  101.018  -73.781  46.089  1
296332  101.056  -73.796  46.055  1
296333  101.094  -73.811  46.021  1
296334  101.131  -73.826  45.987  1
296335  101.170  -73.842  45.951  1
296336  101.207  -73.857  45.918  1
296337  101.246  -73.872  45.884  1
296338  101.279  -73.888  45.850  1
296339  101.308  -73.903  45.815  1
296340  101.337  -73.918  45.781  1
296341  101.367  -73.933  45.747  1
296342  101.395  -73.948  45.712  1
296343  101.425  -73.965  45.680  1
296344  101.456  -73.984  45.647  1
296345  101.487  -74.003  45.614  1
296346  101.519  -74.022  45.581  1
296347  101.550  -74.041  45.549  1
296348  101.581  -74.060  45.517  1
296349  101.612  -74.078  45.486  1
296350  101.643  -74.097  45.456  1
296351  101.674  -74.116  45.424  1
296352  101.705  -74.135  45.394  1
296353  101.736  -74.154  45.364  1
296354  101.779  -74.170  45.334  1
296355  101.823  -74.184  45.304  1
296356  101.868  -74.199  45.275  1
296357  101.912  -74.214  45.246  1
296358  101.957  -74.228  45.217  1
296359  102.001  -74.243  45.189  1
296360  102.041  -74.242  45.158  1
296361  102.074  -74.214  45.128  1
296362  102.112  -74.195  45.098  1
296363  102.139  -74.196  45.068  1
296364  102.164  -74.197  45.037  1
296365  102.189  -74.198  45.006  1
296366  102.214  -74.198  44.976  1
296367  102.239  -74.198  44.946  1
296368  102.263  -74.199  44.915  1
296369  102.288  -74.200  44.886  1
296370  102.313  -74.201  44.857  1
296371  102.338  -74.201  44.828  1
296372  102.362  -74.202  44.798  1
296373  102.385  -74.203  44.769  1
296848  95.212  -72.435  52.502  1
296849  95.238  -72.443  52.481  1
296850  95.263  -72.450  52.461  1
296851  95.277  -72.452  52.438  1
296852  95.298  -72.456  52.414  1
296853  95.318  -72.461  52.390  1
296854  95.338  -72.465  52.365  1
296855  95.359  -72.469  52.339  1
296856  95.380  -72.474  52.314  1
296857  95.427  -72.488  52.288  1
296858  95.484  -72.506  52.263  1
296859  95.532  -72.510  52.239  1
296860  95.560  -72.487  52.216  1
296861  95.591  -72.471  52.195  1
296862  95.626  -72.461  52.174  1
296863  95.661  -72.452  52.154  1
296864  95.696  -72.443  52.134  1
296865  95.725  -72.455  52.116  1
296866  95.751  -72.479  52.097  1
296867  95.780  -72.503  52.079  1
296868  95.810  -72.528  52.061  1
296869  95.839  -72.553  52.043  1
296870  95.864  -72.575  52.025  1
296871  95.871  -72.588  52.007  1
296872  95.879  -72.601  51.990  1
296873  95.886  -72.613  51.973  1
296874  95.893  -72.626  51.956  1
296875  95.900  -72.639  51.940  1
296876  95.908  -72.651  51.926  1
296877  95.926  -72.659  51.913  1
296878  95.961  -72.656  51.902  1
296879  95.995  -72.653  51.892  1
296880  96.030  -72.650  51.885  1
296881  96.065  -72.647  51.878  1
296882  96.099  -72.647  51.872  1
296883  96.133  -72.650  51.867  1
296884  96.167  -72.652  51.862  1
296885  96.200  -72.654  51.855  1
296886  96.234  -72.656  51.846  1
296887  96.268  -72.659  51.837  1
296888  96.302  -72.661  51.825  1
296889  96.335  -72.663  51.814  1
296890  96.369  -72.665  51.802  1
296891  96.406  -72.659  51.789  1
296892  96.443  -72.653  51.770  1
296893  96.471  -72.660  51.751  1
296894  96.499  -72.667  51.732  1
296895  96.544  -72.669  51.715  1
296896  96.595  -72.669  51.699  1
296897  96.645  -72.668  51.683  1
296898  96.693  -72.667  51.663  1
296899  96.726  -72.666  51.639  1
296900  96.759  -72.665  51.612  1
296901  96.792  -72.664  51.583  1
296902  96.825  -72.663  51.555  1
296903  96.858  -72.661  51.528  1
296904  96.887  -72.656  51.503  1
296905  96.918  -72.652  51.477  1
296906  96.948  -72.647  51.452  1
296907  96.978  -72.643  51.428  1
296908  97.009  -72.643  51.401  1
296909  97.042  -72.646  51.376  1
296910  97.075  -72.649  51.351  1
296911  97.107  -72.652  51.324  1
296912  97.155  -72.655  51.295  1
296913  97.211  -72.657  51.264  1
296914  97.268  -72.660  51.231  1
296915  97.317  -72.660  51.196  1
296916  97.350  -72.656  51.158  1
296917  97.385  -72.658  51.120  1
296918  97.403  -72.678  51.085  1
296919  97.421  -72.699  51.050  1
296920  97.439  -72.719  51.015  1
296921  97.461  -72.728  50.978  1
296922  97.493  -72.707  50.937  1
296923  97.524  -72.687  50.893  1
296924  97.556  -72.666  50.847  1
296925  97.591  -72.666  50.798  1
296926  97.629  -72.673  50.746  1
296927  97.667  -72.681  50.691  1
296928  97.705  -72.690  50.636  1
296929  97.742  -72.698  50.583  1
296930  97.780  -72.707  50.532  1
296931  97.817  -72.714  50.479  1
296932  97.855  -72.722  50.422  1
296933  97.889  -72.725  50.367  1
296934  97.923  -72.725  50.314  1
296935  97.957  -72.727  50.262  1
296936  97.998  -72.732  50.210  1
296937  98.032  -72.750  50.160  1
296938  98.065  -72.761  50.108  1
296939  98.098  -72.772  50.055  1
296940  98.132  -72.782  50.003  1
296941  98.165  -72.793  49.953  1
296942  98.198  -72.804  49.905  1
296943  98.231  -72.815  49.857  1
296944  98.265  -72.826  49.808  1
296945  98.305  -72.819  49.757  1
296946  98.360  -72.786  49.706  1
296947  98.414  -72.753  49.657  1
296948  98.445  -72.749  49.608  1
296949  98.467  -72.776  49.560  1
296950  98.493  -72.816  49.514  1
296951  98.518  -72.854  49.465  1
296952  98.544  -72.894  49.415  1
296953  98.584  -72.931  49.365  1
296954  98.597  -72.956  49.315  1
296955  98.610  -72.980  49.264  1
296956  98.629  -72.985  49.214  1
296957  98.645  -72.975  49.164  1
296958  98.661  -72.964  49.113  1
296959  98.684  -72.967  49.062  1
296960  98.710  -72.979  49.012  1
296961  98.748  -73.032  48.964  1
296962  98.786  -73.085  48.916  1
296963  98.824  -73.138  48.868  1
296964  98.937  -73.143  48.820  1
296965  98.938  -73.170  48.773  1
296966  98.939  -73.198  48.726  1
296967  98.946  -73.199  48.680  1
296968  98.950  -73.197  48.633  1
296969  98.955  -73.196  48.585  1
296970  98.961  -73.195  48.537  1
296971  98.968  -73.195  48.489  1
296972  99.051  -73.205  48.442  1
296973  99.145  -73.236  48.395  1
296974  99.183  -73.261  48.346  1
296975  99.221  -73.286  48.298  1
296976  99.258  -73.311  48.251  1
296977  99.296  -73.336  48.204  1
296978  99.332  -73.358  48.158  1
296979  99.356  -73.365  48.113  1
296980  99.380  -73.372  48.068  1
296981  99.405  -73.380  48.023  1
296982  99.429  -73.387  47.978  1
296983  99.453  -73.394  47.932  1
296984  99.478  -73.401  47.888  1
296985  99.502  -73.409  47.843  1
296986  99.526  -73.415  47.799  1
296987  99.551  -73.422  47.754  1
296988  99.578  -73.418  47.710  1
296989  99.616  -73.436  47.666  1
296990  99.655  -73.441  47.621  1
296991  99.692  -73.449  47.576  1
296992  99.726  -73.459  47.531  1
296993  99.761  -73.469  47.487  1
296994  99.795  -73.479  47.443  1
296995  99.830  -73.488  47.397  1
296996  99.864  -73.498  47.351  1
296997  99.899  -73.508  47.306  1
296998  99.933  -73.518  47.262  1
296999  99.970  -73.527  47.218  1
297000  100.007  -73.535  47.175  1
297001  100.044  -73.543  47.132  1
297002  100.081  -73.553  47.090  1
297003  100.118  -73.561  47.049  1
297004  100.155  -73.570  47.010  1
297005  100.192  -73.578  46.973  1
297006  100.229  -73.587  46.936  1
297007  100.266  -73.596  46.899  1
297008  100.303  -73.604  46.864  1
297009  100.342  -73.613  46.829  1
297010  100.382  -73.622  46.795  1
297011  100.422  -73.631  46.763  1
297012  100.462  -73.640  46.732  1
297013  100.491  -73.647  46.700  1
297014  100.512  -73.631  46.666  1
297015  100.534  -73.612  46.633  1
297016  100.556  -73.596  46.598  1
297017  100.575  -73.585  46.565  1
297018  100.594  -73.575  46.533  1
297019  100.613  -73.565  46.501  1
297020  100.633  -73.556  46.469  1
297021  100.652  -73.546  46.436  1
297022  100.671  -73.536  46.404  1
297023  100.690  -73.526  46.373  1
297024  100.710  -73.516  46.343  1
297025  100.735  -73.513  46.312  1
297026  100.763  -73.515  46.280  1
297027  100.792  -73.517  46.247  1
297028  100.821  -73.518  46.214  1
297029  100.867  -73.583  46.180  1
297030  100.950  -73.714  46.146  1
297031  100.988  -73.729  46.113  1
297032  101.025  -73.745  46.079  1
297033  101.064  -73.760  46.045  1
297034  101.102  -73.775  46.011  1
297035  101.140  -73.791  45.977  1
297036  101.178  -73.806  45.942  1
297037  101.215  -73.821  45.908  1
297038  101.254  -73.836  45.874  1
297039  101.291  -73.851  45.840  1
297040  101.327  -73.866  45.805  1
297041  101.356  -73.882  45.771  1
297042  101.386  -73.897  45.737  1
297043  101.415  -73.912  45.702  1
297044  101.446  -73.930  45.670  1
297045  101.477  -73.949  45.637  1
297046  101.507  -73.968  45.604  1
297047  101.539  -73.987  45.571  1
297048  101.570  -74.006  45.539  1
297049  101.601  -74.025  45.506  1
297050  101.632  -74.044  45.475  1
297051  101.663  -74.063  45.444  1
297052  101.694  -74.082  45.413  1
297053  101.725  -74.101  45.383  1
297054  101.756  -74.120  45.353  1
297055  101.790  -74.138  45.324  1
297056  101.834  -74.153  45.294  1
297057  101.878  -74.167  45.264  1
297058  101.922  -74.183  45.235  1
297059  101.967  -74.197  45.206  1
297060  102.012  -74.212  45.178  1
297061  102.045  -74.187  45.147  1
297062  102.083  -74.151  45.116  1
297063  102.122  -74.159  45.085  1
297064  102.147  -74.160  45.055  1
297065  102.172  -74.160  45.025  1
297066  102.197  -74.161  44.994  1
297067  102.222  -74.161  44.964  1
297068  102.246  -74.162  44.934  1
297069  102.271  -74.163  44.904  1
297070  102.296  -74.164  44.874  1
297071  102.321  -74.164  44.845  1
297072  102.345  -74.164  44.815  1
297073  102.370  -74.165  44.787  1
297074  102.395  -74.166  44.757  1
297549  95.211  -72.398  52.499  1
297550  95.237  -72.406  52.478  1
297551  95.262  -72.413  52.457  1
297552  95.285  -72.419  52.434  1
297553  95.301  -72.421  52.411  1
297554  95.321  -72.426  52.387  1
297555  95.342  -72.431  52.363  1
297556  95.362  -72.434  52.336  1
297557  95.383  -72.439  52.311  1
297558  95.431  -72.453  52.285  1
297559  95.488  -72.471  52.260  1
297560  95.527  -72.463  52.236  1
297561  95.555  -72.441  52.214  1
297562  95.587  -72.425  52.192  1
297563  95.622  -72.416  52.170  1
297564  95.657  -72.406  52.151  1
297565  95.691  -72.402  52.131  1
297566  95.717  -72.426  52.112  1
297567  95.744  -72.450  52.094  1
297568  95.773  -72.475  52.077  1
297569  95.802  -72.500  52.060  1
297570  95.831  -72.524  52.042  1
297571  95.861  -72.549  52.023  1
297572  95.874  -72.565  52.006  1
297573  95.881  -72.578  51.989  1
297574  95.888  -72.590  51.972  1
297575  95.895  -72.603  51.956  1
297576  95.903  -72.616  51.940  1
297577  95.910  -72.628  51.926  1
297578  95.935  -72.625  51.913  1
297579  95.969  -72.622  51.900  1
297580  96.004  -72.619  51.890  1
297581  96.038  -72.616  51.882  1
297582  96.074  -72.611  51.875  1
297583  96.112  -72.606  51.869  1
297584  96.144  -72.607  51.864  1
297585  96.175  -72.609  51.858  1
297586  96.206  -72.613  51.849  1
297587  96.238  -72.615  51.839  1
297588  96.269  -72.617  51.828  1
297589  96.302  -72.619  51.817  1
297590  96.335  -72.622  51.806  1
297591  96.369  -72.624  51.794  1
297592  96.403  -72.626  51.781  1
297593  96.439  -72.623  51.762  1
297594  96.469  -72.628  51.743  1
297595  96.515  -72.628  51.726  1
297596  96.566  -72.628  51.711  1
297597  96.616  -72.628  51.697  1
297598  96.667  -72.627  51.683  1
297599  96.705  -72.626  51.665  1
297600  96.738  -72.625  51.642  1
297601  96.771  -72.624  51.616  1
297602  96.804  -72.623  51.589  1
297603  96.837  -72.622  51.563  1
297604  96.870  -72.620  51.537  1
297605  96.900  -72.616  51.513  1
297606  96.930  -72.611  51.486  1
297607  96.960  -72.606  51.460  1
297608  96.990  -72.603  51.435  1
297609  97.020  -72.598  51.409  1
297610  97.052  -72.600  51.385  1
297611  97.085  -72.603  51.360  1
297612  97.117  -72.606  51.333  1
297613  97.161  -72.609  51.303  1
297614  97.218  -72.611  51.272  1
297615  97.275  -72.614  51.237  1
297616  97.331  -72.616  51.200  1
297617  97.371  -72.613  51.161  1
297618  97.406  -72.615  51.123  1
297619  97.425  -72.634  51.085  1
297620  97.443  -72.654  51.048  1
297621  97.461  -72.675  51.012  1
297622  97.478  -72.695  50.975  1
297623  97.509  -72.680  50.935  1
297624  97.540  -72.660  50.891  1
297625  97.572  -72.639  50.844  1
297626  97.609  -72.647  50.795  1
297627  97.647  -72.656  50.744  1
297628  97.685  -72.664  50.690  1
297629  97.723  -72.672  50.634  1
297630  97.760  -72.680  50.580  1
297631  97.798  -72.688  50.528  1
297632  97.832  -72.691  50.475  1
297633  97.866  -72.692  50.421  1
297634  97.900  -72.693  50.367  1
297635  97.934  -72.694  50.316  1
297636  97.967  -72.696  50.265  1
297637  98.008  -72.700  50.213  1
297638  98.052  -72.707  50.159  1
297639  98.081  -72.732  50.106  1
297640  98.114  -72.743  50.054  1
297641  98.147  -72.754  50.005  1
297642  98.180  -72.765  49.957  1
297643  98.214  -72.776  49.907  1
297644  98.247  -72.786  49.858  1
297645  98.280  -72.797  49.808  1
297646  98.311  -72.806  49.756  1
297647  98.359  -72.782  49.708  1
297648  98.414  -72.749  49.659  1
297649  98.451  -72.737  49.610  1
297650  98.471  -72.748  49.561  1
297651  98.493  -72.778  49.514  1
297652  98.519  -72.817  49.465  1
297653  98.545  -72.857  49.415  1
297654  98.587  -72.895  49.364  1
297655  98.613  -72.925  49.314  1
297656  98.627  -72.950  49.264  1
297657  98.646  -72.957  49.213  1
297658  98.662  -72.948  49.163  1
297659  98.678  -72.938  49.111  1
297660  98.703  -72.945  49.059  1
297661  98.728  -72.952  49.009  1
297662  98.765  -73.003  48.959  1
297663  98.803  -73.055  48.910  1
297664  98.842  -73.108  48.862  1
297665  98.878  -73.158  48.815  1
297666  98.913  -73.160  48.768  1
297667  98.947  -73.161  48.720  1
297668  98.982  -73.163  48.673  1
297669  99.003  -73.163  48.627  1
297670  99.009  -73.162  48.580  1
297671  99.029  -73.163  48.532  1
297672  99.092  -73.167  48.484  1
297673  99.126  -73.178  48.437  1
297674  99.151  -73.190  48.389  1
297675  99.188  -73.214  48.342  1
297676  99.226  -73.239  48.294  1
297677  99.263  -73.264  48.247  1
297678  99.301  -73.289  48.201  1
297679  99.338  -73.314  48.156  1
297680  99.369  -73.329  48.110  1
297681  99.394  -73.336  48.065  1
297682  99.418  -73.343  48.021  1
297683  99.442  -73.351  47.975  1
297684  99.467  -73.358  47.929  1
297685  99.491  -73.365  47.885  1
297686  99.515  -73.372  47.841  1
297687  99.540  -73.379  47.797  1
297688  99.564  -73.387  47.752  1
297689  99.588  -73.393  47.708  1
297690  99.614  -73.403  47.664  1
297691  99.645  -73.412  47.619  1
297692  99.680  -73.421  47.574  1
297693  99.714  -73.431  47.529  1
297694  99.749  -73.441  47.484  1
297695  99.783  -73.451  47.439  1
297696  99.818  -73.461  47.393  1
297697  99.852  -73.471  47.347  1
297698  99.887  -73.481  47.302  1
297699  99.922  -73.490  47.258  1
297700  99.959  -73.498  47.214  1
297701  99.996  -73.507  47.170  1
297702  100.033  -73.515  47.127  1
297703  100.070  -73.524  47.084  1
297704  100.107  -73.533  47.044  1
297705  100.147  -73.542  47.004  1
297706  100.187  -73.551  46.966  1
297707  100.227  -73.559  46.928  1
297708  100.267  -73.568  46.891  1
297709  100.307  -73.578  46.855  1
297710  100.347  -73.587  46.820  1
297711  100.387  -73.595  46.785  1
297712  100.426  -73.604  46.752  1
297713  100.466  -73.613  46.720  1
297714  100.495  -73.621  46.688  1
297715  100.511  -73.620  46.655  1
297716  100.533  -73.601  46.621  1
297717  100.555  -73.582  46.587  1
297718  100.577  -73.562  46.554  1
297719  100.600  -73.543  46.522  1
297720  100.622  -73.524  46.490  1
297721  100.642  -73.509  46.458  1
297722  100.662  -73.499  46.426  1
297723  100.681  -73.489  46.394  1
297724  100.700  -73.479  46.361  1
297725  100.719  -73.469  46.330  1
297726  100.739  -73.459  46.299  1
297727  100.762  -73.455  46.267  1
297728  100.791  -73.456  46.235  1
297729  100.820  -73.459  46.201  1
297730  100.876  -73.550  46.168  1
297731  100.958  -73.678  46.135  1
297732  100.996  -73.694  46.102  1
297733  101.034  -73.709  46.068  1
297734  101.072  -73.724  46.035  1
297735  101.110  -73.739  46.001  1
297736  101.148  -73.754  45.966  1
297737  101.186  -73.769  45.933  1
297738  101.223  -73.785  45.898  1
297739  101.262  -73.800  45.865  1
297740  101.299  -73.815  45.831  1
297741  101.338  -73.831  45.796  1
297742  101.376  -73.846  45.762  1
297743  101.405  -73.861  45.727  1
297744  101.434  -73.877  45.693  1
297745  101.466  -73.896  45.660  1
297746  101.497  -73.915  45.627  1
297747  101.528  -73.934  45.594  1
297748  101.559  -73.953  45.560  1
297749  101.590  -73.972  45.529  1
297750  101.621  -73.991  45.495  1
297751  101.652  -74.010  45.463  1
297752  101.683  -74.029  45.433  1
297753  101.714  -74.048  45.401  1
297754  101.745  -74.067  45.371  1
297755  101.776  -74.085  45.341  1
297756  101.808  -74.104  45.311  1
297757  101.844  -74.122  45.280  1
297758  101.889  -74.136  45.251  1
297759  101.933  -74.151  45.222  1
297760  101.977  -74.166  45.193  1
297761  102.016  -74.160  45.164  1
297762  102.053  -74.113  45.133  1
297763  102.096  -74.117  45.103  1
297764  102.130  -74.123  45.072  1
297765  102.155  -74.123  45.042  1
297766  102.180  -74.123  45.012  1
297767  102.205  -74.124  44.982  1
297768  102.230  -74.125  44.952  1
297769  102.254  -74.126  44.922  1
297770  102.279  -74.126  44.892  1
297771  102.304  -74.126  44.862  1
297772  102.328  -74.127  44.833  1
297773  102.353  -74.128  44.803  1
297774  102.378  -74.129  44.775  1
297775  102.403  -74.129  44.745  1
298249  95.183  -72.347  52.516  1
298250  95.209  -72.361  52.496  1
298251  95.235  -72.368  52.475  1
298252  95.261  -72.376  52.454  1
298253  95.287  -72.384  52.431  1
298254  95.304  -72.387  52.408  1
298255  95.324  -72.391  52.384  1
298256  95.345  -72.396  52.360  1
298257  95.365  -72.399  52.333  1
298258  95.386  -72.404  52.308  1
298259  95.436  -72.419  52.282  1
298260  95.493  -72.437  52.257  1
298261  95.523  -72.417  52.234  1
298262  95.551  -72.395  52.211  1
298263  95.583  -72.380  52.189  1
298264  95.618  -72.371  52.167  1
298265  95.653  -72.362  52.148  1
298266  95.683  -72.372  52.128  1
298267  95.709  -72.396  52.109  1
298268  95.736  -72.421  52.092  1
298269  95.765  -72.446  52.075  1
298270  95.795  -72.471  52.058  1
298271  95.824  -72.495  52.040  1
298272  95.853  -72.520  52.022  1
298273  95.876  -72.541  52.005  1
298274  95.883  -72.554  51.988  1
298275  95.890  -72.566  51.972  1
298276  95.898  -72.579  51.956  1
298277  95.905  -72.592  51.941  1
298278  95.912  -72.602  51.926  1
298279  95.944  -72.591  51.912  1
298280  95.978  -72.587  51.899  1
298281  96.013  -72.584  51.888  1
298282  96.048  -72.581  51.879  1
298283  96.086  -72.575  51.871  1
298284  96.123  -72.569  51.865  1
298285  96.161  -72.564  51.859  1
298286  96.192  -72.567  51.852  1
298287  96.223  -72.569  51.844  1
298288  96.254  -72.572  51.833  1
298289  96.286  -72.575  51.821  1
298290  96.317  -72.577  51.809  1
298291  96.348  -72.579  51.797  1
298292  96.380  -72.582  51.785  1
298293  96.411  -72.584  51.773  1
298294  96.442  -72.587  51.754  1
298295  96.485  -72.588  51.737  1
298296  96.536  -72.587  51.722  1
298297  96.587  -72.587  51.707  1
298298  96.638  -72.587  51.694  1
298299  96.683  -72.586  51.680  1
298300  96.717  -72.585  51.662  1
298301  96.750  -72.584  51.641  1
298302  96.783  -72.583  51.616  1
298303  96.816  -72.582  51.592  1
298304  96.849  -72.581  51.568  1
298305  96.882  -72.579  51.544  1
298306  96.912  -72.575  51.520  1
298307  96.942  -72.570  51.494  1
298308  96.972  -72.566  51.468  1
298309  97.002  -72.562  51.442  1
298310  97.032  -72.557  51.417  1
298311  97.063  -72.553  51.393  1
298312  97.095  -72.556  51.368  1
298313  97.128  -72.559  51.341  1
298314  97.168  -72.562  51.310  1
298315  97.225  -72.565  51.278  1
298316  97.281  -72.568  51.243  1
298317  97.338  -72.570  51.205  1
298318  97.394  -72.572  51.166  1
298319  97.428  -72.571  51.127  1
298320  97.447  -72.590  51.088  1
298321  97.465  -72.610  51.049  1
298322  97.483  -72.631  51.010  1
298323  97.501  -72.651  50.974  1
298324  97.525  -72.653  50.933  1
298325  97.556  -72.632  50.889  1
298326  97.590  -72.622  50.842  1
298327  97.628  -72.629  50.792  1
298328  97.665  -72.638  50.741  1
298329  97.703  -72.646  50.689  1
298330  97.741  -72.654  50.634  1
298331  97.776  -72.657  50.583  1
298332  97.809  -72.658  50.533  1
298333  97.843  -72.660  50.480  1
298334  97.877  -72.660  50.426  1
298335  97.911  -72.662  50.372  1
298336  97.944  -72.663  50.321  1
298337  97.978  -72.664  50.269  1
298338  98.019  -72.669  50.216  1
298339  98.063  -72.676  50.163  1
298340  98.106  -72.683  50.110  1
298341  98.130  -72.715  50.058  1
298342  98.163  -72.725  50.008  1
298343  98.196  -72.736  49.960  1
298344  98.229  -72.747  49.909  1
298345  98.263  -72.757  49.859  1
298346  98.294  -72.767  49.809  1
298347  98.325  -72.776  49.759  1
298348  98.359  -72.779  49.710  1
298349  98.414  -72.745  49.660  1
298350  98.458  -72.724  49.610  1
298351  98.477  -72.736  49.562  1
298352  98.496  -72.747  49.515  1
298353  98.519  -72.780  49.466  1
298354  98.546  -72.819  49.416  1
298355  98.588  -72.857  49.365  1
298356  98.629  -72.895  49.315  1
298357  98.643  -72.920  49.264  1
298358  98.662  -72.929  49.213  1
298359  98.679  -72.920  49.163  1
298360  98.698  -72.916  49.109  1
298361  98.723  -72.923  49.057  1
298362  98.747  -72.930  49.006  1
298363  98.783  -72.973  48.955  1
298364  98.820  -73.026  48.907  1
298365  98.859  -73.079  48.858  1
298366  98.885  -73.104  48.810  1
298367  98.919  -73.110  48.763  1
298368  98.953  -73.113  48.716  1
298369  98.989  -73.116  48.669  1
298370  99.023  -73.120  48.622  1
298371  99.062  -73.123  48.576  1
298372  99.100  -73.127  48.528  1
298373  99.132  -73.144  48.480  1
298374  99.154  -73.154  48.432  1
298375  99.177  -73.164  48.385  1
298376  99.198  -73.173  48.338  1
298377  99.231  -73.192  48.290  1
298378  99.269  -73.217  48.244  1
298379  99.306  -73.242  48.198  1
298380  99.344  -73.267  48.153  1
298381  99.381  -73.292  48.108  1
298382  99.407  -73.300  48.063  1
298383  99.431  -73.307  48.019  1
298384  99.455  -73.314  47.973  1
298385  99.480  -73.321  47.927  1
298386  99.504  -73.329  47.883  1
298387  99.528  -73.336  47.839  1
298388  99.553  -73.343  47.795  1
298389  99.577  -73.350  47.750  1
298390  99.603  -73.360  47.706  1
298391  99.631  -73.378  47.661  1
298392  99.661  -73.391  47.616  1
298393  99.691  -73.399  47.571  1
298394  99.721  -73.409  47.526  1
298395  99.752  -73.417  47.481  1
298396  99.782  -73.426  47.435  1
298397  99.813  -73.435  47.390  1
298398  99.843  -73.443  47.344  1
298399  99.875  -73.452  47.299  1
298400  99.913  -73.462  47.255  1
298401  99.952  -73.471  47.210  1
298402  99.992  -73.479  47.166  1
298403  100.032  -73.488  47.122  1
298404  100.072  -73.497  47.079  1
298405  100.112  -73.506  47.038  1
298406  100.152  -73.515  46.998  1
298407  100.192  -73.524  46.959  1
298408  100.231  -73.533  46.920  1
298409  100.271  -73.542  46.884  1
298410  100.312  -73.551  46.848  1
298411  100.351  -73.559  46.811  1
298412  100.391  -73.568  46.776  1
298413  100.431  -73.578  46.742  1
298414  100.471  -73.587  46.709  1
298415  100.498  -73.593  46.676  1
298416  100.513  -73.600  46.643  1
298417  100.532  -73.590  46.610  1
298418  100.554  -73.571  46.577  1
298419  100.576  -73.552  46.544  1
298420  100.599  -73.532  46.512  1
298421  100.621  -73.513  46.480  1
298422  100.643  -73.494  46.449  1
298423  100.665  -73.474  46.417  1
298424  100.687  -73.456  46.385  1
298425  100.709  -73.437  46.352  1
298426  100.729  -73.423  46.321  1
298427  100.749  -73.413  46.289  1
298428  100.768  -73.402  46.257  1
298429  100.790  -73.396  46.224  1
298430  100.819  -73.398  46.191  1
298431  100.885  -73.515  46.158  1
298432  100.966  -73.642  46.125  1
298433  101.004  -73.657  46.092  1
298434  101.042  -73.672  46.059  1
298435  101.080  -73.687  46.025  1
298436  101.118  -73.703  45.991  1
298437  101.156  -73.718  45.957  1
298438  101.194  -73.734  45.923  1
298439  101.232  -73.749  45.889  1
298440  101.270  -73.764  45.855  1
298441  101.308  -73.779  45.822  1
298442  101.346  -73.794  45.787  1
298443  101.384  -73.810  45.752  1
298444  101.421  -73.825  45.718  1
298445  101.455  -73.843  45.683  1
298446  101.486  -73.862  45.650  1
298447  101.517  -73.881  45.617  1
298448  101.548  -73.900  45.583  1
298449  101.579  -73.919  45.550  1
298450  101.610  -73.938  45.517  1
298451  101.641  -73.957  45.484  1
298452  101.672  -73.976  45.452  1
298453  101.703  -73.995  45.421  1
298454  101.735  -74.013  45.389  1
298455  101.765  -74.032  45.359  1
298456  101.796  -74.051  45.328  1
298457  101.828  -74.070  45.298  1
298458  101.858  -74.089  45.267  1
298459  101.899  -74.105  45.237  1
298460  101.944  -74.120  45.209  1
298461  101.987  -74.133  45.180  1
298462  102.023  -74.091  45.150  1
298463  102.066  -74.073  45.119  1
298464  102.109  -74.082  45.088  1
298465  102.138  -74.085  45.058  1
298466  102.163  -74.086  45.028  1
298467  102.188  -74.087  44.999  1
298468  102.212  -74.088  44.970  1
298469  102.237  -74.088  44.940  1
298470  102.262  -74.089  44.910  1
298471  102.287  -74.089  44.878  1
298472  102.312  -74.090  44.850  1
298473  102.336  -74.091  44.821  1
298474  102.361  -74.092  44.791  1
298475  102.386  -74.092  44.762  1
298949  95.155  -72.287  52.532  1
298950  95.181  -72.302  52.512  1
298951  95.208  -72.316  52.491  1
298952  95.234  -72.330  52.470  1
298953  95.260  -72.339  52.449  1
298954  95.285  -72.346  52.427  1
298955  95.311  -72.353  52.404  1
298956  95.327  -72.356  52.380  1
298957  95.348  -72.361  52.355  1
298958  95.368  -72.365  52.330  1
298959  95.389  -72.369  52.304  1
298960  95.440  -72.385  52.278  1
298961  95.490  -72.393  52.254  1
298962  95.519  -72.371  52.231  1
298963  95.547  -72.348  52.208  1
298964  95.580  -72.335  52.186  1
298965  95.615  -72.325  52.165  1
298966  95.649  -72.319  52.144  1
298967  95.675  -72.343  52.125  1
298968  95.701  -72.368  52.106  1
298969  95.729  -72.392  52.089  1
298970  95.758  -72.417  52.073  1
298971  95.788  -72.442  52.055  1
298972  95.816  -72.466  52.038  1
298973  95.845  -72.491  52.021  1
298974  95.875  -72.515  52.005  1
298975  95.885  -72.531  51.987  1
298976  95.893  -72.543  51.971  1
298977  95.900  -72.556  51.956  1
298978  95.907  -72.568  51.941  1
298979  95.918  -72.560  51.925  1
298980  95.953  -72.557  51.911  1
298981  95.987  -72.554  51.898  1
298982  96.022  -72.551  51.885  1
298983  96.059  -72.545  51.876  1
298984  96.097  -72.540  51.868  1
298985  96.135  -72.534  51.861  1
298986  96.173  -72.528  51.854  1
298987  96.209  -72.524  51.847  1
298988  96.240  -72.526  51.838  1
298989  96.271  -72.529  51.827  1
298990  96.303  -72.531  51.814  1
298991  96.334  -72.534  51.802  1
298992  96.365  -72.537  51.790  1
298993  96.397  -72.539  51.777  1
298994  96.428  -72.541  51.764  1
298995  96.458  -72.540  51.747  1
298996  96.507  -72.547  51.732  1
298997  96.557  -72.547  51.718  1
298998  96.608  -72.547  51.703  1
298999  96.659  -72.546  51.690  1
299000  96.695  -72.545  51.674  1
299001  96.729  -72.544  51.656  1
299002  96.761  -72.543  51.636  1
299003  96.795  -72.542  51.614  1
299004  96.828  -72.541  51.593  1
299005  96.861  -72.540  51.571  1
299006  96.894  -72.538  51.549  1
299007  96.924  -72.534  51.526  1
299008  96.954  -72.530  51.500  1
299009  96.984  -72.525  51.474  1
299010  97.014  -72.521  51.448  1
299011  97.044  -72.516  51.423  1
299012  97.075  -72.512  51.399  1
299013  97.105  -72.509  51.374  1
299014  97.138  -72.513  51.347  1
299015  97.174  -72.516  51.315  1
299016  97.231  -72.519  51.283  1
299017  97.288  -72.521  51.248  1
299018  97.345  -72.524  51.211  1
299019  97.401  -72.526  51.172  1
299020  97.449  -72.527  51.135  1
299021  97.469  -72.545  51.095  1
299022  97.487  -72.565  51.054  1
299023  97.505  -72.586  51.012  1
299024  97.523  -72.606  50.973  1
299025  97.541  -72.625  50.932  1
299026  97.572  -72.606  50.887  1
299027  97.608  -72.603  50.841  1
299028  97.646  -72.612  50.790  1
299029  97.683  -72.620  50.740  1
299030  97.718  -72.623  50.690  1
299031  97.752  -72.625  50.638  1
299032  97.786  -72.625  50.590  1
299033  97.819  -72.627  50.540  1
299034  97.854  -72.628  50.488  1
299035  97.887  -72.629  50.434  1
299036  97.921  -72.631  50.380  1
299037  97.955  -72.631  50.327  1
299038  97.989  -72.633  50.274  1
299039  98.029  -72.638  50.221  1
299040  98.073  -72.644  50.169  1
299041  98.117  -72.651  50.115  1
299042  98.161  -72.658  50.063  1
299043  98.178  -72.697  50.013  1
299044  98.211  -72.707  49.963  1
299045  98.244  -72.719  49.912  1
299046  98.278  -72.729  49.861  1
299047  98.309  -72.738  49.812  1
299048  98.340  -72.747  49.763  1
299049  98.370  -72.755  49.713  1
299050  98.414  -72.741  49.662  1
299051  98.465  -72.711  49.612  1
299052  98.484  -72.723  49.564  1
299053  98.503  -72.735  49.516  1
299054  98.521  -72.747  49.467  1
299055  98.547  -72.782  49.417  1
299056  98.589  -72.819  49.367  1
299057  98.632  -72.858  49.316  1
299058  98.659  -72.889  49.265  1
299059  98.678  -72.898  49.213  1
299060  98.696  -72.893  49.162  1
299061  98.717  -72.894  49.108  1
299062  98.742  -72.901  49.056  1
299063  98.767  -72.908  49.004  1
299064  98.800  -72.945  48.953  1
299065  98.838  -72.997  48.904  1
299066  98.868  -73.031  48.855  1
299067  98.893  -73.050  48.806  1
299068  98.924  -73.059  48.758  1
299069  98.959  -73.062  48.712  1
299070  98.994  -73.065  48.666  1
299071  99.030  -73.068  48.619  1
299072  99.069  -73.071  48.572  1
299073  99.103  -73.086  48.525  1
299074  99.137  -73.103  48.477  1
299075  99.170  -73.121  48.428  1
299076  99.204  -73.139  48.381  1
299077  99.226  -73.148  48.335  1
299078  99.249  -73.158  48.288  1
299079  99.274  -73.171  48.241  1
299080  99.311  -73.195  48.196  1
299081  99.349  -73.221  48.151  1
299082  99.386  -73.245  48.105  1
299083  99.420  -73.264  48.061  1
299084  99.444  -73.271  48.016  1
299085  99.468  -73.278  47.971  1
299086  99.493  -73.286  47.925  1
299087  99.517  -73.293  47.881  1
299088  99.542  -73.300  47.838  1
299089  99.566  -73.307  47.793  1
299090  99.591  -73.317  47.749  1
299091  99.620  -73.335  47.704  1
299092  99.648  -73.352  47.659  1
299093  99.677  -73.370  47.613  1
299094  99.708  -73.379  47.569  1
299095  99.738  -73.387  47.523  1
299096  99.768  -73.396  47.478  1
299097  99.799  -73.405  47.433  1
299098  99.829  -73.414  47.387  1
299099  99.860  -73.423  47.341  1
299100  99.890  -73.431  47.295  1
299101  99.922  -73.437  47.251  1
299102  99.957  -73.443  47.206  1
299103  99.997  -73.452  47.162  1
299104  100.037  -73.462  47.118  1
299105  100.077  -73.471  47.075  1
299106  100.117  -73.479  47.033  1
299107  100.156  -73.488  46.993  1
299108  100.196  -73.497  46.954  1
299109  100.236  -73.506  46.915  1
299110  100.276  -73.515  46.877  1
299111  100.316  -73.524  46.840  1
299112  100.356  -73.533  46.803  1
299113  100.396  -73.542  46.766  1
299114  100.436  -73.550  46.732  1
299115  100.476  -73.559  46.699  1
299116  100.502  -73.567  46.666  1
299117  100.516  -73.573  46.632  1
299118  100.531  -73.579  46.599  1
299119  100.553  -73.559  46.567  1
299120  100.575  -73.540  46.535  1
299121  100.598  -73.521  46.503  1
299122  100.620  -73.502  46.473  1
299123  100.642  -73.483  46.441  1
299124  100.664  -73.464  46.409  1
299125  100.686  -73.444  46.377  1
299126  100.708  -73.425  46.344  1
299127  100.731  -73.406  46.313  1
299128  100.753  -73.387  46.282  1
299129  100.775  -73.368  46.249  1
299130  100.797  -73.348  46.216  1
299131  100.818  -73.338  46.183  1
299132  100.894  -73.482  46.149  1
299133  100.974  -73.606  46.116  1
299134  101.012  -73.621  46.083  1
299135  101.050  -73.637  46.050  1
299136  101.088  -73.652  46.016  1
299137  101.126  -73.667  45.982  1
299138  101.164  -73.682  45.949  1
299139  101.201  -73.697  45.914  1
299140  101.238  -73.713  45.880  1
299141  101.275  -73.729  45.846  1
299142  101.312  -73.744  45.812  1
299143  101.348  -73.760  45.778  1
299144  101.386  -73.776  45.743  1
299145  101.424  -73.788  45.709  1
299146  101.463  -73.797  45.674  1
299147  101.498  -73.815  45.640  1
299148  101.531  -73.836  45.606  1
299149  101.563  -73.857  45.573  1
299150  101.596  -73.878  45.539  1
299151  101.628  -73.899  45.505  1
299152  101.660  -73.920  45.472  1
299153  101.692  -73.941  45.440  1
299154  101.724  -73.960  45.409  1
299155  101.755  -73.979  45.377  1
299156  101.785  -73.998  45.347  1
299157  101.817  -74.017  45.316  1
299158  101.848  -74.036  45.284  1
299159  101.879  -74.055  45.253  1
299160  101.910  -74.074  45.224  1
299161  101.954  -74.089  45.195  1
299162  101.993  -74.068  45.165  1
299163  102.036  -74.029  45.135  1
299164  102.079  -74.039  45.105  1
299165  102.121  -74.048  45.074  1
299166  102.146  -74.049  45.044  1
299167  102.171  -74.050  45.015  1
299168  102.195  -74.051  44.985  1
299169  102.221  -74.051  44.956  1
299170  102.245  -74.051  44.926  1
299171  102.270  -74.052  44.896  1
299172  102.295  -74.053  44.866  1
299173  102.319  -74.054  44.837  1
299174  102.344  -74.054  44.808  1
299175  102.369  -74.054  44.778  1
299176  102.394  -74.055  44.750  1
299650  95.153  -72.243  52.528  1
299651  95.179  -72.257  52.508  1
299652  95.206  -72.271  52.487  1
299653  95.232  -72.285  52.466  1
299654  95.259  -72.299  52.445  1
299655  95.284  -72.309  52.422  1
299656  95.310  -72.316  52.399  1
299657  95.331  -72.321  52.376  1
299658  95.351  -72.326  52.351  1
299659  95.371  -72.330  52.326  1
299660  95.392  -72.334  52.301  1
299661  95.445  -72.350  52.276  1
299662  95.486  -72.346  52.252  1
299663  95.514  -72.324  52.230  1
299664  95.542  -72.302  52.207  1
299665  95.576  -72.290  52.184  1
299666  95.611  -72.280  52.163  1
299667  95.640  -72.290  52.142  1
299668  95.667  -72.315  52.123  1
299669  95.693  -72.339  52.105  1
299670  95.722  -72.363  52.087  1
299671  95.751  -72.388  52.071  1
299672  95.780  -72.412  52.054  1
299673  95.809  -72.437  52.037  1
299674  95.838  -72.462  52.020  1
299675  95.868  -72.487  52.005  1
299676  95.888  -72.507  51.988  1
299677  95.895  -72.519  51.972  1
299678  95.902  -72.532  51.956  1
299679  95.909  -72.544  51.941  1
299680  95.927  -72.527  51.926  1
299681  95.962  -72.524  51.911  1
299682  95.996  -72.521  51.898  1
299683  96.033  -72.515  51.884  1
299684  96.071  -72.509  51.874  1
299685  96.109  -72.503  51.865  1
299686  96.147  -72.497  51.856  1
299687  96.184  -72.492  51.848  1
299688  96.222  -72.486  51.841  1
299689  96.257  -72.484  51.833  1
299690  96.288  -72.486  51.822  1
299691  96.320  -72.488  51.808  1
299692  96.351  -72.491  51.797  1
299693  96.382  -72.493  51.785  1
299694  96.413  -72.495  51.772  1
299695  96.443  -72.494  51.757  1
299696  96.473  -72.493  51.742  1
299697  96.520  -72.500  51.728  1
299698  96.579  -72.506  51.713  1
299699  96.630  -72.506  51.698  1
299700  96.674  -72.505  51.683  1
299701  96.707  -72.504  51.665  1
299702  96.740  -72.503  51.647  1
299703  96.773  -72.502  51.629  1
299704  96.807  -72.501  51.610  1
299705  96.839  -72.500  51.590  1
299706  96.873  -72.499  51.570  1
299707  96.906  -72.498  51.551  1
299708  96.936  -72.493  51.530  1
299709  96.966  -72.489  51.504  1
299710  96.996  -72.484  51.478  1
299711  97.026  -72.480  51.453  1
299712  97.056  -72.475  51.427  1
299713  97.087  -72.472  51.402  1
299714  97.117  -72.467  51.377  1
299715  97.148  -72.466  51.350  1
299716  97.181  -72.470  51.319  1
299717  97.238  -72.472  51.285  1
299718  97.295  -72.475  51.251  1
299719  97.351  -72.478  51.216  1
299720  97.408  -72.480  51.182  1
299721  97.459  -72.485  51.147  1
299722  97.489  -72.501  51.108  1
299723  97.509  -72.521  51.065  1
299724  97.527  -72.541  51.020  1
299725  97.544  -72.562  50.976  1
299726  97.563  -72.582  50.931  1
299727  97.588  -72.578  50.885  1
299728  97.626  -72.585  50.839  1
299729  97.661  -72.590  50.790  1
299730  97.695  -72.591  50.742  1
299731  97.729  -72.592  50.694  1
299732  97.762  -72.593  50.646  1
299733  97.796  -72.594  50.600  1
299734  97.830  -72.596  50.550  1
299735  97.864  -72.597  50.497  1
299736  97.897  -72.598  50.442  1
299737  97.932  -72.599  50.388  1
299738  97.965  -72.600  50.335  1
299739  97.999  -72.602  50.282  1
299740  98.039  -72.606  50.229  1
299741  98.083  -72.613  50.177  1
299742  98.127  -72.620  50.122  1
299743  98.171  -72.627  50.070  1
299744  98.194  -72.668  50.019  1
299745  98.227  -72.679  49.967  1
299746  98.260  -72.690  49.915  1
299747  98.292  -72.700  49.865  1
299748  98.323  -72.708  49.816  1
299749  98.354  -72.717  49.767  1
299750  98.384  -72.725  49.717  1
299751  98.415  -72.735  49.666  1
299752  98.467  -72.704  49.617  1
299753  98.491  -72.710  49.568  1
299754  98.510  -72.722  49.520  1
299755  98.528  -72.734  49.469  1
299756  98.551  -72.747  49.417  1
299757  98.592  -72.784  49.367  1
299758  98.633  -72.820  49.316  1
299759  98.674  -72.859  49.264  1
299760  98.695  -72.867  49.212  1
299761  98.713  -72.866  49.160  1
299762  98.737  -72.872  49.107  1
299763  98.761  -72.879  49.055  1
299764  98.786  -72.885  49.004  1
299765  98.817  -72.915  48.953  1
299766  98.851  -72.957  48.902  1
299767  98.875  -72.977  48.852  1
299768  98.900  -72.997  48.804  1
299769  98.930  -73.007  48.756  1
299770  98.964  -73.011  48.709  1
299771  99.000  -73.014  48.662  1
299772  99.037  -73.017  48.615  1
299773  99.074  -73.026  48.569  1
299774  99.107  -73.044  48.522  1
299775  99.141  -73.061  48.475  1
299776  99.174  -73.079  48.427  1
299777  99.208  -73.097  48.380  1
299778  99.241  -73.115  48.333  1
299779  99.275  -73.133  48.286  1
299780  99.299  -73.144  48.240  1
299781  99.321  -73.153  48.195  1
299782  99.354  -73.174  48.149  1
299783  99.392  -73.199  48.104  1
299784  99.429  -73.223  48.059  1
299785  99.457  -73.235  48.015  1
299786  99.481  -73.242  47.970  1
299787  99.506  -73.249  47.925  1
299788  99.530  -73.257  47.880  1
299789  99.555  -73.264  47.836  1
299790  99.580  -73.274  47.791  1
299791  99.609  -73.292  47.748  1
299792  99.637  -73.309  47.703  1
299793  99.665  -73.327  47.657  1
299794  99.694  -73.346  47.612  1
299795  99.724  -73.358  47.567  1
299796  99.754  -73.367  47.522  1
299797  99.785  -73.375  47.476  1
299798  99.815  -73.384  47.430  1
299799  99.846  -73.393  47.385  1
299800  99.876  -73.402  47.339  1
299801  99.907  -73.410  47.293  1
299802  99.938  -73.415  47.249  1
299803  99.970  -73.421  47.204  1
299804  100.001  -73.426  47.159  1
299805  100.042  -73.435  47.115  1
299806  100.081  -73.443  47.071  1
299807  100.121  -73.452  47.029  1
299808  100.161  -73.462  46.988  1
299809  100.201  -73.471  46.949  1
299810  100.241  -73.479  46.910  1
299811  100.281  -73.488  46.871  1
299812  100.321  -73.497  46.833  1
299813  100.360  -73.506  46.795  1
299814  100.401  -73.515  46.758  1
299815  100.440  -73.524  46.724  1
299816  100.480  -73.533  46.690  1
299817  100.506  -73.540  46.656  1
299818  100.521  -73.546  46.623  1
299819  100.535  -73.552  46.590  1
299820  100.552  -73.549  46.558  1
299821  100.574  -73.529  46.527  1
299822  100.597  -73.510  46.496  1
299823  100.619  -73.491  46.466  1
299824  100.641  -73.471  46.434  1
299825  100.663  -73.452  46.403  1
299826  100.685  -73.434  46.372  1
299827  100.707  -73.414  46.339  1
299828  100.729  -73.395  46.308  1
299829  100.752  -73.376  46.276  1
299830  100.774  -73.356  46.243  1
299831  100.788  -73.333  46.209  1
299832  100.799  -73.331  46.175  1
299833  101.008  -73.579  46.141  1
299834  100.981  -73.571  46.107  1
299835  101.018  -73.586  46.074  1
299836  101.054  -73.602  46.041  1
299837  101.092  -73.618  46.008  1
299838  101.128  -73.633  45.974  1
299839  101.165  -73.649  45.940  1
299840  101.202  -73.665  45.905  1
299841  101.239  -73.680  45.871  1
299842  101.276  -73.696  45.837  1
299843  101.313  -73.712  45.803  1
299844  101.349  -73.727  45.769  1
299845  101.388  -73.739  45.735  1
299846  101.427  -73.750  45.700  1
299847  101.466  -73.760  45.665  1
299848  101.506  -73.769  45.631  1
299849  101.541  -73.785  45.597  1
299850  101.574  -73.807  45.563  1
299851  101.606  -73.828  45.529  1
299852  101.638  -73.849  45.494  1
299853  101.671  -73.870  45.460  1
299854  101.703  -73.891  45.428  1
299855  101.736  -73.912  45.396  1
299856  101.768  -73.933  45.365  1
299857  101.801  -73.954  45.335  1
299858  101.833  -73.976  45.304  1
299859  101.865  -73.997  45.272  1
299860  101.897  -74.018  45.240  1
299861  101.930  -74.039  45.211  1
299862  101.964  -74.046  45.181  1
299863  102.006  -73.986  45.150  1
299864  102.049  -73.995  45.120  1
299865  102.092  -74.005  45.090  1
299866  102.129  -74.012  45.059  1
299867  102.154  -74.013  45.030  1
299868  102.179  -74.013  45.000  1
299869  102.203  -74.013  44.971  1
299870  102.228  -74.014  44.941  1
299871  102.253  -74.015  44.912  1
299872  102.277  -74.016  44.882  1
299873  102.303  -74.016  44.853  1
299874  102.327  -74.017  44.824  1
299875  102.352  -74.017  44.795  1
299876  102.377  -74.018  44.766  1
300350  95.125  -72.183  52.544  1
300351  95.151  -72.197  52.524  1
300352  95.178  -72.211  52.503  1
300353  95.204  -72.226  52.483  1
300354  95.230  -72.240  52.462  1
300355  95.257  -72.255  52.440  1
300356  95.283  -72.269  52.417  1
300357  95.309  -72.279  52.395  1
300358  95.335  -72.287  52.372  1
300359  95.354  -72.291  52.348  1
300360  95.375  -72.295  52.324  1
300361  95.395  -72.299  52.299  1
300362  95.449  -72.316  52.275  1
300363  95.481  -72.299  52.251  1
300364  95.510  -72.277  52.229  1
300365  95.538  -72.255  52.206  1
300366  95.572  -72.244  52.183  1
300367  95.606  -72.237  52.162  1
300368  95.632  -72.262  52.141  1
300369  95.659  -72.286  52.121  1
300370  95.685  -72.309  52.103  1
300371  95.714  -72.334  52.086  1
300372  95.743  -72.359  52.070  1
300373  95.772  -72.384  52.054  1
300374  95.802  -72.409  52.037  1
300375  95.831  -72.434  52.021  1
300376  95.860  -72.458  52.005  1
300377  95.889  -72.483  51.989  1
300378  95.897  -72.496  51.973  1
300379  95.904  -72.509  51.957  1
300380  95.912  -72.521  51.942  1
300381  95.937  -72.493  51.927  1
300382  95.971  -72.490  51.912  1
300383  96.008  -72.485  51.898  1
300384  96.045  -72.479  51.885  1
300385  96.083  -72.473  51.874  1
300386  96.120  -72.468  51.863  1
300387  96.158  -72.462  51.853  1
300388  96.196  -72.456  51.845  1
300389  96.234  -72.450  51.837  1
300390  96.271  -72.444  51.829  1
300391  96.305  -72.443  51.819  1
300392  96.336  -72.446  51.807  1
300393  96.368  -72.448  51.795  1
300394  96.398  -72.449  51.783  1
300395  96.429  -72.448  51.770  1
300396  96.459  -72.446  51.755  1
300397  96.489  -72.446  51.739  1
300398  96.533  -72.451  51.724  1
300399  96.601  -72.465  51.708  1
300400  96.651  -72.465  51.692  1
300401  96.686  -72.464  51.676  1
300402  96.719  -72.463  51.658  1
300403  96.752  -72.462  51.638  1
300404  96.785  -72.461  51.620  1
300405  96.818  -72.460  51.602  1
300406  96.852  -72.459  51.584  1
300407  96.885  -72.458  51.567  1
300408  96.918  -72.457  51.549  1
300409  96.948  -72.453  51.529  1
300410  96.978  -72.448  51.504  1
300411  97.008  -72.443  51.478  1
300412  97.038  -72.439  51.453  1
300413  97.069  -72.435  51.428  1
300414  97.099  -72.431  51.402  1
300415  97.129  -72.426  51.376  1
300416  97.159  -72.421  51.348  1
300417  97.191  -72.423  51.316  1
300418  97.245  -72.426  51.285  1
300419  97.301  -72.428  51.254  1
300420  97.358  -72.431  51.223  1
300421  97.389  -72.446  51.192  1
300422  97.418  -72.462  51.158  1
300423  97.448  -72.479  51.119  1
300424  97.477  -72.496  51.075  1
300425  97.506  -72.512  51.029  1
300426  97.536  -72.528  50.983  1
300427  97.568  -72.544  50.937  1
300428  97.604  -72.554  50.892  1
300429  97.638  -72.556  50.848  1
300430  97.672  -72.558  50.803  1
300431  97.706  -72.559  50.755  1
300432  97.739  -72.560  50.707  1
300433  97.773  -72.562  50.659  1
300434  97.807  -72.563  50.611  1
300435  97.841  -72.564  50.560  1
300436  97.874  -72.565  50.507  1
300437  97.908  -72.566  50.452  1
300438  97.942  -72.568  50.399  1
300439  97.975  -72.569  50.346  1
300440  98.010  -72.570  50.293  1
300441  98.050  -72.575  50.240  1
300442  98.094  -72.581  50.187  1
300443  98.138  -72.588  50.132  1
300444  98.181  -72.595  50.078  1
300445  98.226  -72.602  50.026  1
300446  98.242  -72.650  49.972  1
300447  98.276  -72.661  49.921  1
300448  98.306  -72.670  49.871  1
300449  98.337  -72.678  49.822  1
300450  98.368  -72.688  49.772  1
300451  98.398  -72.696  49.722  1
300452  98.429  -72.705  49.671  1
300453  98.467  -72.700  49.621  1
300454  98.498  -72.698  49.571  1
300455  98.516  -72.710  49.521  1
300456  98.539  -72.718  49.468  1
300457  98.567  -72.725  49.416  1
300458  98.607  -72.762  49.366  1
300459  98.648  -72.799  49.315  1
300460  98.680  -72.820  49.263  1
300461  98.708  -72.835  49.210  1
300462  98.731  -72.842  49.158  1
300463  98.756  -72.850  49.105  1
300464  98.781  -72.857  49.053  1
300465  98.805  -72.863  49.002  1
300466  98.834  -72.884  48.952  1
300467  98.858  -72.904  48.901  1
300468  98.883  -72.923  48.851  1
300469  98.907  -72.943  48.803  1
300470  98.935  -72.957  48.755  1
300471  98.970  -72.960  48.708  1
300472  99.005  -72.963  48.661  1
300473  99.044  -72.967  48.614  1
300474  99.077  -72.984  48.568  1
300475  99.111  -73.002  48.522  1
300476  99.145  -73.020  48.475  1
300477  99.178  -73.038  48.428  1
300478  99.212  -73.055  48.380  1
300479  99.245  -73.073  48.333  1
300480  99.279  -73.091  48.286  1
300481  99.312  -73.109  48.240  1
300482  99.346  -73.127  48.194  1
300483  99.371  -73.139  48.148  1
300484  99.397  -73.152  48.104  1
300485  99.434  -73.177  48.059  1
300486  99.470  -73.199  48.014  1
300487  99.494  -73.206  47.970  1
300488  99.519  -73.214  47.924  1
300489  99.543  -73.221  47.880  1
300490  99.569  -73.230  47.835  1
300491  99.597  -73.249  47.790  1
300492  99.626  -73.266  47.746  1
300493  99.654  -73.284  47.701  1
300494  99.683  -73.302  47.656  1
300495  99.711  -73.320  47.611  1
300496  99.740  -73.337  47.566  1
300497  99.771  -73.346  47.520  1
300498  99.801  -73.355  47.474  1
300499  99.832  -73.363  47.429  1
300500  99.862  -73.372  47.384  1
300501  99.893  -73.381  47.337  1
300502  99.923  -73.389  47.292  1
300503  99.955  -73.393  47.247  1
300504  99.986  -73.399  47.203  1
300505  100.018  -73.404  47.157  1
300506  100.050  -73.409  47.112  1
300507  100.086  -73.417  47.068  1
300508  100.126  -73.426  47.025  1
300509  100.165  -73.434  46.984  1
300510  100.206  -73.443  46.944  1
300511  100.246  -73.452  46.905  1
300512  100.285  -73.462  46.865  1
300513  100.325  -73.471  46.826  1
300514  100.365  -73.479  46.788  1
300515  100.405  -73.488  46.751  1
300516  100.445  -73.497  46.716  1
300517  100.485  -73.506  46.682  1
300518  100.510  -73.513  46.648  1
300519  100.525  -73.519  46.615  1
300520  100.539  -73.525  46.583  1
300521  100.553  -73.531  46.551  1
300522  100.573  -73.518  46.521  1
300523  100.596  -73.499  46.491  1
300524  100.618  -73.480  46.461  1
300525  100.640  -73.461  46.430  1
300526  100.662  -73.441  46.400  1
300527  100.684  -73.422  46.370  1
300528  100.706  -73.403  46.340  1
300529  100.728  -73.383  46.306  1
300530  100.751  -73.365  46.273  1
300531  100.755  -73.349  46.239  1
300532  100.789  -73.362  46.204  1
300533  100.823  -73.374  46.170  1
300534  100.935  -73.531  46.135  1
300535  100.978  -73.556  46.101  1
300536  101.016  -73.562  46.068  1
300537  101.055  -73.568  46.034  1
300538  101.092  -73.584  46.000  1
300539  101.129  -73.600  45.967  1
300540  101.166  -73.615  45.933  1
300541  101.203  -73.631  45.898  1
300542  101.240  -73.647  45.864  1
300543  101.276  -73.662  45.830  1
300544  101.313  -73.678  45.796  1
300545  101.351  -73.691  45.762  1
300546  101.391  -73.701  45.727  1
300547  101.430  -73.711  45.692  1
300548  101.469  -73.722  45.657  1
300549  101.509  -73.731  45.622  1
300550  101.548  -73.741  45.588  1
300551  101.585  -73.756  45.553  1
300552  101.617  -73.777  45.519  1
300553  101.649  -73.798  45.484  1
300554  101.682  -73.819  45.450  1
300555  101.714  -73.841  45.417  1
300556  101.746  -73.862  45.385  1
300557  101.778  -73.883  45.353  1
300558  101.811  -73.904  45.323  1
300559  101.843  -73.926  45.292  1
300560  101.876  -73.946  45.260  1
300561  101.908  -73.969  45.228  1
300562  101.937  -73.998  45.198  1
300563  101.976  -73.949  45.167  1
300564  102.019  -73.952  45.136  1
300565  102.062  -73.961  45.105  1
300566  102.105  -73.971  45.075  1
300567  102.137  -73.975  45.045  1
300568  102.162  -73.976  45.016  1
300569  102.186  -73.976  44.987  1
300570  102.211  -73.977  44.957  1
300571  102.236  -73.978  44.928  1
300572  102.261  -73.979  44.898  1
300573  102.286  -73.979  44.869  1
300574  102.310  -73.979  44.840  1
300575  102.335  -73.980  44.812  1
300576  102.360  -73.981  44.783  1
301051  95.123  -72.138  52.541  1
301052  95.149  -72.152  52.520  1
301053  95.176  -72.167  52.499  1
301054  95.202  -72.181  52.479  1
301055  95.229  -72.196  52.458  1
301056  95.255  -72.209  52.436  1
301057  95.281  -72.224  52.413  1
301058  95.308  -72.238  52.391  1
301059  95.334  -72.249  52.369  1
301060  95.359  -72.257  52.346  1
301061  95.378  -72.260  52.322  1
301062  95.398  -72.265  52.298  1
301063  95.449  -72.275  52.274  1
301064  95.477  -72.253  52.251  1
301065  95.506  -72.231  52.228  1
301066  95.534  -72.208  52.205  1
301067  95.568  -72.199  52.183  1
301068  95.599  -72.208  52.161  1
301069  95.624  -72.232  52.141  1
301070  95.651  -72.256  52.121  1
301071  95.678  -72.280  52.103  1
301072  95.707  -72.305  52.087  1
301073  95.736  -72.330  52.070  1
301074  95.765  -72.355  52.053  1
301075  95.794  -72.380  52.038  1
301076  95.823  -72.404  52.023  1
301077  95.852  -72.429  52.006  1
301078  95.882  -72.454  51.990  1
301079  95.899  -72.472  51.975  1
301080  95.907  -72.485  51.960  1
301081  95.914  -72.472  51.945  1
301082  95.945  -72.459  51.930  1
301083  95.981  -72.455  51.915  1
301084  96.019  -72.449  51.900  1
301085  96.056  -72.443  51.886  1
301086  96.094  -72.437  51.874  1
301087  96.132  -72.431  51.863  1
301088  96.170  -72.425  51.852  1
301089  96.207  -72.420  51.843  1
301090  96.245  -72.414  51.834  1
301091  96.283  -72.408  51.826  1
301092  96.321  -72.402  51.816  1
301093  96.354  -72.403  51.806  1
301094  96.384  -72.403  51.795  1
301095  96.414  -72.402  51.783  1
301096  96.444  -72.400  51.770  1
301097  96.474  -72.399  51.756  1
301098  96.505  -72.398  51.738  1
301099  96.546  -72.403  51.721  1
301100  96.616  -72.419  51.704  1
301101  96.665  -72.424  51.687  1
301102  96.698  -72.423  51.669  1
301103  96.731  -72.421  51.650  1
301104  96.764  -72.421  51.630  1
301105  96.797  -72.420  51.611  1
301106  96.830  -72.418  51.593  1
301107  96.863  -72.418  51.577  1
301108  96.896  -72.417  51.561  1
301109  96.930  -72.415  51.545  1
301110  96.960  -72.412  51.525  1
301111  96.991  -72.407  51.501  1
301112  97.020  -72.403  51.475  1
301113  97.050  -72.399  51.450  1
301114  97.081  -72.394  51.425  1
301115  97.111  -72.390  51.399  1
301116  97.141  -72.385  51.371  1
301117  97.171  -72.381  51.343  1
301118  97.202  -72.377  51.312  1
301119  97.251  -72.380  51.284  1
301120  97.289  -72.392  51.257  1
301121  97.318  -72.408  51.229  1
301122  97.351  -72.424  51.199  1
301123  97.391  -72.440  51.166  1
301124  97.430  -72.456  51.126  1
301125  97.469  -72.472  51.082  1
301126  97.509  -72.489  51.037  1
301127  97.548  -72.505  50.991  1
301128  97.584  -72.512  50.945  1
301129  97.617  -72.515  50.901  1
301130  97.648  -72.517  50.860  1
301131  97.679  -72.520  50.816  1
301132  97.713  -72.522  50.770  1
301133  97.747  -72.523  50.721  1
301134  97.781  -72.525  50.672  1
301135  97.815  -72.527  50.622  1
301136  97.849  -72.528  50.570  1
301137  97.883  -72.530  50.517  1
301138  97.917  -72.532  50.463  1
301139  97.951  -72.534  50.410  1
301140  97.985  -72.535  50.357  1
301141  98.019  -72.537  50.304  1
301142  98.055  -72.544  50.251  1
301143  98.099  -72.551  50.197  1
301144  98.144  -72.558  50.142  1
301145  98.189  -72.564  50.087  1
301146  98.234  -72.571  50.032  1
301147  98.280  -72.578  49.978  1
301148  98.290  -72.632  49.927  1
301149  98.321  -72.641  49.877  1
301150  98.352  -72.650  49.828  1
301151  98.382  -72.658  49.777  1
301152  98.413  -72.667  49.726  1
301153  98.444  -72.675  49.675  1
301154  98.475  -72.685  49.624  1
301155  98.504  -72.685  49.573  1
301156  98.529  -72.693  49.520  1
301157  98.556  -72.698  49.467  1
301158  98.583  -72.704  49.414  1
301159  98.624  -72.741  49.363  1
301160  98.658  -72.767  49.312  1
301161  98.686  -72.781  49.261  1
301162  98.718  -72.797  49.208  1
301163  98.733  -72.804  49.156  1
301164  98.758  -72.811  49.103  1
301165  98.783  -72.819  49.052  1
301166  98.808  -72.826  49.001  1
301167  98.847  -72.838  48.951  1
301168  98.865  -72.850  48.900  1
301169  98.890  -72.870  48.851  1
301170  98.915  -72.889  48.804  1
301171  98.941  -72.906  48.756  1
301172  98.976  -72.909  48.708  1
301173  99.012  -72.912  48.662  1
301174  99.048  -72.925  48.616  1
301175  99.081  -72.942  48.568  1
301176  99.115  -72.960  48.523  1
301177  99.148  -72.978  48.477  1
301178  99.182  -72.996  48.429  1
301179  99.215  -73.014  48.381  1
301180  99.249  -73.032  48.333  1
301181  99.283  -73.049  48.286  1
301182  99.316  -73.067  48.240  1
301183  99.350  -73.086  48.194  1
301184  99.383  -73.103  48.148  1
301185  99.417  -73.121  48.104  1
301186  99.443  -73.133  48.060  1
301187  99.477  -73.155  48.015  1
301188  99.507  -73.170  47.969  1
301189  99.532  -73.177  47.924  1
301190  99.557  -73.187  47.880  1
301191  99.586  -73.205  47.836  1
301192  99.615  -73.223  47.790  1
301193  99.643  -73.241  47.745  1
301194  99.672  -73.258  47.700  1
301195  99.700  -73.277  47.655  1
301196  99.729  -73.295  47.610  1
301197  99.758  -73.312  47.564  1
301198  99.787  -73.325  47.519  1
301199  99.818  -73.333  47.474  1
301200  99.848  -73.343  47.428  1
301201  99.878  -73.352  47.383  1
301202  99.909  -73.360  47.336  1
301203  99.940  -73.367  47.290  1
301204  99.972  -73.372  47.245  1
301205  100.003  -73.377  47.201  1
301206  100.034  -73.383  47.155  1
301207  100.066  -73.388  47.111  1
301208  100.098  -73.393  47.067  1
301209  100.130  -73.399  47.022  1
301210  100.171  -73.408  46.982  1
301211  100.210  -73.417  46.941  1
301212  100.250  -73.426  46.900  1
301213  100.290  -73.434  46.861  1
301214  100.330  -73.443  46.821  1
301215  100.370  -73.452  46.782  1
301216  100.410  -73.462  46.745  1
301217  100.450  -73.470  46.710  1
301218  100.489  -73.479  46.676  1
301219  100.514  -73.487  46.643  1
301220  100.528  -73.493  46.610  1
301221  100.543  -73.498  46.578  1
301222  100.557  -73.504  46.546  1
301223  100.572  -73.507  46.516  1
301224  100.595  -73.488  46.488  1
301225  100.617  -73.469  46.460  1
301226  100.639  -73.449  46.431  1
301227  100.661  -73.430  46.401  1
301228  100.683  -73.411  46.369  1
301229  100.705  -73.392  46.337  1
301230  100.711  -73.367  46.304  1
301231  100.745  -73.379  46.270  1
301232  100.778  -73.392  46.235  1
301233  100.812  -73.404  46.199  1
301234  100.873  -73.455  46.164  1
301235  100.936  -73.534  46.130  1
301236  100.975  -73.541  46.096  1
301237  101.013  -73.547  46.062  1
301238  101.052  -73.554  46.029  1
301239  101.091  -73.561  45.995  1
301240  101.129  -73.568  45.961  1
301241  101.167  -73.582  45.927  1
301242  101.203  -73.598  45.892  1
301243  101.240  -73.614  45.858  1
301244  101.277  -73.630  45.824  1
301245  101.315  -73.643  45.790  1
301246  101.354  -73.653  45.755  1
301247  101.394  -73.663  45.720  1
301248  101.433  -73.673  45.685  1
301249  101.472  -73.683  45.649  1
301250  101.512  -73.694  45.614  1
301251  101.551  -73.703  45.580  1
301252  101.591  -73.713  45.545  1
301253  101.627  -73.727  45.510  1
301254  101.660  -73.748  45.475  1
301255  101.692  -73.769  45.440  1
301256  101.725  -73.791  45.408  1
301257  101.757  -73.811  45.375  1
301258  101.790  -73.832  45.342  1
301259  101.822  -73.854  45.311  1
301260  101.853  -73.877  45.280  1
301261  101.883  -73.906  45.248  1
301262  101.912  -73.935  45.216  1
301263  101.947  -73.927  45.184  1
301264  101.989  -73.908  45.153  1
301265  102.032  -73.918  45.123  1
301266  102.076  -73.928  45.093  1
301267  102.118  -73.937  45.062  1
301268  102.144  -73.938  45.032  1
301269  102.170  -73.939  45.002  1
301270  102.194  -73.940  44.974  1
301271  102.219  -73.941  44.945  1
301272  102.244  -73.941  44.915  1
301273  102.268  -73.941  44.886  1
301274  102.293  -73.942  44.857  1
301275  102.318  -73.943  44.828  1
301276  102.343  -73.944  44.800  1
301752  95.121  -72.092  52.537  1
301753  95.147  -72.107  52.516  1
301754  95.174  -72.121  52.495  1
301755  95.200  -72.136  52.474  1
301756  95.227  -72.150  52.453  1
301757  95.253  -72.164  52.432  1
301758  95.279  -72.179  52.409  1
301759  95.306  -72.193  52.386  1
301760  95.332  -72.208  52.365  1
301761  95.358  -72.220  52.342  1
301762  95.381  -72.225  52.319  1
301763  95.401  -72.230  52.296  1
301764  95.445  -72.229  52.273  1
301765  95.473  -72.207  52.249  1
301766  95.501  -72.184  52.227  1
301767  95.530  -72.163  52.205  1
301768  95.564  -72.155  52.184  1
301769  95.591  -72.179  52.161  1
301770  95.617  -72.203  52.141  1
301771  95.642  -72.227  52.122  1
301772  95.670  -72.252  52.104  1
301773  95.699  -72.277  52.086  1
301774  95.729  -72.301  52.069  1
301775  95.758  -72.326  52.054  1
301776  95.787  -72.351  52.039  1
301777  95.816  -72.375  52.025  1
301778  95.845  -72.400  52.008  1
301779  95.874  -72.425  51.993  1
301780  95.902  -72.449  51.978  1
301781  95.909  -72.462  51.963  1
301782  95.920  -72.428  51.947  1
301783  95.955  -72.424  51.933  1
301784  95.993  -72.419  51.919  1
301785  96.031  -72.413  51.905  1
301786  96.068  -72.407  51.891  1
301787  96.106  -72.401  51.878  1
301788  96.144  -72.396  51.865  1
301789  96.181  -72.390  51.853  1
301790  96.219  -72.384  51.843  1
301791  96.257  -72.377  51.833  1
301792  96.295  -72.370  51.824  1
301793  96.333  -72.362  51.815  1
301794  96.369  -72.356  51.805  1
301795  96.400  -72.352  51.794  1
301796  96.431  -72.349  51.782  1
301797  96.461  -72.348  51.771  1
301798  96.491  -72.347  51.758  1
301799  96.522  -72.346  51.738  1
301800  96.552  -72.344  51.720  1
301801  96.608  -72.354  51.701  1
301802  96.668  -72.365  51.683  1
301803  96.716  -72.377  51.663  1
301804  96.743  -72.381  51.644  1
301805  96.776  -72.380  51.624  1
301806  96.809  -72.378  51.603  1
301807  96.842  -72.377  51.585  1
301808  96.875  -72.377  51.569  1
301809  96.908  -72.375  51.552  1
301810  96.941  -72.374  51.536  1
301811  96.972  -72.371  51.517  1
301812  97.003  -72.367  51.493  1
301813  97.032  -72.362  51.468  1
301814  97.063  -72.358  51.442  1
301815  97.093  -72.353  51.416  1
301816  97.123  -72.349  51.389  1
301817  97.153  -72.344  51.362  1
301818  97.183  -72.340  51.333  1
301819  97.216  -72.340  51.307  1
301820  97.253  -72.352  51.283  1
301821  97.293  -72.368  51.258  1
301822  97.332  -72.385  51.231  1
301823  97.371  -72.401  51.203  1
301824  97.411  -72.417  51.169  1
301825  97.450  -72.433  51.130  1
301826  97.490  -72.450  51.087  1
301827  97.529  -72.465  51.043  1
301828  97.564  -72.470  50.998  1
301829  97.596  -72.472  50.954  1
301830  97.630  -72.475  50.911  1
301831  97.662  -72.477  50.872  1
301832  97.692  -72.479  50.829  1
301833  97.723  -72.482  50.783  1
301834  97.754  -72.484  50.735  1
301835  97.788  -72.487  50.685  1
301836  97.822  -72.488  50.634  1
301837  97.857  -72.490  50.582  1
301838  97.890  -72.492  50.528  1
301839  97.925  -72.493  50.473  1
301840  97.958  -72.495  50.419  1
301841  97.993  -72.497  50.368  1
301842  98.026  -72.499  50.315  1
301843  98.062  -72.506  50.261  1
301844  98.097  -72.517  50.206  1
301845  98.133  -72.527  50.150  1
301846  98.169  -72.537  50.094  1
301847  98.211  -72.544  50.039  1
301848  98.256  -72.551  49.985  1
301849  98.301  -72.558  49.933  1
301850  98.320  -72.591  49.884  1
301851  98.352  -72.601  49.834  1
301852  98.384  -72.612  49.781  1
301853  98.416  -72.622  49.728  1
301854  98.450  -72.634  49.676  1
301855  98.487  -72.650  49.623  1
301856  98.509  -72.666  49.572  1
301857  98.546  -72.672  49.517  1
301858  98.572  -72.678  49.463  1
301859  98.599  -72.684  49.410  1
301860  98.636  -72.713  49.359  1
301861  98.667  -72.728  49.307  1
301862  98.702  -72.745  49.255  1
301863  98.725  -72.757  49.204  1
301864  98.729  -72.760  49.153  1
301865  98.754  -72.768  49.102  1
301866  98.779  -72.776  49.051  1
301867  98.815  -72.786  49.000  1
301868  98.867  -72.801  48.951  1
301869  98.881  -72.807  48.901  1
301870  98.897  -72.816  48.854  1
301871  98.922  -72.835  48.807  1
301872  98.946  -72.855  48.759  1
301873  98.981  -72.858  48.712  1
301874  99.018  -72.865  48.666  1
301875  99.052  -72.883  48.619  1
301876  99.085  -72.901  48.572  1
301877  99.119  -72.919  48.525  1
301878  99.152  -72.936  48.479  1
301879  99.186  -72.954  48.431  1
301880  99.219  -72.972  48.383  1
301881  99.253  -72.990  48.334  1
301882  99.286  -73.008  48.287  1
301883  99.320  -73.026  48.240  1
301884  99.354  -73.044  48.194  1
301885  99.387  -73.061  48.148  1
301886  99.421  -73.079  48.104  1
301887  99.454  -73.097  48.059  1
301888  99.488  -73.115  48.014  1
301889  99.519  -73.133  47.969  1
301890  99.546  -73.144  47.924  1
301891  99.575  -73.162  47.879  1
301892  99.603  -73.180  47.834  1
301893  99.632  -73.198  47.789  1
301894  99.660  -73.215  47.744  1
301895  99.689  -73.233  47.699  1
301896  99.717  -73.252  47.654  1
301897  99.746  -73.269  47.608  1
301898  99.775  -73.287  47.562  1
301899  99.803  -73.304  47.517  1
301900  99.834  -73.313  47.473  1
301901  99.864  -73.321  47.427  1
301902  99.895  -73.330  47.382  1
301903  99.925  -73.340  47.335  1
301904  99.957  -73.346  47.289  1
301905  99.988  -73.351  47.245  1
301906  100.019  -73.356  47.199  1
301907  100.051  -73.362  47.154  1
301908  100.083  -73.366  47.109  1
301909  100.114  -73.371  47.065  1
301910  100.146  -73.377  47.019  1
301911  100.177  -73.382  46.978  1
301912  100.215  -73.390  46.937  1
301913  100.255  -73.399  46.896  1
301914  100.295  -73.408  46.856  1
301915  100.335  -73.417  46.816  1
301916  100.374  -73.426  46.777  1
301917  100.414  -73.434  46.740  1
301918  100.454  -73.443  46.705  1
301919  100.494  -73.452  46.671  1
301920  100.517  -73.459  46.637  1
301921  100.532  -73.465  46.605  1
301922  100.547  -73.471  46.573  1
301923  100.561  -73.477  46.541  1
301924  100.575  -73.484  46.513  1
301925  100.594  -73.477  46.486  1
301926  100.616  -73.458  46.460  1
301927  100.638  -73.439  46.431  1
301928  100.660  -73.419  46.401  1
301929  100.682  -73.400  46.368  1
301930  100.700  -73.396  46.333  1
301931  100.734  -73.409  46.301  1
301932  100.768  -73.421  46.266  1
301933  100.802  -73.434  46.230  1
301934  100.835  -73.446  46.195  1
301935  100.919  -73.528  46.159  1
301936  100.933  -73.520  46.124  1
301937  100.972  -73.526  46.090  1
301938  101.011  -73.533  46.057  1
301939  101.049  -73.540  46.025  1
301940  101.088  -73.546  45.991  1
301941  101.127  -73.553  45.956  1
301942  101.165  -73.560  45.922  1
301943  101.204  -73.567  45.888  1
301944  101.241  -73.581  45.854  1
301945  101.279  -73.594  45.820  1
301946  101.318  -73.605  45.785  1
301947  101.357  -73.615  45.750  1
301948  101.397  -73.625  45.714  1
301949  101.436  -73.635  45.679  1
301950  101.475  -73.645  45.644  1
301951  101.515  -73.655  45.609  1
301952  101.554  -73.665  45.574  1
301953  101.594  -73.675  45.539  1
301954  101.633  -73.685  45.504  1
301955  101.671  -73.697  45.468  1
301956  101.703  -73.719  45.433  1
301957  101.735  -73.740  45.399  1
301958  101.768  -73.761  45.367  1
301959  101.799  -73.785  45.334  1
301960  101.828  -73.814  45.301  1
301961  101.858  -73.843  45.269  1
301962  101.888  -73.871  45.237  1
301963  101.917  -73.900  45.205  1
301964  101.959  -73.865  45.173  1
301965  102.003  -73.874  45.143  1
301966  102.045  -73.884  45.112  1
301967  102.089  -73.894  45.081  1
301968  102.128  -73.901  45.051  1
301969  102.153  -73.902  45.020  1
301970  102.177  -73.903  44.991  1
301971  102.202  -73.903  44.962  1
301972  102.227  -73.904  44.933  1
301973  102.252  -73.904  44.904  1
301974  102.276  -73.905  44.876  1
301975  102.301  -73.906  44.847  1
301976  102.326  -73.906  44.818  1
302453  95.119  -72.048  52.533  1
302454  95.145  -72.062  52.512  1
302455  95.172  -72.077  52.491  1
302456  95.198  -72.091  52.470  1
302457  95.225  -72.105  52.448  1
302458  95.251  -72.120  52.427  1
302459  95.277  -72.133  52.404  1
302460  95.304  -72.148  52.382  1
302461  95.330  -72.162  52.361  1
302462  95.356  -72.177  52.339  1
302463  95.383  -72.190  52.316  1
302464  95.405  -72.196  52.294  1
302465  95.440  -72.183  52.271  1
302466  95.468  -72.160  52.248  1
302467  95.496  -72.138  52.227  1
302468  95.526  -72.117  52.205  1
302469  95.556  -72.126  52.184  1
302470  95.583  -72.150  52.162  1
302471  95.609  -72.174  52.141  1
302472  95.635  -72.199  52.122  1
302473  95.663  -72.223  52.104  1
302474  95.692  -72.248  52.086  1
302475  95.721  -72.272  52.070  1
302476  95.750  -72.297  52.055  1
302477  95.779  -72.322  52.040  1
302478  95.809  -72.346  52.027  1
302479  95.838  -72.371  52.012  1
302480  95.867  -72.396  51.997  1
302481  95.896  -72.421  51.982  1
302482  95.911  -72.438  51.967  1
302483  95.929  -72.395  51.953  1
302484  95.967  -72.389  51.938  1
302485  96.005  -72.383  51.924  1
302486  96.042  -72.376  51.911  1
302487  96.081  -72.368  51.896  1
302488  96.119  -72.361  51.882  1
302489  96.157  -72.353  51.868  1
302490  96.195  -72.346  51.855  1
302491  96.233  -72.338  51.844  1
302492  96.271  -72.330  51.834  1
302493  96.309  -72.322  51.824  1
302494  96.347  -72.315  51.814  1
302495  96.382  -72.309  51.803  1
302496  96.413  -72.306  51.792  1
302497  96.445  -72.302  51.781  1
302498  96.476  -72.299  51.769  1
302499  96.507  -72.296  51.756  1
302500  96.538  -72.293  51.738  1
302501  96.570  -72.290  51.719  1
302502  96.601  -72.287  51.701  1
302503  96.652  -72.294  51.682  1
302504  96.709  -72.302  51.660  1
302505  96.765  -72.312  51.639  1
302506  96.803  -72.327  51.618  1
302507  96.821  -72.337  51.596  1
302508  96.854  -72.337  51.577  1
302509  96.887  -72.336  51.558  1
302510  96.920  -72.334  51.540  1
302511  96.953  -72.334  51.521  1
302512  96.984  -72.330  51.501  1
302513  97.015  -72.326  51.478  1
302514  97.044  -72.321  51.453  1
302515  97.075  -72.317  51.428  1
302516  97.105  -72.312  51.402  1
302517  97.136  -72.309  51.375  1
302518  97.171  -72.312  51.349  1
302519  97.204  -72.313  51.324  1
302520  97.234  -72.313  51.300  1
302521  97.274  -72.329  51.278  1
302522  97.313  -72.345  51.254  1
302523  97.352  -72.362  51.229  1
302524  97.391  -72.377  51.202  1
302525  97.431  -72.393  51.169  1
302526  97.470  -72.410  51.131  1
302527  97.510  -72.426  51.090  1
302528  97.543  -72.428  51.048  1
302529  97.576  -72.431  51.004  1
302530  97.609  -72.432  50.962  1
302531  97.642  -72.434  50.922  1
302532  97.675  -72.437  50.882  1
302533  97.707  -72.439  50.838  1
302534  97.737  -72.442  50.792  1
302535  97.767  -72.445  50.744  1
302536  97.797  -72.447  50.694  1
302537  97.829  -72.450  50.643  1
302538  97.864  -72.452  50.591  1
302539  97.898  -72.453  50.537  1
302540  97.932  -72.455  50.481  1
302541  97.966  -72.457  50.427  1
302542  98.000  -72.459  50.373  1
302543  98.034  -72.460  50.319  1
302544  98.069  -72.469  50.263  1
302545  98.105  -72.479  50.209  1
302546  98.141  -72.489  50.153  1
302547  98.176  -72.499  50.097  1
302548  98.212  -72.509  50.041  1
302549  98.248  -72.519  49.988  1
302550  98.284  -72.529  49.937  1
302551  98.320  -72.542  49.886  1
302552  98.358  -72.558  49.835  1
302553  98.395  -72.574  49.781  1
302554  98.432  -72.590  49.728  1
302555  98.469  -72.606  49.674  1
302556  98.507  -72.622  49.621  1
302557  98.498  -72.642  49.568  1
302558  98.535  -72.649  49.515  1
302559  98.573  -72.656  49.461  1
302560  98.610  -72.663  49.407  1
302561  98.651  -72.678  49.355  1
302562  98.686  -72.694  49.303  1
302563  98.721  -72.711  49.251  1
302564  98.724  -72.715  49.200  1
302565  98.726  -72.718  49.149  1
302566  98.750  -72.725  49.100  1
302567  98.775  -72.732  49.050  1
302568  98.833  -72.749  49.001  1
302569  98.887  -72.764  48.953  1
302570  98.901  -72.770  48.904  1
302571  98.915  -72.776  48.858  1
302572  98.929  -72.782  48.810  1
302573  98.953  -72.801  48.763  1
302574  98.988  -72.807  48.717  1
302575  99.021  -72.823  48.670  1
302576  99.055  -72.841  48.623  1
302577  99.089  -72.859  48.576  1
302578  99.122  -72.877  48.528  1
302579  99.156  -72.895  48.480  1
302580  99.190  -72.913  48.432  1
302581  99.223  -72.930  48.384  1
302582  99.257  -72.948  48.335  1
302583  99.290  -72.967  48.288  1
302584  99.324  -72.984  48.241  1
302585  99.357  -73.003  48.194  1
302586  99.391  -73.023  48.148  1
302587  99.425  -73.043  48.104  1
302588  99.459  -73.064  48.059  1
302589  99.493  -73.083  48.014  1
302590  99.528  -73.100  47.969  1
302591  99.562  -73.117  47.923  1
302592  99.592  -73.136  47.878  1
302593  99.621  -73.155  47.834  1
302594  99.649  -73.172  47.789  1
302595  99.678  -73.190  47.743  1
302596  99.706  -73.208  47.698  1
302597  99.735  -73.226  47.653  1
302598  99.764  -73.244  47.607  1
302599  99.792  -73.261  47.562  1
302600  99.821  -73.280  47.517  1
302601  99.850  -73.292  47.472  1
302602  99.880  -73.301  47.427  1
302603  99.911  -73.310  47.381  1
302604  99.941  -73.318  47.335  1
302605  99.973  -73.324  47.289  1
302606  100.004  -73.329  47.244  1
302607  100.036  -73.334  47.198  1
302608  100.068  -73.340  47.152  1
302609  100.100  -73.345  47.107  1
302610  100.131  -73.350  47.063  1
302611  100.162  -73.355  47.017  1
302612  100.194  -73.361  46.975  1
302613  100.226  -73.366  46.933  1
302614  100.260  -73.372  46.892  1
302615  100.299  -73.381  46.851  1
302616  100.339  -73.390  46.811  1
302617  100.379  -73.399  46.773  1
302618  100.419  -73.408  46.735  1
302619  100.459  -73.417  46.700  1
302620  100.499  -73.426  46.665  1
302621  100.522  -73.433  46.632  1
302622  100.536  -73.439  46.600  1
302623  100.550  -73.445  46.568  1
302624  100.565  -73.450  46.538  1
302625  100.579  -73.456  46.511  1
302626  100.594  -73.462  46.485  1
302627  100.615  -73.446  46.459  1
302628  100.637  -73.427  46.429  1
302629  100.656  -73.415  46.398  1
302630  100.690  -73.427  46.364  1
302631  100.723  -73.440  46.329  1
302632  100.757  -73.452  46.297  1
302633  100.791  -73.465  46.262  1
302634  100.825  -73.477  46.226  1
302635  100.858  -73.490  46.191  1
302636  100.893  -73.496  46.155  1
302637  100.933  -73.502  46.120  1
302638  100.973  -73.506  46.087  1
302639  101.012  -73.512  46.054  1
302640  101.052  -73.516  46.019  1
302641  101.092  -73.521  45.985  1
302642  101.132  -73.526  45.951  1
302643  101.172  -73.531  45.917  1
302644  101.211  -73.536  45.882  1
302645  101.251  -73.541  45.849  1
302646  101.289  -73.552  45.815  1
302647  101.328  -73.562  45.780  1
302648  101.367  -73.573  45.745  1
302649  101.405  -73.584  45.710  1
302650  101.443  -73.594  45.674  1
302651  101.481  -73.605  45.639  1
302652  101.519  -73.615  45.603  1
302653  101.558  -73.626  45.568  1
302654  101.597  -73.637  45.533  1
302655  101.636  -73.647  45.497  1
302656  101.675  -73.657  45.461  1
302657  101.713  -73.669  45.426  1
302658  101.745  -73.694  45.392  1
302659  101.774  -73.722  45.359  1
302660  101.804  -73.751  45.326  1
302661  101.833  -73.780  45.292  1
302662  101.863  -73.808  45.259  1
302663  101.893  -73.837  45.227  1
302664  101.929  -73.821  45.195  1
302665  101.972  -73.831  45.162  1
302666  102.016  -73.841  45.132  1
302667  102.058  -73.850  45.101  1
302668  102.102  -73.860  45.070  1
302669  102.135  -73.865  45.040  1
302670  102.160  -73.865  45.009  1
302671  102.185  -73.866  44.980  1
302672  102.210  -73.866  44.951  1
302673  102.235  -73.867  44.922  1
302674  102.259  -73.868  44.894  1
302675  102.284  -73.869  44.865  1
302676  102.309  -73.869  44.837  1
302677  102.334  -73.869  44.808  1
303154  95.117  -72.002  52.529  1
303155  95.143  -72.017  52.508  1
303156  95.170  -72.031  52.486  1
303157  95.196  -72.045  52.465  1
303158  95.222  -72.060  52.443  1
303159  95.249  -72.074  52.422  1
303160  95.275  -72.089  52.400  1
303161  95.302  -72.103  52.379  1
303162  95.328  -72.117  52.358  1
303163  95.354  -72.132  52.336  1
303164  95.381  -72.146  52.314  1
303165  95.407  -72.158  52.292  1
303166  95.436  -72.136  52.269  1
303167  95.464  -72.114  52.247  1
303168  95.492  -72.092  52.227  1
303169  95.522  -72.073  52.206  1
303170  95.548  -72.097  52.185  1
303171  95.574  -72.121  52.164  1
303172  95.601  -72.146  52.143  1
303173  95.627  -72.169  52.123  1
303174  95.656  -72.194  52.105  1
303175  95.685  -72.219  52.087  1
303176  95.713  -72.243  52.071  1
303177  95.743  -72.268  52.056  1
303178  95.772  -72.293  52.042  1
303179  95.801  -72.318  52.029  1
303180  95.830  -72.343  52.015  1
303181  95.860  -72.367  52.001  1
303182  95.889  -72.392  51.987  1
303183  95.915  -72.398  51.973  1
303184  95.942  -72.352  51.959  1
303185  95.980  -72.344  51.945  1
303186  96.019  -72.337  51.930  1
303187  96.057  -72.329  51.917  1
303188  96.095  -72.321  51.902  1
303189  96.133  -72.314  51.887  1
303190  96.171  -72.305  51.873  1
303191  96.209  -72.298  51.859  1
303192  96.247  -72.290  51.846  1
303193  96.286  -72.283  51.835  1
303194  96.324  -72.275  51.824  1
303195  96.362  -72.268  51.812  1
303196  96.395  -72.263  51.801  1
303197  96.427  -72.259  51.790  1
303198  96.458  -72.256  51.779  1
303199  96.489  -72.252  51.766  1
303200  96.521  -72.249  51.753  1
303201  96.552  -72.246  51.736  1
303202  96.583  -72.243  51.718  1
303203  96.613  -72.245  51.700  1
303204  96.654  -72.250  51.681  1
303205  96.702  -72.247  51.658  1
303206  96.752  -72.244  51.635  1
303207  96.806  -72.249  51.612  1
303208  96.863  -72.258  51.589  1
303209  96.890  -72.276  51.568  1
303210  96.899  -72.294  51.548  1
303211  96.932  -72.293  51.527  1
303212  96.965  -72.293  51.506  1
303213  96.997  -72.290  51.485  1
303214  97.027  -72.285  51.462  1
303215  97.056  -72.280  51.438  1
303216  97.090  -72.280  51.414  1
303217  97.125  -72.283  51.388  1
303218  97.160  -72.286  51.362  1
303219  97.191  -72.285  51.337  1
303220  97.221  -72.285  51.315  1
303221  97.254  -72.290  51.294  1
303222  97.294  -72.305  51.273  1
303223  97.333  -72.322  51.251  1
303224  97.372  -72.338  51.227  1
303225  97.412  -72.354  51.200  1
303226  97.451  -72.371  51.168  1
303227  97.490  -72.384  51.132  1
303228  97.522  -72.387  51.092  1
303229  97.556  -72.388  51.051  1
303230  97.589  -72.390  51.010  1
303231  97.621  -72.393  50.970  1
303232  97.655  -72.394  50.930  1
303233  97.688  -72.396  50.890  1
303234  97.720  -72.399  50.845  1
303235  97.751  -72.402  50.799  1
303236  97.781  -72.404  50.751  1
303237  97.811  -72.407  50.701  1
303238  97.842  -72.410  50.650  1
303239  97.872  -72.413  50.597  1
303240  97.905  -72.415  50.542  1
303241  97.939  -72.417  50.486  1
303242  97.973  -72.418  50.431  1
303243  98.007  -72.420  50.375  1
303244  98.041  -72.422  50.319  1
303245  98.077  -72.431  50.263  1
303246  98.112  -72.442  50.208  1
303247  98.148  -72.452  50.152  1
303248  98.184  -72.462  50.096  1
303249  98.220  -72.472  50.041  1
303250  98.259  -72.484  49.988  1
303251  98.299  -72.498  49.938  1
303252  98.340  -72.512  49.887  1
303253  98.377  -72.528  49.834  1
303254  98.415  -72.544  49.780  1
303255  98.452  -72.560  49.726  1
303256  98.489  -72.576  49.673  1
303257  98.526  -72.592  49.619  1
303258  98.486  -72.619  49.566  1
303259  98.523  -72.625  49.513  1
303260  98.561  -72.633  49.458  1
303261  98.610  -72.638  49.404  1
303262  98.668  -72.644  49.352  1
303263  98.705  -72.660  49.299  1
303264  98.720  -72.669  49.248  1
303265  98.722  -72.672  49.197  1
303266  98.725  -72.675  49.147  1
303267  98.746  -72.681  49.099  1
303268  98.790  -72.694  49.050  1
303269  98.850  -72.711  49.003  1
303270  98.908  -72.728  48.956  1
303271  98.921  -72.733  48.908  1
303272  98.935  -72.738  48.861  1
303273  98.948  -72.744  48.814  1
303274  98.962  -72.750  48.766  1
303275  98.992  -72.764  48.721  1
303276  99.025  -72.782  48.674  1
303277  99.059  -72.802  48.626  1
303278  99.093  -72.822  48.578  1
303279  99.127  -72.842  48.531  1
303280  99.161  -72.862  48.482  1
303281  99.195  -72.882  48.434  1
303282  99.228  -72.903  48.385  1
303283  99.262  -72.923  48.336  1
303284  99.296  -72.943  48.288  1
303285  99.330  -72.963  48.241  1
303286  99.364  -72.983  48.194  1
303287  99.398  -73.004  48.149  1
303288  99.431  -73.024  48.104  1
303289  99.465  -73.044  48.059  1
303290  99.501  -73.061  48.014  1
303291  99.541  -73.068  47.968  1
303292  99.576  -73.082  47.922  1
303293  99.604  -73.106  47.878  1
303294  99.636  -73.126  47.834  1
303295  99.666  -73.147  47.788  1
303296  99.695  -73.164  47.743  1
303297  99.723  -73.183  47.697  1
303298  99.752  -73.201  47.651  1
303299  99.781  -73.218  47.605  1
303300  99.809  -73.236  47.561  1
303301  99.838  -73.254  47.516  1
303302  99.866  -73.271  47.471  1
303303  99.897  -73.280  47.426  1
303304  99.927  -73.289  47.381  1
303305  99.958  -73.297  47.334  1
303306  99.990  -73.302  47.288  1
303307  100.021  -73.308  47.242  1
303308  100.053  -73.313  47.197  1
303309  100.084  -73.318  47.151  1
303310  100.116  -73.324  47.106  1
303311  100.147  -73.329  47.061  1
303312  100.179  -73.334  47.016  1
303313  100.211  -73.339  46.972  1
303314  100.243  -73.344  46.930  1
303315  100.274  -73.349  46.889  1
303316  100.305  -73.355  46.848  1
303317  100.344  -73.363  46.807  1
303318  100.384  -73.372  46.768  1
303319  100.424  -73.381  46.731  1
303320  100.464  -73.390  46.695  1
303321  100.503  -73.399  46.661  1
303322  100.525  -73.405  46.629  1
303323  100.540  -73.412  46.596  1
303324  100.554  -73.418  46.565  1
303325  100.568  -73.424  46.536  1
303326  100.583  -73.430  46.510  1
303327  100.598  -73.436  46.484  1
303328  100.614  -73.436  46.458  1
303329  100.645  -73.444  46.427  1
303330  100.679  -73.442  46.395  1
303331  100.711  -73.439  46.361  1
303332  100.745  -73.437  46.326  1
303333  100.777  -73.434  46.292  1
303334  100.810  -73.431  46.257  1
303335  100.843  -73.428  46.222  1
303336  100.878  -73.432  46.187  1
303337  100.916  -73.446  46.151  1
303338  100.954  -73.450  46.116  1
303339  100.993  -73.456  46.082  1
303340  101.033  -73.460  46.049  1
303341  101.073  -73.465  46.014  1
303342  101.113  -73.470  45.980  1
303343  101.152  -73.475  45.946  1
303344  101.192  -73.480  45.912  1
303345  101.232  -73.485  45.877  1
303346  101.271  -73.492  45.844  1
303347  101.310  -73.503  45.810  1
303348  101.348  -73.513  45.775  1
303349  101.387  -73.524  45.740  1
303350  101.425  -73.534  45.705  1
303351  101.463  -73.545  45.669  1
303352  101.501  -73.556  45.633  1
303353  101.540  -73.566  45.598  1
303354  101.579  -73.577  45.563  1
303355  101.617  -73.588  45.526  1
303356  101.655  -73.599  45.490  1
303357  101.693  -73.611  45.454  1
303358  101.721  -73.637  45.419  1
303359  101.750  -73.662  45.385  1
303360  101.779  -73.688  45.351  1
303361  101.809  -73.716  45.318  1
303362  101.838  -73.745  45.283  1
303363  101.868  -73.774  45.250  1
303364  101.900  -73.785  45.217  1
303365  101.943  -73.787  45.185  1
303366  101.985  -73.797  45.152  1
303367  102.029  -73.807  45.120  1
303368  102.071  -73.816  45.089  1
303369  102.115  -73.825  45.060  1
303370  102.144  -73.828  45.029  1
303371  102.168  -73.828  44.999  1
303372  102.193  -73.829  44.970  1
303373  102.218  -73.830  44.941  1
303374  102.242  -73.831  44.912  1
303375  102.267  -73.831  44.883  1
303376  102.292  -73.832  44.855  1
303377  102.317  -73.832  44.827  1
303855  95.115  -71.958  52.524  1
303856  95.141  -71.972  52.504  1
303857  95.168  -71.986  52.482  1
303858  95.194  -72.001  52.460  1
303859  95.220  -72.015  52.439  1
303860  95.247  -72.030  52.418  1
303861  95.273  -72.044  52.396  1
303862  95.300  -72.058  52.375  1
303863  95.326  -72.072  52.354  1
303864  95.352  -72.086  52.333  1
303865  95.379  -72.101  52.312  1
303866  95.392  -72.130  52.290  1
303867  95.404  -72.102  52.268  1
303868  95.438  -72.080  52.246  1
303869  95.471  -72.062  52.226  1
303870  95.509  -72.056  52.206  1
303871  95.540  -72.068  52.186  1
303872  95.566  -72.092  52.166  1
303873  95.593  -72.116  52.146  1
303874  95.619  -72.140  52.126  1
303875  95.648  -72.165  52.107  1
303876  95.677  -72.189  52.089  1
303877  95.706  -72.215  52.073  1
303878  95.736  -72.240  52.057  1
303879  95.765  -72.264  52.043  1
303880  95.794  -72.287  52.031  1
303881  95.824  -72.309  52.019  1
303882  95.853  -72.330  52.006  1
303883  95.883  -72.352  51.993  1
303884  95.921  -72.356  51.979  1
303885  95.948  -72.312  51.966  1
303886  95.995  -72.297  51.951  1
303887  96.033  -72.290  51.937  1
303888  96.071  -72.281  51.923  1
303889  96.109  -72.274  51.908  1
303890  96.148  -72.266  51.893  1
303891  96.185  -72.258  51.879  1
303892  96.224  -72.251  51.865  1
303893  96.262  -72.243  51.852  1
303894  96.300  -72.236  51.839  1
303895  96.338  -72.228  51.826  1
303896  96.376  -72.220  51.812  1
303897  96.408  -72.216  51.800  1
303898  96.440  -72.213  51.787  1
303899  96.471  -72.209  51.775  1
303900  96.503  -72.206  51.762  1
303901  96.534  -72.202  51.749  1
303902  96.565  -72.199  51.732  1
303903  96.596  -72.198  51.715  1
303904  96.624  -72.213  51.698  1
303905  96.663  -72.220  51.679  1
303906  96.713  -72.217  51.655  1
303907  96.761  -72.214  51.631  1
303908  96.810  -72.211  51.607  1
303909  96.860  -72.208  51.581  1
303910  96.908  -72.205  51.558  1
303911  96.960  -72.205  51.537  1
303912  96.977  -72.226  51.516  1
303913  96.977  -72.251  51.494  1
303914  97.009  -72.249  51.472  1
303915  97.043  -72.251  51.448  1
303916  97.079  -72.254  51.424  1
303917  97.114  -72.256  51.398  1
303918  97.149  -72.258  51.373  1
303919  97.178  -72.258  51.349  1
303920  97.209  -72.257  51.327  1
303921  97.238  -72.257  51.307  1
303922  97.274  -72.266  51.287  1
303923  97.314  -72.283  51.267  1
303924  97.353  -72.299  51.247  1
303925  97.392  -72.315  51.225  1
303926  97.432  -72.331  51.200  1
303927  97.469  -72.342  51.168  1
303928  97.502  -72.344  51.132  1
303929  97.535  -72.346  51.093  1
303930  97.568  -72.348  51.055  1
303931  97.601  -72.350  51.016  1
303932  97.634  -72.352  50.976  1
303933  97.667  -72.354  50.936  1
303934  97.701  -72.356  50.895  1
303935  97.733  -72.359  50.850  1
303936  97.764  -72.361  50.803  1
303937  97.795  -72.364  50.754  1
303938  97.825  -72.367  50.703  1
303939  97.856  -72.370  50.652  1
303940  97.886  -72.372  50.599  1
303941  97.917  -72.375  50.544  1
303942  97.947  -72.378  50.487  1
303943  97.981  -72.380  50.430  1
303944  98.014  -72.382  50.372  1
303945  98.049  -72.384  50.315  1
303946  98.084  -72.394  50.258  1
303947  98.120  -72.404  50.203  1
303948  98.156  -72.414  50.147  1
303949  98.196  -72.428  50.092  1
303950  98.236  -72.441  50.037  1
303951  98.277  -72.455  49.986  1
303952  98.318  -72.469  49.937  1
303953  98.358  -72.484  49.886  1
303954  98.396  -72.500  49.834  1
303955  98.435  -72.515  49.779  1
303956  98.472  -72.531  49.726  1
303957  98.509  -72.547  49.672  1
303958  98.547  -72.563  49.618  1
303959  98.474  -72.595  49.565  1
303960  98.512  -72.603  49.510  1
303961  98.554  -72.609  49.456  1
303962  98.611  -72.614  49.402  1
303963  98.668  -72.619  49.349  1
303964  98.717  -72.624  49.296  1
303965  98.719  -72.626  49.246  1
303966  98.721  -72.629  49.197  1
303967  98.723  -72.632  49.148  1
303968  98.747  -72.640  49.101  1
303969  98.807  -72.656  49.053  1
303970  98.867  -72.674  49.005  1
303971  98.927  -72.691  48.958  1
303972  98.941  -72.698  48.911  1
303973  98.952  -72.708  48.864  1
303974  98.963  -72.719  48.816  1
303975  98.977  -72.729  48.770  1
303976  98.998  -72.742  48.723  1
303977  99.031  -72.763  48.676  1
303978  99.066  -72.782  48.628  1
303979  99.099  -72.803  48.580  1
303980  99.133  -72.823  48.531  1
303981  99.167  -72.843  48.483  1
303982  99.201  -72.863  48.434  1
303983  99.234  -72.883  48.385  1
303984  99.269  -72.904  48.335  1
303985  99.302  -72.924  48.287  1
303986  99.336  -72.944  48.240  1
303987  99.370  -72.964  48.194  1
303988  99.404  -72.985  48.149  1
303989  99.438  -73.004  48.103  1
303990  99.474  -73.020  48.058  1
303991  99.513  -73.028  48.012  1
303992  99.553  -73.036  47.966  1
303993  99.592  -73.043  47.921  1
303994  99.615  -73.075  47.876  1
303995  99.647  -73.095  47.832  1
303996  99.678  -73.116  47.786  1
303997  99.710  -73.136  47.741  1
303998  99.741  -73.157  47.696  1
303999  99.769  -73.175  47.651  1
304000  99.798  -73.193  47.605  1
304001  99.827  -73.211  47.560  1
304002  99.855  -73.229  47.515  1
304003  99.884  -73.246  47.470  1
304004  99.913  -73.259  47.425  1
304005  99.944  -73.268  47.379  1
304006  99.975  -73.276  47.333  1
304007  100.006  -73.281  47.287  1
304008  100.037  -73.286  47.242  1
304009  100.069  -73.291  47.196  1
304010  100.101  -73.296  47.151  1
304011  100.133  -73.302  47.105  1
304012  100.164  -73.307  47.060  1
304013  100.196  -73.312  47.014  1
304014  100.227  -73.318  46.971  1
304015  100.259  -73.323  46.928  1
304016  100.290  -73.328  46.886  1
304017  100.322  -73.333  46.845  1
304018  100.354  -73.339  46.804  1
304019  100.388  -73.346  46.765  1
304020  100.428  -73.354  46.727  1
304021  100.468  -73.363  46.692  1
304022  100.508  -73.372  46.658  1
304023  100.529  -73.379  46.625  1
304024  100.544  -73.385  46.593  1
304025  100.558  -73.391  46.562  1
304026  100.572  -73.397  46.534  1
304027  100.587  -73.402  46.508  1
304028  100.609  -73.392  46.482  1
304029  100.632  -73.378  46.455  1
304030  100.663  -73.374  46.425  1
304031  100.696  -73.371  46.391  1
304032  100.729  -73.368  46.357  1
304033  100.762  -73.365  46.323  1
304034  100.795  -73.363  46.288  1
304035  100.828  -73.360  46.253  1
304036  100.863  -73.365  46.218  1
304037  100.903  -73.382  46.182  1
304038  100.939  -73.394  46.147  1
304039  100.974  -73.399  46.112  1
304040  101.014  -73.404  46.077  1
304041  101.054  -73.409  46.043  1
304042  101.094  -73.414  46.009  1
304043  101.133  -73.419  45.976  1
304044  101.173  -73.424  45.942  1
304045  101.213  -73.429  45.907  1
304046  101.253  -73.434  45.873  1
304047  101.291  -73.443  45.839  1
304048  101.330  -73.453  45.805  1
304049  101.369  -73.464  45.770  1
304050  101.407  -73.474  45.736  1
304051  101.445  -73.485  45.700  1
304052  101.483  -73.496  45.663  1
304053  101.522  -73.506  45.628  1
304054  101.560  -73.518  45.593  1
304055  101.599  -73.528  45.557  1
304056  101.637  -73.539  45.521  1
304057  101.670  -73.557  45.484  1
304058  101.699  -73.584  45.447  1
304059  101.727  -73.610  45.412  1
304060  101.756  -73.634  45.378  1
304061  101.785  -73.659  45.343  1
304062  101.814  -73.684  45.309  1
304063  101.843  -73.711  45.275  1
304064  101.873  -73.740  45.242  1
304065  101.913  -73.744  45.208  1
304066  101.956  -73.753  45.174  1
304067  101.999  -73.763  45.142  1
304068  102.042  -73.772  45.110  1
304069  102.085  -73.781  45.079  1
304070  102.126  -73.791  45.049  1
304071  102.151  -73.791  45.019  1
304072  102.176  -73.792  44.989  1
304073  102.201  -73.793  44.960  1
304074  102.226  -73.793  44.931  1
304075  102.250  -73.794  44.902  1
304076  102.275  -73.794  44.873  1
304077  102.300  -73.795  44.845  1
304556  95.113  -71.912  52.519  1
304557  95.140  -71.926  52.499  1
304558  95.166  -71.941  52.478  1
304559  95.192  -71.955  52.456  1
304560  95.219  -71.970  52.435  1
304561  95.245  -71.984  52.414  1
304562  95.271  -71.998  52.393  1
304563  95.298  -72.013  52.371  1
304564  95.324  -72.027  52.351  1
304565  95.351  -72.042  52.330  1
304566  95.377  -72.056  52.309  1
304567  95.376  -72.095  52.288  1
304568  95.366  -72.106  52.267  1
304569  95.398  -72.090  52.246  1
304570  95.436  -72.086  52.225  1
304571  95.474  -72.085  52.206  1
304572  95.512  -72.083  52.187  1
304573  95.550  -72.080  52.167  1
304574  95.585  -72.087  52.148  1
304575  95.611  -72.111  52.129  1
304576  95.640  -72.136  52.110  1
304577  95.670  -72.159  52.092  1
304578  95.699  -72.180  52.075  1
304579  95.729  -72.202  52.060  1
304580  95.758  -72.224  52.047  1
304581  95.788  -72.246  52.034  1
304582  95.818  -72.268  52.022  1
304583  95.847  -72.290  52.010  1
304584  95.880  -72.299  51.998  1
304585  95.925  -72.308  51.985  1
304586  95.952  -72.273  51.972  1
304587  96.002  -72.256  51.959  1
304588  96.047  -72.242  51.945  1
304589  96.086  -72.234  51.932  1
304590  96.123  -72.227  51.916  1
304591  96.162  -72.219  51.902  1
304592  96.200  -72.211  51.888  1
304593  96.238  -72.204  51.873  1
304594  96.276  -72.196  51.859  1
304595  96.314  -72.188  51.846  1
304596  96.353  -72.180  51.831  1
304597  96.390  -72.173  51.815  1
304598  96.422  -72.170  51.800  1
304599  96.453  -72.166  51.786  1
304600  96.484  -72.163  51.772  1
304601  96.516  -72.159  51.758  1
304602  96.547  -72.156  51.744  1
304603  96.579  -72.152  51.727  1
304604  96.607  -72.167  51.709  1
304605  96.636  -72.182  51.692  1
304606  96.673  -72.189  51.674  1
304607  96.722  -72.186  51.652  1
304608  96.771  -72.183  51.629  1
304609  96.820  -72.180  51.604  1
304610  96.869  -72.177  51.578  1
304611  96.918  -72.174  51.554  1
304612  96.967  -72.171  51.532  1
304613  97.007  -72.168  51.510  1
304614  97.004  -72.193  51.487  1
304615  97.017  -72.215  51.465  1
304616  97.061  -72.223  51.441  1
304617  97.095  -72.225  51.415  1
304618  97.130  -72.227  51.390  1
304619  97.165  -72.230  51.366  1
304620  97.196  -72.230  51.343  1
304621  97.226  -72.229  51.322  1
304622  97.256  -72.229  51.303  1
304623  97.294  -72.243  51.283  1
304624  97.334  -72.259  51.263  1
304625  97.373  -72.275  51.243  1
304626  97.413  -72.292  51.222  1
304627  97.449  -72.300  51.198  1
304628  97.481  -72.302  51.169  1
304629  97.515  -72.304  51.134  1
304630  97.547  -72.306  51.096  1
304631  97.581  -72.309  51.057  1
304632  97.614  -72.310  51.019  1
304633  97.647  -72.312  50.979  1
304634  97.680  -72.315  50.937  1
304635  97.713  -72.316  50.895  1
304636  97.746  -72.318  50.848  1
304637  97.779  -72.321  50.800  1
304638  97.809  -72.324  50.750  1
304639  97.840  -72.326  50.698  1
304640  97.870  -72.329  50.646  1
304641  97.900  -72.332  50.594  1
304642  97.930  -72.335  50.540  1
304643  97.961  -72.338  50.484  1
304644  97.991  -72.340  50.427  1
304645  98.022  -72.343  50.370  1
304646  98.056  -72.346  50.313  1
304647  98.092  -72.357  50.256  1
304648  98.133  -72.371  50.201  1
304649  98.173  -72.384  50.145  1
304650  98.214  -72.399  50.089  1
304651  98.254  -72.412  50.036  1
304652  98.295  -72.426  49.985  1
304653  98.336  -72.440  49.936  1
304654  98.376  -72.454  49.886  1
304655  98.415  -72.470  49.834  1
304656  98.453  -72.486  49.780  1
304657  98.492  -72.502  49.726  1
304658  98.529  -72.518  49.671  1
304659  98.566  -72.534  49.617  1
304660  98.462  -72.572  49.563  1
304661  98.500  -72.579  49.510  1
304662  98.554  -72.584  49.456  1
304663  98.612  -72.590  49.402  1
304664  98.678  -72.594  49.349  1
304665  98.726  -72.597  49.298  1
304666  98.725  -72.596  49.248  1
304667  98.725  -72.595  49.200  1
304668  98.725  -72.594  49.151  1
304669  98.764  -72.609  49.104  1
304670  98.823  -72.631  49.056  1
304671  98.883  -72.652  49.009  1
304672  98.938  -72.672  48.962  1
304673  98.949  -72.682  48.914  1
304674  98.960  -72.693  48.866  1
304675  98.972  -72.703  48.819  1
304676  98.992  -72.715  48.772  1
304677  99.012  -72.728  48.725  1
304678  99.038  -72.743  48.677  1
304679  99.072  -72.763  48.630  1
304680  99.106  -72.784  48.582  1
304681  99.139  -72.804  48.533  1
304682  99.173  -72.824  48.484  1
304683  99.207  -72.844  48.435  1
304684  99.241  -72.864  48.385  1
304685  99.275  -72.885  48.336  1
304686  99.308  -72.904  48.288  1
304687  99.342  -72.925  48.240  1
304688  99.376  -72.945  48.194  1
304689  99.410  -72.965  48.148  1
304690  99.446  -72.981  48.103  1
304691  99.486  -72.988  48.058  1
304692  99.525  -72.995  48.012  1
304693  99.565  -73.003  47.966  1
304694  99.605  -73.011  47.920  1
304695  99.631  -73.037  47.876  1
304696  99.658  -73.064  47.831  1
304697  99.689  -73.085  47.786  1
304698  99.721  -73.105  47.741  1
304699  99.752  -73.126  47.696  1
304700  99.783  -73.146  47.650  1
304701  99.815  -73.167  47.605  1
304702  99.844  -73.186  47.560  1
304703  99.872  -73.203  47.515  1
304704  99.901  -73.221  47.470  1
304705  99.930  -73.239  47.425  1
304706  99.960  -73.247  47.379  1
304707  99.991  -73.254  47.332  1
304708  100.023  -73.259  47.287  1
304709  100.054  -73.264  47.242  1
304710  100.086  -73.270  47.197  1
304711  100.118  -73.275  47.151  1
304712  100.149  -73.280  47.105  1
304713  100.181  -73.286  47.059  1
304714  100.212  -73.291  47.013  1
304715  100.244  -73.296  46.970  1
304716  100.275  -73.302  46.927  1
304717  100.307  -73.307  46.885  1
304718  100.339  -73.311  46.843  1
304719  100.370  -73.317  46.802  1
304720  100.402  -73.322  46.762  1
304721  100.433  -73.327  46.725  1
304722  100.473  -73.336  46.689  1
304723  100.513  -73.346  46.654  1
304724  100.533  -73.352  46.622  1
304725  100.547  -73.358  46.591  1
304726  100.562  -73.364  46.561  1
304727  100.584  -73.353  46.532  1
304728  100.607  -73.340  46.504  1
304729  100.630  -73.326  46.477  1
304730  100.653  -73.311  46.451  1
304731  100.681  -73.302  46.420  1
304732  100.714  -73.300  46.388  1
304733  100.747  -73.297  46.354  1
304734  100.779  -73.294  46.319  1
304735  100.813  -73.292  46.284  1
304736  100.848  -73.298  46.249  1
304737  100.888  -73.314  46.213  1
304738  100.927  -73.332  46.178  1
304739  100.964  -73.343  46.143  1
304740  100.996  -73.348  46.107  1
304741  101.035  -73.353  46.073  1
304742  101.075  -73.358  46.039  1
304743  101.115  -73.363  46.005  1
304744  101.155  -73.368  45.971  1
304745  101.194  -73.373  45.938  1
304746  101.234  -73.377  45.903  1
304747  101.274  -73.383  45.868  1
304748  101.312  -73.393  45.834  1
304749  101.350  -73.404  45.800  1
304750  101.389  -73.415  45.766  1
304751  101.427  -73.425  45.731  1
304752  101.465  -73.436  45.695  1
304753  101.503  -73.447  45.659  1
304754  101.542  -73.458  45.624  1
304755  101.581  -73.468  45.588  1
304756  101.619  -73.479  45.552  1
304757  101.648  -73.504  45.515  1
304758  101.677  -73.531  45.478  1
304759  101.705  -73.558  45.441  1
304760  101.734  -73.583  45.406  1
304761  101.762  -73.607  45.371  1
304762  101.791  -73.632  45.336  1
304763  101.820  -73.656  45.301  1
304764  101.849  -73.681  45.267  1
304765  101.883  -73.700  45.233  1
304766  101.926  -73.709  45.198  1
304767  101.969  -73.719  45.164  1
304768  102.012  -73.728  45.132  1
304769  102.055  -73.738  45.101  1
304770  102.098  -73.748  45.070  1
304771  102.134  -73.754  45.039  1
304772  102.159  -73.755  45.009  1
304773  102.184  -73.755  44.980  1
304774  102.208  -73.756  44.951  1
304775  102.233  -73.756  44.922  1
304776  102.258  -73.757  44.893  1
304777  102.283  -73.758  44.864  1
305257  95.111  -71.867  52.514  1
305258  95.138  -71.882  52.494  1
305259  95.164  -71.896  52.473  1
305260  95.191  -71.911  52.452  1
305261  95.217  -71.925  52.431  1
305262  95.243  -71.939  52.410  1
305263  95.270  -71.954  52.389  1
305264  95.296  -71.968  52.369  1
305265  95.322  -71.982  52.349  1
305266  95.349  -71.996  52.327  1
305267  95.365  -72.014  52.307  1
305268  95.359  -72.059  52.287  1
305269  95.355  -72.078  52.266  1
305270  95.370  -72.089  52.245  1
305271  95.408  -72.086  52.226  1
305272  95.447  -72.083  52.207  1
305273  95.485  -72.080  52.189  1
305274  95.523  -72.077  52.169  1
305275  95.563  -72.074  52.151  1
305276  95.605  -72.075  52.133  1
305277  95.634  -72.096  52.113  1
305278  95.664  -72.118  52.095  1
305279  95.693  -72.140  52.079  1
305280  95.723  -72.161  52.064  1
305281  95.752  -72.183  52.051  1
305282  95.782  -72.205  52.039  1
305283  95.812  -72.227  52.027  1
305284  95.840  -72.245  52.015  1
305285  95.884  -72.251  52.004  1
305286  95.929  -72.260  51.992  1
305287  95.961  -72.238  51.980  1
305288  96.007  -72.217  51.967  1
305289  96.055  -72.199  51.954  1
305290  96.100  -72.187  51.942  1
305291  96.138  -72.180  51.926  1
305292  96.176  -72.171  51.911  1
305293  96.214  -72.164  51.897  1
305294  96.252  -72.156  51.883  1
305295  96.291  -72.149  51.869  1
305296  96.329  -72.141  51.855  1
305297  96.367  -72.133  51.839  1
305298  96.404  -72.127  51.821  1
305299  96.435  -72.123  51.803  1
305300  96.466  -72.120  51.787  1
305301  96.498  -72.116  51.771  1
305302  96.529  -72.113  51.756  1
305303  96.560  -72.109  51.741  1
305304  96.590  -72.120  51.723  1
305305  96.618  -72.135  51.704  1
305306  96.647  -72.150  51.686  1
305307  96.683  -72.158  51.668  1
305308  96.732  -72.155  51.648  1
305309  96.781  -72.153  51.626  1
305310  96.830  -72.150  51.603  1
305311  96.879  -72.147  51.578  1
305312  96.928  -72.144  51.554  1
305313  96.977  -72.141  51.532  1
305314  97.003  -72.137  51.510  1
305315  97.009  -72.152  51.487  1
305316  97.015  -72.175  51.464  1
305317  97.066  -72.187  51.438  1
305318  97.111  -72.196  51.412  1
305319  97.146  -72.199  51.386  1
305320  97.181  -72.201  51.362  1
305321  97.214  -72.202  51.340  1
305322  97.243  -72.202  51.320  1
305323  97.275  -72.204  51.300  1
305324  97.314  -72.220  51.279  1
305325  97.354  -72.236  51.259  1
305326  97.393  -72.252  51.239  1
305327  97.428  -72.258  51.218  1
305328  97.461  -72.260  51.195  1
305329  97.494  -72.262  51.167  1
305330  97.527  -72.265  51.135  1
305331  97.561  -72.266  51.098  1
305332  97.593  -72.268  51.059  1
305333  97.627  -72.271  51.020  1
305334  97.659  -72.272  50.979  1
305335  97.692  -72.274  50.937  1
305336  97.726  -72.277  50.893  1
305337  97.758  -72.278  50.843  1
305338  97.792  -72.280  50.793  1
305339  97.823  -72.283  50.742  1
305340  97.853  -72.286  50.690  1
305341  97.884  -72.289  50.639  1
305342  97.914  -72.292  50.588  1
305343  97.944  -72.294  50.534  1
305344  97.974  -72.297  50.478  1
305345  98.005  -72.300  50.423  1
305346  98.035  -72.303  50.367  1
305347  98.048  -72.321  50.310  1
305348  98.107  -72.329  50.255  1
305349  98.151  -72.342  50.200  1
305350  98.192  -72.356  50.144  1
305351  98.232  -72.369  50.088  1
305352  98.273  -72.384  50.035  1
305353  98.313  -72.397  49.985  1
305354  98.354  -72.411  49.936  1
305355  98.394  -72.424  49.886  1
305356  98.433  -72.441  49.834  1
305357  98.472  -72.457  49.780  1
305358  98.510  -72.473  49.726  1
305359  98.549  -72.489  49.671  1
305360  98.569  -72.508  49.616  1
305361  98.451  -72.549  49.563  1
305362  98.497  -72.555  49.511  1
305363  98.559  -72.559  49.457  1
305364  98.627  -72.563  49.404  1
305365  98.694  -72.568  49.351  1
305366  98.734  -72.569  49.301  1
305367  98.734  -72.569  49.252  1
305368  98.734  -72.568  49.204  1
305369  98.754  -72.579  49.155  1
305370  98.783  -72.596  49.108  1
305371  98.839  -72.617  49.060  1
305372  98.898  -72.638  49.013  1
305373  98.946  -72.656  48.966  1
305374  98.957  -72.667  48.918  1
305375  98.969  -72.677  48.869  1
305376  98.988  -72.689  48.821  1
305377  99.008  -72.701  48.775  1
305378  99.027  -72.713  48.727  1
305379  99.048  -72.725  48.679  1
305380  99.078  -72.744  48.632  1
305381  99.112  -72.764  48.584  1
305382  99.146  -72.785  48.534  1
305383  99.180  -72.804  48.485  1
305384  99.213  -72.825  48.435  1
305385  99.247  -72.845  48.386  1
305386  99.281  -72.865  48.337  1
305387  99.315  -72.885  48.289  1
305388  99.349  -72.906  48.241  1
305389  99.382  -72.926  48.194  1
305390  99.419  -72.941  48.148  1
305391  99.458  -72.948  48.103  1
305392  99.498  -72.956  48.057  1
305393  99.538  -72.963  48.011  1
305394  99.577  -72.970  47.966  1
305395  99.617  -72.978  47.920  1
305396  99.649  -72.997  47.876  1
305397  99.669  -73.032  47.831  1
305398  99.700  -73.054  47.787  1
305399  99.732  -73.074  47.741  1
305400  99.763  -73.095  47.696  1
305401  99.794  -73.115  47.650  1
305402  99.826  -73.136  47.605  1
305403  99.857  -73.156  47.561  1
305404  99.889  -73.177  47.515  1
305405  99.918  -73.195  47.470  1
305406  99.947  -73.214  47.425  1
305407  99.977  -73.227  47.379  1
305408  100.008  -73.233  47.333  1
305409  100.039  -73.238  47.288  1
305410  100.071  -73.243  47.243  1
305411  100.103  -73.249  47.197  1
305412  100.134  -73.254  47.152  1
305413  100.165  -73.259  47.106  1
305414  100.197  -73.264  47.060  1
305415  100.229  -73.269  47.015  1
305416  100.261  -73.274  46.971  1
305417  100.292  -73.280  46.928  1
305418  100.324  -73.285  46.886  1
305419  100.355  -73.290  46.844  1
305420  100.387  -73.296  46.803  1
305421  100.418  -73.301  46.762  1
305422  100.450  -73.306  46.723  1
305423  100.482  -73.311  46.688  1
305424  100.517  -73.318  46.654  1
305425  100.537  -73.325  46.622  1
305426  100.559  -73.314  46.591  1
305427  100.582  -73.300  46.562  1
305428  100.605  -73.286  46.533  1
305429  100.629  -73.273  46.506  1
305430  100.652  -73.259  46.478  1
305431  100.675  -73.246  46.449  1
305432  100.698  -73.232  46.417  1
305433  100.731  -73.229  46.384  1
305434  100.764  -73.226  46.349  1
305435  100.797  -73.224  46.315  1
305436  100.833  -73.230  46.280  1
305437  100.873  -73.247  46.245  1
305438  100.912  -73.264  46.210  1
305439  100.952  -73.281  46.174  1
305440  100.987  -73.292  46.139  1
305441  101.020  -73.297  46.104  1
305442  101.056  -73.302  46.070  1
305443  101.096  -73.307  46.036  1
305444  101.135  -73.311  46.002  1
305445  101.175  -73.317  45.969  1
305446  101.215  -73.321  45.935  1
305447  101.255  -73.327  45.900  1
305448  101.294  -73.333  45.865  1
305449  101.332  -73.344  45.831  1
305450  101.371  -73.355  45.797  1
305451  101.409  -73.365  45.762  1
305452  101.447  -73.376  45.727  1
305453  101.486  -73.387  45.692  1
305454  101.524  -73.398  45.656  1
305455  101.562  -73.409  45.620  1
305456  101.598  -73.424  45.584  1
305457  101.626  -73.451  45.547  1
305458  101.655  -73.477  45.510  1
305459  101.683  -73.505  45.473  1
305460  101.711  -73.531  45.436  1
305461  101.740  -73.556  45.400  1
305462  101.769  -73.581  45.364  1
305463  101.798  -73.605  45.329  1
305464  101.826  -73.629  45.293  1
305465  101.855  -73.653  45.258  1
305466  101.896  -73.666  45.224  1
305467  101.939  -73.675  45.189  1
305468  101.982  -73.685  45.155  1
305469  102.025  -73.694  45.123  1
305470  102.068  -73.704  45.092  1
305471  102.111  -73.714  45.061  1
305472  102.142  -73.718  45.030  1
305473  102.167  -73.718  44.999  1
305474  102.192  -73.719  44.970  1
305475  102.217  -73.719  44.940  1
305476  102.241  -73.720  44.912  1
305477  102.266  -73.721  44.885  1
305478  102.290  -73.721  44.856  1
305958  95.110  -71.823  52.511  1
305959  95.136  -71.836  52.490  1
305960  95.162  -71.851  52.469  1
305961  95.189  -71.865  52.449  1
305962  95.215  -71.879  52.428  1
305963  95.242  -71.894  52.407  1
305964  95.268  -71.908  52.386  1
305965  95.294  -71.923  52.366  1
305966  95.321  -71.937  52.347  1
305967  95.347  -71.951  52.327  1
305968  95.342  -71.973  52.307  1
305969  95.342  -72.023  52.287  1
305970  95.344  -72.050  52.267  1
305971  95.349  -72.058  52.246  1
305972  95.388  -72.055  52.227  1
305973  95.426  -72.052  52.208  1
305974  95.464  -72.049  52.190  1
305975  95.509  -72.046  52.172  1
305976  95.561  -72.043  52.154  1
305977  95.601  -72.040  52.136  1
305978  95.628  -72.055  52.118  1
305979  95.658  -72.077  52.100  1
305980  95.687  -72.099  52.083  1
305981  95.717  -72.121  52.068  1
305982  95.747  -72.142  52.055  1
305983  95.776  -72.164  52.043  1
305984  95.806  -72.186  52.031  1
305985  95.842  -72.195  52.020  1
305986  95.887  -72.203  52.010  1
305987  95.933  -72.212  51.999  1
305988  95.971  -72.206  51.987  1
305989  96.012  -72.177  51.975  1
305990  96.060  -72.160  51.963  1
305991  96.110  -72.143  51.951  1
305992  96.152  -72.132  51.937  1
305993  96.190  -72.124  51.922  1
305994  96.229  -72.117  51.907  1
305995  96.267  -72.109  51.893  1
305996  96.305  -72.102  51.880  1
305997  96.343  -72.094  51.865  1
305998  96.381  -72.086  51.849  1
305999  96.417  -72.080  51.831  1
306000  96.448  -72.077  51.812  1
306001  96.480  -72.073  51.793  1
306002  96.511  -72.070  51.774  1
306003  96.542  -72.066  51.757  1
306004  96.572  -72.073  51.742  1
306005  96.601  -72.088  51.722  1
306006  96.629  -72.104  51.701  1
306007  96.658  -72.119  51.681  1
306008  96.692  -72.128  51.661  1
306009  96.742  -72.125  51.643  1
306010  96.791  -72.123  51.624  1
306011  96.839  -72.120  51.603  1
306012  96.889  -72.117  51.580  1
306013  96.938  -72.114  51.560  1
306014  96.979  -72.111  51.538  1
306015  97.000  -72.106  51.516  1
306016  97.013  -72.111  51.492  1
306017  97.015  -72.136  51.469  1
306018  97.057  -72.143  51.441  1
306019  97.114  -72.159  51.413  1
306020  97.162  -72.170  51.385  1
306021  97.197  -72.172  51.362  1
306022  97.231  -72.174  51.340  1
306023  97.261  -72.174  51.319  1
306024  97.295  -72.180  51.299  1
306025  97.334  -72.196  51.277  1
306026  97.374  -72.213  51.255  1
306027  97.407  -72.216  51.234  1
306028  97.441  -72.218  51.213  1
306029  97.474  -72.221  51.191  1
306030  97.507  -72.222  51.164  1
306031  97.540  -72.224  51.133  1
306032  97.573  -72.227  51.098  1
306033  97.606  -72.228  51.060  1
306034  97.639  -72.230  51.020  1
306035  97.672  -72.233  50.978  1
306036  97.705  -72.234  50.933  1
306037  97.738  -72.236  50.887  1
306038  97.771  -72.239  50.835  1
306039  97.804  -72.240  50.782  1
306040  97.837  -72.243  50.730  1
306041  97.867  -72.246  50.681  1
306042  97.897  -72.249  50.631  1
306043  97.928  -72.251  50.579  1
306044  97.958  -72.254  50.526  1
306045  97.989  -72.257  50.472  1
306046  98.008  -72.268  50.418  1
306047  98.010  -72.290  50.363  1
306048  98.015  -72.311  50.308  1
306049  98.074  -72.318  50.254  1
306050  98.134  -72.325  50.199  1
306051  98.193  -72.332  50.143  1
306052  98.250  -72.340  50.088  1
306053  98.291  -72.354  50.034  1
306054  98.332  -72.368  49.986  1
306055  98.372  -72.382  49.936  1
306056  98.413  -72.396  49.885  1
306057  98.451  -72.412  49.833  1
306058  98.490  -72.428  49.778  1
306059  98.528  -72.443  49.724  1
306060  98.567  -72.460  49.671  1
306061  98.558  -72.481  49.617  1
306062  98.445  -72.522  49.565  1
306063  98.508  -72.529  49.510  1
306064  98.575  -72.533  49.458  1
306065  98.643  -72.537  49.407  1
306066  98.710  -72.541  49.356  1
306067  98.743  -72.543  49.306  1
306068  98.743  -72.541  49.257  1
306069  98.759  -72.550  49.208  1
306070  98.788  -72.568  49.160  1
306071  98.817  -72.584  49.112  1
306072  98.854  -72.603  49.065  1
306073  98.913  -72.624  49.018  1
306074  98.955  -72.641  48.971  1
306075  98.966  -72.651  48.922  1
306076  98.984  -72.663  48.873  1
306077  99.003  -72.675  48.825  1
306078  99.023  -72.688  48.777  1
306079  99.043  -72.700  48.729  1
306080  99.063  -72.712  48.682  1
306081  99.084  -72.725  48.634  1
306082  99.118  -72.745  48.585  1
306083  99.152  -72.766  48.535  1
306084  99.186  -72.785  48.485  1
306085  99.220  -72.806  48.436  1
306086  99.254  -72.826  48.387  1
306087  99.287  -72.846  48.337  1
306088  99.321  -72.866  48.289  1
306089  99.355  -72.886  48.242  1
306090  99.392  -72.901  48.195  1
306091  99.431  -72.908  48.149  1
306092  99.471  -72.916  48.104  1
306093  99.510  -72.923  48.057  1
306094  99.550  -72.931  48.012  1
306095  99.589  -72.938  47.967  1
306096  99.629  -72.946  47.922  1
306097  99.666  -72.957  47.877  1
306098  99.687  -72.992  47.832  1
306099  99.712  -73.023  47.787  1
306100  99.743  -73.043  47.742  1
306101  99.774  -73.064  47.697  1
306102  99.806  -73.084  47.651  1
306103  99.837  -73.105  47.606  1
306104  99.868  -73.125  47.562  1
306105  99.900  -73.145  47.517  1
306106  99.931  -73.166  47.472  1
306107  99.963  -73.187  47.427  1
306108  99.993  -73.205  47.380  1
306109  100.025  -73.211  47.334  1
306110  100.056  -73.216  47.289  1
306111  100.087  -73.221  47.245  1
306112  100.119  -73.227  47.199  1
306113  100.151  -73.232  47.154  1
306114  100.182  -73.236  47.109  1
306115  100.213  -73.241  47.063  1
306116  100.245  -73.245  47.018  1
306117  100.276  -73.249  46.973  1
306118  100.308  -73.253  46.930  1
306119  100.339  -73.257  46.888  1
306120  100.370  -73.261  46.846  1
306121  100.402  -73.264  46.804  1
306122  100.433  -73.269  46.764  1
306123  100.465  -73.273  46.725  1
306124  100.496  -73.277  46.689  1
306125  100.527  -73.280  46.656  1
306126  100.556  -73.273  46.623  1
306127  100.580  -73.252  46.592  1
306128  100.604  -73.233  46.562  1
306129  100.627  -73.220  46.534  1
306130  100.650  -73.206  46.506  1
306131  100.674  -73.192  46.478  1
306132  100.697  -73.179  46.447  1
306133  100.720  -73.165  46.415  1
306134  100.749  -73.158  46.381  1
306135  100.782  -73.155  46.346  1
306136  100.818  -73.163  46.311  1
306137  100.857  -73.180  46.276  1
306138  100.897  -73.197  46.242  1
306139  100.936  -73.214  46.207  1
306140  100.976  -73.231  46.171  1
306141  101.011  -73.241  46.136  1
306142  101.044  -73.246  46.102  1
306143  101.077  -73.251  46.068  1
306144  101.116  -73.255  46.034  1
306145  101.156  -73.261  46.000  1
306146  101.196  -73.265  45.967  1
306147  101.236  -73.271  45.933  1
306148  101.275  -73.275  45.898  1
306149  101.314  -73.284  45.863  1
306150  101.352  -73.295  45.829  1
306151  101.391  -73.305  45.795  1
306152  101.429  -73.317  45.760  1
306153  101.468  -73.327  45.725  1
306154  101.506  -73.338  45.690  1
306155  101.544  -73.349  45.654  1
306156  101.575  -73.371  45.618  1
306157  101.604  -73.398  45.581  1
306158  101.632  -73.424  45.543  1
306159  101.661  -73.452  45.506  1
306160  101.689  -73.478  45.468  1
306161  101.717  -73.505  45.431  1
306162  101.746  -73.529  45.395  1
306163  101.775  -73.553  45.359  1
306164  101.804  -73.578  45.323  1
306165  101.833  -73.603  45.287  1
306166  101.868  -73.621  45.251  1
306167  101.909  -73.632  45.216  1
306168  101.952  -73.641  45.182  1
306169  101.995  -73.651  45.149  1
306170  102.038  -73.661  45.117  1
306171  102.081  -73.670  45.085  1
306172  102.124  -73.680  45.054  1
306173  102.150  -73.681  45.023  1
306174  102.175  -73.681  44.992  1
306175  102.199  -73.682  44.962  1
306176  102.224  -73.683  44.933  1
306177  102.249  -73.683  44.904  1
306178  102.274  -73.684  44.876  1
306659  95.108  -71.777  52.508  1
306660  95.134  -71.791  52.486  1
306661  95.161  -71.806  52.466  1
306662  95.187  -71.820  52.446  1
306663  95.213  -71.835  52.425  1
306664  95.240  -71.849  52.405  1
306665  95.266  -71.864  52.384  1
306666  95.293  -71.878  52.364  1
306667  95.319  -71.892  52.346  1
306668  95.345  -71.906  52.326  1
306669  95.320  -71.934  52.306  1
306670  95.325  -71.988  52.287  1
306671  95.332  -72.022  52.267  1
306672  95.328  -72.028  52.247  1
306673  95.367  -72.025  52.228  1
306674  95.405  -72.022  52.210  1
306675  95.455  -72.018  52.192  1
306676  95.507  -72.015  52.175  1
306677  95.559  -72.012  52.157  1
306678  95.598  -72.009  52.140  1
306679  95.622  -72.015  52.122  1
306680  95.652  -72.036  52.104  1
306681  95.681  -72.058  52.088  1
306682  95.711  -72.080  52.073  1
306683  95.741  -72.102  52.060  1
306684  95.770  -72.124  52.047  1
306685  95.800  -72.138  52.036  1
306686  95.845  -72.147  52.026  1
306687  95.891  -72.156  52.015  1
306688  95.937  -72.164  52.005  1
306689  95.982  -72.174  51.994  1
306690  96.016  -72.137  51.984  1
306691  96.065  -72.121  51.973  1
306692  96.114  -72.104  51.962  1
306693  96.164  -72.087  51.948  1
306694  96.204  -72.077  51.934  1
306695  96.243  -72.070  51.920  1
306696  96.281  -72.061  51.906  1
306697  96.319  -72.054  51.893  1
306698  96.358  -72.046  51.879  1
306699  96.395  -72.039  51.863  1
306700  96.431  -72.033  51.845  1
306701  96.462  -72.030  51.825  1
306702  96.493  -72.026  51.805  1
306703  96.524  -72.023  51.785  1
306704  96.554  -72.026  51.767  1
306705  96.583  -72.042  51.749  1
306706  96.612  -72.057  51.727  1
306707  96.640  -72.072  51.705  1
306708  96.669  -72.087  51.683  1
306709  96.702  -72.098  51.661  1
306710  96.751  -72.095  51.643  1
306711  96.800  -72.092  51.625  1
306712  96.850  -72.089  51.606  1
306713  96.898  -72.086  51.587  1
306714  96.947  -72.083  51.568  1
306715  96.976  -72.080  51.547  1
306716  96.997  -72.075  51.525  1
306717  97.017  -72.071  51.503  1
306718  97.015  -72.098  51.479  1
306719  97.054  -72.103  51.451  1
306720  97.105  -72.115  51.422  1
306721  97.163  -72.131  51.392  1
306722  97.213  -72.143  51.365  1
306723  97.248  -72.146  51.340  1
306724  97.279  -72.146  51.318  1
306725  97.315  -72.157  51.296  1
306726  97.354  -72.172  51.273  1
306727  97.387  -72.174  51.250  1
306728  97.420  -72.176  51.227  1
306729  97.453  -72.178  51.204  1
306730  97.487  -72.180  51.180  1
306731  97.519  -72.182  51.155  1
306732  97.552  -72.184  51.125  1
306733  97.586  -72.186  51.092  1
306734  97.618  -72.188  51.055  1
306735  97.652  -72.190  51.014  1
306736  97.684  -72.193  50.970  1
306737  97.718  -72.194  50.925  1
306738  97.751  -72.196  50.877  1
306739  97.784  -72.199  50.826  1
306740  97.817  -72.200  50.774  1
306741  97.850  -72.202  50.722  1
306742  97.881  -72.205  50.673  1
306743  97.912  -72.208  50.622  1
306744  97.942  -72.211  50.571  1
306745  97.972  -72.214  50.518  1
306746  97.979  -72.233  50.463  1
306747  97.981  -72.254  50.409  1
306748  97.984  -72.276  50.355  1
306749  98.005  -72.293  50.301  1
306750  98.048  -72.300  50.247  1
306751  98.104  -72.310  50.194  1
306752  98.161  -72.321  50.140  1
306753  98.219  -72.328  50.087  1
306754  98.279  -72.336  50.035  1
306755  98.338  -72.343  49.986  1
306756  98.390  -72.352  49.935  1
306757  98.431  -72.367  49.883  1
306758  98.469  -72.382  49.831  1
306759  98.505  -72.397  49.777  1
306760  98.536  -72.409  49.722  1
306761  98.567  -72.420  49.669  1
306762  98.504  -72.451  49.617  1
306763  98.492  -72.476  49.565  1
306764  98.540  -72.493  49.514  1
306765  98.591  -72.506  49.463  1
306766  98.659  -72.510  49.412  1
306767  98.726  -72.515  49.362  1
306768  98.752  -72.515  49.314  1
306769  98.765  -72.522  49.264  1
306770  98.794  -72.539  49.215  1
306771  98.823  -72.556  49.167  1
306772  98.852  -72.573  49.118  1
306773  98.881  -72.591  49.071  1
306774  98.929  -72.609  49.024  1
306775  98.963  -72.625  48.976  1
306776  98.979  -72.637  48.927  1
306777  98.999  -72.649  48.878  1
306778  99.019  -72.661  48.828  1
306779  99.039  -72.673  48.779  1
306780  99.059  -72.685  48.730  1
306781  99.078  -72.698  48.683  1
306782  99.098  -72.710  48.635  1
306783  99.124  -72.726  48.586  1
306784  99.158  -72.746  48.536  1
306785  99.192  -72.766  48.486  1
306786  99.226  -72.786  48.437  1
306787  99.260  -72.807  48.388  1
306788  99.293  -72.827  48.339  1
306789  99.328  -72.847  48.290  1
306790  99.364  -72.861  48.243  1
306791  99.404  -72.869  48.196  1
306792  99.443  -72.876  48.150  1
306793  99.483  -72.884  48.104  1
306794  99.522  -72.891  48.058  1
306795  99.562  -72.898  48.012  1
306796  99.602  -72.906  47.967  1
306797  99.641  -72.913  47.922  1
306798  99.681  -72.921  47.877  1
306799  99.704  -72.952  47.833  1
306800  99.725  -72.989  47.788  1
306801  99.754  -73.011  47.743  1
306802  99.785  -73.032  47.698  1
306803  99.817  -73.053  47.653  1
306804  99.848  -73.073  47.607  1
306805  99.879  -73.094  47.563  1
306806  99.911  -73.114  47.518  1
306807  99.942  -73.135  47.473  1
306808  99.974  -73.155  47.429  1
306809  100.005  -73.173  47.382  1
306810  100.037  -73.167  47.336  1
306811  100.068  -73.171  47.291  1
306812  100.100  -73.176  47.247  1
306813  100.131  -73.180  47.201  1
306814  100.162  -73.183  47.157  1
306815  100.194  -73.187  47.112  1
306816  100.225  -73.192  47.066  1
306817  100.256  -73.195  47.021  1
306818  100.288  -73.199  46.977  1
306819  100.319  -73.203  46.934  1
306820  100.350  -73.208  46.891  1
306821  100.382  -73.211  46.849  1
306822  100.413  -73.215  46.807  1
306823  100.444  -73.219  46.767  1
306824  100.476  -73.224  46.728  1
306825  100.507  -73.227  46.692  1
306826  100.540  -73.236  46.659  1
306827  100.573  -73.239  46.625  1
306828  100.597  -73.218  46.593  1
306829  100.621  -73.198  46.562  1
306830  100.645  -73.177  46.534  1
306831  100.670  -73.155  46.505  1
306832  100.694  -73.134  46.476  1
306833  100.718  -73.114  46.445  1
306834  100.742  -73.098  46.414  1
306835  100.766  -73.087  46.380  1
306836  100.804  -73.096  46.344  1
306837  100.843  -73.113  46.308  1
306838  100.882  -73.130  46.273  1
306839  100.921  -73.147  46.239  1
306840  100.961  -73.164  46.203  1
306841  101.000  -73.181  46.168  1
306842  101.035  -73.190  46.135  1
306843  101.068  -73.195  46.100  1
306844  101.101  -73.199  46.065  1
306845  101.137  -73.205  46.032  1
306846  101.177  -73.209  45.999  1
306847  101.216  -73.214  45.966  1
306848  101.256  -73.219  45.932  1
306849  101.296  -73.224  45.897  1
306850  101.334  -73.235  45.863  1
306851  101.373  -73.246  45.829  1
306852  101.411  -73.257  45.795  1
306853  101.450  -73.267  45.760  1
306854  101.488  -73.278  45.725  1
306855  101.525  -73.291  45.689  1
306856  101.553  -73.318  45.652  1
306857  101.582  -73.345  45.616  1
306858  101.610  -73.371  45.579  1
306859  101.638  -73.398  45.541  1
306860  101.667  -73.425  45.504  1
306861  101.695  -73.452  45.466  1
306862  101.724  -73.477  45.429  1
306863  101.752  -73.502  45.391  1
306864  101.781  -73.526  45.355  1
306865  101.810  -73.551  45.319  1
306866  101.840  -73.574  45.282  1
306867  101.880  -73.587  45.245  1
306868  101.922  -73.598  45.210  1
306869  101.965  -73.607  45.176  1
306870  102.009  -73.617  45.143  1
306871  102.051  -73.627  45.111  1
306872  102.095  -73.636  45.079  1
306873  102.133  -73.644  45.048  1
306874  102.158  -73.644  45.017  1
306875  102.182  -73.645  44.986  1
306876  102.207  -73.646  44.955  1
306877  102.232  -73.646  44.926  1
306878  102.257  -73.647  44.898  1
307360  95.106  -71.732  52.504  1
307361  95.132  -71.747  52.483  1
307362  95.159  -71.760  52.463  1
307363  95.185  -71.775  52.443  1
307364  95.211  -71.789  52.422  1
307365  95.238  -71.804  52.402  1
307366  95.264  -71.818  52.382  1
307367  95.290  -71.832  52.363  1
307368  95.317  -71.847  52.345  1
307369  95.326  -71.866  52.325  1
307370  95.298  -71.894  52.306  1
307371  95.309  -71.952  52.288  1
307372  95.317  -71.990  52.269  1
307373  95.308  -71.997  52.249  1
307374  95.349  -71.994  52.230  1
307375  95.401  -71.991  52.212  1
307376  95.453  -71.987  52.195  1
307377  95.506  -71.984  52.178  1
307378  95.557  -71.981  52.161  1
307379  95.595  -71.978  52.143  1
307380  95.617  -71.975  52.127  1
307381  95.646  -71.995  52.109  1
307382  95.675  -72.017  52.093  1
307383  95.705  -72.039  52.079  1
307384  95.735  -72.061  52.065  1
307385  95.764  -72.083  52.052  1
307386  95.804  -72.090  52.042  1
307387  95.849  -72.099  52.031  1
307388  95.895  -72.108  52.021  1
307389  95.940  -72.117  52.012  1
307390  95.986  -72.126  52.003  1
307391  96.021  -72.098  51.993  1
307392  96.071  -72.081  51.984  1
307393  96.119  -72.064  51.973  1
307394  96.169  -72.048  51.961  1
307395  96.218  -72.031  51.947  1
307396  96.257  -72.022  51.933  1
307397  96.295  -72.014  51.920  1
307398  96.333  -72.007  51.907  1
307399  96.372  -71.999  51.894  1
307400  96.410  -71.992  51.878  1
307401  96.444  -71.986  51.860  1
307402  96.475  -71.983  51.840  1
307403  96.507  -71.980  51.820  1
307404  96.537  -71.980  51.801  1
307405  96.566  -71.995  51.780  1
307406  96.594  -72.010  51.760  1
307407  96.622  -72.025  51.736  1
307408  96.651  -72.040  51.712  1
307409  96.679  -72.056  51.688  1
307410  96.712  -72.067  51.665  1
307411  96.761  -72.064  51.645  1
307412  96.810  -72.061  51.627  1
307413  96.859  -72.058  51.611  1
307414  96.908  -72.056  51.593  1
307415  96.952  -72.052  51.577  1
307416  96.972  -72.048  51.557  1
307417  96.993  -72.044  51.536  1
307418  97.013  -72.040  51.515  1
307419  97.016  -72.059  51.491  1
307420  97.054  -72.064  51.463  1
307421  97.097  -72.071  51.432  1
307422  97.154  -72.087  51.401  1
307423  97.211  -72.103  51.369  1
307424  97.263  -72.117  51.341  1
307425  97.296  -72.117  51.316  1
307426  97.334  -72.130  51.292  1
307427  97.367  -72.132  51.268  1
307428  97.400  -72.134  51.245  1
307429  97.433  -72.136  51.220  1
307430  97.466  -72.138  51.195  1
307431  97.499  -72.140  51.169  1
307432  97.532  -72.142  51.144  1
307433  97.565  -72.144  51.115  1
307434  97.598  -72.146  51.083  1
307435  97.631  -72.149  51.047  1
307436  97.664  -72.150  51.006  1
307437  97.697  -72.152  50.963  1
307438  97.730  -72.155  50.918  1
307439  97.764  -72.156  50.870  1
307440  97.796  -72.158  50.819  1
307441  97.829  -72.161  50.767  1
307442  97.863  -72.162  50.715  1
307443  97.895  -72.164  50.665  1
307444  97.926  -72.168  50.614  1
307445  97.948  -72.175  50.563  1
307446  97.950  -72.197  50.511  1
307447  97.964  -72.216  50.456  1
307448  97.980  -72.234  50.402  1
307449  97.999  -72.249  50.348  1
307450  98.033  -72.265  50.294  1
307451  98.058  -72.270  50.241  1
307452  98.098  -72.275  50.189  1
307453  98.155  -72.285  50.136  1
307454  98.211  -72.295  50.085  1
307455  98.267  -72.305  50.034  1
307456  98.323  -72.315  49.985  1
307457  98.380  -72.325  49.933  1
307458  98.431  -72.334  49.881  1
307459  98.473  -72.344  49.829  1
307460  98.503  -72.356  49.776  1
307461  98.534  -72.367  49.722  1
307462  98.565  -72.379  49.670  1
307463  98.492  -72.414  49.619  1
307464  98.539  -72.430  49.568  1
307465  98.587  -72.446  49.520  1
307466  98.635  -72.463  49.469  1
307467  98.683  -72.479  49.418  1
307468  98.742  -72.488  49.369  1
307469  98.770  -72.493  49.321  1
307470  98.799  -72.511  49.272  1
307471  98.829  -72.528  49.223  1
307472  98.857  -72.545  49.174  1
307473  98.886  -72.562  49.126  1
307474  98.916  -72.579  49.078  1
307475  98.945  -72.596  49.029  1
307476  98.975  -72.610  48.981  1
307477  98.995  -72.623  48.931  1
307478  99.015  -72.635  48.881  1
307479  99.034  -72.647  48.831  1
307480  99.054  -72.660  48.781  1
307481  99.074  -72.672  48.732  1
307482  99.094  -72.684  48.683  1
307483  99.114  -72.696  48.635  1
307484  99.134  -72.709  48.587  1
307485  99.164  -72.727  48.537  1
307486  99.198  -72.747  48.487  1
307487  99.232  -72.767  48.438  1
307488  99.266  -72.788  48.388  1
307489  99.300  -72.807  48.340  1
307490  99.337  -72.821  48.291  1
307491  99.376  -72.829  48.244  1
307492  99.416  -72.836  48.197  1
307493  99.455  -72.844  48.151  1
307494  99.495  -72.851  48.105  1
307495  99.535  -72.859  48.059  1
307496  99.574  -72.866  48.013  1
307497  99.614  -72.873  47.967  1
307498  99.653  -72.881  47.922  1
307499  99.693  -72.888  47.878  1
307500  99.722  -72.912  47.834  1
307501  99.742  -72.948  47.790  1
307502  99.765  -72.980  47.744  1
307503  99.797  -73.001  47.699  1
307504  99.828  -73.021  47.654  1
307505  99.859  -73.042  47.609  1
307506  99.891  -73.063  47.565  1
307507  99.922  -73.083  47.520  1
307508  99.954  -73.104  47.475  1
307509  99.985  -73.124  47.430  1
307510  100.016  -73.136  47.384  1
307511  100.048  -73.126  47.339  1
307512  100.079  -73.122  47.294  1
307513  100.111  -73.126  47.250  1
307514  100.142  -73.130  47.205  1
307515  100.174  -73.134  47.161  1
307516  100.205  -73.138  47.116  1
307517  100.237  -73.142  47.071  1
307518  100.268  -73.146  47.026  1
307519  100.299  -73.150  46.982  1
307520  100.331  -73.154  46.940  1
307521  100.362  -73.158  46.897  1
307522  100.393  -73.162  46.854  1
307523  100.424  -73.166  46.812  1
307524  100.456  -73.170  46.771  1
307525  100.487  -73.174  46.732  1
307526  100.519  -73.178  46.695  1
307527  100.554  -73.191  46.661  1
307528  100.591  -73.207  46.629  1
307529  100.615  -73.186  46.597  1
307530  100.639  -73.164  46.565  1
307531  100.663  -73.143  46.534  1
307532  100.687  -73.123  46.504  1
307533  100.711  -73.101  46.474  1
307534  100.736  -73.080  46.444  1
307535  100.760  -73.059  46.411  1
307536  100.788  -73.045  46.377  1
307537  100.828  -73.045  46.342  1
307538  100.867  -73.063  46.306  1
307539  100.906  -73.079  46.272  1
307540  100.946  -73.097  46.237  1
307541  100.985  -73.114  46.201  1
307542  101.025  -73.131  46.167  1
307543  101.059  -73.139  46.133  1
307544  101.092  -73.144  46.098  1
307545  101.124  -73.148  46.064  1
307546  101.158  -73.153  46.031  1
307547  101.197  -73.158  45.998  1
307548  101.237  -73.163  45.965  1
307549  101.277  -73.168  45.931  1
307550  101.316  -73.176  45.897  1
307551  101.354  -73.186  45.862  1
307552  101.393  -73.197  45.829  1
307553  101.431  -73.208  45.794  1
307554  101.470  -73.218  45.760  1
307555  101.502  -73.238  45.725  1
307556  101.531  -73.264  45.689  1
307557  101.559  -73.291  45.651  1
307558  101.588  -73.318  45.614  1
307559  101.616  -73.345  45.577  1
307560  101.644  -73.372  45.539  1
307561  101.673  -73.399  45.501  1
307562  101.701  -73.426  45.464  1
307563  101.730  -73.450  45.426  1
307564  101.759  -73.475  45.388  1
307565  101.787  -73.499  45.351  1
307566  101.816  -73.524  45.314  1
307567  101.853  -73.540  45.277  1
307568  101.893  -73.554  45.240  1
307569  101.936  -73.564  45.206  1
307570  101.978  -73.574  45.171  1
307571  102.022  -73.583  45.137  1
307572  102.064  -73.593  45.106  1
307573  102.108  -73.602  45.074  1
307574  102.140  -73.607  45.043  1
307575  102.166  -73.608  45.012  1
307576  102.190  -73.608  44.981  1
307577  102.215  -73.609  44.951  1
307578  102.240  -73.609  44.921  1
308061  95.104  -71.687  52.500  1
308062  95.130  -71.701  52.479  1
308063  95.157  -71.716  52.460  1
308064  95.183  -71.730  52.440  1
308065  95.209  -71.744  52.420  1
308066  95.236  -71.759  52.400  1
308067  95.262  -71.773  52.380  1
308068  95.288  -71.788  52.361  1
308069  95.315  -71.802  52.343  1
308070  95.304  -71.826  52.325  1
308071  95.275  -71.854  52.306  1
308072  95.291  -71.917  52.288  1
308073  95.301  -71.958  52.269  1
308074  95.296  -71.964  52.250  1
308075  95.347  -71.963  52.232  1
308076  95.399  -71.960  52.214  1
308077  95.451  -71.956  52.197  1
308078  95.503  -71.953  52.180  1
308079  95.555  -71.950  52.163  1
308080  95.592  -71.947  52.147  1
308081  95.614  -71.944  52.131  1
308082  95.640  -71.955  52.114  1
308083  95.670  -71.976  52.099  1
308084  95.699  -71.998  52.084  1
308085  95.729  -72.020  52.070  1
308086  95.762  -72.034  52.058  1
308087  95.808  -72.042  52.047  1
308088  95.853  -72.052  52.038  1
308089  95.899  -72.061  52.028  1
308090  95.944  -72.070  52.019  1
308091  95.989  -72.079  52.011  1
308092  96.026  -72.058  52.002  1
308093  96.075  -72.042  51.994  1
308094  96.124  -72.025  51.985  1
308095  96.174  -72.008  51.973  1
308096  96.223  -71.992  51.960  1
308097  96.271  -71.975  51.948  1
308098  96.310  -71.967  51.936  1
308099  96.348  -71.959  51.923  1
308100  96.386  -71.951  51.910  1
308101  96.424  -71.944  51.895  1
308102  96.457  -71.939  51.878  1
308103  96.488  -71.936  51.859  1
308104  96.520  -71.933  51.841  1
308105  96.548  -71.948  51.821  1
308106  96.577  -71.963  51.799  1
308107  96.605  -71.979  51.776  1
308108  96.633  -71.994  51.750  1
308109  96.662  -72.009  51.723  1
308110  96.690  -72.024  51.697  1
308111  96.722  -72.037  51.672  1
308112  96.771  -72.034  51.650  1
308113  96.820  -72.031  51.633  1
308114  96.869  -72.028  51.616  1
308115  96.918  -72.025  51.600  1
308116  96.948  -72.022  51.585  1
308117  96.969  -72.017  51.568  1
308118  96.990  -72.014  51.549  1
308119  97.010  -72.009  51.529  1
308120  97.020  -72.018  51.505  1
308121  97.054  -72.026  51.475  1
308122  97.093  -72.030  51.443  1
308123  97.145  -72.043  51.409  1
308124  97.203  -72.059  51.376  1
308125  97.259  -72.075  51.344  1
308126  97.312  -72.090  51.314  1
308127  97.346  -72.092  51.288  1
308128  97.379  -72.094  51.263  1
308129  97.412  -72.096  51.238  1
308130  97.445  -72.098  51.212  1
308131  97.478  -72.100  51.184  1
308132  97.511  -72.102  51.158  1
308133  97.544  -72.104  51.132  1
308134  97.577  -72.105  51.103  1
308135  97.610  -72.108  51.071  1
308136  97.643  -72.110  51.037  1
308137  97.676  -72.111  50.998  1
308138  97.709  -72.114  50.956  1
308139  97.742  -72.115  50.912  1
308140  97.776  -72.117  50.866  1
308141  97.809  -72.119  50.814  1
308142  97.842  -72.121  50.762  1
308143  97.875  -72.123  50.709  1
308144  97.908  -72.125  50.657  1
308145  97.930  -72.138  50.607  1
308146  97.945  -72.155  50.558  1
308147  97.961  -72.174  50.506  1
308148  97.977  -72.192  50.452  1
308149  97.992  -72.210  50.396  1
308150  98.034  -72.202  50.341  1
308151  98.062  -72.238  50.288  1
308152  98.086  -72.244  50.235  1
308153  98.111  -72.245  50.185  1
308154  98.149  -72.250  50.133  1
308155  98.205  -72.260  50.082  1
308156  98.261  -72.270  50.032  1
308157  98.317  -72.280  49.982  1
308158  98.365  -72.289  49.930  1
308159  98.411  -72.296  49.877  1
308160  98.461  -72.305  49.825  1
308161  98.501  -72.315  49.776  1
308162  98.532  -72.326  49.726  1
308163  98.512  -72.348  49.676  1
308164  98.539  -72.368  49.626  1
308165  98.587  -72.384  49.576  1
308166  98.634  -72.400  49.526  1
308167  98.682  -72.417  49.475  1
308168  98.726  -72.434  49.424  1
308169  98.758  -72.450  49.375  1
308170  98.789  -72.468  49.327  1
308171  98.817  -72.484  49.279  1
308172  98.846  -72.500  49.230  1
308173  98.874  -72.517  49.182  1
308174  98.903  -72.533  49.133  1
308175  98.932  -72.550  49.084  1
308176  98.966  -72.569  49.035  1
308177  98.988  -72.587  48.985  1
308178  99.009  -72.605  48.935  1
308179  99.030  -72.621  48.884  1
308180  99.050  -72.633  48.834  1
308181  99.070  -72.646  48.784  1
308182  99.090  -72.658  48.734  1
308183  99.110  -72.670  48.685  1
308184  99.130  -72.682  48.637  1
308185  99.149  -72.694  48.588  1
308186  99.171  -72.708  48.537  1
308187  99.205  -72.728  48.488  1
308188  99.238  -72.748  48.438  1
308189  99.272  -72.768  48.388  1
308190  99.309  -72.782  48.339  1
308191  99.349  -72.789  48.291  1
308192  99.389  -72.797  48.244  1
308193  99.428  -72.804  48.197  1
308194  99.468  -72.811  48.151  1
308195  99.507  -72.819  48.106  1
308196  99.547  -72.826  48.060  1
308197  99.586  -72.834  48.014  1
308198  99.626  -72.841  47.969  1
308199  99.665  -72.849  47.923  1
308200  99.705  -72.856  47.878  1
308201  99.739  -72.872  47.834  1
308202  99.760  -72.908  47.790  1
308203  99.780  -72.944  47.745  1
308204  99.808  -72.970  47.700  1
308205  99.839  -72.990  47.655  1
308206  99.870  -73.011  47.609  1
308207  99.902  -73.031  47.566  1
308208  99.933  -73.052  47.522  1
308209  99.965  -73.073  47.477  1
308210  99.996  -73.093  47.432  1
308211  100.028  -73.098  47.386  1
308212  100.059  -73.089  47.341  1
308213  100.091  -73.079  47.297  1
308214  100.122  -73.076  47.253  1
308215  100.154  -73.081  47.209  1
308216  100.185  -73.085  47.165  1
308217  100.216  -73.089  47.120  1
308218  100.248  -73.092  47.075  1
308219  100.279  -73.097  47.031  1
308220  100.311  -73.101  46.988  1
308221  100.342  -73.105  46.945  1
308222  100.373  -73.108  46.902  1
308223  100.405  -73.113  46.860  1
308224  100.436  -73.117  46.817  1
308225  100.467  -73.120  46.776  1
308226  100.499  -73.125  46.737  1
308227  100.530  -73.129  46.699  1
308228  100.567  -73.147  46.665  1
308229  100.607  -73.170  46.632  1
308230  100.632  -73.152  46.600  1
308231  100.656  -73.132  46.568  1
308232  100.680  -73.111  46.536  1
308233  100.704  -73.089  46.505  1
308234  100.728  -73.068  46.474  1
308235  100.753  -73.048  46.443  1
308236  100.777  -73.026  46.410  1
308237  100.813  -73.022  46.375  1
308238  100.852  -73.022  46.340  1
308239  100.892  -73.022  46.304  1
308240  100.931  -73.029  46.270  1
308241  100.970  -73.047  46.234  1
308242  101.009  -73.064  46.200  1
308243  101.049  -73.080  46.165  1
308244  101.083  -73.088  46.130  1
308245  101.116  -73.092  46.096  1
308246  101.148  -73.098  46.063  1
308247  101.181  -73.102  46.030  1
308248  101.218  -73.107  45.997  1
308249  101.258  -73.112  45.964  1
308250  101.298  -73.117  45.930  1
308251  101.336  -73.126  45.896  1
308252  101.375  -73.137  45.862  1
308253  101.413  -73.148  45.828  1
308254  101.452  -73.158  45.794  1
308255  101.480  -73.184  45.760  1
308256  101.509  -73.211  45.724  1
308257  101.537  -73.238  45.688  1
308258  101.565  -73.265  45.650  1
308259  101.594  -73.292  45.613  1
308260  101.622  -73.319  45.575  1
308261  101.650  -73.346  45.537  1
308262  101.679  -73.372  45.499  1
308263  101.707  -73.399  45.461  1
308264  101.736  -73.424  45.423  1
308265  101.765  -73.448  45.385  1
308266  101.794  -73.472  45.347  1
308267  101.826  -73.494  45.309  1
308268  101.866  -73.507  45.272  1
308269  101.906  -73.520  45.236  1
308270  101.949  -73.530  45.202  1
308271  101.991  -73.540  45.167  1
308272  102.035  -73.549  45.133  1
308273  102.078  -73.559  45.101  1
308274  102.121  -73.568  45.069  1
308275  102.149  -73.570  45.037  1
308276  102.173  -73.571  45.007  1
308277  102.198  -73.571  44.977  1
308278  102.223  -73.572  44.946  1
308762  95.102  -71.642  52.496  1
308763  95.128  -71.657  52.475  1
308764  95.155  -71.671  52.456  1
308765  95.181  -71.685  52.437  1
308766  95.207  -71.699  52.417  1
308767  95.234  -71.713  52.398  1
308768  95.260  -71.728  52.378  1
308769  95.286  -71.742  52.360  1
308770  95.309  -71.757  52.342  1
308771  95.281  -71.786  52.324  1
308772  95.253  -71.814  52.306  1
308773  95.275  -71.881  52.288  1
308774  95.293  -71.916  52.270  1
308775  95.299  -71.917  52.251  1
308776  95.347  -71.926  52.233  1
308777  95.397  -71.928  52.216  1
308778  95.449  -71.925  52.199  1
308779  95.501  -71.922  52.183  1
308780  95.553  -71.919  52.166  1
308781  95.588  -71.916  52.150  1
308782  95.610  -71.913  52.135  1
308783  95.634  -71.914  52.119  1
308784  95.664  -71.936  52.104  1
308785  95.693  -71.958  52.089  1
308786  95.723  -71.980  52.076  1
308787  95.766  -71.986  52.064  1
308788  95.812  -71.995  52.053  1
308789  95.857  -72.004  52.044  1
308790  95.902  -72.013  52.035  1
308791  95.948  -72.022  52.027  1
308792  95.993  -72.031  52.020  1
308793  96.031  -72.019  52.012  1
308794  96.080  -72.002  52.005  1
308795  96.129  -71.986  51.998  1
308796  96.178  -71.969  51.988  1
308797  96.228  -71.951  51.977  1
308798  96.277  -71.935  51.965  1
308799  96.324  -71.920  51.953  1
308800  96.362  -71.912  51.940  1
308801  96.400  -71.904  51.925  1
308802  96.439  -71.897  51.910  1
308803  96.470  -71.893  51.893  1
308804  96.502  -71.889  51.876  1
308805  96.531  -71.901  51.859  1
308806  96.559  -71.917  51.840  1
308807  96.588  -71.932  51.818  1
308808  96.616  -71.947  51.794  1
308809  96.645  -71.962  51.766  1
308810  96.673  -71.977  51.737  1
308811  96.701  -71.992  51.708  1
308812  96.732  -72.007  51.681  1
308813  96.781  -72.004  51.658  1
308814  96.829  -72.001  51.640  1
308815  96.879  -71.998  51.623  1
308816  96.925  -71.995  51.605  1
308817  96.945  -71.991  51.590  1
308818  96.965  -71.986  51.576  1
308819  96.986  -71.983  51.561  1
308820  97.007  -71.978  51.543  1
308821  97.025  -71.976  51.520  1
308822  97.054  -71.987  51.489  1
308823  97.093  -71.992  51.454  1
308824  97.137  -71.999  51.419  1
308825  97.193  -72.015  51.384  1
308826  97.253  -72.034  51.349  1
308827  97.317  -72.057  51.317  1
308828  97.356  -72.065  51.288  1
308829  97.385  -72.067  51.258  1
308830  97.418  -72.070  51.231  1
308831  97.451  -72.071  51.203  1
308832  97.484  -72.073  51.176  1
308833  97.517  -72.075  51.149  1
308834  97.550  -72.077  51.123  1
308835  97.583  -72.079  51.094  1
308836  97.616  -72.081  51.063  1
308837  97.649  -72.083  51.030  1
308838  97.682  -72.085  50.993  1
308839  97.715  -72.087  50.952  1
308840  97.748  -72.089  50.908  1
308841  97.782  -72.091  50.863  1
308842  97.815  -72.092  50.810  1
308843  97.848  -72.095  50.758  1
308844  97.881  -72.096  50.706  1
308845  97.914  -72.099  50.654  1
308846  97.937  -72.114  50.602  1
308847  97.957  -72.132  50.552  1
308848  97.973  -72.150  50.502  1
308849  97.989  -72.168  50.450  1
308850  98.025  -72.165  50.397  1
308851  98.069  -72.158  50.343  1
308852  98.090  -72.211  50.291  1
308853  98.114  -72.219  50.241  1
308854  98.139  -72.220  50.193  1
308855  98.163  -72.221  50.142  1
308856  98.199  -72.224  50.089  1
308857  98.255  -72.235  50.035  1
308858  98.299  -72.243  49.983  1
308859  98.344  -72.251  49.931  1
308860  98.390  -72.258  49.880  1
308861  98.441  -72.267  49.831  1
308862  98.492  -72.274  49.783  1
308863  98.530  -72.285  49.733  1
308864  98.538  -72.305  49.683  1
308865  98.586  -72.321  49.633  1
308866  98.627  -72.338  49.582  1
308867  98.659  -72.356  49.532  1
308868  98.692  -72.373  49.481  1
308869  98.724  -72.390  49.430  1
308870  98.757  -72.407  49.381  1
308871  98.789  -72.424  49.333  1
308872  98.819  -72.441  49.284  1
308873  98.848  -72.458  49.236  1
308874  98.877  -72.475  49.187  1
308875  98.912  -72.493  49.138  1
308876  98.945  -72.513  49.088  1
308877  98.977  -72.532  49.039  1
308878  98.998  -72.550  48.988  1
308879  99.019  -72.568  48.937  1
308880  99.040  -72.586  48.887  1
308881  99.062  -72.603  48.837  1
308882  99.083  -72.622  48.786  1
308883  99.104  -72.639  48.737  1
308884  99.125  -72.656  48.687  1
308885  99.145  -72.669  48.638  1
308886  99.165  -72.681  48.589  1
308887  99.185  -72.693  48.538  1
308888  99.211  -72.709  48.489  1
308889  99.244  -72.728  48.439  1
308890  99.282  -72.741  48.389  1
308891  99.322  -72.749  48.340  1
308892  99.361  -72.757  48.292  1
308893  99.401  -72.764  48.244  1
308894  99.440  -72.772  48.198  1
308895  99.480  -72.779  48.152  1
308896  99.519  -72.786  48.106  1
308897  99.559  -72.794  48.060  1
308898  99.598  -72.801  48.015  1
308899  99.638  -72.809  47.970  1
308900  99.678  -72.816  47.924  1
308901  99.717  -72.824  47.879  1
308902  99.757  -72.832  47.835  1
308903  99.777  -72.868  47.790  1
308904  99.798  -72.904  47.745  1
308905  99.819  -72.938  47.701  1
308906  99.850  -72.959  47.655  1
308907  99.881  -72.979  47.610  1
308908  99.913  -73.000  47.567  1
308909  99.944  -73.020  47.523  1
308910  99.976  -73.042  47.479  1
308911  100.007  -73.062  47.434  1
308912  100.039  -73.060  47.388  1
308913  100.070  -73.051  47.343  1
308914  100.102  -73.042  47.300  1
308915  100.134  -73.032  47.256  1
308916  100.165  -73.032  47.213  1
308917  100.197  -73.036  47.169  1
308918  100.228  -73.039  47.124  1
308919  100.259  -73.043  47.080  1
308920  100.290  -73.048  47.036  1
308921  100.322  -73.051  46.993  1
308922  100.353  -73.055  46.950  1
308923  100.385  -73.059  46.908  1
308924  100.416  -73.064  46.866  1
308925  100.447  -73.067  46.824  1
308926  100.479  -73.071  46.782  1
308927  100.510  -73.075  46.743  1
308928  100.542  -73.079  46.705  1
308929  100.581  -73.102  46.670  1
308930  100.620  -73.125  46.636  1
308931  100.649  -73.120  46.603  1
308932  100.674  -73.098  46.572  1
308933  100.698  -73.077  46.540  1
308934  100.722  -73.057  46.509  1
308935  100.746  -73.036  46.477  1
308936  100.770  -73.014  46.443  1
308937  100.798  -72.999  46.410  1
308938  100.838  -72.999  46.373  1
308939  100.876  -72.999  46.337  1
308940  100.916  -72.999  46.302  1
308941  100.955  -72.999  46.267  1
308942  100.994  -72.999  46.232  1
308943  101.034  -73.014  46.198  1
308944  101.073  -73.030  46.164  1
308945  101.107  -73.037  46.128  1
308946  101.139  -73.042  46.094  1
308947  101.172  -73.046  46.061  1
308948  101.205  -73.051  46.029  1
308949  101.239  -73.056  45.997  1
308950  101.279  -73.061  45.963  1
308951  101.318  -73.067  45.929  1
308952  101.356  -73.077  45.895  1
308953  101.395  -73.088  45.861  1
308954  101.430  -73.105  45.827  1
308955  101.458  -73.131  45.793  1
308956  101.486  -73.158  45.758  1
308957  101.515  -73.185  45.722  1
308958  101.543  -73.212  45.686  1
308959  101.571  -73.239  45.649  1
308960  101.600  -73.265  45.611  1
308961  101.628  -73.293  45.573  1
308962  101.656  -73.319  45.535  1
308963  101.685  -73.346  45.496  1
308964  101.713  -73.372  45.459  1
308965  101.743  -73.396  45.421  1
308966  101.771  -73.421  45.382  1
308967  101.800  -73.445  45.344  1
308968  101.838  -73.460  45.306  1
308969  101.878  -73.474  45.269  1
308970  101.918  -73.487  45.233  1
308971  101.962  -73.496  45.198  1
308972  102.004  -73.506  45.163  1
308973  102.048  -73.515  45.129  1
308974  102.091  -73.524  45.097  1
308975  102.131  -73.533  45.065  1
308976  102.157  -73.534  45.033  1
308977  102.181  -73.534  45.002  1
308978  102.206  -73.535  44.973  1
308979  102.231  -73.536  44.942  1
309463  95.100  -71.597  52.491  1
309464  95.126  -71.611  52.472  1
309465  95.153  -71.625  52.453  1
309466  95.179  -71.640  52.434  1
309467  95.205  -71.654  52.414  1
309468  95.232  -71.669  52.395  1
309469  95.258  -71.683  52.377  1
309470  95.284  -71.697  52.358  1
309471  95.287  -71.718  52.340  1
309472  95.259  -71.746  52.323  1
309473  95.231  -71.774  52.306  1
309474  95.258  -71.845  52.289  1
309475  95.289  -71.869  52.271  1
309476  95.301  -71.871  52.252  1
309477  95.349  -71.880  52.234  1
309478  95.397  -71.890  52.217  1
309479  95.447  -71.894  52.201  1
309480  95.499  -71.891  52.186  1
309481  95.551  -71.888  52.170  1
309482  95.585  -71.885  52.154  1
309483  95.607  -71.882  52.138  1
309484  95.629  -71.879  52.124  1
309485  95.658  -71.895  52.109  1
309486  95.687  -71.917  52.094  1
309487  95.725  -71.929  52.081  1
309488  95.770  -71.939  52.070  1
309489  95.815  -71.948  52.060  1
309490  95.861  -71.957  52.051  1
309491  95.906  -71.965  52.043  1
309492  95.952  -71.974  52.036  1
309493  95.997  -71.983  52.029  1
309494  96.038  -71.982  52.023  1
309495  96.085  -71.963  52.018  1
309496  96.134  -71.946  52.013  1
309497  96.183  -71.929  52.004  1
309498  96.233  -71.912  51.994  1
309499  96.282  -71.895  51.983  1
309500  96.331  -71.879  51.971  1
309501  96.377  -71.865  51.957  1
309502  96.414  -71.857  51.942  1
309503  96.452  -71.850  51.925  1
309504  96.483  -71.846  51.908  1
309505  96.513  -71.854  51.890  1
309506  96.542  -71.870  51.874  1
309507  96.570  -71.885  51.855  1
309508  96.599  -71.900  51.835  1
309509  96.627  -71.916  51.810  1
309510  96.656  -71.931  51.781  1
309511  96.684  -71.946  51.750  1
309512  96.713  -71.961  51.719  1
309513  96.741  -71.976  51.691  1
309514  96.790  -71.973  51.667  1
309515  96.839  -71.970  51.647  1
309516  96.888  -71.967  51.628  1
309517  96.921  -71.964  51.609  1
309518  96.942  -71.960  51.594  1
309519  96.962  -71.955  51.581  1
309520  96.982  -71.951  51.569  1
309521  97.003  -71.947  51.554  1
309522  97.023  -71.943  51.530  1
309523  97.054  -71.948  51.499  1
309524  97.093  -71.953  51.464  1
309525  97.132  -71.958  51.428  1
309526  97.187  -71.973  51.392  1
309527  97.251  -71.997  51.356  1
309528  97.314  -72.020  51.322  1
309529  97.372  -72.039  51.290  1
309530  97.399  -72.041  51.258  1
309531  97.427  -72.043  51.228  1
309532  97.457  -72.045  51.199  1
309533  97.490  -72.047  51.171  1
309534  97.523  -72.048  51.144  1
309535  97.556  -72.051  51.117  1
309536  97.589  -72.052  51.087  1
309537  97.622  -72.055  51.055  1
309538  97.655  -72.057  51.022  1
309539  97.688  -72.058  50.986  1
309540  97.721  -72.061  50.946  1
309541  97.754  -72.062  50.903  1
309542  97.788  -72.064  50.857  1
309543  97.821  -72.066  50.806  1
309544  97.854  -72.068  50.754  1
309545  97.887  -72.070  50.702  1
309546  97.917  -72.076  50.649  1
309547  97.940  -72.092  50.597  1
309548  97.963  -72.109  50.547  1
309549  97.985  -72.127  50.497  1
309550  98.016  -72.129  50.447  1
309551  98.061  -72.117  50.396  1
309552  98.095  -72.130  50.345  1
309553  98.109  -72.180  50.296  1
309554  98.132  -72.190  50.249  1
309555  98.156  -72.191  50.201  1
309556  98.180  -72.192  50.150  1
309557  98.206  -72.194  50.096  1
309558  98.234  -72.197  50.041  1
309559  98.278  -72.205  49.988  1
309560  98.322  -72.213  49.935  1
309561  98.370  -72.221  49.885  1
309562  98.421  -72.229  49.837  1
309563  98.472  -72.236  49.790  1
309564  98.528  -72.248  49.740  1
309565  98.564  -72.262  49.690  1
309566  98.596  -72.279  49.639  1
309567  98.629  -72.296  49.587  1
309568  98.661  -72.314  49.537  1
309569  98.694  -72.331  49.486  1
309570  98.726  -72.348  49.435  1
309571  98.759  -72.365  49.385  1
309572  98.791  -72.383  49.337  1
309573  98.824  -72.399  49.288  1
309574  98.858  -72.419  49.240  1
309575  98.891  -72.438  49.191  1
309576  98.925  -72.457  49.142  1
309577  98.959  -72.477  49.091  1
309578  98.986  -72.495  49.041  1
309579  99.007  -72.513  48.990  1
309580  99.029  -72.531  48.939  1
309581  99.050  -72.549  48.889  1
309582  99.071  -72.567  48.838  1
309583  99.092  -72.584  48.788  1
309584  99.114  -72.603  48.738  1
309585  99.135  -72.620  48.689  1
309586  99.156  -72.638  48.639  1
309587  99.178  -72.656  48.589  1
309588  99.199  -72.674  48.539  1
309589  99.220  -72.691  48.490  1
309590  99.255  -72.702  48.440  1
309591  99.294  -72.710  48.390  1
309592  99.334  -72.717  48.342  1
309593  99.373  -72.724  48.293  1
309594  99.413  -72.732  48.245  1
309595  99.452  -72.739  48.198  1
309596  99.492  -72.747  48.152  1
309597  99.532  -72.754  48.107  1
309598  99.571  -72.762  48.061  1
309599  99.611  -72.769  48.015  1
309600  99.650  -72.776  47.970  1
309601  99.690  -72.784  47.925  1
309602  99.730  -72.791  47.881  1
309603  99.769  -72.799  47.836  1
309604  99.795  -72.828  47.790  1
309605  99.815  -72.863  47.745  1
309606  99.836  -72.899  47.701  1
309607  99.861  -72.928  47.656  1
309608  99.893  -72.948  47.611  1
309609  99.924  -72.969  47.567  1
309610  99.956  -72.989  47.523  1
309611  99.987  -73.010  47.480  1
309612  100.018  -73.030  47.435  1
309613  100.050  -73.023  47.389  1
309614  100.082  -73.014  47.345  1
309615  100.113  -73.004  47.302  1
309616  100.145  -72.995  47.258  1
309617  100.177  -72.985  47.216  1
309618  100.208  -72.986  47.172  1
309619  100.240  -72.990  47.129  1
309620  100.271  -72.994  47.085  1
309621  100.302  -72.998  47.041  1
309622  100.333  -73.002  46.998  1
309623  100.365  -73.006  46.956  1
309624  100.396  -73.010  46.914  1
309625  100.427  -73.014  46.871  1
309626  100.459  -73.018  46.830  1
309627  100.490  -73.022  46.789  1
309628  100.522  -73.026  46.750  1
309629  100.555  -73.035  46.712  1
309630  100.594  -73.058  46.677  1
309631  100.633  -73.081  46.643  1
309632  100.667  -73.086  46.610  1
309633  100.691  -73.066  46.577  1
309634  100.715  -73.045  46.545  1
309635  100.739  -73.023  46.512  1
309636  100.763  -73.002  46.478  1
309637  100.787  -72.982  46.443  1
309638  100.823  -72.976  46.408  1
309639  100.862  -72.976  46.371  1
309640  100.901  -72.976  46.335  1
309641  100.940  -72.976  46.300  1
309642  100.980  -72.976  46.264  1
309643  101.019  -72.976  46.230  1
309644  101.058  -72.976  46.196  1
309645  101.098  -72.980  46.162  1
309646  101.131  -72.985  46.126  1
309647  101.164  -72.991  46.092  1
309648  101.196  -72.995  46.060  1
309649  101.229  -73.000  46.028  1
309650  101.262  -73.005  45.995  1
309651  101.299  -73.010  45.962  1
309652  101.338  -73.017  45.928  1
309653  101.377  -73.028  45.894  1
309654  101.407  -73.051  45.860  1
309655  101.436  -73.078  45.827  1
309656  101.464  -73.105  45.792  1
309657  101.493  -73.132  45.756  1
309658  101.521  -73.158  45.721  1
309659  101.549  -73.186  45.684  1
309660  101.578  -73.212  45.646  1
309661  101.606  -73.239  45.609  1
309662  101.634  -73.266  45.571  1
309663  101.663  -73.293  45.533  1
309664  101.691  -73.320  45.494  1
309665  101.720  -73.345  45.456  1
309666  101.749  -73.369  45.418  1
309667  101.777  -73.394  45.379  1
309668  101.811  -73.414  45.341  1
309669  101.851  -73.427  45.303  1
309670  101.891  -73.440  45.266  1
309671  101.932  -73.452  45.230  1
309672  101.975  -73.462  45.194  1
309673  102.018  -73.471  45.160  1
309674  102.061  -73.481  45.126  1
309675  102.104  -73.490  45.093  1
309676  102.139  -73.496  45.060  1
309677  102.164  -73.497  45.029  1
309678  102.189  -73.498  44.998  1
309679  102.214  -73.498  44.968  1
310164  95.098  -71.552  52.488  1
310165  95.124  -71.566  52.469  1
310166  95.151  -71.581  52.450  1
310167  95.177  -71.595  52.431  1
310168  95.203  -71.609  52.412  1
310169  95.230  -71.623  52.393  1
310170  95.256  -71.638  52.375  1
310171  95.283  -71.652  52.357  1
310172  95.265  -71.678  52.339  1
310173  95.237  -71.707  52.322  1
310174  95.209  -71.735  52.306  1
310175  95.238  -71.795  52.289  1
310176  95.285  -71.821  52.271  1
310177  95.304  -71.825  52.254  1
310178  95.352  -71.834  52.237  1
310179  95.400  -71.844  52.221  1
310180  95.448  -71.853  52.205  1
310181  95.497  -71.860  52.190  1
310182  95.549  -71.857  52.175  1
310183  95.582  -71.854  52.160  1
310184  95.604  -71.851  52.144  1
310185  95.626  -71.848  52.128  1
310186  95.652  -71.854  52.114  1
310187  95.683  -71.873  52.101  1
310188  95.728  -71.882  52.088  1
310189  95.773  -71.891  52.077  1
310190  95.819  -71.900  52.068  1
310191  95.865  -71.909  52.059  1
310192  95.910  -71.918  52.051  1
310193  95.955  -71.926  52.046  1
310194  96.001  -71.936  52.040  1
310195  96.046  -71.945  52.036  1
310196  96.090  -71.923  52.033  1
310197  96.139  -71.907  52.029  1
310198  96.188  -71.889  52.022  1
310199  96.238  -71.873  52.013  1
310200  96.287  -71.856  52.003  1
310201  96.336  -71.839  51.991  1
310202  96.385  -71.823  51.975  1
310203  96.429  -71.810  51.959  1
310204  96.466  -71.803  51.942  1
310205  96.496  -71.807  51.922  1
310206  96.524  -71.823  51.902  1
310207  96.553  -71.838  51.885  1
310208  96.581  -71.854  51.867  1
310209  96.610  -71.869  51.847  1
310210  96.638  -71.884  51.824  1
310211  96.667  -71.899  51.794  1
310212  96.695  -71.914  51.763  1
310213  96.724  -71.929  51.730  1
310214  96.752  -71.945  51.702  1
310215  96.800  -71.943  51.677  1
310216  96.849  -71.940  51.654  1
310217  96.897  -71.937  51.633  1
310218  96.918  -71.932  51.612  1
310219  96.938  -71.929  51.597  1
310220  96.958  -71.925  51.584  1
310221  96.979  -71.920  51.572  1
310222  97.000  -71.917  51.559  1
310223  97.028  -71.914  51.536  1
310224  97.069  -71.920  51.507  1
310225  97.109  -71.926  51.473  1
310226  97.149  -71.932  51.436  1
310227  97.185  -71.936  51.400  1
310228  97.248  -71.960  51.364  1
310229  97.312  -71.983  51.329  1
310230  97.375  -72.005  51.295  1
310231  97.415  -72.014  51.261  1
310232  97.442  -72.017  51.229  1
310233  97.470  -72.018  51.199  1
310234  97.497  -72.020  51.169  1
310235  97.529  -72.022  51.141  1
310236  97.562  -72.024  51.112  1
310237  97.595  -72.026  51.081  1
310238  97.628  -72.028  51.047  1
310239  97.661  -72.030  51.013  1
310240  97.695  -72.032  50.977  1
310241  97.727  -72.034  50.938  1
310242  97.760  -72.036  50.896  1
310243  97.794  -72.038  50.851  1
310244  97.827  -72.039  50.802  1
310245  97.860  -72.042  50.750  1
310246  97.893  -72.043  50.697  1
310247  97.920  -72.054  50.644  1
310248  97.943  -72.070  50.592  1
310249  97.966  -72.087  50.541  1
310250  97.990  -72.101  50.491  1
310251  98.016  -72.108  50.443  1
310252  98.056  -72.101  50.394  1
310253  98.096  -72.094  50.348  1
310254  98.109  -72.144  50.303  1
310255  98.132  -72.155  50.258  1
310256  98.156  -72.156  50.210  1
310257  98.180  -72.157  50.158  1
310258  98.218  -72.173  50.103  1
310259  98.248  -72.178  50.048  1
310260  98.270  -72.174  49.996  1
310261  98.301  -72.175  49.944  1
310262  98.350  -72.183  49.893  1
310263  98.422  -72.202  49.844  1
310264  98.494  -72.221  49.795  1
310265  98.530  -72.223  49.745  1
310266  98.569  -72.227  49.694  1
310267  98.610  -72.243  49.642  1
310268  98.643  -72.261  49.591  1
310269  98.675  -72.277  49.539  1
310270  98.708  -72.295  49.489  1
310271  98.740  -72.312  49.438  1
310272  98.773  -72.330  49.388  1
310273  98.805  -72.346  49.338  1
310274  98.838  -72.364  49.290  1
310275  98.871  -72.383  49.241  1
310276  98.905  -72.402  49.193  1
310277  98.939  -72.421  49.143  1
310278  98.973  -72.440  49.093  1
310279  98.996  -72.459  49.042  1
310280  99.017  -72.476  48.991  1
310281  99.039  -72.494  48.940  1
310282  99.060  -72.512  48.888  1
310283  99.081  -72.530  48.838  1
310284  99.102  -72.548  48.789  1
310285  99.124  -72.565  48.738  1
310286  99.145  -72.584  48.689  1
310287  99.166  -72.601  48.639  1
310288  99.188  -72.619  48.590  1
310289  99.209  -72.637  48.540  1
310290  99.231  -72.653  48.491  1
310291  99.273  -72.666  48.441  1
310292  99.306  -72.677  48.391  1
310293  99.346  -72.685  48.343  1
310294  99.385  -72.692  48.295  1
310295  99.425  -72.700  48.247  1
310296  99.465  -72.707  48.200  1
310297  99.504  -72.714  48.154  1
310298  99.544  -72.722  48.109  1
310299  99.583  -72.729  48.063  1
310300  99.623  -72.737  48.017  1
310301  99.663  -72.744  47.971  1
310302  99.702  -72.752  47.926  1
310303  99.742  -72.759  47.882  1
310304  99.782  -72.766  47.837  1
310305  99.812  -72.788  47.792  1
310306  99.833  -72.823  47.747  1
310307  99.853  -72.859  47.703  1
310308  99.873  -72.895  47.658  1
310309  99.904  -72.917  47.613  1
310310  99.935  -72.938  47.569  1
310311  99.967  -72.958  47.526  1
310312  99.998  -72.979  47.482  1
310313  100.030  -72.994  47.437  1
310314  100.061  -72.985  47.393  1
310315  100.093  -72.976  47.348  1
310316  100.125  -72.967  47.305  1
310317  100.156  -72.957  47.262  1
310318  100.188  -72.948  47.220  1
310319  100.219  -72.939  47.177  1
310320  100.251  -72.941  47.134  1
310321  100.282  -72.945  47.091  1
310322  100.314  -72.948  47.047  1
310323  100.345  -72.953  47.005  1
310324  100.376  -72.957  46.963  1
310325  100.408  -72.960  46.922  1
310326  100.439  -72.964  46.879  1
310327  100.470  -72.969  46.838  1
310328  100.501  -72.973  46.797  1
310329  100.533  -72.976  46.758  1
310330  100.568  -72.991  46.720  1
310331  100.608  -73.014  46.684  1
310332  100.647  -73.036  46.650  1
310333  100.684  -73.054  46.617  1
310334  100.708  -73.032  46.584  1
310335  100.733  -73.011  46.549  1
310336  100.757  -72.991  46.515  1
310337  100.781  -72.970  46.480  1
310338  100.808  -72.953  46.444  1
310339  100.847  -72.953  46.408  1
310340  100.887  -72.953  46.370  1
310341  100.926  -72.953  46.334  1
310342  100.965  -72.953  46.298  1
310343  101.004  -72.953  46.263  1
310344  101.044  -72.953  46.228  1
310345  101.080  -72.957  46.194  1
310346  101.109  -72.973  46.160  1
310347  101.144  -72.969  46.126  1
310348  101.181  -72.960  46.091  1
310349  101.218  -72.951  46.059  1
310350  101.253  -72.949  46.027  1
310351  101.285  -72.954  45.994  1
310352  101.320  -72.959  45.961  1
310353  101.357  -72.971  45.927  1
310354  101.385  -72.998  45.893  1
310355  101.414  -73.025  45.859  1
310356  101.442  -73.051  45.826  1
310357  101.470  -73.079  45.790  1
310358  101.499  -73.105  45.755  1
310359  101.527  -73.133  45.720  1
310360  101.555  -73.159  45.682  1
310361  101.584  -73.186  45.644  1
310362  101.612  -73.213  45.606  1
310363  101.641  -73.239  45.569  1
310364  101.669  -73.267  45.531  1
310365  101.697  -73.293  45.493  1
310366  101.726  -73.318  45.454  1
310367  101.755  -73.343  45.414  1
310368  101.784  -73.367  45.376  1
310369  101.824  -73.380  45.337  1
310370  101.864  -73.393  45.300  1
310371  101.904  -73.406  45.263  1
310372  101.945  -73.418  45.226  1
310373  101.988  -73.427  45.191  1
310374  102.031  -73.437  45.156  1
310375  102.074  -73.447  45.123  1
310376  102.117  -73.456  45.089  1
310377  102.147  -73.460  45.057  1
310378  102.172  -73.460  45.026  1
310379  102.197  -73.461  44.995  1
310865  95.096  -71.506  52.485  1
310866  95.123  -71.521  52.466  1
310867  95.149  -71.535  52.448  1
310868  95.175  -71.550  52.429  1
310869  95.202  -71.564  52.410  1
310870  95.228  -71.578  52.391  1
310871  95.255  -71.593  52.373  1
310872  95.270  -71.610  52.356  1
310873  95.242  -71.638  52.339  1
310874  95.214  -71.666  52.322  1
310875  95.186  -71.694  52.306  1
310876  95.217  -71.739  52.290  1
310877  95.265  -71.766  52.273  1
310878  95.306  -71.779  52.256  1
310879  95.354  -71.788  52.240  1
310880  95.403  -71.798  52.225  1
310881  95.451  -71.807  52.209  1
310882  95.499  -71.817  52.194  1
310883  95.548  -71.826  52.180  1
310884  95.579  -71.823  52.166  1
310885  95.601  -71.820  52.150  1
310886  95.623  -71.817  52.135  1
310887  95.645  -71.814  52.121  1
310888  95.687  -71.826  52.108  1
310889  95.732  -71.835  52.095  1
310890  95.777  -71.843  52.085  1
310891  95.823  -71.852  52.076  1
310892  95.868  -71.861  52.068  1
310893  95.914  -71.870  52.061  1
310894  95.959  -71.879  52.057  1
310895  96.005  -71.888  52.053  1
310896  96.050  -71.897  52.051  1
310897  96.095  -71.884  52.048  1
310898  96.144  -71.867  52.046  1
310899  96.193  -71.850  52.039  1
310900  96.242  -71.833  52.032  1
310901  96.292  -71.817  52.022  1
310902  96.341  -71.800  52.011  1
310903  96.390  -71.783  51.996  1
310904  96.439  -71.766  51.980  1
310905  96.478  -71.761  51.962  1
310906  96.507  -71.776  51.940  1
310907  96.535  -71.791  51.918  1
310908  96.564  -71.807  51.898  1
310909  96.592  -71.822  51.877  1
310910  96.620  -71.837  51.855  1
310911  96.649  -71.852  51.832  1
310912  96.678  -71.868  51.804  1
310913  96.706  -71.883  51.774  1
310914  96.735  -71.898  51.744  1
310915  96.763  -71.914  51.715  1
310916  96.810  -71.913  51.688  1
310917  96.859  -71.910  51.664  1
310918  96.893  -71.906  51.641  1
310919  96.914  -71.902  51.619  1
310920  96.935  -71.898  51.600  1
310921  96.955  -71.894  51.583  1
310922  96.975  -71.889  51.568  1
310923  97.013  -71.890  51.553  1
310924  97.052  -71.892  51.532  1
310925  97.094  -71.898  51.505  1
310926  97.135  -71.904  51.473  1
310927  97.170  -71.909  51.440  1
310928  97.205  -71.914  51.406  1
310929  97.246  -71.923  51.373  1
310930  97.310  -71.945  51.339  1
310931  97.373  -71.968  51.303  1
310932  97.431  -71.988  51.266  1
310933  97.458  -71.990  51.232  1
310934  97.486  -71.992  51.202  1
310935  97.513  -71.994  51.173  1
310936  97.540  -71.995  51.144  1
310937  97.568  -71.998  51.115  1
310938  97.601  -71.999  51.081  1
310939  97.634  -72.001  51.044  1
310940  97.667  -72.004  51.006  1
310941  97.701  -72.005  50.968  1
310942  97.733  -72.008  50.928  1
310943  97.767  -72.009  50.887  1
310944  97.800  -72.011  50.843  1
310945  97.832  -72.013  50.794  1
310946  97.866  -72.015  50.745  1
310947  97.899  -72.017  50.694  1
310948  97.923  -72.032  50.643  1
310949  97.946  -72.048  50.590  1
310950  97.969  -72.064  50.542  1
310951  97.995  -72.072  50.495  1
310952  98.020  -72.080  50.449  1
310953  98.045  -72.089  50.404  1
310954  98.085  -72.081  50.359  1
310955  98.110  -72.108  50.314  1
310956  98.131  -72.121  50.269  1
310957  98.155  -72.122  50.220  1
310958  98.191  -72.135  50.167  1
310959  98.230  -72.152  50.112  1
310960  98.263  -72.160  50.056  1
310961  98.285  -72.155  50.002  1
310962  98.308  -72.152  49.949  1
310963  98.386  -72.174  49.898  1
310964  98.458  -72.193  49.849  1
310965  98.496  -72.196  49.799  1
310966  98.532  -72.198  49.749  1
310967  98.570  -72.200  49.698  1
310968  98.611  -72.210  49.645  1
310969  98.655  -72.225  49.593  1
310970  98.690  -72.242  49.542  1
310971  98.722  -72.259  49.490  1
310972  98.755  -72.277  49.440  1
310973  98.787  -72.293  49.389  1
310974  98.819  -72.311  49.339  1
310975  98.852  -72.328  49.290  1
310976  98.885  -72.346  49.241  1
310977  98.919  -72.365  49.192  1
310978  98.953  -72.385  49.143  1
310979  98.984  -72.404  49.093  1
310980  99.006  -72.421  49.042  1
310981  99.027  -72.440  48.991  1
310982  99.048  -72.457  48.941  1
310983  99.069  -72.475  48.889  1
310984  99.091  -72.493  48.839  1
310985  99.112  -72.511  48.789  1
310986  99.133  -72.529  48.738  1
310987  99.155  -72.547  48.689  1
310988  99.177  -72.564  48.639  1
310989  99.199  -72.581  48.590  1
310990  99.221  -72.597  48.540  1
310991  99.243  -72.614  48.491  1
310992  99.287  -72.626  48.441  1
310993  99.334  -72.638  48.392  1
310994  99.364  -72.650  48.344  1
310995  99.398  -72.660  48.296  1
310996  99.437  -72.667  48.248  1
310997  99.477  -72.675  48.202  1
310998  99.516  -72.682  48.157  1
310999  99.556  -72.689  48.111  1
311000  99.596  -72.697  48.064  1
311001  99.635  -72.704  48.018  1
311002  99.675  -72.712  47.972  1
311003  99.715  -72.719  47.927  1
311004  99.754  -72.727  47.883  1
311005  99.794  -72.735  47.839  1
311006  99.830  -72.747  47.794  1
311007  99.850  -72.783  47.749  1
311008  99.871  -72.819  47.705  1
311009  99.891  -72.855  47.660  1
311010  99.915  -72.885  47.614  1
311011  99.946  -72.907  47.572  1
311012  99.978  -72.927  47.528  1
311013  100.009  -72.948  47.484  1
311014  100.041  -72.956  47.440  1
311015  100.072  -72.947  47.396  1
311016  100.104  -72.938  47.352  1
311017  100.136  -72.929  47.309  1
311018  100.168  -72.920  47.267  1
311019  100.199  -72.910  47.225  1
311020  100.230  -72.901  47.183  1
311021  100.262  -72.892  47.140  1
311022  100.293  -72.895  47.097  1
311023  100.325  -72.899  47.055  1
311024  100.356  -72.903  47.013  1
311025  100.388  -72.907  46.972  1
311026  100.419  -72.911  46.930  1
311027  100.451  -72.915  46.889  1
311028  100.482  -72.920  46.847  1
311029  100.513  -72.923  46.806  1
311030  100.544  -72.927  46.767  1
311031  100.582  -72.946  46.729  1
311032  100.621  -72.970  46.693  1
311033  100.661  -72.992  46.659  1
311034  100.700  -73.015  46.625  1
311035  100.725  -72.999  46.591  1
311036  100.750  -72.979  46.554  1
311037  100.774  -72.957  46.518  1
311038  100.798  -72.936  46.481  1
311039  100.833  -72.930  46.444  1
311040  100.872  -72.930  46.408  1
311041  100.911  -72.930  46.370  1
311042  100.951  -72.930  46.334  1
311043  100.990  -72.930  46.298  1
311044  101.029  -72.930  46.262  1
311045  101.060  -72.942  46.228  1
311046  101.089  -72.957  46.194  1
311047  101.117  -72.973  46.160  1
311048  101.150  -72.975  46.126  1
311049  101.187  -72.967  46.092  1
311050  101.224  -72.957  46.059  1
311051  101.261  -72.949  46.027  1
311052  101.298  -72.940  45.993  1
311053  101.339  -72.927  45.961  1
311054  101.363  -72.945  45.927  1
311055  101.392  -72.972  45.893  1
311056  101.420  -72.998  45.859  1
311057  101.448  -73.026  45.825  1
311058  101.477  -73.052  45.790  1
311059  101.505  -73.079  45.754  1
311060  101.533  -73.106  45.718  1
311061  101.562  -73.133  45.681  1
311062  101.590  -73.160  45.644  1
311063  101.618  -73.186  45.606  1
311064  101.647  -73.214  45.568  1
311065  101.675  -73.240  45.530  1
311066  101.704  -73.266  45.491  1
311067  101.733  -73.291  45.452  1
311068  101.761  -73.315  45.412  1
311069  101.796  -73.333  45.373  1
311070  101.836  -73.346  45.335  1
311071  101.877  -73.360  45.298  1
311072  101.916  -73.373  45.261  1
311073  101.958  -73.384  45.225  1
311074  102.001  -73.394  45.189  1
311075  102.044  -73.403  45.154  1
311076  102.087  -73.413  45.120  1
311077  102.130  -73.422  45.087  1
311078  102.155  -73.423  45.055  1
311079  102.180  -73.424  45.024  1
311566  95.094  -71.462  52.482  1
311567  95.121  -71.476  52.463  1
311568  95.147  -71.491  52.445  1
311569  95.174  -71.505  52.427  1
311570  95.200  -71.519  52.408  1
311571  95.226  -71.533  52.390  1
311572  95.253  -71.547  52.372  1
311573  95.248  -71.570  52.355  1
311574  95.220  -71.598  52.338  1
311575  95.192  -71.626  52.323  1
311576  95.164  -71.655  52.307  1
311577  95.200  -71.682  52.291  1
311578  95.252  -71.705  52.276  1
311579  95.305  -71.726  52.260  1
311580  95.352  -71.735  52.244  1
311581  95.401  -71.745  52.229  1
311582  95.449  -71.754  52.214  1
311583  95.497  -71.764  52.200  1
311584  95.546  -71.773  52.186  1
311585  95.584  -71.783  52.172  1
311586  95.606  -71.782  52.157  1
311587  95.629  -71.779  52.143  1
311588  95.651  -71.776  52.128  1
311589  95.685  -71.779  52.115  1
311590  95.731  -71.787  52.104  1
311591  95.778  -71.796  52.093  1
311592  95.824  -71.805  52.085  1
311593  95.871  -71.813  52.078  1
311594  95.917  -71.823  52.072  1
311595  95.963  -71.832  52.068  1
311596  96.008  -71.841  52.066  1
311597  96.054  -71.849  52.066  1
311598  96.100  -71.845  52.065  1
311599  96.149  -71.827  52.063  1
311600  96.198  -71.810  52.057  1
311601  96.247  -71.793  52.050  1
311602  96.293  -71.773  52.041  1
311603  96.338  -71.751  52.031  1
311604  96.384  -71.731  52.018  1
311605  96.439  -71.719  52.002  1
311606  96.488  -71.724  51.983  1
311607  96.518  -71.742  51.960  1
311608  96.546  -71.760  51.936  1
311609  96.575  -71.775  51.913  1
311610  96.603  -71.791  51.890  1
311611  96.631  -71.806  51.867  1
311612  96.660  -71.821  51.844  1
311613  96.688  -71.836  51.817  1
311614  96.717  -71.851  51.789  1
311615  96.746  -71.867  51.759  1
311616  96.774  -71.882  51.731  1
311617  96.820  -71.882  51.703  1
311618  96.869  -71.879  51.677  1
311619  96.890  -71.875  51.651  1
311620  96.910  -71.871  51.626  1
311621  96.931  -71.867  51.603  1
311622  96.958  -71.864  51.583  1
311623  96.998  -71.866  51.565  1
311624  97.038  -71.867  51.546  1
311625  97.078  -71.870  51.526  1
311626  97.119  -71.877  51.500  1
311627  97.155  -71.882  51.471  1
311628  97.190  -71.886  51.441  1
311629  97.226  -71.892  51.410  1
311630  97.261  -71.896  51.378  1
311631  97.307  -71.908  51.345  1
311632  97.371  -71.931  51.310  1
311633  97.434  -71.954  51.271  1
311634  97.474  -71.964  51.235  1
311635  97.502  -71.965  51.203  1
311636  97.529  -71.967  51.175  1
311637  97.557  -71.969  51.146  1
311638  97.584  -71.971  51.116  1
311639  97.611  -71.973  51.081  1
311640  97.640  -71.975  51.042  1
311641  97.673  -71.977  51.002  1
311642  97.707  -71.979  50.960  1
311643  97.739  -71.981  50.918  1
311644  97.773  -71.983  50.876  1
311645  97.806  -71.985  50.832  1
311646  97.839  -71.986  50.784  1
311647  97.872  -71.989  50.737  1
311648  97.903  -71.993  50.689  1
311649  97.926  -72.010  50.639  1
311650  97.949  -72.026  50.590  1
311651  97.974  -72.035  50.546  1
311652  98.000  -72.043  50.503  1
311653  98.025  -72.052  50.458  1
311654  98.050  -72.060  50.415  1
311655  98.075  -72.068  50.371  1
311656  98.110  -72.070  50.326  1
311657  98.131  -72.087  50.280  1
311658  98.164  -72.096  50.230  1
311659  98.204  -72.113  50.175  1
311660  98.243  -72.130  50.119  1
311661  98.278  -72.141  50.062  1
311662  98.299  -72.137  50.005  1
311663  98.350  -72.146  49.953  1
311664  98.423  -72.166  49.902  1
311665  98.460  -72.168  49.853  1
311666  98.498  -72.171  49.803  1
311667  98.534  -72.173  49.752  1
311668  98.572  -72.175  49.699  1
311669  98.609  -72.177  49.646  1
311670  98.653  -72.192  49.593  1
311671  98.697  -72.208  49.541  1
311672  98.736  -72.224  49.490  1
311673  98.769  -72.240  49.439  1
311674  98.801  -72.258  49.389  1
311675  98.834  -72.275  49.338  1
311676  98.866  -72.293  49.289  1
311677  98.899  -72.310  49.240  1
311678  98.933  -72.329  49.191  1
311679  98.967  -72.349  49.141  1
311680  98.994  -72.367  49.091  1
311681  99.015  -72.385  49.041  1
311682  99.037  -72.403  48.990  1
311683  99.058  -72.421  48.941  1
311684  99.079  -72.438  48.889  1
311685  99.100  -72.456  48.839  1
311686  99.122  -72.474  48.789  1
311687  99.143  -72.491  48.738  1
311688  99.166  -72.508  48.688  1
311689  99.188  -72.525  48.638  1
311690  99.210  -72.541  48.589  1
311691  99.233  -72.558  48.539  1
311692  99.255  -72.575  48.490  1
311693  99.301  -72.587  48.441  1
311694  99.348  -72.599  48.393  1
311695  99.395  -72.610  48.345  1
311696  99.424  -72.622  48.297  1
311697  99.451  -72.634  48.250  1
311698  99.489  -72.642  48.204  1
311699  99.529  -72.650  48.158  1
311700  99.568  -72.657  48.112  1
311701  99.608  -72.665  48.066  1
311702  99.648  -72.672  48.019  1
311703  99.687  -72.679  47.973  1
311704  99.727  -72.687  47.927  1
311705  99.767  -72.694  47.884  1
311706  99.806  -72.702  47.840  1
311707  99.846  -72.710  47.795  1
311708  99.868  -72.743  47.750  1
311709  99.888  -72.779  47.706  1
311710  99.909  -72.815  47.661  1
311711  99.929  -72.851  47.617  1
311712  99.958  -72.875  47.574  1
311713  99.989  -72.895  47.531  1
311714  100.020  -72.916  47.486  1
311715  100.052  -72.919  47.442  1
311716  100.083  -72.910  47.400  1
311717  100.115  -72.901  47.356  1
311718  100.147  -72.891  47.314  1
311719  100.179  -72.882  47.273  1
311720  100.210  -72.873  47.231  1
311721  100.242  -72.863  47.189  1
311722  100.273  -72.854  47.147  1
311723  100.305  -72.846  47.105  1
311724  100.336  -72.850  47.063  1
311725  100.368  -72.854  47.022  1
311726  100.399  -72.858  46.981  1
311727  100.430  -72.862  46.940  1
311728  100.462  -72.866  46.899  1
311729  100.493  -72.870  46.857  1
311730  100.525  -72.874  46.817  1
311731  100.556  -72.879  46.779  1
311732  100.596  -72.902  46.742  1
311733  100.635  -72.925  46.705  1
311734  100.674  -72.948  46.669  1
311735  100.713  -72.971  46.633  1
311736  100.743  -72.967  46.596  1
311737  100.767  -72.945  46.557  1
311738  100.791  -72.924  46.521  1
311739  100.818  -72.907  46.484  1
311740  100.857  -72.907  46.447  1
311741  100.897  -72.907  46.411  1
311742  100.936  -72.907  46.373  1
311743  100.975  -72.907  46.337  1
311744  101.011  -72.911  46.301  1
311745  101.040  -72.927  46.265  1
311746  101.068  -72.942  46.230  1
311747  101.097  -72.958  46.196  1
311748  101.125  -72.973  46.162  1
311749  101.156  -72.981  46.127  1
311750  101.193  -72.973  46.093  1
311751  101.230  -72.963  46.061  1
311752  101.267  -72.955  46.028  1
311753  101.309  -72.942  45.994  1
311754  101.356  -72.923  45.961  1
311755  101.374  -72.929  45.927  1
311756  101.398  -72.945  45.893  1
311757  101.426  -72.972  45.859  1
311758  101.455  -72.999  45.825  1
311759  101.483  -73.026  45.790  1
311760  101.511  -73.053  45.754  1
311761  101.540  -73.079  45.718  1
311762  101.568  -73.107  45.681  1
311763  101.596  -73.133  45.644  1
311764  101.625  -73.160  45.606  1
311765  101.653  -73.187  45.567  1
311766  101.681  -73.214  45.529  1
311767  101.710  -73.239  45.490  1
311768  101.739  -73.264  45.450  1
311769  101.769  -73.286  45.411  1
311770  101.809  -73.300  45.372  1
311771  101.849  -73.313  45.334  1
311772  101.889  -73.326  45.297  1
311773  101.929  -73.340  45.260  1
311774  101.971  -73.350  45.224  1
311775  102.014  -73.360  45.188  1
311776  102.057  -73.369  45.153  1
311777  102.100  -73.379  45.119  1
311778  102.138  -73.386  45.086  1
311779  102.163  -73.387  45.054  1
311780  102.188  -73.387  45.023  1
312267  95.093  -71.416  52.478  1
312268  95.119  -71.431  52.460  1
312269  95.145  -71.445  52.442  1
312270  95.172  -71.459  52.423  1
312271  95.198  -71.474  52.406  1
312272  95.225  -71.488  52.388  1
312273  95.251  -71.503  52.371  1
312274  95.226  -71.530  52.355  1
312275  95.198  -71.558  52.339  1
312276  95.170  -71.587  52.323  1
312277  95.164  -71.612  52.308  1
312278  95.194  -71.618  52.293  1
312279  95.246  -71.640  52.278  1
312280  95.299  -71.663  52.263  1
312281  95.349  -71.681  52.248  1
312282  95.397  -71.690  52.234  1
312283  95.446  -71.700  52.220  1
312284  95.494  -71.709  52.206  1
312285  95.542  -71.719  52.191  1
312286  95.586  -71.728  52.177  1
312287  95.613  -71.738  52.162  1
312288  95.637  -71.738  52.149  1
312289  95.660  -71.735  52.136  1
312290  95.682  -71.732  52.124  1
312291  95.727  -71.740  52.112  1
312292  95.773  -71.749  52.102  1
312293  95.820  -71.758  52.095  1
312294  95.866  -71.766  52.088  1
312295  95.913  -71.776  52.081  1
312296  95.959  -71.785  52.079  1
312297  96.006  -71.793  52.079  1
312298  96.052  -71.802  52.080  1
312299  96.094  -71.791  52.081  1
312300  96.140  -71.770  52.081  1
312301  96.186  -71.750  52.076  1
312302  96.232  -71.729  52.069  1
312303  96.277  -71.708  52.060  1
312304  96.327  -71.691  52.051  1
312305  96.386  -71.684  52.040  1
312306  96.446  -71.677  52.025  1
312307  96.495  -71.685  52.006  1
312308  96.530  -71.701  51.981  1
312309  96.560  -71.719  51.957  1
312310  96.587  -71.739  51.931  1
312311  96.614  -71.759  51.907  1
312312  96.643  -71.774  51.883  1
312313  96.671  -71.789  51.860  1
312314  96.699  -71.804  51.834  1
312315  96.728  -71.820  51.806  1
312316  96.756  -71.835  51.777  1
312317  96.785  -71.851  51.749  1
312318  96.829  -71.851  51.720  1
312319  96.866  -71.848  51.692  1
312320  96.887  -71.844  51.663  1
312321  96.907  -71.840  51.634  1
312322  96.944  -71.841  51.608  1
312323  96.983  -71.842  51.584  1
312324  97.023  -71.844  51.561  1
312325  97.063  -71.845  51.539  1
312326  97.103  -71.849  51.517  1
312327  97.140  -71.854  51.492  1
312328  97.175  -71.860  51.466  1
312329  97.211  -71.864  51.439  1
312330  97.246  -71.869  51.410  1
312331  97.281  -71.873  51.380  1
312332  97.316  -71.879  51.349  1
312333  97.368  -71.894  51.314  1
312334  97.432  -71.917  51.274  1
312335  97.490  -71.937  51.236  1
312336  97.517  -71.939  51.203  1
312337  97.545  -71.941  51.174  1
312338  97.572  -71.942  51.146  1
312339  97.600  -71.945  51.116  1
312340  97.628  -71.946  51.081  1
312341  97.655  -71.948  51.041  1
312342  97.682  -71.951  50.999  1
312343  97.713  -71.952  50.954  1
312344  97.745  -71.954  50.909  1
312345  97.779  -71.956  50.865  1
312346  97.812  -71.958  50.820  1
312347  97.845  -71.960  50.774  1
312348  97.878  -71.962  50.728  1
312349  97.906  -71.971  50.681  1
312350  97.929  -71.988  50.634  1
312351  97.954  -71.997  50.590  1
312352  97.979  -72.005  50.552  1
312353  98.004  -72.014  50.513  1
312354  98.029  -72.022  50.470  1
312355  98.055  -72.030  50.427  1
312356  98.080  -72.039  50.383  1
312357  98.105  -72.047  50.337  1
312358  98.137  -72.058  50.289  1
312359  98.176  -72.075  50.238  1
312360  98.216  -72.092  50.183  1
312361  98.255  -72.108  50.124  1
312362  98.292  -72.123  50.064  1
312363  98.314  -72.118  50.006  1
312364  98.388  -72.139  49.954  1
312365  98.425  -72.141  49.905  1
312366  98.462  -72.143  49.855  1
312367  98.500  -72.146  49.805  1
312368  98.536  -72.148  49.753  1
312369  98.574  -72.150  49.700  1
312370  98.611  -72.152  49.645  1
312371  98.650  -72.159  49.590  1
312372  98.695  -72.174  49.538  1
312373  98.738  -72.189  49.486  1
312374  98.782  -72.205  49.435  1
312375  98.815  -72.222  49.386  1
312376  98.848  -72.240  49.335  1
312377  98.880  -72.256  49.285  1
312378  98.913  -72.274  49.237  1
312379  98.947  -72.293  49.188  1
312380  98.981  -72.312  49.138  1
312381  99.004  -72.330  49.088  1
312382  99.025  -72.348  49.038  1
312383  99.047  -72.366  48.988  1
312384  99.068  -72.384  48.939  1
312385  99.089  -72.402  48.889  1
312386  99.111  -72.419  48.839  1
312387  99.133  -72.436  48.789  1
312388  99.155  -72.453  48.738  1
312389  99.178  -72.469  48.686  1
312390  99.200  -72.486  48.636  1
312391  99.222  -72.503  48.586  1
312392  99.244  -72.519  48.536  1
312393  99.268  -72.535  48.489  1
312394  99.315  -72.547  48.441  1
312395  99.362  -72.559  48.393  1
312396  99.409  -72.571  48.346  1
312397  99.455  -72.582  48.299  1
312398  99.484  -72.594  48.252  1
312399  99.511  -72.606  48.205  1
312400  99.541  -72.617  48.159  1
312401  99.581  -72.625  48.113  1
312402  99.620  -72.632  48.067  1
312403  99.660  -72.640  48.021  1
312404  99.700  -72.647  47.975  1
312405  99.739  -72.654  47.929  1
312406  99.779  -72.662  47.885  1
312407  99.819  -72.669  47.841  1
312408  99.858  -72.677  47.797  1
312409  99.886  -72.703  47.752  1
312410  99.906  -72.738  47.708  1
312411  99.926  -72.775  47.663  1
312412  99.946  -72.810  47.619  1
312413  99.969  -72.844  47.576  1
312414  100.000  -72.864  47.533  1
312415  100.031  -72.885  47.489  1
312416  100.063  -72.881  47.446  1
312417  100.095  -72.872  47.404  1
312418  100.126  -72.863  47.360  1
312419  100.158  -72.854  47.318  1
312420  100.190  -72.844  47.278  1
312421  100.221  -72.835  47.236  1
312422  100.253  -72.826  47.195  1
312423  100.284  -72.816  47.154  1
312424  100.316  -72.807  47.112  1
312425  100.348  -72.801  47.071  1
312426  100.379  -72.804  47.031  1
312427  100.411  -72.808  46.991  1
312428  100.442  -72.813  46.951  1
312429  100.473  -72.816  46.911  1
312430  100.504  -72.820  46.869  1
312431  100.536  -72.825  46.829  1
312432  100.570  -72.835  46.791  1
312433  100.609  -72.857  46.754  1
312434  100.648  -72.880  46.717  1
312435  100.687  -72.904  46.681  1
312436  100.726  -72.926  46.644  1
312437  100.760  -72.933  46.606  1
312438  100.784  -72.913  46.566  1
312439  100.809  -72.891  46.528  1
312440  100.843  -72.884  46.490  1
312441  100.882  -72.884  46.452  1
312442  100.921  -72.884  46.415  1
312443  100.960  -72.884  46.377  1
312444  100.991  -72.896  46.340  1
312445  101.019  -72.912  46.304  1
312446  101.048  -72.928  46.268  1
312447  101.076  -72.943  46.233  1
312448  101.105  -72.959  46.198  1
312449  101.133  -72.974  46.164  1
312450  101.162  -72.987  46.129  1
312451  101.199  -72.979  46.095  1
312452  101.236  -72.970  46.062  1
312453  101.278  -72.957  46.029  1
312454  101.328  -72.936  45.995  1
312455  101.374  -72.919  45.962  1
312456  101.391  -72.924  45.928  1
312457  101.409  -72.930  45.894  1
312458  101.432  -72.946  45.860  1
312459  101.461  -72.973  45.825  1
312460  101.489  -72.999  45.790  1
312461  101.517  -73.026  45.754  1
312462  101.546  -73.053  45.718  1
312463  101.574  -73.080  45.682  1
312464  101.603  -73.107  45.644  1
312465  101.631  -73.134  45.607  1
312466  101.659  -73.161  45.568  1
312467  101.688  -73.187  45.528  1
312468  101.716  -73.212  45.490  1
312469  101.745  -73.236  45.450  1
312470  101.782  -73.253  45.410  1
312471  101.822  -73.266  45.371  1
312472  101.862  -73.280  45.333  1
312473  101.902  -73.293  45.296  1
312474  101.942  -73.305  45.260  1
312475  101.984  -73.316  45.224  1
312476  102.028  -73.326  45.189  1
312477  102.070  -73.335  45.153  1
312478  102.114  -73.345  45.119  1
312479  102.146  -73.349  45.087  1
312480  102.171  -73.350  45.054  1
312968  95.091  -71.371  52.474  1
312969  95.117  -71.386  52.456  1
312970  95.143  -71.400  52.438  1
312971  95.170  -71.415  52.421  1
312972  95.196  -71.429  52.404  1
312973  95.222  -71.444  52.387  1
312974  95.232  -71.462  52.371  1
312975  95.203  -71.491  52.355  1
312976  95.176  -71.519  52.339  1
312977  95.147  -71.547  52.324  1
312978  95.178  -71.566  52.310  1
312979  95.215  -71.584  52.295  1
312980  95.239  -71.575  52.281  1
312981  95.292  -71.599  52.266  1
312982  95.344  -71.622  52.252  1
312983  95.394  -71.635  52.239  1
312984  95.442  -71.644  52.225  1
312985  95.490  -71.654  52.211  1
312986  95.539  -71.663  52.196  1
312987  95.587  -71.673  52.182  1
312988  95.616  -71.683  52.169  1
312989  95.643  -71.692  52.156  1
312990  95.668  -71.694  52.143  1
312991  95.690  -71.691  52.131  1
312992  95.722  -71.693  52.120  1
312993  95.768  -71.702  52.111  1
312994  95.815  -71.711  52.104  1
312995  95.861  -71.719  52.098  1
312996  95.908  -71.729  52.093  1
312997  95.954  -71.738  52.090  1
312998  96.000  -71.745  52.092  1
312999  96.036  -71.741  52.095  1
313000  96.079  -71.727  52.098  1
313001  96.125  -71.706  52.099  1
313002  96.171  -71.685  52.095  1
313003  96.217  -71.664  52.089  1
313004  96.274  -71.657  52.082  1
313005  96.334  -71.650  52.074  1
313006  96.393  -71.642  52.065  1
313007  96.452  -71.635  52.052  1
313008  96.502  -71.645  52.033  1
313009  96.537  -71.662  52.007  1
313010  96.572  -71.679  51.980  1
313011  96.601  -71.697  51.952  1
313012  96.628  -71.716  51.926  1
313013  96.656  -71.736  51.902  1
313014  96.683  -71.756  51.879  1
313015  96.711  -71.773  51.853  1
313016  96.739  -71.788  51.827  1
313017  96.767  -71.804  51.799  1
313018  96.796  -71.819  51.770  1
313019  96.839  -71.821  51.741  1
313020  96.863  -71.817  51.711  1
313021  96.889  -71.815  51.680  1
313022  96.929  -71.817  51.648  1
313023  96.968  -71.818  51.617  1
313024  97.008  -71.820  51.588  1
313025  97.047  -71.821  51.562  1
313026  97.087  -71.823  51.536  1
313027  97.125  -71.827  51.513  1
313028  97.161  -71.832  51.487  1
313029  97.196  -71.837  51.460  1
313030  97.231  -71.842  51.433  1
313031  97.266  -71.847  51.405  1
313032  97.302  -71.851  51.376  1
313033  97.337  -71.856  51.345  1
313034  97.372  -71.861  51.311  1
313035  97.429  -71.879  51.271  1
313036  97.493  -71.903  51.235  1
313037  97.533  -71.912  51.202  1
313038  97.561  -71.914  51.172  1
313039  97.588  -71.916  51.145  1
313040  97.615  -71.918  51.116  1
313041  97.643  -71.920  51.081  1
313042  97.671  -71.922  51.041  1
313043  97.698  -71.924  50.998  1
313044  97.726  -71.926  50.953  1
313045  97.753  -71.928  50.909  1
313046  97.785  -71.929  50.864  1
313047  97.818  -71.932  50.818  1
313048  97.851  -71.933  50.771  1
313049  97.884  -71.936  50.725  1
313050  97.909  -71.949  50.679  1
313051  97.934  -71.960  50.635  1
313052  97.959  -71.968  50.594  1
313053  97.984  -71.976  50.556  1
313054  98.009  -71.985  50.518  1
313055  98.034  -71.993  50.478  1
313056  98.060  -72.001  50.434  1
313057  98.087  -72.010  50.389  1
313058  98.114  -72.018  50.342  1
313059  98.147  -72.032  50.292  1
313060  98.188  -72.052  50.240  1
313061  98.228  -72.070  50.182  1
313062  98.268  -72.087  50.122  1
313063  98.307  -72.104  50.062  1
313064  98.353  -72.111  50.004  1
313065  98.390  -72.114  49.951  1
313066  98.427  -72.116  49.900  1
313067  98.464  -72.118  49.849  1
313068  98.502  -72.121  49.798  1
313069  98.539  -72.123  49.746  1
313070  98.576  -72.125  49.693  1
313071  98.613  -72.127  49.641  1
313072  98.650  -72.130  49.587  1
313073  98.692  -72.141  49.535  1
313074  98.736  -72.156  49.484  1
313075  98.780  -72.172  49.433  1
313076  98.824  -72.187  49.383  1
313077  98.862  -72.203  49.332  1
313078  98.895  -72.221  49.283  1
313079  98.927  -72.238  49.235  1
313080  98.961  -72.256  49.187  1
313081  98.992  -72.275  49.137  1
313082  99.013  -72.293  49.087  1
313083  99.035  -72.311  49.037  1
313084  99.056  -72.329  48.987  1
313085  99.078  -72.346  48.937  1
313086  99.100  -72.363  48.886  1
313087  99.122  -72.380  48.837  1
313088  99.145  -72.396  48.787  1
313089  99.167  -72.413  48.736  1
313090  99.189  -72.430  48.685  1
313091  99.212  -72.446  48.634  1
313092  99.234  -72.463  48.585  1
313093  99.257  -72.480  48.535  1
313094  99.282  -72.496  48.488  1
313095  99.329  -72.508  48.440  1
313096  99.376  -72.519  48.393  1
313097  99.423  -72.531  48.346  1
313098  99.470  -72.543  48.300  1
313099  99.516  -72.555  48.253  1
313100  99.545  -72.566  48.207  1
313101  99.571  -72.578  48.161  1
313102  99.598  -72.591  48.115  1
313103  99.633  -72.600  48.068  1
313104  99.672  -72.607  48.022  1
313105  99.712  -72.615  47.976  1
313106  99.752  -72.622  47.931  1
313107  99.791  -72.630  47.887  1
313108  99.831  -72.637  47.842  1
313109  99.870  -72.644  47.798  1
313110  99.903  -72.663  47.754  1
313111  99.923  -72.698  47.710  1
313112  99.944  -72.735  47.665  1
313113  99.964  -72.770  47.621  1
313114  99.985  -72.806  47.579  1
313115  100.011  -72.833  47.536  1
313116  100.043  -72.853  47.492  1
313117  100.074  -72.843  47.449  1
313118  100.106  -72.834  47.407  1
313119  100.138  -72.825  47.364  1
313120  100.170  -72.816  47.323  1
313121  100.201  -72.807  47.283  1
313122  100.232  -72.797  47.242  1
313123  100.264  -72.788  47.202  1
313124  100.296  -72.779  47.161  1
313125  100.328  -72.770  47.120  1
313126  100.359  -72.761  47.079  1
313127  100.391  -72.755  47.039  1
313128  100.422  -72.759  47.000  1
313129  100.454  -72.763  46.961  1
313130  100.485  -72.767  46.922  1
313131  100.516  -72.771  46.880  1
313132  100.547  -72.775  46.841  1
313133  100.583  -72.790  46.804  1
313134  100.623  -72.813  46.767  1
313135  100.662  -72.836  46.731  1
313136  100.701  -72.859  46.694  1
313137  100.740  -72.882  46.656  1
313138  100.778  -72.901  46.617  1
313139  100.802  -72.879  46.577  1
313140  100.828  -72.861  46.537  1
313141  100.867  -72.861  46.498  1
313142  100.906  -72.861  46.459  1
313143  100.943  -72.866  46.420  1
313144  100.971  -72.882  46.382  1
313145  100.999  -72.897  46.344  1
313146  101.028  -72.913  46.308  1
313147  101.056  -72.928  46.272  1
313148  101.085  -72.944  46.236  1
313149  101.113  -72.960  46.200  1
313150  101.141  -72.975  46.166  1
313151  101.170  -72.991  46.132  1
313152  101.205  -72.985  46.097  1
313153  101.247  -72.972  46.064  1
313154  101.296  -72.951  46.030  1
313155  101.346  -72.930  45.996  1
313156  101.391  -72.914  45.962  1
313157  101.408  -72.920  45.928  1
313158  101.426  -72.926  45.894  1
313159  101.444  -72.931  45.860  1
313160  101.467  -72.946  45.825  1
313161  101.495  -72.973  45.790  1
313162  101.524  -73.000  45.754  1
313163  101.552  -73.027  45.718  1
313164  101.580  -73.054  45.681  1
313165  101.609  -73.080  45.644  1
313166  101.637  -73.108  45.606  1
313167  101.665  -73.134  45.568  1
313168  101.694  -73.161  45.529  1
313169  101.723  -73.186  45.489  1
313170  101.755  -73.206  45.450  1
313171  101.795  -73.220  45.410  1
313172  101.835  -73.233  45.372  1
313173  101.875  -73.246  45.334  1
313174  101.915  -73.259  45.298  1
313175  101.955  -73.272  45.261  1
313176  101.997  -73.282  45.225  1
313177  102.041  -73.292  45.190  1
313178  102.084  -73.302  45.154  1
313179  102.127  -73.311  45.120  1
313180  102.153  -73.313  45.088  1
313669  95.089  -71.326  52.470  1
313670  95.115  -71.340  52.452  1
313671  95.141  -71.355  52.435  1
313672  95.168  -71.369  52.419  1
313673  95.194  -71.384  52.402  1
313674  95.220  -71.398  52.386  1
313675  95.209  -71.422  52.370  1
313676  95.181  -71.450  52.355  1
313677  95.154  -71.478  52.339  1
313678  95.157  -71.502  52.325  1
313679  95.193  -71.520  52.311  1
313680  95.231  -71.538  52.298  1
313681  95.264  -71.550  52.283  1
313682  95.285  -71.535  52.269  1
313683  95.338  -71.558  52.256  1
313684  95.390  -71.581  52.243  1
313685  95.439  -71.590  52.229  1
313686  95.487  -71.600  52.216  1
313687  95.535  -71.609  52.202  1
313688  95.584  -71.619  52.188  1
313689  95.618  -71.628  52.175  1
313690  95.646  -71.638  52.163  1
313691  95.673  -71.647  52.150  1
313692  95.698  -71.651  52.138  1
313693  95.721  -71.648  52.128  1
313694  95.763  -71.655  52.120  1
313695  95.810  -71.663  52.113  1
313696  95.856  -71.672  52.108  1
313697  95.903  -71.682  52.104  1
313698  95.947  -71.688  52.102  1
313699  95.983  -71.684  52.105  1
313700  96.020  -71.681  52.110  1
313701  96.064  -71.663  52.115  1
313702  96.110  -71.642  52.117  1
313703  96.162  -71.629  52.114  1
313704  96.222  -71.622  52.110  1
313705  96.281  -71.615  52.104  1
313706  96.340  -71.607  52.097  1
313707  96.399  -71.600  52.089  1
313708  96.459  -71.594  52.077  1
313709  96.508  -71.606  52.058  1
313710  96.543  -71.622  52.033  1
313711  96.578  -71.639  52.004  1
313712  96.613  -71.655  51.973  1
313713  96.643  -71.674  51.944  1
313714  96.670  -71.694  51.918  1
313715  96.697  -71.713  51.896  1
313716  96.724  -71.733  51.870  1
313717  96.751  -71.753  51.844  1
313718  96.779  -71.773  51.818  1
313719  96.807  -71.788  51.790  1
313720  96.838  -71.791  51.761  1
313721  96.874  -71.791  51.730  1
313722  96.914  -71.792  51.697  1
313723  96.954  -71.794  51.663  1
313724  96.993  -71.795  51.628  1
313725  97.033  -71.797  51.595  1
313726  97.072  -71.797  51.565  1
313727  97.110  -71.799  51.537  1
313728  97.146  -71.805  51.512  1
313729  97.181  -71.810  51.484  1
313730  97.217  -71.814  51.455  1
313731  97.252  -71.820  51.428  1
313732  97.287  -71.824  51.400  1
313733  97.322  -71.829  51.370  1
313734  97.358  -71.834  51.339  1
313735  97.393  -71.838  51.306  1
313736  97.428  -71.843  51.268  1
313737  97.491  -71.866  51.233  1
313738  97.549  -71.885  51.200  1
313739  97.577  -71.888  51.170  1
313740  97.604  -71.890  51.142  1
313741  97.632  -71.892  51.114  1
313742  97.659  -71.894  51.081  1
313743  97.686  -71.895  51.042  1
313744  97.714  -71.898  51.000  1
313745  97.741  -71.899  50.955  1
313746  97.769  -71.901  50.910  1
313747  97.796  -71.903  50.864  1
313748  97.824  -71.905  50.819  1
313749  97.857  -71.907  50.774  1
313750  97.889  -71.911  50.729  1
313751  97.913  -71.922  50.685  1
313752  97.938  -71.930  50.641  1
313753  97.963  -71.939  50.600  1
313754  97.991  -71.948  50.562  1
313755  98.017  -71.956  50.523  1
313756  98.044  -71.964  50.481  1
313757  98.072  -71.973  50.435  1
313758  98.098  -71.981  50.388  1
313759  98.126  -71.989  50.339  1
313760  98.155  -71.998  50.288  1
313761  98.196  -72.019  50.236  1
313762  98.237  -72.039  50.179  1
313763  98.278  -72.060  50.120  1
313764  98.318  -72.080  50.061  1
313765  98.355  -72.086  50.006  1
313766  98.392  -72.089  49.954  1
313767  98.430  -72.091  49.902  1
313768  98.466  -72.093  49.851  1
313769  98.504  -72.095  49.799  1
313770  98.541  -72.098  49.746  1
313771  98.578  -72.100  49.694  1
313772  98.615  -72.102  49.642  1
313773  98.652  -72.105  49.590  1
313774  98.690  -72.108  49.538  1
313775  98.734  -72.124  49.486  1
313776  98.778  -72.139  49.435  1
313777  98.822  -72.154  49.384  1
313778  98.866  -72.169  49.333  1
313779  98.909  -72.185  49.284  1
313780  98.941  -72.202  49.235  1
313781  98.975  -72.220  49.186  1
313782  99.002  -72.239  49.137  1
313783  99.023  -72.256  49.086  1
313784  99.045  -72.274  49.036  1
313785  99.067  -72.290  48.987  1
313786  99.089  -72.307  48.935  1
313787  99.112  -72.324  48.884  1
313788  99.134  -72.340  48.834  1
313789  99.156  -72.357  48.784  1
313790  99.179  -72.374  48.734  1
313791  99.201  -72.390  48.683  1
313792  99.223  -72.407  48.634  1
313793  99.246  -72.424  48.584  1
313794  99.268  -72.440  48.535  1
313795  99.296  -72.456  48.487  1
313796  99.343  -72.468  48.440  1
313797  99.390  -72.480  48.393  1
313798  99.436  -72.491  48.346  1
313799  99.484  -72.503  48.300  1
313800  99.531  -72.515  48.254  1
313801  99.577  -72.527  48.208  1
313802  99.605  -72.539  48.163  1
313803  99.632  -72.550  48.116  1
313804  99.658  -72.562  48.069  1
313805  99.685  -72.575  48.023  1
313806  99.724  -72.582  47.976  1
313807  99.764  -72.590  47.931  1
313808  99.803  -72.597  47.888  1
313809  99.843  -72.605  47.844  1
313810  99.883  -72.613  47.799  1
313811  99.920  -72.622  47.756  1
313812  99.941  -72.658  47.712  1
313813  99.961  -72.694  47.667  1
313814  99.982  -72.730  47.624  1
313815  100.002  -72.766  47.582  1
313816  100.022  -72.802  47.538  1
313817  100.054  -72.815  47.495  1
313818  100.085  -72.806  47.453  1
313819  100.117  -72.797  47.411  1
313820  100.149  -72.788  47.369  1
313821  100.181  -72.779  47.328  1
313822  100.212  -72.769  47.288  1
313823  100.244  -72.760  47.248  1
313824  100.275  -72.750  47.209  1
313825  100.307  -72.741  47.168  1
313826  100.339  -72.732  47.127  1
313827  100.370  -72.723  47.087  1
313828  100.402  -72.714  47.048  1
313829  100.433  -72.710  47.009  1
313830  100.465  -72.714  46.970  1
313831  100.496  -72.718  46.932  1
313832  100.528  -72.722  46.894  1
313833  100.559  -72.725  46.856  1
313834  100.597  -72.746  46.820  1
313835  100.636  -72.769  46.784  1
313836  100.675  -72.791  46.744  1
313837  100.714  -72.815  46.707  1
313838  100.754  -72.838  46.668  1
313839  100.793  -72.860  46.628  1
313840  100.819  -72.847  46.588  1
313841  100.852  -72.838  46.546  1
313842  100.892  -72.838  46.506  1
313843  100.922  -72.851  46.467  1
313844  100.951  -72.866  46.428  1
313845  100.979  -72.882  46.389  1
313846  101.007  -72.898  46.351  1
313847  101.036  -72.913  46.313  1
313848  101.064  -72.929  46.277  1
313849  101.093  -72.945  46.241  1
313850  101.121  -72.960  46.205  1
313851  101.149  -72.976  46.171  1
313852  101.178  -72.992  46.137  1
313853  101.215  -72.987  46.101  1
313854  101.265  -72.966  46.067  1
313855  101.315  -72.945  46.033  1
313856  101.365  -72.925  45.999  1
313857  101.408  -72.910  45.964  1
313858  101.425  -72.916  45.929  1
313859  101.444  -72.921  45.895  1
313860  101.461  -72.927  45.860  1
313861  101.479  -72.932  45.826  1
313862  101.501  -72.947  45.790  1
313863  101.530  -72.973  45.754  1
313864  101.558  -73.001  45.718  1
313865  101.587  -73.027  45.681  1
313866  101.615  -73.054  45.644  1
313867  101.643  -73.081  45.606  1
313868  101.672  -73.108  45.568  1
313869  101.700  -73.134  45.529  1
313870  101.729  -73.158  45.489  1
313871  101.767  -73.173  45.450  1
313872  101.808  -73.186  45.411  1
313873  101.847  -73.199  45.373  1
313874  101.888  -73.212  45.335  1
313875  101.927  -73.226  45.299  1
313876  101.968  -73.239  45.263  1
313877  102.010  -73.248  45.227  1
313878  102.054  -73.258  45.191  1
313879  102.097  -73.267  45.156  1
313880  102.137  -73.275  45.121  1
314370  95.087  -71.281  52.467  1
314371  95.113  -71.296  52.450  1
314372  95.139  -71.310  52.433  1
314373  95.166  -71.324  52.417  1
314374  95.192  -71.339  52.401  1
314375  95.215  -71.354  52.385  1
314376  95.187  -71.382  52.370  1
314377  95.159  -71.410  52.355  1
314378  95.134  -71.438  52.341  1
314379  95.172  -71.456  52.327  1
314380  95.208  -71.474  52.313  1
314381  95.245  -71.492  52.300  1
314382  95.282  -71.510  52.286  1
314383  95.306  -71.504  52.274  1
314384  95.331  -71.493  52.261  1
314385  95.384  -71.516  52.248  1
314386  95.435  -71.535  52.235  1
314387  95.483  -71.544  52.222  1
314388  95.532  -71.554  52.208  1
314389  95.580  -71.563  52.195  1
314390  95.621  -71.573  52.183  1
314391  95.649  -71.582  52.169  1
314392  95.676  -71.592  52.157  1
314393  95.703  -71.602  52.146  1
314394  95.729  -71.607  52.135  1
314395  95.758  -71.608  52.128  1
314396  95.805  -71.616  52.122  1
314397  95.851  -71.625  52.117  1
314398  95.894  -71.630  52.114  1
314399  95.930  -71.626  52.113  1
314400  95.966  -71.623  52.119  1
314401  96.003  -71.619  52.124  1
314402  96.050  -71.600  52.129  1
314403  96.109  -71.594  52.133  1
314404  96.169  -71.587  52.134  1
314405  96.228  -71.580  52.132  1
314406  96.288  -71.572  52.128  1
314407  96.346  -71.566  52.122  1
314408  96.406  -71.559  52.113  1
314409  96.468  -71.553  52.099  1
314410  96.515  -71.567  52.080  1
314411  96.550  -71.583  52.056  1
314412  96.585  -71.600  52.028  1
314413  96.620  -71.616  51.995  1
314414  96.655  -71.632  51.963  1
314415  96.684  -71.651  51.933  1
314416  96.711  -71.671  51.911  1
314417  96.738  -71.691  51.885  1
314418  96.765  -71.710  51.859  1
314419  96.793  -71.730  51.834  1
314420  96.820  -71.750  51.807  1
314421  96.855  -71.757  51.779  1
314422  96.893  -71.756  51.748  1
314423  96.932  -71.756  51.715  1
314424  96.970  -71.755  51.677  1
314425  97.009  -71.755  51.640  1
314426  97.047  -71.754  51.604  1
314427  97.084  -71.755  51.570  1
314428  97.120  -71.761  51.541  1
314429  97.160  -71.773  51.513  1
314430  97.199  -71.784  51.483  1
314431  97.237  -71.792  51.453  1
314432  97.273  -71.797  51.424  1
314433  97.308  -71.801  51.395  1
314434  97.343  -71.807  51.363  1
314435  97.378  -71.811  51.332  1
314436  97.413  -71.816  51.300  1
314437  97.448  -71.821  51.264  1
314438  97.488  -71.829  51.230  1
314439  97.551  -71.851  51.198  1
314440  97.592  -71.861  51.167  1
314441  97.620  -71.864  51.138  1
314442  97.647  -71.865  51.110  1
314443  97.675  -71.867  51.079  1
314444  97.703  -71.869  51.043  1
314445  97.730  -71.871  51.002  1
314446  97.757  -71.873  50.958  1
314447  97.785  -71.875  50.911  1
314448  97.812  -71.876  50.866  1
314449  97.840  -71.879  50.823  1
314450  97.867  -71.880  50.782  1
314451  97.894  -71.885  50.739  1
314452  97.921  -71.893  50.695  1
314453  97.948  -71.901  50.651  1
314454  97.975  -71.910  50.609  1
314455  98.002  -71.918  50.569  1
314456  98.029  -71.926  50.528  1
314457  98.056  -71.936  50.482  1
314458  98.083  -71.944  50.432  1
314459  98.110  -71.952  50.381  1
314460  98.138  -71.960  50.330  1
314461  98.165  -71.967  50.279  1
314462  98.205  -71.986  50.228  1
314463  98.245  -72.007  50.173  1
314464  98.286  -72.027  50.117  1
314465  98.326  -72.048  50.062  1
314466  98.364  -72.062  50.011  1
314467  98.396  -72.064  49.961  1
314468  98.432  -72.066  49.910  1
314469  98.468  -72.068  49.858  1
314470  98.506  -72.070  49.807  1
314471  98.543  -72.073  49.752  1
314472  98.580  -72.075  49.700  1
314473  98.617  -72.077  49.649  1
314474  98.654  -72.080  49.597  1
314475  98.691  -72.082  49.546  1
314476  98.732  -72.090  49.493  1
314477  98.776  -72.105  49.440  1
314478  98.819  -72.121  49.388  1
314479  98.864  -72.136  49.337  1
314480  98.908  -72.152  49.287  1
314481  98.951  -72.167  49.236  1
314482  98.989  -72.183  49.186  1
314483  99.012  -72.202  49.138  1
314484  99.034  -72.218  49.087  1
314485  99.057  -72.235  49.038  1
314486  99.079  -72.252  48.988  1
314487  99.101  -72.268  48.936  1
314488  99.124  -72.285  48.883  1
314489  99.146  -72.302  48.831  1
314490  99.168  -72.318  48.781  1
314491  99.191  -72.335  48.731  1
314492  99.213  -72.352  48.682  1
314493  99.235  -72.368  48.632  1
314494  99.258  -72.385  48.583  1
314495  99.280  -72.402  48.534  1
314496  99.310  -72.417  48.486  1
314497  99.357  -72.428  48.440  1
314498  99.404  -72.440  48.393  1
314499  99.450  -72.452  48.347  1
314500  99.497  -72.464  48.301  1
314501  99.544  -72.475  48.255  1
314502  99.591  -72.487  48.209  1
314503  99.638  -72.499  48.164  1
314504  99.665  -72.511  48.117  1
314505  99.692  -72.523  48.071  1
314506  99.719  -72.535  48.024  1
314507  99.746  -72.547  47.978  1
314508  99.776  -72.557  47.932  1
314509  99.816  -72.565  47.888  1
314510  99.855  -72.572  47.844  1
314511  99.895  -72.580  47.800  1
314512  99.934  -72.587  47.756  1
314513  99.959  -72.618  47.713  1
314514  99.979  -72.653  47.669  1
314515  99.999  -72.690  47.626  1
314516  100.019  -72.725  47.584  1
314517  100.040  -72.762  47.541  1
314518  100.065  -72.777  47.499  1
314519  100.097  -72.768  47.456  1
314520  100.128  -72.759  47.414  1
314521  100.160  -72.750  47.373  1
314522  100.192  -72.741  47.333  1
314523  100.223  -72.732  47.294  1
314524  100.255  -72.722  47.254  1
314525  100.286  -72.713  47.215  1
314526  100.318  -72.703  47.175  1
314527  100.350  -72.694  47.135  1
314528  100.382  -72.685  47.095  1
314529  100.413  -72.676  47.058  1
314530  100.444  -72.667  47.019  1
314531  100.476  -72.664  46.981  1
314532  100.507  -72.669  46.943  1
314533  100.539  -72.672  46.905  1
314534  100.571  -72.678  46.869  1
314535  100.610  -72.701  46.834  1
314536  100.649  -72.724  46.798  1
314537  100.689  -72.747  46.758  1
314538  100.728  -72.770  46.720  1
314539  100.767  -72.793  46.680  1
314540  100.806  -72.816  46.639  1
314541  100.838  -72.815  46.598  1
314542  100.874  -72.820  46.556  1
314543  100.902  -72.836  46.516  1
314544  100.930  -72.851  46.476  1
314545  100.959  -72.867  46.436  1
314546  100.987  -72.883  46.397  1
314547  101.015  -72.898  46.357  1
314548  101.044  -72.911  46.319  1
314549  101.073  -72.923  46.283  1
314550  101.102  -72.935  46.247  1
314551  101.130  -72.948  46.211  1
314552  101.159  -72.960  46.175  1
314553  101.191  -72.972  46.141  1
314554  101.234  -72.981  46.105  1
314555  101.284  -72.960  46.070  1
314556  101.334  -72.940  46.036  1
314557  101.384  -72.919  46.001  1
314558  101.425  -72.906  45.966  1
314559  101.443  -72.911  45.931  1
314560  101.461  -72.917  45.896  1
314561  101.478  -72.923  45.861  1
314562  101.496  -72.928  45.826  1
314563  101.514  -72.934  45.791  1
314564  101.536  -72.948  45.755  1
314565  101.564  -72.974  45.719  1
314566  101.593  -73.001  45.682  1
314567  101.621  -73.028  45.643  1
314568  101.650  -73.054  45.605  1
314569  101.678  -73.082  45.568  1
314570  101.706  -73.107  45.529  1
314571  101.740  -73.126  45.490  1
314572  101.780  -73.139  45.451  1
314573  101.820  -73.152  45.412  1
314574  101.861  -73.166  45.374  1
314575  101.900  -73.179  45.337  1
314576  101.941  -73.192  45.300  1
314577  101.981  -73.205  45.264  1
314578  102.024  -73.214  45.228  1
314579  102.067  -73.224  45.192  1
314580  102.110  -73.233  45.157  1
314581  102.144  -73.239  45.123  1
315071  95.085  -71.236  52.465  1
315072  95.111  -71.250  52.448  1
315073  95.137  -71.265  52.432  1
315074  95.164  -71.279  52.416  1
315075  95.190  -71.293  52.401  1
315076  95.193  -71.314  52.385  1
315077  95.165  -71.343  52.370  1
315078  95.137  -71.371  52.356  1
315079  95.149  -71.393  52.342  1
315080  95.187  -71.410  52.330  1
315081  95.224  -71.428  52.316  1
315082  95.260  -71.447  52.303  1
315083  95.298  -71.465  52.290  1
315084  95.334  -71.482  52.277  1
315085  95.348  -71.458  52.265  1
315086  95.377  -71.452  52.253  1
315087  95.430  -71.475  52.240  1
315088  95.480  -71.490  52.227  1
315089  95.528  -71.499  52.214  1
315090  95.577  -71.509  52.201  1
315091  95.623  -71.518  52.189  1
315092  95.651  -71.528  52.176  1
315093  95.678  -71.538  52.165  1
315094  95.705  -71.547  52.154  1
315095  95.733  -71.556  52.144  1
315096  95.759  -71.564  52.136  1
315097  95.800  -71.569  52.130  1
315098  95.841  -71.572  52.126  1
315099  95.877  -71.569  52.123  1
315100  95.913  -71.566  52.123  1
315101  95.954  -71.563  52.128  1
315102  95.998  -71.563  52.134  1
315103  96.057  -71.559  52.140  1
315104  96.116  -71.552  52.146  1
315105  96.175  -71.545  52.149  1
315106  96.235  -71.538  52.148  1
315107  96.294  -71.531  52.145  1
315108  96.353  -71.524  52.139  1
315109  96.412  -71.517  52.129  1
315110  96.482  -71.512  52.115  1
315111  96.521  -71.528  52.096  1
315112  96.556  -71.544  52.073  1
315113  96.591  -71.560  52.044  1
315114  96.626  -71.577  52.011  1
315115  96.661  -71.594  51.978  1
315116  96.696  -71.610  51.947  1
315117  96.725  -71.629  51.921  1
315118  96.752  -71.648  51.894  1
315119  96.780  -71.668  51.867  1
315120  96.807  -71.688  51.842  1
315121  96.834  -71.707  51.817  1
315122  96.869  -71.713  51.791  1
315123  96.907  -71.713  51.761  1
315124  96.946  -71.713  51.728  1
315125  96.985  -71.712  51.690  1
315126  97.023  -71.712  51.651  1
315127  97.060  -71.713  51.613  1
315128  97.093  -71.716  51.576  1
315129  97.130  -71.724  51.544  1
315130  97.170  -71.735  51.515  1
315131  97.210  -71.747  51.484  1
315132  97.249  -71.758  51.453  1
315133  97.289  -71.770  51.422  1
315134  97.328  -71.779  51.391  1
315135  97.363  -71.784  51.360  1
315136  97.398  -71.789  51.329  1
315137  97.434  -71.794  51.298  1
315138  97.469  -71.798  51.263  1
315139  97.504  -71.803  51.230  1
315140  97.549  -71.814  51.197  1
315141  97.608  -71.835  51.165  1
315142  97.636  -71.837  51.134  1
315143  97.663  -71.838  51.106  1
315144  97.691  -71.841  51.075  1
315145  97.718  -71.842  51.039  1
315146  97.746  -71.845  50.999  1
315147  97.773  -71.846  50.956  1
315148  97.801  -71.848  50.912  1
315149  97.828  -71.850  50.868  1
315150  97.855  -71.852  50.827  1
315151  97.880  -71.853  50.788  1
315152  97.906  -71.856  50.747  1
315153  97.932  -71.864  50.705  1
315154  97.959  -71.873  50.661  1
315155  97.987  -71.881  50.618  1
315156  98.013  -71.889  50.574  1
315157  98.040  -71.898  50.527  1
315158  98.067  -71.906  50.477  1
315159  98.094  -71.915  50.426  1
315160  98.122  -71.923  50.376  1
315161  98.149  -71.931  50.326  1
315162  98.177  -71.939  50.277  1
315163  98.213  -71.954  50.227  1
315164  98.253  -71.974  50.175  1
315165  98.294  -71.995  50.123  1
315166  98.335  -72.015  50.071  1
315167  98.376  -72.039  50.022  1
315168  98.408  -72.040  49.974  1
315169  98.440  -72.042  49.924  1
315170  98.472  -72.043  49.873  1
315171  98.508  -72.045  49.820  1
315172  98.545  -72.048  49.766  1
315173  98.582  -72.050  49.714  1
315174  98.619  -72.052  49.662  1
315175  98.656  -72.055  49.610  1
315176  98.693  -72.057  49.558  1
315177  98.730  -72.059  49.504  1
315178  98.774  -72.073  49.450  1
315179  98.817  -72.088  49.395  1
315180  98.861  -72.103  49.343  1
315181  98.906  -72.118  49.292  1
315182  98.949  -72.133  49.242  1
315183  98.991  -72.149  49.191  1
315184  99.023  -72.162  49.140  1
315185  99.046  -72.179  49.089  1
315186  99.068  -72.196  49.039  1
315187  99.090  -72.212  48.988  1
315188  99.113  -72.229  48.937  1
315189  99.135  -72.246  48.883  1
315190  99.158  -72.262  48.831  1
315191  99.180  -72.279  48.781  1
315192  99.202  -72.296  48.731  1
315193  99.225  -72.312  48.681  1
315194  99.247  -72.329  48.632  1
315195  99.269  -72.346  48.583  1
315196  99.292  -72.362  48.535  1
315197  99.324  -72.377  48.488  1
315198  99.370  -72.389  48.441  1
315199  99.418  -72.400  48.394  1
315200  99.465  -72.412  48.348  1
315201  99.511  -72.424  48.301  1
315202  99.558  -72.436  48.255  1
315203  99.605  -72.447  48.209  1
315204  99.652  -72.459  48.163  1
315205  99.699  -72.472  48.118  1
315206  99.725  -72.483  48.072  1
315207  99.752  -72.495  48.026  1
315208  99.779  -72.507  47.979  1
315209  99.806  -72.519  47.934  1
315210  99.833  -72.531  47.889  1
315211  99.867  -72.540  47.845  1
315212  99.907  -72.547  47.802  1
315213  99.946  -72.555  47.758  1
315214  99.976  -72.578  47.714  1
315215  99.996  -72.613  47.671  1
315216  100.017  -72.650  47.628  1
315217  100.037  -72.685  47.587  1
315218  100.056  -72.717  47.545  1
315219  100.081  -72.733  47.502  1
315220  100.113  -72.735  47.460  1
315221  100.143  -72.724  47.418  1
315222  100.174  -72.714  47.377  1
315223  100.204  -72.704  47.338  1
315224  100.234  -72.694  47.299  1
315225  100.266  -72.685  47.260  1
315226  100.298  -72.675  47.221  1
315227  100.329  -72.666  47.182  1
315228  100.361  -72.657  47.143  1
315229  100.393  -72.648  47.104  1
315230  100.424  -72.639  47.068  1
315231  100.456  -72.629  47.030  1
315232  100.487  -72.620  46.993  1
315233  100.519  -72.619  46.956  1
315234  100.550  -72.623  46.918  1
315235  100.584  -72.634  46.883  1
315236  100.624  -72.657  46.847  1
315237  100.663  -72.680  46.810  1
315238  100.702  -72.703  46.771  1
315239  100.742  -72.725  46.732  1
315240  100.780  -72.749  46.691  1
315241  100.819  -72.772  46.650  1
315242  100.854  -72.795  46.608  1
315243  100.883  -72.807  46.566  1
315244  100.912  -72.819  46.525  1
315245  100.940  -72.832  46.485  1
315246  100.970  -72.844  46.445  1
315247  100.998  -72.857  46.404  1
315248  101.027  -72.869  46.364  1
315249  101.056  -72.882  46.326  1
315250  101.085  -72.894  46.290  1
315251  101.114  -72.906  46.253  1
315252  101.142  -72.919  46.217  1
315253  101.174  -72.930  46.180  1
315254  101.216  -72.939  46.144  1
315255  101.259  -72.949  46.108  1
315256  101.303  -72.955  46.073  1
315257  101.353  -72.934  46.038  1
315258  101.403  -72.913  46.003  1
315259  101.442  -72.901  45.969  1
315260  101.460  -72.907  45.933  1
315261  101.478  -72.913  45.898  1
315262  101.495  -72.918  45.862  1
315263  101.513  -72.924  45.828  1
315264  101.531  -72.929  45.792  1
315265  101.549  -72.935  45.757  1
315266  101.570  -72.948  45.720  1
315267  101.599  -72.975  45.682  1
315268  101.627  -73.001  45.644  1
315269  101.656  -73.029  45.606  1
315270  101.684  -73.055  45.568  1
315271  101.713  -73.079  45.529  1
315272  101.753  -73.092  45.490  1
315273  101.793  -73.106  45.452  1
315274  101.833  -73.119  45.414  1
315275  101.873  -73.132  45.376  1
315276  101.913  -73.145  45.339  1
315277  101.953  -73.158  45.302  1
315278  101.994  -73.170  45.266  1
315279  102.037  -73.180  45.230  1
315280  102.080  -73.189  45.195  1
315281  102.123  -73.199  45.160  1
315772  95.083  -71.191  52.462  1
315773  95.109  -71.205  52.447  1
315774  95.136  -71.220  52.432  1
315775  95.162  -71.234  52.417  1
315776  95.188  -71.249  52.402  1
315777  95.171  -71.274  52.386  1
315778  95.142  -71.303  52.372  1
315779  95.128  -71.329  52.358  1
315780  95.165  -71.346  52.345  1
315781  95.201  -71.365  52.333  1
315782  95.239  -71.383  52.320  1
315783  95.275  -71.400  52.307  1
315784  95.313  -71.419  52.294  1
315785  95.349  -71.437  52.282  1
315786  95.376  -71.436  52.270  1
315787  95.390  -71.412  52.258  1
315788  95.423  -71.411  52.246  1
315789  95.476  -71.434  52.233  1
315790  95.525  -71.444  52.220  1
315791  95.573  -71.454  52.208  1
315792  95.621  -71.463  52.196  1
315793  95.654  -71.473  52.184  1
315794  95.681  -71.482  52.172  1
315795  95.708  -71.492  52.162  1
315796  95.736  -71.502  52.152  1
315797  95.763  -71.511  52.144  1
315798  95.796  -71.516  52.138  1
315799  95.836  -71.513  52.134  1
315800  95.877  -71.511  52.132  1
315801  95.918  -71.509  52.132  1
315802  95.959  -71.506  52.137  1
315803  96.008  -71.511  52.142  1
315804  96.063  -71.517  52.148  1
315805  96.122  -71.510  52.157  1
315806  96.182  -71.503  52.161  1
315807  96.241  -71.496  52.161  1
315808  96.301  -71.489  52.158  1
315809  96.360  -71.482  52.153  1
315810  96.419  -71.475  52.142  1
315811  96.493  -71.472  52.127  1
315812  96.528  -71.488  52.109  1
315813  96.563  -71.505  52.085  1
315814  96.598  -71.521  52.057  1
315815  96.633  -71.538  52.026  1
315816  96.668  -71.554  51.993  1
315817  96.703  -71.571  51.960  1
315818  96.738  -71.587  51.933  1
315819  96.766  -71.606  51.903  1
315820  96.794  -71.625  51.875  1
315821  96.821  -71.645  51.849  1
315822  96.848  -71.665  51.825  1
315823  96.883  -71.670  51.799  1
315824  96.922  -71.670  51.770  1
315825  96.961  -71.669  51.738  1
315826  97.000  -71.669  51.699  1
315827  97.035  -71.670  51.660  1
315828  97.068  -71.673  51.622  1
315829  97.101  -71.675  51.584  1
315830  97.140  -71.686  51.551  1
315831  97.180  -71.697  51.520  1
315832  97.220  -71.709  51.488  1
315833  97.259  -71.721  51.455  1
315834  97.299  -71.732  51.423  1
315835  97.339  -71.744  51.391  1
315836  97.379  -71.755  51.360  1
315837  97.419  -71.766  51.329  1
315838  97.454  -71.771  51.299  1
315839  97.490  -71.776  51.265  1
315840  97.525  -71.781  51.231  1
315841  97.560  -71.785  51.198  1
315842  97.610  -71.800  51.165  1
315843  97.652  -71.810  51.133  1
315844  97.679  -71.812  51.103  1
315845  97.707  -71.814  51.071  1
315846  97.734  -71.816  51.035  1
315847  97.761  -71.818  50.997  1
315848  97.789  -71.820  50.955  1
315849  97.816  -71.822  50.913  1
315850  97.842  -71.823  50.872  1
315851  97.867  -71.824  50.835  1
315852  97.892  -71.826  50.797  1
315853  97.917  -71.827  50.757  1
315854  97.944  -71.835  50.715  1
315855  97.971  -71.844  50.671  1
315856  97.998  -71.852  50.626  1
315857  98.025  -71.860  50.579  1
315858  98.052  -71.869  50.530  1
315859  98.079  -71.877  50.479  1
315860  98.105  -71.885  50.429  1
315861  98.133  -71.894  50.381  1
315862  98.161  -71.901  50.333  1
315863  98.189  -71.909  50.284  1
315864  98.221  -71.920  50.235  1
315865  98.262  -71.941  50.184  1
315866  98.302  -71.961  50.134  1
315867  98.343  -71.982  50.085  1
315868  98.384  -72.006  50.035  1
315869  98.420  -72.017  49.988  1
315870  98.452  -72.018  49.938  1
315871  98.484  -72.020  49.886  1
315872  98.516  -72.021  49.832  1
315873  98.548  -72.023  49.779  1
315874  98.584  -72.025  49.727  1
315875  98.621  -72.027  49.676  1
315876  98.658  -72.030  49.624  1
315877  98.696  -72.032  49.571  1
315878  98.732  -72.034  49.516  1
315879  98.771  -72.039  49.460  1
315880  98.815  -72.055  49.404  1
315881  98.859  -72.070  49.351  1
315882  98.903  -72.086  49.300  1
315883  98.947  -72.101  49.248  1
315884  98.984  -72.114  49.196  1
315885  99.018  -72.128  49.143  1
315886  99.052  -72.142  49.091  1
315887  99.080  -72.156  49.040  1
315888  99.102  -72.173  48.989  1
315889  99.125  -72.189  48.936  1
315890  99.147  -72.206  48.883  1
315891  99.169  -72.223  48.831  1
315892  99.192  -72.240  48.781  1
315893  99.214  -72.256  48.730  1
315894  99.236  -72.273  48.681  1
315895  99.259  -72.290  48.632  1
315896  99.281  -72.306  48.584  1
315897  99.303  -72.323  48.536  1
315898  99.338  -72.337  48.490  1
315899  99.384  -72.349  48.442  1
315900  99.431  -72.361  48.395  1
315901  99.478  -72.373  48.349  1
315902  99.525  -72.384  48.302  1
315903  99.572  -72.396  48.255  1
315904  99.619  -72.408  48.209  1
315905  99.665  -72.420  48.163  1
315906  99.713  -72.431  48.118  1
315907  99.759  -72.443  48.073  1
315908  99.786  -72.456  48.027  1
315909  99.812  -72.467  47.981  1
315910  99.839  -72.479  47.936  1
315911  99.866  -72.491  47.891  1
315912  99.893  -72.503  47.847  1
315913  99.920  -72.515  47.804  1
315914  99.959  -72.522  47.760  1
315915  99.993  -72.537  47.716  1
315916  100.014  -72.573  47.673  1
315917  100.034  -72.608  47.631  1
315918  100.053  -72.639  47.590  1
315919  100.074  -72.663  47.548  1
315920  100.100  -72.678  47.506  1
315921  100.130  -72.698  47.464  1
315922  100.161  -72.692  47.423  1
315923  100.191  -72.681  47.382  1
315924  100.221  -72.672  47.342  1
315925  100.252  -72.661  47.304  1
315926  100.282  -72.651  47.266  1
315927  100.313  -72.641  47.227  1
315928  100.343  -72.631  47.189  1
315929  100.374  -72.621  47.151  1
315930  100.404  -72.610  47.114  1
315931  100.435  -72.601  47.078  1
315932  100.467  -72.592  47.042  1
315933  100.499  -72.583  47.006  1
315934  100.530  -72.574  46.970  1
315935  100.562  -72.574  46.935  1
315936  100.598  -72.590  46.895  1
315937  100.637  -72.613  46.858  1
315938  100.677  -72.635  46.822  1
315939  100.714  -72.660  46.784  1
315940  100.751  -72.685  46.745  1
315941  100.788  -72.710  46.704  1
315942  100.826  -72.735  46.661  1
315943  100.863  -72.760  46.618  1
315944  100.895  -72.778  46.576  1
315945  100.924  -72.790  46.534  1
315946  100.953  -72.803  46.494  1
315947  100.981  -72.815  46.454  1
315948  101.010  -72.827  46.413  1
315949  101.039  -72.839  46.372  1
315950  101.068  -72.852  46.334  1
315951  101.097  -72.864  46.297  1
315952  101.125  -72.876  46.259  1
315953  101.156  -72.888  46.223  1
315954  101.198  -72.898  46.186  1
315955  101.242  -72.907  46.150  1
315956  101.284  -72.916  46.114  1
315957  101.327  -72.926  46.078  1
315958  101.372  -72.929  46.043  1
315959  101.421  -72.908  46.007  1
315960  101.459  -72.897  45.972  1
315961  101.477  -72.903  45.936  1
315962  101.495  -72.908  45.901  1
315963  101.513  -72.914  45.865  1
315964  101.531  -72.920  45.830  1
315965  101.548  -72.925  45.794  1
315966  101.566  -72.931  45.758  1
315967  101.584  -72.936  45.722  1
315968  101.605  -72.948  45.684  1
315969  101.633  -72.975  45.646  1
315970  101.662  -73.002  45.608  1
315971  101.690  -73.028  45.570  1
315972  101.726  -73.046  45.530  1
315973  101.766  -73.059  45.492  1
315974  101.806  -73.072  45.454  1
315975  101.846  -73.086  45.416  1
315976  101.886  -73.098  45.378  1
315977  101.926  -73.111  45.341  1
315978  101.966  -73.125  45.305  1
315979  102.007  -73.136  45.269  1
315980  102.050  -73.146  45.233  1
315981  102.093  -73.155  45.198  1
315982  102.135  -73.165  45.163  1
316473  95.081  -71.146  52.463  1
316474  95.107  -71.160  52.447  1
316475  95.134  -71.174  52.433  1
316476  95.160  -71.189  52.418  1
316477  95.176  -71.206  52.403  1
316478  95.148  -71.234  52.389  1
316479  95.120  -71.262  52.376  1
316480  95.143  -71.283  52.363  1
316481  95.180  -71.301  52.350  1
316482  95.216  -71.319  52.337  1
316483  95.254  -71.337  52.325  1
316484  95.290  -71.355  52.313  1
316485  95.327  -71.373  52.300  1
316486  95.365  -71.391  52.288  1
316487  95.401  -71.409  52.276  1
316488  95.418  -71.390  52.264  1
316489  95.432  -71.365  52.251  1
316490  95.470  -71.370  52.240  1
316491  95.521  -71.390  52.227  1
316492  95.569  -71.399  52.215  1
316493  95.618  -71.409  52.204  1
316494  95.656  -71.418  52.192  1
316495  95.683  -71.428  52.180  1
316496  95.710  -71.437  52.169  1
316497  95.738  -71.447  52.160  1
316498  95.765  -71.456  52.152  1
316499  95.800  -71.459  52.147  1
316500  95.841  -71.456  52.143  1
316501  95.882  -71.454  52.140  1
316502  95.922  -71.452  52.140  1
316503  95.963  -71.449  52.144  1
316504  96.017  -71.458  52.148  1
316505  96.072  -71.468  52.155  1
316506  96.129  -71.469  52.164  1
316507  96.188  -71.462  52.168  1
316508  96.248  -71.454  52.169  1
316509  96.307  -71.447  52.168  1
316510  96.366  -71.440  52.163  1
316511  96.426  -71.434  52.151  1
316512  96.499  -71.433  52.136  1
316513  96.534  -71.449  52.118  1
316514  96.570  -71.466  52.095  1
316515  96.604  -71.482  52.068  1
316516  96.640  -71.498  52.039  1
316517  96.674  -71.515  52.007  1
316518  96.710  -71.531  51.974  1
316519  96.744  -71.548  51.944  1
316520  96.780  -71.564  51.914  1
316521  96.808  -71.583  51.884  1
316522  96.835  -71.603  51.857  1
316523  96.862  -71.622  51.832  1
316524  96.898  -71.628  51.804  1
316525  96.937  -71.627  51.776  1
316526  96.975  -71.627  51.745  1
316527  97.011  -71.628  51.707  1
316528  97.043  -71.631  51.669  1
316529  97.077  -71.634  51.631  1
316530  97.110  -71.638  51.593  1
316531  97.150  -71.649  51.559  1
316532  97.190  -71.660  51.528  1
316533  97.230  -71.672  51.494  1
316534  97.270  -71.683  51.459  1
316535  97.309  -71.694  51.426  1
316536  97.349  -71.706  51.393  1
316537  97.389  -71.717  51.363  1
316538  97.429  -71.729  51.333  1
316539  97.469  -71.740  51.303  1
316540  97.509  -71.751  51.269  1
316541  97.545  -71.758  51.235  1
316542  97.580  -71.763  51.201  1
316543  97.615  -71.768  51.167  1
316544  97.667  -71.784  51.134  1
316545  97.695  -71.785  51.102  1
316546  97.722  -71.788  51.068  1
316547  97.750  -71.789  51.032  1
316548  97.778  -71.791  50.994  1
316549  97.803  -71.793  50.954  1
316550  97.828  -71.794  50.915  1
316551  97.854  -71.795  50.878  1
316552  97.878  -71.797  50.844  1
316553  97.903  -71.798  50.807  1
316554  97.929  -71.799  50.767  1
316555  97.955  -71.807  50.725  1
316556  97.982  -71.815  50.680  1
316557  98.009  -71.823  50.633  1
316558  98.036  -71.832  50.584  1
316559  98.063  -71.840  50.534  1
316560  98.090  -71.848  50.485  1
316561  98.117  -71.857  50.438  1
316562  98.145  -71.864  50.393  1
316563  98.173  -71.873  50.347  1
316564  98.201  -71.880  50.299  1
316565  98.229  -71.888  50.250  1
316566  98.270  -71.908  50.199  1
316567  98.310  -71.929  50.150  1
316568  98.351  -71.949  50.100  1
316569  98.392  -71.973  50.051  1
316570  98.432  -71.993  50.002  1
316571  98.464  -71.995  49.951  1
316572  98.496  -71.996  49.897  1
316573  98.528  -71.998  49.842  1
316574  98.560  -71.999  49.792  1
316575  98.592  -72.001  49.741  1
316576  98.624  -72.002  49.689  1
316577  98.660  -72.005  49.637  1
316578  98.698  -72.007  49.583  1
316579  98.734  -72.009  49.527  1
316580  98.772  -72.011  49.471  1
316581  98.813  -72.022  49.415  1
316582  98.857  -72.037  49.360  1
316583  98.901  -72.052  49.308  1
316584  98.943  -72.067  49.255  1
316585  98.977  -72.081  49.201  1
316586  99.011  -72.094  49.147  1
316587  99.045  -72.108  49.093  1
316588  99.079  -72.121  49.041  1
316589  99.113  -72.134  48.989  1
316590  99.137  -72.151  48.935  1
316591  99.159  -72.168  48.883  1
316592  99.181  -72.184  48.831  1
316593  99.204  -72.201  48.781  1
316594  99.226  -72.218  48.730  1
316595  99.248  -72.234  48.681  1
316596  99.271  -72.251  48.632  1
316597  99.293  -72.268  48.584  1
316598  99.315  -72.284  48.536  1
316599  99.352  -72.298  48.490  1
316600  99.399  -72.309  48.444  1
316601  99.445  -72.321  48.397  1
316602  99.492  -72.333  48.350  1
316603  99.539  -72.345  48.302  1
316604  99.586  -72.356  48.255  1
316605  99.633  -72.368  48.208  1
316606  99.680  -72.381  48.163  1
316607  99.726  -72.392  48.118  1
316608  99.773  -72.404  48.073  1
316609  99.820  -72.415  48.029  1
316610  99.846  -72.428  47.984  1
316611  99.873  -72.440  47.937  1
316612  99.900  -72.451  47.894  1
316613  99.926  -72.463  47.850  1
316614  99.953  -72.475  47.806  1
316615  99.980  -72.487  47.762  1
316616  100.010  -72.498  47.719  1
316617  100.031  -72.530  47.676  1
316618  100.050  -72.561  47.634  1
316619  100.069  -72.592  47.593  1
316620  100.093  -72.609  47.551  1
316621  100.118  -72.625  47.510  1
316622  100.142  -72.640  47.469  1
316623  100.178  -72.660  47.428  1
316624  100.209  -72.649  47.387  1
316625  100.239  -72.639  47.348  1
316626  100.270  -72.628  47.310  1
316627  100.300  -72.619  47.272  1
316628  100.330  -72.609  47.234  1
316629  100.361  -72.598  47.197  1
316630  100.391  -72.588  47.160  1
316631  100.422  -72.578  47.124  1
316632  100.452  -72.568  47.088  1
316633  100.482  -72.558  47.054  1
316634  100.513  -72.547  47.020  1
316635  100.543  -72.537  46.985  1
316636  100.574  -72.527  46.951  1
316637  100.609  -72.547  46.911  1
316638  100.646  -72.572  46.872  1
316639  100.684  -72.598  46.834  1
316640  100.721  -72.623  46.795  1
316641  100.758  -72.648  46.756  1
316642  100.795  -72.673  46.715  1
316643  100.833  -72.698  46.672  1
316644  100.870  -72.723  46.629  1
316645  100.907  -72.748  46.587  1
316646  100.936  -72.760  46.545  1
316647  100.965  -72.773  46.504  1
316648  100.993  -72.785  46.464  1
316649  101.022  -72.797  46.422  1
316650  101.051  -72.810  46.382  1
316651  101.080  -72.823  46.343  1
316652  101.109  -72.835  46.305  1
316653  101.138  -72.847  46.267  1
316654  101.181  -72.857  46.230  1
316655  101.223  -72.866  46.193  1
316656  101.266  -72.875  46.156  1
316657  101.309  -72.884  46.120  1
316658  101.352  -72.893  46.084  1
316659  101.395  -72.903  46.048  1
316660  101.440  -72.902  46.012  1
316661  101.476  -72.893  45.976  1
316662  101.494  -72.898  45.940  1
316663  101.512  -72.904  45.904  1
316664  101.530  -72.910  45.868  1
316665  101.548  -72.915  45.832  1
316666  101.565  -72.921  45.797  1
316667  101.583  -72.926  45.760  1
316668  101.601  -72.932  45.724  1
316669  101.619  -72.938  45.687  1
316670  101.639  -72.949  45.648  1
316671  101.668  -72.976  45.611  1
316672  101.698  -72.999  45.572  1
316673  101.739  -73.012  45.532  1
316674  101.778  -73.026  45.495  1
316675  101.819  -73.039  45.456  1
316676  101.858  -73.051  45.419  1
316677  101.899  -73.065  45.381  1
316678  101.939  -73.078  45.344  1
316679  101.979  -73.091  45.308  1
316680  102.020  -73.102  45.272  1
316681  102.063  -73.112  45.237  1
316682  102.106  -73.122  45.202  1
316683  102.144  -73.128  45.167  1
317174  95.079  -71.101  52.465  1
317175  95.106  -71.115  52.449  1
317176  95.132  -71.130  52.435  1
317177  95.158  -71.144  52.421  1
317178  95.154  -71.166  52.406  1
317179  95.126  -71.194  52.393  1
317180  95.121  -71.219  52.380  1
317181  95.158  -71.237  52.367  1
317182  95.195  -71.255  52.355  1
317183  95.232  -71.273  52.342  1
317184  95.269  -71.291  52.331  1
317185  95.306  -71.309  52.319  1
317186  95.342  -71.327  52.306  1
317187  95.380  -71.345  52.295  1
317188  95.416  -71.363  52.282  1
317189  95.446  -71.368  52.270  1
317190  95.460  -71.343  52.258  1
317191  95.475  -71.320  52.246  1
317192  95.516  -71.328  52.235  1
317193  95.566  -71.344  52.223  1
317194  95.614  -71.353  52.212  1
317195  95.659  -71.363  52.199  1
317196  95.686  -71.373  52.188  1
317197  95.713  -71.382  52.178  1
317198  95.741  -71.392  52.169  1
317199  95.770  -71.400  52.161  1
317200  95.805  -71.403  52.155  1
317201  95.846  -71.400  52.150  1
317202  95.887  -71.397  52.147  1
317203  95.927  -71.395  52.148  1
317204  95.972  -71.396  52.149  1
317205  96.027  -71.406  52.152  1
317206  96.082  -71.415  52.158  1
317207  96.136  -71.425  52.165  1
317208  96.195  -71.419  52.168  1
317209  96.254  -71.412  52.169  1
317210  96.314  -71.406  52.168  1
317211  96.373  -71.399  52.164  1
317212  96.432  -71.392  52.154  1
317213  96.506  -71.393  52.141  1
317214  96.541  -71.409  52.124  1
317215  96.576  -71.426  52.104  1
317216  96.611  -71.443  52.079  1
317217  96.646  -71.459  52.052  1
317218  96.681  -71.475  52.023  1
317219  96.716  -71.492  51.992  1
317220  96.751  -71.509  51.964  1
317221  96.786  -71.525  51.932  1
317222  96.821  -71.541  51.900  1
317223  96.849  -71.561  51.869  1
317224  96.876  -71.580  51.840  1
317225  96.912  -71.585  51.812  1
317226  96.951  -71.584  51.784  1
317227  96.986  -71.585  51.754  1
317228  97.019  -71.588  51.719  1
317229  97.052  -71.591  51.682  1
317230  97.085  -71.594  51.643  1
317231  97.120  -71.600  51.606  1
317232  97.160  -71.612  51.571  1
317233  97.200  -71.623  51.539  1
317234  97.240  -71.635  51.505  1
317235  97.280  -71.646  51.469  1
317236  97.319  -71.657  51.433  1
317237  97.359  -71.669  51.401  1
317238  97.399  -71.680  51.370  1
317239  97.439  -71.691  51.341  1
317240  97.479  -71.703  51.311  1
317241  97.519  -71.714  51.277  1
317242  97.559  -71.726  51.242  1
317243  97.598  -71.737  51.207  1
317244  97.636  -71.745  51.173  1
317245  97.671  -71.751  51.139  1
317246  97.711  -71.759  51.106  1
317247  97.738  -71.761  51.071  1
317248  97.765  -71.763  51.034  1
317249  97.790  -71.764  50.995  1
317250  97.815  -71.765  50.958  1
317251  97.840  -71.766  50.921  1
317252  97.865  -71.768  50.886  1
317253  97.890  -71.769  50.851  1
317254  97.915  -71.770  50.815  1
317255  97.940  -71.771  50.776  1
317256  97.966  -71.778  50.734  1
317257  97.994  -71.786  50.691  1
317258  98.020  -71.795  50.644  1
317259  98.048  -71.803  50.595  1
317260  98.075  -71.811  50.545  1
317261  98.101  -71.820  50.496  1
317262  98.129  -71.828  50.453  1
317263  98.157  -71.835  50.409  1
317264  98.184  -71.843  50.364  1
317265  98.213  -71.851  50.317  1
317266  98.240  -71.859  50.270  1
317267  98.278  -71.876  50.220  1
317268  98.318  -71.896  50.169  1
317269  98.359  -71.917  50.117  1
317270  98.401  -71.940  50.064  1
317271  98.442  -71.964  50.011  1
317272  98.476  -71.971  49.959  1
317273  98.508  -71.973  49.907  1
317274  98.540  -71.974  49.855  1
317275  98.572  -71.976  49.805  1
317276  98.604  -71.977  49.753  1
317277  98.636  -71.979  49.700  1
317278  98.668  -71.980  49.647  1
317279  98.700  -71.982  49.591  1
317280  98.736  -71.984  49.535  1
317281  98.774  -71.986  49.479  1
317282  98.811  -71.989  49.423  1
317283  98.855  -72.004  49.366  1
317284  98.899  -72.019  49.312  1
317285  98.936  -72.033  49.259  1
317286  98.971  -72.047  49.205  1
317287  99.004  -72.060  49.150  1
317288  99.038  -72.073  49.096  1
317289  99.072  -72.087  49.042  1
317290  99.106  -72.101  48.989  1
317291  99.139  -72.114  48.935  1
317292  99.170  -72.128  48.883  1
317293  99.193  -72.145  48.832  1
317294  99.215  -72.161  48.781  1
317295  99.237  -72.178  48.730  1
317296  99.260  -72.195  48.682  1
317297  99.282  -72.211  48.633  1
317298  99.305  -72.228  48.584  1
317299  99.327  -72.245  48.536  1
317300  99.365  -72.258  48.490  1
317301  99.412  -72.270  48.444  1
317302  99.459  -72.282  48.397  1
317303  99.506  -72.293  48.350  1
317304  99.553  -72.305  48.302  1
317305  99.600  -72.317  48.255  1
317306  99.647  -72.329  48.209  1
317307  99.694  -72.340  48.164  1
317308  99.740  -72.352  48.119  1
317309  99.787  -72.364  48.075  1
317310  99.834  -72.376  48.030  1
317311  99.879  -72.387  47.985  1
317312  99.907  -72.399  47.939  1
317313  99.933  -72.412  47.895  1
317314  99.960  -72.424  47.852  1
317315  99.981  -72.437  47.809  1
317316  99.999  -72.449  47.765  1
317317  100.027  -72.453  47.723  1
317318  100.046  -72.483  47.680  1
317319  100.065  -72.514  47.638  1
317320  100.086  -72.539  47.597  1
317321  100.112  -72.555  47.555  1
317322  100.136  -72.570  47.514  1
317323  100.161  -72.586  47.473  1
317324  100.192  -72.606  47.433  1
317325  100.226  -72.616  47.393  1
317326  100.257  -72.606  47.354  1
317327  100.287  -72.597  47.316  1
317328  100.318  -72.586  47.279  1
317329  100.348  -72.576  47.241  1
317330  100.378  -72.565  47.205  1
317331  100.409  -72.556  47.169  1
317332  100.439  -72.546  47.133  1
317333  100.470  -72.535  47.099  1
317334  100.500  -72.525  47.066  1
317335  100.530  -72.515  47.033  1
317336  100.561  -72.505  46.999  1
317337  100.592  -72.503  46.965  1
317338  100.624  -72.522  46.926  1
317339  100.656  -72.540  46.886  1
317340  100.691  -72.560  46.847  1
317341  100.728  -72.585  46.807  1
317342  100.765  -72.611  46.767  1
317343  100.802  -72.636  46.726  1
317344  100.839  -72.661  46.683  1
317345  100.876  -72.686  46.640  1
317346  100.914  -72.711  46.599  1
317347  100.948  -72.731  46.557  1
317348  100.977  -72.744  46.515  1
317349  101.005  -72.756  46.473  1
317350  101.034  -72.768  46.431  1
317351  101.063  -72.781  46.392  1
317352  101.092  -72.793  46.353  1
317353  101.121  -72.805  46.314  1
317354  101.162  -72.815  46.276  1
317355  101.205  -72.824  46.238  1
317356  101.249  -72.833  46.200  1
317357  101.291  -72.842  46.162  1
317358  101.334  -72.852  46.126  1
317359  101.377  -72.861  46.090  1
317360  101.420  -72.870  46.053  1
317361  101.463  -72.879  46.017  1
317362  101.494  -72.888  45.981  1
317363  101.512  -72.894  45.945  1
317364  101.529  -72.900  45.908  1
317365  101.547  -72.905  45.872  1
317366  101.565  -72.911  45.836  1
317367  101.583  -72.916  45.801  1
317368  101.600  -72.922  45.764  1
317369  101.618  -72.928  45.727  1
317370  101.636  -72.933  45.689  1
317371  101.653  -72.939  45.651  1
317372  101.674  -72.949  45.613  1
317373  101.711  -72.966  45.575  1
317374  101.751  -72.979  45.536  1
317375  101.792  -72.992  45.499  1
317376  101.831  -73.005  45.461  1
317377  101.872  -73.018  45.423  1
317378  101.911  -73.032  45.386  1
317379  101.951  -73.045  45.349  1
317380  101.991  -73.058  45.313  1
317381  102.033  -73.068  45.277  1
317382  102.077  -73.078  45.242  1
317383  102.119  -73.088  45.208  1
317873  95.025  -71.027  52.501  1
317874  95.051  -71.042  52.484  1
317875  95.077  -71.056  52.468  1
317876  95.104  -71.071  52.453  1
317877  95.130  -71.084  52.438  1
317878  95.157  -71.099  52.425  1
317879  95.132  -71.127  52.411  1
317880  95.104  -71.155  52.398  1
317881  95.136  -71.174  52.385  1
317882  95.173  -71.191  52.372  1
317883  95.210  -71.209  52.360  1
317884  95.247  -71.227  52.348  1
317885  95.283  -71.246  52.337  1
317886  95.321  -71.263  52.325  1
317887  95.357  -71.281  52.313  1
317888  95.395  -71.299  52.301  1
317889  95.431  -71.318  52.289  1
317890  95.468  -71.335  52.277  1
317891  95.488  -71.321  52.265  1
317892  95.502  -71.298  52.253  1
317893  95.517  -71.274  52.242  1
317894  95.562  -71.287  52.230  1
317895  95.611  -71.299  52.219  1
317896  95.659  -71.309  52.207  1
317897  95.688  -71.318  52.196  1
317898  95.716  -71.328  52.187  1
317899  95.743  -71.337  52.177  1
317900  95.775  -71.343  52.169  1
317901  95.810  -71.346  52.163  1
317902  95.851  -71.343  52.159  1
317903  95.892  -71.340  52.155  1
317904  95.933  -71.338  52.156  1
317905  95.982  -71.343  52.156  1
317906  96.036  -71.353  52.158  1
317907  96.091  -71.362  52.162  1
317908  96.146  -71.372  52.167  1
317909  96.201  -71.378  52.168  1
317910  96.261  -71.371  52.167  1
317911  96.320  -71.364  52.165  1
317912  96.379  -71.357  52.162  1
317913  96.439  -71.350  52.154  1
317914  96.512  -71.354  52.144  1
317915  96.547  -71.371  52.130  1
317916  96.583  -71.387  52.112  1
317917  96.617  -71.403  52.091  1
317918  96.653  -71.420  52.066  1
317919  96.687  -71.437  52.039  1
317920  96.723  -71.453  52.012  1
317921  96.757  -71.469  51.984  1
317922  96.793  -71.486  51.951  1
317923  96.827  -71.502  51.917  1
317924  96.863  -71.519  51.883  1
317925  96.890  -71.538  51.852  1
317926  96.927  -71.541  51.823  1
317927  96.962  -71.544  51.794  1
317928  96.995  -71.546  51.764  1
317929  97.027  -71.549  51.731  1
317930  97.061  -71.551  51.694  1
317931  97.093  -71.554  51.656  1
317932  97.131  -71.563  51.619  1
317933  97.170  -71.574  51.584  1
317934  97.210  -71.585  51.551  1
317935  97.250  -71.597  51.516  1
317936  97.290  -71.608  51.479  1
317937  97.329  -71.619  51.443  1
317938  97.369  -71.631  51.410  1
317939  97.409  -71.642  51.378  1
317940  97.449  -71.654  51.349  1
317941  97.489  -71.665  51.319  1
317942  97.529  -71.676  51.285  1
317943  97.569  -71.688  51.249  1
317944  97.608  -71.700  51.214  1
317945  97.648  -71.711  51.179  1
317946  97.688  -71.722  51.145  1
317947  97.727  -71.732  51.111  1
317948  97.751  -71.734  51.076  1
317949  97.777  -71.735  51.040  1
317950  97.802  -71.736  51.003  1
317951  97.827  -71.738  50.967  1
317952  97.852  -71.738  50.932  1
317953  97.877  -71.740  50.897  1
317954  97.902  -71.741  50.862  1
317955  97.927  -71.742  50.824  1
317956  97.952  -71.744  50.784  1
317957  97.978  -71.748  50.743  1
317958  98.005  -71.757  50.698  1
317959  98.032  -71.766  50.653  1
317960  98.059  -71.774  50.605  1
317961  98.086  -71.782  50.556  1
317962  98.113  -71.791  50.509  1
317963  98.141  -71.798  50.467  1
317964  98.168  -71.806  50.426  1
317965  98.197  -71.814  50.383  1
317966  98.224  -71.822  50.336  1
317967  98.252  -71.829  50.289  1
317968  98.286  -71.843  50.238  1
317969  98.326  -71.864  50.185  1
317970  98.367  -71.884  50.131  1
317971  98.409  -71.907  50.076  1
317972  98.450  -71.932  50.021  1
317973  98.488  -71.948  49.967  1
317974  98.520  -71.949  49.915  1
317975  98.552  -71.951  49.865  1
317976  98.584  -71.952  49.813  1
317977  98.616  -71.954  49.761  1
317978  98.648  -71.955  49.708  1
317979  98.680  -71.957  49.654  1
317980  98.712  -71.958  49.597  1
317981  98.744  -71.960  49.541  1
317982  98.776  -71.961  49.486  1
317983  98.813  -71.964  49.430  1
317984  98.853  -71.971  49.373  1
317985  98.896  -71.986  49.317  1
317986  98.930  -71.999  49.262  1
317987  98.963  -72.013  49.207  1
317988  98.997  -72.026  49.153  1
317989  99.031  -72.039  49.098  1
317990  99.065  -72.053  49.044  1
317991  99.099  -72.067  48.990  1
317992  99.133  -72.080  48.936  1
317993  99.166  -72.093  48.884  1
317994  99.200  -72.107  48.832  1
317995  99.227  -72.122  48.781  1
317996  99.250  -72.139  48.730  1
317997  99.272  -72.155  48.682  1
317998  99.294  -72.172  48.634  1
317999  99.316  -72.189  48.585  1
318000  99.339  -72.205  48.535  1
318001  99.379  -72.218  48.489  1
318002  99.426  -72.230  48.443  1
318003  99.473  -72.242  48.396  1
318004  99.520  -72.254  48.349  1
318005  99.567  -72.265  48.302  1
318006  99.614  -72.277  48.256  1
318007  99.660  -72.290  48.210  1
318008  99.707  -72.301  48.165  1
318009  99.754  -72.313  48.120  1
318010  99.801  -72.324  48.076  1
318011  99.848  -72.337  48.031  1
318012  99.895  -72.348  47.986  1
318013  99.930  -72.362  47.940  1
318014  99.947  -72.376  47.896  1
318015  99.964  -72.390  47.854  1
318016  99.986  -72.393  47.811  1
318017  100.010  -72.395  47.769  1
318018  100.043  -72.405  47.726  1
318019  100.062  -72.436  47.683  1
318020  100.081  -72.467  47.641  1
318021  100.105  -72.484  47.600  1
318022  100.130  -72.500  47.559  1
318023  100.154  -72.515  47.518  1
318024  100.179  -72.531  47.478  1
318025  100.205  -72.547  47.438  1
318026  100.242  -72.572  47.399  1
318027  100.274  -72.574  47.360  1
318028  100.304  -72.564  47.323  1
318029  100.335  -72.553  47.286  1
318030  100.365  -72.544  47.249  1
318031  100.396  -72.534  47.213  1
318032  100.426  -72.523  47.177  1
318033  100.457  -72.513  47.142  1
318034  100.487  -72.503  47.110  1
318035  100.517  -72.493  47.077  1
318036  100.548  -72.483  47.045  1
318037  100.578  -72.472  47.012  1
318038  100.610  -72.482  46.978  1
318039  100.642  -72.500  46.940  1
318040  100.675  -72.519  46.901  1
318041  100.707  -72.537  46.862  1
318042  100.739  -72.554  46.822  1
318043  100.772  -72.573  46.780  1
318044  100.809  -72.599  46.738  1
318045  100.846  -72.624  46.695  1
318046  100.884  -72.649  46.652  1
318047  100.921  -72.674  46.610  1
318048  100.958  -72.699  46.567  1
318049  100.988  -72.714  46.526  1
318050  101.018  -72.726  46.484  1
318051  101.046  -72.738  46.442  1
318052  101.075  -72.751  46.402  1
318053  101.104  -72.763  46.362  1
318054  101.145  -72.773  46.324  1
318055  101.188  -72.782  46.285  1
318056  101.231  -72.791  46.246  1
318057  101.273  -72.801  46.208  1
318058  101.316  -72.810  46.170  1
318059  101.359  -72.819  46.133  1
318060  101.400  -72.827  46.097  1
318061  101.439  -72.835  46.060  1
318062  101.478  -72.841  46.023  1
318063  101.513  -72.852  45.987  1
318064  101.533  -72.860  45.951  1
318065  101.550  -72.866  45.914  1
318066  101.568  -72.873  45.877  1
318067  101.586  -72.879  45.841  1
318068  101.604  -72.886  45.804  1
318069  101.621  -72.892  45.768  1
318070  101.639  -72.899  45.730  1
318071  101.656  -72.906  45.692  1
318072  101.674  -72.912  45.655  1
318073  101.692  -72.919  45.617  1
318074  101.724  -72.932  45.579  1
318075  101.764  -72.945  45.541  1
318076  101.804  -72.958  45.503  1
318077  101.844  -72.972  45.466  1
318078  101.884  -72.985  45.429  1
318079  101.924  -72.998  45.391  1
318080  101.964  -73.011  45.354  1
318081  102.004  -73.024  45.319  1
318082  102.046  -73.035  45.284  1
318083  102.090  -73.044  45.248  1
318084  102.132  -73.054  45.214  1
318571  94.944  -70.939  52.556  1
318572  94.970  -70.953  52.538  1
318573  94.996  -70.967  52.521  1
318574  95.023  -70.982  52.504  1
318575  95.049  -70.996  52.487  1
318576  95.075  -71.011  52.472  1
318577  95.102  -71.025  52.458  1
318578  95.128  -71.039  52.444  1
318579  95.137  -71.058  52.430  1
318580  95.110  -71.086  52.417  1
318581  95.114  -71.110  52.404  1
318582  95.151  -71.127  52.391  1
318583  95.188  -71.146  52.379  1
318584  95.225  -71.164  52.366  1
318585  95.262  -71.181  52.354  1
318586  95.299  -71.199  52.343  1
318587  95.336  -71.218  52.331  1
318588  95.373  -71.236  52.319  1
318589  95.409  -71.253  52.307  1
318590  95.447  -71.271  52.295  1
318591  95.483  -71.290  52.283  1
318592  95.516  -71.300  52.273  1
318593  95.531  -71.276  52.261  1
318594  95.545  -71.252  52.249  1
318595  95.559  -71.227  52.237  1
318596  95.607  -71.244  52.226  1
318597  95.656  -71.253  52.215  1
318598  95.691  -71.263  52.204  1
318599  95.719  -71.272  52.194  1
318600  95.746  -71.282  52.184  1
318601  95.780  -71.285  52.177  1
318602  95.815  -71.289  52.172  1
318603  95.855  -71.287  52.168  1
318604  95.896  -71.284  52.164  1
318605  95.937  -71.281  52.163  1
318606  95.991  -71.290  52.165  1
318607  96.046  -71.300  52.166  1
318608  96.101  -71.310  52.167  1
318609  96.156  -71.319  52.170  1
318610  96.210  -71.329  52.168  1
318611  96.267  -71.329  52.165  1
318612  96.327  -71.322  52.162  1
318613  96.386  -71.315  52.158  1
318614  96.445  -71.309  52.152  1
318615  96.519  -71.315  52.144  1
318616  96.554  -71.331  52.134  1
318617  96.589  -71.348  52.121  1
318618  96.624  -71.364  52.102  1
318619  96.659  -71.381  52.080  1
318620  96.694  -71.397  52.057  1
318621  96.729  -71.413  52.032  1
318622  96.764  -71.430  52.005  1
318623  96.799  -71.447  51.971  1
318624  96.834  -71.463  51.935  1
318625  96.869  -71.479  51.899  1
318626  96.904  -71.496  51.865  1
318627  96.937  -71.501  51.835  1
318628  96.970  -71.503  51.805  1
318629  97.003  -71.506  51.775  1
318630  97.036  -71.509  51.742  1
318631  97.069  -71.512  51.706  1
318632  97.102  -71.515  51.669  1
318633  97.141  -71.525  51.632  1
318634  97.180  -71.537  51.596  1
318635  97.220  -71.548  51.563  1
318636  97.260  -71.560  51.527  1
318637  97.300  -71.571  51.491  1
318638  97.339  -71.582  51.455  1
318639  97.379  -71.594  51.419  1
318640  97.419  -71.605  51.387  1
318641  97.459  -71.616  51.357  1
318642  97.499  -71.628  51.328  1
318643  97.539  -71.639  51.294  1
318644  97.579  -71.650  51.258  1
318645  97.618  -71.662  51.223  1
318646  97.655  -71.674  51.188  1
318647  97.690  -71.686  51.152  1
318648  97.726  -71.698  51.119  1
318649  97.762  -71.706  51.085  1
318650  97.788  -71.707  51.049  1
318651  97.813  -71.709  51.016  1
318652  97.839  -71.710  50.981  1
318653  97.864  -71.711  50.947  1
318654  97.888  -71.713  50.912  1
318655  97.914  -71.713  50.876  1
318656  97.939  -71.715  50.836  1
318657  97.964  -71.716  50.795  1
318658  97.990  -71.719  50.752  1
318659  98.016  -71.728  50.707  1
318660  98.043  -71.736  50.662  1
318661  98.070  -71.745  50.615  1
318662  98.097  -71.754  50.568  1
318663  98.125  -71.761  50.522  1
318664  98.152  -71.770  50.482  1
318665  98.180  -71.777  50.442  1
318666  98.208  -71.785  50.400  1
318667  98.236  -71.793  50.355  1
318668  98.264  -71.801  50.306  1
318669  98.294  -71.810  50.253  1
318670  98.335  -71.830  50.198  1
318671  98.375  -71.851  50.142  1
318672  98.417  -71.874  50.086  1
318673  98.458  -71.898  50.030  1
318674  98.500  -71.923  49.975  1
318675  98.532  -71.926  49.922  1
318676  98.564  -71.927  49.871  1
318677  98.596  -71.929  49.819  1
318678  98.628  -71.930  49.767  1
318679  98.660  -71.932  49.713  1
318680  98.692  -71.933  49.658  1
318681  98.724  -71.935  49.602  1
318682  98.756  -71.936  49.546  1
318683  98.788  -71.938  49.490  1
318684  98.820  -71.939  49.435  1
318685  98.852  -71.941  49.379  1
318686  98.889  -71.952  49.321  1
318687  98.923  -71.966  49.264  1
318688  98.956  -71.979  49.209  1
318689  98.991  -71.992  49.154  1
318690  99.024  -72.006  49.099  1
318691  99.058  -72.019  49.046  1
318692  99.092  -72.033  48.992  1
318693  99.126  -72.046  48.938  1
318694  99.160  -72.059  48.884  1
318695  99.194  -72.073  48.832  1
318696  99.227  -72.086  48.782  1
318697  99.261  -72.100  48.731  1
318698  99.284  -72.117  48.683  1
318699  99.306  -72.133  48.634  1
318700  99.328  -72.150  48.585  1
318701  99.351  -72.167  48.536  1
318702  99.393  -72.179  48.488  1
318703  99.440  -72.191  48.441  1
318704  99.487  -72.202  48.395  1
318705  99.534  -72.215  48.349  1
318706  99.581  -72.226  48.302  1
318707  99.628  -72.238  48.256  1
318708  99.675  -72.249  48.210  1
318709  99.721  -72.262  48.165  1
318710  99.766  -72.274  48.122  1
318711  99.807  -72.288  48.077  1
318712  99.849  -72.302  48.031  1
318713  99.890  -72.315  47.986  1
318714  99.929  -72.329  47.941  1
318715  99.949  -72.338  47.899  1
318716  99.973  -72.339  47.856  1
318717  99.997  -72.340  47.814  1
318718  100.021  -72.342  47.771  1
318719  100.059  -72.358  47.729  1
318720  100.078  -72.389  47.686  1
318721  100.099  -72.415  47.644  1
318722  100.124  -72.431  47.604  1
318723  100.148  -72.446  47.563  1
318724  100.173  -72.462  47.522  1
318725  100.198  -72.477  47.482  1
318726  100.222  -72.493  47.441  1
318727  100.254  -72.513  47.403  1
318728  100.291  -72.537  47.365  1
318729  100.322  -72.531  47.329  1
318730  100.352  -72.521  47.293  1
318731  100.382  -72.511  47.256  1
318732  100.413  -72.501  47.220  1
318733  100.443  -72.490  47.186  1
318734  100.474  -72.481  47.152  1
318735  100.504  -72.470  47.121  1
318736  100.535  -72.460  47.091  1
318737  100.565  -72.450  47.059  1
318738  100.596  -72.443  47.026  1
318739  100.628  -72.462  46.991  1
318740  100.661  -72.479  46.954  1
318741  100.693  -72.497  46.915  1
318742  100.725  -72.515  46.876  1
318743  100.757  -72.534  46.836  1
318744  100.789  -72.551  46.794  1
318745  100.822  -72.569  46.752  1
318746  100.854  -72.587  46.709  1
318747  100.890  -72.612  46.665  1
318748  100.927  -72.637  46.623  1
318749  100.965  -72.662  46.580  1
318750  101.000  -72.685  46.537  1
318751  101.029  -72.697  46.495  1
318752  101.058  -72.709  46.453  1
318753  101.087  -72.722  46.411  1
318754  101.127  -72.732  46.372  1
318755  101.170  -72.741  46.333  1
318756  101.213  -72.750  46.294  1
318757  101.256  -72.759  46.255  1
318758  101.296  -72.767  46.216  1
318759  101.335  -72.775  46.178  1
318760  101.375  -72.782  46.140  1
318761  101.413  -72.789  46.104  1
318762  101.452  -72.796  46.067  1
318763  101.491  -72.803  46.030  1
318764  101.526  -72.813  45.993  1
318765  101.554  -72.826  45.956  1
318766  101.572  -72.832  45.919  1
318767  101.590  -72.838  45.882  1
318768  101.607  -72.845  45.845  1
318769  101.625  -72.851  45.808  1
318770  101.642  -72.858  45.771  1
318771  101.660  -72.865  45.734  1
318772  101.678  -72.871  45.696  1
318773  101.696  -72.878  45.659  1
318774  101.712  -72.885  45.621  1
318775  101.737  -72.898  45.583  1
318776  101.777  -72.912  45.545  1
318777  101.817  -72.925  45.507  1
318778  101.857  -72.938  45.472  1
318779  101.897  -72.951  45.434  1
318780  101.937  -72.964  45.397  1
318781  101.977  -72.977  45.361  1
318782  102.017  -72.991  45.326  1
318783  102.060  -73.001  45.291  1
318784  102.103  -73.010  45.256  1
318785  102.142  -73.017  45.222  1
319269  94.884  -70.908  52.612  1
319270  94.903  -70.902  52.592  1
319271  94.922  -70.897  52.574  1
319272  94.942  -70.894  52.558  1
319273  94.968  -70.908  52.540  1
319274  94.994  -70.923  52.524  1
319275  95.021  -70.937  52.508  1
319276  95.047  -70.952  52.492  1
319277  95.073  -70.966  52.477  1
319278  95.100  -70.980  52.464  1
319279  95.126  -70.995  52.450  1
319280  95.115  -71.018  52.437  1
319281  95.092  -71.046  52.424  1
319282  95.129  -71.064  52.411  1
319283  95.166  -71.082  52.398  1
319284  95.203  -71.100  52.386  1
319285  95.240  -71.118  52.373  1
319286  95.277  -71.136  52.361  1
319287  95.314  -71.154  52.350  1
319288  95.351  -71.172  52.338  1
319289  95.388  -71.190  52.327  1
319290  95.424  -71.208  52.314  1
319291  95.462  -71.226  52.303  1
319292  95.498  -71.244  52.291  1
319293  95.535  -71.262  52.279  1
319294  95.558  -71.254  52.267  1
319295  95.572  -71.230  52.256  1
319296  95.587  -71.205  52.245  1
319297  95.601  -71.181  52.234  1
319298  95.652  -71.199  52.222  1
319299  95.693  -71.208  52.212  1
319300  95.721  -71.218  52.201  1
319301  95.751  -71.224  52.192  1
319302  95.786  -71.228  52.185  1
319303  95.821  -71.231  52.180  1
319304  95.861  -71.230  52.176  1
319305  95.901  -71.227  52.172  1
319306  95.946  -71.228  52.173  1
319307  96.001  -71.238  52.174  1
319308  96.055  -71.247  52.175  1
319309  96.110  -71.257  52.176  1
319310  96.165  -71.267  52.177  1
319311  96.220  -71.277  52.176  1
319312  96.274  -71.286  52.172  1
319313  96.333  -71.281  52.168  1
319314  96.392  -71.274  52.163  1
319315  96.453  -71.268  52.158  1
319316  96.525  -71.275  52.152  1
319317  96.560  -71.292  52.144  1
319318  96.596  -71.309  52.133  1
319319  96.630  -71.325  52.114  1
319320  96.666  -71.341  52.094  1
319321  96.700  -71.358  52.071  1
319322  96.736  -71.375  52.047  1
319323  96.770  -71.390  52.022  1
319324  96.806  -71.407  51.989  1
319325  96.841  -71.424  51.953  1
319326  96.878  -71.442  51.916  1
319327  96.913  -71.454  51.882  1
319328  96.946  -71.461  51.849  1
319329  96.978  -71.464  51.818  1
319330  97.011  -71.467  51.788  1
319331  97.044  -71.469  51.754  1
319332  97.077  -71.472  51.719  1
319333  97.111  -71.476  51.683  1
319334  97.151  -71.487  51.646  1
319335  97.190  -71.499  51.611  1
319336  97.230  -71.510  51.577  1
319337  97.270  -71.522  51.540  1
319338  97.310  -71.533  51.503  1
319339  97.350  -71.544  51.466  1
319340  97.389  -71.556  51.430  1
319341  97.429  -71.567  51.398  1
319342  97.469  -71.578  51.367  1
319343  97.509  -71.591  51.338  1
319344  97.546  -71.602  51.304  1
319345  97.582  -71.614  51.270  1
319346  97.617  -71.626  51.235  1
319347  97.653  -71.638  51.199  1
319348  97.688  -71.650  51.164  1
319349  97.724  -71.663  51.131  1
319350  97.760  -71.671  51.097  1
319351  97.797  -71.678  51.064  1
319352  97.825  -71.681  51.034  1
319353  97.850  -71.682  51.000  1
319354  97.875  -71.683  50.966  1
319355  97.900  -71.685  50.932  1
319356  97.925  -71.686  50.896  1
319357  97.950  -71.687  50.855  1
319358  97.975  -71.688  50.812  1
319359  98.001  -71.691  50.768  1
319360  98.028  -71.699  50.722  1
319361  98.055  -71.707  50.676  1
319362  98.082  -71.716  50.630  1
319363  98.108  -71.725  50.584  1
319364  98.136  -71.732  50.538  1
319365  98.164  -71.740  50.497  1
319366  98.192  -71.748  50.456  1
319367  98.220  -71.756  50.412  1
319368  98.248  -71.763  50.367  1
319369  98.276  -71.771  50.318  1
319370  98.304  -71.779  50.264  1
319371  98.343  -71.798  50.208  1
319372  98.383  -71.818  50.151  1
319373  98.425  -71.842  50.093  1
319374  98.466  -71.866  50.037  1
319375  98.508  -71.890  49.983  1
319376  98.544  -71.902  49.929  1
319377  98.576  -71.904  49.877  1
319378  98.608  -71.905  49.824  1
319379  98.640  -71.907  49.770  1
319380  98.672  -71.908  49.714  1
319381  98.704  -71.910  49.659  1
319382  98.736  -71.911  49.602  1
319383  98.768  -71.913  49.547  1
319384  98.800  -71.914  49.491  1
319385  98.832  -71.914  49.437  1
319386  98.863  -71.913  49.380  1
319387  98.892  -71.920  49.324  1
319388  98.922  -71.931  49.267  1
319389  98.954  -71.945  49.210  1
319390  98.987  -71.958  49.156  1
319391  99.019  -71.972  49.101  1
319392  99.051  -71.986  49.047  1
319393  99.085  -71.998  48.993  1
319394  99.119  -72.012  48.940  1
319395  99.153  -72.026  48.886  1
319396  99.187  -72.039  48.834  1
319397  99.220  -72.052  48.784  1
319398  99.254  -72.066  48.733  1
319399  99.288  -72.080  48.684  1
319400  99.317  -72.094  48.635  1
319401  99.340  -72.111  48.586  1
319402  99.362  -72.127  48.536  1
319403  99.407  -72.139  48.489  1
319404  99.454  -72.151  48.442  1
319405  99.501  -72.163  48.395  1
319406  99.548  -72.174  48.348  1
319407  99.594  -72.186  48.302  1
319408  99.636  -72.200  48.256  1
319409  99.678  -72.214  48.210  1
319410  99.719  -72.227  48.166  1
319411  99.761  -72.241  48.121  1
319412  99.802  -72.255  48.077  1
319413  99.843  -72.268  48.032  1
319414  99.884  -72.281  47.987  1
319415  99.926  -72.283  47.942  1
319416  99.960  -72.284  47.901  1
319417  99.984  -72.286  47.858  1
319418  100.008  -72.287  47.815  1
319419  100.034  -72.290  47.773  1
319420  100.074  -72.311  47.731  1
319421  100.093  -72.342  47.689  1
319422  100.117  -72.361  47.647  1
319423  100.142  -72.376  47.608  1
319424  100.167  -72.392  47.567  1
319425  100.191  -72.407  47.527  1
319426  100.216  -72.423  47.486  1
319427  100.241  -72.438  47.446  1
319428  100.267  -72.455  47.408  1
319429  100.303  -72.479  47.371  1
319430  100.339  -72.499  47.335  1
319431  100.370  -72.489  47.299  1
319432  100.400  -72.478  47.264  1
319433  100.430  -72.468  47.228  1
319434  100.461  -72.458  47.195  1
319435  100.491  -72.448  47.163  1
319436  100.522  -72.438  47.133  1
319437  100.552  -72.428  47.105  1
319438  100.582  -72.418  47.073  1
319439  100.614  -72.422  47.039  1
319440  100.646  -72.440  47.004  1
319441  100.679  -72.459  46.967  1
319442  100.711  -72.477  46.929  1
319443  100.743  -72.494  46.889  1
319444  100.775  -72.512  46.849  1
319445  100.808  -72.531  46.807  1
319446  100.840  -72.548  46.765  1
319447  100.872  -72.566  46.722  1
319448  100.904  -72.584  46.678  1
319449  100.936  -72.602  46.636  1
319450  100.972  -72.625  46.592  1
319451  101.009  -72.650  46.549  1
319452  101.041  -72.667  46.507  1
319453  101.070  -72.680  46.463  1
319454  101.109  -72.690  46.421  1
319455  101.152  -72.699  46.381  1
319456  101.193  -72.707  46.342  1
319457  101.232  -72.715  46.302  1
319458  101.271  -72.722  46.264  1
319459  101.310  -72.728  46.225  1
319460  101.349  -72.736  46.186  1
319461  101.388  -72.743  46.148  1
319462  101.426  -72.750  46.111  1
319463  101.465  -72.757  46.074  1
319464  101.504  -72.764  46.037  1
319465  101.539  -72.776  45.999  1
319466  101.571  -72.788  45.962  1
319467  101.594  -72.797  45.924  1
319468  101.611  -72.804  45.887  1
319469  101.629  -72.810  45.850  1
319470  101.646  -72.817  45.813  1
319471  101.664  -72.824  45.776  1
319472  101.682  -72.830  45.738  1
319473  101.699  -72.837  45.701  1
319474  101.717  -72.844  45.664  1
319475  101.734  -72.852  45.626  1
319476  101.750  -72.865  45.588  1
319477  101.790  -72.878  45.551  1
319478  101.830  -72.891  45.514  1
319479  101.870  -72.904  45.477  1
319480  101.910  -72.917  45.440  1
319481  101.950  -72.931  45.404  1
319482  101.989  -72.944  45.368  1
319483  102.030  -72.957  45.333  1
319484  102.073  -72.967  45.298  1
319485  102.116  -72.976  45.263  1
319969  94.860  -70.879  52.632  1
319970  94.886  -70.873  52.613  1
319971  94.905  -70.867  52.594  1
319972  94.924  -70.862  52.576  1
319973  94.943  -70.858  52.560  1
319974  94.966  -70.863  52.544  1
319975  94.992  -70.877  52.528  1
319976  95.019  -70.892  52.512  1
319977  95.045  -70.906  52.497  1
319978  95.071  -70.920  52.484  1
319979  95.098  -70.935  52.471  1
319980  95.121  -70.950  52.458  1
319981  95.093  -70.979  52.445  1
319982  95.107  -71.000  52.432  1
319983  95.144  -71.018  52.420  1
319984  95.181  -71.036  52.407  1
319985  95.218  -71.054  52.393  1
319986  95.255  -71.072  52.381  1
319987  95.292  -71.090  52.369  1
319988  95.329  -71.108  52.358  1
319989  95.366  -71.126  52.346  1
319990  95.403  -71.144  52.334  1
319991  95.440  -71.162  52.322  1
319992  95.476  -71.180  52.310  1
319993  95.514  -71.198  52.299  1
319994  95.550  -71.216  52.286  1
319995  95.586  -71.232  52.275  1
319996  95.601  -71.208  52.264  1
319997  95.615  -71.183  52.254  1
319998  95.629  -71.159  52.242  1
319999  95.647  -71.140  52.230  1
320000  95.696  -71.153  52.219  1
320001  95.724  -71.163  52.209  1
320002  95.757  -71.168  52.200  1
320003  95.792  -71.171  52.193  1
320004  95.826  -71.174  52.188  1
320005  95.866  -71.173  52.184  1
320006  95.906  -71.171  52.180  1
320007  95.956  -71.176  52.181  1
320008  96.011  -71.185  52.183  1
320009  96.065  -71.195  52.185  1
320010  96.120  -71.205  52.186  1
320011  96.175  -71.214  52.188  1
320012  96.229  -71.224  52.186  1
320013  96.284  -71.234  52.183  1
320014  96.339  -71.239  52.178  1
320015  96.399  -71.232  52.174  1
320016  96.466  -71.227  52.169  1
320017  96.532  -71.237  52.164  1
320018  96.567  -71.252  52.157  1
320019  96.602  -71.269  52.146  1
320020  96.637  -71.286  52.128  1
320021  96.672  -71.302  52.108  1
320022  96.707  -71.318  52.086  1
320023  96.742  -71.335  52.062  1
320024  96.779  -71.353  52.038  1
320025  96.816  -71.371  52.006  1
320026  96.853  -71.389  51.971  1
320027  96.889  -71.403  51.935  1
320028  96.922  -71.410  51.899  1
320029  96.954  -71.418  51.864  1
320030  96.987  -71.425  51.832  1
320031  97.020  -71.428  51.801  1
320032  97.052  -71.430  51.767  1
320033  97.085  -71.433  51.732  1
320034  97.121  -71.439  51.697  1
320035  97.161  -71.450  51.661  1
320036  97.201  -71.462  51.625  1
320037  97.240  -71.473  51.590  1
320038  97.280  -71.484  51.553  1
320039  97.320  -71.496  51.515  1
320040  97.360  -71.507  51.478  1
320041  97.399  -71.519  51.443  1
320042  97.438  -71.530  51.411  1
320043  97.473  -71.542  51.380  1
320044  97.509  -71.554  51.350  1
320045  97.544  -71.566  51.317  1
320046  97.580  -71.578  51.282  1
320047  97.615  -71.591  51.248  1
320048  97.651  -71.603  51.213  1
320049  97.686  -71.615  51.179  1
320050  97.722  -71.627  51.146  1
320051  97.758  -71.636  51.113  1
320052  97.795  -71.643  51.081  1
320053  97.831  -71.650  51.052  1
320054  97.862  -71.654  51.019  1
320055  97.887  -71.656  50.986  1
320056  97.912  -71.657  50.954  1
320057  97.937  -71.658  50.919  1
320058  97.962  -71.660  50.877  1
320059  97.987  -71.660  50.832  1
320060  98.012  -71.662  50.786  1
320061  98.039  -71.670  50.739  1
320062  98.066  -71.679  50.692  1
320063  98.093  -71.687  50.646  1
320064  98.120  -71.695  50.601  1
320065  98.148  -71.703  50.556  1
320066  98.176  -71.711  50.515  1
320067  98.204  -71.719  50.471  1
320068  98.232  -71.726  50.426  1
320069  98.260  -71.735  50.380  1
320070  98.288  -71.742  50.330  1
320071  98.315  -71.750  50.275  1
320072  98.351  -71.765  50.217  1
320073  98.391  -71.785  50.159  1
320074  98.433  -71.808  50.102  1
320075  98.475  -71.833  50.046  1
320076  98.516  -71.857  49.991  1
320077  98.556  -71.879  49.937  1
320078  98.588  -71.880  49.883  1
320079  98.620  -71.882  49.829  1
320080  98.652  -71.883  49.774  1
320081  98.684  -71.885  49.718  1
320082  98.716  -71.886  49.661  1
320083  98.748  -71.887  49.604  1
320084  98.780  -71.885  49.547  1
320085  98.811  -71.884  49.492  1
320086  98.843  -71.883  49.436  1
320087  98.874  -71.882  49.380  1
320088  98.905  -71.885  49.325  1
320089  98.931  -71.901  49.269  1
320090  98.958  -71.910  49.212  1
320091  98.991  -71.923  49.158  1
320092  99.023  -71.937  49.103  1
320093  99.055  -71.951  49.048  1
320094  99.087  -71.964  48.995  1
320095  99.120  -71.978  48.942  1
320096  99.152  -71.991  48.888  1
320097  99.184  -72.005  48.837  1
320098  99.217  -72.018  48.786  1
320099  99.249  -72.032  48.736  1
320100  99.281  -72.045  48.687  1
320101  99.315  -72.059  48.637  1
320102  99.349  -72.072  48.588  1
320103  99.374  -72.088  48.538  1
320104  99.421  -72.100  48.490  1
320105  99.465  -72.112  48.443  1
320106  99.507  -72.126  48.395  1
320107  99.548  -72.139  48.348  1
320108  99.589  -72.153  48.302  1
320109  99.630  -72.166  48.256  1
320110  99.671  -72.180  48.211  1
320111  99.712  -72.193  48.166  1
320112  99.753  -72.206  48.122  1
320113  99.794  -72.219  48.077  1
320114  99.836  -72.228  48.032  1
320115  99.878  -72.229  47.988  1
320116  99.921  -72.230  47.944  1
320117  99.963  -72.231  47.902  1
320118  99.995  -72.232  47.860  1
320119  100.019  -72.233  47.817  1
320120  100.051  -72.241  47.775  1
320121  100.090  -72.264  47.733  1
320122  100.111  -72.291  47.691  1
320123  100.135  -72.306  47.651  1
320124  100.160  -72.322  47.612  1
320125  100.185  -72.337  47.571  1
320126  100.210  -72.353  47.531  1
320127  100.234  -72.368  47.492  1
320128  100.259  -72.384  47.452  1
320129  100.284  -72.399  47.413  1
320130  100.316  -72.421  47.376  1
320131  100.353  -72.444  47.341  1
320132  100.387  -72.456  47.306  1
320133  100.418  -72.446  47.271  1
320134  100.448  -72.436  47.237  1
320135  100.478  -72.426  47.204  1
320136  100.509  -72.415  47.174  1
320137  100.539  -72.406  47.145  1
320138  100.570  -72.395  47.119  1
320139  100.600  -72.385  47.088  1
320140  100.632  -72.402  47.053  1
320141  100.665  -72.419  47.017  1
320142  100.697  -72.437  46.979  1
320143  100.729  -72.456  46.941  1
320144  100.761  -72.474  46.902  1
320145  100.793  -72.491  46.862  1
320146  100.826  -72.509  46.818  1
320147  100.858  -72.528  46.776  1
320148  100.890  -72.545  46.733  1
320149  100.922  -72.563  46.689  1
320150  100.955  -72.581  46.647  1
320151  100.987  -72.599  46.603  1
320152  101.019  -72.617  46.560  1
320153  101.053  -72.638  46.517  1
320154  101.090  -72.647  46.474  1
320155  101.129  -72.655  46.432  1
320156  101.168  -72.662  46.391  1
320157  101.206  -72.669  46.351  1
320158  101.246  -72.676  46.312  1
320159  101.284  -72.683  46.273  1
320160  101.323  -72.690  46.234  1
320161  101.362  -72.697  46.195  1
320162  101.401  -72.704  46.157  1
320163  101.440  -72.712  46.119  1
320164  101.478  -72.719  46.082  1
320165  101.517  -72.725  46.044  1
320166  101.551  -72.737  46.006  1
320167  101.584  -72.750  45.968  1
320168  101.615  -72.763  45.931  1
320169  101.632  -72.770  45.894  1
320170  101.650  -72.776  45.856  1
320171  101.668  -72.783  45.819  1
320172  101.686  -72.790  45.781  1
320173  101.703  -72.796  45.744  1
320174  101.721  -72.803  45.707  1
320175  101.739  -72.810  45.669  1
320176  101.754  -72.819  45.632  1
320177  101.768  -72.832  45.594  1
320178  101.802  -72.844  45.557  1
320179  101.842  -72.857  45.520  1
320180  101.882  -72.871  45.484  1
320181  101.922  -72.884  45.447  1
320182  101.962  -72.898  45.411  1
320183  102.003  -72.910  45.376  1
320184  102.043  -72.923  45.340  1
320185  102.086  -72.932  45.305  1
320186  102.129  -72.942  45.270  1
320670  94.855  -70.845  52.634  1
320671  94.881  -70.839  52.616  1
320672  94.907  -70.833  52.598  1
320673  94.926  -70.828  52.581  1
320674  94.945  -70.823  52.566  1
320675  94.964  -70.818  52.550  1
320676  94.990  -70.832  52.535  1
320677  95.017  -70.847  52.521  1
320678  95.043  -70.861  52.506  1
320679  95.069  -70.876  52.493  1
320680  95.096  -70.890  52.480  1
320681  95.099  -70.911  52.467  1
320682  95.085  -70.936  52.455  1
320683  95.122  -70.955  52.442  1
320684  95.159  -70.972  52.429  1
320685  95.196  -70.990  52.416  1
320686  95.233  -71.008  52.402  1
320687  95.270  -71.027  52.390  1
320688  95.307  -71.044  52.378  1
320689  95.344  -71.062  52.366  1
320690  95.381  -71.080  52.354  1
320691  95.418  -71.099  52.342  1
320692  95.455  -71.116  52.330  1
320693  95.491  -71.134  52.318  1
320694  95.529  -71.152  52.306  1
320695  95.565  -71.171  52.293  1
320696  95.602  -71.188  52.283  1
320697  95.628  -71.186  52.272  1
320698  95.642  -71.162  52.261  1
320699  95.657  -71.137  52.250  1
320700  95.671  -71.114  52.238  1
320701  95.693  -71.099  52.227  1
320702  95.728  -71.107  52.217  1
320703  95.762  -71.110  52.208  1
320704  95.797  -71.113  52.200  1
320705  95.831  -71.117  52.195  1
320706  95.870  -71.116  52.192  1
320707  95.911  -71.114  52.188  1
320708  95.966  -71.123  52.189  1
320709  96.020  -71.133  52.192  1
320710  96.075  -71.143  52.195  1
320711  96.129  -71.152  52.199  1
320712  96.184  -71.162  52.201  1
320713  96.239  -71.171  52.200  1
320714  96.294  -71.181  52.196  1
320715  96.348  -71.190  52.192  1
320716  96.405  -71.190  52.189  1
320717  96.479  -71.186  52.185  1
320718  96.538  -71.197  52.179  1
320719  96.574  -71.214  52.171  1
320720  96.609  -71.230  52.160  1
320721  96.644  -71.246  52.142  1
320722  96.679  -71.263  52.123  1
320723  96.717  -71.281  52.101  1
320724  96.754  -71.299  52.077  1
320725  96.791  -71.318  52.054  1
320726  96.828  -71.337  52.023  1
320727  96.865  -71.353  51.989  1
320728  96.897  -71.359  51.953  1
320729  96.930  -71.367  51.916  1
320730  96.963  -71.374  51.881  1
320731  96.996  -71.381  51.847  1
320732  97.028  -71.387  51.814  1
320733  97.061  -71.390  51.780  1
320734  97.094  -71.393  51.746  1
320735  97.131  -71.401  51.711  1
320736  97.171  -71.412  51.675  1
320737  97.211  -71.424  51.638  1
320738  97.250  -71.435  51.602  1
320739  97.290  -71.447  51.565  1
320740  97.330  -71.458  51.527  1
320741  97.365  -71.470  51.491  1
320742  97.401  -71.482  51.457  1
320743  97.436  -71.494  51.426  1
320744  97.472  -71.506  51.396  1
320745  97.507  -71.519  51.365  1
320746  97.542  -71.531  51.331  1
320747  97.578  -71.543  51.296  1
320748  97.613  -71.555  51.262  1
320749  97.649  -71.567  51.228  1
320750  97.684  -71.579  51.196  1
320751  97.720  -71.591  51.163  1
320752  97.756  -71.601  51.130  1
320753  97.792  -71.609  51.098  1
320754  97.829  -71.616  51.068  1
320755  97.865  -71.622  51.037  1
320756  97.898  -71.628  51.007  1
320757  97.924  -71.629  50.977  1
320758  97.949  -71.631  50.943  1
320759  97.974  -71.632  50.899  1
320760  97.999  -71.633  50.852  1
320761  98.024  -71.634  50.805  1
320762  98.051  -71.641  50.756  1
320763  98.078  -71.650  50.708  1
320764  98.104  -71.658  50.663  1
320765  98.132  -71.666  50.618  1
320766  98.160  -71.674  50.574  1
320767  98.188  -71.682  50.533  1
320768  98.216  -71.689  50.489  1
320769  98.244  -71.697  50.442  1
320770  98.272  -71.705  50.393  1
320771  98.299  -71.713  50.342  1
320772  98.327  -71.721  50.284  1
320773  98.359  -71.732  50.226  1
320774  98.400  -71.752  50.169  1
320775  98.441  -71.776  50.112  1
320776  98.483  -71.800  50.056  1
320777  98.524  -71.825  50.000  1
320778  98.566  -71.849  49.945  1
320779  98.600  -71.857  49.889  1
320780  98.632  -71.858  49.834  1
320781  98.664  -71.860  49.779  1
320782  98.696  -71.859  49.722  1
320783  98.727  -71.857  49.663  1
320784  98.759  -71.856  49.606  1
320785  98.791  -71.854  49.548  1
320786  98.822  -71.853  49.491  1
320787  98.854  -71.852  49.435  1
320788  98.886  -71.851  49.379  1
320789  98.917  -71.851  49.325  1
320790  98.943  -71.867  49.270  1
320791  98.970  -71.882  49.214  1
320792  98.995  -71.889  49.160  1
320793  99.027  -71.902  49.104  1
320794  99.059  -71.916  49.050  1
320795  99.092  -71.929  48.997  1
320796  99.124  -71.943  48.944  1
320797  99.156  -71.957  48.891  1
320798  99.189  -71.970  48.840  1
320799  99.221  -71.983  48.789  1
320800  99.253  -71.997  48.738  1
320801  99.285  -72.011  48.690  1
320802  99.317  -72.024  48.640  1
320803  99.350  -72.038  48.590  1
320804  99.380  -72.051  48.541  1
320805  99.417  -72.064  48.491  1
320806  99.458  -72.077  48.444  1
320807  99.499  -72.091  48.396  1
320808  99.540  -72.104  48.349  1
320809  99.581  -72.117  48.303  1
320810  99.622  -72.130  48.257  1
320811  99.663  -72.144  48.211  1
320812  99.704  -72.157  48.167  1
320813  99.746  -72.171  48.123  1
320814  99.787  -72.174  48.079  1
320815  99.830  -72.175  48.035  1
320816  99.872  -72.176  47.990  1
320817  99.915  -72.177  47.945  1
320818  99.957  -72.178  47.903  1
320819  99.999  -72.179  47.861  1
320820  100.030  -72.180  47.819  1
320821  100.069  -72.193  47.778  1
320822  100.106  -72.217  47.736  1
320823  100.129  -72.236  47.694  1
320824  100.154  -72.252  47.654  1
320825  100.179  -72.268  47.615  1
320826  100.203  -72.283  47.576  1
320827  100.228  -72.299  47.536  1
320828  100.253  -72.314  47.497  1
320829  100.278  -72.330  47.458  1
320830  100.302  -72.345  47.419  1
320831  100.329  -72.362  47.382  1
320832  100.366  -72.386  47.347  1
320833  100.402  -72.410  47.313  1
320834  100.435  -72.413  47.279  1
320835  100.466  -72.403  47.245  1
320836  100.496  -72.393  47.214  1
320837  100.527  -72.383  47.185  1
320838  100.557  -72.373  47.158  1
320839  100.587  -72.362  47.131  1
320840  100.618  -72.362  47.099  1
320841  100.650  -72.381  47.065  1
320842  100.683  -72.399  47.029  1
320843  100.715  -72.416  46.990  1
320844  100.747  -72.434  46.952  1
320845  100.779  -72.453  46.912  1
320846  100.812  -72.471  46.870  1
320847  100.844  -72.488  46.827  1
320848  100.876  -72.506  46.784  1
320849  100.908  -72.525  46.741  1
320850  100.940  -72.542  46.698  1
320851  100.973  -72.560  46.656  1
320852  101.005  -72.578  46.612  1
320853  101.036  -72.587  46.569  1
320854  101.067  -72.596  46.527  1
320855  101.103  -72.609  46.484  1
320856  101.142  -72.616  46.442  1
320857  101.181  -72.623  46.401  1
320858  101.220  -72.630  46.361  1
320859  101.259  -72.638  46.322  1
320860  101.298  -72.644  46.282  1
320861  101.336  -72.652  46.243  1
320862  101.375  -72.659  46.205  1
320863  101.414  -72.666  46.166  1
320864  101.453  -72.673  46.128  1
320865  101.492  -72.680  46.090  1
320866  101.531  -72.687  46.052  1
320867  101.564  -72.699  46.014  1
320868  101.597  -72.712  45.976  1
320869  101.628  -72.725  45.938  1
320870  101.654  -72.735  45.901  1
320871  101.672  -72.742  45.863  1
320872  101.689  -72.749  45.826  1
320873  101.707  -72.755  45.788  1
320874  101.725  -72.762  45.751  1
320875  101.742  -72.769  45.714  1
320876  101.760  -72.775  45.675  1
320877  101.775  -72.785  45.637  1
320878  101.789  -72.798  45.600  1
320879  101.815  -72.811  45.563  1
320880  101.855  -72.824  45.526  1
320881  101.895  -72.838  45.491  1
320882  101.935  -72.851  45.455  1
320883  101.975  -72.863  45.419  1
320884  102.015  -72.877  45.384  1
320885  102.056  -72.888  45.349  1
320886  102.099  -72.898  45.314  1
321370  94.825  -70.817  52.654  1
321371  94.850  -70.811  52.638  1
321372  94.876  -70.805  52.620  1
321373  94.902  -70.799  52.603  1
321374  94.928  -70.794  52.587  1
321375  94.947  -70.789  52.572  1
321376  94.966  -70.783  52.557  1
321377  94.988  -70.787  52.543  1
321378  95.015  -70.801  52.529  1
321379  95.041  -70.816  52.515  1
321380  95.068  -70.830  52.502  1
321381  95.094  -70.845  52.489  1
321382  95.076  -70.870  52.477  1
321383  95.100  -70.891  52.465  1
321384  95.137  -70.908  52.452  1
321385  95.174  -70.927  52.439  1
321386  95.211  -70.945  52.426  1
321387  95.248  -70.962  52.413  1
321388  95.285  -70.980  52.400  1
321389  95.322  -70.999  52.388  1
321390  95.359  -71.017  52.376  1
321391  95.396  -71.034  52.363  1
321392  95.432  -71.052  52.350  1
321393  95.470  -71.071  52.338  1
321394  95.507  -71.089  52.326  1
321395  95.544  -71.106  52.314  1
321396  95.581  -71.124  52.302  1
321397  95.617  -71.143  52.291  1
321398  95.655  -71.161  52.279  1
321399  95.671  -71.140  52.268  1
321400  95.685  -71.116  52.257  1
321401  95.699  -71.092  52.246  1
321402  95.713  -71.068  52.235  1
321403  95.733  -71.049  52.224  1
321404  95.767  -71.052  52.215  1
321405  95.802  -71.056  52.208  1
321406  95.837  -71.059  52.203  1
321407  95.875  -71.059  52.200  1
321408  95.920  -71.061  52.196  1
321409  95.975  -71.071  52.196  1
321410  96.030  -71.080  52.198  1
321411  96.085  -71.089  52.202  1
321412  96.139  -71.099  52.208  1
321413  96.194  -71.109  52.214  1
321414  96.248  -71.118  52.214  1
321415  96.303  -71.128  52.213  1
321416  96.358  -71.138  52.210  1
321417  96.412  -71.148  52.207  1
321418  96.493  -71.145  52.202  1
321419  96.545  -71.158  52.195  1
321420  96.580  -71.174  52.186  1
321421  96.617  -71.192  52.171  1
321422  96.654  -71.210  52.152  1
321423  96.691  -71.229  52.132  1
321424  96.729  -71.247  52.111  1
321425  96.766  -71.265  52.089  1
321426  96.803  -71.284  52.066  1
321427  96.840  -71.302  52.036  1
321428  96.873  -71.309  52.003  1
321429  96.906  -71.316  51.968  1
321430  96.939  -71.323  51.931  1
321431  96.971  -71.331  51.896  1
321432  97.004  -71.337  51.863  1
321433  97.036  -71.345  51.831  1
321434  97.069  -71.351  51.795  1
321435  97.102  -71.353  51.762  1
321436  97.141  -71.364  51.726  1
321437  97.181  -71.375  51.689  1
321438  97.221  -71.387  51.651  1
321439  97.257  -71.399  51.615  1
321440  97.293  -71.411  51.577  1
321441  97.328  -71.423  51.540  1
321442  97.363  -71.435  51.506  1
321443  97.399  -71.447  51.475  1
321444  97.434  -71.459  51.444  1
321445  97.470  -71.471  51.414  1
321446  97.505  -71.483  51.384  1
321447  97.541  -71.495  51.348  1
321448  97.576  -71.507  51.313  1
321449  97.611  -71.519  51.279  1
321450  97.647  -71.531  51.246  1
321451  97.682  -71.544  51.214  1
321452  97.718  -71.556  51.182  1
321453  97.754  -71.567  51.148  1
321454  97.790  -71.574  51.115  1
321455  97.827  -71.581  51.084  1
321456  97.863  -71.588  51.055  1
321457  97.900  -71.595  51.026  1
321458  97.935  -71.602  50.996  1
321459  97.960  -71.603  50.963  1
321460  97.986  -71.604  50.917  1
321461  98.011  -71.605  50.870  1
321462  98.035  -71.607  50.820  1
321463  98.062  -71.613  50.770  1
321464  98.089  -71.621  50.723  1
321465  98.116  -71.629  50.680  1
321466  98.144  -71.637  50.639  1
321467  98.172  -71.644  50.597  1
321468  98.200  -71.653  50.554  1
321469  98.228  -71.660  50.508  1
321470  98.255  -71.668  50.459  1
321471  98.283  -71.676  50.407  1
321472  98.311  -71.684  50.353  1
321473  98.339  -71.691  50.295  1
321474  98.367  -71.699  50.238  1
321475  98.408  -71.719  50.181  1
321476  98.449  -71.743  50.124  1
321477  98.491  -71.767  50.067  1
321478  98.532  -71.791  50.009  1
321479  98.574  -71.816  49.952  1
321480  98.612  -71.832  49.895  1
321481  98.644  -71.830  49.838  1
321482  98.675  -71.829  49.780  1
321483  98.707  -71.828  49.722  1
321484  98.738  -71.826  49.662  1
321485  98.770  -71.825  49.606  1
321486  98.802  -71.823  49.548  1
321487  98.834  -71.822  49.491  1
321488  98.865  -71.821  49.435  1
321489  98.897  -71.820  49.380  1
321490  98.929  -71.818  49.325  1
321491  98.955  -71.833  49.270  1
321492  98.982  -71.848  49.216  1
321493  99.009  -71.864  49.161  1
321494  99.035  -71.879  49.106  1
321495  99.064  -71.881  49.052  1
321496  99.096  -71.895  48.999  1
321497  99.128  -71.908  48.946  1
321498  99.160  -71.922  48.893  1
321499  99.193  -71.936  48.842  1
321500  99.225  -71.949  48.792  1
321501  99.257  -71.963  48.743  1
321502  99.289  -71.976  48.694  1
321503  99.322  -71.989  48.644  1
321504  99.354  -72.003  48.593  1
321505  99.382  -72.016  48.543  1
321506  99.410  -72.029  48.494  1
321507  99.450  -72.042  48.446  1
321508  99.491  -72.055  48.398  1
321509  99.532  -72.068  48.351  1
321510  99.573  -72.082  48.304  1
321511  99.615  -72.095  48.258  1
321512  99.655  -72.108  48.212  1
321513  99.697  -72.119  48.168  1
321514  99.739  -72.120  48.124  1
321515  99.782  -72.121  48.080  1
321516  99.824  -72.122  48.036  1
321517  99.866  -72.123  47.992  1
321518  99.909  -72.124  47.948  1
321519  99.951  -72.125  47.905  1
321520  99.994  -72.126  47.863  1
321521  100.041  -72.129  47.822  1
321522  100.086  -72.146  47.781  1
321523  100.123  -72.167  47.739  1
321524  100.147  -72.182  47.697  1
321525  100.173  -72.198  47.657  1
321526  100.197  -72.213  47.619  1
321527  100.222  -72.229  47.580  1
321528  100.247  -72.244  47.541  1
321529  100.271  -72.260  47.502  1
321530  100.296  -72.275  47.463  1
321531  100.321  -72.291  47.425  1
321532  100.346  -72.306  47.389  1
321533  100.379  -72.327  47.354  1
321534  100.415  -72.352  47.320  1
321535  100.452  -72.376  47.287  1
321536  100.483  -72.371  47.254  1
321537  100.513  -72.361  47.223  1
321538  100.544  -72.350  47.194  1
321539  100.574  -72.340  47.168  1
321540  100.605  -72.330  47.139  1
321541  100.636  -72.342  47.108  1
321542  100.668  -72.359  47.075  1
321543  100.701  -72.377  47.039  1
321544  100.733  -72.396  47.000  1
321545  100.765  -72.413  46.961  1
321546  100.797  -72.431  46.921  1
321547  100.830  -72.450  46.879  1
321548  100.862  -72.468  46.835  1
321549  100.894  -72.485  46.792  1
321550  100.926  -72.503  46.749  1
321551  100.958  -72.515  46.705  1
321552  100.989  -72.524  46.664  1
321553  101.019  -72.532  46.621  1
321554  101.050  -72.541  46.579  1
321555  101.083  -72.552  46.537  1
321556  101.118  -72.566  46.494  1
321557  101.156  -72.578  46.453  1
321558  101.194  -72.584  46.412  1
321559  101.233  -72.591  46.371  1
321560  101.272  -72.599  46.332  1
321561  101.311  -72.606  46.292  1
321562  101.349  -72.613  46.254  1
321563  101.388  -72.620  46.215  1
321564  101.427  -72.627  46.177  1
321565  101.466  -72.634  46.138  1
321566  101.505  -72.641  46.100  1
321567  101.544  -72.648  46.061  1
321568  101.577  -72.660  46.023  1
321569  101.609  -72.674  45.985  1
321570  101.641  -72.687  45.947  1
321571  101.674  -72.700  45.909  1
321572  101.693  -72.708  45.871  1
321573  101.711  -72.714  45.835  1
321574  101.729  -72.721  45.797  1
321575  101.746  -72.728  45.759  1
321576  101.764  -72.734  45.721  1
321577  101.781  -72.741  45.683  1
321578  101.796  -72.752  45.646  1
321579  101.810  -72.765  45.609  1
321580  101.828  -72.778  45.572  1
321581  101.868  -72.791  45.535  1
321582  101.908  -72.804  45.500  1
321583  101.948  -72.817  45.463  1
321584  101.988  -72.830  45.427  1
321585  102.028  -72.843  45.393  1
321586  102.069  -72.855  45.358  1
321587  102.112  -72.864  45.323  1
322071  94.820  -70.782  52.658  1
322072  94.845  -70.777  52.642  1
322073  94.871  -70.771  52.626  1
322074  94.897  -70.766  52.609  1
322075  94.923  -70.760  52.593  1
322076  94.949  -70.754  52.578  1
322077  94.968  -70.749  52.565  1
322078  94.987  -70.744  52.551  1
322079  95.013  -70.757  52.538  1
322080  95.039  -70.771  52.524  1
322081  95.066  -70.785  52.511  1
322082  95.082  -70.802  52.500  1
322083  95.078  -70.826  52.488  1
322084  95.115  -70.845  52.476  1
322085  95.152  -70.863  52.463  1
322086  95.189  -70.881  52.450  1
322087  95.226  -70.898  52.438  1
322088  95.263  -70.917  52.424  1
322089  95.300  -70.935  52.411  1
322090  95.337  -70.953  52.398  1
322091  95.374  -70.970  52.386  1
322092  95.411  -70.989  52.373  1
322093  95.448  -71.007  52.359  1
322094  95.485  -71.025  52.346  1
322095  95.522  -71.042  52.335  1
322096  95.558  -71.061  52.323  1
322097  95.596  -71.079  52.311  1
322098  95.632  -71.097  52.299  1
322099  95.670  -71.115  52.287  1
322100  95.698  -71.118  52.276  1
322101  95.712  -71.094  52.265  1
322102  95.727  -71.070  52.254  1
322103  95.747  -71.041  52.242  1
322104  95.773  -71.008  52.232  1
322105  95.776  -70.997  52.221  1
322106  95.808  -70.999  52.215  1
322107  95.842  -71.002  52.210  1
322108  95.880  -71.002  52.207  1
322109  95.930  -71.008  52.204  1
322110  95.985  -71.017  52.203  1
322111  96.039  -71.027  52.203  1
322112  96.094  -71.037  52.207  1
322113  96.149  -71.046  52.214  1
322114  96.203  -71.056  52.222  1
322115  96.258  -71.066  52.224  1
322116  96.313  -71.076  52.223  1
322117  96.367  -71.086  52.221  1
322118  96.421  -71.101  52.217  1
322119  96.489  -71.111  52.212  1
322120  96.555  -71.121  52.204  1
322121  96.593  -71.140  52.193  1
322122  96.630  -71.158  52.176  1
322123  96.667  -71.176  52.156  1
322124  96.704  -71.194  52.136  1
322125  96.741  -71.212  52.116  1
322126  96.779  -71.231  52.095  1
322127  96.816  -71.249  52.074  1
322128  96.849  -71.259  52.046  1
322129  96.882  -71.266  52.014  1
322130  96.914  -71.273  51.980  1
322131  96.947  -71.280  51.944  1
322132  96.980  -71.287  51.910  1
322133  97.012  -71.294  51.878  1
322134  97.045  -71.301  51.846  1
322135  97.078  -71.309  51.811  1
322136  97.111  -71.315  51.776  1
322137  97.149  -71.327  51.739  1
322138  97.184  -71.339  51.701  1
322139  97.220  -71.351  51.664  1
322140  97.255  -71.363  51.627  1
322141  97.291  -71.375  51.591  1
322142  97.326  -71.387  51.556  1
322143  97.362  -71.400  51.526  1
322144  97.397  -71.412  51.496  1
322145  97.432  -71.424  51.467  1
322146  97.468  -71.436  51.438  1
322147  97.503  -71.448  51.407  1
322148  97.539  -71.460  51.370  1
322149  97.574  -71.472  51.334  1
322150  97.609  -71.484  51.300  1
322151  97.645  -71.496  51.267  1
322152  97.680  -71.508  51.235  1
322153  97.716  -71.520  51.202  1
322154  97.751  -71.532  51.168  1
322155  97.788  -71.539  51.134  1
322156  97.824  -71.546  51.100  1
322157  97.861  -71.553  51.071  1
322158  97.898  -71.560  51.042  1
322159  97.934  -71.567  51.012  1
322160  97.971  -71.575  50.978  1
322161  97.997  -71.576  50.934  1
322162  98.022  -71.578  50.886  1
322163  98.048  -71.578  50.836  1
322164  98.073  -71.584  50.785  1
322165  98.100  -71.592  50.738  1
322166  98.128  -71.600  50.697  1
322167  98.156  -71.608  50.657  1
322168  98.183  -71.616  50.616  1
322169  98.212  -71.623  50.572  1
322170  98.239  -71.632  50.525  1
322171  98.267  -71.639  50.475  1
322172  98.295  -71.647  50.421  1
322173  98.323  -71.654  50.365  1
322174  98.351  -71.663  50.307  1
322175  98.379  -71.670  50.249  1
322176  98.416  -71.687  50.191  1
322177  98.457  -71.710  50.132  1
322178  98.499  -71.735  50.073  1
322179  98.540  -71.759  50.015  1
322180  98.582  -71.779  49.956  1
322181  98.621  -71.788  49.899  1
322182  98.654  -71.795  49.841  1
322183  98.687  -71.798  49.782  1
322184  98.718  -71.797  49.722  1
322185  98.750  -71.795  49.663  1
322186  98.782  -71.794  49.606  1
322187  98.813  -71.792  49.548  1
322188  98.845  -71.791  49.491  1
322189  98.877  -71.790  49.435  1
322190  98.908  -71.788  49.379  1
322191  98.940  -71.787  49.325  1
322192  98.968  -71.799  49.270  1
322193  98.994  -71.814  49.216  1
322194  99.021  -71.829  49.161  1
322195  99.048  -71.845  49.108  1
322196  99.074  -71.860  49.054  1
322197  99.100  -71.860  49.001  1
322198  99.132  -71.873  48.949  1
322199  99.164  -71.887  48.897  1
322200  99.197  -71.901  48.846  1
322201  99.229  -71.914  48.796  1
322202  99.261  -71.928  48.746  1
322203  99.293  -71.942  48.697  1
322204  99.326  -71.954  48.647  1
322205  99.356  -71.968  48.595  1
322206  99.383  -71.981  48.544  1
322207  99.411  -71.993  48.496  1
322208  99.442  -72.006  48.447  1
322209  99.484  -72.020  48.399  1
322210  99.524  -72.033  48.352  1
322211  99.566  -72.046  48.305  1
322212  99.607  -72.059  48.259  1
322213  99.649  -72.064  48.214  1
322214  99.691  -72.066  48.170  1
322215  99.733  -72.067  48.125  1
322216  99.776  -72.067  48.082  1
322217  99.818  -72.068  48.038  1
322218  99.864  -72.070  47.994  1
322219  99.914  -72.074  47.950  1
322220  99.964  -72.078  47.908  1
322221  100.014  -72.081  47.866  1
322222  100.060  -72.093  47.825  1
322223  100.105  -72.106  47.783  1
322224  100.139  -72.117  47.742  1
322225  100.166  -72.128  47.701  1
322226  100.191  -72.143  47.661  1
322227  100.215  -72.159  47.622  1
322228  100.240  -72.174  47.584  1
322229  100.265  -72.190  47.546  1
322230  100.290  -72.205  47.507  1
322231  100.315  -72.221  47.468  1
322232  100.339  -72.236  47.432  1
322233  100.364  -72.252  47.396  1
322234  100.391  -72.269  47.361  1
322235  100.428  -72.293  47.327  1
322236  100.465  -72.318  47.295  1
322237  100.500  -72.338  47.263  1
322238  100.531  -72.328  47.230  1
322239  100.561  -72.318  47.200  1
322240  100.592  -72.308  47.173  1
322241  100.622  -72.302  47.144  1
322242  100.654  -72.321  47.114  1
322243  100.687  -72.339  47.082  1
322244  100.719  -72.356  47.047  1
322245  100.751  -72.374  47.008  1
322246  100.783  -72.393  46.970  1
322247  100.816  -72.410  46.930  1
322248  100.848  -72.428  46.888  1
322249  100.879  -72.443  46.843  1
322250  100.911  -72.451  46.800  1
322251  100.941  -72.460  46.756  1
322252  100.972  -72.468  46.713  1
322253  101.003  -72.478  46.671  1
322254  101.034  -72.486  46.629  1
322255  101.065  -72.495  46.587  1
322256  101.099  -72.507  46.546  1
322257  101.134  -72.522  46.504  1
322258  101.170  -72.537  46.464  1
322259  101.207  -72.546  46.424  1
322260  101.246  -72.553  46.384  1
322261  101.285  -72.560  46.344  1
322262  101.324  -72.567  46.305  1
322263  101.363  -72.575  46.266  1
322264  101.402  -72.581  46.227  1
322265  101.441  -72.588  46.188  1
322266  101.479  -72.596  46.149  1
322267  101.518  -72.603  46.110  1
322268  101.557  -72.609  46.072  1
322269  101.590  -72.622  46.033  1
322270  101.622  -72.635  45.995  1
322271  101.654  -72.649  45.956  1
322272  101.686  -72.662  45.918  1
322273  101.714  -72.673  45.880  1
322274  101.732  -72.680  45.844  1
322275  101.750  -72.687  45.806  1
322276  101.768  -72.693  45.768  1
322277  101.785  -72.700  45.730  1
322278  101.803  -72.707  45.692  1
322279  101.817  -72.719  45.655  1
322280  101.831  -72.732  45.618  1
322281  101.845  -72.744  45.581  1
322282  101.881  -72.757  45.544  1
322283  101.920  -72.770  45.509  1
322284  101.961  -72.783  45.473  1
322285  102.000  -72.797  45.437  1
322286  102.041  -72.810  45.402  1
322287  102.083  -72.821  45.368  1
322288  102.125  -72.830  45.333  1
322771  94.789  -70.754  52.678  1
322772  94.815  -70.748  52.662  1
322773  94.840  -70.743  52.647  1
322774  94.866  -70.737  52.631  1
322775  94.892  -70.732  52.615  1
322776  94.918  -70.726  52.600  1
322777  94.944  -70.720  52.587  1
322778  94.970  -70.714  52.574  1
322779  94.989  -70.709  52.561  1
322780  95.011  -70.711  52.548  1
322781  95.038  -70.726  52.535  1
322782  95.064  -70.740  52.522  1
322783  95.060  -70.763  52.510  1
322784  95.094  -70.781  52.499  1
322785  95.130  -70.799  52.487  1
322786  95.167  -70.817  52.475  1
322787  95.204  -70.835  52.463  1
322788  95.241  -70.853  52.451  1
322789  95.278  -70.871  52.436  1
322790  95.315  -70.889  52.424  1
322791  95.352  -70.907  52.410  1
322792  95.389  -70.925  52.397  1
322793  95.426  -70.943  52.384  1
322794  95.463  -70.961  52.370  1
322795  95.500  -70.979  52.357  1
322796  95.537  -70.997  52.344  1
322797  95.573  -71.015  52.332  1
322798  95.611  -71.033  52.319  1
322799  95.648  -71.051  52.307  1
322800  95.684  -71.069  52.295  1
322801  95.722  -71.087  52.284  1
322802  95.741  -71.072  52.273  1
322803  95.758  -71.046  52.261  1
322804  95.785  -71.011  52.250  1
322805  95.813  -70.977  52.239  1
322806  95.823  -70.958  52.228  1
322807  95.827  -70.948  52.222  1
322808  95.848  -70.945  52.216  1
322809  95.885  -70.945  52.212  1
322810  95.940  -70.955  52.210  1
322811  95.994  -70.965  52.208  1
322812  96.049  -70.975  52.207  1
322813  96.104  -70.984  52.210  1
322814  96.158  -70.999  52.216  1
322815  96.213  -71.013  52.225  1
322816  96.267  -71.027  52.227  1
322817  96.321  -71.042  52.227  1
322818  96.376  -71.057  52.225  1
322819  96.430  -71.071  52.221  1
322820  96.485  -71.084  52.214  1
322821  96.563  -71.091  52.205  1
322822  96.608  -71.107  52.193  1
322823  96.646  -71.125  52.175  1
322824  96.683  -71.143  52.155  1
322825  96.720  -71.162  52.136  1
322826  96.757  -71.180  52.117  1
322827  96.795  -71.198  52.096  1
322828  96.828  -71.215  52.076  1
322829  96.858  -71.225  52.051  1
322830  96.891  -71.232  52.022  1
322831  96.924  -71.239  51.989  1
322832  96.956  -71.246  51.955  1
322833  96.989  -71.252  51.923  1
322834  97.022  -71.259  51.892  1
322835  97.054  -71.266  51.860  1
322836  97.088  -71.272  51.825  1
322837  97.125  -71.276  51.788  1
322838  97.154  -71.290  51.751  1
322839  97.182  -71.303  51.713  1
322840  97.218  -71.315  51.676  1
322841  97.253  -71.328  51.640  1
322842  97.289  -71.340  51.606  1
322843  97.324  -71.352  51.574  1
322844  97.360  -71.364  51.547  1
322845  97.395  -71.376  51.518  1
322846  97.430  -71.388  51.491  1
322847  97.466  -71.400  51.463  1
322848  97.501  -71.412  51.432  1
322849  97.537  -71.425  51.394  1
322850  97.572  -71.437  51.358  1
322851  97.608  -71.449  51.322  1
322852  97.643  -71.461  51.289  1
322853  97.678  -71.473  51.257  1
322854  97.714  -71.485  51.224  1
322855  97.749  -71.497  51.189  1
322856  97.786  -71.504  51.153  1
322857  97.822  -71.512  51.118  1
322858  97.859  -71.519  51.085  1
322859  97.895  -71.525  51.055  1
322860  97.932  -71.533  51.025  1
322861  97.968  -71.540  50.991  1
322862  98.005  -71.547  50.948  1
322863  98.034  -71.550  50.900  1
322864  98.059  -71.551  50.851  1
322865  98.085  -71.555  50.800  1
322866  98.111  -71.563  50.752  1
322867  98.140  -71.571  50.712  1
322868  98.167  -71.578  50.674  1
322869  98.196  -71.586  50.633  1
322870  98.223  -71.594  50.590  1
322871  98.251  -71.602  50.541  1
322872  98.279  -71.610  50.489  1
322873  98.307  -71.618  50.435  1
322874  98.335  -71.625  50.378  1
322875  98.363  -71.633  50.319  1
322876  98.390  -71.641  50.260  1
322877  98.424  -71.654  50.201  1
322878  98.465  -71.677  50.141  1
322879  98.507  -71.701  50.080  1
322880  98.548  -71.725  50.019  1
322881  98.591  -71.733  49.960  1
322882  98.630  -71.741  49.901  1
322883  98.663  -71.748  49.844  1
322884  98.696  -71.754  49.784  1
322885  98.729  -71.761  49.724  1
322886  98.761  -71.764  49.665  1
322887  98.793  -71.763  49.607  1
322888  98.825  -71.761  49.549  1
322889  98.856  -71.760  49.492  1
322890  98.888  -71.759  49.435  1
322891  98.920  -71.757  49.379  1
322892  98.951  -71.756  49.325  1
322893  98.980  -71.766  49.270  1
322894  99.006  -71.781  49.216  1
322895  99.033  -71.796  49.162  1
322896  99.060  -71.811  49.109  1
322897  99.086  -71.826  49.056  1
322898  99.113  -71.842  49.004  1
322899  99.136  -71.839  48.953  1
322900  99.169  -71.852  48.901  1
322901  99.201  -71.866  48.851  1
322902  99.233  -71.879  48.800  1
322903  99.266  -71.893  48.749  1
322904  99.298  -71.907  48.699  1
322905  99.330  -71.920  48.649  1
322906  99.357  -71.932  48.598  1
322907  99.385  -71.945  48.546  1
322908  99.413  -71.958  48.497  1
322909  99.440  -71.971  48.448  1
322910  99.476  -71.984  48.401  1
322911  99.517  -71.997  48.354  1
322912  99.558  -72.010  48.306  1
322913  99.600  -72.011  48.260  1
322914  99.643  -72.011  48.216  1
322915  99.687  -72.013  48.172  1
322916  99.737  -72.017  48.127  1
322917  99.787  -72.020  48.083  1
322918  99.837  -72.023  48.040  1
322919  99.887  -72.027  47.996  1
322920  99.937  -72.031  47.952  1
322921  99.987  -72.035  47.910  1
322922  100.034  -72.045  47.868  1
322923  100.079  -72.058  47.827  1
322924  100.117  -72.070  47.786  1
322925  100.151  -72.082  47.745  1
322926  100.179  -72.090  47.704  1
322927  100.206  -72.099  47.665  1
322928  100.233  -72.106  47.627  1
322929  100.259  -72.120  47.589  1
322930  100.283  -72.136  47.551  1
322931  100.308  -72.151  47.513  1
322932  100.333  -72.167  47.475  1
322933  100.358  -72.182  47.438  1
322934  100.382  -72.198  47.402  1
322935  100.407  -72.213  47.368  1
322936  100.440  -72.235  47.334  1
322937  100.477  -72.259  47.301  1
322938  100.514  -72.283  47.270  1
322939  100.548  -72.296  47.238  1
322940  100.579  -72.286  47.208  1
322941  100.609  -72.275  47.179  1
322942  100.640  -72.282  47.150  1
322943  100.673  -72.299  47.121  1
322944  100.705  -72.318  47.089  1
322945  100.737  -72.336  47.053  1
322946  100.769  -72.353  47.015  1
322947  100.802  -72.371  46.976  1
322948  100.833  -72.379  46.936  1
322949  100.863  -72.388  46.895  1
322950  100.894  -72.396  46.852  1
322951  100.925  -72.406  46.809  1
322952  100.956  -72.414  46.766  1
322953  100.987  -72.423  46.723  1
322954  101.018  -72.431  46.681  1
322955  101.049  -72.440  46.639  1
322956  101.079  -72.449  46.598  1
322957  101.114  -72.462  46.558  1
322958  101.150  -72.478  46.517  1
322959  101.185  -72.492  46.478  1
322960  101.221  -72.506  46.438  1
322961  101.259  -72.515  46.398  1
322962  101.299  -72.522  46.358  1
322963  101.337  -72.528  46.318  1
322964  101.376  -72.536  46.280  1
322965  101.415  -72.543  46.241  1
322966  101.454  -72.550  46.201  1
322967  101.492  -72.557  46.161  1
322968  101.531  -72.564  46.122  1
322969  101.570  -72.571  46.083  1
322970  101.603  -72.584  46.044  1
322971  101.635  -72.597  46.006  1
322972  101.667  -72.610  45.967  1
322973  101.699  -72.624  45.928  1
322974  101.732  -72.637  45.890  1
322975  101.754  -72.646  45.853  1
322976  101.771  -72.653  45.815  1
322977  101.789  -72.659  45.777  1
322978  101.807  -72.666  45.739  1
322979  101.824  -72.673  45.702  1
322980  101.838  -72.685  45.665  1
322981  101.852  -72.698  45.627  1
322982  101.866  -72.710  45.590  1
322983  101.893  -72.723  45.553  1
322984  101.934  -72.737  45.519  1
322985  101.973  -72.750  45.483  1
322986  102.013  -72.763  45.448  1
322987  102.053  -72.776  45.413  1
322988  102.096  -72.787  45.378  1
322989  102.138  -72.796  45.344  1
322990  102.164  -72.797  45.309  1
323371  91.895  -71.027  55.313  3
323372  91.926  -71.037  55.299  3
323373  91.956  -71.047  55.283  3
323374  91.987  -71.058  55.267  3
323375  92.017  -71.068  55.250  3
323376  92.048  -71.078  55.235  3
323377  92.079  -71.089  55.218  3
323378  92.109  -71.099  55.201  3
323379  92.140  -71.109  55.183  3
323380  92.171  -71.120  55.165  3
323381  92.202  -71.130  55.146  3
323382  92.237  -71.140  55.127  3
323383  92.278  -71.151  55.108  3
323384  92.305  -71.159  55.088  3
323385  92.333  -71.168  55.067  3
323386  92.360  -71.176  55.046  3
323387  92.388  -71.184  55.024  3
323388  92.415  -71.193  55.002  3
323389  92.443  -71.201  54.978  3
323390  92.471  -71.209  54.955  3
323391  92.498  -71.218  54.930  3
323392  92.531  -71.218  54.903  3
323393  92.579  -71.207  54.875  3
323472  94.784  -70.720  52.682  1
323473  94.810  -70.715  52.667  1
323474  94.836  -70.709  52.652  1
323475  94.861  -70.704  52.637  1
323476  94.887  -70.698  52.621  1
323477  94.913  -70.692  52.607  1
323478  94.939  -70.686  52.595  1
323479  94.965  -70.681  52.583  1
323480  94.990  -70.675  52.570  1
323481  95.011  -70.670  52.558  1
323482  95.036  -70.681  52.546  1
323483  95.062  -70.695  52.534  1
323484  95.071  -70.717  52.522  1
323485  95.108  -70.735  52.511  1
323486  95.145  -70.753  52.499  1
323487  95.182  -70.771  52.487  1
323488  95.219  -70.789  52.476  1
323489  95.256  -70.807  52.464  1
323490  95.293  -70.825  52.450  1
323491  95.330  -70.843  52.436  1
323492  95.367  -70.861  52.422  1
323493  95.404  -70.880  52.409  1
323494  95.441  -70.897  52.395  1
323495  95.478  -70.915  52.381  1
323496  95.515  -70.933  52.367  1
323497  95.552  -70.952  52.354  1
323498  95.589  -70.969  52.341  1
323499  95.625  -70.987  52.328  1
323500  95.663  -71.005  52.316  1
323501  95.699  -71.024  52.304  1
323502  95.737  -71.041  52.292  1
323503  95.768  -71.050  52.281  1
323504  95.796  -71.015  52.269  1
323505  95.823  -70.981  52.257  1
323506  95.850  -70.947  52.245  1
323507  95.870  -70.920  52.234  1
323508  95.874  -70.909  52.226  1
323509  95.877  -70.898  52.220  1
323510  95.894  -70.896  52.216  1
323511  95.949  -70.911  52.212  1
323512  96.003  -70.925  52.210  1
323513  96.058  -70.939  52.208  1
323514  96.112  -70.954  52.208  1
323515  96.167  -70.969  52.212  1
323516  96.221  -70.983  52.218  1
323517  96.275  -70.998  52.218  1
323518  96.330  -71.012  52.217  1
323519  96.384  -71.027  52.215  1
323520  96.439  -71.041  52.211  1
323521  96.493  -71.054  52.204  1
323522  96.548  -71.068  52.194  1
323523  96.624  -71.074  52.182  1
323524  96.662  -71.093  52.164  1
323525  96.699  -71.111  52.145  1
323526  96.736  -71.129  52.126  1
323527  96.773  -71.147  52.108  1
323528  96.810  -71.165  52.089  1
323529  96.839  -71.178  52.071  1
323530  96.868  -71.191  52.049  1
323531  96.900  -71.199  52.024  1
323532  96.933  -71.205  51.995  1
323533  96.965  -71.212  51.963  1
323534  96.998  -71.218  51.932  1
323535  97.031  -71.225  51.901  1
323536  97.066  -71.231  51.869  1
323537  97.104  -71.233  51.834  1
323538  97.142  -71.237  51.797  1
323539  97.171  -71.250  51.760  1
323540  97.199  -71.264  51.723  1
323541  97.228  -71.278  51.687  1
323542  97.256  -71.291  51.653  1
323543  97.287  -71.304  51.622  1
323544  97.322  -71.316  51.594  1
323545  97.358  -71.328  51.569  1
323546  97.393  -71.340  51.543  1
323547  97.429  -71.353  51.518  1
323548  97.464  -71.365  51.491  1
323549  97.499  -71.377  51.460  1
323550  97.535  -71.389  51.422  1
323551  97.570  -71.401  51.384  1
323552  97.606  -71.413  51.348  1
323553  97.641  -71.425  51.314  1
323554  97.677  -71.437  51.282  1
323555  97.712  -71.450  51.248  1
323556  97.747  -71.462  51.211  1
323557  97.784  -71.470  51.173  1
323558  97.820  -71.477  51.136  1
323559  97.857  -71.484  51.100  1
323560  97.893  -71.491  51.066  1
323561  97.930  -71.498  51.033  1
323562  97.966  -71.505  50.999  1
323563  98.003  -71.512  50.956  1
323564  98.039  -71.519  50.909  1
323565  98.071  -71.523  50.860  1
323566  98.096  -71.525  50.810  1
323567  98.124  -71.534  50.766  1
323568  98.151  -71.541  50.725  1
323569  98.179  -71.550  50.686  1
323570  98.207  -71.557  50.646  1
323571  98.235  -71.565  50.604  1
323572  98.263  -71.573  50.556  1
323573  98.291  -71.581  50.504  1
323574  98.319  -71.588  50.448  1
323575  98.347  -71.596  50.390  1
323576  98.374  -71.604  50.332  1
323577  98.403  -71.612  50.272  1
323578  98.432  -71.621  50.212  1
323579  98.473  -71.644  50.151  1
323580  98.515  -71.669  50.088  1
323581  98.557  -71.678  50.026  1
323582  98.600  -71.686  49.965  1
323583  98.638  -71.694  49.904  1
323584  98.671  -71.701  49.846  1
323585  98.704  -71.707  49.787  1
323586  98.737  -71.714  49.729  1
323587  98.771  -71.721  49.670  1
323588  98.803  -71.728  49.612  1
323589  98.836  -71.730  49.553  1
323590  98.867  -71.729  49.495  1
323591  98.899  -71.728  49.438  1
323592  98.931  -71.726  49.382  1
323593  98.962  -71.725  49.326  1
323594  98.992  -71.732  49.271  1
323595  99.018  -71.747  49.216  1
323596  99.045  -71.762  49.162  1
323597  99.072  -71.777  49.110  1
323598  99.098  -71.792  49.058  1
323599  99.125  -71.807  49.006  1
323600  99.152  -71.823  48.954  1
323601  99.178  -71.838  48.903  1
323602  99.205  -71.832  48.853  1
323603  99.237  -71.845  48.803  1
323604  99.270  -71.858  48.752  1
323605  99.302  -71.872  48.702  1
323606  99.331  -71.885  48.651  1
323607  99.359  -71.898  48.600  1
323608  99.386  -71.911  48.548  1
323609  99.414  -71.923  48.499  1
323610  99.442  -71.936  48.450  1
323611  99.470  -71.948  48.402  1
323612  99.510  -71.955  48.355  1
323613  99.560  -71.959  48.308  1
323614  99.610  -71.963  48.262  1
323615  99.660  -71.966  48.217  1
323616  99.710  -71.970  48.173  1
323617  99.760  -71.973  48.128  1
323618  99.810  -71.977  48.084  1
323619  99.860  -71.980  48.041  1
323620  99.910  -71.984  47.998  1
323621  99.960  -71.988  47.955  1
323622  100.007  -71.996  47.912  1
323623  100.053  -72.009  47.870  1
323624  100.090  -72.021  47.830  1
323625  100.127  -72.033  47.789  1
323626  100.163  -72.046  47.748  1
323627  100.190  -72.055  47.708  1
323628  100.217  -72.062  47.669  1
323629  100.245  -72.070  47.631  1
323630  100.272  -72.079  47.593  1
323631  100.299  -72.087  47.556  1
323632  100.327  -72.097  47.518  1
323633  100.351  -72.112  47.481  1
323634  100.376  -72.128  47.443  1
323635  100.401  -72.143  47.408  1
323636  100.426  -72.159  47.374  1
323637  100.454  -72.177  47.340  1
323638  100.490  -72.201  47.308  1
323639  100.527  -72.225  47.277  1
323640  100.563  -72.249  47.247  1
323641  100.596  -72.253  47.217  1
323642  100.627  -72.243  47.188  1
323643  100.659  -72.261  47.159  1
323644  100.691  -72.279  47.128  1
323645  100.723  -72.296  47.095  1
323646  100.754  -72.307  47.058  1
323647  100.785  -72.315  47.021  1
323648  100.816  -72.324  46.982  1
323649  100.847  -72.333  46.942  1
323650  100.878  -72.342  46.902  1
323651  100.909  -72.350  46.861  1
323652  100.939  -72.359  46.819  1
323653  100.971  -72.368  46.776  1
323654  101.001  -72.377  46.734  1
323655  101.032  -72.385  46.693  1
323656  101.063  -72.394  46.652  1
323657  101.095  -72.403  46.611  1
323658  101.130  -72.418  46.571  1
323659  101.165  -72.433  46.531  1
323660  101.201  -72.448  46.492  1
323661  101.237  -72.462  46.452  1
323662  101.273  -72.476  46.412  1
323663  101.312  -72.483  46.373  1
323664  101.350  -72.490  46.333  1
323665  101.389  -72.497  46.294  1
323666  101.428  -72.504  46.254  1
323667  101.467  -72.511  46.214  1
323668  101.505  -72.519  46.173  1
323669  101.545  -72.525  46.135  1
323670  101.584  -72.532  46.095  1
323671  101.616  -72.546  46.056  1
323672  101.648  -72.559  46.017  1
323673  101.680  -72.572  45.978  1
323674  101.712  -72.585  45.940  1
323675  101.744  -72.599  45.902  1
323676  101.775  -72.612  45.863  1
323677  101.793  -72.618  45.825  1
323678  101.811  -72.625  45.788  1
323679  101.828  -72.631  45.750  1
323680  101.845  -72.640  45.712  1
323681  101.859  -72.652  45.675  1
323682  101.873  -72.665  45.638  1
323683  101.887  -72.677  45.601  1
323684  101.906  -72.690  45.565  1
323685  101.946  -72.703  45.529  1
323686  101.986  -72.716  45.494  1
323687  102.026  -72.729  45.459  1
323688  102.066  -72.743  45.425  1
323689  102.109  -72.753  45.390  1
323690  102.147  -72.760  45.355  1
323691  102.172  -72.760  45.322  1
323692  102.197  -72.761  45.289  1
324069  91.799  -70.967  55.356  3
324070  91.829  -70.977  55.341  3
324071  91.860  -70.987  55.327  3
324072  91.891  -70.998  55.313  3
324073  91.921  -71.008  55.299  3
324074  91.952  -71.018  55.284  3
324075  91.983  -71.028  55.267  3
324076  92.013  -71.039  55.252  3
324077  92.044  -71.049  55.237  3
324078  92.075  -71.059  55.220  3
324079  92.105  -71.070  55.204  3
324080  92.136  -71.080  55.186  3
324081  92.167  -71.090  55.168  3
324082  92.197  -71.101  55.149  3
324083  92.234  -71.111  55.131  3
324084  92.270  -71.121  55.113  3
324085  92.298  -71.130  55.093  3
324086  92.325  -71.138  55.074  3
324087  92.353  -71.146  55.053  3
324088  92.380  -71.155  55.031  3
324089  92.408  -71.163  55.009  3
324090  92.435  -71.171  54.987  3
324091  92.463  -71.179  54.962  3
324092  92.490  -71.187  54.938  3
324093  92.529  -71.183  54.912  3
324094  92.577  -71.172  54.884  3
324095  92.624  -71.162  54.855  3
324096  92.671  -71.151  54.825  3
324097  92.719  -71.140  54.795  3
324172  94.753  -70.692  52.699  1
324173  94.779  -70.686  52.686  1
324174  94.805  -70.681  52.673  1
324175  94.831  -70.675  52.658  1
324176  94.856  -70.670  52.643  1
324177  94.882  -70.663  52.629  1
324178  94.908  -70.658  52.614  1
324179  94.934  -70.653  52.603  1
324180  94.960  -70.647  52.592  1
324181  94.985  -70.641  52.580  1
324182  95.011  -70.635  52.569  1
324183  95.034  -70.635  52.558  1
324184  95.050  -70.654  52.546  1
324185  95.087  -70.672  52.535  1
324186  95.123  -70.689  52.523  1
324187  95.161  -70.707  52.512  1
324188  95.197  -70.726  52.500  1
324189  95.234  -70.743  52.488  1
324190  95.271  -70.761  52.477  1
324191  95.308  -70.779  52.463  1
324192  95.345  -70.798  52.449  1
324193  95.382  -70.815  52.435  1
324194  95.419  -70.833  52.421  1
324195  95.456  -70.851  52.407  1
324196  95.494  -70.870  52.391  1
324197  95.531  -70.889  52.378  1
324198  95.569  -70.907  52.364  1
324199  95.606  -70.925  52.350  1
324200  95.644  -70.944  52.338  1
324201  95.682  -70.962  52.325  1
324202  95.719  -70.980  52.313  1
324203  95.757  -70.999  52.300  1
324204  95.791  -71.006  52.288  1
324205  95.824  -70.988  52.275  1
324206  95.861  -70.952  52.263  1
324207  95.889  -70.917  52.251  1
324208  95.916  -70.883  52.240  1
324209  95.920  -70.871  52.230  1
324210  95.916  -70.862  52.224  1
324211  95.917  -70.866  52.218  1
324212  95.957  -70.880  52.214  1
324213  96.012  -70.895  52.210  1
324214  96.066  -70.910  52.207  1
324215  96.120  -70.924  52.205  1
324216  96.175  -70.939  52.206  1
324217  96.229  -70.953  52.208  1
324218  96.284  -70.967  52.207  1
324219  96.338  -70.982  52.205  1
324220  96.392  -70.996  52.202  1
324221  96.447  -71.011  52.198  1
324222  96.502  -71.024  52.190  1
324223  96.557  -71.037  52.180  1
324224  96.612  -71.050  52.167  1
324225  96.677  -71.060  52.151  1
324226  96.715  -71.078  52.132  1
324227  96.752  -71.096  52.115  1
324228  96.789  -71.115  52.097  1
324229  96.821  -71.130  52.079  1
324230  96.850  -71.143  52.063  1
324231  96.878  -71.155  52.044  1
324232  96.909  -71.165  52.022  1
324233  96.942  -71.171  51.996  1
324234  96.975  -71.178  51.965  1
324235  97.007  -71.185  51.935  1
324236  97.043  -71.190  51.905  1
324237  97.083  -71.192  51.873  1
324238  97.121  -71.193  51.838  1
324239  97.159  -71.197  51.802  1
324240  97.188  -71.211  51.767  1
324241  97.217  -71.224  51.732  1
324242  97.245  -71.238  51.697  1
324243  97.274  -71.252  51.665  1
324244  97.302  -71.265  51.637  1
324245  97.331  -71.278  51.611  1
324246  97.360  -71.292  51.590  1
324247  97.391  -71.305  51.568  1
324248  97.427  -71.317  51.544  1
324249  97.462  -71.329  51.518  1
324250  97.498  -71.341  51.488  1
324251  97.533  -71.353  51.450  1
324252  97.568  -71.365  51.411  1
324253  97.604  -71.378  51.374  1
324254  97.639  -71.390  51.340  1
324255  97.675  -71.402  51.307  1
324256  97.710  -71.414  51.272  1
324257  97.746  -71.426  51.234  1
324258  97.782  -71.435  51.195  1
324259  97.818  -71.442  51.156  1
324260  97.855  -71.449  51.117  1
324261  97.891  -71.456  51.078  1
324262  97.928  -71.463  51.040  1
324263  97.964  -71.470  51.004  1
324264  98.001  -71.478  50.961  1
324265  98.037  -71.484  50.915  1
324266  98.074  -71.491  50.868  1
324267  98.107  -71.497  50.823  1
324268  98.135  -71.505  50.781  1
324269  98.163  -71.513  50.741  1
324270  98.191  -71.520  50.701  1
324271  98.219  -71.528  50.660  1
324272  98.247  -71.536  50.617  1
324273  98.275  -71.544  50.569  1
324274  98.303  -71.551  50.517  1
324275  98.331  -71.560  50.462  1
324276  98.358  -71.567  50.404  1
324277  98.386  -71.575  50.345  1
324278  98.414  -71.582  50.285  1
324279  98.442  -71.591  50.223  1
324280  98.482  -71.611  50.162  1
324281  98.524  -71.623  50.098  1
324282  98.566  -71.631  50.035  1
324283  98.608  -71.639  49.973  1
324284  98.647  -71.647  49.914  1
324285  98.680  -71.654  49.854  1
324286  98.713  -71.660  49.795  1
324287  98.746  -71.667  49.736  1
324288  98.779  -71.674  49.677  1
324289  98.812  -71.681  49.618  1
324290  98.845  -71.688  49.559  1
324291  98.878  -71.694  49.500  1
324292  98.911  -71.697  49.442  1
324293  98.942  -71.695  49.386  1
324294  98.974  -71.694  49.329  1
324295  99.004  -71.698  49.273  1
324296  99.030  -71.713  49.217  1
324297  99.057  -71.728  49.163  1
324298  99.084  -71.743  49.111  1
324299  99.111  -71.758  49.059  1
324300  99.137  -71.773  49.007  1
324301  99.164  -71.788  48.955  1
324302  99.190  -71.804  48.904  1
324303  99.217  -71.819  48.854  1
324304  99.241  -71.810  48.805  1
324305  99.274  -71.824  48.754  1
324306  99.305  -71.837  48.703  1
324307  99.333  -71.850  48.652  1
324308  99.360  -71.863  48.601  1
324309  99.388  -71.875  48.550  1
324310  99.420  -71.886  48.501  1
324311  99.453  -71.897  48.452  1
324312  99.487  -71.907  48.404  1
324313  99.533  -71.912  48.357  1
324314  99.583  -71.916  48.310  1
324315  99.633  -71.920  48.264  1
324316  99.683  -71.923  48.219  1
324317  99.733  -71.926  48.175  1
324318  99.783  -71.930  48.129  1
324319  99.833  -71.933  48.086  1
324320  99.883  -71.937  48.043  1
324321  99.932  -71.941  48.000  1
324322  99.981  -71.947  47.957  1
324323  100.026  -71.961  47.914  1
324324  100.065  -71.973  47.874  1
324325  100.101  -71.985  47.833  1
324326  100.137  -71.997  47.793  1
324327  100.173  -72.010  47.752  1
324328  100.202  -72.018  47.712  1
324329  100.229  -72.026  47.673  1
324330  100.257  -72.035  47.635  1
324331  100.284  -72.043  47.597  1
324332  100.312  -72.052  47.561  1
324333  100.339  -72.060  47.524  1
324334  100.366  -72.068  47.487  1
324335  100.394  -72.077  47.449  1
324336  100.419  -72.089  47.415  1
324337  100.444  -72.105  47.380  1
324338  100.469  -72.121  47.346  1
324339  100.503  -72.142  47.315  1
324340  100.540  -72.167  47.285  1
324341  100.576  -72.191  47.256  1
324342  100.613  -72.215  47.227  1
324343  100.645  -72.221  47.199  1
324344  100.676  -72.235  47.170  1
324345  100.707  -72.243  47.136  1
324346  100.738  -72.252  47.101  1
324347  100.769  -72.261  47.063  1
324348  100.800  -72.270  47.024  1
324349  100.831  -72.278  46.987  1
324350  100.861  -72.287  46.948  1
324351  100.893  -72.296  46.908  1
324352  100.923  -72.304  46.867  1
324353  100.954  -72.313  46.827  1
324354  100.985  -72.321  46.787  1
324355  101.016  -72.330  46.748  1
324356  101.047  -72.339  46.707  1
324357  101.078  -72.348  46.668  1
324358  101.111  -72.359  46.627  1
324359  101.146  -72.374  46.587  1
324360  101.182  -72.389  46.547  1
324361  101.217  -72.403  46.507  1
324362  101.252  -72.418  46.466  1
324363  101.288  -72.433  46.426  1
324364  101.325  -72.444  46.387  1
324365  101.363  -72.451  46.348  1
324366  101.402  -72.459  46.308  1
324367  101.441  -72.465  46.268  1
324368  101.480  -72.472  46.228  1
324369  101.519  -72.480  46.187  1
324370  101.558  -72.487  46.147  1
324371  101.597  -72.494  46.107  1
324372  101.628  -72.507  46.067  1
324373  101.661  -72.521  46.028  1
324374  101.693  -72.534  45.989  1
324375  101.725  -72.547  45.951  1
324376  101.757  -72.560  45.912  1
324377  101.789  -72.574  45.873  1
324378  101.814  -72.584  45.836  1
324379  101.832  -72.591  45.799  1
324380  101.850  -72.597  45.761  1
324381  101.866  -72.606  45.723  1
324382  101.880  -72.619  45.685  1
324383  101.894  -72.631  45.649  1
324384  101.907  -72.644  45.613  1
324385  101.921  -72.656  45.577  1
324386  101.959  -72.669  45.541  1
324387  101.999  -72.683  45.506  1
324388  102.039  -72.696  45.471  1
324389  102.079  -72.709  45.437  1
324390  102.122  -72.719  45.402  1
324391  102.155  -72.723  45.368  1
324392  102.180  -72.724  45.334  1
324393  102.204  -72.725  45.302  1
324394  102.229  -72.725  45.268  1
324395  102.254  -72.726  45.235  1
324770  91.795  -70.937  55.354  3
324771  91.825  -70.948  55.341  3
324772  91.856  -70.958  55.327  3
324773  91.886  -70.968  55.312  3
324774  91.917  -70.979  55.299  3
324775  91.948  -70.989  55.284  3
324776  91.979  -70.999  55.268  3
324777  92.009  -71.010  55.253  3
324778  92.040  -71.020  55.238  3
324779  92.071  -71.030  55.222  3
324780  92.101  -71.041  55.207  3
324781  92.132  -71.051  55.190  3
324782  92.162  -71.061  55.172  3
324783  92.193  -71.071  55.153  3
324784  92.230  -71.083  55.136  3
324785  92.263  -71.092  55.118  3
324786  92.290  -71.099  55.099  3
324787  92.317  -71.108  55.080  3
324788  92.345  -71.116  55.059  3
324789  92.373  -71.124  55.038  3
324790  92.400  -71.133  55.016  3
324791  92.428  -71.141  54.994  3
324792  92.455  -71.149  54.970  3
324793  92.482  -71.157  54.946  3
324794  92.527  -71.149  54.920  3
324795  92.574  -71.138  54.892  3
324796  92.622  -71.127  54.863  3
324797  92.669  -71.117  54.833  3
324798  92.717  -71.106  54.803  3
324799  92.764  -71.095  54.770  3
324800  92.811  -71.084  54.737  3
324873  94.749  -70.658  52.704  1
324874  94.774  -70.653  52.691  1
324875  94.800  -70.647  52.678  1
324876  94.826  -70.641  52.665  1
324877  94.852  -70.635  52.651  1
324878  94.878  -70.630  52.637  1
324879  94.903  -70.624  52.623  1
324880  94.929  -70.619  52.613  1
324881  94.955  -70.613  52.602  1
324882  94.981  -70.607  52.590  1
324883  95.006  -70.601  52.579  1
324884  95.032  -70.596  52.569  1
324885  95.065  -70.607  52.558  1
324886  95.102  -70.626  52.547  1
324887  95.140  -70.644  52.537  1
324888  95.177  -70.663  52.526  1
324889  95.215  -70.682  52.514  1
324890  95.253  -70.700  52.503  1
324891  95.290  -70.718  52.490  1
324892  95.328  -70.737  52.477  1
324893  95.366  -70.755  52.462  1
324894  95.403  -70.773  52.448  1
324895  95.441  -70.792  52.434  1
324896  95.478  -70.811  52.419  1
324897  95.516  -70.829  52.403  1
324898  95.553  -70.848  52.387  1
324899  95.591  -70.866  52.373  1
324900  95.628  -70.884  52.359  1
324901  95.666  -70.903  52.346  1
324902  95.703  -70.921  52.334  1
324903  95.741  -70.939  52.321  1
324904  95.779  -70.958  52.308  1
324905  95.809  -70.955  52.295  1
324906  95.838  -70.949  52.282  1
324907  95.873  -70.928  52.268  1
324908  95.913  -70.891  52.255  1
324909  95.954  -70.853  52.244  1
324910  95.960  -70.835  52.233  1
324911  95.943  -70.829  52.226  1
324912  95.948  -70.835  52.220  1
324913  95.973  -70.850  52.214  1
324914  96.020  -70.865  52.209  1
324915  96.075  -70.880  52.205  1
324916  96.129  -70.894  52.201  1
324917  96.183  -70.908  52.199  1
324918  96.238  -70.923  52.198  1
324919  96.292  -70.937  52.194  1
324920  96.346  -70.952  52.191  1
324921  96.401  -70.966  52.188  1
324922  96.455  -70.980  52.183  1
324923  96.510  -70.993  52.175  1
324924  96.565  -71.006  52.163  1
324925  96.620  -71.020  52.151  1
324926  96.675  -71.033  52.137  1
324927  96.730  -71.046  52.119  1
324928  96.767  -71.064  52.101  1
324929  96.802  -71.080  52.083  1
324930  96.831  -71.093  52.067  1
324931  96.860  -71.106  52.054  1
324932  96.889  -71.119  52.037  1
324933  96.919  -71.130  52.017  1
324934  96.951  -71.137  51.992  1
324935  96.984  -71.144  51.964  1
324936  97.021  -71.148  51.935  1
324937  97.061  -71.150  51.905  1
324938  97.099  -71.152  51.873  1
324939  97.139  -71.154  51.839  1
324940  97.176  -71.158  51.805  1
324941  97.205  -71.171  51.771  1
324942  97.233  -71.185  51.738  1
324943  97.262  -71.199  51.706  1
324944  97.291  -71.212  51.677  1
324945  97.319  -71.226  51.651  1
324946  97.348  -71.239  51.628  1
324947  97.377  -71.252  51.610  1
324948  97.405  -71.266  51.591  1
324949  97.434  -71.280  51.569  1
324950  97.462  -71.293  51.544  1
324951  97.496  -71.306  51.515  1
324952  97.531  -71.318  51.477  1
324953  97.567  -71.330  51.438  1
324954  97.602  -71.342  51.401  1
324955  97.637  -71.354  51.365  1
324956  97.673  -71.366  51.332  1
324957  97.708  -71.378  51.296  1
324958  97.744  -71.390  51.258  1
324959  97.780  -71.400  51.216  1
324960  97.816  -71.407  51.176  1
324961  97.853  -71.415  51.134  1
324962  97.889  -71.422  51.091  1
324963  97.926  -71.428  51.049  1
324964  97.962  -71.436  51.010  1
324965  97.999  -71.443  50.967  1
324966  98.035  -71.450  50.923  1
324967  98.073  -71.454  50.879  1
324968  98.108  -71.458  50.837  1
324969  98.137  -71.466  50.796  1
324970  98.166  -71.475  50.756  1
324971  98.195  -71.484  50.716  1
324972  98.223  -71.492  50.673  1
324973  98.252  -71.500  50.629  1
324974  98.281  -71.509  50.580  1
324975  98.309  -71.517  50.528  1
324976  98.338  -71.526  50.474  1
324977  98.367  -71.534  50.417  1
324978  98.395  -71.543  50.357  1
324979  98.424  -71.551  50.296  1
324980  98.452  -71.560  50.234  1
324981  98.490  -71.568  50.172  1
324982  98.532  -71.576  50.108  1
324983  98.575  -71.585  50.044  1
324984  98.618  -71.593  49.983  1
324985  98.656  -71.600  49.925  1
324986  98.689  -71.607  49.866  1
324987  98.722  -71.613  49.805  1
324988  98.755  -71.620  49.744  1
324989  98.788  -71.627  49.684  1
324990  98.821  -71.634  49.624  1
324991  98.854  -71.641  49.565  1
324992  98.887  -71.647  49.506  1
324993  98.920  -71.654  49.447  1
324994  98.953  -71.661  49.390  1
324995  98.985  -71.663  49.332  1
324996  99.016  -71.664  49.276  1
324997  99.043  -71.679  49.220  1
324998  99.069  -71.694  49.165  1
324999  99.096  -71.710  49.112  1
325000  99.123  -71.725  49.060  1
325001  99.149  -71.740  49.007  1
325002  99.176  -71.755  48.956  1
325003  99.203  -71.770  48.906  1
325004  99.229  -71.785  48.856  1
325005  99.256  -71.801  48.806  1
325006  99.278  -71.789  48.756  1
325007  99.307  -71.801  48.704  1
325008  99.341  -71.812  48.653  1
325009  99.375  -71.822  48.602  1
325010  99.409  -71.832  48.551  1
325011  99.443  -71.843  48.503  1
325012  99.477  -71.853  48.455  1
325013  99.511  -71.864  48.407  1
325014  99.556  -71.869  48.359  1
325015  99.606  -71.873  48.313  1
325016  99.656  -71.876  48.265  1
325017  99.706  -71.879  48.221  1
325018  99.756  -71.883  48.177  1
325019  99.805  -71.886  48.132  1
325020  99.855  -71.890  48.089  1
325021  99.905  -71.894  48.045  1
325022  99.955  -71.898  48.002  1
325023  100.000  -71.911  47.959  1
325024  100.039  -71.924  47.918  1
325025  100.075  -71.936  47.877  1
325026  100.111  -71.948  47.838  1
325027  100.147  -71.961  47.798  1
325028  100.183  -71.973  47.756  1
325029  100.214  -71.983  47.716  1
325030  100.241  -71.991  47.678  1
325031  100.268  -71.999  47.641  1
325032  100.296  -72.008  47.603  1
325033  100.323  -72.016  47.567  1
325034  100.350  -72.024  47.530  1
325035  100.378  -72.033  47.493  1
325036  100.405  -72.041  47.455  1
325037  100.432  -72.049  47.421  1
325038  100.460  -72.058  47.387  1
325039  100.487  -72.066  47.354  1
325040  100.515  -72.084  47.322  1
325041  100.552  -72.108  47.291  1
325042  100.587  -72.138  47.262  1
325043  100.623  -72.169  47.234  1
325044  100.657  -72.183  47.206  1
325045  100.691  -72.189  47.176  1
325046  100.721  -72.197  47.143  1
325047  100.753  -72.206  47.108  1
325048  100.783  -72.215  47.071  1
325049  100.814  -72.224  47.033  1
325050  100.845  -72.232  46.996  1
325051  100.876  -72.241  46.958  1
325052  100.907  -72.249  46.918  1
325053  100.938  -72.258  46.879  1
325054  100.969  -72.267  46.839  1
325055  100.999  -72.276  46.799  1
325056  101.031  -72.284  46.760  1
325057  101.061  -72.293  46.722  1
325058  101.092  -72.302  46.682  1
325059  101.126  -72.315  46.642  1
325060  101.162  -72.330  46.601  1
325061  101.197  -72.344  46.561  1
325062  101.233  -72.359  46.520  1
325063  101.268  -72.374  46.481  1
325064  101.304  -72.388  46.441  1
325065  101.339  -72.403  46.401  1
325066  101.376  -72.412  46.362  1
325067  101.415  -72.420  46.321  1
325068  101.455  -72.427  46.281  1
325069  101.493  -72.434  46.241  1
325070  101.532  -72.441  46.200  1
325071  101.571  -72.448  46.159  1
325072  101.609  -72.456  46.119  1
325073  101.641  -72.469  46.080  1
325074  101.674  -72.482  46.040  1
325075  101.706  -72.496  46.001  1
325076  101.738  -72.509  45.962  1
325077  101.770  -72.522  45.923  1
325078  101.802  -72.535  45.884  1
325079  101.834  -72.549  45.847  1
325080  101.853  -72.556  45.809  1
325081  101.871  -72.562  45.772  1
325082  101.887  -72.572  45.734  1
325083  101.900  -72.585  45.697  1
325084  101.914  -72.598  45.660  1
325085  101.928  -72.610  45.625  1
325086  101.942  -72.623  45.589  1
325087  101.972  -72.636  45.553  1
325088  102.012  -72.649  45.518  1
325089  102.052  -72.663  45.483  1
325090  102.092  -72.675  45.449  1
325091  102.135  -72.685  45.415  1
325092  102.163  -72.687  45.380  1
325093  102.187  -72.688  45.347  1
325094  102.212  -72.688  45.314  1
325095  102.237  -72.688  45.281  1
325096  102.262  -72.689  45.248  1
325097  102.287  -72.690  45.217  1
325098  102.311  -72.691  45.185  1
325471  91.790  -70.908  55.353  3
325472  91.821  -70.918  55.340  3
325473  91.852  -70.929  55.327  3
325474  91.882  -70.939  55.313  3
325475  91.913  -70.949  55.300  3
325476  91.944  -70.960  55.284  3
325477  91.975  -70.970  55.269  3
325478  92.005  -70.980  55.255  3
325479  92.035  -70.991  55.239  3
325480  92.066  -71.001  55.225  3
325481  92.097  -71.011  55.210  3
325482  92.128  -71.022  55.194  3
325483  92.158  -71.032  55.175  3
325484  92.189  -71.042  55.158  3
325485  92.227  -71.053  55.141  3
325486  92.255  -71.061  55.123  3
325487  92.283  -71.070  55.104  3
325488  92.310  -71.078  55.086  3
325489  92.338  -71.086  55.066  3
325490  92.365  -71.095  55.045  3
325491  92.392  -71.103  55.024  3
325492  92.420  -71.111  55.001  3
325493  92.447  -71.119  54.978  3
325494  92.478  -71.124  54.954  3
325495  92.525  -71.114  54.928  3
325496  92.572  -71.103  54.900  3
325497  92.620  -71.093  54.871  3
325498  92.667  -71.082  54.842  3
325499  92.714  -71.071  54.811  3
325500  92.762  -71.061  54.778  3
325501  92.809  -71.050  54.745  3
325502  92.857  -71.039  54.709  3
325503  92.904  -71.029  54.673  3
325574  94.744  -70.624  52.709  1
325575  94.769  -70.619  52.697  1
325576  94.795  -70.613  52.684  1
325577  94.821  -70.607  52.672  1
325578  94.847  -70.601  52.658  1
325579  94.875  -70.595  52.645  1
325580  94.905  -70.587  52.633  1
325581  94.935  -70.579  52.623  1
325582  94.965  -70.571  52.612  1
325583  94.995  -70.563  52.601  1
325584  95.025  -70.555  52.591  1
325585  95.055  -70.547  52.581  1
325586  95.088  -70.566  52.570  1
325587  95.124  -70.585  52.560  1
325588  95.162  -70.604  52.551  1
325589  95.199  -70.622  52.540  1
325590  95.237  -70.641  52.528  1
325591  95.274  -70.659  52.516  1
325592  95.312  -70.677  52.503  1
325593  95.350  -70.696  52.490  1
325594  95.387  -70.714  52.475  1
325595  95.425  -70.732  52.460  1
325596  95.463  -70.751  52.446  1
325597  95.500  -70.770  52.431  1
325598  95.538  -70.788  52.415  1
325599  95.576  -70.807  52.399  1
325600  95.613  -70.825  52.384  1
325601  95.651  -70.843  52.370  1
325602  95.688  -70.862  52.356  1
325603  95.726  -70.880  52.342  1
325604  95.763  -70.898  52.329  1
325605  95.798  -70.909  52.316  1
325606  95.827  -70.904  52.302  1
325607  95.856  -70.898  52.289  1
325608  95.886  -70.892  52.275  1
325609  95.921  -70.869  52.261  1
325610  95.962  -70.831  52.249  1
325611  95.987  -70.802  52.238  1
325612  95.970  -70.797  52.230  1
325613  95.979  -70.804  52.223  1
325614  96.004  -70.820  52.215  1
325615  96.029  -70.835  52.208  1
325616  96.083  -70.849  52.201  1
325617  96.137  -70.864  52.194  1
325618  96.191  -70.878  52.188  1
325619  96.246  -70.892  52.185  1
325620  96.301  -70.907  52.182  1
325621  96.355  -70.921  52.179  1
325622  96.409  -70.936  52.177  1
325623  96.464  -70.949  52.171  1
325624  96.519  -70.963  52.161  1
325625  96.574  -70.976  52.149  1
325626  96.628  -70.989  52.135  1
325627  96.683  -71.002  52.120  1
325628  96.739  -71.015  52.103  1
325629  96.784  -71.032  52.087  1
325630  96.813  -71.045  52.070  1
325631  96.842  -71.058  52.055  1
325632  96.871  -71.071  52.042  1
325633  96.899  -71.083  52.026  1
325634  96.928  -71.096  52.007  1
325635  96.960  -71.104  51.985  1
325636  96.999  -71.106  51.957  1
325637  97.038  -71.108  51.928  1
325638  97.077  -71.111  51.900  1
325639  97.116  -71.113  51.871  1
325640  97.156  -71.115  51.836  1
325641  97.193  -71.119  51.805  1
325642  97.222  -71.132  51.773  1
325643  97.250  -71.146  51.743  1
325644  97.279  -71.159  51.714  1
325645  97.308  -71.173  51.690  1
325646  97.336  -71.187  51.666  1
325647  97.365  -71.199  51.644  1
325648  97.394  -71.213  51.630  1
325649  97.422  -71.227  51.611  1
325650  97.451  -71.240  51.592  1
325651  97.479  -71.254  51.569  1
325652  97.508  -71.267  51.541  1
325653  97.537  -71.281  51.505  1
325654  97.566  -71.294  51.465  1
325655  97.600  -71.306  51.426  1
325656  97.636  -71.318  51.390  1
325657  97.671  -71.331  51.355  1
325658  97.706  -71.343  51.319  1
325659  97.742  -71.355  51.280  1
325660  97.778  -71.365  51.237  1
325661  97.814  -71.373  51.194  1
325662  97.851  -71.380  51.150  1
325663  97.887  -71.387  51.105  1
325664  97.924  -71.393  51.062  1
325665  97.960  -71.401  51.021  1
325666  97.998  -71.404  50.979  1
325667  98.035  -71.406  50.937  1
325668  98.073  -71.409  50.894  1
325669  98.106  -71.415  50.853  1
325670  98.135  -71.424  50.812  1
325671  98.163  -71.432  50.772  1
325672  98.192  -71.440  50.730  1
325673  98.221  -71.450  50.686  1
325674  98.249  -71.458  50.640  1
325675  98.278  -71.466  50.591  1
325676  98.306  -71.475  50.538  1
325677  98.335  -71.483  50.483  1
325678  98.364  -71.492  50.427  1
325679  98.392  -71.500  50.366  1
325680  98.423  -71.509  50.303  1
325681  98.463  -71.516  50.241  1
325682  98.503  -71.522  50.178  1
325683  98.543  -71.530  50.114  1
325684  98.584  -71.538  50.053  1
325685  98.627  -71.546  49.994  1
325686  98.664  -71.553  49.937  1
325687  98.698  -71.560  49.877  1
325688  98.730  -71.567  49.815  1
325689  98.764  -71.574  49.753  1
325690  98.797  -71.581  49.693  1
325691  98.830  -71.588  49.632  1
325692  98.863  -71.594  49.572  1
325693  98.896  -71.601  49.511  1
325694  98.929  -71.608  49.452  1
325695  98.962  -71.615  49.393  1
325696  98.995  -71.622  49.335  1
325697  99.027  -71.629  49.279  1
325698  99.052  -71.644  49.223  1
325699  99.078  -71.660  49.166  1
325700  99.104  -71.674  49.113  1
325701  99.130  -71.689  49.060  1
325702  99.156  -71.704  49.008  1
325703  99.182  -71.719  48.956  1
325704  99.208  -71.733  48.906  1
325705  99.233  -71.748  48.856  1
325706  99.259  -71.763  48.807  1
325707  99.296  -71.774  48.757  1
325708  99.331  -71.758  48.705  1
325709  99.364  -71.768  48.654  1
325710  99.399  -71.779  48.604  1
325711  99.432  -71.788  48.553  1
325712  99.466  -71.799  48.504  1
325713  99.500  -71.810  48.457  1
325714  99.534  -71.820  48.409  1
325715  99.579  -71.826  48.362  1
325716  99.629  -71.829  48.315  1
325717  99.679  -71.832  48.269  1
325718  99.728  -71.836  48.224  1
325719  99.778  -71.839  48.180  1
325720  99.828  -71.843  48.136  1
325721  99.878  -71.847  48.093  1
325722  99.928  -71.851  48.050  1
325723  99.974  -71.863  48.006  1
325724  100.013  -71.876  47.964  1
325725  100.049  -71.888  47.923  1
325726  100.085  -71.900  47.883  1
325727  100.121  -71.912  47.843  1
325728  100.157  -71.924  47.802  1
325729  100.193  -71.936  47.762  1
325730  100.225  -71.947  47.722  1
325731  100.253  -71.955  47.684  1
325732  100.280  -71.964  47.647  1
325733  100.308  -71.972  47.610  1
325734  100.335  -71.980  47.573  1
325735  100.362  -71.989  47.536  1
325736  100.390  -71.997  47.500  1
325737  100.417  -72.005  47.461  1
325738  100.444  -72.014  47.427  1
325739  100.472  -72.022  47.394  1
325740  100.499  -72.030  47.361  1
325741  100.525  -72.042  47.328  1
325742  100.560  -72.073  47.297  1
325743  100.596  -72.105  47.266  1
325744  100.631  -72.135  47.237  1
325745  100.665  -72.147  47.209  1
325746  100.699  -72.152  47.178  1
325747  100.733  -72.156  47.145  1
325748  100.766  -72.161  47.111  1
325749  100.798  -72.168  47.076  1
325750  100.829  -72.177  47.040  1
325751  100.860  -72.186  47.003  1
325752  100.891  -72.195  46.966  1
325753  100.921  -72.203  46.928  1
325754  100.953  -72.212  46.891  1
325755  100.983  -72.221  46.851  1
325756  101.014  -72.230  46.811  1
325757  101.045  -72.238  46.772  1
325758  101.076  -72.247  46.734  1
325759  101.107  -72.255  46.695  1
325760  101.142  -72.271  46.655  1
325761  101.178  -72.285  46.615  1
325762  101.213  -72.299  46.575  1
325763  101.249  -72.315  46.534  1
325764  101.284  -72.329  46.495  1
325765  101.320  -72.343  46.456  1
325766  101.355  -72.359  46.416  1
325767  101.390  -72.373  46.375  1
325768  101.429  -72.381  46.334  1
325769  101.468  -72.388  46.294  1
325770  101.506  -72.395  46.253  1
325771  101.545  -72.403  46.212  1
325772  101.584  -72.409  46.171  1
325773  101.622  -72.418  46.132  1
325774  101.655  -72.431  46.093  1
325775  101.686  -72.444  46.053  1
325776  101.718  -72.457  46.012  1
325777  101.751  -72.471  45.973  1
325778  101.783  -72.484  45.935  1
325779  101.815  -72.497  45.896  1
325780  101.847  -72.510  45.859  1
325781  101.875  -72.522  45.821  1
325782  101.893  -72.528  45.783  1
325783  101.907  -72.539  45.745  1
325784  101.921  -72.552  45.708  1
325785  101.936  -72.565  45.673  1
325786  101.949  -72.577  45.637  1
325787  101.963  -72.590  45.601  1
325788  101.984  -72.603  45.565  1
325789  102.025  -72.616  45.530  1
325790  102.064  -72.628  45.496  1
325791  102.105  -72.641  45.461  1
325792  102.146  -72.650  45.427  1
325793  102.171  -72.650  45.392  1
325794  102.195  -72.650  45.359  1
325795  102.220  -72.651  45.327  1
325796  102.245  -72.652  45.294  1
325797  102.269  -72.653  45.262  1
325798  102.295  -72.653  45.230  1
325799  102.319  -72.653  45.198  1
325800  102.344  -72.654  45.167  1
326172  91.786  -70.879  55.352  3
326173  91.817  -70.889  55.339  3
326174  91.848  -70.899  55.326  3
326175  91.878  -70.910  55.313  3
326176  91.909  -70.920  55.300  3
326177  91.939  -70.930  55.285  3
326178  91.970  -70.941  55.271  3
326179  92.001  -70.952  55.256  3
326180  92.031  -70.961  55.242  3
326181  92.062  -70.972  55.228  3
326182  92.093  -70.982  55.213  3
326183  92.124  -70.992  55.198  3
326184  92.154  -71.003  55.183  3
326185  92.185  -71.013  55.165  3
326186  92.220  -71.024  55.147  3
326187  92.247  -71.032  55.128  3
326188  92.275  -71.039  55.111  3
326189  92.302  -71.048  55.092  3
326190  92.330  -71.056  55.073  3
326191  92.357  -71.064  55.052  3
326192  92.385  -71.073  55.031  3
326193  92.413  -71.081  55.009  3
326194  92.440  -71.089  54.986  3
326195  92.475  -71.090  54.962  3
326196  92.522  -71.080  54.936  3
326197  92.570  -71.069  54.908  3
326198  92.618  -71.058  54.879  3
326199  92.665  -71.048  54.849  3
326200  92.712  -71.036  54.818  3
326201  92.760  -71.026  54.786  3
326202  92.807  -71.015  54.752  3
326203  92.854  -71.005  54.717  3
326204  92.902  -70.994  54.679  3
326205  92.934  -70.987  54.641  3
326206  92.960  -70.981  54.603  3
326207  92.986  -70.976  54.565  3
326275  94.750  -70.584  52.715  1
326276  94.780  -70.576  52.704  1
326277  94.811  -70.569  52.691  1
326278  94.840  -70.560  52.679  1
326279  94.871  -70.553  52.666  1
326280  94.901  -70.544  52.654  1
326281  94.930  -70.537  52.642  1
326282  94.961  -70.529  52.633  1
326283  94.991  -70.521  52.623  1
326284  95.021  -70.513  52.613  1
326285  95.051  -70.505  52.604  1
326286  95.076  -70.502  52.594  1
326287  95.112  -70.522  52.583  1
326288  95.147  -70.543  52.573  1
326289  95.184  -70.563  52.564  1
326290  95.222  -70.581  52.553  1
326291  95.259  -70.600  52.542  1
326292  95.297  -70.618  52.530  1
326293  95.334  -70.636  52.516  1
326294  95.372  -70.655  52.502  1
326295  95.409  -70.673  52.488  1
326296  95.447  -70.691  52.473  1
326297  95.484  -70.710  52.458  1
326298  95.522  -70.729  52.443  1
326299  95.560  -70.747  52.427  1
326300  95.597  -70.766  52.410  1
326301  95.635  -70.784  52.395  1
326302  95.672  -70.802  52.380  1
326303  95.710  -70.821  52.365  1
326304  95.748  -70.839  52.350  1
326305  95.785  -70.858  52.336  1
326306  95.816  -70.858  52.323  1
326307  95.846  -70.852  52.309  1
326308  95.875  -70.847  52.295  1
326309  95.904  -70.841  52.280  1
326310  95.934  -70.836  52.266  1
326311  95.970  -70.809  52.253  1
326312  96.011  -70.771  52.242  1
326313  95.997  -70.764  52.233  1
326314  96.010  -70.773  52.226  1
326315  96.035  -70.789  52.217  1
326316  96.060  -70.804  52.208  1
326317  96.091  -70.819  52.199  1
326318  96.146  -70.833  52.190  1
326319  96.200  -70.848  52.181  1
326320  96.254  -70.862  52.176  1
326321  96.309  -70.876  52.171  1
326322  96.363  -70.891  52.166  1
326323  96.417  -70.905  52.162  1
326324  96.472  -70.919  52.156  1
326325  96.527  -70.933  52.146  1
326326  96.582  -70.945  52.134  1
326327  96.637  -70.958  52.119  1
326328  96.692  -70.972  52.104  1
326329  96.747  -70.985  52.088  1
326330  96.792  -70.997  52.072  1
326331  96.820  -71.010  52.056  1
326332  96.850  -71.023  52.042  1
326333  96.878  -71.036  52.031  1
326334  96.907  -71.049  52.015  1
326335  96.936  -71.061  51.997  1
326336  96.975  -71.068  51.975  1
326337  97.014  -71.071  51.949  1
326338  97.052  -71.074  51.920  1
326339  97.091  -71.077  51.892  1
326340  97.131  -71.079  51.865  1
326341  97.169  -71.082  51.833  1
326342  97.202  -71.084  51.803  1
326343  97.229  -71.096  51.775  1
326344  97.259  -71.108  51.748  1
326345  97.289  -71.121  51.724  1
326346  97.319  -71.135  51.703  1
326347  97.349  -71.148  51.681  1
326348  97.379  -71.161  51.661  1
326349  97.409  -71.174  51.647  1
326350  97.439  -71.187  51.629  1
326351  97.468  -71.201  51.611  1
326352  97.497  -71.215  51.589  1
326353  97.525  -71.227  51.562  1
326354  97.554  -71.241  51.527  1
326355  97.583  -71.255  51.488  1
326356  97.611  -71.268  51.450  1
326357  97.640  -71.282  51.413  1
326358  97.669  -71.295  51.378  1
326359  97.705  -71.307  51.341  1
326360  97.740  -71.319  51.301  1
326361  97.776  -71.331  51.258  1
326362  97.812  -71.338  51.213  1
326363  97.849  -71.345  51.167  1
326364  97.885  -71.351  51.121  1
326365  97.923  -71.353  51.077  1
326366  97.960  -71.356  51.037  1
326367  97.998  -71.359  50.997  1
326368  98.035  -71.362  50.954  1
326369  98.073  -71.365  50.912  1
326370  98.103  -71.372  50.871  1
326371  98.132  -71.381  50.829  1
326372  98.160  -71.390  50.787  1
326373  98.189  -71.398  50.743  1
326374  98.218  -71.406  50.698  1
326375  98.246  -71.415  50.650  1
326376  98.275  -71.424  50.600  1
326377  98.304  -71.432  50.546  1
326378  98.333  -71.440  50.489  1
326379  98.361  -71.449  50.431  1
326380  98.397  -71.456  50.370  1
326381  98.437  -71.464  50.307  1
326382  98.477  -71.471  50.244  1
326383  98.516  -71.478  50.184  1
326384  98.556  -71.485  50.123  1
326385  98.596  -71.492  50.064  1
326386  98.636  -71.499  50.006  1
326387  98.673  -71.506  49.948  1
326388  98.706  -71.513  49.887  1
326389  98.739  -71.521  49.825  1
326390  98.771  -71.528  49.763  1
326391  98.804  -71.535  49.701  1
326392  98.837  -71.543  49.639  1
326393  98.869  -71.550  49.577  1
326394  98.902  -71.557  49.516  1
326395  98.934  -71.565  49.456  1
326396  98.967  -71.572  49.397  1
326397  98.999  -71.579  49.339  1
326398  99.032  -71.587  49.281  1
326399  99.052  -71.606  49.224  1
326400  99.078  -71.620  49.167  1
326401  99.103  -71.635  49.114  1
326402  99.129  -71.650  49.061  1
326403  99.155  -71.665  49.009  1
326404  99.181  -71.680  48.958  1
326405  99.207  -71.694  48.907  1
326406  99.233  -71.710  48.857  1
326407  99.265  -71.722  48.807  1
326408  99.310  -71.729  48.756  1
326409  99.355  -71.737  48.705  1
326410  99.388  -71.725  48.655  1
326411  99.422  -71.735  48.605  1
326412  99.455  -71.745  48.555  1
326413  99.489  -71.755  48.506  1
326414  99.523  -71.766  48.460  1
326415  99.557  -71.776  48.412  1
326416  99.602  -71.782  48.365  1
326417  99.651  -71.785  48.319  1
326418  99.701  -71.789  48.273  1
326419  99.751  -71.793  48.229  1
326420  99.801  -71.796  48.185  1
326421  99.851  -71.800  48.141  1
326422  99.901  -71.804  48.098  1
326423  99.947  -71.814  48.055  1
326424  99.987  -71.826  48.012  1
326425  100.023  -71.839  47.970  1
326426  100.059  -71.851  47.930  1
326427  100.095  -71.864  47.889  1
326428  100.131  -71.876  47.849  1
326429  100.168  -71.888  47.808  1
326430  100.203  -71.900  47.768  1
326431  100.237  -71.911  47.728  1
326432  100.265  -71.920  47.691  1
326433  100.292  -71.928  47.654  1
326434  100.319  -71.936  47.617  1
326435  100.347  -71.945  47.580  1
326436  100.374  -71.953  47.543  1
326437  100.401  -71.961  47.506  1
326438  100.429  -71.970  47.469  1
326439  100.456  -71.977  47.435  1
326440  100.483  -71.986  47.401  1
326441  100.510  -71.995  47.367  1
326442  100.534  -72.010  47.335  1
326443  100.568  -72.039  47.302  1
326444  100.603  -72.070  47.269  1
326445  100.638  -72.102  47.238  1
326446  100.673  -72.111  47.208  1
326447  100.706  -72.115  47.177  1
326448  100.740  -72.120  47.144  1
326449  100.774  -72.124  47.111  1
326450  100.808  -72.129  47.078  1
326451  100.842  -72.133  47.044  1
326452  100.875  -72.140  47.009  1
326453  100.905  -72.149  46.974  1
326454  100.936  -72.158  46.938  1
326455  100.967  -72.166  46.902  1
326456  100.998  -72.175  46.863  1
326457  101.029  -72.183  46.823  1
326458  101.059  -72.193  46.783  1
326459  101.091  -72.201  46.745  1
326460  101.122  -72.211  46.707  1
326461  101.158  -72.226  46.668  1
326462  101.193  -72.240  46.628  1
326463  101.229  -72.255  46.588  1
326464  101.264  -72.270  46.548  1
326465  101.300  -72.284  46.510  1
326466  101.335  -72.299  46.470  1
326467  101.371  -72.314  46.429  1
326468  101.406  -72.328  46.389  1
326469  101.442  -72.343  46.347  1
326470  101.481  -72.349  46.306  1
326471  101.519  -72.357  46.264  1
326472  101.558  -72.364  46.225  1
326473  101.597  -72.371  46.184  1
326474  101.635  -72.379  46.145  1
326475  101.667  -72.393  46.107  1
326476  101.699  -72.406  46.067  1
326477  101.732  -72.419  46.027  1
326478  101.763  -72.432  45.987  1
326479  101.796  -72.446  45.948  1
326480  101.828  -72.459  45.909  1
326481  101.860  -72.472  45.871  1
326482  101.892  -72.485  45.833  1
326483  101.914  -72.494  45.795  1
326484  101.928  -72.506  45.758  1
326485  101.942  -72.519  45.720  1
326486  101.956  -72.531  45.685  1
326487  101.970  -72.544  45.649  1
326488  101.984  -72.556  45.613  1
326489  101.998  -72.569  45.578  1
326490  102.037  -72.582  45.543  1
326491  102.077  -72.595  45.508  1
326492  102.118  -72.607  45.474  1
326493  102.153  -72.613  45.439  1
326494  102.178  -72.613  45.405  1
326495  102.203  -72.614  45.372  1
326496  102.228  -72.615  45.339  1
326497  102.253  -72.616  45.307  1
326498  102.277  -72.616  45.275  1
326499  102.302  -72.616  45.243  1
326500  102.327  -72.617  45.211  1
326501  102.352  -72.618  45.180  1
326873  91.782  -70.850  55.350  3
326874  91.813  -70.860  55.338  3
326875  91.844  -70.870  55.325  3
326876  91.874  -70.880  55.312  3
326877  91.905  -70.891  55.300  3
326878  91.935  -70.901  55.286  3
326879  91.966  -70.911  55.272  3
326880  91.997  -70.922  55.258  3
326881  92.027  -70.933  55.245  3
326882  92.058  -70.942  55.230  3
326883  92.089  -70.953  55.216  3
326884  92.119  -70.964  55.203  3
326885  92.150  -70.974  55.189  3
326886  92.180  -70.984  55.172  3
326887  92.212  -70.993  55.154  3
326888  92.240  -71.002  55.135  3
326889  92.267  -71.010  55.117  3
326890  92.295  -71.018  55.099  3
326891  92.322  -71.027  55.080  3
326892  92.350  -71.035  55.059  3
326893  92.377  -71.043  55.038  3
326894  92.405  -71.051  55.017  3
326895  92.433  -71.059  54.994  3
326896  92.473  -71.055  54.970  3
326897  92.520  -71.045  54.945  3
326898  92.568  -71.034  54.917  3
326899  92.615  -71.024  54.888  3
326900  92.662  -71.013  54.858  3
326901  92.710  -71.002  54.826  3
326902  92.758  -70.992  54.793  3
326903  92.805  -70.981  54.759  3
326904  92.852  -70.970  54.723  3
326905  92.900  -70.960  54.685  3
326906  92.929  -70.953  54.647  3
326907  92.955  -70.948  54.608  3
326908  92.981  -70.942  54.569  3
326909  93.006  -70.936  54.531  3
326910  93.032  -70.930  54.494  3
326975  94.746  -70.542  52.735  1
326976  94.776  -70.534  52.722  1
326977  94.806  -70.526  52.711  1
326978  94.836  -70.518  52.700  1
326979  94.866  -70.510  52.687  1
326980  94.897  -70.502  52.675  1
326981  94.926  -70.494  52.664  1
326982  94.957  -70.486  52.653  1
326983  94.987  -70.478  52.644  1
326984  95.017  -70.470  52.634  1
326985  95.047  -70.463  52.625  1
326986  95.077  -70.454  52.617  1
326987  95.100  -70.459  52.608  1
326988  95.136  -70.479  52.597  1
326989  95.172  -70.500  52.587  1
326990  95.207  -70.520  52.578  1
326991  95.244  -70.540  52.567  1
326992  95.281  -70.559  52.556  1
326993  95.319  -70.577  52.544  1
326994  95.356  -70.595  52.530  1
326995  95.394  -70.614  52.516  1
326996  95.431  -70.632  52.502  1
326997  95.469  -70.651  52.487  1
326998  95.507  -70.670  52.471  1
326999  95.544  -70.688  52.454  1
327000  95.582  -70.706  52.438  1
327001  95.619  -70.725  52.421  1
327002  95.657  -70.743  52.405  1
327003  95.694  -70.761  52.390  1
327004  95.732  -70.780  52.374  1
327005  95.769  -70.798  52.359  1
327006  95.806  -70.813  52.344  1
327007  95.835  -70.807  52.330  1
327008  95.864  -70.801  52.315  1
327009  95.893  -70.795  52.300  1
327010  95.922  -70.790  52.285  1
327011  95.952  -70.785  52.271  1
327012  95.981  -70.779  52.258  1
327013  96.019  -70.749  52.247  1
327014  96.024  -70.732  52.238  1
327015  96.041  -70.743  52.229  1
327016  96.066  -70.758  52.220  1
327017  96.091  -70.773  52.209  1
327018  96.116  -70.789  52.198  1
327019  96.154  -70.803  52.187  1
327020  96.208  -70.817  52.177  1
327021  96.263  -70.832  52.169  1
327022  96.317  -70.846  52.160  1
327023  96.372  -70.861  52.153  1
327024  96.426  -70.876  52.146  1
327025  96.481  -70.889  52.140  1
327026  96.536  -70.902  52.129  1
327027  96.591  -70.915  52.117  1
327028  96.646  -70.928  52.104  1
327029  96.700  -70.942  52.088  1
327030  96.750  -70.953  52.072  1
327031  96.794  -70.964  52.057  1
327032  96.823  -70.977  52.042  1
327033  96.852  -70.990  52.030  1
327034  96.881  -71.003  52.019  1
327035  96.909  -71.016  52.004  1
327036  96.943  -71.028  51.985  1
327037  96.987  -71.036  51.965  1
327038  97.026  -71.039  51.938  1
327039  97.065  -71.042  51.911  1
327040  97.104  -71.045  51.885  1
327041  97.143  -71.048  51.858  1
327042  97.181  -71.050  51.829  1
327043  97.210  -71.052  51.801  1
327044  97.234  -71.059  51.776  1
327045  97.263  -71.072  51.754  1
327046  97.294  -71.085  51.735  1
327047  97.323  -71.099  51.716  1
327048  97.354  -71.111  51.696  1
327049  97.383  -71.125  51.676  1
327050  97.414  -71.138  51.661  1
327051  97.443  -71.151  51.645  1
327052  97.473  -71.165  51.628  1
327053  97.503  -71.177  51.606  1
327054  97.533  -71.190  51.580  1
327055  97.563  -71.204  51.546  1
327056  97.593  -71.217  51.509  1
327057  97.623  -71.230  51.471  1
327058  97.653  -71.243  51.435  1
327059  97.683  -71.256  51.400  1
327060  97.713  -71.270  51.361  1
327061  97.743  -71.283  51.320  1
327062  97.774  -71.296  51.276  1
327063  97.810  -71.301  51.230  1
327064  97.848  -71.303  51.183  1
327065  97.885  -71.306  51.137  1
327066  97.923  -71.309  51.094  1
327067  97.961  -71.312  51.056  1
327068  97.998  -71.315  51.015  1
327069  98.036  -71.318  50.973  1
327070  98.072  -71.321  50.931  1
327071  98.100  -71.330  50.890  1
327072  98.129  -71.338  50.847  1
327073  98.158  -71.346  50.803  1
327074  98.186  -71.356  50.757  1
327075  98.215  -71.364  50.710  1
327076  98.244  -71.372  50.660  1
327077  98.273  -71.381  50.608  1
327078  98.301  -71.389  50.552  1
327079  98.331  -71.397  50.494  1
327080  98.371  -71.405  50.434  1
327081  98.411  -71.412  50.372  1
327082  98.450  -71.419  50.309  1
327083  98.491  -71.426  50.248  1
327084  98.530  -71.433  50.192  1
327085  98.570  -71.440  50.133  1
327086  98.608  -71.447  50.075  1
327087  98.644  -71.454  50.016  1
327088  98.681  -71.459  49.958  1
327089  98.711  -71.471  49.897  1
327090  98.743  -71.478  49.835  1
327091  98.776  -71.486  49.772  1
327092  98.808  -71.493  49.709  1
327093  98.841  -71.500  49.646  1
327094  98.873  -71.508  49.583  1
327095  98.906  -71.515  49.521  1
327096  98.939  -71.522  49.460  1
327097  98.971  -71.530  49.401  1
327098  99.004  -71.537  49.342  1
327099  99.037  -71.544  49.283  1
327100  99.059  -71.560  49.225  1
327101  99.077  -71.582  49.168  1
327102  99.103  -71.597  49.115  1
327103  99.129  -71.611  49.063  1
327104  99.155  -71.626  49.010  1
327105  99.181  -71.641  48.959  1
327106  99.207  -71.656  48.909  1
327107  99.234  -71.670  48.859  1
327108  99.279  -71.678  48.807  1
327109  99.324  -71.685  48.756  1
327110  99.369  -71.693  48.707  1
327111  99.415  -71.701  48.656  1
327112  99.445  -71.691  48.606  1
327113  99.479  -71.701  48.557  1
327114  99.513  -71.712  48.510  1
327115  99.547  -71.722  48.463  1
327116  99.580  -71.732  48.416  1
327117  99.624  -71.738  48.369  1
327118  99.674  -71.742  48.324  1
327119  99.724  -71.746  48.278  1
327120  99.774  -71.749  48.234  1
327121  99.824  -71.753  48.190  1
327122  99.873  -71.757  48.147  1
327123  99.921  -71.765  48.105  1
327124  99.961  -71.778  48.062  1
327125  99.997  -71.790  48.019  1
327126  100.033  -71.802  47.977  1
327127  100.069  -71.815  47.937  1
327128  100.106  -71.827  47.896  1
327129  100.141  -71.839  47.856  1
327130  100.177  -71.851  47.816  1
327131  100.214  -71.864  47.777  1
327132  100.249  -71.876  47.738  1
327133  100.276  -71.884  47.700  1
327134  100.303  -71.892  47.664  1
327135  100.331  -71.901  47.627  1
327136  100.358  -71.909  47.588  1
327137  100.385  -71.917  47.551  1
327138  100.413  -71.926  47.515  1
327139  100.440  -71.933  47.480  1
327140  100.468  -71.942  47.444  1
327141  100.495  -71.950  47.409  1
327142  100.520  -71.963  47.375  1
327143  100.543  -71.978  47.340  1
327144  100.576  -72.006  47.306  1
327145  100.611  -72.036  47.272  1
327146  100.646  -72.067  47.238  1
327147  100.680  -72.075  47.206  1
327148  100.714  -72.080  47.174  1
327149  100.748  -72.084  47.142  1
327150  100.782  -72.089  47.109  1
327151  100.816  -72.093  47.077  1
327152  100.849  -72.098  47.044  1
327153  100.883  -72.102  47.010  1
327154  100.917  -72.106  46.976  1
327155  100.951  -72.111  46.942  1
327156  100.981  -72.120  46.907  1
327157  101.012  -72.129  46.870  1
327158  101.043  -72.137  46.831  1
327159  101.074  -72.146  46.792  1
327160  101.105  -72.155  46.754  1
327161  101.138  -72.167  46.717  1
327162  101.174  -72.181  46.679  1
327163  101.209  -72.196  46.641  1
327164  101.245  -72.211  46.601  1
327165  101.280  -72.225  46.561  1
327166  101.316  -72.240  46.523  1
327167  101.351  -72.255  46.483  1
327168  101.387  -72.269  46.441  1
327169  101.422  -72.284  46.401  1
327170  101.458  -72.299  46.360  1
327171  101.494  -72.311  46.319  1
327172  101.533  -72.318  46.278  1
327173  101.572  -72.325  46.238  1
327174  101.611  -72.332  46.197  1
327175  101.648  -72.340  46.159  1
327176  101.680  -72.354  46.120  1
327177  101.712  -72.368  46.081  1
327178  101.744  -72.381  46.042  1
327179  101.776  -72.394  46.001  1
327180  101.809  -72.407  45.962  1
327181  101.840  -72.421  45.922  1
327182  101.873  -72.434  45.884  1
327183  101.905  -72.447  45.846  1
327184  101.936  -72.460  45.808  1
327185  101.949  -72.472  45.771  1
327186  101.963  -72.485  45.733  1
327187  101.977  -72.498  45.697  1
327188  101.991  -72.510  45.661  1
327189  102.005  -72.523  45.626  1
327190  102.019  -72.536  45.590  1
327191  102.050  -72.549  45.556  1
327192  102.090  -72.562  45.521  1
327193  102.131  -72.573  45.486  1
327194  102.162  -72.576  45.452  1
327195  102.186  -72.577  45.418  1
327196  102.211  -72.578  45.385  1
327197  102.236  -72.578  45.352  1
327198  102.260  -72.578  45.320  1
327199  102.285  -72.579  45.287  1
327200  102.310  -72.580  45.255  1
327201  102.335  -72.581  45.224  1
327202  102.360  -72.581  45.193  1
327574  91.772  -70.818  55.348  3
327575  91.803  -70.829  55.336  3
327576  91.835  -70.839  55.324  3
327577  91.865  -70.850  55.312  3
327578  91.896  -70.861  55.301  3
327579  91.928  -70.870  55.287  3
327580  91.959  -70.881  55.272  3
327581  91.990  -70.892  55.258  3
327582  92.021  -70.902  55.245  3
327583  92.053  -70.913  55.232  3
327584  92.084  -70.923  55.219  3
327585  92.115  -70.934  55.207  3
327586  92.146  -70.945  55.194  3
327587  92.176  -70.955  55.179  3
327588  92.205  -70.964  55.162  3
327589  92.233  -70.971  55.143  3
327590  92.262  -70.979  55.124  3
327591  92.290  -70.986  55.106  3
327592  92.318  -70.994  55.087  3
327593  92.347  -71.002  55.067  3
327594  92.375  -71.009  55.047  3
327595  92.403  -71.017  55.026  3
327596  92.437  -71.021  55.003  3
327597  92.478  -71.021  54.979  3
327598  92.518  -71.011  54.954  3
327599  92.566  -71.000  54.926  3
327600  92.613  -70.989  54.897  3
327601  92.660  -70.978  54.867  3
327602  92.708  -70.967  54.835  3
327603  92.755  -70.957  54.801  3
327604  92.802  -70.946  54.767  3
327605  92.850  -70.936  54.731  3
327606  92.897  -70.925  54.693  3
327607  92.924  -70.919  54.654  3
327608  92.950  -70.914  54.614  3
327609  92.976  -70.908  54.575  3
327610  93.002  -70.902  54.536  3
327611  93.027  -70.897  54.498  3
327612  93.053  -70.891  54.460  3
327613  93.079  -70.886  54.425  3
327676  94.772  -70.491  52.741  1
327677  94.802  -70.484  52.729  1
327678  94.832  -70.475  52.719  1
327679  94.862  -70.468  52.708  1
327680  94.892  -70.460  52.696  1
327681  94.922  -70.452  52.685  1
327682  94.953  -70.444  52.674  1
327683  94.982  -70.436  52.664  1
327684  95.013  -70.428  52.655  1
327685  95.043  -70.420  52.646  1
327686  95.072  -70.412  52.638  1
327687  95.103  -70.404  52.631  1
327688  95.124  -70.416  52.622  1
327689  95.160  -70.436  52.612  1
327690  95.196  -70.456  52.603  1
327691  95.232  -70.477  52.594  1
327692  95.268  -70.497  52.583  1
327693  95.304  -70.517  52.572  1
327694  95.340  -70.536  52.559  1
327695  95.378  -70.554  52.545  1
327696  95.416  -70.573  52.530  1
327697  95.453  -70.591  52.516  1
327698  95.491  -70.610  52.500  1
327699  95.529  -70.629  52.483  1
327700  95.566  -70.647  52.466  1
327701  95.604  -70.665  52.450  1
327702  95.641  -70.684  52.433  1
327703  95.679  -70.702  52.416  1
327704  95.716  -70.720  52.400  1
327705  95.754  -70.739  52.383  1
327706  95.792  -70.757  52.368  1
327707  95.824  -70.761  52.353  1
327708  95.853  -70.756  52.337  1
327709  95.883  -70.750  52.322  1
327710  95.912  -70.745  52.307  1
327711  95.941  -70.739  52.292  1
327712  95.970  -70.733  52.277  1
327713  96.000  -70.728  52.263  1
327714  96.029  -70.722  52.251  1
327715  96.050  -70.699  52.241  1
327716  96.072  -70.712  52.232  1
327717  96.097  -70.727  52.223  1
327718  96.122  -70.742  52.213  1
327719  96.147  -70.757  52.203  1
327720  96.172  -70.773  52.191  1
327721  96.217  -70.787  52.180  1
327722  96.271  -70.802  52.169  1
327723  96.326  -70.817  52.155  1
327724  96.380  -70.831  52.142  1
327725  96.435  -70.845  52.131  1
327726  96.489  -70.858  52.122  1
327727  96.544  -70.871  52.111  1
327728  96.599  -70.885  52.100  1
327729  96.654  -70.898  52.087  1
327730  96.703  -70.909  52.072  1
327731  96.751  -70.920  52.057  1
327732  96.796  -70.932  52.043  1
327733  96.825  -70.945  52.029  1
327734  96.854  -70.958  52.018  1
327735  96.883  -70.970  52.006  1
327736  96.912  -70.983  51.991  1
327737  96.953  -70.993  51.972  1
327738  96.998  -71.002  51.952  1
327739  97.039  -71.008  51.927  1
327740  97.078  -71.011  51.903  1
327741  97.116  -71.014  51.880  1
327742  97.155  -71.016  51.856  1
327743  97.194  -71.019  51.828  1
327744  97.219  -71.021  51.803  1
327745  97.238  -71.023  51.781  1
327746  97.268  -71.036  51.763  1
327747  97.298  -71.049  51.747  1
327748  97.328  -71.062  51.731  1
327749  97.358  -71.075  51.711  1
327750  97.388  -71.089  51.690  1
327751  97.418  -71.102  51.673  1
327752  97.448  -71.115  51.657  1
327753  97.477  -71.128  51.639  1
327754  97.508  -71.141  51.618  1
327755  97.537  -71.154  51.594  1
327756  97.568  -71.168  51.560  1
327757  97.597  -71.180  51.525  1
327758  97.628  -71.194  51.489  1
327759  97.657  -71.207  51.453  1
327760  97.687  -71.220  51.417  1
327761  97.717  -71.233  51.379  1
327762  97.746  -71.246  51.337  1
327763  97.778  -71.257  51.291  1
327764  97.811  -71.256  51.243  1
327765  97.848  -71.259  51.196  1
327766  97.886  -71.262  51.152  1
327767  97.924  -71.265  51.110  1
327768  97.961  -71.267  51.074  1
327769  97.999  -71.270  51.033  1
327770  98.036  -71.273  50.993  1
327771  98.069  -71.279  50.951  1
327772  98.098  -71.287  50.908  1
327773  98.127  -71.296  50.865  1
327774  98.155  -71.304  50.820  1
327775  98.183  -71.312  50.772  1
327776  98.212  -71.321  50.723  1
327777  98.241  -71.330  50.670  1
327778  98.270  -71.338  50.614  1
327779  98.305  -71.346  50.557  1
327780  98.345  -71.353  50.497  1
327781  98.385  -71.360  50.436  1
327782  98.425  -71.367  50.374  1
327783  98.464  -71.375  50.314  1
327784  98.504  -71.381  50.258  1
327785  98.541  -71.388  50.204  1
327786  98.577  -71.395  50.145  1
327787  98.614  -71.402  50.085  1
327788  98.651  -71.407  50.025  1
327789  98.690  -71.411  49.966  1
327790  98.720  -71.422  49.904  1
327791  98.750  -71.433  49.842  1
327792  98.781  -71.444  49.778  1
327793  98.813  -71.451  49.713  1
327794  98.846  -71.458  49.651  1
327795  98.878  -71.466  49.588  1
327796  98.911  -71.473  49.526  1
327797  98.943  -71.480  49.464  1
327798  98.976  -71.487  49.404  1
327799  99.008  -71.495  49.343  1
327800  99.041  -71.502  49.283  1
327801  99.067  -71.516  49.225  1
327802  99.084  -71.538  49.171  1
327803  99.102  -71.557  49.117  1
327804  99.129  -71.572  49.064  1
327805  99.154  -71.587  49.012  1
327806  99.180  -71.602  48.962  1
327807  99.206  -71.616  48.910  1
327808  99.248  -71.625  48.859  1
327809  99.293  -71.633  48.809  1
327810  99.338  -71.641  48.758  1
327811  99.383  -71.649  48.708  1
327812  99.428  -71.657  48.659  1
327813  99.468  -71.647  48.609  1
327814  99.502  -71.658  48.560  1
327815  99.536  -71.668  48.514  1
327816  99.570  -71.679  48.467  1
327817  99.604  -71.689  48.420  1
327818  99.647  -71.695  48.374  1
327819  99.697  -71.699  48.329  1
327820  99.747  -71.702  48.284  1
327821  99.796  -71.706  48.240  1
327822  99.846  -71.710  48.198  1
327823  99.895  -71.716  48.155  1
327824  99.935  -71.729  48.113  1
327825  99.971  -71.741  48.070  1
327826  100.007  -71.754  48.027  1
327827  100.044  -71.766  47.985  1
327828  100.079  -71.779  47.945  1
327829  100.116  -71.791  47.905  1
327830  100.151  -71.803  47.865  1
327831  100.188  -71.815  47.826  1
327832  100.224  -71.827  47.787  1
327833  100.260  -71.839  47.748  1
327834  100.288  -71.848  47.710  1
327835  100.316  -71.857  47.673  1
327836  100.343  -71.865  47.636  1
327837  100.370  -71.873  47.598  1
327838  100.398  -71.881  47.561  1
327839  100.425  -71.889  47.525  1
327840  100.452  -71.898  47.489  1
327841  100.480  -71.906  47.453  1
327842  100.506  -71.917  47.417  1
327843  100.529  -71.931  47.381  1
327844  100.552  -71.946  47.345  1
327845  100.583  -71.972  47.310  1
327846  100.619  -72.003  47.275  1
327847  100.654  -72.033  47.241  1
327848  100.688  -72.039  47.207  1
327849  100.721  -72.043  47.175  1
327850  100.756  -72.048  47.142  1
327851  100.789  -72.052  47.110  1
327852  100.823  -72.057  47.078  1
327853  100.857  -72.061  47.045  1
327854  100.891  -72.066  47.013  1
327855  100.925  -72.070  46.980  1
327856  100.959  -72.075  46.946  1
327857  100.992  -72.080  46.911  1
327858  101.026  -72.084  46.875  1
327859  101.058  -72.092  46.837  1
327860  101.089  -72.100  46.800  1
327861  101.120  -72.109  46.762  1
327862  101.154  -72.122  46.726  1
327863  101.190  -72.137  46.689  1
327864  101.225  -72.152  46.652  1
327865  101.260  -72.166  46.613  1
327866  101.296  -72.181  46.574  1
327867  101.331  -72.196  46.535  1
327868  101.367  -72.211  46.494  1
327869  101.402  -72.225  46.453  1
327870  101.438  -72.240  46.413  1
327871  101.473  -72.255  46.372  1
327872  101.509  -72.269  46.333  1
327873  101.546  -72.280  46.293  1
327874  101.585  -72.287  46.251  1
327875  101.624  -72.293  46.212  1
327876  101.661  -72.302  46.172  1
327877  101.693  -72.315  46.133  1
327878  101.725  -72.329  46.094  1
327879  101.757  -72.343  46.056  1
327880  101.789  -72.356  46.016  1
327881  101.821  -72.369  45.977  1
327882  101.853  -72.382  45.938  1
327883  101.886  -72.396  45.899  1
327884  101.910  -72.410  45.860  1
327885  101.934  -72.424  45.822  1
327886  101.962  -72.439  45.784  1
327887  101.984  -72.452  45.747  1
327888  101.998  -72.465  45.710  1
327889  102.012  -72.477  45.674  1
327890  102.026  -72.490  45.639  1
327891  102.040  -72.502  45.604  1
327892  102.062  -72.515  45.569  1
327893  102.103  -72.528  45.534  1
327894  102.144  -72.539  45.499  1
327895  102.169  -72.540  45.465  1
327896  102.194  -72.540  45.432  1
327897  102.219  -72.540  45.398  1
327898  102.244  -72.541  45.365  1
327899  102.268  -72.542  45.332  1
327900  102.293  -72.543  45.300  1
327901  102.318  -72.544  45.269  1
327902  102.342  -72.544  45.237  1
327903  102.368  -72.544  45.206  1
328275  91.760  -70.785  55.345  3
328276  91.791  -70.796  55.334  3
328277  91.822  -70.807  55.323  3
328278  91.854  -70.817  55.311  3
328279  91.884  -70.828  55.300  3
328280  91.916  -70.839  55.286  3
328281  91.947  -70.849  55.273  3
328282  91.978  -70.860  55.259  3
328283  92.009  -70.870  55.246  3
328284  92.040  -70.880  55.233  3
328285  92.072  -70.891  55.221  3
328286  92.103  -70.901  55.209  3
328287  92.134  -70.912  55.197  3
328288  92.166  -70.923  55.184  3
328289  92.203  -70.930  55.168  3
328290  92.231  -70.937  55.151  3
328291  92.260  -70.945  55.133  3
328292  92.288  -70.952  55.116  3
328293  92.316  -70.960  55.097  3
328294  92.345  -70.967  55.078  3
328295  92.373  -70.976  55.057  3
328296  92.402  -70.983  55.036  3
328297  92.443  -70.982  55.013  3
328298  92.484  -70.981  54.989  3
328299  92.523  -70.976  54.965  3
328300  92.563  -70.965  54.936  3
328301  92.611  -70.955  54.906  3
328302  92.658  -70.944  54.876  3
328303  92.705  -70.933  54.844  3
328304  92.753  -70.923  54.810  3
328305  92.800  -70.912  54.775  3
328306  92.848  -70.901  54.739  3
328307  92.894  -70.891  54.701  3
328308  92.919  -70.886  54.661  3
328309  92.945  -70.880  54.621  3
328310  92.971  -70.874  54.580  3
328311  92.997  -70.868  54.540  3
328312  93.022  -70.863  54.503  3
328313  93.048  -70.857  54.464  3
328314  93.074  -70.851  54.428  3
328315  93.100  -70.845  54.394  3
328377  94.798  -70.441  52.748  1
328378  94.828  -70.433  52.736  1
328379  94.858  -70.425  52.727  1
328380  94.888  -70.417  52.716  1
328381  94.918  -70.409  52.706  1
328382  94.948  -70.401  52.695  1
328383  94.978  -70.394  52.684  1
328384  95.008  -70.385  52.675  1
328385  95.038  -70.378  52.666  1
328386  95.068  -70.369  52.659  1
328387  95.099  -70.362  52.652  1
328388  95.128  -70.353  52.645  1
328389  95.148  -70.372  52.636  1
328390  95.184  -70.393  52.627  1
328391  95.220  -70.413  52.619  1
328392  95.256  -70.434  52.611  1
328393  95.292  -70.453  52.600  1
328394  95.328  -70.474  52.588  1
328395  95.364  -70.494  52.574  1
328396  95.400  -70.513  52.560  1
328397  95.438  -70.532  52.545  1
328398  95.475  -70.550  52.530  1
328399  95.513  -70.569  52.513  1
328400  95.550  -70.588  52.496  1
328401  95.588  -70.606  52.479  1
328402  95.626  -70.624  52.461  1
328403  95.663  -70.643  52.444  1
328404  95.701  -70.661  52.427  1
328405  95.738  -70.679  52.410  1
328406  95.776  -70.698  52.393  1
328407  95.813  -70.716  52.377  1
328408  95.842  -70.710  52.361  1
328409  95.872  -70.704  52.345  1
328410  95.901  -70.699  52.330  1
328411  95.931  -70.693  52.314  1
328412  95.960  -70.688  52.298  1
328413  95.989  -70.682  52.283  1
328414  96.018  -70.676  52.268  1
328415  96.047  -70.671  52.256  1
328416  96.076  -70.666  52.245  1
328417  96.102  -70.682  52.236  1
328418  96.127  -70.697  52.226  1
328419  96.153  -70.712  52.216  1
328420  96.178  -70.727  52.205  1
328421  96.203  -70.742  52.194  1
328422  96.228  -70.757  52.182  1
328423  96.279  -70.772  52.169  1
328424  96.334  -70.786  52.152  1
328425  96.388  -70.801  52.135  1
328426  96.443  -70.815  52.121  1
328427  96.498  -70.828  52.109  1
328428  96.553  -70.841  52.097  1
328429  96.608  -70.854  52.086  1
328430  96.657  -70.866  52.073  1
328431  96.704  -70.877  52.059  1
328432  96.752  -70.888  52.045  1
328433  96.799  -70.899  52.031  1
328434  96.827  -70.912  52.017  1
328435  96.856  -70.925  52.006  1
328436  96.885  -70.938  51.994  1
328437  96.918  -70.950  51.978  1
328438  96.963  -70.959  51.961  1
328439  97.007  -70.968  51.942  1
328440  97.051  -70.977  51.921  1
328441  97.090  -70.980  51.899  1
328442  97.129  -70.982  51.879  1
328443  97.168  -70.985  51.858  1
328444  97.207  -70.988  51.834  1
328445  97.228  -70.989  51.812  1
328446  97.246  -70.990  51.792  1
328447  97.273  -70.999  51.775  1
328448  97.302  -71.013  51.760  1
328449  97.332  -71.026  51.744  1
328450  97.362  -71.039  51.724  1
328451  97.392  -71.052  51.704  1
328452  97.422  -71.065  51.687  1
328453  97.452  -71.078  51.670  1
328454  97.482  -71.092  51.652  1
328455  97.512  -71.105  51.632  1
328456  97.542  -71.118  51.608  1
328457  97.572  -71.131  51.574  1
328458  97.602  -71.144  51.539  1
328459  97.632  -71.157  51.504  1
328460  97.661  -71.170  51.468  1
328461  97.690  -71.182  51.432  1
328462  97.720  -71.195  51.393  1
328463  97.749  -71.207  51.350  1
328464  97.782  -71.218  51.303  1
328465  97.813  -71.214  51.255  1
328466  97.849  -71.215  51.208  1
328467  97.886  -71.217  51.165  1
328468  97.924  -71.220  51.126  1
328469  97.961  -71.223  51.091  1
328470  97.999  -71.225  51.051  1
328471  98.036  -71.228  51.011  1
328472  98.066  -71.236  50.969  1
328473  98.095  -71.244  50.925  1
328474  98.124  -71.253  50.881  1
328475  98.152  -71.262  50.835  1
328476  98.181  -71.270  50.786  1
328477  98.210  -71.278  50.734  1
328478  98.239  -71.287  50.679  1
328479  98.279  -71.294  50.621  1
328480  98.319  -71.301  50.562  1
328481  98.359  -71.308  50.501  1
328482  98.398  -71.315  50.440  1
328483  98.438  -71.322  50.379  1
328484  98.474  -71.329  50.322  1
328485  98.510  -71.336  50.267  1
328486  98.547  -71.343  50.213  1
328487  98.583  -71.350  50.154  1
328488  98.619  -71.356  50.093  1
328489  98.658  -71.360  50.033  1
328490  98.698  -71.363  49.971  1
328491  98.729  -71.373  49.909  1
328492  98.760  -71.384  49.845  1
328493  98.789  -71.395  49.781  1
328494  98.819  -71.406  49.717  1
328495  98.850  -71.416  49.654  1
328496  98.883  -71.423  49.591  1
328497  98.915  -71.431  49.529  1
328498  98.948  -71.438  49.467  1
328499  98.981  -71.445  49.406  1
328500  99.013  -71.453  49.345  1
328501  99.046  -71.460  49.285  1
328502  99.074  -71.471  49.227  1
328503  99.091  -71.492  49.172  1
328504  99.109  -71.514  49.119  1
328505  99.128  -71.533  49.066  1
328506  99.154  -71.548  49.014  1
328507  99.180  -71.563  48.964  1
328508  99.216  -71.574  48.912  1
328509  99.262  -71.582  48.861  1
328510  99.306  -71.589  48.811  1
328511  99.352  -71.597  48.760  1
328512  99.397  -71.604  48.711  1
328513  99.442  -71.612  48.661  1
328514  99.487  -71.619  48.612  1
328515  99.525  -71.614  48.564  1
328516  99.559  -71.625  48.517  1
328517  99.593  -71.635  48.471  1
328518  99.627  -71.645  48.425  1
328519  99.669  -71.652  48.379  1
328520  99.719  -71.655  48.334  1
328521  99.769  -71.659  48.290  1
328522  99.819  -71.663  48.248  1
328523  99.868  -71.668  48.206  1
328524  99.909  -71.681  48.164  1
328525  99.945  -71.693  48.122  1
328526  99.982  -71.705  48.080  1
328527  100.017  -71.717  48.037  1
328528  100.054  -71.729  47.994  1
328529  100.089  -71.741  47.954  1
328530  100.126  -71.754  47.914  1
328531  100.162  -71.766  47.875  1
328532  100.198  -71.779  47.837  1
328533  100.234  -71.791  47.798  1
328534  100.270  -71.803  47.758  1
328535  100.300  -71.813  47.719  1
328536  100.327  -71.821  47.681  1
328537  100.354  -71.829  47.646  1
328538  100.382  -71.837  47.608  1
328539  100.409  -71.845  47.571  1
328540  100.436  -71.854  47.535  1
328541  100.464  -71.862  47.498  1
328542  100.491  -71.870  47.461  1
328543  100.515  -71.885  47.424  1
328544  100.539  -71.899  47.387  1
328545  100.562  -71.914  47.350  1
328546  100.592  -71.938  47.314  1
328547  100.627  -71.969  47.279  1
328548  100.662  -71.998  47.245  1
328549  100.695  -72.002  47.211  1
328550  100.729  -72.007  47.178  1
328551  100.763  -72.011  47.145  1
328552  100.797  -72.016  47.112  1
328553  100.831  -72.020  47.080  1
328554  100.864  -72.025  47.047  1
328555  100.899  -72.030  47.018  1
328556  100.932  -72.034  46.985  1
328557  100.966  -72.039  46.950  1
328558  101.000  -72.043  46.915  1
328559  101.034  -72.048  46.879  1
328560  101.067  -72.052  46.844  1
328561  101.102  -72.057  46.807  1
328562  101.134  -72.063  46.770  1
328563  101.170  -72.078  46.733  1
328564  101.205  -72.092  46.697  1
328565  101.241  -72.107  46.661  1
328566  101.276  -72.122  46.623  1
328567  101.312  -72.136  46.585  1
328568  101.347  -72.152  46.545  1
328569  101.383  -72.166  46.505  1
328570  101.418  -72.180  46.466  1
328571  101.454  -72.196  46.427  1
328572  101.489  -72.210  46.387  1
328573  101.525  -72.224  46.346  1
328574  101.560  -72.240  46.305  1
328575  101.598  -72.248  46.265  1
328576  101.637  -72.255  46.226  1
328577  101.674  -72.264  46.185  1
328578  101.706  -72.277  46.145  1
328579  101.738  -72.290  46.105  1
328580  101.770  -72.304  46.067  1
328581  101.802  -72.318  46.028  1
328582  101.834  -72.330  45.989  1
328583  101.859  -72.345  45.951  1
328584  101.883  -72.360  45.913  1
328585  101.906  -72.374  45.874  1
328586  101.929  -72.390  45.836  1
328587  101.954  -72.404  45.798  1
328588  101.985  -72.418  45.761  1
328589  102.017  -72.431  45.724  1
328590  102.033  -72.443  45.688  1
328591  102.047  -72.456  45.652  1
328592  102.060  -72.468  45.617  1
328593  102.076  -72.481  45.582  1
328594  102.115  -72.494  45.547  1
328595  102.152  -72.503  45.512  1
328596  102.177  -72.503  45.478  1
328597  102.202  -72.503  45.445  1
328598  102.227  -72.504  45.411  1
328599  102.251  -72.505  45.377  1
328600  102.276  -72.506  45.345  1
328601  102.301  -72.506  45.313  1
328602  102.326  -72.506  45.282  1
328603  102.350  -72.507  45.250  1
328604  102.375  -72.508  45.219  1
328976  91.748  -70.754  55.342  3
328977  91.779  -70.764  55.332  3
328978  91.810  -70.775  55.321  3
328979  91.842  -70.785  55.309  3
328980  91.873  -70.795  55.298  3
328981  91.904  -70.806  55.286  3
328982  91.935  -70.817  55.273  3
328983  91.966  -70.827  55.260  3
328984  91.997  -70.838  55.246  3
328985  92.028  -70.848  55.235  3
328986  92.060  -70.859  55.223  3
328987  92.091  -70.870  55.211  3
328988  92.122  -70.880  55.200  3
328989  92.160  -70.898  55.189  3
328990  92.201  -70.895  55.176  3
328991  92.229  -70.903  55.160  3
328992  92.258  -70.911  55.144  3
328993  92.286  -70.918  55.127  3
328994  92.314  -70.927  55.108  3
328995  92.343  -70.934  55.089  3
328996  92.371  -70.942  55.069  3
328997  92.409  -70.942  55.047  3
328998  92.449  -70.942  55.025  3
328999  92.491  -70.941  55.001  3
329000  92.531  -70.940  54.976  3
329001  92.568  -70.931  54.948  3
329002  92.609  -70.920  54.918  3
329003  92.656  -70.909  54.887  3
329004  92.703  -70.898  54.854  3
329005  92.751  -70.888  54.820  3
329006  92.798  -70.877  54.785  3
329007  92.845  -70.867  54.748  3
329008  92.888  -70.857  54.709  3
329009  92.915  -70.851  54.669  3
329010  92.940  -70.845  54.628  3
329011  92.966  -70.840  54.587  3
329012  92.992  -70.835  54.547  3
329013  93.017  -70.829  54.507  3
329014  93.044  -70.823  54.469  3
329015  93.069  -70.817  54.432  3
329016  93.095  -70.812  54.397  3
329017  93.121  -70.806  54.363  3
329078  94.824  -70.391  52.756  1
329079  94.854  -70.383  52.745  1
329080  94.884  -70.375  52.735  1
329081  94.914  -70.367  52.725  1
329082  94.944  -70.359  52.714  1
329083  94.974  -70.351  52.704  1
329084  95.004  -70.343  52.695  1
329085  95.034  -70.335  52.686  1
329086  95.064  -70.327  52.679  1
329087  95.095  -70.319  52.673  1
329088  95.124  -70.311  52.667  1
329089  95.155  -70.303  52.661  1
329090  95.173  -70.329  52.653  1
329091  95.208  -70.350  52.644  1
329092  95.244  -70.370  52.636  1
329093  95.280  -70.391  52.629  1
329094  95.316  -70.410  52.618  1
329095  95.352  -70.431  52.604  1
329096  95.388  -70.451  52.591  1
329097  95.423  -70.471  52.577  1
329098  95.460  -70.491  52.561  1
329099  95.497  -70.510  52.545  1
329100  95.535  -70.528  52.527  1
329101  95.572  -70.547  52.509  1
329102  95.610  -70.565  52.491  1
329103  95.648  -70.583  52.474  1
329104  95.685  -70.602  52.456  1
329105  95.723  -70.620  52.438  1
329106  95.760  -70.638  52.420  1
329107  95.798  -70.657  52.402  1
329108  95.832  -70.665  52.385  1
329109  95.861  -70.659  52.369  1
329110  95.890  -70.654  52.353  1
329111  95.919  -70.648  52.337  1
329112  95.949  -70.642  52.321  1
329113  95.978  -70.637  52.304  1
329114  96.007  -70.631  52.289  1
329115  96.037  -70.626  52.273  1
329116  96.060  -70.632  52.260  1
329117  96.083  -70.641  52.249  1
329118  96.114  -70.652  52.238  1
329119  96.153  -70.666  52.229  1
329120  96.183  -70.681  52.218  1
329121  96.208  -70.696  52.207  1
329122  96.234  -70.711  52.195  1
329123  96.259  -70.726  52.183  1
329124  96.288  -70.742  52.169  1
329125  96.342  -70.756  52.152  1
329126  96.397  -70.770  52.133  1
329127  96.451  -70.784  52.115  1
329128  96.506  -70.798  52.100  1
329129  96.561  -70.811  52.087  1
329130  96.610  -70.822  52.074  1
329131  96.658  -70.833  52.061  1
329132  96.705  -70.845  52.047  1
329133  96.753  -70.855  52.034  1
329134  96.801  -70.867  52.020  1
329135  96.830  -70.880  52.007  1
329136  96.859  -70.892  51.995  1
329137  96.887  -70.905  51.983  1
329138  96.928  -70.915  51.969  1
329139  96.972  -70.924  51.953  1
329140  97.017  -70.933  51.936  1
329141  97.062  -70.942  51.918  1
329142  97.103  -70.948  51.900  1
329143  97.142  -70.951  51.883  1
329144  97.180  -70.953  51.866  1
329145  97.219  -70.956  51.845  1
329146  97.237  -70.958  51.825  1
329147  97.255  -70.958  51.807  1
329148  97.277  -70.963  51.789  1
329149  97.307  -70.977  51.773  1
329150  97.336  -70.989  51.756  1
329151  97.367  -71.002  51.737  1
329152  97.396  -71.016  51.718  1
329153  97.427  -71.029  51.701  1
329154  97.456  -71.042  51.683  1
329155  97.487  -71.055  51.666  1
329156  97.516  -71.068  51.646  1
329157  97.546  -71.081  51.621  1
329158  97.575  -71.093  51.587  1
329159  97.605  -71.106  51.552  1
329160  97.634  -71.119  51.517  1
329161  97.664  -71.131  51.481  1
329162  97.693  -71.144  51.443  1
329163  97.723  -71.156  51.403  1
329164  97.754  -71.168  51.360  1
329165  97.787  -71.178  51.313  1
329166  97.818  -71.176  51.265  1
329167  97.849  -71.170  51.219  1
329168  97.886  -71.172  51.178  1
329169  97.924  -71.175  51.141  1
329170  97.961  -71.178  51.107  1
329171  97.999  -71.180  51.068  1
329172  98.035  -71.185  51.028  1
329173  98.064  -71.193  50.986  1
329174  98.092  -71.202  50.941  1
329175  98.121  -71.210  50.896  1
329176  98.150  -71.219  50.848  1
329177  98.178  -71.227  50.798  1
329178  98.213  -71.235  50.744  1
329179  98.253  -71.242  50.686  1
329180  98.293  -71.249  50.627  1
329181  98.333  -71.256  50.566  1
329182  98.371  -71.263  50.504  1
329183  98.407  -71.270  50.443  1
329184  98.443  -71.277  50.385  1
329185  98.480  -71.284  50.330  1
329186  98.516  -71.290  50.276  1
329187  98.552  -71.297  50.220  1
329188  98.588  -71.304  50.160  1
329189  98.625  -71.310  50.100  1
329190  98.665  -71.313  50.037  1
329191  98.705  -71.316  49.974  1
329192  98.739  -71.324  49.911  1
329193  98.769  -71.335  49.847  1
329194  98.798  -71.346  49.783  1
329195  98.829  -71.357  49.719  1
329196  98.858  -71.368  49.655  1
329197  98.888  -71.380  49.592  1
329198  98.920  -71.388  49.530  1
329199  98.952  -71.396  49.469  1
329200  98.985  -71.403  49.406  1
329201  99.017  -71.410  49.346  1
329202  99.050  -71.418  49.286  1
329203  99.082  -71.426  49.228  1
329204  99.098  -71.447  49.173  1
329205  99.116  -71.469  49.121  1
329206  99.133  -71.491  49.068  1
329207  99.153  -71.509  49.017  1
329208  99.185  -71.522  48.966  1
329209  99.230  -71.530  48.915  1
329210  99.275  -71.538  48.864  1
329211  99.321  -71.545  48.813  1
329212  99.366  -71.553  48.763  1
329213  99.411  -71.560  48.714  1
329214  99.456  -71.568  48.664  1
329215  99.501  -71.575  48.615  1
329216  99.547  -71.583  48.567  1
329217  99.582  -71.581  48.521  1
329218  99.616  -71.591  48.475  1
329219  99.650  -71.602  48.429  1
329220  99.692  -71.609  48.384  1
329221  99.742  -71.612  48.340  1
329222  99.792  -71.616  48.298  1
329223  99.842  -71.619  48.256  1
329224  99.884  -71.632  48.214  1
329225  99.920  -71.644  48.172  1
329226  99.956  -71.657  48.131  1
329227  99.992  -71.669  48.090  1
329228  100.028  -71.681  48.048  1
329229  100.064  -71.693  48.006  1
329230  100.100  -71.705  47.965  1
329231  100.136  -71.718  47.926  1
329232  100.172  -71.730  47.887  1
329233  100.208  -71.742  47.848  1
329234  100.244  -71.754  47.808  1
329235  100.280  -71.766  47.767  1
329236  100.312  -71.777  47.728  1
329237  100.339  -71.785  47.691  1
329238  100.366  -71.793  47.656  1
329239  100.394  -71.801  47.619  1
329240  100.421  -71.810  47.582  1
329241  100.449  -71.818  47.544  1
329242  100.476  -71.826  47.505  1
329243  100.501  -71.838  47.468  1
329244  100.525  -71.853  47.432  1
329245  100.548  -71.868  47.395  1
329246  100.571  -71.882  47.357  1
329247  100.599  -71.904  47.320  1
329248  100.634  -71.935  47.285  1
329249  100.669  -71.961  47.251  1
329250  100.703  -71.966  47.217  1
329251  100.737  -71.970  47.184  1
329252  100.771  -71.975  47.150  1
329253  100.805  -71.980  47.116  1
329254  100.838  -71.984  47.084  1
329255  100.873  -71.989  47.050  1
329256  100.906  -71.993  47.022  1
329257  100.940  -71.998  46.991  1
329258  100.974  -72.002  46.957  1
329259  101.007  -72.007  46.923  1
329260  101.041  -72.011  46.886  1
329261  101.075  -72.016  46.849  1
329262  101.115  -72.021  46.813  1
329263  101.149  -72.031  46.776  1
329264  101.185  -72.041  46.739  1
329265  101.220  -72.053  46.704  1
329266  101.256  -72.066  46.668  1
329267  101.292  -72.078  46.630  1
329268  101.328  -72.092  46.594  1
329269  101.363  -72.107  46.555  1
329270  101.398  -72.121  46.517  1
329271  101.434  -72.136  46.479  1
329272  101.469  -72.151  46.441  1
329273  101.505  -72.165  46.400  1
329274  101.540  -72.180  46.360  1
329275  101.576  -72.195  46.319  1
329276  101.611  -72.209  46.278  1
329277  101.650  -72.216  46.239  1
329278  101.686  -72.226  46.198  1
329279  101.718  -72.239  46.156  1
329280  101.751  -72.252  46.117  1
329281  101.783  -72.265  46.079  1
329282  101.809  -72.280  46.041  1
329283  101.832  -72.295  46.003  1
329284  101.856  -72.309  45.965  1
329285  101.879  -72.324  45.928  1
329286  101.902  -72.339  45.889  1
329287  101.925  -72.354  45.851  1
329288  101.949  -72.368  45.814  1
329289  101.977  -72.383  45.776  1
329290  102.009  -72.396  45.738  1
329291  102.040  -72.409  45.702  1
329292  102.067  -72.423  45.666  1
329293  102.082  -72.435  45.631  1
329294  102.095  -72.448  45.596  1
329295  102.128  -72.461  45.561  1
329296  102.160  -72.465  45.525  1
329297  102.185  -72.466  45.490  1
329298  102.209  -72.467  45.458  1
329299  102.234  -72.468  45.423  1
329300  102.259  -72.468  45.390  1
329301  102.284  -72.468  45.358  1
329302  102.309  -72.469  45.326  1
329303  102.333  -72.470  45.295  1
329304  102.358  -72.471  45.263  1
329305  102.383  -72.472  45.232  1
329677  91.736  -70.721  55.340  3
329678  91.767  -70.732  55.329  3
329679  91.798  -70.742  55.318  3
329680  91.829  -70.753  55.306  3
329681  91.861  -70.764  55.296  3
329682  91.892  -70.774  55.284  3
329683  91.923  -70.785  55.272  3
329684  91.954  -70.795  55.260  3
329685  91.985  -70.805  55.248  3
329686  92.016  -70.816  55.236  3
329687  92.048  -70.826  55.225  3
329688  92.079  -70.837  55.215  3
329689  92.110  -70.848  55.204  3
329690  92.153  -70.872  55.195  3
329691  92.201  -70.852  55.184  3
329692  92.227  -70.869  55.172  3
329693  92.255  -70.876  55.157  3
329694  92.284  -70.885  55.140  3
329695  92.312  -70.892  55.121  3
329696  92.341  -70.900  55.102  3
329697  92.374  -70.904  55.082  3
329698  92.415  -70.903  55.060  3
329699  92.456  -70.902  55.037  3
329700  92.497  -70.901  55.014  3
329701  92.538  -70.900  54.989  3
329702  92.577  -70.896  54.961  3
329703  92.613  -70.886  54.931  3
329704  92.653  -70.875  54.900  3
329705  92.701  -70.864  54.866  3
329706  92.748  -70.854  54.831  3
329707  92.796  -70.843  54.795  3
329708  92.843  -70.832  54.757  3
329709  92.884  -70.823  54.717  3
329710  92.910  -70.817  54.678  3
329711  92.935  -70.812  54.636  3
329712  92.961  -70.806  54.595  3
329713  92.987  -70.801  54.554  3
329714  93.013  -70.795  54.514  3
329715  93.039  -70.789  54.474  3
329716  93.064  -70.783  54.436  3
329717  93.090  -70.778  54.400  3
329718  93.116  -70.772  54.366  3
329719  93.142  -70.767  54.334  3
329779  94.850  -70.341  52.763  1
329780  94.880  -70.332  52.753  1
329781  94.910  -70.325  52.744  1
329782  94.938  -70.317  52.734  1
329783  94.968  -70.309  52.724  1
329784  94.996  -70.301  52.715  1
329785  95.025  -70.293  52.706  1
329786  95.054  -70.286  52.697  1
329787  95.083  -70.278  52.692  1
329788  95.112  -70.271  52.687  1
329789  95.144  -70.269  52.683  1
329790  95.179  -70.268  52.677  1
329791  95.198  -70.291  52.671  1
329792  95.233  -70.306  52.663  1
329793  95.268  -70.327  52.655  1
329794  95.305  -70.347  52.647  1
329795  95.340  -70.367  52.637  1
329796  95.376  -70.388  52.623  1
329797  95.412  -70.408  52.609  1
329798  95.448  -70.428  52.594  1
329799  95.483  -70.448  52.578  1
329800  95.520  -70.469  52.560  1
329801  95.557  -70.487  52.542  1
329802  95.595  -70.506  52.523  1
329803  95.632  -70.524  52.504  1
329804  95.670  -70.542  52.486  1
329805  95.707  -70.561  52.468  1
329806  95.745  -70.579  52.449  1
329807  95.782  -70.597  52.431  1
329808  95.820  -70.616  52.413  1
329809  95.850  -70.613  52.395  1
329810  95.880  -70.608  52.378  1
329811  95.909  -70.602  52.362  1
329812  95.938  -70.597  52.345  1
329813  95.967  -70.591  52.328  1
329814  95.996  -70.585  52.311  1
329815  96.022  -70.588  52.296  1
329816  96.044  -70.597  52.280  1
329817  96.066  -70.606  52.267  1
329818  96.089  -70.615  52.254  1
329819  96.113  -70.625  52.243  1
329820  96.152  -70.638  52.231  1
329821  96.191  -70.652  52.219  1
329822  96.230  -70.666  52.208  1
329823  96.265  -70.680  52.196  1
329824  96.290  -70.695  52.183  1
329825  96.315  -70.710  52.169  1
329826  96.350  -70.726  52.152  1
329827  96.405  -70.740  52.133  1
329828  96.460  -70.754  52.115  1
329829  96.515  -70.767  52.096  1
329830  96.563  -70.779  52.083  1
329831  96.611  -70.789  52.070  1
329832  96.659  -70.801  52.057  1
329833  96.707  -70.812  52.041  1
329834  96.754  -70.823  52.027  1
329835  96.802  -70.834  52.014  1
329836  96.832  -70.847  52.000  1
329837  96.861  -70.860  51.988  1
329838  96.893  -70.872  51.978  1
329839  96.938  -70.881  51.966  1
329840  96.982  -70.890  51.952  1
329841  97.027  -70.899  51.939  1
329842  97.072  -70.908  51.924  1
329843  97.115  -70.917  51.910  1
329844  97.154  -70.919  51.896  1
329845  97.193  -70.922  51.883  1
329846  97.228  -70.924  51.863  1
329847  97.246  -70.926  51.844  1
329848  97.264  -70.927  51.825  1
329849  97.282  -70.928  51.805  1
329850  97.311  -70.940  51.787  1
329851  97.341  -70.953  51.769  1
329852  97.371  -70.967  51.751  1
329853  97.401  -70.980  51.731  1
329854  97.431  -70.992  51.714  1
329855  97.460  -71.005  51.697  1
329856  97.490  -71.017  51.679  1
329857  97.519  -71.030  51.658  1
329858  97.548  -71.042  51.634  1
329859  97.578  -71.055  51.599  1
329860  97.607  -71.068  51.563  1
329861  97.637  -71.080  51.526  1
329862  97.667  -71.093  51.488  1
329863  97.696  -71.105  51.449  1
329864  97.726  -71.118  51.408  1
329865  97.758  -71.128  51.365  1
329866  97.792  -71.139  51.318  1
329867  97.823  -71.137  51.271  1
329868  97.853  -71.130  51.227  1
329869  97.887  -71.127  51.188  1
329870  97.924  -71.130  51.154  1
329871  97.962  -71.133  51.121  1
329872  98.000  -71.136  51.083  1
329873  98.032  -71.142  51.043  1
329874  98.061  -71.151  51.000  1
329875  98.089  -71.159  50.955  1
329876  98.118  -71.168  50.908  1
329877  98.147  -71.176  50.858  1
329878  98.187  -71.183  50.805  1
329879  98.227  -71.190  50.750  1
329880  98.267  -71.197  50.690  1
329881  98.304  -71.204  50.628  1
329882  98.340  -71.211  50.567  1
329883  98.376  -71.218  50.505  1
329884  98.413  -71.224  50.445  1
329885  98.448  -71.231  50.391  1
329886  98.485  -71.238  50.338  1
329887  98.521  -71.245  50.283  1
329888  98.557  -71.252  50.226  1
329889  98.593  -71.259  50.165  1
329890  98.632  -71.263  50.102  1
329891  98.672  -71.266  50.038  1
329892  98.712  -71.268  49.973  1
329893  98.748  -71.274  49.909  1
329894  98.778  -71.286  49.845  1
329895  98.808  -71.296  49.781  1
329896  98.838  -71.308  49.718  1
329897  98.868  -71.319  49.655  1
329898  98.898  -71.331  49.593  1
329899  98.928  -71.341  49.530  1
329900  98.957  -71.353  49.467  1
329901  98.990  -71.361  49.405  1
329902  99.022  -71.368  49.345  1
329903  99.055  -71.375  49.286  1
329904  99.087  -71.383  49.230  1
329905  99.106  -71.403  49.177  1
329906  99.123  -71.424  49.124  1
329907  99.140  -71.446  49.072  1
329908  99.160  -71.466  49.021  1
329909  99.199  -71.478  48.970  1
329910  99.244  -71.485  48.917  1
329911  99.289  -71.493  48.866  1
329912  99.335  -71.500  48.816  1
329913  99.379  -71.508  48.766  1
329914  99.425  -71.516  48.716  1
329915  99.470  -71.524  48.667  1
329916  99.515  -71.531  48.619  1
329917  99.560  -71.539  48.571  1
329918  99.606  -71.547  48.526  1
329919  99.640  -71.547  48.480  1
329920  99.674  -71.558  48.436  1
329921  99.715  -71.565  48.392  1
329922  99.765  -71.569  48.348  1
329923  99.815  -71.572  48.306  1
329924  99.857  -71.583  48.265  1
329925  99.894  -71.595  48.224  1
329926  99.930  -71.608  48.184  1
329927  99.966  -71.620  48.143  1
329928  100.002  -71.632  48.101  1
329929  100.038  -71.644  48.059  1
329930  100.074  -71.657  48.018  1
329931  100.110  -71.669  47.978  1
329932  100.146  -71.681  47.939  1
329933  100.182  -71.694  47.899  1
329934  100.218  -71.706  47.859  1
329935  100.254  -71.718  47.818  1
329936  100.290  -71.730  47.778  1
329937  100.323  -71.741  47.739  1
329938  100.351  -71.749  47.702  1
329939  100.378  -71.757  47.667  1
329940  100.405  -71.766  47.629  1
329941  100.433  -71.774  47.591  1
329942  100.460  -71.782  47.552  1
329943  100.487  -71.791  47.513  1
329944  100.510  -71.806  47.476  1
329945  100.534  -71.821  47.440  1
329946  100.557  -71.836  47.402  1
329947  100.580  -71.851  47.364  1
329948  100.607  -71.870  47.326  1
329949  100.642  -71.901  47.291  1
329950  100.677  -71.925  47.256  1
329951  100.711  -71.929  47.221  1
329952  100.745  -71.934  47.188  1
329953  100.778  -71.939  47.153  1
329954  100.812  -71.943  47.120  1
329955  100.846  -71.948  47.087  1
329956  100.880  -71.952  47.055  1
329957  100.914  -71.957  47.027  1
329958  100.948  -71.961  46.997  1
329959  100.981  -71.966  46.964  1
329960  101.015  -71.970  46.930  1
329961  101.049  -71.975  46.893  1
329962  101.097  -71.981  46.855  1
329963  101.140  -71.991  46.819  1
329964  101.164  -72.002  46.783  1
329965  101.200  -72.008  46.746  1
329966  101.236  -72.020  46.711  1
329967  101.271  -72.033  46.675  1
329968  101.307  -72.045  46.637  1
329969  101.342  -72.058  46.602  1
329970  101.378  -72.070  46.565  1
329971  101.414  -72.083  46.528  1
329972  101.450  -72.095  46.491  1
329973  101.485  -72.107  46.453  1
329974  101.521  -72.121  46.412  1
329975  101.556  -72.136  46.373  1
329976  101.592  -72.150  46.332  1
329977  101.627  -72.165  46.291  1
329978  101.664  -72.177  46.251  1
329979  101.699  -72.187  46.209  1
329980  101.732  -72.201  46.168  1
329981  101.759  -72.215  46.129  1
329982  101.782  -72.230  46.093  1
329983  101.805  -72.244  46.056  1
329984  101.829  -72.259  46.019  1
329985  101.852  -72.274  45.981  1
329986  101.875  -72.289  45.944  1
329987  101.902  -72.305  45.906  1
329988  101.929  -72.321  45.869  1
329989  101.956  -72.338  45.831  1
329990  101.980  -72.351  45.793  1
329991  102.006  -72.363  45.755  1
329992  102.032  -72.374  45.718  1
329993  102.063  -72.388  45.682  1
329994  102.095  -72.402  45.646  1
329995  102.116  -72.415  45.610  1
329996  102.141  -72.428  45.574  1
329997  102.168  -72.429  45.539  1
329998  102.193  -72.430  45.504  1
329999  102.218  -72.431  45.470  1
330000  102.242  -72.431  45.436  1
330001  102.267  -72.431  45.403  1
330002  102.292  -72.432  45.371  1
330003  102.317  -72.433  45.339  1
330004  102.341  -72.434  45.307  1
330005  102.366  -72.434  45.276  1
330006  102.392  -72.434  45.244  1
330007  102.418  -72.434  45.212  1
330379  91.755  -70.699  55.327  3
330380  91.786  -70.710  55.316  3
330381  91.817  -70.720  55.305  3
330382  91.849  -70.731  55.295  3
330383  91.880  -70.742  55.283  3
330384  91.911  -70.752  55.272  3
330385  91.942  -70.763  55.260  3
330386  91.973  -70.773  55.248  3
330387  92.004  -70.784  55.237  3
330388  92.035  -70.795  55.226  3
330389  92.067  -70.804  55.216  3
330390  92.098  -70.815  55.207  3
330391  92.146  -70.842  55.199  3
330392  92.197  -70.818  55.192  3
330393  92.225  -70.835  55.184  3
330394  92.253  -70.843  55.172  3
330395  92.282  -70.851  55.157  3
330396  92.310  -70.858  55.139  3
330397  92.340  -70.865  55.118  3
330398  92.380  -70.864  55.097  3
330399  92.422  -70.864  55.074  3
330400  92.462  -70.862  55.051  3
330401  92.504  -70.861  55.028  3
330402  92.545  -70.861  55.003  3
330403  92.585  -70.860  54.975  3
330404  92.623  -70.851  54.945  3
330405  92.658  -70.841  54.914  3
330406  92.699  -70.829  54.880  3
330407  92.746  -70.819  54.842  3
330408  92.793  -70.808  54.805  3
330409  92.841  -70.798  54.767  3
330410  92.879  -70.789  54.727  3
330411  92.905  -70.784  54.687  3
330412  92.930  -70.778  54.645  3
330413  92.956  -70.773  54.603  3
330414  92.982  -70.767  54.562  3
330415  93.008  -70.761  54.521  3
330416  93.034  -70.755  54.481  3
330417  93.059  -70.750  54.442  3
330418  93.085  -70.744  54.404  3
330419  93.111  -70.739  54.369  3
330420  93.137  -70.732  54.336  3
330421  93.162  -70.727  54.305  3
330479  94.831  -70.302  52.782  1
330480  94.859  -70.294  52.771  1
330481  94.888  -70.287  52.761  1
330482  94.917  -70.279  52.751  1
330483  94.946  -70.271  52.743  1
330484  94.975  -70.263  52.734  1
330485  95.004  -70.256  52.726  1
330486  95.033  -70.248  52.718  1
330487  95.065  -70.248  52.709  1
330488  95.098  -70.249  52.705  1
330489  95.131  -70.250  52.702  1
330490  95.164  -70.250  52.698  1
330491  95.194  -70.251  52.694  1
330492  95.225  -70.268  52.689  1
330493  95.259  -70.281  52.682  1
330494  95.295  -70.295  52.674  1
330495  95.329  -70.309  52.666  1
330496  95.365  -70.324  52.656  1
330497  95.400  -70.344  52.643  1
330498  95.436  -70.365  52.628  1
330499  95.472  -70.384  52.612  1
330500  95.508  -70.405  52.595  1
330501  95.544  -70.425  52.576  1
330502  95.580  -70.446  52.556  1
330503  95.616  -70.465  52.537  1
330504  95.654  -70.483  52.518  1
330505  95.692  -70.501  52.499  1
330506  95.729  -70.520  52.480  1
330507  95.767  -70.538  52.461  1
330508  95.804  -70.557  52.442  1
330509  95.839  -70.568  52.424  1
330510  95.869  -70.563  52.405  1
330511  95.898  -70.557  52.388  1
330512  95.927  -70.551  52.370  1
330513  95.957  -70.546  52.354  1
330514  95.983  -70.544  52.336  1
330515  96.006  -70.554  52.319  1
330516  96.028  -70.563  52.303  1
330517  96.050  -70.572  52.288  1
330518  96.073  -70.580  52.274  1
330519  96.095  -70.589  52.260  1
330520  96.118  -70.598  52.248  1
330521  96.152  -70.610  52.235  1
330522  96.190  -70.625  52.222  1
330523  96.229  -70.638  52.209  1
330524  96.268  -70.652  52.196  1
330525  96.307  -70.666  52.183  1
330526  96.345  -70.680  52.170  1
330527  96.371  -70.695  52.153  1
330528  96.413  -70.710  52.135  1
330529  96.468  -70.723  52.115  1
330530  96.516  -70.735  52.096  1
330531  96.564  -70.746  52.081  1
330532  96.612  -70.757  52.067  1
330533  96.660  -70.768  52.054  1
330534  96.708  -70.779  52.038  1
330535  96.755  -70.790  52.024  1
330536  96.803  -70.801  52.011  1
330537  96.834  -70.814  51.999  1
330538  96.863  -70.827  51.987  1
330539  96.903  -70.837  51.978  1
330540  96.948  -70.846  51.967  1
330541  96.992  -70.855  51.956  1
330542  97.037  -70.864  51.945  1
330543  97.081  -70.874  51.935  1
330544  97.126  -70.883  51.926  1
330545  97.166  -70.888  51.917  1
330546  97.205  -70.890  51.905  1
330547  97.237  -70.892  51.887  1
330548  97.255  -70.894  51.866  1
330549  97.273  -70.895  51.845  1
330550  97.291  -70.896  51.823  1
330551  97.315  -70.904  51.804  1
330552  97.345  -70.917  51.784  1
330553  97.375  -70.929  51.763  1
330554  97.404  -70.942  51.743  1
330555  97.434  -70.955  51.727  1
330556  97.463  -70.967  51.710  1
330557  97.493  -70.980  51.690  1
330558  97.522  -70.992  51.668  1
330559  97.551  -71.005  51.643  1
330560  97.581  -71.017  51.609  1
330561  97.610  -71.030  51.571  1
330562  97.640  -71.042  51.531  1
330563  97.669  -71.055  51.492  1
330564  97.699  -71.068  51.451  1
330565  97.730  -71.079  51.409  1
330566  97.764  -71.089  51.366  1
330567  97.796  -71.099  51.321  1
330568  97.828  -71.099  51.277  1
330569  97.858  -71.093  51.236  1
330570  97.888  -71.085  51.200  1
330571  97.925  -71.086  51.166  1
330572  97.962  -71.089  51.134  1
330573  98.000  -71.092  51.095  1
330574  98.029  -71.099  51.053  1
330575  98.058  -71.108  51.009  1
330576  98.087  -71.116  50.962  1
330577  98.121  -71.124  50.913  1
330578  98.161  -71.131  50.861  1
330579  98.201  -71.138  50.807  1
330580  98.237  -71.145  50.749  1
330581  98.273  -71.152  50.689  1
330582  98.309  -71.159  50.626  1
330583  98.345  -71.166  50.564  1
330584  98.381  -71.173  50.504  1
330585  98.418  -71.180  50.447  1
330586  98.454  -71.187  50.395  1
330587  98.490  -71.193  50.342  1
330588  98.526  -71.200  50.287  1
330589  98.563  -71.207  50.228  1
330590  98.599  -71.213  50.166  1
330591  98.639  -71.216  50.102  1
330592  98.678  -71.218  50.037  1
330593  98.719  -71.221  49.973  1
330594  98.757  -71.225  49.908  1
330595  98.787  -71.237  49.843  1
330596  98.817  -71.248  49.780  1
330597  98.847  -71.259  49.716  1
330598  98.877  -71.270  49.653  1
330599  98.907  -71.281  49.591  1
330600  98.937  -71.293  49.529  1
330601  98.967  -71.303  49.466  1
330602  98.997  -71.315  49.405  1
330603  99.027  -71.326  49.345  1
330604  99.059  -71.333  49.287  1
330605  99.092  -71.340  49.232  1
330606  99.114  -71.358  49.180  1
330607  99.131  -71.379  49.127  1
330608  99.153  -71.398  49.076  1
330609  99.180  -71.415  49.024  1
330610  99.212  -71.430  48.972  1
330611  99.257  -71.438  48.919  1
330612  99.303  -71.447  48.868  1
330613  99.348  -71.456  48.819  1
330614  99.394  -71.464  48.769  1
330615  99.439  -71.472  48.719  1
330616  99.484  -71.479  48.671  1
330617  99.529  -71.487  48.623  1
330618  99.574  -71.494  48.576  1
330619  99.620  -71.502  48.532  1
330620  99.663  -71.504  48.487  1
330621  99.697  -71.514  48.443  1
330622  99.738  -71.522  48.400  1
330623  99.788  -71.525  48.357  1
330624  99.832  -71.535  48.315  1
330625  99.868  -71.547  48.275  1
330626  99.904  -71.559  48.235  1
330627  99.940  -71.571  48.196  1
330628  99.976  -71.584  48.155  1
330629  100.012  -71.596  48.114  1
330630  100.048  -71.608  48.072  1
330631  100.084  -71.620  48.031  1
330632  100.120  -71.632  47.992  1
330633  100.156  -71.644  47.952  1
330634  100.192  -71.657  47.912  1
330635  100.228  -71.669  47.871  1
330636  100.264  -71.682  47.830  1
330637  100.300  -71.694  47.790  1
330638  100.335  -71.705  47.751  1
330639  100.362  -71.713  47.713  1
330640  100.390  -71.722  47.677  1
330641  100.417  -71.730  47.639  1
330642  100.444  -71.738  47.600  1
330643  100.472  -71.747  47.561  1
330644  100.497  -71.759  47.521  1
330645  100.520  -71.774  47.484  1
330646  100.543  -71.789  47.448  1
330647  100.566  -71.804  47.410  1
330648  100.590  -71.820  47.371  1
330649  100.615  -71.836  47.332  1
330650  100.650  -71.867  47.296  1
330651  100.685  -71.889  47.261  1
330652  100.718  -71.893  47.226  1
330653  100.752  -71.898  47.192  1
330654  100.786  -71.902  47.157  1
330655  100.820  -71.907  47.123  1
330656  100.854  -71.911  47.091  1
330657  100.888  -71.916  47.062  1
330658  100.921  -71.920  47.034  1
330659  100.955  -71.925  47.003  1
330660  100.989  -71.929  46.970  1
330661  101.025  -71.934  46.936  1
330662  101.078  -71.942  46.900  1
330663  101.132  -71.949  46.863  1
330664  101.152  -71.963  46.827  1
330665  101.178  -71.973  46.791  1
330666  101.214  -71.980  46.755  1
330667  101.250  -71.987  46.719  1
330668  101.286  -71.999  46.682  1
330669  101.321  -72.012  46.645  1
330670  101.357  -72.024  46.609  1
330671  101.393  -72.037  46.572  1
330672  101.428  -72.049  46.536  1
330673  101.464  -72.061  46.500  1
330674  101.500  -72.074  46.462  1
330675  101.536  -72.086  46.421  1
330676  101.571  -72.099  46.381  1
330677  101.607  -72.111  46.342  1
330678  101.642  -72.124  46.302  1
330679  101.678  -72.136  46.261  1
330680  101.709  -72.150  46.220  1
330681  101.736  -72.167  46.180  1
330682  101.763  -72.183  46.141  1
330683  101.790  -72.200  46.104  1
330684  101.817  -72.217  46.068  1
330685  101.844  -72.233  46.032  1
330686  101.871  -72.249  45.995  1
330687  101.898  -72.266  45.959  1
330688  101.925  -72.283  45.922  1
330689  101.952  -72.299  45.885  1
330690  101.979  -72.315  45.847  1
330691  102.001  -72.325  45.809  1
330692  102.026  -72.336  45.770  1
330693  102.051  -72.348  45.734  1
330694  102.077  -72.359  45.697  1
330695  102.102  -72.371  45.661  1
330696  102.127  -72.383  45.624  1
330697  102.153  -72.390  45.587  1
330698  102.179  -72.390  45.551  1
330699  102.206  -72.390  45.516  1
330700  102.232  -72.390  45.482  1
330701  102.258  -72.390  45.448  1
330702  102.284  -72.390  45.416  1
330703  102.311  -72.390  45.383  1
330704  102.337  -72.389  45.351  1
330705  102.364  -72.389  45.319  1
330706  102.390  -72.389  45.288  1
330707  102.416  -72.389  45.256  1
330708  102.443  -72.388  45.224  1
331081  91.774  -70.678  55.314  3
331082  91.805  -70.688  55.304  3
331083  91.837  -70.699  55.293  3
331084  91.868  -70.709  55.282  3
331085  91.899  -70.720  55.271  3
331086  91.930  -70.730  55.260  3
331087  91.961  -70.741  55.248  3
331088  91.992  -70.751  55.237  3
331089  92.023  -70.762  55.227  3
331090  92.055  -70.773  55.217  3
331091  92.086  -70.783  55.209  3
331092  92.139  -70.813  55.202  3
331093  92.190  -70.789  55.196  3
331094  92.225  -70.795  55.192  3
331095  92.251  -70.809  55.185  3
331096  92.280  -70.817  55.173  3
331097  92.308  -70.824  55.156  3
331098  92.346  -70.826  55.135  3
331099  92.387  -70.824  55.112  3
331100  92.428  -70.823  55.089  3
331101  92.469  -70.823  55.065  3
331102  92.510  -70.822  55.041  3
331103  92.551  -70.821  55.016  3
331104  92.592  -70.820  54.989  3
331105  92.632  -70.817  54.960  3
331106  92.667  -70.806  54.928  3
331107  92.703  -70.795  54.894  3
331108  92.744  -70.785  54.856  3
331109  92.791  -70.774  54.819  3
331110  92.839  -70.764  54.781  3
331111  92.874  -70.755  54.739  3
331112  92.900  -70.750  54.697  3
331113  92.926  -70.744  54.655  3
331114  92.951  -70.739  54.613  3
331115  92.977  -70.732  54.570  3
331116  93.003  -70.727  54.529  3
331117  93.028  -70.721  54.488  3
331118  93.055  -70.716  54.449  3
331119  93.080  -70.710  54.410  3
331120  93.106  -70.704  54.373  3
331121  93.132  -70.699  54.338  3
331122  93.157  -70.693  54.306  3
331123  93.184  -70.688  54.276  3
331180  94.838  -70.256  52.788  1
331181  94.867  -70.249  52.779  1
331182  94.896  -70.241  52.770  1
331183  94.925  -70.233  52.763  1
331184  94.954  -70.225  52.754  1
331185  94.986  -70.226  52.746  1
331186  95.020  -70.227  52.738  1
331187  95.052  -70.228  52.730  1
331188  95.086  -70.228  52.723  1
331189  95.119  -70.229  52.719  1
331190  95.151  -70.230  52.716  1
331191  95.185  -70.231  52.713  1
331192  95.216  -70.231  52.710  1
331193  95.252  -70.244  52.707  1
331194  95.286  -70.258  52.701  1
331195  95.321  -70.272  52.694  1
331196  95.356  -70.285  52.687  1
331197  95.391  -70.299  52.675  1
331198  95.426  -70.313  52.662  1
331199  95.461  -70.327  52.647  1
331200  95.496  -70.341  52.631  1
331201  95.532  -70.362  52.613  1
331202  95.568  -70.382  52.592  1
331203  95.604  -70.402  52.571  1
331204  95.639  -70.422  52.551  1
331205  95.676  -70.442  52.531  1
331206  95.713  -70.460  52.512  1
331207  95.751  -70.479  52.492  1
331208  95.789  -70.497  52.473  1
331209  95.826  -70.516  52.455  1
331210  95.858  -70.517  52.435  1
331211  95.887  -70.511  52.416  1
331212  95.916  -70.506  52.398  1
331213  95.945  -70.501  52.380  1
331214  95.967  -70.510  52.363  1
331215  95.990  -70.519  52.345  1
331216  96.012  -70.528  52.328  1
331217  96.035  -70.537  52.310  1
331218  96.057  -70.546  52.295  1
331219  96.080  -70.554  52.281  1
331220  96.102  -70.563  52.267  1
331221  96.124  -70.572  52.253  1
331222  96.151  -70.582  52.239  1
331223  96.190  -70.597  52.225  1
331224  96.229  -70.610  52.210  1
331225  96.267  -70.624  52.196  1
331226  96.306  -70.638  52.184  1
331227  96.345  -70.652  52.170  1
331228  96.384  -70.666  52.154  1
331229  96.424  -70.679  52.136  1
331230  96.470  -70.691  52.117  1
331231  96.517  -70.702  52.098  1
331232  96.565  -70.713  52.082  1
331233  96.613  -70.724  52.066  1
331234  96.661  -70.735  52.052  1
331235  96.709  -70.747  52.037  1
331236  96.756  -70.757  52.024  1
331237  96.804  -70.769  52.011  1
331238  96.837  -70.782  52.000  1
331239  96.868  -70.794  51.990  1
331240  96.913  -70.803  51.982  1
331241  96.957  -70.812  51.972  1
331242  97.002  -70.821  51.962  1
331243  97.046  -70.830  51.955  1
331244  97.091  -70.839  51.950  1
331245  97.136  -70.848  51.945  1
331246  97.179  -70.856  51.939  1
331247  97.218  -70.859  51.929  1
331248  97.246  -70.861  51.911  1
331249  97.264  -70.862  51.888  1
331250  97.282  -70.864  51.865  1
331251  97.298  -70.864  51.842  1
331252  97.318  -70.871  51.820  1
331253  97.348  -70.878  51.797  1
331254  97.377  -70.891  51.775  1
331255  97.407  -70.904  51.755  1
331256  97.436  -70.916  51.738  1
331257  97.466  -70.929  51.720  1
331258  97.495  -70.942  51.700  1
331259  97.525  -70.954  51.677  1
331260  97.555  -70.967  51.650  1
331261  97.584  -70.979  51.616  1
331262  97.613  -70.992  51.576  1
331263  97.643  -71.005  51.536  1
331264  97.672  -71.017  51.494  1
331265  97.702  -71.029  51.452  1
331266  97.735  -71.039  51.411  1
331267  97.768  -71.049  51.368  1
331268  97.801  -71.060  51.325  1
331269  97.833  -71.061  51.283  1
331270  97.863  -71.054  51.244  1
331271  97.893  -71.047  51.209  1
331272  97.925  -71.041  51.177  1
331273  97.962  -71.044  51.145  1
331274  97.998  -71.049  51.105  1
331275  98.027  -71.057  51.061  1
331276  98.056  -71.065  51.015  1
331277  98.095  -71.072  50.966  1
331278  98.134  -71.080  50.915  1
331279  98.170  -71.086  50.861  1
331280  98.206  -71.093  50.805  1
331281  98.242  -71.100  50.746  1
331282  98.278  -71.107  50.685  1
331283  98.314  -71.114  50.623  1
331284  98.351  -71.121  50.562  1
331285  98.387  -71.127  50.504  1
331286  98.423  -71.134  50.450  1
331287  98.459  -71.141  50.399  1
331288  98.495  -71.148  50.345  1
331289  98.531  -71.155  50.289  1
331290  98.568  -71.162  50.229  1
331291  98.606  -71.166  50.166  1
331292  98.646  -71.168  50.101  1
331293  98.686  -71.171  50.036  1
331294  98.725  -71.174  49.972  1
331295  98.765  -71.177  49.906  1
331296  98.796  -71.187  49.842  1
331297  98.827  -71.199  49.778  1
331298  98.856  -71.210  49.714  1
331299  98.886  -71.221  49.651  1
331300  98.916  -71.232  49.589  1
331301  98.946  -71.243  49.528  1
331302  98.976  -71.255  49.466  1
331303  99.006  -71.265  49.405  1
331304  99.036  -71.277  49.346  1
331305  99.066  -71.288  49.289  1
331306  99.096  -71.298  49.235  1
331307  99.121  -71.312  49.183  1
331308  99.146  -71.331  49.131  1
331309  99.173  -71.347  49.079  1
331310  99.201  -71.364  49.028  1
331311  99.228  -71.381  48.975  1
331312  99.270  -71.390  48.921  1
331313  99.316  -71.400  48.871  1
331314  99.361  -71.408  48.821  1
331315  99.407  -71.416  48.772  1
331316  99.452  -71.425  48.723  1
331317  99.497  -71.434  48.675  1
331318  99.543  -71.442  48.628  1
331319  99.588  -71.450  48.582  1
331320  99.633  -71.458  48.538  1
331321  99.679  -71.466  48.494  1
331322  99.720  -71.471  48.451  1
331323  99.761  -71.478  48.408  1
331324  99.806  -71.486  48.365  1
331325  99.842  -71.498  48.324  1
331326  99.878  -71.510  48.286  1
331327  99.914  -71.522  48.247  1
331328  99.950  -71.534  48.209  1
331329  99.986  -71.547  48.168  1
331330  100.022  -71.560  48.127  1
331331  100.058  -71.572  48.085  1
331332  100.094  -71.584  48.045  1
331333  100.130  -71.596  48.006  1
331334  100.167  -71.608  47.966  1
331335  100.202  -71.621  47.926  1
331336  100.239  -71.633  47.885  1
331337  100.275  -71.645  47.844  1
331338  100.311  -71.657  47.803  1
331339  100.347  -71.669  47.764  1
331340  100.374  -71.678  47.724  1
331341  100.402  -71.686  47.686  1
331342  100.429  -71.694  47.647  1
331343  100.456  -71.703  47.608  1
331344  100.483  -71.712  47.569  1
331345  100.506  -71.727  47.529  1
331346  100.530  -71.742  47.492  1
331347  100.553  -71.757  47.456  1
331348  100.576  -71.773  47.418  1
331349  100.599  -71.788  47.379  1
331350  100.622  -71.803  47.340  1
331351  100.657  -71.833  47.303  1
331352  100.692  -71.852  47.266  1
331353  100.726  -71.857  47.230  1
331354  100.760  -71.861  47.195  1
331355  100.793  -71.866  47.162  1
331356  100.828  -71.870  47.128  1
331357  100.861  -71.875  47.096  1
331358  100.895  -71.879  47.066  1
331359  100.929  -71.884  47.037  1
331360  100.963  -71.889  47.005  1
331361  101.006  -71.895  46.971  1
331362  101.059  -71.902  46.938  1
331363  101.113  -71.909  46.904  1
331364  101.148  -71.920  46.869  1
331365  101.165  -71.935  46.835  1
331366  101.193  -71.945  46.800  1
331367  101.229  -71.951  46.765  1
331368  101.265  -71.956  46.729  1
331369  101.301  -71.967  46.691  1
331370  101.336  -71.979  46.654  1
331371  101.372  -71.991  46.617  1
331372  101.407  -72.004  46.580  1
331373  101.443  -72.016  46.543  1
331374  101.479  -72.029  46.506  1
331375  101.515  -72.041  46.469  1
331376  101.550  -72.053  46.429  1
331377  101.586  -72.066  46.389  1
331378  101.621  -72.078  46.349  1
331379  101.657  -72.091  46.310  1
331380  101.693  -72.103  46.270  1
331381  101.729  -72.121  46.230  1
331382  101.758  -72.141  46.191  1
331383  101.786  -72.161  46.152  1
331384  101.814  -72.177  46.116  1
331385  101.840  -72.194  46.080  1
331386  101.868  -72.210  46.044  1
331387  101.894  -72.227  46.008  1
331388  101.921  -72.243  45.972  1
331389  101.948  -72.260  45.936  1
331390  101.975  -72.276  45.899  1
331391  102.001  -72.292  45.862  1
331392  102.022  -72.299  45.823  1
331393  102.045  -72.309  45.785  1
331394  102.071  -72.321  45.748  1
331395  102.096  -72.333  45.711  1
331396  102.120  -72.340  45.674  1
331397  102.136  -72.338  45.637  1
331398  102.166  -72.340  45.600  1
331399  102.196  -72.341  45.563  1
331400  102.226  -72.343  45.527  1
331401  102.256  -72.344  45.493  1
331402  102.283  -72.344  45.461  1
331403  102.309  -72.344  45.429  1
331404  102.335  -72.344  45.396  1
331405  102.362  -72.343  45.363  1
331406  102.388  -72.343  45.330  1
331407  102.414  -72.343  45.299  1
331408  102.441  -72.343  45.268  1
331409  102.467  -72.343  45.237  1
331783  91.793  -70.656  55.302  3
331784  91.824  -70.666  55.291  3
331785  91.856  -70.677  55.280  3
331786  91.887  -70.688  55.269  3
331787  91.918  -70.698  55.258  3
331788  91.949  -70.709  55.248  3
331789  91.981  -70.719  55.238  3
331790  92.011  -70.729  55.227  3
331791  92.042  -70.740  55.218  3
331792  92.078  -70.754  55.210  3
331793  92.132  -70.783  55.203  3
331794  92.183  -70.759  55.199  3
331795  92.225  -70.751  55.197  3
331796  92.249  -70.775  55.196  3
331797  92.278  -70.782  55.188  3
331798  92.312  -70.786  55.172  3
331799  92.353  -70.785  55.151  3
331800  92.393  -70.785  55.128  3
331801  92.435  -70.784  55.104  3
331802  92.476  -70.783  55.079  3
331803  92.516  -70.782  55.054  3
331804  92.558  -70.781  55.028  3
331805  92.598  -70.780  55.001  3
331806  92.640  -70.779  54.973  3
331807  92.677  -70.772  54.942  3
331808  92.713  -70.761  54.907  3
331809  92.748  -70.750  54.870  3
331810  92.789  -70.739  54.833  3
331811  92.836  -70.729  54.794  3
331812  92.869  -70.722  54.752  3
331813  92.895  -70.716  54.709  3
331814  92.921  -70.710  54.667  3
331815  92.946  -70.704  54.625  3
331816  92.972  -70.699  54.582  3
331817  92.998  -70.693  54.540  3
331818  93.024  -70.688  54.498  3
331819  93.050  -70.682  54.457  3
331820  93.075  -70.676  54.417  3
331821  93.101  -70.670  54.380  3
331822  93.127  -70.665  54.343  3
331823  93.155  -70.658  54.309  3
331824  93.185  -70.650  54.277  3
331825  93.215  -70.642  54.246  3
331881  94.845  -70.211  52.795  1
331882  94.875  -70.204  52.786  1
331883  94.908  -70.205  52.779  1
331884  94.941  -70.206  52.772  1
331885  94.974  -70.206  52.764  1
331886  95.007  -70.206  52.757  1
331887  95.040  -70.207  52.750  1
331888  95.073  -70.208  52.743  1
331889  95.106  -70.209  52.737  1
331890  95.139  -70.209  52.734  1
331891  95.172  -70.210  52.731  1
331892  95.207  -70.209  52.728  1
331893  95.244  -70.207  52.726  1
331894  95.278  -70.221  52.724  1
331895  95.313  -70.234  52.718  1
331896  95.348  -70.248  52.712  1
331897  95.383  -70.262  52.705  1
331898  95.418  -70.275  52.694  1
331899  95.453  -70.289  52.680  1
331900  95.488  -70.303  52.665  1
331901  95.523  -70.317  52.649  1
331902  95.558  -70.331  52.630  1
331903  95.593  -70.344  52.609  1
331904  95.628  -70.359  52.587  1
331905  95.664  -70.379  52.565  1
331906  95.699  -70.400  52.545  1
331907  95.736  -70.419  52.524  1
331908  95.773  -70.438  52.505  1
331909  95.811  -70.456  52.485  1
331910  95.847  -70.472  52.466  1
331911  95.876  -70.466  52.447  1
331912  95.906  -70.460  52.428  1
331913  95.929  -70.466  52.409  1
331914  95.952  -70.475  52.390  1
331915  95.974  -70.485  52.374  1
331916  95.996  -70.494  52.355  1
331917  96.019  -70.502  52.337  1
331918  96.041  -70.511  52.319  1
331919  96.063  -70.520  52.304  1
331920  96.086  -70.529  52.289  1
331921  96.108  -70.538  52.275  1
331922  96.130  -70.547  52.261  1
331923  96.154  -70.555  52.248  1
331924  96.191  -70.568  52.232  1
331925  96.232  -70.581  52.215  1
331926  96.271  -70.594  52.200  1
331927  96.311  -70.607  52.187  1
331928  96.352  -70.621  52.172  1
331929  96.391  -70.635  52.157  1
331930  96.431  -70.648  52.140  1
331931  96.467  -70.651  52.122  1
331932  96.517  -70.666  52.103  1
331933  96.566  -70.680  52.084  1
331934  96.614  -70.691  52.068  1
331935  96.662  -70.703  52.054  1
331936  96.710  -70.714  52.039  1
331937  96.757  -70.726  52.025  1
331938  96.805  -70.736  52.014  1
331939  96.839  -70.749  52.004  1
331940  96.878  -70.759  51.996  1
331941  96.923  -70.768  51.989  1
331942  96.967  -70.777  51.981  1
331943  97.012  -70.787  51.974  1
331944  97.056  -70.796  51.970  1
331945  97.101  -70.805  51.968  1
331946  97.145  -70.814  51.966  1
331947  97.190  -70.823  51.961  1
331948  97.230  -70.828  51.951  1
331949  97.254  -70.829  51.932  1
331950  97.273  -70.830  51.907  1
331951  97.287  -70.832  51.882  1
331952  97.302  -70.833  51.857  1
331953  97.324  -70.842  51.832  1
331954  97.348  -70.850  51.808  1
331955  97.380  -70.854  51.786  1
331956  97.409  -70.865  51.765  1
331957  97.439  -70.878  51.748  1
331958  97.468  -70.891  51.728  1
331959  97.498  -70.903  51.707  1
331960  97.528  -70.916  51.682  1
331961  97.557  -70.928  51.654  1
331962  97.587  -70.941  51.619  1
331963  97.616  -70.954  51.580  1
331964  97.646  -70.966  51.538  1
331965  97.675  -70.979  51.496  1
331966  97.707  -70.989  51.454  1
331967  97.740  -71.000  51.414  1
331968  97.773  -71.010  51.374  1
331969  97.806  -71.021  51.333  1
331970  97.838  -71.023  51.291  1
331971  97.868  -71.016  51.251  1
331972  97.898  -71.008  51.216  1
331973  97.929  -71.002  51.184  1
331974  97.963  -70.999  51.152  1
331975  97.995  -71.005  51.111  1
331976  98.029  -71.014  51.066  1
331977  98.067  -71.021  51.018  1
331978  98.103  -71.027  50.966  1
331979  98.139  -71.034  50.913  1
331980  98.175  -71.041  50.858  1
331981  98.211  -71.048  50.801  1
331982  98.247  -71.055  50.741  1
331983  98.284  -71.061  50.680  1
331984  98.320  -71.068  50.620  1
331985  98.356  -71.075  50.561  1
331986  98.392  -71.082  50.506  1
331987  98.428  -71.089  50.455  1
331988  98.464  -71.096  50.401  1
331989  98.501  -71.102  50.347  1
331990  98.537  -71.109  50.289  1
331991  98.573  -71.116  50.227  1
331992  98.613  -71.119  50.164  1
331993  98.653  -71.121  50.098  1
331994  98.693  -71.124  50.033  1
331995  98.732  -71.127  49.968  1
331996  98.772  -71.130  49.904  1
331997  98.806  -71.138  49.839  1
331998  98.836  -71.149  49.776  1
331999  98.866  -71.161  49.713  1
332000  98.896  -71.172  49.649  1
332001  98.926  -71.183  49.588  1
332002  98.955  -71.194  49.527  1
332003  98.985  -71.205  49.466  1
332004  99.015  -71.217  49.406  1
332005  99.045  -71.227  49.348  1
332006  99.075  -71.239  49.291  1
332007  99.105  -71.250  49.238  1
332008  99.137  -71.264  49.186  1
332009  99.167  -71.280  49.134  1
332010  99.194  -71.296  49.082  1
332011  99.221  -71.313  49.030  1
332012  99.249  -71.330  48.977  1
332013  99.284  -71.343  48.924  1
332014  99.329  -71.352  48.874  1
332015  99.374  -71.360  48.825  1
332016  99.420  -71.368  48.775  1
332017  99.465  -71.378  48.728  1
332018  99.510  -71.386  48.680  1
332019  99.556  -71.394  48.633  1
332020  99.602  -71.403  48.589  1
332021  99.647  -71.412  48.545  1
332022  99.692  -71.420  48.502  1
332023  99.737  -71.429  48.459  1
332024  99.780  -71.437  48.417  1
332025  99.816  -71.450  48.374  1
332026  99.852  -71.462  48.335  1
332027  99.888  -71.474  48.296  1
332028  99.924  -71.486  48.258  1
332029  99.960  -71.498  48.221  1
332030  99.996  -71.510  48.181  1
332031  100.032  -71.523  48.141  1
332032  100.068  -71.535  48.101  1
332033  100.105  -71.547  48.061  1
332034  100.140  -71.560  48.022  1
332035  100.177  -71.572  47.982  1
332036  100.212  -71.584  47.941  1
332037  100.249  -71.597  47.900  1
332038  100.285  -71.609  47.858  1
332039  100.321  -71.621  47.816  1
332040  100.357  -71.633  47.775  1
332041  100.386  -71.642  47.735  1
332042  100.413  -71.650  47.695  1
332043  100.440  -71.659  47.656  1
332044  100.468  -71.667  47.617  1
332045  100.492  -71.680  47.577  1
332046  100.515  -71.695  47.538  1
332047  100.539  -71.710  47.501  1
332048  100.562  -71.726  47.463  1
332049  100.585  -71.741  47.425  1
332050  100.609  -71.756  47.385  1
332051  100.632  -71.771  47.346  1
332052  100.665  -71.799  47.308  1
332053  100.700  -71.817  47.271  1
332054  100.734  -71.821  47.236  1
332055  100.767  -71.826  47.200  1
332056  100.802  -71.830  47.166  1
332057  100.835  -71.834  47.133  1
332058  100.869  -71.838  47.102  1
332059  100.903  -71.843  47.071  1
332060  100.936  -71.848  47.039  1
332061  100.987  -71.854  47.006  1
332062  101.041  -71.862  46.973  1
332063  101.095  -71.870  46.942  1
332064  101.144  -71.878  46.910  1
332065  101.160  -71.892  46.877  1
332066  101.177  -71.907  46.844  1
332067  101.207  -71.916  46.810  1
332068  101.243  -71.921  46.775  1
332069  101.279  -71.927  46.739  1
332070  101.315  -71.933  46.701  1
332071  101.351  -71.945  46.664  1
332072  101.387  -71.958  46.626  1
332073  101.422  -71.970  46.588  1
332074  101.458  -71.983  46.551  1
332075  101.493  -71.995  46.513  1
332076  101.529  -72.008  46.475  1
332077  101.565  -72.020  46.436  1
332078  101.601  -72.033  46.397  1
332079  101.636  -72.045  46.357  1
332080  101.672  -72.058  46.318  1
332081  101.709  -72.071  46.279  1
332082  101.748  -72.089  46.239  1
332083  101.776  -72.110  46.201  1
332084  101.805  -72.130  46.164  1
332085  101.834  -72.150  46.127  1
332086  101.863  -72.170  46.091  1
332087  101.891  -72.187  46.055  1
332088  101.917  -72.204  46.020  1
332089  101.945  -72.221  45.983  1
332090  101.971  -72.237  45.948  1
332091  101.998  -72.253  45.911  1
332092  102.023  -72.266  45.873  1
332093  102.044  -72.274  45.835  1
332094  102.065  -72.283  45.796  1
332095  102.089  -72.288  45.759  1
332096  102.112  -72.291  45.721  1
332097  102.120  -72.286  45.683  1
332098  102.150  -72.288  45.646  1
332099  102.180  -72.290  45.609  1
332100  102.210  -72.291  45.573  1
332101  102.240  -72.293  45.538  1
332102  102.270  -72.294  45.504  1
332103  102.300  -72.296  45.471  1
332104  102.330  -72.297  45.438  1
332105  102.360  -72.299  45.406  1
332106  102.386  -72.298  45.374  1
332107  102.412  -72.298  45.341  1
332108  102.439  -72.298  45.310  1
332109  102.465  -72.298  45.278  1
332110  102.491  -72.297  45.248  1
332485  91.812  -70.634  55.288  3
332486  91.844  -70.644  55.278  3
332487  91.875  -70.655  55.267  3
332488  91.906  -70.666  55.256  3
332489  91.937  -70.676  55.246  3
332490  91.968  -70.687  55.237  3
332491  92.000  -70.698  55.228  3
332492  92.030  -70.708  55.220  3
332493  92.072  -70.726  55.211  3
332494  92.125  -70.754  55.204  3
332495  92.176  -70.729  55.200  3
332496  92.226  -70.707  55.199  3
332497  92.248  -70.739  55.202  3
332498  92.277  -70.748  55.197  3
332499  92.318  -70.747  55.185  3
332500  92.359  -70.746  55.167  3
332501  92.400  -70.745  55.146  3
332502  92.441  -70.744  55.120  3
332503  92.482  -70.743  55.093  3
332504  92.523  -70.742  55.066  3
332505  92.564  -70.742  55.038  3
332506  92.605  -70.741  55.012  3
332507  92.646  -70.739  54.985  3
332508  92.687  -70.738  54.956  3
332509  92.722  -70.726  54.920  3
332510  92.758  -70.716  54.883  3
332511  92.793  -70.705  54.846  3
332512  92.834  -70.695  54.807  3
332513  92.864  -70.688  54.765  3
332514  92.890  -70.682  54.722  3
332515  92.916  -70.676  54.680  3
332516  92.941  -70.670  54.638  3
332517  92.970  -70.663  54.595  3
332518  93.000  -70.655  54.552  3
332519  93.030  -70.648  54.509  3
332520  93.060  -70.639  54.467  3
332521  93.090  -70.632  54.426  3
332522  93.120  -70.624  54.387  3
332523  93.149  -70.616  54.350  3
332524  93.178  -70.609  54.314  3
332525  93.206  -70.601  54.280  3
332526  93.235  -70.593  54.248  3
332527  93.264  -70.585  54.218  3
332581  94.829  -70.183  52.808  1
332582  94.862  -70.184  52.802  1
332583  94.895  -70.184  52.794  1
332584  94.928  -70.185  52.786  1
332585  94.961  -70.186  52.780  1
332586  94.994  -70.187  52.773  1
332587  95.027  -70.187  52.767  1
332588  95.060  -70.188  52.762  1
332589  95.093  -70.189  52.756  1
332590  95.126  -70.189  52.751  1
332591  95.159  -70.190  52.748  1
332592  95.192  -70.190  52.746  1
332593  95.234  -70.183  52.744  1
332594  95.270  -70.183  52.743  1
332595  95.306  -70.197  52.740  1
332596  95.340  -70.211  52.735  1
332597  95.375  -70.225  52.729  1
332598  95.410  -70.238  52.723  1
332599  95.445  -70.252  52.712  1
332600  95.480  -70.265  52.699  1
332601  95.515  -70.279  52.683  1
332602  95.550  -70.293  52.665  1
332603  95.585  -70.307  52.647  1
332604  95.620  -70.321  52.626  1
332605  95.655  -70.334  52.603  1
332606  95.690  -70.348  52.579  1
332607  95.725  -70.362  52.558  1
332608  95.760  -70.377  52.537  1
332609  95.796  -70.397  52.517  1
332610  95.833  -70.416  52.498  1
332611  95.866  -70.420  52.477  1
332612  95.891  -70.423  52.459  1
332613  95.913  -70.432  52.440  1
332614  95.936  -70.441  52.421  1
332615  95.958  -70.450  52.402  1
332616  95.981  -70.459  52.384  1
332617  96.004  -70.466  52.365  1
332618  96.027  -70.475  52.346  1
332619  96.050  -70.483  52.329  1
332620  96.074  -70.491  52.313  1
332621  96.097  -70.499  52.298  1
332622  96.120  -70.507  52.284  1
332623  96.143  -70.516  52.270  1
332624  96.166  -70.524  52.256  1
332625  96.202  -70.536  52.240  1
332626  96.240  -70.549  52.222  1
332627  96.279  -70.563  52.206  1
332628  96.319  -70.576  52.193  1
332629  96.360  -70.589  52.179  1
332630  96.399  -70.603  52.163  1
332631  96.439  -70.614  52.146  1
332632  96.474  -70.616  52.127  1
332633  96.514  -70.623  52.109  1
332634  96.563  -70.638  52.091  1
332635  96.612  -70.653  52.075  1
332636  96.662  -70.667  52.060  1
332637  96.711  -70.682  52.044  1
332638  96.758  -70.693  52.032  1
332639  96.806  -70.704  52.022  1
332640  96.843  -70.716  52.014  1
332641  96.888  -70.725  52.008  1
332642  96.933  -70.734  52.004  1
332643  96.977  -70.743  51.998  1
332644  97.022  -70.752  51.992  1
332645  97.066  -70.761  51.988  1
332646  97.111  -70.770  51.987  1
332647  97.155  -70.779  51.984  1
332648  97.199  -70.789  51.979  1
332649  97.243  -70.796  51.969  1
332650  97.263  -70.798  51.949  1
332651  97.277  -70.798  51.923  1
332652  97.290  -70.799  51.895  1
332653  97.308  -70.804  51.867  1
332654  97.330  -70.813  51.841  1
332655  97.353  -70.822  51.817  1
332656  97.379  -70.829  51.795  1
332657  97.411  -70.832  51.775  1
332658  97.442  -70.840  51.757  1
332659  97.471  -70.852  51.735  1
332660  97.501  -70.865  51.712  1
332661  97.530  -70.877  51.686  1
332662  97.560  -70.890  51.656  1
332663  97.589  -70.903  51.618  1
332664  97.619  -70.915  51.578  1
332665  97.648  -70.928  51.538  1
332666  97.678  -70.940  51.497  1
332667  97.712  -70.950  51.458  1
332668  97.745  -70.961  51.420  1
332669  97.778  -70.970  51.380  1
332670  97.811  -70.980  51.338  1
332671  97.843  -70.985  51.296  1
332672  97.873  -70.977  51.258  1
332673  97.903  -70.970  51.223  1
332674  97.934  -70.963  51.190  1
332675  97.964  -70.956  51.155  1
332676  98.000  -70.961  51.113  1
332677  98.036  -70.968  51.066  1
332678  98.072  -70.975  51.016  1
332679  98.108  -70.982  50.963  1
332680  98.144  -70.989  50.909  1
332681  98.180  -70.995  50.853  1
332682  98.217  -71.002  50.795  1
332683  98.253  -71.009  50.735  1
332684  98.289  -71.016  50.675  1
332685  98.325  -71.023  50.617  1
332686  98.361  -71.030  50.562  1
332687  98.397  -71.036  50.510  1
332688  98.434  -71.043  50.459  1
332689  98.470  -71.050  50.404  1
332690  98.506  -71.057  50.347  1
332691  98.542  -71.064  50.289  1
332692  98.580  -71.069  50.227  1
332693  98.620  -71.071  50.162  1
332694  98.660  -71.074  50.096  1
332695  98.700  -71.077  50.030  1
332696  98.739  -71.080  49.964  1
332697  98.779  -71.083  49.900  1
332698  98.815  -71.089  49.836  1
332699  98.845  -71.100  49.773  1
332700  98.875  -71.111  49.710  1
332701  98.905  -71.123  49.648  1
332702  98.935  -71.133  49.586  1
332703  98.964  -71.145  49.526  1
332704  98.995  -71.156  49.466  1
332705  99.024  -71.168  49.407  1
332706  99.055  -71.179  49.349  1
332707  99.084  -71.190  49.293  1
332708  99.117  -71.204  49.239  1
332709  99.149  -71.218  49.188  1
332710  99.182  -71.232  49.136  1
332711  99.214  -71.246  49.085  1
332712  99.242  -71.262  49.032  1
332713  99.269  -71.279  48.980  1
332714  99.297  -71.295  48.927  1
332715  99.342  -71.304  48.877  1
332716  99.387  -71.312  48.829  1
332717  99.433  -71.321  48.780  1
332718  99.478  -71.330  48.732  1
332719  99.523  -71.338  48.685  1
332720  99.569  -71.346  48.640  1
332721  99.615  -71.356  48.596  1
332722  99.659  -71.364  48.553  1
332723  99.699  -71.371  48.510  1
332724  99.740  -71.378  48.468  1
332725  99.783  -71.393  48.427  1
332726  99.822  -71.409  48.385  1
332727  99.861  -71.424  48.346  1
332728  99.898  -71.437  48.308  1
332729  99.934  -71.450  48.271  1
332730  99.970  -71.462  48.234  1
332731  100.006  -71.474  48.195  1
332732  100.043  -71.487  48.156  1
332733  100.078  -71.499  48.116  1
332734  100.115  -71.511  48.076  1
332735  100.150  -71.523  48.037  1
332736  100.187  -71.535  47.997  1
332737  100.223  -71.547  47.956  1
332738  100.259  -71.560  47.913  1
332739  100.295  -71.572  47.870  1
332740  100.331  -71.585  47.827  1
332741  100.367  -71.597  47.785  1
332742  100.398  -71.607  47.744  1
332743  100.425  -71.615  47.704  1
332744  100.453  -71.623  47.664  1
332745  100.478  -71.634  47.624  1
332746  100.501  -71.649  47.584  1
332747  100.525  -71.663  47.545  1
332748  100.548  -71.679  47.507  1
332749  100.571  -71.694  47.469  1
332750  100.595  -71.709  47.430  1
332751  100.618  -71.724  47.391  1
332752  100.641  -71.739  47.352  1
332753  100.673  -71.766  47.314  1
332754  100.707  -71.780  47.277  1
332755  100.741  -71.785  47.242  1
332756  100.775  -71.789  47.206  1
332757  100.809  -71.794  47.171  1
332758  100.843  -71.798  47.138  1
332759  100.876  -71.803  47.107  1
332760  100.915  -71.807  47.075  1
332761  100.969  -71.815  47.042  1
332762  101.022  -71.823  47.009  1
332763  101.076  -71.829  46.977  1
332764  101.130  -71.837  46.947  1
332765  101.156  -71.850  46.919  1
332766  101.172  -71.864  46.887  1
332767  101.189  -71.879  46.853  1
332768  101.221  -71.886  46.819  1
332769  101.258  -71.892  46.785  1
332770  101.293  -71.898  46.748  1
332771  101.330  -71.904  46.711  1
332772  101.365  -71.913  46.673  1
332773  101.401  -71.925  46.635  1
332774  101.437  -71.938  46.599  1
332775  101.473  -71.950  46.561  1
332776  101.509  -71.962  46.523  1
332777  101.544  -71.975  46.485  1
332778  101.580  -71.987  46.447  1
332779  101.615  -72.000  46.407  1
332780  101.651  -72.012  46.368  1
332781  101.687  -72.024  46.329  1
332782  101.727  -72.040  46.289  1
332783  101.766  -72.058  46.250  1
332784  101.795  -72.078  46.212  1
332785  101.824  -72.099  46.175  1
332786  101.852  -72.118  46.138  1
332787  101.882  -72.139  46.102  1
332788  101.910  -72.158  46.065  1
332789  101.939  -72.179  46.029  1
332790  101.968  -72.198  45.992  1
332791  101.994  -72.215  45.956  1
332792  102.022  -72.230  45.919  1
332793  102.044  -72.241  45.881  1
332794  102.058  -72.236  45.843  1
332795  102.081  -72.240  45.803  1
332796  102.102  -72.242  45.765  1
332797  102.104  -72.234  45.726  1
332798  102.134  -72.236  45.689  1
332799  102.164  -72.237  45.653  1
332800  102.194  -72.239  45.617  1
332801  102.224  -72.240  45.582  1
332802  102.254  -72.242  45.548  1
332803  102.284  -72.243  45.514  1
332804  102.314  -72.245  45.481  1
332805  102.344  -72.246  45.449  1
332806  102.374  -72.248  45.416  1
332807  102.404  -72.249  45.384  1
332808  102.434  -72.251  45.352  1
332809  102.463  -72.252  45.321  1
332810  102.489  -72.252  45.289  1
333186  91.800  -70.602  55.285  3
333187  91.832  -70.613  55.275  3
333188  91.863  -70.623  55.264  3
333189  91.894  -70.633  55.254  3
333190  91.925  -70.644  55.244  3
333191  91.956  -70.654  55.235  3
333192  91.988  -70.665  55.227  3
333193  92.019  -70.676  55.220  3
333194  92.066  -70.698  55.211  3
333195  92.119  -70.725  55.205  3
333196  92.169  -70.701  55.201  3
333197  92.220  -70.676  55.200  3
333198  92.248  -70.695  55.204  3
333199  92.281  -70.707  55.201  3
333200  92.324  -70.707  55.192  3
333201  92.366  -70.706  55.176  3
333202  92.407  -70.705  55.156  3
333203  92.448  -70.704  55.131  3
333204  92.489  -70.704  55.104  3
333205  92.529  -70.703  55.076  3
333206  92.571  -70.701  55.048  3
333207  92.612  -70.701  55.021  3
333208  92.652  -70.700  54.994  3
333209  92.694  -70.699  54.965  3
333210  92.731  -70.692  54.930  3
333211  92.767  -70.682  54.894  3
333212  92.803  -70.671  54.857  3
333213  92.835  -70.659  54.818  3
333214  92.867  -70.647  54.778  3
333215  92.896  -70.639  54.736  3
333216  92.925  -70.632  54.693  3
333217  92.954  -70.624  54.651  3
333218  92.983  -70.616  54.609  3
333219  93.012  -70.609  54.565  3
333220  93.041  -70.601  54.522  3
333221  93.069  -70.594  54.479  3
333222  93.098  -70.586  54.436  3
333223  93.127  -70.579  54.395  3
333224  93.156  -70.571  54.357  3
333225  93.185  -70.563  54.320  3
333226  93.214  -70.555  54.285  3
333227  93.243  -70.547  54.252  3
333228  93.272  -70.540  54.220  3
333229  93.300  -70.532  54.189  3
333282  94.849  -70.163  52.813  1
333283  94.883  -70.164  52.807  1
333284  94.915  -70.165  52.800  1
333285  94.949  -70.165  52.793  1
333286  94.982  -70.166  52.787  1
333287  95.015  -70.167  52.782  1
333288  95.048  -70.168  52.777  1
333289  95.080  -70.168  52.772  1
333290  95.114  -70.169  52.768  1
333291  95.146  -70.170  52.764  1
333292  95.180  -70.171  52.761  1
333293  95.212  -70.171  52.760  1
333294  95.261  -70.157  52.759  1
333295  95.298  -70.159  52.757  1
333296  95.332  -70.173  52.754  1
333297  95.367  -70.187  52.750  1
333298  95.402  -70.201  52.746  1
333299  95.437  -70.215  52.740  1
333300  95.472  -70.228  52.729  1
333301  95.507  -70.242  52.715  1
333302  95.542  -70.256  52.698  1
333303  95.577  -70.269  52.680  1
333304  95.612  -70.284  52.663  1
333305  95.647  -70.297  52.641  1
333306  95.682  -70.311  52.617  1
333307  95.716  -70.325  52.594  1
333308  95.751  -70.338  52.571  1
333309  95.787  -70.352  52.550  1
333310  95.821  -70.366  52.529  1
333311  95.851  -70.378  52.510  1
333312  95.877  -70.387  52.490  1
333313  95.900  -70.394  52.471  1
333314  95.923  -70.403  52.452  1
333315  95.947  -70.411  52.433  1
333316  95.970  -70.419  52.414  1
333317  95.993  -70.427  52.394  1
333318  96.016  -70.435  52.374  1
333319  96.039  -70.444  52.356  1
333320  96.062  -70.452  52.339  1
333321  96.086  -70.460  52.323  1
333322  96.109  -70.468  52.308  1
333323  96.132  -70.476  52.294  1
333324  96.155  -70.485  52.279  1
333325  96.180  -70.493  52.264  1
333326  96.216  -70.505  52.248  1
333327  96.252  -70.518  52.231  1
333328  96.288  -70.531  52.215  1
333329  96.327  -70.544  52.201  1
333330  96.368  -70.557  52.188  1
333331  96.407  -70.571  52.172  1
333332  96.446  -70.582  52.154  1
333333  96.481  -70.584  52.135  1
333334  96.517  -70.586  52.117  1
333335  96.560  -70.595  52.100  1
333336  96.609  -70.610  52.083  1
333337  96.658  -70.625  52.068  1
333338  96.708  -70.640  52.052  1
333339  96.757  -70.654  52.041  1
333340  96.806  -70.670  52.033  1
333341  96.853  -70.681  52.027  1
333342  96.897  -70.690  52.024  1
333343  96.942  -70.699  52.022  1
333344  96.986  -70.708  52.019  1
333345  97.030  -70.717  52.013  1
333346  97.075  -70.726  52.008  1
333347  97.119  -70.735  52.005  1
333348  97.163  -70.744  52.001  1
333349  97.208  -70.753  51.993  1
333350  97.250  -70.761  51.983  1
333351  97.265  -70.765  51.963  1
333352  97.279  -70.766  51.936  1
333353  97.293  -70.767  51.906  1
333354  97.314  -70.775  51.876  1
333355  97.336  -70.784  51.848  1
333356  97.359  -70.793  51.825  1
333357  97.381  -70.801  51.804  1
333358  97.410  -70.807  51.784  1
333359  97.442  -70.811  51.765  1
333360  97.474  -70.815  51.742  1
333361  97.504  -70.826  51.717  1
333362  97.533  -70.839  51.689  1
333363  97.563  -70.852  51.656  1
333364  97.592  -70.864  51.616  1
333365  97.621  -70.877  51.577  1
333366  97.651  -70.890  51.538  1
333367  97.683  -70.901  51.499  1
333368  97.716  -70.911  51.462  1
333369  97.749  -70.921  51.424  1
333370  97.783  -70.931  51.384  1
333371  97.815  -70.941  51.341  1
333372  97.848  -70.946  51.300  1
333373  97.878  -70.939  51.264  1
333374  97.909  -70.932  51.229  1
333375  97.939  -70.925  51.193  1
333376  97.971  -70.920  51.155  1
333377  98.005  -70.916  51.112  1
333378  98.041  -70.923  51.063  1
333379  98.077  -70.930  51.012  1
333380  98.113  -70.936  50.959  1
333381  98.150  -70.943  50.904  1
333382  98.185  -70.950  50.848  1
333383  98.222  -70.957  50.790  1
333384  98.258  -70.964  50.731  1
333385  98.294  -70.970  50.672  1
333386  98.331  -70.977  50.616  1
333387  98.367  -70.984  50.563  1
333388  98.403  -70.991  50.512  1
333389  98.439  -70.998  50.461  1
333390  98.475  -71.005  50.404  1
333391  98.511  -71.011  50.347  1
333392  98.548  -71.018  50.287  1
333393  98.587  -71.021  50.226  1
333394  98.627  -71.024  50.160  1
333395  98.667  -71.027  50.094  1
333396  98.707  -71.030  50.027  1
333397  98.746  -71.033  49.962  1
333398  98.786  -71.036  49.897  1
333399  98.825  -71.040  49.833  1
333400  98.854  -71.051  49.769  1
333401  98.884  -71.062  49.707  1
333402  98.914  -71.074  49.646  1
333403  98.944  -71.085  49.585  1
333404  98.974  -71.096  49.524  1
333405  99.004  -71.107  49.465  1
333406  99.034  -71.118  49.406  1
333407  99.064  -71.130  49.349  1
333408  99.096  -71.144  49.294  1
333409  99.129  -71.158  49.240  1
333410  99.161  -71.171  49.189  1
333411  99.193  -71.186  49.138  1
333412  99.225  -71.199  49.086  1
333413  99.258  -71.214  49.034  1
333414  99.290  -71.227  48.982  1
333415  99.317  -71.244  48.930  1
333416  99.355  -71.256  48.881  1
333417  99.401  -71.265  48.833  1
333418  99.446  -71.274  48.786  1
333419  99.491  -71.282  48.738  1
333420  99.535  -71.290  48.691  1
333421  99.575  -71.297  48.647  1
333422  99.615  -71.304  48.603  1
333423  99.656  -71.312  48.561  1
333424  99.696  -71.318  48.519  1
333425  99.738  -71.329  48.478  1
333426  99.784  -71.346  48.437  1
333427  99.823  -71.362  48.397  1
333428  99.862  -71.377  48.358  1
333429  99.901  -71.392  48.322  1
333430  99.939  -71.407  48.285  1
333431  99.978  -71.422  48.247  1
333432  100.016  -71.437  48.208  1
333433  100.053  -71.450  48.170  1
333434  100.088  -71.462  48.130  1
333435  100.125  -71.475  48.090  1
333436  100.161  -71.487  48.052  1
333437  100.197  -71.499  48.011  1
333438  100.233  -71.511  47.968  1
333439  100.269  -71.523  47.924  1
333440  100.305  -71.536  47.880  1
333441  100.341  -71.548  47.835  1
333442  100.377  -71.560  47.793  1
333443  100.409  -71.571  47.752  1
333444  100.437  -71.579  47.712  1
333445  100.464  -71.588  47.671  1
333446  100.488  -71.602  47.631  1
333447  100.511  -71.617  47.590  1
333448  100.534  -71.632  47.550  1
333449  100.557  -71.647  47.511  1
333450  100.580  -71.662  47.472  1
333451  100.604  -71.677  47.434  1
333452  100.627  -71.692  47.396  1
333453  100.650  -71.707  47.357  1
333454  100.681  -71.732  47.320  1
333455  100.715  -71.744  47.284  1
333456  100.749  -71.748  47.249  1
333457  100.783  -71.753  47.213  1
333458  100.817  -71.757  47.178  1
333459  100.850  -71.762  47.145  1
333460  100.897  -71.768  47.112  1
333461  100.950  -71.776  47.078  1
333462  101.004  -71.782  47.045  1
333463  101.057  -71.790  47.014  1
333464  101.111  -71.798  46.983  1
333465  101.151  -71.807  46.954  1
333466  101.168  -71.822  46.924  1
333467  101.184  -71.836  46.893  1
333468  101.201  -71.851  46.860  1
333469  101.236  -71.857  46.827  1
333470  101.272  -71.864  46.792  1
333471  101.308  -71.870  46.756  1
333472  101.344  -71.876  46.719  1
333473  101.380  -71.882  46.682  1
333474  101.416  -71.892  46.646  1
333475  101.452  -71.904  46.610  1
333476  101.487  -71.917  46.573  1
333477  101.523  -71.929  46.535  1
333478  101.559  -71.942  46.497  1
333479  101.595  -71.954  46.459  1
333480  101.630  -71.967  46.419  1
333481  101.666  -71.979  46.379  1
333482  101.702  -71.992  46.340  1
333483  101.744  -72.009  46.300  1
333484  101.784  -72.026  46.261  1
333485  101.814  -72.047  46.223  1
333486  101.842  -72.067  46.185  1
333487  101.871  -72.087  46.148  1
333488  101.900  -72.107  46.111  1
333489  101.929  -72.127  46.074  1
333490  101.958  -72.147  46.036  1
333491  101.986  -72.168  45.999  1
333492  102.016  -72.187  45.961  1
333493  102.043  -72.205  45.924  1
333494  102.050  -72.188  45.886  1
333495  102.073  -72.191  45.847  1
333496  102.088  -72.190  45.808  1
333497  102.090  -72.183  45.769  1
333498  102.118  -72.183  45.731  1
333499  102.148  -72.185  45.695  1
333500  102.178  -72.186  45.660  1
333501  102.208  -72.188  45.625  1
333502  102.238  -72.189  45.591  1
333503  102.268  -72.191  45.557  1
333504  102.298  -72.193  45.524  1
333505  102.328  -72.195  45.492  1
333506  102.358  -72.196  45.459  1
333507  102.388  -72.198  45.427  1
333508  102.418  -72.199  45.394  1
333509  102.448  -72.201  45.363  1
333510  102.478  -72.202  45.332  1
333511  102.508  -72.204  45.300  1
333888  91.819  -70.580  55.272  3
333889  91.851  -70.591  55.261  3
333890  91.882  -70.601  55.251  3
333891  91.913  -70.612  55.242  3
333892  91.944  -70.623  55.233  3
333893  91.976  -70.632  55.226  3
333894  92.007  -70.643  55.218  3
333895  92.060  -70.669  55.211  3
333896  92.111  -70.695  55.205  3
333897  92.162  -70.671  55.200  3
333898  92.213  -70.647  55.199  3
333899  92.249  -70.651  55.203  3
333900  92.278  -70.666  55.202  3
333901  92.315  -70.664  55.194  3
333902  92.359  -70.663  55.180  3
333903  92.402  -70.663  55.162  3
333904  92.446  -70.663  55.138  3
333905  92.490  -70.663  55.111  3
333906  92.533  -70.663  55.083  3
333907  92.577  -70.662  55.056  3
333908  92.618  -70.661  55.029  3
333909  92.659  -70.660  55.001  3
333910  92.700  -70.659  54.971  3
333911  92.741  -70.658  54.938  3
333912  92.777  -70.648  54.904  3
333913  92.806  -70.635  54.868  3
333914  92.834  -70.621  54.830  3
333915  92.873  -70.604  54.792  3
333916  92.904  -70.594  54.751  3
333917  92.932  -70.586  54.709  3
333918  92.961  -70.579  54.667  3
333919  92.990  -70.571  54.625  3
333920  93.019  -70.563  54.580  3
333921  93.048  -70.556  54.536  3
333922  93.077  -70.548  54.493  3
333923  93.106  -70.541  54.449  3
333924  93.135  -70.532  54.407  3
333925  93.163  -70.525  54.366  3
333926  93.193  -70.517  54.328  3
333927  93.221  -70.510  54.292  3
333928  93.250  -70.502  54.256  3
333929  93.279  -70.494  54.222  3
333930  93.308  -70.487  54.190  3
333931  93.337  -70.479  54.159  3
333982  94.837  -70.143  52.824  1
333983  94.870  -70.144  52.817  1
333984  94.903  -70.145  52.811  1
333985  94.936  -70.146  52.804  1
333986  94.969  -70.146  52.799  1
333987  95.002  -70.146  52.794  1
333988  95.035  -70.147  52.790  1
333989  95.068  -70.148  52.786  1
333990  95.101  -70.149  52.783  1
333991  95.134  -70.149  52.779  1
333992  95.167  -70.150  52.777  1
333993  95.200  -70.151  52.775  1
333994  95.237  -70.148  52.773  1
333995  95.287  -70.131  52.772  1
333996  95.324  -70.136  52.770  1
333997  95.359  -70.149  52.768  1
333998  95.394  -70.163  52.765  1
333999  95.429  -70.178  52.762  1
334000  95.464  -70.191  52.758  1
334001  95.499  -70.205  52.747  1
334002  95.534  -70.218  52.733  1
334003  95.569  -70.232  52.715  1
334004  95.604  -70.246  52.696  1
334005  95.638  -70.259  52.676  1
334006  95.674  -70.274  52.653  1
334007  95.705  -70.285  52.630  1
334008  95.737  -70.297  52.606  1
334009  95.768  -70.309  52.584  1
334010  95.800  -70.321  52.563  1
334011  95.831  -70.333  52.542  1
334012  95.853  -70.347  52.523  1
334013  95.879  -70.356  52.505  1
334014  95.908  -70.364  52.486  1
334015  95.936  -70.372  52.467  1
334016  95.959  -70.380  52.448  1
334017  95.982  -70.388  52.428  1
334018  96.005  -70.396  52.407  1
334019  96.028  -70.404  52.386  1
334020  96.051  -70.413  52.367  1
334021  96.075  -70.420  52.350  1
334022  96.098  -70.428  52.333  1
334023  96.121  -70.437  52.319  1
334024  96.144  -70.445  52.303  1
334025  96.167  -70.453  52.287  1
334026  96.193  -70.462  52.271  1
334027  96.229  -70.475  52.255  1
334028  96.265  -70.487  52.239  1
334029  96.301  -70.500  52.223  1
334030  96.337  -70.513  52.210  1
334031  96.375  -70.525  52.199  1
334032  96.415  -70.538  52.185  1
334033  96.454  -70.548  52.168  1
334034  96.489  -70.550  52.150  1
334035  96.524  -70.553  52.131  1
334036  96.559  -70.555  52.112  1
334037  96.606  -70.567  52.095  1
334038  96.655  -70.582  52.080  1
334039  96.704  -70.597  52.065  1
334040  96.756  -70.613  52.056  1
334041  96.811  -70.630  52.049  1
334042  96.859  -70.642  52.044  1
334043  96.901  -70.651  52.044  1
334044  96.945  -70.660  52.045  1
334045  96.990  -70.669  52.043  1
334046  97.034  -70.678  52.037  1
334047  97.078  -70.687  52.030  1
334048  97.122  -70.696  52.023  1
334049  97.167  -70.705  52.014  1
334050  97.209  -70.713  52.004  1
334051  97.248  -70.722  51.991  1
334052  97.266  -70.730  51.969  1
334053  97.282  -70.734  51.943  1
334054  97.297  -70.737  51.914  1
334055  97.320  -70.746  51.883  1
334056  97.342  -70.754  51.854  1
334057  97.365  -70.764  51.832  1
334058  97.387  -70.773  51.812  1
334059  97.409  -70.782  51.791  1
334060  97.441  -70.786  51.771  1
334061  97.473  -70.790  51.747  1
334062  97.505  -70.794  51.720  1
334063  97.536  -70.801  51.689  1
334064  97.566  -70.814  51.656  1
334065  97.595  -70.826  51.616  1
334066  97.625  -70.839  51.577  1
334067  97.655  -70.851  51.539  1
334068  97.688  -70.861  51.503  1
334069  97.721  -70.871  51.465  1
334070  97.754  -70.881  51.427  1
334071  97.787  -70.892  51.385  1
334072  97.820  -70.901  51.343  1
334073  97.853  -70.908  51.305  1
334074  97.883  -70.901  51.269  1
334075  97.913  -70.894  51.232  1
334076  97.945  -70.888  51.194  1
334077  97.979  -70.883  51.154  1
334078  98.012  -70.878  51.108  1
334079  98.046  -70.877  51.058  1
334080  98.083  -70.884  51.006  1
334081  98.119  -70.891  50.953  1
334082  98.155  -70.898  50.899  1
334083  98.191  -70.905  50.844  1
334084  98.227  -70.911  50.788  1
334085  98.264  -70.918  50.730  1
334086  98.300  -70.925  50.673  1
334087  98.336  -70.932  50.618  1
334088  98.372  -70.939  50.565  1
334089  98.408  -70.945  50.513  1
334090  98.444  -70.952  50.460  1
334091  98.481  -70.959  50.402  1
334092  98.517  -70.966  50.343  1
334093  98.554  -70.971  50.284  1
334094  98.594  -70.974  50.221  1
334095  98.634  -70.977  50.157  1
334096  98.673  -70.980  50.092  1
334097  98.714  -70.983  50.026  1
334098  98.754  -70.986  49.961  1
334099  98.793  -70.989  49.894  1
334100  98.833  -70.992  49.829  1
334101  98.864  -71.002  49.766  1
334102  98.894  -71.013  49.704  1
334103  98.923  -71.024  49.643  1
334104  98.953  -71.036  49.582  1
334105  98.983  -71.047  49.522  1
334106  99.013  -71.058  49.463  1
334107  99.044  -71.070  49.405  1
334108  99.076  -71.083  49.348  1
334109  99.108  -71.098  49.293  1
334110  99.140  -71.111  49.240  1
334111  99.173  -71.125  49.189  1
334112  99.205  -71.140  49.139  1
334113  99.237  -71.153  49.087  1
334114  99.270  -71.168  49.036  1
334115  99.302  -71.181  48.984  1
334116  99.334  -71.196  48.933  1
334117  99.368  -71.209  48.884  1
334118  99.410  -71.216  48.836  1
334119  99.450  -71.223  48.790  1
334120  99.491  -71.231  48.744  1
334121  99.531  -71.237  48.698  1
334122  99.572  -71.245  48.654  1
334123  99.612  -71.252  48.611  1
334124  99.652  -71.259  48.570  1
334125  99.693  -71.266  48.528  1
334126  99.739  -71.282  48.487  1
334127  99.786  -71.300  48.446  1
334128  99.825  -71.315  48.407  1
334129  99.863  -71.331  48.368  1
334130  99.902  -71.346  48.332  1
334131  99.940  -71.361  48.297  1
334132  99.979  -71.376  48.259  1
334133  100.018  -71.391  48.221  1
334134  100.057  -71.406  48.182  1
334135  100.095  -71.422  48.141  1
334136  100.134  -71.437  48.100  1
334137  100.171  -71.450  48.061  1
334138  100.207  -71.462  48.018  1
334139  100.243  -71.475  47.975  1
334140  100.279  -71.487  47.932  1
334141  100.315  -71.500  47.888  1
334142  100.351  -71.512  47.844  1
334143  100.387  -71.524  47.801  1
334144  100.421  -71.535  47.759  1
334145  100.449  -71.544  47.718  1
334146  100.474  -71.555  47.678  1
334147  100.497  -71.570  47.637  1
334148  100.521  -71.585  47.596  1
334149  100.544  -71.600  47.556  1
334150  100.567  -71.615  47.517  1
334151  100.590  -71.630  47.479  1
334152  100.613  -71.645  47.441  1
334153  100.636  -71.660  47.404  1
334154  100.660  -71.675  47.366  1
334155  100.689  -71.697  47.329  1
334156  100.723  -71.707  47.293  1
334157  100.757  -71.712  47.257  1
334158  100.790  -71.716  47.222  1
334159  100.824  -71.721  47.187  1
334160  100.878  -71.729  47.152  1
334161  100.931  -71.735  47.118  1
334162  100.985  -71.743  47.084  1
334163  101.039  -71.750  47.051  1
334164  101.093  -71.757  47.020  1
334165  101.146  -71.765  46.989  1
334166  101.164  -71.779  46.958  1
334167  101.180  -71.794  46.928  1
334168  101.196  -71.809  46.896  1
334169  101.214  -71.823  46.864  1
334170  101.251  -71.829  46.831  1
334171  101.286  -71.835  46.796  1
334172  101.323  -71.841  46.761  1
334173  101.358  -71.847  46.724  1
334174  101.395  -71.852  46.689  1
334175  101.431  -71.859  46.655  1
334176  101.466  -71.871  46.619  1
334177  101.502  -71.884  46.584  1
334178  101.538  -71.896  46.547  1
334179  101.573  -71.908  46.509  1
334180  101.609  -71.921  46.471  1
334181  101.645  -71.933  46.431  1
334182  101.680  -71.946  46.391  1
334183  101.719  -71.961  46.351  1
334184  101.761  -71.978  46.312  1
334185  101.803  -71.995  46.272  1
334186  101.832  -72.015  46.233  1
334187  101.861  -72.036  46.195  1
334188  101.890  -72.055  46.157  1
334189  101.918  -72.076  46.119  1
334190  101.948  -72.095  46.081  1
334191  101.976  -72.116  46.042  1
334192  102.005  -72.136  46.004  1
334193  102.033  -72.155  45.963  1
334194  102.042  -72.139  45.925  1
334195  102.065  -72.143  45.887  1
334196  102.074  -72.139  45.847  1
334197  102.076  -72.131  45.810  1
334198  102.102  -72.131  45.773  1
334199  102.132  -72.133  45.737  1
334200  102.162  -72.135  45.702  1
334201  102.192  -72.136  45.667  1
334202  102.222  -72.138  45.633  1
334203  102.252  -72.139  45.600  1
334204  102.282  -72.141  45.566  1
334205  102.312  -72.142  45.533  1
334206  102.342  -72.144  45.501  1
334207  102.372  -72.146  45.469  1
334208  102.402  -72.147  45.436  1
334209  102.432  -72.149  45.404  1
334210  102.462  -72.150  45.372  1
334211  102.492  -72.152  45.340  1
334212  102.522  -72.153  45.309  1
334589  91.808  -70.547  55.268  3
334590  91.839  -70.558  55.258  3
334591  91.870  -70.569  55.248  3
334592  91.901  -70.579  55.240  3
334593  91.932  -70.590  55.232  3
334594  91.963  -70.601  55.224  3
334595  91.996  -70.612  55.217  3
334596  92.054  -70.641  55.210  3
334597  92.104  -70.666  55.204  3
334598  92.155  -70.641  55.199  3
334599  92.206  -70.617  55.196  3
334600  92.249  -70.607  55.198  3
334601  92.277  -70.627  55.198  3
334602  92.314  -70.624  55.192  3
334603  92.351  -70.622  55.180  3
334604  92.392  -70.620  55.161  3
334605  92.436  -70.620  55.139  3
334606  92.480  -70.619  55.114  3
334607  92.523  -70.619  55.087  3
334608  92.567  -70.619  55.063  3
334609  92.611  -70.619  55.036  3
334610  92.655  -70.618  55.007  3
334611  92.699  -70.618  54.977  3
334612  92.742  -70.617  54.945  3
334613  92.778  -70.610  54.913  3
334614  92.805  -70.597  54.879  3
334615  92.833  -70.584  54.843  3
334616  92.872  -70.571  54.807  3
334617  92.911  -70.548  54.769  3
334618  92.940  -70.541  54.727  3
334619  92.969  -70.533  54.685  3
334620  92.998  -70.525  54.642  3
334621  93.026  -70.518  54.597  3
334622  93.056  -70.510  54.552  3
334623  93.084  -70.502  54.506  3
334624  93.114  -70.494  54.461  3
334625  93.142  -70.487  54.418  3
334626  93.171  -70.479  54.376  3
334627  93.200  -70.472  54.336  3
334628  93.229  -70.464  54.299  3
334629  93.258  -70.456  54.262  3
334630  93.287  -70.449  54.227  3
334631  93.315  -70.441  54.193  3
334632  93.344  -70.434  54.161  3
334682  94.824  -70.123  52.832  1
334683  94.857  -70.124  52.826  1
334684  94.890  -70.124  52.819  1
334685  94.923  -70.125  52.813  1
334686  94.956  -70.126  52.808  1
334687  94.989  -70.127  52.804  1
334688  95.022  -70.127  52.800  1
334689  95.055  -70.128  52.798  1
334690  95.088  -70.129  52.796  1
334691  95.121  -70.129  52.794  1
334692  95.154  -70.130  52.791  1
334693  95.187  -70.130  52.790  1
334694  95.220  -70.131  52.788  1
334695  95.263  -70.123  52.787  1
334696  95.314  -70.106  52.786  1
334697  95.351  -70.112  52.783  1
334698  95.386  -70.126  52.780  1
334699  95.421  -70.140  52.778  1
334700  95.456  -70.153  52.776  1
334701  95.491  -70.168  52.775  1
334702  95.526  -70.181  52.765  1
334703  95.558  -70.193  52.751  1
334704  95.590  -70.206  52.733  1
334705  95.621  -70.217  52.712  1
334706  95.653  -70.229  52.690  1
334707  95.684  -70.241  52.666  1
334708  95.716  -70.253  52.642  1
334709  95.747  -70.265  52.619  1
334710  95.779  -70.277  52.596  1
334711  95.810  -70.288  52.576  1
334712  95.834  -70.303  52.556  1
334713  95.854  -70.317  52.537  1
334714  95.880  -70.327  52.521  1
334715  95.908  -70.334  52.502  1
334716  95.937  -70.342  52.483  1
334717  95.965  -70.349  52.463  1
334718  95.993  -70.356  52.443  1
334719  96.018  -70.365  52.421  1
334720  96.041  -70.373  52.399  1
334721  96.064  -70.381  52.378  1
334722  96.087  -70.389  52.360  1
334723  96.110  -70.397  52.345  1
334724  96.133  -70.406  52.329  1
334725  96.157  -70.413  52.312  1
334726  96.180  -70.422  52.295  1
334727  96.206  -70.431  52.278  1
334728  96.242  -70.444  52.263  1
334729  96.278  -70.456  52.247  1
334730  96.315  -70.469  52.232  1
334731  96.350  -70.481  52.221  1
334732  96.387  -70.494  52.211  1
334733  96.424  -70.507  52.198  1
334734  96.461  -70.516  52.182  1
334735  96.497  -70.517  52.164  1
334736  96.532  -70.519  52.146  1
334737  96.567  -70.522  52.127  1
334738  96.603  -70.525  52.110  1
334739  96.654  -70.541  52.095  1
334740  96.709  -70.557  52.082  1
334741  96.763  -70.575  52.072  1
334742  96.818  -70.592  52.067  1
334743  96.867  -70.605  52.066  1
334744  96.906  -70.613  52.068  1
334745  96.949  -70.621  52.071  1
334746  96.993  -70.630  52.069  1
334747  97.037  -70.639  52.063  1
334748  97.082  -70.648  52.052  1
334749  97.126  -70.657  52.041  1
334750  97.167  -70.666  52.027  1
334751  97.207  -70.673  52.013  1
334752  97.245  -70.682  51.997  1
334753  97.264  -70.691  51.973  1
334754  97.283  -70.699  51.946  1
334755  97.303  -70.707  51.918  1
334756  97.326  -70.717  51.887  1
334757  97.349  -70.726  51.860  1
334758  97.371  -70.735  51.838  1
334759  97.393  -70.744  51.817  1
334760  97.416  -70.753  51.795  1
334761  97.440  -70.760  51.773  1
334762  97.472  -70.764  51.748  1
334763  97.504  -70.768  51.720  1
334764  97.536  -70.773  51.688  1
334765  97.568  -70.776  51.654  1
334766  97.598  -70.789  51.616  1
334767  97.628  -70.801  51.577  1
334768  97.660  -70.811  51.539  1
334769  97.693  -70.822  51.502  1
334770  97.726  -70.832  51.463  1
334771  97.759  -70.842  51.424  1
334772  97.792  -70.852  51.383  1
334773  97.825  -70.862  51.343  1
334774  97.858  -70.870  51.308  1
334775  97.888  -70.863  51.271  1
334776  97.920  -70.857  51.233  1
334777  97.953  -70.851  51.192  1
334778  97.986  -70.847  51.150  1
334779  98.019  -70.842  51.101  1
334780  98.053  -70.837  51.050  1
334781  98.088  -70.839  50.998  1
334782  98.124  -70.845  50.946  1
334783  98.160  -70.852  50.893  1
334784  98.197  -70.859  50.839  1
334785  98.232  -70.866  50.784  1
334786  98.269  -70.873  50.727  1
334787  98.305  -70.880  50.671  1
334788  98.341  -70.887  50.617  1
334789  98.377  -70.894  50.563  1
334790  98.414  -70.901  50.509  1
334791  98.449  -70.908  50.454  1
334792  98.486  -70.914  50.394  1
334793  98.522  -70.921  50.335  1
334794  98.561  -70.924  50.275  1
334795  98.601  -70.927  50.214  1
334796  98.641  -70.930  50.151  1
334797  98.680  -70.933  50.087  1
334798  98.720  -70.936  50.023  1
334799  98.760  -70.939  49.957  1
334800  98.800  -70.942  49.891  1
334801  98.840  -70.944  49.826  1
334802  98.873  -70.953  49.762  1
334803  98.903  -70.964  49.700  1
334804  98.933  -70.975  49.638  1
334805  98.962  -70.986  49.578  1
334806  98.993  -70.998  49.519  1
334807  99.023  -71.009  49.460  1
334808  99.055  -71.024  49.402  1
334809  99.088  -71.037  49.347  1
334810  99.120  -71.052  49.293  1
334811  99.152  -71.065  49.240  1
334812  99.185  -71.080  49.190  1
334813  99.217  -71.093  49.139  1
334814  99.249  -71.107  49.088  1
334815  99.281  -71.121  49.037  1
334816  99.313  -71.137  48.986  1
334817  99.345  -71.154  48.936  1
334818  99.377  -71.169  48.887  1
334819  99.413  -71.173  48.840  1
334820  99.452  -71.179  48.794  1
334821  99.492  -71.186  48.749  1
334822  99.532  -71.192  48.705  1
334823  99.572  -71.199  48.661  1
334824  99.613  -71.205  48.619  1
334825  99.653  -71.212  48.578  1
334826  99.693  -71.218  48.538  1
334827  99.739  -71.235  48.497  1
334828  99.786  -71.253  48.457  1
334829  99.826  -71.268  48.418  1
334830  99.864  -71.284  48.379  1
334831  99.903  -71.299  48.343  1
334832  99.941  -71.314  48.307  1
334833  99.980  -71.330  48.269  1
334834  100.019  -71.345  48.230  1
334835  100.058  -71.360  48.191  1
334836  100.097  -71.375  48.150  1
334837  100.135  -71.390  48.108  1
334838  100.174  -71.406  48.069  1
334839  100.212  -71.421  48.026  1
334840  100.251  -71.436  47.983  1
334841  100.289  -71.450  47.939  1
334842  100.325  -71.462  47.896  1
334843  100.361  -71.475  47.852  1
334844  100.398  -71.487  47.810  1
334845  100.433  -71.500  47.767  1
334846  100.460  -71.508  47.725  1
334847  100.483  -71.523  47.685  1
334848  100.506  -71.538  47.644  1
334849  100.530  -71.553  47.603  1
334850  100.553  -71.569  47.563  1
334851  100.576  -71.583  47.525  1
334852  100.600  -71.598  47.488  1
334853  100.623  -71.613  47.450  1
334854  100.646  -71.629  47.413  1
334855  100.669  -71.644  47.376  1
334856  100.696  -71.664  47.339  1
334857  100.731  -71.671  47.302  1
334858  100.764  -71.675  47.267  1
334859  100.805  -71.681  47.231  1
334860  100.859  -71.688  47.196  1
334861  100.913  -71.696  47.162  1
334862  100.967  -71.703  47.127  1
334863  101.020  -71.710  47.092  1
334864  101.074  -71.718  47.059  1
334865  101.128  -71.725  47.027  1
334866  101.159  -71.737  46.994  1
334867  101.176  -71.751  46.961  1
334868  101.192  -71.766  46.929  1
334869  101.208  -71.781  46.896  1
334870  101.229  -71.794  46.863  1
334871  101.265  -71.800  46.830  1
334872  101.301  -71.806  46.796  1
334873  101.337  -71.812  46.761  1
334874  101.373  -71.817  46.726  1
334875  101.409  -71.823  46.692  1
334876  101.445  -71.829  46.660  1
334877  101.481  -71.838  46.626  1
334878  101.516  -71.851  46.593  1
334879  101.552  -71.863  46.558  1
334880  101.588  -71.876  46.520  1
334881  101.624  -71.888  46.482  1
334882  101.659  -71.901  46.442  1
334883  101.695  -71.913  46.402  1
334884  101.736  -71.929  46.363  1
334885  101.778  -71.947  46.322  1
334886  101.820  -71.964  46.282  1
334887  101.850  -71.984  46.241  1
334888  101.880  -72.004  46.201  1
334889  101.908  -72.024  46.163  1
334890  101.937  -72.044  46.123  1
334891  101.966  -72.064  46.083  1
334892  101.995  -72.084  46.043  1
334893  102.024  -72.105  46.003  1
334894  102.034  -72.091  45.964  1
334895  102.057  -72.095  45.927  1
334896  102.060  -72.087  45.889  1
334897  102.062  -72.080  45.851  1
334898  102.086  -72.080  45.815  1
334899  102.116  -72.081  45.779  1
334900  102.146  -72.083  45.744  1
334901  102.176  -72.084  45.710  1
334902  102.206  -72.086  45.676  1
334903  102.236  -72.087  45.642  1
334904  102.266  -72.089  45.608  1
334905  102.296  -72.090  45.575  1
334906  102.326  -72.092  45.543  1
334907  102.356  -72.093  45.510  1
334908  102.386  -72.095  45.478  1
334909  102.416  -72.096  45.446  1
334910  102.446  -72.098  45.413  1
334911  102.476  -72.100  45.381  1
334912  102.506  -72.102  45.350  1
335291  91.827  -70.526  55.254  3
335292  91.858  -70.537  55.245  3
335293  91.889  -70.547  55.237  3
335294  91.920  -70.557  55.229  3
335295  91.951  -70.568  55.221  3
335296  91.989  -70.583  55.214  3
335297  92.047  -70.616  55.207  3
335298  92.097  -70.636  55.201  3
335299  92.148  -70.612  55.196  3
335300  92.199  -70.588  55.192  3
335301  92.250  -70.563  55.192  3
335302  92.276  -70.587  55.191  3
335303  92.313  -70.584  55.187  3
335304  92.350  -70.582  55.176  3
335305  92.387  -70.579  55.158  3
335306  92.426  -70.577  55.136  3
335307  92.470  -70.576  55.112  3
335308  92.513  -70.576  55.089  3
335309  92.557  -70.576  55.065  3
335310  92.601  -70.576  55.038  3
335311  92.645  -70.575  55.011  3
335312  92.689  -70.575  54.982  3
335313  92.732  -70.575  54.954  3
335314  92.777  -70.573  54.923  3
335315  92.804  -70.560  54.891  3
335316  92.832  -70.546  54.859  3
335317  92.865  -70.533  54.825  3
335318  92.914  -70.515  54.788  3
335319  92.947  -70.495  54.748  3
335320  92.977  -70.488  54.705  3
335321  93.005  -70.480  54.662  3
335322  93.034  -70.472  54.615  3
335323  93.063  -70.464  54.567  3
335324  93.092  -70.456  54.520  3
335325  93.121  -70.449  54.474  3
335326  93.150  -70.441  54.429  3
335327  93.179  -70.434  54.386  3
335328  93.208  -70.426  54.345  3
335329  93.236  -70.419  54.306  3
335330  93.265  -70.411  54.268  3
335331  93.294  -70.403  54.231  3
335332  93.323  -70.396  54.196  3
335333  93.352  -70.388  54.163  3
335383  94.845  -70.103  52.832  1
335384  94.878  -70.104  52.827  1
335385  94.911  -70.105  52.822  1
335386  94.944  -70.105  52.816  1
335387  94.977  -70.106  52.812  1
335388  95.010  -70.107  52.808  1
335389  95.043  -70.108  52.806  1
335390  95.075  -70.109  52.806  1
335391  95.109  -70.109  52.805  1
335392  95.141  -70.110  52.804  1
335393  95.175  -70.111  52.802  1
335394  95.207  -70.112  52.801  1
335395  95.241  -70.112  52.800  1
335396  95.290  -70.097  52.799  1
335397  95.341  -70.080  52.797  1
335398  95.378  -70.089  52.794  1
335399  95.411  -70.102  52.791  1
335400  95.443  -70.113  52.789  1
335401  95.474  -70.125  52.789  1
335402  95.506  -70.137  52.789  1
335403  95.537  -70.149  52.783  1
335404  95.568  -70.161  52.769  1
335405  95.600  -70.173  52.751  1
335406  95.632  -70.184  52.730  1
335407  95.663  -70.196  52.704  1
335408  95.695  -70.209  52.680  1
335409  95.726  -70.220  52.655  1
335410  95.758  -70.232  52.631  1
335411  95.790  -70.244  52.609  1
335412  95.815  -70.258  52.589  1
335413  95.835  -70.272  52.569  1
335414  95.855  -70.287  52.552  1
335415  95.881  -70.297  52.536  1
335416  95.909  -70.305  52.518  1
335417  95.938  -70.312  52.499  1
335418  95.966  -70.319  52.480  1
335419  95.994  -70.327  52.461  1
335420  96.022  -70.334  52.436  1
335421  96.051  -70.342  52.412  1
335422  96.076  -70.350  52.391  1
335423  96.099  -70.358  52.371  1
335424  96.122  -70.366  52.356  1
335425  96.146  -70.374  52.338  1
335426  96.169  -70.382  52.321  1
335427  96.192  -70.391  52.304  1
335428  96.220  -70.400  52.286  1
335429  96.256  -70.413  52.271  1
335430  96.292  -70.425  52.255  1
335431  96.328  -70.438  52.241  1
335432  96.364  -70.450  52.231  1
335433  96.400  -70.463  52.223  1
335434  96.436  -70.474  52.211  1
335435  96.471  -70.481  52.196  1
335436  96.507  -70.483  52.179  1
335437  96.542  -70.485  52.160  1
335438  96.578  -70.487  52.143  1
335439  96.616  -70.492  52.126  1
335440  96.661  -70.503  52.111  1
335441  96.716  -70.519  52.099  1
335442  96.770  -70.536  52.090  1
335443  96.825  -70.554  52.087  1
335444  96.875  -70.567  52.089  1
335445  96.914  -70.576  52.093  1
335446  96.954  -70.583  52.096  1
335447  96.997  -70.591  52.094  1
335448  97.041  -70.601  52.087  1
335449  97.085  -70.610  52.074  1
335450  97.126  -70.618  52.058  1
335451  97.166  -70.626  52.041  1
335452  97.206  -70.634  52.023  1
335453  97.243  -70.642  52.002  1
335454  97.262  -70.651  51.976  1
335455  97.283  -70.662  51.949  1
335456  97.307  -70.681  51.920  1
335457  97.328  -70.691  51.891  1
335458  97.352  -70.700  51.865  1
335459  97.375  -70.707  51.844  1
335460  97.398  -70.716  51.822  1
335461  97.421  -70.724  51.799  1
335462  97.444  -70.732  51.775  1
335463  97.471  -70.739  51.748  1
335464  97.503  -70.743  51.719  1
335465  97.535  -70.747  51.686  1
335466  97.567  -70.751  51.652  1
335467  97.599  -70.755  51.614  1
335468  97.632  -70.762  51.575  1
335469  97.664  -70.772  51.537  1
335470  97.698  -70.782  51.498  1
335471  97.731  -70.792  51.458  1
335472  97.764  -70.802  51.418  1
335473  97.797  -70.813  51.379  1
335474  97.830  -70.823  51.342  1
335475  97.863  -70.832  51.307  1
335476  97.894  -70.825  51.270  1
335477  97.927  -70.820  51.230  1
335478  97.960  -70.815  51.187  1
335479  97.994  -70.811  51.143  1
335480  98.027  -70.805  51.093  1
335481  98.060  -70.801  51.041  1
335482  98.094  -70.795  50.990  1
335483  98.129  -70.801  50.938  1
335484  98.165  -70.807  50.887  1
335485  98.202  -70.814  50.834  1
335486  98.238  -70.821  50.781  1
335487  98.274  -70.828  50.726  1
335488  98.310  -70.835  50.671  1
335489  98.347  -70.842  50.616  1
335490  98.382  -70.848  50.561  1
335491  98.419  -70.855  50.505  1
335492  98.455  -70.862  50.447  1
335493  98.491  -70.869  50.386  1
335494  98.528  -70.874  50.326  1
335495  98.568  -70.877  50.266  1
335496  98.608  -70.880  50.205  1
335497  98.648  -70.883  50.143  1
335498  98.688  -70.886  50.080  1
335499  98.727  -70.889  50.017  1
335500  98.767  -70.892  49.952  1
335501  98.807  -70.894  49.886  1
335502  98.847  -70.897  49.821  1
335503  98.882  -70.904  49.757  1
335504  98.912  -70.915  49.695  1
335505  98.942  -70.926  49.633  1
335506  98.972  -70.937  49.573  1
335507  99.003  -70.949  49.515  1
335508  99.035  -70.964  49.457  1
335509  99.067  -70.977  49.400  1
335510  99.099  -70.991  49.346  1
335511  99.132  -71.005  49.292  1
335512  99.164  -71.019  49.240  1
335513  99.196  -71.033  49.190  1
335514  99.228  -71.050  49.140  1
335515  99.260  -71.067  49.089  1
335516  99.292  -71.083  49.039  1
335517  99.325  -71.099  48.989  1
335518  99.356  -71.116  48.938  1
335519  99.389  -71.130  48.891  1
335520  99.423  -71.136  48.845  1
335521  99.458  -71.139  48.799  1
335522  99.495  -71.143  48.755  1
335523  99.535  -71.150  48.712  1
335524  99.575  -71.156  48.669  1
335525  99.616  -71.163  48.627  1
335526  99.656  -71.170  48.587  1
335527  99.696  -71.177  48.547  1
335528  99.739  -71.188  48.508  1
335529  99.786  -71.206  48.469  1
335530  99.827  -71.222  48.430  1
335531  99.865  -71.237  48.392  1
335532  99.904  -71.252  48.354  1
335533  99.943  -71.268  48.316  1
335534  99.982  -71.283  48.279  1
335535  100.020  -71.298  48.239  1
335536  100.059  -71.313  48.199  1
335537  100.098  -71.328  48.157  1
335538  100.136  -71.343  48.115  1
335539  100.175  -71.359  48.076  1
335540  100.214  -71.375  48.034  1
335541  100.252  -71.390  47.992  1
335542  100.291  -71.405  47.948  1
335543  100.330  -71.420  47.903  1
335544  100.368  -71.435  47.860  1
335545  100.407  -71.450  47.817  1
335546  100.443  -71.463  47.776  1
335547  100.469  -71.476  47.735  1
335548  100.492  -71.491  47.695  1
335549  100.516  -71.506  47.654  1
335550  100.539  -71.522  47.613  1
335551  100.562  -71.537  47.573  1
335552  100.585  -71.552  47.534  1
335553  100.609  -71.566  47.498  1
335554  100.632  -71.582  47.461  1
335555  100.655  -71.597  47.424  1
335556  100.679  -71.612  47.387  1
335557  100.704  -71.630  47.350  1
335558  100.738  -71.635  47.314  1
335559  100.787  -71.641  47.279  1
335560  100.841  -71.649  47.243  1
335561  100.895  -71.656  47.208  1
335562  100.948  -71.663  47.173  1
335563  101.002  -71.671  47.138  1
335564  101.055  -71.678  47.103  1
335565  101.109  -71.685  47.070  1
335566  101.155  -71.694  47.036  1
335567  101.171  -71.709  47.003  1
335568  101.188  -71.723  46.969  1
335569  101.204  -71.738  46.936  1
335570  101.220  -71.753  46.902  1
335571  101.244  -71.765  46.868  1
335572  101.279  -71.771  46.834  1
335573  101.316  -71.776  46.799  1
335574  101.351  -71.782  46.764  1
335575  101.388  -71.788  46.729  1
335576  101.424  -71.795  46.695  1
335577  101.460  -71.801  46.662  1
335578  101.496  -71.807  46.629  1
335579  101.532  -71.817  46.597  1
335580  101.567  -71.830  46.564  1
335581  101.603  -71.842  46.528  1
335582  101.638  -71.855  46.490  1
335583  101.674  -71.867  46.450  1
335584  101.711  -71.881  46.411  1
335585  101.753  -71.898  46.372  1
335586  101.796  -71.916  46.331  1
335587  101.837  -71.933  46.289  1
335588  101.869  -71.953  46.248  1
335589  101.898  -71.973  46.208  1
335590  101.927  -71.992  46.167  1
335591  101.956  -72.013  46.126  1
335592  101.984  -72.033  46.085  1
335593  102.013  -72.053  46.045  1
335594  102.026  -72.043  46.005  1
335595  102.044  -72.044  45.967  1
335596  102.046  -72.036  45.930  1
335597  102.048  -72.029  45.893  1
335598  102.069  -72.027  45.857  1
335599  102.100  -72.029  45.821  1
335600  102.129  -72.030  45.786  1
335601  102.160  -72.032  45.751  1
335602  102.189  -72.033  45.718  1
335603  102.220  -72.035  45.684  1
335604  102.250  -72.036  45.650  1
335605  102.279  -72.039  45.617  1
335606  102.310  -72.040  45.584  1
335607  102.339  -72.042  45.553  1
335608  102.370  -72.043  45.520  1
335609  102.400  -72.045  45.488  1
335610  102.430  -72.046  45.456  1
335611  102.460  -72.048  45.424  1
335612  102.489  -72.049  45.391  1
335992  91.815  -70.494  55.249  3
335993  91.846  -70.504  55.240  3
335994  91.877  -70.515  55.233  3
335995  91.908  -70.525  55.225  3
335996  91.939  -70.536  55.218  3
335997  91.983  -70.555  55.211  3
335998  92.040  -70.591  55.204  3
335999  92.091  -70.607  55.197  3
336000  92.141  -70.582  55.192  3
336001  92.192  -70.558  55.187  3
336002  92.243  -70.534  55.185  3
336003  92.275  -70.547  55.183  3
336004  92.311  -70.544  55.179  3
336005  92.349  -70.541  55.169  3
336006  92.386  -70.539  55.153  3
336007  92.423  -70.536  55.133  3
336008  92.460  -70.534  55.110  3
336009  92.503  -70.533  55.090  3
336010  92.547  -70.532  55.068  3
336011  92.591  -70.532  55.045  3
336012  92.635  -70.532  55.020  3
336013  92.678  -70.532  54.994  3
336014  92.722  -70.532  54.967  3
336015  92.768  -70.530  54.937  3
336016  92.803  -70.522  54.907  3
336017  92.831  -70.509  54.877  3
336018  92.859  -70.495  54.844  3
336019  92.916  -70.483  54.808  3
336020  92.952  -70.456  54.769  3
336021  92.984  -70.442  54.727  3
336022  93.013  -70.434  54.682  3
336023  93.042  -70.426  54.634  3
336024  93.071  -70.419  54.584  3
336025  93.099  -70.411  54.535  3
336026  93.128  -70.403  54.488  3
336027  93.157  -70.396  54.442  3
336028  93.186  -70.388  54.398  3
336029  93.215  -70.381  54.355  3
336030  93.244  -70.373  54.314  3
336031  93.273  -70.366  54.275  3
336032  93.302  -70.358  54.237  3
336033  93.331  -70.350  54.201  3
336034  93.359  -70.342  54.166  3
336083  94.832  -70.083  52.838  1
336084  94.865  -70.084  52.833  1
336085  94.898  -70.085  52.828  1
336086  94.931  -70.086  52.823  1
336087  94.964  -70.086  52.819  1
336088  94.997  -70.087  52.815  1
336089  95.030  -70.087  52.813  1
336090  95.063  -70.088  52.812  1
336091  95.096  -70.089  52.813  1
336092  95.129  -70.090  52.814  1
336093  95.162  -70.090  52.815  1
336094  95.195  -70.091  52.814  1
336095  95.228  -70.092  52.813  1
336096  95.265  -70.088  52.812  1
336097  95.317  -70.071  52.811  1
336098  95.362  -70.058  52.809  1
336099  95.390  -70.057  52.805  1
336100  95.421  -70.069  52.802  1
336101  95.453  -70.080  52.799  1
336102  95.484  -70.093  52.799  1
336103  95.516  -70.105  52.802  1
336104  95.548  -70.116  52.799  1
336105  95.579  -70.128  52.788  1
336106  95.611  -70.140  52.770  1
336107  95.642  -70.152  52.749  1
336108  95.674  -70.164  52.721  1
336109  95.705  -70.176  52.696  1
336110  95.737  -70.187  52.670  1
336111  95.768  -70.199  52.645  1
336112  95.796  -70.212  52.623  1
336113  95.816  -70.228  52.602  1
336114  95.836  -70.242  52.583  1
336115  95.856  -70.257  52.565  1
336116  95.881  -70.267  52.552  1
336117  95.910  -70.275  52.533  1
336118  95.938  -70.282  52.514  1
336119  95.966  -70.290  52.495  1
336120  95.994  -70.297  52.477  1
336121  96.023  -70.305  52.451  1
336122  96.051  -70.312  52.425  1
336123  96.080  -70.319  52.402  1
336124  96.108  -70.327  52.381  1
336125  96.135  -70.334  52.363  1
336126  96.158  -70.343  52.345  1
336127  96.181  -70.351  52.328  1
336128  96.204  -70.359  52.313  1
336129  96.233  -70.369  52.295  1
336130  96.269  -70.382  52.278  1
336131  96.305  -70.394  52.262  1
336132  96.341  -70.407  52.248  1
336133  96.377  -70.417  52.240  1
336134  96.413  -70.427  52.234  1
336135  96.449  -70.437  52.223  1
336136  96.484  -70.444  52.208  1
336137  96.520  -70.447  52.190  1
336138  96.555  -70.449  52.173  1
336139  96.591  -70.451  52.156  1
336140  96.636  -70.462  52.140  1
336141  96.681  -70.472  52.126  1
336142  96.726  -70.483  52.115  1
336143  96.778  -70.498  52.110  1
336144  96.832  -70.515  52.109  1
336145  96.883  -70.530  52.111  1
336146  96.923  -70.538  52.115  1
336147  96.962  -70.545  52.119  1
336148  97.002  -70.553  52.116  1
336149  97.044  -70.562  52.108  1
336150  97.085  -70.569  52.095  1
336151  97.124  -70.578  52.075  1
336152  97.164  -70.586  52.055  1
336153  97.204  -70.594  52.034  1
336154  97.241  -70.602  52.010  1
336155  97.259  -70.611  51.981  1
336156  97.286  -70.629  51.952  1
336157  97.313  -70.650  51.923  1
336158  97.331  -70.665  51.894  1
336159  97.352  -70.676  51.869  1
336160  97.375  -70.684  51.848  1
336161  97.398  -70.691  51.826  1
336162  97.422  -70.700  51.801  1
336163  97.445  -70.708  51.777  1
336164  97.471  -70.715  51.747  1
336165  97.504  -70.719  51.717  1
336166  97.535  -70.723  51.684  1
336167  97.568  -70.727  51.649  1
336168  97.599  -70.731  51.610  1
336169  97.627  -70.735  51.570  1
336170  97.659  -70.742  51.530  1
336171  97.693  -70.751  51.489  1
336172  97.728  -70.760  51.449  1
336173  97.762  -70.769  51.410  1
336174  97.797  -70.777  51.374  1
336175  97.831  -70.786  51.339  1
336176  97.867  -70.792  51.304  1
336177  97.901  -70.789  51.266  1
336178  97.935  -70.784  51.224  1
336179  97.968  -70.779  51.179  1
336180  98.001  -70.774  51.132  1
336181  98.034  -70.769  51.082  1
336182  98.068  -70.764  51.031  1
336183  98.101  -70.759  50.981  1
336184  98.135  -70.755  50.931  1
336185  98.171  -70.762  50.882  1
336186  98.207  -70.769  50.831  1
336187  98.243  -70.776  50.779  1
336188  98.279  -70.782  50.726  1
336189  98.315  -70.789  50.671  1
336190  98.352  -70.796  50.615  1
336191  98.388  -70.803  50.559  1
336192  98.424  -70.810  50.501  1
336193  98.460  -70.817  50.440  1
336194  98.496  -70.823  50.378  1
336195  98.535  -70.827  50.316  1
336196  98.575  -70.830  50.255  1
336197  98.615  -70.833  50.194  1
336198  98.655  -70.836  50.132  1
336199  98.695  -70.839  50.070  1
336200  98.734  -70.842  50.007  1
336201  98.774  -70.845  49.944  1
336202  98.814  -70.847  49.879  1
336203  98.854  -70.850  49.814  1
336204  98.891  -70.854  49.751  1
336205  98.921  -70.866  49.689  1
336206  98.951  -70.877  49.628  1
336207  98.982  -70.889  49.569  1
336208  99.014  -70.903  49.511  1
336209  99.047  -70.917  49.454  1
336210  99.079  -70.931  49.399  1
336211  99.111  -70.945  49.345  1
336212  99.143  -70.962  49.292  1
336213  99.175  -70.979  49.241  1
336214  99.207  -70.995  49.191  1
336215  99.239  -71.012  49.139  1
336216  99.271  -71.029  49.089  1
336217  99.303  -71.046  49.040  1
336218  99.335  -71.062  48.991  1
336219  99.367  -71.078  48.942  1
336220  99.400  -71.092  48.895  1
336221  99.433  -71.099  48.850  1
336222  99.469  -71.102  48.805  1
336223  99.503  -71.105  48.762  1
336224  99.539  -71.108  48.719  1
336225  99.578  -71.115  48.677  1
336226  99.619  -71.121  48.637  1
336227  99.659  -71.127  48.597  1
336228  99.699  -71.134  48.558  1
336229  99.739  -71.141  48.521  1
336230  99.786  -71.159  48.483  1
336231  99.828  -71.175  48.445  1
336232  99.866  -71.190  48.406  1
336233  99.905  -71.205  48.369  1
336234  99.944  -71.221  48.331  1
336235  99.983  -71.237  48.293  1
336236  100.021  -71.252  48.254  1
336237  100.060  -71.267  48.214  1
336238  100.099  -71.282  48.173  1
336239  100.137  -71.297  48.131  1
336240  100.176  -71.312  48.090  1
336241  100.215  -71.328  48.047  1
336242  100.254  -71.343  48.004  1
336243  100.292  -71.358  47.960  1
336244  100.331  -71.373  47.915  1
336245  100.369  -71.388  47.872  1
336246  100.408  -71.407  47.831  1
336247  100.444  -71.425  47.790  1
336248  100.468  -71.441  47.748  1
336249  100.492  -71.456  47.707  1
336250  100.516  -71.472  47.666  1
336251  100.541  -71.487  47.625  1
336252  100.565  -71.503  47.585  1
336253  100.590  -71.518  47.547  1
336254  100.614  -71.533  47.510  1
336255  100.638  -71.549  47.474  1
336256  100.662  -71.564  47.437  1
336257  100.686  -71.579  47.399  1
336258  100.714  -71.594  47.363  1
336259  100.769  -71.602  47.327  1
336260  100.822  -71.609  47.292  1
336261  100.876  -71.616  47.256  1
336262  100.929  -71.624  47.221  1
336263  100.983  -71.631  47.185  1
336264  101.037  -71.638  47.150  1
336265  101.091  -71.645  47.115  1
336266  101.144  -71.653  47.082  1
336267  101.167  -71.666  47.047  1
336268  101.183  -71.681  47.013  1
336269  101.200  -71.696  46.979  1
336270  101.216  -71.710  46.945  1
336271  101.233  -71.725  46.910  1
336272  101.258  -71.736  46.876  1
336273  101.294  -71.741  46.841  1
336274  101.330  -71.748  46.805  1
336275  101.366  -71.754  46.770  1
336276  101.402  -71.760  46.734  1
336277  101.438  -71.766  46.699  1
336278  101.474  -71.772  46.665  1
336279  101.510  -71.778  46.632  1
336280  101.546  -71.785  46.600  1
336281  101.582  -71.797  46.567  1
336282  101.618  -71.809  46.533  1
336283  101.653  -71.822  46.494  1
336284  101.689  -71.834  46.456  1
336285  101.729  -71.850  46.418  1
336286  101.770  -71.867  46.378  1
336287  101.813  -71.885  46.337  1
336288  101.855  -71.902  46.295  1
336289  101.888  -71.921  46.254  1
336290  101.916  -71.942  46.213  1
336291  101.946  -71.961  46.172  1
336292  101.974  -71.982  46.130  1
336293  102.003  -72.001  46.088  1
336294  102.018  -71.995  46.049  1
336295  102.030  -71.992  46.010  1
336296  102.032  -71.985  45.972  1
336297  102.034  -71.977  45.936  1
336298  102.053  -71.975  45.900  1
336299  102.084  -71.977  45.864  1
336300  102.113  -71.979  45.828  1
336301  102.144  -71.980  45.794  1
336302  102.173  -71.982  45.760  1
336303  102.203  -71.983  45.726  1
336304  102.234  -71.985  45.693  1
336305  102.263  -71.986  45.659  1
336306  102.293  -71.988  45.626  1
336307  102.323  -71.989  45.594  1
336308  102.353  -71.991  45.562  1
336309  102.384  -71.992  45.529  1
336310  102.413  -71.994  45.497  1
336311  102.444  -71.995  45.464  1
336693  91.803  -70.461  55.245  3
336694  91.834  -70.472  55.236  3
336695  91.865  -70.482  55.229  3
336696  91.896  -70.493  55.221  3
336697  91.927  -70.503  55.214  3
336698  91.977  -70.527  55.207  3
336699  92.033  -70.566  55.201  3
336700  92.084  -70.578  55.193  3
336701  92.135  -70.554  55.186  3
336702  92.185  -70.529  55.182  3
336703  92.236  -70.504  55.178  3
336704  92.274  -70.506  55.175  3
336705  92.310  -70.504  55.170  3
336706  92.348  -70.501  55.161  3
336707  92.385  -70.499  55.147  3
336708  92.422  -70.496  55.129  3
336709  92.459  -70.494  55.108  3
336710  92.496  -70.491  55.089  3
336711  92.536  -70.490  55.072  3
336712  92.580  -70.489  55.054  3
336713  92.624  -70.489  55.034  3
336714  92.668  -70.488  55.011  3
336715  92.713  -70.488  54.984  3
336716  92.759  -70.487  54.955  3
336717  92.802  -70.485  54.926  3
336718  92.830  -70.471  54.897  3
336719  92.857  -70.458  54.865  3
336720  92.909  -70.445  54.829  3
336721  92.954  -70.425  54.791  3
336722  92.991  -70.397  54.749  3
336723  93.020  -70.388  54.703  3
336724  93.049  -70.381  54.653  3
336725  93.078  -70.373  54.601  3
336726  93.107  -70.366  54.550  3
336727  93.136  -70.358  54.501  3
336728  93.165  -70.350  54.454  3
336729  93.194  -70.343  54.409  3
336730  93.222  -70.335  54.365  3
336731  93.252  -70.328  54.323  3
336732  93.280  -70.320  54.282  3
336733  93.309  -70.312  54.244  3
336734  93.338  -70.304  54.208  3
336735  93.367  -70.297  54.172  3
336783  94.819  -70.063  52.844  1
336784  94.852  -70.064  52.838  1
336785  94.885  -70.065  52.833  1
336786  94.918  -70.065  52.827  1
336787  94.951  -70.066  52.822  1
336788  94.984  -70.067  52.821  1
336789  95.018  -70.068  52.819  1
336790  95.050  -70.068  52.817  1
336791  95.084  -70.069  52.818  1
336792  95.116  -70.069  52.821  1
336793  95.149  -70.070  52.823  1
336794  95.182  -70.071  52.825  1
336795  95.215  -70.071  52.827  1
336796  95.248  -70.072  52.827  1
336797  95.292  -70.062  52.826  1
336798  95.343  -70.046  52.824  1
336799  95.379  -70.037  52.821  1
336800  95.412  -70.031  52.816  1
336801  95.432  -70.037  52.811  1
336802  95.464  -70.048  52.809  1
336803  95.495  -70.060  52.809  1
336804  95.527  -70.072  52.813  1
336805  95.558  -70.083  52.814  1
336806  95.590  -70.096  52.805  1
336807  95.621  -70.108  52.789  1
336808  95.653  -70.119  52.768  1
336809  95.684  -70.131  52.738  1
336810  95.716  -70.143  52.712  1
336811  95.747  -70.155  52.686  1
336812  95.777  -70.168  52.659  1
336813  95.797  -70.182  52.636  1
336814  95.817  -70.197  52.615  1
336815  95.837  -70.212  52.596  1
336816  95.858  -70.227  52.579  1
336817  95.882  -70.237  52.567  1
336818  95.910  -70.245  52.547  1
336819  95.939  -70.253  52.528  1
336820  95.967  -70.260  52.509  1
336821  95.995  -70.268  52.490  1
336822  96.024  -70.275  52.464  1
336823  96.052  -70.282  52.438  1
336824  96.080  -70.290  52.412  1
336825  96.109  -70.297  52.390  1
336826  96.137  -70.305  52.370  1
336827  96.165  -70.312  52.352  1
336828  96.193  -70.320  52.335  1
336829  96.217  -70.328  52.320  1
336830  96.247  -70.338  52.303  1
336831  96.283  -70.350  52.286  1
336832  96.319  -70.360  52.270  1
336833  96.355  -70.370  52.257  1
336834  96.390  -70.380  52.248  1
336835  96.426  -70.390  52.242  1
336836  96.462  -70.400  52.230  1
336837  96.498  -70.409  52.216  1
336838  96.533  -70.411  52.199  1
336839  96.569  -70.413  52.183  1
336840  96.611  -70.422  52.167  1
336841  96.656  -70.432  52.153  1
336842  96.701  -70.443  52.140  1
336843  96.746  -70.453  52.129  1
336844  96.791  -70.464  52.126  1
336845  96.839  -70.477  52.127  1
336846  96.891  -70.492  52.131  1
336847  96.931  -70.500  52.134  1
336848  96.970  -70.508  52.137  1
336849  97.009  -70.516  52.133  1
336850  97.047  -70.524  52.124  1
336851  97.084  -70.530  52.111  1
336852  97.123  -70.538  52.091  1
336853  97.163  -70.546  52.070  1
336854  97.203  -70.554  52.047  1
336855  97.238  -70.563  52.023  1
336856  97.261  -70.576  51.991  1
336857  97.290  -70.597  51.960  1
336858  97.318  -70.619  51.930  1
336859  97.337  -70.634  51.901  1
336860  97.355  -70.649  51.876  1
336861  97.376  -70.660  51.854  1
336862  97.399  -70.668  51.830  1
336863  97.423  -70.676  51.803  1
336864  97.446  -70.684  51.775  1
336865  97.472  -70.691  51.744  1
336866  97.504  -70.695  51.712  1
336867  97.536  -70.699  51.678  1
336868  97.568  -70.703  51.642  1
336869  97.596  -70.707  51.602  1
336870  97.623  -70.711  51.563  1
336871  97.650  -70.715  51.524  1
336872  97.685  -70.724  51.484  1
336873  97.719  -70.732  51.445  1
336874  97.754  -70.742  51.407  1
336875  97.791  -70.745  51.370  1
336876  97.828  -70.746  51.333  1
336877  97.867  -70.747  51.296  1
336878  97.904  -70.748  51.257  1
336879  97.942  -70.748  51.214  1
336880  97.975  -70.742  51.168  1
336881  98.009  -70.738  51.121  1
336882  98.042  -70.732  51.070  1
336883  98.075  -70.728  51.019  1
336884  98.108  -70.723  50.967  1
336885  98.142  -70.718  50.917  1
336886  98.176  -70.717  50.870  1
336887  98.212  -70.723  50.822  1
336888  98.248  -70.730  50.772  1
336889  98.285  -70.737  50.720  1
336890  98.321  -70.744  50.665  1
336891  98.357  -70.751  50.608  1
336892  98.393  -70.757  50.551  1
336893  98.429  -70.764  50.493  1
336894  98.465  -70.771  50.432  1
336895  98.502  -70.777  50.370  1
336896  98.542  -70.780  50.308  1
336897  98.582  -70.783  50.244  1
336898  98.622  -70.785  50.181  1
336899  98.662  -70.789  50.120  1
336900  98.702  -70.792  50.058  1
336901  98.741  -70.795  49.996  1
336902  98.781  -70.797  49.933  1
336903  98.821  -70.800  49.869  1
336904  98.861  -70.803  49.806  1
336905  98.901  -70.806  49.745  1
336906  98.931  -70.817  49.686  1
336907  98.961  -70.829  49.626  1
336908  98.994  -70.843  49.567  1
336909  99.026  -70.858  49.509  1
336910  99.058  -70.874  49.452  1
336911  99.090  -70.891  49.398  1
336912  99.122  -70.908  49.344  1
336913  99.154  -70.924  49.292  1
336914  99.186  -70.941  49.240  1
336915  99.218  -70.958  49.190  1
336916  99.250  -70.974  49.140  1
336917  99.282  -70.991  49.090  1
336918  99.314  -71.008  49.042  1
336919  99.346  -71.024  48.994  1
336920  99.378  -71.041  48.945  1
336921  99.410  -71.053  48.900  1
336922  99.444  -71.061  48.855  1
336923  99.479  -71.065  48.812  1
336924  99.514  -71.068  48.769  1
336925  99.549  -71.071  48.727  1
336926  99.584  -71.074  48.686  1
336927  99.622  -71.079  48.647  1
336928  99.662  -71.086  48.608  1
336929  99.702  -71.092  48.570  1
336930  99.742  -71.099  48.534  1
336931  99.786  -71.112  48.498  1
336932  99.829  -71.129  48.461  1
336933  99.868  -71.144  48.423  1
336934  99.907  -71.159  48.387  1
336935  99.945  -71.174  48.350  1
336936  99.984  -71.190  48.312  1
336937  100.022  -71.205  48.273  1
336938  100.061  -71.220  48.234  1
336939  100.100  -71.235  48.193  1
336940  100.139  -71.250  48.150  1
336941  100.177  -71.266  48.107  1
336942  100.216  -71.281  48.062  1
336943  100.255  -71.296  48.017  1
336944  100.293  -71.315  47.972  1
336945  100.331  -71.334  47.927  1
336946  100.369  -71.353  47.884  1
336947  100.408  -71.371  47.843  1
336948  100.437  -71.388  47.802  1
336949  100.462  -71.403  47.761  1
336950  100.486  -71.419  47.720  1
336951  100.510  -71.434  47.678  1
336952  100.535  -71.450  47.637  1
336953  100.559  -71.465  47.598  1
336954  100.583  -71.481  47.561  1
336955  100.607  -71.496  47.523  1
336956  100.631  -71.511  47.487  1
336957  100.656  -71.526  47.450  1
336958  100.694  -71.535  47.413  1
336959  100.732  -71.544  47.377  1
336960  100.789  -71.558  47.341  1
336961  100.856  -71.575  47.306  1
336962  100.911  -71.584  47.270  1
336963  100.965  -71.591  47.235  1
336964  101.018  -71.598  47.199  1
336965  101.072  -71.606  47.164  1
336966  101.125  -71.613  47.128  1
336967  101.162  -71.624  47.094  1
336968  101.179  -71.638  47.060  1
336969  101.195  -71.654  47.025  1
336970  101.212  -71.668  46.991  1
336971  101.228  -71.682  46.956  1
336972  101.245  -71.697  46.921  1
336973  101.272  -71.707  46.885  1
336974  101.309  -71.713  46.850  1
336975  101.344  -71.719  46.814  1
336976  101.381  -71.725  46.779  1
336977  101.417  -71.731  46.743  1
336978  101.453  -71.737  46.707  1
336979  101.489  -71.742  46.671  1
336980  101.525  -71.748  46.636  1
336981  101.561  -71.754  46.601  1
336982  101.597  -71.763  46.566  1
336983  101.632  -71.776  46.530  1
336984  101.668  -71.788  46.495  1
336985  101.704  -71.801  46.457  1
336986  101.746  -71.819  46.418  1
336987  101.788  -71.836  46.379  1
336988  101.830  -71.854  46.339  1
336989  101.872  -71.871  46.299  1
336990  101.906  -71.890  46.258  1
336991  101.935  -71.910  46.217  1
336992  101.964  -71.930  46.176  1
336993  101.993  -71.950  46.134  1
336994  102.010  -71.946  46.093  1
336995  102.016  -71.941  46.054  1
336996  102.018  -71.933  46.016  1
336997  102.020  -71.926  45.978  1
336998  102.037  -71.923  45.942  1
336999  102.067  -71.925  45.906  1
337000  102.097  -71.926  45.871  1
337001  102.127  -71.928  45.835  1
337002  102.157  -71.929  45.801  1
337003  102.187  -71.931  45.767  1
337004  102.218  -71.933  45.733  1
337005  102.247  -71.934  45.700  1
337006  102.277  -71.936  45.667  1
337007  102.307  -71.937  45.634  1
337008  102.337  -71.939  45.602  1
337009  102.368  -71.940  45.570  1
337010  102.397  -71.942  45.537  1
337011  102.427  -71.943  45.505  1
337394  91.791  -70.429  55.240  3
337395  91.822  -70.440  55.232  3
337396  91.853  -70.450  55.224  3
337397  91.884  -70.461  55.217  3
337398  91.915  -70.471  55.210  3
337399  91.971  -70.499  55.203  3
337400  92.026  -70.542  55.197  3
337401  92.077  -70.548  55.189  3
337402  92.128  -70.524  55.182  3
337403  92.178  -70.500  55.177  3
337404  92.229  -70.475  55.172  3
337405  92.274  -70.462  55.167  3
337406  92.309  -70.464  55.161  3
337407  92.346  -70.461  55.152  3
337408  92.383  -70.459  55.139  3
337409  92.421  -70.456  55.124  3
337410  92.458  -70.453  55.109  3
337411  92.495  -70.451  55.095  3
337412  92.532  -70.448  55.083  3
337413  92.570  -70.446  55.071  3
337414  92.614  -70.446  55.056  3
337415  92.658  -70.445  55.036  3
337416  92.703  -70.444  55.007  3
337417  92.749  -70.444  54.976  3
337418  92.794  -70.443  54.946  3
337419  92.829  -70.434  54.917  3
337420  92.856  -70.420  54.888  3
337421  92.902  -70.407  54.854  3
337422  92.956  -70.394  54.814  3
337423  92.993  -70.366  54.771  3
337424  93.028  -70.343  54.723  3
337425  93.057  -70.335  54.671  3
337426  93.085  -70.328  54.618  3
337427  93.115  -70.320  54.565  3
337428  93.143  -70.312  54.514  3
337429  93.172  -70.305  54.466  3
337430  93.201  -70.297  54.420  3
337431  93.230  -70.290  54.375  3
337432  93.259  -70.281  54.333  3
337433  93.288  -70.274  54.291  3
337434  93.317  -70.266  54.253  3
337435  93.346  -70.259  54.216  3
337436  93.374  -70.251  54.179  3
337437  93.403  -70.243  54.145  3
337484  94.840  -70.043  52.842  1
337485  94.873  -70.044  52.836  1
337486  94.906  -70.045  52.831  1
337487  94.938  -70.046  52.826  1
337488  94.972  -70.046  52.823  1
337489  95.004  -70.047  52.822  1
337490  95.038  -70.048  52.821  1
337491  95.070  -70.049  52.821  1
337492  95.104  -70.049  52.824  1
337493  95.137  -70.050  52.828  1
337494  95.170  -70.051  52.833  1
337495  95.203  -70.052  52.837  1
337496  95.236  -70.052  52.841  1
337497  95.269  -70.053  52.843  1
337498  95.319  -70.037  52.841  1
337499  95.360  -70.026  52.837  1
337500  95.396  -70.018  52.831  1
337501  95.431  -70.009  52.826  1
337502  95.455  -70.010  52.821  1
337503  95.474  -70.015  52.818  1
337504  95.506  -70.027  52.817  1
337505  95.537  -70.040  52.822  1
337506  95.568  -70.051  52.824  1
337507  95.600  -70.063  52.820  1
337508  95.631  -70.075  52.806  1
337509  95.663  -70.087  52.784  1
337510  95.695  -70.099  52.756  1
337511  95.726  -70.111  52.728  1
337512  95.758  -70.123  52.701  1
337513  95.778  -70.137  52.673  1
337514  95.798  -70.152  52.648  1
337515  95.818  -70.167  52.627  1
337516  95.839  -70.181  52.608  1
337517  95.859  -70.196  52.593  1
337518  95.883  -70.208  52.580  1
337519  95.911  -70.215  52.561  1
337520  95.939  -70.223  52.540  1
337521  95.968  -70.231  52.520  1
337522  95.996  -70.237  52.502  1
337523  96.024  -70.245  52.477  1
337524  96.052  -70.253  52.449  1
337525  96.081  -70.260  52.422  1
337526  96.109  -70.268  52.400  1
337527  96.137  -70.275  52.378  1
337528  96.166  -70.282  52.359  1
337529  96.196  -70.288  52.342  1
337530  96.227  -70.293  52.325  1
337531  96.260  -70.304  52.309  1
337532  96.296  -70.313  52.293  1
337533  96.331  -70.323  52.278  1
337534  96.367  -70.333  52.265  1
337535  96.403  -70.343  52.255  1
337536  96.439  -70.353  52.248  1
337537  96.475  -70.362  52.237  1
337538  96.511  -70.372  52.223  1
337539  96.546  -70.375  52.208  1
337540  96.586  -70.381  52.193  1
337541  96.631  -70.391  52.178  1
337542  96.676  -70.402  52.164  1
337543  96.721  -70.413  52.153  1
337544  96.766  -70.423  52.143  1
337545  96.811  -70.434  52.141  1
337546  96.856  -70.444  52.144  1
337547  96.899  -70.455  52.148  1
337548  96.938  -70.463  52.150  1
337549  96.977  -70.472  52.152  1
337550  97.016  -70.480  52.148  1
337551  97.054  -70.488  52.139  1
337552  97.091  -70.494  52.126  1
337553  97.127  -70.500  52.106  1
337554  97.163  -70.507  52.084  1
337555  97.201  -70.514  52.060  1
337556  97.236  -70.522  52.035  1
337557  97.264  -70.544  52.003  1
337558  97.293  -70.565  51.970  1
337559  97.322  -70.586  51.939  1
337560  97.343  -70.603  51.910  1
337561  97.361  -70.618  51.884  1
337562  97.379  -70.633  51.861  1
337563  97.400  -70.644  51.835  1
337564  97.424  -70.652  51.806  1
337565  97.447  -70.660  51.775  1
337566  97.472  -70.667  51.743  1
337567  97.504  -70.671  51.709  1
337568  97.536  -70.676  51.673  1
337569  97.566  -70.679  51.637  1
337570  97.593  -70.683  51.597  1
337571  97.620  -70.687  51.558  1
337572  97.647  -70.691  51.520  1
337573  97.676  -70.697  51.480  1
337574  97.714  -70.699  51.442  1
337575  97.752  -70.699  51.404  1
337576  97.790  -70.700  51.365  1
337577  97.828  -70.701  51.325  1
337578  97.866  -70.701  51.286  1
337579  97.904  -70.702  51.245  1
337580  97.942  -70.702  51.201  1
337581  97.980  -70.703  51.155  1
337582  98.016  -70.701  51.109  1
337583  98.050  -70.696  51.058  1
337584  98.083  -70.691  51.007  1
337585  98.116  -70.686  50.955  1
337586  98.149  -70.682  50.904  1
337587  98.183  -70.676  50.857  1
337588  98.218  -70.678  50.810  1
337589  98.254  -70.685  50.761  1
337590  98.290  -70.691  50.710  1
337591  98.326  -70.698  50.656  1
337592  98.362  -70.705  50.600  1
337593  98.398  -70.712  50.543  1
337594  98.435  -70.719  50.484  1
337595  98.471  -70.726  50.423  1
337596  98.509  -70.730  50.362  1
337597  98.549  -70.733  50.299  1
337598  98.589  -70.735  50.235  1
337599  98.629  -70.739  50.173  1
337600  98.668  -70.742  50.111  1
337601  98.708  -70.745  50.049  1
337602  98.748  -70.747  49.986  1
337603  98.788  -70.750  49.923  1
337604  98.828  -70.753  49.860  1
337605  98.868  -70.756  49.800  1
337606  98.908  -70.758  49.741  1
337607  98.941  -70.770  49.683  1
337608  98.973  -70.786  49.623  1
337609  99.005  -70.803  49.564  1
337610  99.037  -70.820  49.506  1
337611  99.069  -70.836  49.450  1
337612  99.101  -70.853  49.396  1
337613  99.133  -70.870  49.343  1
337614  99.165  -70.886  49.291  1
337615  99.197  -70.903  49.240  1
337616  99.229  -70.920  49.189  1
337617  99.261  -70.936  49.140  1
337618  99.293  -70.953  49.091  1
337619  99.325  -70.970  49.043  1
337620  99.357  -70.986  48.996  1
337621  99.389  -71.002  48.949  1
337622  99.421  -71.014  48.904  1
337623  99.454  -71.025  48.861  1
337624  99.489  -71.028  48.819  1
337625  99.524  -71.031  48.777  1
337626  99.559  -71.034  48.735  1
337627  99.594  -71.037  48.695  1
337628  99.630  -71.040  48.657  1
337629  99.664  -71.043  48.621  1
337630  99.705  -71.050  48.583  1
337631  99.745  -71.056  48.548  1
337632  99.786  -71.065  48.513  1
337633  99.830  -71.082  48.478  1
337634  99.869  -71.097  48.443  1
337635  99.908  -71.112  48.407  1
337636  99.946  -71.127  48.371  1
337637  99.985  -71.143  48.335  1
337638  100.024  -71.158  48.296  1
337639  100.062  -71.174  48.257  1
337640  100.101  -71.189  48.214  1
337641  100.140  -71.204  48.169  1
337642  100.178  -71.222  48.124  1
337643  100.216  -71.241  48.077  1
337644  100.255  -71.260  48.031  1
337645  100.293  -71.279  47.985  1
337646  100.331  -71.298  47.940  1
337647  100.369  -71.317  47.895  1
337648  100.407  -71.335  47.854  1
337649  100.431  -71.351  47.813  1
337650  100.455  -71.366  47.771  1
337651  100.480  -71.381  47.732  1
337652  100.504  -71.397  47.692  1
337653  100.528  -71.412  47.651  1
337654  100.552  -71.428  47.612  1
337655  100.576  -71.443  47.575  1
337656  100.601  -71.459  47.538  1
337657  100.637  -71.468  47.501  1
337658  100.675  -71.476  47.465  1
337659  100.712  -71.485  47.428  1
337660  100.750  -71.494  47.391  1
337661  100.796  -71.505  47.355  1
337662  100.863  -71.522  47.320  1
337663  100.930  -71.540  47.284  1
337664  100.997  -71.557  47.250  1
337665  101.053  -71.566  47.215  1
337666  101.107  -71.573  47.180  1
337667  101.158  -71.582  47.145  1
337668  101.175  -71.596  47.110  1
337669  101.191  -71.610  47.076  1
337670  101.207  -71.625  47.041  1
337671  101.224  -71.640  47.006  1
337672  101.240  -71.655  46.971  1
337673  101.257  -71.669  46.935  1
337674  101.287  -71.678  46.899  1
337675  101.323  -71.684  46.864  1
337676  101.359  -71.690  46.827  1
337677  101.395  -71.696  46.791  1
337678  101.431  -71.702  46.754  1
337679  101.467  -71.707  46.717  1
337680  101.503  -71.713  46.680  1
337681  101.539  -71.719  46.644  1
337682  101.575  -71.726  46.607  1
337683  101.611  -71.732  46.570  1
337684  101.647  -71.743  46.533  1
337685  101.683  -71.756  46.496  1
337686  101.721  -71.770  46.458  1
337687  101.763  -71.787  46.419  1
337688  101.805  -71.804  46.380  1
337689  101.847  -71.822  46.341  1
337690  101.889  -71.840  46.302  1
337691  101.925  -71.858  46.261  1
337692  101.954  -71.879  46.221  1
337693  101.982  -71.898  46.181  1
337694  102.000  -71.898  46.139  1
337695  102.002  -71.890  46.099  1
337696  102.004  -71.882  46.059  1
337697  102.006  -71.874  46.021  1
337698  102.021  -71.871  45.984  1
337699  102.051  -71.873  45.948  1
337700  102.081  -71.874  45.912  1
337701  102.111  -71.876  45.877  1
337702  102.141  -71.877  45.842  1
337703  102.171  -71.879  45.807  1
337704  102.201  -71.880  45.774  1
337705  102.231  -71.882  45.740  1
337706  102.261  -71.884  45.707  1
337707  102.291  -71.885  45.675  1
337708  102.321  -71.887  45.643  1
337709  102.351  -71.889  45.610  1
337710  102.381  -71.890  45.578  1
338096  91.810  -70.407  55.227  3
338097  91.841  -70.418  55.219  3
338098  91.872  -70.428  55.212  3
338099  91.907  -70.441  55.205  3
338100  91.965  -70.471  55.199  3
338101  92.019  -70.517  55.192  3
338102  92.070  -70.519  55.185  3
338103  92.121  -70.494  55.177  3
338104  92.171  -70.470  55.171  3
338105  92.222  -70.446  55.166  3
338106  92.273  -70.422  55.160  3
338107  92.308  -70.424  55.153  3
338108  92.345  -70.421  55.144  3
338109  92.382  -70.419  55.133  3
338110  92.419  -70.416  55.122  3
338111  92.456  -70.413  55.112  3
338112  92.494  -70.411  55.102  3
338113  92.531  -70.408  55.095  3
338114  92.568  -70.406  55.086  3
338115  92.605  -70.403  55.074  3
338116  92.648  -70.402  55.057  3
338117  92.694  -70.401  55.030  3
338118  92.739  -70.400  55.000  3
338119  92.785  -70.400  54.968  3
338120  92.827  -70.396  54.940  3
338121  92.854  -70.383  54.910  3
338122  92.896  -70.370  54.876  3
338123  92.952  -70.357  54.836  3
338124  92.995  -70.334  54.789  3
338125  93.031  -70.307  54.740  3
338126  93.064  -70.290  54.686  3
338127  93.093  -70.282  54.633  3
338128  93.122  -70.275  54.580  3
338129  93.151  -70.267  54.528  3
338130  93.180  -70.259  54.479  3
338131  93.209  -70.252  54.432  3
338132  93.237  -70.243  54.387  3
338133  93.266  -70.236  54.344  3
338134  93.295  -70.228  54.302  3
338135  93.324  -70.221  54.262  3
338136  93.353  -70.213  54.224  3
338137  93.382  -70.206  54.187  3
338138  93.411  -70.198  54.152  3
338184  94.827  -70.024  52.849  1
338185  94.860  -70.024  52.840  1
338186  94.893  -70.025  52.834  1
338187  94.926  -70.026  52.829  1
338188  94.959  -70.026  52.825  1
338189  94.992  -70.027  52.823  1
338190  95.025  -70.027  52.822  1
338191  95.058  -70.028  52.823  1
338192  95.091  -70.029  52.825  1
338193  95.124  -70.030  52.829  1
338194  95.157  -70.030  52.836  1
338195  95.190  -70.031  52.844  1
338196  95.223  -70.032  52.851  1
338197  95.256  -70.033  52.856  1
338198  95.295  -70.028  52.860  1
338199  95.341  -70.014  52.857  1
338200  95.377  -70.005  52.852  1
338201  95.412  -69.997  52.844  1
338202  95.448  -69.990  52.836  1
338203  95.478  -69.985  52.831  1
338204  95.497  -69.990  52.826  1
338205  95.516  -69.995  52.825  1
338206  95.547  -70.007  52.828  1
338207  95.579  -70.018  52.831  1
338208  95.611  -70.030  52.829  1
338209  95.642  -70.043  52.818  1
338210  95.674  -70.054  52.797  1
338211  95.705  -70.066  52.769  1
338212  95.737  -70.078  52.742  1
338213  95.759  -70.093  52.715  1
338214  95.779  -70.107  52.687  1
338215  95.800  -70.122  52.660  1
338216  95.820  -70.137  52.639  1
338217  95.840  -70.151  52.620  1
338218  95.860  -70.166  52.605  1
338219  95.883  -70.178  52.592  1
338220  95.911  -70.186  52.573  1
338221  95.940  -70.193  52.553  1
338222  95.968  -70.200  52.531  1
338223  95.997  -70.208  52.512  1
338224  96.028  -70.213  52.488  1
338225  96.058  -70.218  52.460  1
338226  96.090  -70.224  52.432  1
338227  96.120  -70.229  52.409  1
338228  96.151  -70.234  52.387  1
338229  96.182  -70.240  52.367  1
338230  96.212  -70.246  52.349  1
338231  96.241  -70.259  52.332  1
338232  96.274  -70.269  52.315  1
338233  96.309  -70.278  52.300  1
338234  96.345  -70.287  52.286  1
338235  96.381  -70.297  52.272  1
338236  96.416  -70.306  52.261  1
338237  96.452  -70.315  52.253  1
338238  96.488  -70.325  52.244  1
338239  96.524  -70.334  52.232  1
338240  96.561  -70.341  52.219  1
338241  96.606  -70.351  52.204  1
338242  96.651  -70.362  52.190  1
338243  96.695  -70.371  52.177  1
338244  96.740  -70.378  52.165  1
338245  96.784  -70.384  52.156  1
338246  96.828  -70.391  52.155  1
338247  96.869  -70.401  52.158  1
338248  96.907  -70.416  52.161  1
338249  96.945  -70.427  52.162  1
338250  96.983  -70.435  52.164  1
338251  97.022  -70.444  52.161  1
338252  97.061  -70.452  52.153  1
338253  97.097  -70.458  52.138  1
338254  97.134  -70.465  52.118  1
338255  97.170  -70.471  52.096  1
338256  97.208  -70.478  52.071  1
338257  97.240  -70.491  52.045  1
338258  97.268  -70.511  52.015  1
338259  97.297  -70.532  51.982  1
338260  97.325  -70.554  51.950  1
338261  97.349  -70.572  51.919  1
338262  97.367  -70.587  51.893  1
338263  97.385  -70.602  51.867  1
338264  97.403  -70.617  51.840  1
338265  97.425  -70.628  51.810  1
338266  97.448  -70.636  51.778  1
338267  97.472  -70.644  51.743  1
338268  97.504  -70.648  51.707  1
338269  97.535  -70.651  51.671  1
338270  97.563  -70.655  51.636  1
338271  97.590  -70.660  51.596  1
338272  97.617  -70.663  51.557  1
338273  97.651  -70.660  51.519  1
338274  97.684  -70.657  51.479  1
338275  97.719  -70.656  51.441  1
338276  97.753  -70.654  51.401  1
338277  97.790  -70.654  51.358  1
338278  97.827  -70.655  51.316  1
338279  97.866  -70.656  51.276  1
338280  97.904  -70.656  51.231  1
338281  97.942  -70.657  51.186  1
338282  97.980  -70.657  51.141  1
338283  98.018  -70.658  51.096  1
338284  98.056  -70.659  51.047  1
338285  98.090  -70.655  50.996  1
338286  98.124  -70.650  50.943  1
338287  98.157  -70.645  50.890  1
338288  98.190  -70.640  50.841  1
338289  98.224  -70.635  50.794  1
338290  98.259  -70.639  50.747  1
338291  98.295  -70.646  50.698  1
338292  98.332  -70.653  50.646  1
338293  98.368  -70.660  50.592  1
338294  98.404  -70.666  50.534  1
338295  98.440  -70.673  50.474  1
338296  98.477  -70.680  50.414  1
338297  98.516  -70.683  50.352  1
338298  98.556  -70.685  50.290  1
338299  98.596  -70.688  50.229  1
338300  98.636  -70.691  50.169  1
338301  98.675  -70.695  50.106  1
338302  98.715  -70.697  50.043  1
338303  98.755  -70.700  49.979  1
338304  98.795  -70.703  49.916  1
338305  98.835  -70.706  49.854  1
338306  98.874  -70.712  49.795  1
338307  98.912  -70.721  49.737  1
338308  98.951  -70.732  49.679  1
338309  98.984  -70.748  49.620  1
338310  99.016  -70.765  49.561  1
338311  99.048  -70.782  49.504  1
338312  99.080  -70.798  49.449  1
338313  99.112  -70.815  49.394  1
338314  99.144  -70.832  49.341  1
338315  99.176  -70.848  49.290  1
338316  99.208  -70.865  49.239  1
338317  99.240  -70.882  49.189  1
338318  99.272  -70.898  49.140  1
338319  99.304  -70.915  49.091  1
338320  99.336  -70.932  49.044  1
338321  99.368  -70.948  48.999  1
338322  99.400  -70.964  48.952  1
338323  99.432  -70.976  48.909  1
338324  99.465  -70.987  48.867  1
338325  99.499  -70.991  48.826  1
338326  99.535  -70.994  48.784  1
338327  99.570  -70.997  48.745  1
338328  99.605  -71.000  48.706  1
338329  99.640  -71.003  48.668  1
338330  99.675  -71.006  48.632  1
338331  99.710  -71.009  48.597  1
338332  99.748  -71.014  48.564  1
338333  99.788  -71.021  48.531  1
338334  99.832  -71.036  48.498  1
338335  99.870  -71.051  48.464  1
338336  99.909  -71.066  48.429  1
338337  99.947  -71.081  48.393  1
338338  99.986  -71.096  48.356  1
338339  100.025  -71.111  48.315  1
338340  100.063  -71.130  48.274  1
338341  100.102  -71.149  48.230  1
338342  100.140  -71.168  48.184  1
338343  100.178  -71.187  48.137  1
338344  100.216  -71.205  48.090  1
338345  100.254  -71.224  48.044  1
338346  100.292  -71.243  47.999  1
338347  100.331  -71.262  47.953  1
338348  100.369  -71.281  47.909  1
338349  100.401  -71.298  47.869  1
338350  100.425  -71.313  47.828  1
338351  100.449  -71.329  47.787  1
338352  100.473  -71.344  47.747  1
338353  100.497  -71.359  47.707  1
338354  100.522  -71.375  47.667  1
338355  100.546  -71.390  47.627  1
338356  100.580  -71.400  47.591  1
338357  100.618  -71.409  47.554  1
338358  100.656  -71.418  47.517  1
338359  100.694  -71.426  47.481  1
338360  100.731  -71.435  47.444  1
338361  100.769  -71.444  47.407  1
338362  100.807  -71.453  47.372  1
338363  100.870  -71.469  47.337  1
338364  100.937  -71.486  47.302  1
338365  101.004  -71.503  47.267  1
338366  101.071  -71.521  47.233  1
338367  101.138  -71.538  47.198  1
338368  101.170  -71.553  47.163  1
338369  101.187  -71.568  47.128  1
338370  101.203  -71.583  47.094  1
338371  101.219  -71.597  47.059  1
338372  101.236  -71.612  47.024  1
338373  101.252  -71.627  46.989  1
338374  101.269  -71.641  46.952  1
338375  101.302  -71.649  46.916  1
338376  101.337  -71.655  46.880  1
338377  101.374  -71.661  46.843  1
338378  101.410  -71.667  46.805  1
338379  101.446  -71.672  46.767  1
338380  101.482  -71.679  46.729  1
338381  101.518  -71.685  46.691  1
338382  101.554  -71.691  46.654  1
338383  101.590  -71.697  46.616  1
338384  101.626  -71.703  46.578  1
338385  101.662  -71.710  46.539  1
338386  101.697  -71.722  46.500  1
338387  101.738  -71.738  46.462  1
338388  101.780  -71.756  46.422  1
338389  101.822  -71.773  46.383  1
338390  101.865  -71.791  46.344  1
338391  101.906  -71.808  46.305  1
338392  101.943  -71.827  46.266  1
338393  101.972  -71.847  46.226  1
338394  101.986  -71.846  46.186  1
338395  101.988  -71.838  46.145  1
338396  101.990  -71.831  46.105  1
338397  101.992  -71.823  46.065  1
338398  102.005  -71.819  46.027  1
338399  102.035  -71.820  45.989  1
338400  102.065  -71.822  45.954  1
338401  102.095  -71.824  45.918  1
338402  102.125  -71.826  45.883  1
338403  102.155  -71.827  45.848  1
338404  102.185  -71.829  45.814  1
338405  102.215  -71.830  45.780  1
338406  102.245  -71.832  45.747  1
338407  102.275  -71.833  45.715  1
338408  102.305  -71.835  45.682  1
338409  102.335  -71.836  45.649  1
338410  102.365  -71.838  45.616  1
338797  91.798  -70.375  55.222  3
338798  91.829  -70.385  55.215  3
338799  91.860  -70.396  55.208  3
338800  91.900  -70.413  55.202  3
338801  91.959  -70.442  55.195  3
338802  92.012  -70.493  55.188  3
338803  92.063  -70.489  55.180  3
338804  92.113  -70.465  55.173  3
338805  92.164  -70.441  55.166  3
338806  92.215  -70.416  55.160  3
338807  92.266  -70.392  55.153  3
338808  92.307  -70.384  55.147  3
338809  92.344  -70.381  55.139  3
338810  92.381  -70.378  55.130  3
338811  92.418  -70.375  55.123  3
338812  92.456  -70.372  55.117  3
338813  92.493  -70.368  55.112  3
338814  92.530  -70.364  55.107  3
338815  92.567  -70.362  55.099  3
338816  92.602  -70.362  55.088  3
338817  92.639  -70.361  55.075  3
338818  92.684  -70.358  55.052  3
338819  92.729  -70.357  55.022  3
338820  92.775  -70.356  54.991  3
338821  92.821  -70.355  54.963  3
338822  92.853  -70.345  54.932  3
338823  92.889  -70.332  54.897  3
338824  92.945  -70.319  54.856  3
338825  92.997  -70.303  54.807  3
338826  93.034  -70.276  54.756  3
338827  93.070  -70.249  54.703  3
338828  93.100  -70.237  54.649  3
338829  93.130  -70.229  54.597  3
338830  93.158  -70.221  54.542  3
338831  93.187  -70.213  54.492  3
338832  93.216  -70.206  54.444  3
338833  93.245  -70.198  54.399  3
338834  93.274  -70.190  54.355  3
338835  93.303  -70.183  54.312  3
338836  93.332  -70.175  54.272  3
338837  93.360  -70.168  54.234  3
338838  93.390  -70.160  54.196  3
338839  93.418  -70.152  54.161  3
338840  93.447  -70.145  54.125  3
338885  94.847  -70.004  52.847  1
338886  94.881  -70.005  52.838  1
338887  94.913  -70.005  52.832  1
338888  94.947  -70.006  52.827  1
338889  94.979  -70.007  52.824  1
338890  95.013  -70.008  52.822  1
338891  95.045  -70.008  52.822  1
338892  95.078  -70.009  52.824  1
338893  95.111  -70.009  52.828  1
338894  95.144  -70.010  52.835  1
338895  95.177  -70.011  52.845  1
338896  95.210  -70.011  52.856  1
338897  95.243  -70.012  52.867  1
338898  95.276  -70.013  52.874  1
338899  95.321  -70.002  52.876  1
338900  95.358  -69.993  52.874  1
338901  95.393  -69.986  52.867  1
338902  95.429  -69.977  52.857  1
338903  95.464  -69.969  52.848  1
338904  95.499  -69.961  52.840  1
338905  95.520  -69.964  52.835  1
338906  95.539  -69.969  52.832  1
338907  95.558  -69.974  52.832  1
338908  95.590  -69.986  52.836  1
338909  95.621  -69.998  52.836  1
338910  95.653  -70.010  52.827  1
338911  95.684  -70.021  52.807  1
338912  95.716  -70.033  52.780  1
338913  95.740  -70.047  52.754  1
338914  95.760  -70.062  52.728  1
338915  95.780  -70.077  52.699  1
338916  95.801  -70.092  52.672  1
338917  95.821  -70.106  52.650  1
338918  95.841  -70.121  52.632  1
338919  95.864  -70.134  52.617  1
338920  95.890  -70.143  52.604  1
338921  95.921  -70.149  52.585  1
338922  95.952  -70.154  52.564  1
338923  95.982  -70.159  52.543  1
338924  96.013  -70.165  52.523  1
338925  96.044  -70.170  52.499  1
338926  96.075  -70.175  52.471  1
338927  96.105  -70.181  52.443  1
338928  96.136  -70.187  52.419  1
338929  96.167  -70.192  52.397  1
338930  96.197  -70.200  52.376  1
338931  96.226  -70.212  52.357  1
338932  96.255  -70.224  52.339  1
338933  96.288  -70.234  52.322  1
338934  96.323  -70.243  52.308  1
338935  96.359  -70.253  52.294  1
338936  96.394  -70.262  52.281  1
338937  96.430  -70.271  52.269  1
338938  96.465  -70.280  52.262  1
338939  96.501  -70.290  52.253  1
338940  96.537  -70.299  52.244  1
338941  96.579  -70.301  52.233  1
338942  96.623  -70.308  52.218  1
338943  96.667  -70.315  52.203  1
338944  96.711  -70.321  52.190  1
338945  96.755  -70.328  52.177  1
338946  96.799  -70.334  52.167  1
338947  96.838  -70.347  52.166  1
338948  96.876  -70.362  52.168  1
338949  96.914  -70.377  52.171  1
338950  96.953  -70.389  52.172  1
338951  96.991  -70.398  52.172  1
338952  97.029  -70.407  52.168  1
338953  97.068  -70.416  52.159  1
338954  97.104  -70.422  52.144  1
338955  97.142  -70.430  52.123  1
338956  97.180  -70.438  52.101  1
338957  97.219  -70.447  52.077  1
338958  97.248  -70.461  52.051  1
338959  97.272  -70.478  52.022  1
338960  97.300  -70.500  51.990  1
338961  97.329  -70.522  51.957  1
338962  97.355  -70.541  51.927  1
338963  97.373  -70.557  51.899  1
338964  97.391  -70.571  51.873  1
338965  97.409  -70.586  51.845  1
338966  97.427  -70.601  51.814  1
338967  97.448  -70.612  51.780  1
338968  97.472  -70.619  51.745  1
338969  97.505  -70.623  51.709  1
338970  97.532  -70.628  51.672  1
338971  97.560  -70.632  51.635  1
338972  97.593  -70.628  51.593  1
338973  97.628  -70.623  51.554  1
338974  97.663  -70.617  51.514  1
338975  97.696  -70.618  51.473  1
338976  97.730  -70.616  51.434  1
338977  97.764  -70.615  51.392  1
338978  97.799  -70.613  51.348  1
338979  97.833  -70.613  51.303  1
338980  97.867  -70.611  51.259  1
338981  97.903  -70.610  51.216  1
338982  97.941  -70.611  51.172  1
338983  97.980  -70.612  51.126  1
338984  98.017  -70.613  51.081  1
338985  98.056  -70.613  51.032  1
338986  98.093  -70.613  50.981  1
338987  98.131  -70.613  50.930  1
338988  98.164  -70.609  50.878  1
338989  98.198  -70.604  50.827  1
338990  98.231  -70.599  50.779  1
338991  98.265  -70.594  50.731  1
338992  98.301  -70.601  50.682  1
338993  98.337  -70.608  50.632  1
338994  98.373  -70.615  50.579  1
338995  98.409  -70.622  50.523  1
338996  98.445  -70.629  50.465  1
338997  98.484  -70.633  50.407  1
338998  98.523  -70.635  50.346  1
338999  98.563  -70.638  50.285  1
339000  98.603  -70.641  50.225  1
339001  98.643  -70.644  50.163  1
339002  98.683  -70.647  50.099  1
339003  98.722  -70.650  50.036  1
339004  98.762  -70.653  49.974  1
339005  98.801  -70.660  49.911  1
339006  98.839  -70.670  49.849  1
339007  98.877  -70.679  49.791  1
339008  98.916  -70.688  49.733  1
339009  98.957  -70.701  49.675  1
339010  98.994  -70.712  49.616  1
339011  99.027  -70.727  49.557  1
339012  99.059  -70.744  49.500  1
339013  99.091  -70.760  49.445  1
339014  99.123  -70.777  49.391  1
339015  99.155  -70.794  49.339  1
339016  99.187  -70.811  49.288  1
339017  99.219  -70.827  49.238  1
339018  99.251  -70.844  49.189  1
339019  99.283  -70.861  49.140  1
339020  99.314  -70.877  49.093  1
339021  99.347  -70.894  49.046  1
339022  99.378  -70.911  49.001  1
339023  99.411  -70.925  48.956  1
339024  99.443  -70.937  48.913  1
339025  99.476  -70.948  48.872  1
339026  99.510  -70.954  48.832  1
339027  99.545  -70.957  48.792  1
339028  99.580  -70.960  48.753  1
339029  99.615  -70.963  48.716  1
339030  99.650  -70.966  48.680  1
339031  99.685  -70.969  48.645  1
339032  99.720  -70.972  48.611  1
339033  99.756  -70.975  48.578  1
339034  99.791  -70.979  48.547  1
339035  99.833  -70.989  48.516  1
339036  99.871  -71.004  48.483  1
339037  99.910  -71.019  48.448  1
339038  99.948  -71.037  48.411  1
339039  99.987  -71.056  48.372  1
339040  100.025  -71.075  48.330  1
339041  100.063  -71.094  48.287  1
339042  100.101  -71.113  48.242  1
339043  100.139  -71.132  48.195  1
339044  100.177  -71.151  48.150  1
339045  100.216  -71.169  48.103  1
339046  100.254  -71.188  48.058  1
339047  100.292  -71.207  48.013  1
339048  100.330  -71.226  47.969  1
339049  100.368  -71.245  47.925  1
339050  100.394  -71.261  47.884  1
339051  100.418  -71.276  47.844  1
339052  100.442  -71.291  47.803  1
339053  100.467  -71.307  47.763  1
339054  100.491  -71.322  47.724  1
339055  100.524  -71.333  47.683  1
339056  100.562  -71.342  47.644  1
339057  100.600  -71.350  47.608  1
339058  100.637  -71.359  47.571  1
339059  100.675  -71.368  47.534  1
339060  100.712  -71.377  47.498  1
339061  100.750  -71.385  47.461  1
339062  100.787  -71.394  47.424  1
339063  100.825  -71.403  47.389  1
339064  100.877  -71.415  47.355  1
339065  100.945  -71.433  47.321  1
339066  101.011  -71.450  47.286  1
339067  101.078  -71.468  47.252  1
339068  101.143  -71.484  47.218  1
339069  101.173  -71.497  47.183  1
339070  101.192  -71.522  47.149  1
339071  101.212  -71.547  47.115  1
339072  101.232  -71.569  47.080  1
339073  101.248  -71.585  47.045  1
339074  101.264  -71.599  47.009  1
339075  101.281  -71.613  46.972  1
339076  101.316  -71.620  46.935  1
339077  101.352  -71.626  46.898  1
339078  101.388  -71.632  46.860  1
339079  101.424  -71.638  46.822  1
339080  101.460  -71.644  46.782  1
339081  101.496  -71.650  46.743  1
339082  101.532  -71.656  46.704  1
339083  101.568  -71.662  46.665  1
339084  101.604  -71.668  46.627  1
339085  101.640  -71.673  46.589  1
339086  101.676  -71.679  46.550  1
339087  101.713  -71.690  46.509  1
339088  101.755  -71.707  46.470  1
339089  101.798  -71.725  46.430  1
339090  101.839  -71.742  46.390  1
339091  101.882  -71.760  46.350  1
339092  101.923  -71.777  46.312  1
339093  101.962  -71.795  46.272  1
339094  101.972  -71.795  46.232  1
339095  101.974  -71.787  46.191  1
339096  101.976  -71.779  46.151  1
339097  101.978  -71.772  46.111  1
339098  101.989  -71.767  46.071  1
339099  102.019  -71.769  46.033  1
339100  102.049  -71.770  45.996  1
339101  102.079  -71.772  45.961  1
339102  102.109  -71.773  45.925  1
339103  102.139  -71.775  45.889  1
339104  102.169  -71.776  45.855  1
339105  102.199  -71.778  45.820  1
339106  102.229  -71.779  45.787  1
339107  102.259  -71.781  45.754  1
339108  102.289  -71.782  45.721  1
339109  102.319  -71.784  45.689  1
339498  91.786  -70.343  55.218  3
339499  91.817  -70.353  55.210  3
339500  91.848  -70.364  55.204  3
339501  91.894  -70.385  55.198  3
339502  91.953  -70.414  55.192  3
339503  92.005  -70.468  55.184  3
339504  92.056  -70.460  55.176  3
339505  92.106  -70.436  55.169  3
339506  92.157  -70.411  55.162  3
339507  92.208  -70.387  55.156  3
339508  92.259  -70.362  55.149  3
339509  92.308  -70.334  55.142  3
339510  92.345  -70.330  55.135  3
339511  92.383  -70.327  55.128  3
339512  92.419  -70.325  55.123  3
339513  92.455  -70.324  55.120  3
339514  92.490  -70.324  55.117  3
339515  92.526  -70.323  55.113  3
339516  92.561  -70.323  55.106  3
339517  92.597  -70.322  55.097  3
339518  92.632  -70.322  55.084  3
339519  92.675  -70.317  55.064  3
339520  92.720  -70.314  55.039  3
339521  92.766  -70.312  55.011  3
339522  92.811  -70.312  54.984  3
339523  92.852  -70.308  54.952  3
339524  92.882  -70.294  54.916  3
339525  92.939  -70.282  54.873  3
339526  92.996  -70.269  54.823  3
339527  93.036  -70.244  54.772  3
339528  93.072  -70.217  54.720  3
339529  93.108  -70.191  54.668  3
339530  93.137  -70.184  54.616  3
339531  93.166  -70.175  54.558  3
339532  93.195  -70.168  54.505  3
339533  93.224  -70.160  54.456  3
339534  93.253  -70.152  54.410  3
339535  93.281  -70.145  54.366  3
339536  93.310  -70.137  54.323  3
339537  93.339  -70.130  54.283  3
339538  93.368  -70.122  54.244  3
339539  93.397  -70.115  54.206  3
339540  93.426  -70.107  54.169  3
339541  93.454  -70.099  54.134  3
339542  93.484  -70.091  54.098  3
339585  94.835  -69.983  52.857  1
339586  94.867  -69.984  52.846  1
339587  94.901  -69.985  52.836  1
339588  94.933  -69.986  52.829  1
339589  94.967  -69.986  52.825  1
339590  95.000  -69.987  52.822  1
339591  95.033  -69.988  52.821  1
339592  95.066  -69.989  52.821  1
339593  95.099  -69.990  52.825  1
339594  95.132  -69.990  52.831  1
339595  95.165  -69.991  52.841  1
339596  95.198  -69.992  52.856  1
339597  95.231  -69.993  52.874  1
339598  95.264  -69.993  52.890  1
339599  95.297  -69.993  52.898  1
339600  95.339  -69.982  52.893  1
339601  95.375  -69.974  52.887  1
339602  95.410  -69.965  52.880  1
339603  95.445  -69.958  52.871  1
339604  95.481  -69.949  52.860  1
339605  95.516  -69.941  52.850  1
339606  95.544  -69.939  52.843  1
339607  95.562  -69.944  52.839  1
339608  95.581  -69.949  52.837  1
339609  95.600  -69.954  52.840  1
339610  95.631  -69.965  52.840  1
339611  95.663  -69.977  52.833  1
339612  95.694  -69.990  52.816  1
339613  95.721  -70.002  52.790  1
339614  95.741  -70.017  52.764  1
339615  95.761  -70.032  52.737  1
339616  95.782  -70.046  52.710  1
339617  95.804  -70.060  52.683  1
339618  95.830  -70.070  52.661  1
339619  95.856  -70.079  52.643  1
339620  95.882  -70.089  52.628  1
339621  95.908  -70.099  52.615  1
339622  95.937  -70.105  52.596  1
339623  95.968  -70.112  52.575  1
339624  95.999  -70.117  52.555  1
339625  96.029  -70.122  52.536  1
339626  96.060  -70.127  52.511  1
339627  96.091  -70.133  52.482  1
339628  96.121  -70.138  52.454  1
339629  96.153  -70.143  52.431  1
339630  96.182  -70.153  52.408  1
339631  96.211  -70.165  52.386  1
339632  96.240  -70.177  52.366  1
339633  96.268  -70.189  52.348  1
339634  96.301  -70.199  52.330  1
339635  96.336  -70.209  52.316  1
339636  96.372  -70.218  52.303  1
339637  96.408  -70.227  52.290  1
339638  96.444  -70.236  52.279  1
339639  96.479  -70.246  52.271  1
339640  96.515  -70.255  52.264  1
339641  96.554  -70.255  52.256  1
339642  96.595  -70.253  52.246  1
339643  96.638  -70.258  52.232  1
339644  96.682  -70.265  52.217  1
339645  96.726  -70.271  52.203  1
339646  96.769  -70.278  52.189  1
339647  96.808  -70.293  52.178  1
339648  96.846  -70.309  52.176  1
339649  96.884  -70.323  52.178  1
339650  96.922  -70.338  52.181  1
339651  96.960  -70.352  52.181  1
339652  96.998  -70.361  52.179  1
339653  97.036  -70.370  52.173  1
339654  97.076  -70.381  52.161  1
339655  97.115  -70.391  52.145  1
339656  97.154  -70.399  52.123  1
339657  97.191  -70.406  52.100  1
339658  97.230  -70.415  52.077  1
339659  97.255  -70.431  52.053  1
339660  97.280  -70.450  52.024  1
339661  97.304  -70.468  51.993  1
339662  97.332  -70.489  51.962  1
339663  97.361  -70.510  51.932  1
339664  97.379  -70.525  51.903  1
339665  97.397  -70.541  51.876  1
339666  97.415  -70.555  51.847  1
339667  97.433  -70.570  51.815  1
339668  97.451  -70.585  51.781  1
339669  97.473  -70.596  51.746  1
339670  97.502  -70.600  51.710  1
339671  97.535  -70.597  51.672  1
339672  97.570  -70.591  51.633  1
339673  97.605  -70.585  51.589  1
339674  97.641  -70.580  51.547  1
339675  97.675  -70.576  51.506  1
339676  97.708  -70.579  51.464  1
339677  97.742  -70.577  51.425  1
339678  97.776  -70.576  51.383  1
339679  97.810  -70.574  51.339  1
339680  97.845  -70.573  51.292  1
339681  97.879  -70.572  51.245  1
339682  97.913  -70.570  51.201  1
339683  97.947  -70.569  51.156  1
339684  97.981  -70.567  51.111  1
339685  98.017  -70.566  51.066  1
339686  98.055  -70.567  51.017  1
339687  98.093  -70.568  50.968  1
339688  98.131  -70.569  50.918  1
339689  98.169  -70.569  50.867  1
339690  98.205  -70.567  50.816  1
339691  98.238  -70.563  50.766  1
339692  98.272  -70.557  50.715  1
339693  98.306  -70.556  50.665  1
339694  98.342  -70.563  50.616  1
339695  98.378  -70.569  50.565  1
339696  98.415  -70.576  50.511  1
339697  98.451  -70.583  50.455  1
339698  98.491  -70.585  50.399  1
339699  98.530  -70.588  50.338  1
339700  98.570  -70.591  50.278  1
339701  98.610  -70.594  50.217  1
339702  98.650  -70.597  50.154  1
339703  98.690  -70.600  50.091  1
339704  98.728  -70.609  50.029  1
339705  98.766  -70.618  49.967  1
339706  98.804  -70.627  49.905  1
339707  98.843  -70.636  49.845  1
339708  98.880  -70.645  49.787  1
339709  98.920  -70.657  49.730  1
339710  98.961  -70.669  49.671  1
339711  99.000  -70.680  49.612  1
339712  99.036  -70.691  49.553  1
339713  99.070  -70.706  49.496  1
339714  99.101  -70.723  49.442  1
339715  99.134  -70.739  49.389  1
339716  99.165  -70.756  49.338  1
339717  99.198  -70.773  49.286  1
339718  99.229  -70.789  49.236  1
339719  99.262  -70.806  49.188  1
339720  99.293  -70.823  49.140  1
339721  99.326  -70.839  49.094  1
339722  99.357  -70.856  49.048  1
339723  99.390  -70.873  49.004  1
339724  99.422  -70.886  48.960  1
339725  99.454  -70.898  48.918  1
339726  99.486  -70.910  48.878  1
339727  99.520  -70.917  48.839  1
339728  99.555  -70.920  48.800  1
339729  99.590  -70.923  48.763  1
339730  99.626  -70.927  48.726  1
339731  99.660  -70.930  48.691  1
339732  99.696  -70.933  48.659  1
339733  99.731  -70.936  48.625  1
339734  99.766  -70.939  48.593  1
339735  99.801  -70.942  48.563  1
339736  99.836  -70.946  48.532  1
339737  99.872  -70.964  48.500  1
339738  99.910  -70.983  48.464  1
339739  99.948  -71.002  48.426  1
339740  99.986  -71.021  48.385  1
339741  100.025  -71.039  48.342  1
339742  100.063  -71.058  48.298  1
339743  100.101  -71.077  48.252  1
339744  100.139  -71.096  48.206  1
339745  100.177  -71.115  48.162  1
339746  100.215  -71.133  48.117  1
339747  100.254  -71.152  48.072  1
339748  100.292  -71.171  48.028  1
339749  100.330  -71.190  47.985  1
339750  100.363  -71.208  47.942  1
339751  100.388  -71.223  47.901  1
339752  100.412  -71.239  47.861  1
339753  100.436  -71.254  47.822  1
339754  100.468  -71.266  47.781  1
339755  100.505  -71.274  47.741  1
339756  100.543  -71.283  47.701  1
339757  100.580  -71.292  47.662  1
339758  100.618  -71.300  47.626  1
339759  100.656  -71.309  47.590  1
339760  100.693  -71.318  47.553  1
339761  100.731  -71.327  47.516  1
339762  100.769  -71.335  47.480  1
339763  100.807  -71.344  47.444  1
339764  100.844  -71.353  47.409  1
339765  100.885  -71.362  47.375  1
339766  100.952  -71.380  47.341  1
339767  101.019  -71.397  47.308  1
339768  101.086  -71.414  47.275  1
339769  101.136  -71.429  47.242  1
339770  101.166  -71.440  47.209  1
339771  101.192  -71.457  47.177  1
339772  101.212  -71.482  47.142  1
339773  101.232  -71.507  47.108  1
339774  101.252  -71.532  47.073  1
339775  101.272  -71.556  47.036  1
339776  101.293  -71.581  47.000  1
339777  101.330  -71.588  46.962  1
339778  101.366  -71.593  46.922  1
339779  101.402  -71.598  46.883  1
339780  101.438  -71.603  46.843  1
339781  101.474  -71.608  46.802  1
339782  101.510  -71.613  46.761  1
339783  101.545  -71.619  46.721  1
339784  101.581  -71.623  46.681  1
339785  101.617  -71.629  46.640  1
339786  101.653  -71.634  46.601  1
339787  101.689  -71.639  46.561  1
339788  101.726  -71.647  46.520  1
339789  101.768  -71.665  46.480  1
339790  101.811  -71.684  46.440  1
339791  101.853  -71.702  46.399  1
339792  101.896  -71.721  46.358  1
339793  101.939  -71.739  46.318  1
339794  101.958  -71.743  46.277  1
339795  101.960  -71.735  46.237  1
339796  101.962  -71.728  46.196  1
339797  101.964  -71.720  46.156  1
339798  101.973  -71.715  46.117  1
339799  102.003  -71.716  46.078  1
339800  102.033  -71.718  46.039  1
339801  102.063  -71.719  46.003  1
339802  102.093  -71.721  45.968  1
339803  102.123  -71.722  45.931  1
339804  102.153  -71.724  45.896  1
339805  102.183  -71.726  45.861  1
339806  102.213  -71.727  45.827  1
339807  102.243  -71.729  45.794  1
339808  102.273  -71.731  45.761  1
339809  102.303  -71.732  45.728  1
340200  91.805  -70.321  55.207  3
340201  91.836  -70.331  55.200  3
340202  91.888  -70.356  55.194  3
340203  91.947  -70.386  55.188  3
340204  91.998  -70.444  55.182  3
340205  92.049  -70.431  55.174  3
340206  92.100  -70.406  55.166  3
340207  92.150  -70.382  55.159  3
340208  92.201  -70.358  55.152  3
340209  92.252  -70.333  55.145  3
340210  92.304  -70.296  55.138  3
340211  92.343  -70.284  55.131  3
340212  92.378  -70.285  55.125  3
340213  92.414  -70.285  55.121  3
340214  92.449  -70.284  55.119  3
340215  92.485  -70.284  55.117  3
340216  92.520  -70.284  55.113  3
340217  92.556  -70.284  55.107  3
340218  92.591  -70.283  55.099  3
340219  92.627  -70.283  55.088  3
340220  92.668  -70.279  55.071  3
340221  92.712  -70.274  55.049  3
340222  92.756  -70.269  55.024  3
340223  92.801  -70.268  54.998  3
340224  92.847  -70.268  54.966  3
340225  92.878  -70.257  54.931  3
340226  92.932  -70.244  54.890  3
340227  92.989  -70.231  54.841  3
340228  93.038  -70.213  54.791  3
340229  93.074  -70.186  54.741  3
340230  93.111  -70.159  54.689  3
340231  93.144  -70.137  54.635  3
340232  93.174  -70.130  54.574  3
340233  93.202  -70.122  54.519  3
340234  93.231  -70.115  54.468  3
340235  93.260  -70.107  54.420  3
340236  93.289  -70.099  54.376  3
340237  93.318  -70.092  54.334  3
340238  93.347  -70.084  54.293  3
340239  93.375  -70.077  54.254  3
340240  93.405  -70.069  54.215  3
340241  93.433  -70.061  54.179  3
340242  93.462  -70.053  54.143  3
340243  93.491  -70.046  54.107  3
340244  93.520  -70.038  54.071  3
340286  94.855  -69.964  52.856  1
340287  94.888  -69.965  52.844  1
340288  94.921  -69.966  52.834  1
340289  94.954  -69.966  52.827  1
340290  94.987  -69.967  52.823  1
340291  95.020  -69.968  52.820  1
340292  95.053  -69.968  52.820  1
340293  95.086  -69.969  52.821  1
340294  95.119  -69.970  52.826  1
340295  95.152  -69.971  52.834  1
340296  95.185  -69.971  52.847  1
340297  95.218  -69.972  52.867  1
340298  95.251  -69.973  52.890  1
340299  95.284  -69.974  52.911  1
340300  95.321  -69.970  52.922  1
340301  95.356  -69.961  52.914  1
340302  95.391  -69.953  52.906  1
340303  95.426  -69.946  52.896  1
340304  95.462  -69.937  52.885  1
340305  95.497  -69.929  52.873  1
340306  95.533  -69.921  52.862  1
340307  95.567  -69.914  52.853  1
340308  95.586  -69.918  52.847  1
340309  95.605  -69.924  52.843  1
340310  95.623  -69.928  52.844  1
340311  95.642  -69.933  52.843  1
340312  95.674  -69.945  52.836  1
340313  95.702  -69.957  52.820  1
340314  95.723  -69.972  52.796  1
340315  95.744  -69.986  52.771  1
340316  95.770  -69.996  52.745  1
340317  95.796  -70.005  52.719  1
340318  95.822  -70.015  52.695  1
340319  95.848  -70.024  52.673  1
340320  95.875  -70.034  52.654  1
340321  95.901  -70.044  52.638  1
340322  95.926  -70.053  52.623  1
340323  95.953  -70.063  52.605  1
340324  95.984  -70.068  52.586  1
340325  96.015  -70.074  52.567  1
340326  96.045  -70.079  52.548  1
340327  96.076  -70.084  52.521  1
340328  96.107  -70.090  52.494  1
340329  96.137  -70.096  52.467  1
340330  96.167  -70.106  52.444  1
340331  96.196  -70.118  52.422  1
340332  96.225  -70.130  52.398  1
340333  96.253  -70.142  52.376  1
340334  96.283  -70.154  52.357  1
340335  96.315  -70.165  52.340  1
340336  96.350  -70.174  52.325  1
340337  96.386  -70.183  52.312  1
340338  96.421  -70.192  52.300  1
340339  96.457  -70.202  52.290  1
340340  96.493  -70.211  52.281  1
340341  96.532  -70.212  52.274  1
340342  96.572  -70.210  52.266  1
340343  96.613  -70.209  52.257  1
340344  96.654  -70.208  52.245  1
340345  96.697  -70.215  52.231  1
340346  96.739  -70.225  52.216  1
340347  96.777  -70.240  52.202  1
340348  96.815  -70.254  52.189  1
340349  96.854  -70.269  52.186  1
340350  96.891  -70.284  52.188  1
340351  96.930  -70.299  52.191  1
340352  96.967  -70.314  52.190  1
340353  97.006  -70.324  52.184  1
340354  97.046  -70.335  52.174  1
340355  97.086  -70.347  52.160  1
340356  97.126  -70.359  52.142  1
340357  97.165  -70.367  52.118  1
340358  97.203  -70.375  52.094  1
340359  97.239  -70.384  52.071  1
340360  97.263  -70.402  52.050  1
340361  97.287  -70.420  52.023  1
340362  97.311  -70.438  51.993  1
340363  97.336  -70.456  51.963  1
340364  97.365  -70.478  51.935  1
340365  97.385  -70.494  51.905  1
340366  97.403  -70.510  51.878  1
340367  97.421  -70.525  51.847  1
340368  97.439  -70.539  51.814  1
340369  97.457  -70.554  51.781  1
340370  97.477  -70.565  51.745  1
340371  97.513  -70.560  51.710  1
340372  97.548  -70.554  51.672  1
340373  97.583  -70.549  51.631  1
340374  97.618  -70.543  51.583  1
340375  97.653  -70.538  51.538  1
340376  97.687  -70.537  51.494  1
340377  97.719  -70.538  51.453  1
340378  97.753  -70.538  51.414  1
340379  97.788  -70.536  51.374  1
340380  97.822  -70.535  51.330  1
340381  97.856  -70.534  51.283  1
340382  97.890  -70.532  51.234  1
340383  97.924  -70.531  51.185  1
340384  97.958  -70.529  51.140  1
340385  97.993  -70.528  51.096  1
340386  98.027  -70.526  51.051  1
340387  98.061  -70.525  51.002  1
340388  98.095  -70.524  50.956  1
340389  98.131  -70.523  50.908  1
340390  98.169  -70.523  50.859  1
340391  98.207  -70.524  50.806  1
340392  98.245  -70.525  50.753  1
340393  98.279  -70.521  50.700  1
340394  98.313  -70.516  50.648  1
340395  98.348  -70.517  50.599  1
340396  98.383  -70.524  50.549  1
340397  98.420  -70.531  50.498  1
340398  98.457  -70.536  50.444  1
340399  98.497  -70.538  50.388  1
340400  98.537  -70.541  50.329  1
340401  98.577  -70.544  50.267  1
340402  98.617  -70.547  50.205  1
340403  98.655  -70.557  50.143  1
340404  98.693  -70.566  50.081  1
340405  98.731  -70.575  50.020  1
340406  98.770  -70.584  49.959  1
340407  98.807  -70.594  49.899  1
340408  98.846  -70.603  49.841  1
340409  98.884  -70.612  49.784  1
340410  98.925  -70.624  49.726  1
340411  98.966  -70.636  49.666  1
340412  99.006  -70.649  49.607  1
340413  99.042  -70.660  49.549  1
340414  99.079  -70.670  49.493  1
340415  99.113  -70.685  49.440  1
340416  99.144  -70.701  49.387  1
340417  99.177  -70.718  49.336  1
340418  99.208  -70.735  49.285  1
340419  99.240  -70.751  49.236  1
340420  99.272  -70.768  49.188  1
340421  99.304  -70.785  49.141  1
340422  99.336  -70.801  49.095  1
340423  99.368  -70.818  49.050  1
340424  99.400  -70.835  49.006  1
340425  99.432  -70.848  48.963  1
340426  99.465  -70.859  48.924  1
340427  99.497  -70.871  48.885  1
340428  99.531  -70.880  48.846  1
340429  99.566  -70.883  48.809  1
340430  99.601  -70.886  48.773  1
340431  99.636  -70.889  48.737  1
340432  99.671  -70.892  48.703  1
340433  99.706  -70.895  48.673  1
340434  99.741  -70.898  48.640  1
340435  99.776  -70.901  48.609  1
340436  99.813  -70.908  48.579  1
340437  99.848  -70.916  48.549  1
340438  99.880  -70.926  48.516  1
340439  99.915  -70.942  48.478  1
340440  99.952  -70.963  48.438  1
340441  99.988  -70.983  48.396  1
340442  100.025  -71.003  48.353  1
340443  100.062  -71.022  48.308  1
340444  100.101  -71.041  48.265  1
340445  100.139  -71.060  48.222  1
340446  100.177  -71.079  48.179  1
340447  100.215  -71.098  48.135  1
340448  100.254  -71.117  48.092  1
340449  100.292  -71.136  48.049  1
340450  100.330  -71.155  48.006  1
340451  100.357  -71.171  47.963  1
340452  100.381  -71.186  47.922  1
340453  100.411  -71.199  47.882  1
340454  100.449  -71.207  47.841  1
340455  100.486  -71.216  47.800  1
340456  100.524  -71.224  47.761  1
340457  100.561  -71.234  47.722  1
340458  100.599  -71.242  47.683  1
340459  100.637  -71.251  47.647  1
340460  100.675  -71.259  47.610  1
340461  100.712  -71.268  47.574  1
340462  100.750  -71.277  47.537  1
340463  100.787  -71.285  47.500  1
340464  100.825  -71.294  47.465  1
340465  100.863  -71.303  47.431  1
340466  100.900  -71.312  47.397  1
340467  100.959  -71.326  47.364  1
340468  101.025  -71.343  47.332  1
340469  101.093  -71.361  47.299  1
340470  101.129  -71.373  47.267  1
340471  101.159  -71.384  47.235  1
340472  101.189  -71.396  47.202  1
340473  101.211  -71.418  47.170  1
340474  101.232  -71.443  47.136  1
340475  101.251  -71.468  47.100  1
340476  101.271  -71.492  47.063  1
340477  101.301  -71.513  47.027  1
340478  101.339  -71.528  46.988  1
340479  101.378  -71.543  46.947  1
340480  101.415  -71.553  46.906  1
340481  101.451  -71.558  46.864  1
340482  101.487  -71.563  46.822  1
340483  101.523  -71.569  46.780  1
340484  101.558  -71.573  46.738  1
340485  101.594  -71.578  46.697  1
340486  101.630  -71.584  46.655  1
340487  101.666  -71.588  46.614  1
340488  101.702  -71.594  46.573  1
340489  101.740  -71.603  46.533  1
340490  101.783  -71.622  46.491  1
340491  101.825  -71.641  46.450  1
340492  101.868  -71.659  46.409  1
340493  101.913  -71.680  46.365  1
340494  101.944  -71.692  46.323  1
340495  101.946  -71.685  46.282  1
340496  101.948  -71.677  46.241  1
340497  101.950  -71.669  46.202  1
340498  101.957  -71.663  46.161  1
340499  101.987  -71.664  46.123  1
340500  102.017  -71.666  46.084  1
340501  102.047  -71.668  46.046  1
340502  102.077  -71.669  46.010  1
340503  102.107  -71.671  45.974  1
340504  102.137  -71.672  45.938  1
340505  102.167  -71.674  45.903  1
340506  102.197  -71.675  45.868  1
340507  102.227  -71.677  45.833  1
340508  102.257  -71.679  45.800  1
340509  102.287  -71.680  45.767  1
340901  91.793  -70.289  55.204  3
340902  91.824  -70.300  55.198  3
340903  91.882  -70.328  55.192  3
340904  91.941  -70.359  55.186  3
340905  91.991  -70.419  55.179  3
340906  92.042  -70.401  55.172  3
340907  92.093  -70.377  55.164  3
340908  92.144  -70.353  55.157  3
340909  92.194  -70.328  55.150  3
340910  92.245  -70.303  55.142  3
340911  92.296  -70.265  55.135  3
340912  92.336  -70.235  55.126  3
340913  92.372  -70.234  55.120  3
340914  92.408  -70.240  55.116  3
340915  92.444  -70.245  55.114  3
340916  92.479  -70.245  55.113  3
340917  92.514  -70.244  55.110  3
340918  92.550  -70.244  55.104  3
340919  92.585  -70.243  55.097  3
340920  92.621  -70.243  55.089  3
340921  92.661  -70.240  55.074  3
340922  92.705  -70.235  55.054  3
340923  92.748  -70.231  55.030  3
340924  92.792  -70.225  55.005  3
340925  92.838  -70.225  54.975  3
340926  92.877  -70.219  54.942  3
340927  92.926  -70.206  54.904  3
340928  92.982  -70.193  54.858  3
340929  93.039  -70.181  54.809  3
340930  93.076  -70.155  54.759  3
340931  93.113  -70.127  54.708  3
340932  93.149  -70.100  54.651  3
340933  93.181  -70.084  54.590  3
340934  93.210  -70.077  54.532  3
340935  93.238  -70.069  54.479  3
340936  93.268  -70.062  54.430  3
340937  93.296  -70.054  54.386  3
340938  93.325  -70.046  54.343  3
340939  93.354  -70.039  54.302  3
340940  93.383  -70.031  54.264  3
340941  93.412  -70.023  54.225  3
340942  93.441  -70.015  54.189  3
340943  93.470  -70.008  54.152  3
340944  93.499  -70.000  54.116  3
340945  93.528  -69.993  54.080  3
340946  93.556  -69.985  54.044  3
340986  94.842  -69.944  52.867  1
340987  94.876  -69.945  52.854  1
340988  94.908  -69.946  52.843  1
340989  94.942  -69.946  52.833  1
340990  94.974  -69.947  52.826  1
340991  95.007  -69.948  52.822  1
340992  95.040  -69.949  52.819  1
340993  95.073  -69.949  52.820  1
340994  95.106  -69.949  52.822  1
340995  95.139  -69.950  52.827  1
340996  95.172  -69.951  52.837  1
340997  95.204  -69.948  52.854  1
340998  95.235  -69.945  52.877  1
340999  95.267  -69.942  52.905  1
341000  95.299  -69.939  52.930  1
341001  95.333  -69.934  52.943  1
341002  95.370  -69.930  52.937  1
341003  95.406  -69.925  52.926  1
341004  95.442  -69.921  52.914  1
341005  95.478  -69.916  52.901  1
341006  95.514  -69.909  52.887  1
341007  95.549  -69.901  52.875  1
341008  95.585  -69.893  52.864  1
341009  95.610  -69.893  52.856  1
341010  95.628  -69.898  52.851  1
341011  95.647  -69.902  52.849  1
341012  95.666  -69.908  52.846  1
341013  95.684  -69.911  52.839  1
341014  95.710  -69.921  52.825  1
341015  95.737  -69.930  52.801  1
341016  95.763  -69.940  52.777  1
341017  95.789  -69.950  52.754  1
341018  95.815  -69.960  52.730  1
341019  95.841  -69.970  52.707  1
341020  95.867  -69.979  52.685  1
341021  95.893  -69.989  52.665  1
341022  95.919  -69.999  52.649  1
341023  95.945  -70.008  52.633  1
341024  95.971  -70.018  52.614  1
341025  96.000  -70.026  52.597  1
341026  96.031  -70.031  52.579  1
341027  96.061  -70.037  52.559  1
341028  96.092  -70.042  52.532  1
341029  96.123  -70.047  52.505  1
341030  96.152  -70.059  52.479  1
341031  96.181  -70.071  52.458  1
341032  96.209  -70.083  52.436  1
341033  96.238  -70.096  52.411  1
341034  96.267  -70.107  52.387  1
341035  96.296  -70.119  52.368  1
341036  96.328  -70.130  52.350  1
341037  96.364  -70.139  52.335  1
341038  96.399  -70.148  52.322  1
341039  96.435  -70.158  52.310  1
341040  96.471  -70.167  52.299  1
341041  96.509  -70.169  52.290  1
341042  96.550  -70.168  52.283  1
341043  96.590  -70.166  52.275  1
341044  96.630  -70.164  52.266  1
341045  96.671  -70.162  52.254  1
341046  96.709  -70.172  52.241  1
341047  96.747  -70.187  52.227  1
341048  96.785  -70.203  52.212  1
341049  96.823  -70.218  52.197  1
341050  96.861  -70.233  52.193  1
341051  96.899  -70.248  52.194  1
341052  96.937  -70.263  52.196  1
341053  96.975  -70.278  52.194  1
341054  97.015  -70.290  52.186  1
341055  97.055  -70.301  52.172  1
341056  97.096  -70.313  52.154  1
341057  97.137  -70.325  52.133  1
341058  97.176  -70.335  52.108  1
341059  97.214  -70.344  52.085  1
341060  97.247  -70.355  52.064  1
341061  97.271  -70.373  52.044  1
341062  97.295  -70.391  52.017  1
341063  97.319  -70.409  51.989  1
341064  97.343  -70.426  51.961  1
341065  97.368  -70.446  51.934  1
341066  97.391  -70.463  51.906  1
341067  97.409  -70.478  51.877  1
341068  97.427  -70.494  51.844  1
341069  97.448  -70.504  51.809  1
341070  97.469  -70.513  51.774  1
341071  97.491  -70.522  51.737  1
341072  97.525  -70.517  51.702  1
341073  97.561  -70.512  51.665  1
341074  97.595  -70.507  51.623  1
341075  97.631  -70.500  51.575  1
341076  97.666  -70.495  51.527  1
341077  97.699  -70.497  51.482  1
341078  97.731  -70.499  51.441  1
341079  97.765  -70.498  51.402  1
341080  97.799  -70.497  51.364  1
341081  97.833  -70.495  51.322  1
341082  97.867  -70.494  51.276  1
341083  97.901  -70.493  51.227  1
341084  97.936  -70.491  51.177  1
341085  97.970  -70.490  51.128  1
341086  98.004  -70.488  51.080  1
341087  98.038  -70.487  51.033  1
341088  98.073  -70.485  50.986  1
341089  98.107  -70.485  50.941  1
341090  98.141  -70.483  50.897  1
341091  98.175  -70.481  50.850  1
341092  98.210  -70.480  50.800  1
341093  98.244  -70.479  50.746  1
341094  98.283  -70.480  50.691  1
341095  98.320  -70.480  50.636  1
341096  98.354  -70.475  50.582  1
341097  98.389  -70.478  50.531  1
341098  98.425  -70.485  50.479  1
341099  98.464  -70.488  50.425  1
341100  98.504  -70.491  50.369  1
341101  98.544  -70.496  50.310  1
341102  98.582  -70.505  50.249  1
341103  98.620  -70.514  50.189  1
341104  98.658  -70.523  50.129  1
341105  98.697  -70.532  50.069  1
341106  98.735  -70.541  50.010  1
341107  98.773  -70.550  49.952  1
341108  98.811  -70.560  49.894  1
341109  98.849  -70.569  49.836  1
341110  98.888  -70.579  49.779  1
341111  98.929  -70.591  49.721  1
341112  98.970  -70.604  49.662  1
341113  99.010  -70.616  49.603  1
341114  99.048  -70.628  49.546  1
341115  99.085  -70.639  49.491  1
341116  99.121  -70.650  49.437  1
341117  99.155  -70.663  49.386  1
341118  99.187  -70.680  49.334  1
341119  99.219  -70.697  49.284  1
341120  99.251  -70.713  49.236  1
341121  99.283  -70.730  49.188  1
341122  99.315  -70.747  49.141  1
341123  99.347  -70.764  49.096  1
341124  99.379  -70.780  49.052  1
341125  99.411  -70.797  49.009  1
341126  99.443  -70.809  48.967  1
341127  99.476  -70.820  48.929  1
341128  99.508  -70.832  48.891  1
341129  99.541  -70.843  48.853  1
341130  99.576  -70.846  48.817  1
341131  99.611  -70.849  48.781  1
341132  99.646  -70.852  48.747  1
341133  99.682  -70.855  48.716  1
341134  99.716  -70.858  48.686  1
341135  99.752  -70.861  48.655  1
341136  99.789  -70.868  48.624  1
341137  99.826  -70.876  48.594  1
341138  99.860  -70.886  48.565  1
341139  99.892  -70.895  48.530  1
341140  99.924  -70.906  48.492  1
341141  99.959  -70.921  48.451  1
341142  99.995  -70.941  48.409  1
341143  100.032  -70.961  48.367  1
341144  100.068  -70.982  48.323  1
341145  100.105  -71.002  48.281  1
341146  100.141  -71.022  48.240  1
341147  100.177  -71.042  48.198  1
341148  100.215  -71.062  48.155  1
341149  100.253  -71.081  48.113  1
341150  100.291  -71.099  48.071  1
341151  100.326  -71.118  48.028  1
341152  100.354  -71.131  47.986  1
341153  100.392  -71.140  47.945  1
341154  100.429  -71.149  47.904  1
341155  100.467  -71.157  47.863  1
341156  100.505  -71.166  47.822  1
341157  100.543  -71.174  47.782  1
341158  100.580  -71.183  47.743  1
341159  100.618  -71.192  47.705  1
341160  100.655  -71.201  47.669  1
341161  100.693  -71.209  47.632  1
341162  100.731  -71.218  47.595  1
341163  100.768  -71.227  47.559  1
341164  100.806  -71.236  47.523  1
341165  100.844  -71.244  47.488  1
341166  100.882  -71.253  47.454  1
341167  100.919  -71.262  47.420  1
341168  100.966  -71.273  47.388  1
341169  101.033  -71.290  47.356  1
341170  101.092  -71.306  47.324  1
341171  101.122  -71.318  47.292  1
341172  101.152  -71.329  47.260  1
341173  101.182  -71.340  47.226  1
341174  101.211  -71.353  47.196  1
341175  101.231  -71.378  47.162  1
341176  101.251  -71.403  47.127  1
341177  101.271  -71.428  47.090  1
341178  101.308  -71.444  47.052  1
341179  101.346  -71.459  47.013  1
341180  101.385  -71.474  46.972  1
341181  101.423  -71.489  46.930  1
341182  101.462  -71.504  46.886  1
341183  101.500  -71.518  46.843  1
341184  101.536  -71.523  46.799  1
341185  101.571  -71.528  46.756  1
341186  101.608  -71.533  46.714  1
341187  101.643  -71.538  46.671  1
341188  101.679  -71.544  46.629  1
341189  101.715  -71.548  46.588  1
341190  101.754  -71.560  46.548  1
341191  101.797  -71.579  46.504  1
341192  101.839  -71.597  46.461  1
341193  101.889  -71.622  46.416  1
341194  101.934  -71.645  46.371  1
341195  101.933  -71.633  46.329  1
341196  101.935  -71.625  46.288  1
341197  101.936  -71.618  46.247  1
341198  101.941  -71.611  46.208  1
341199  101.971  -71.613  46.168  1
341200  102.000  -71.614  46.130  1
341201  102.031  -71.616  46.091  1
341202  102.060  -71.617  46.053  1
341203  102.091  -71.619  46.017  1
341204  102.121  -71.620  45.980  1
341205  102.150  -71.622  45.944  1
341206  102.181  -71.623  45.909  1
341207  102.210  -71.625  45.875  1
341208  102.241  -71.626  45.840  1
341209  102.270  -71.628  45.807  1
341602  91.781  -70.256  55.203  3
341603  91.818  -70.271  55.196  3
341604  91.876  -70.300  55.191  3
341605  91.934  -70.334  55.185  3
341606  91.985  -70.394  55.178  3
341607  92.035  -70.372  55.170  3
341608  92.086  -70.347  55.162  3
341609  92.137  -70.323  55.155  3
341610  92.188  -70.299  55.147  3
341611  92.238  -70.271  55.139  3
341612  92.287  -70.234  55.132  3
341613  92.326  -70.205  55.123  3
341614  92.365  -70.178  55.115  3
341615  92.402  -70.184  55.109  3
341616  92.437  -70.190  55.104  3
341617  92.473  -70.196  55.102  3
341618  92.509  -70.203  55.099  3
341619  92.545  -70.205  55.094  3
341620  92.580  -70.204  55.089  3
341621  92.616  -70.204  55.082  3
341622  92.653  -70.202  55.070  3
341623  92.697  -70.197  55.051  3
341624  92.741  -70.192  55.027  3
341625  92.785  -70.187  55.003  3
341626  92.829  -70.182  54.977  3
341627  92.873  -70.180  54.949  3
341628  92.919  -70.168  54.916  3
341629  92.976  -70.156  54.874  3
341630  93.032  -70.143  54.825  3
341631  93.078  -70.123  54.776  3
341632  93.115  -70.096  54.723  3
341633  93.151  -70.068  54.665  3
341634  93.188  -70.041  54.604  3
341635  93.217  -70.031  54.545  3
341636  93.246  -70.024  54.489  3
341637  93.275  -70.016  54.439  3
341638  93.304  -70.008  54.395  3
341639  93.333  -70.001  54.352  3
341640  93.362  -69.993  54.311  3
341641  93.391  -69.985  54.273  3
341642  93.419  -69.977  54.235  3
341643  93.448  -69.970  54.198  3
341644  93.477  -69.962  54.162  3
341645  93.506  -69.955  54.125  3
341646  93.535  -69.947  54.090  3
341647  93.564  -69.939  54.054  3
341687  94.862  -69.922  52.869  1
341688  94.894  -69.920  52.856  1
341689  94.925  -69.917  52.844  1
341690  94.957  -69.914  52.834  1
341691  94.988  -69.911  52.827  1
341692  95.020  -69.908  52.823  1
341693  95.051  -69.905  52.820  1
341694  95.083  -69.902  52.820  1
341695  95.114  -69.899  52.823  1
341696  95.146  -69.895  52.830  1
341697  95.177  -69.892  52.840  1
341698  95.209  -69.889  52.858  1
341699  95.241  -69.886  52.882  1
341700  95.272  -69.883  52.911  1
341701  95.305  -69.880  52.938  1
341702  95.341  -69.876  52.955  1
341703  95.377  -69.871  52.956  1
341704  95.413  -69.866  52.948  1
341705  95.450  -69.861  52.935  1
341706  95.485  -69.857  52.920  1
341707  95.522  -69.852  52.904  1
341708  95.558  -69.850  52.888  1
341709  95.594  -69.855  52.876  1
341710  95.629  -69.859  52.866  1
341711  95.649  -69.863  52.858  1
341712  95.667  -69.867  52.855  1
341713  95.686  -69.871  52.850  1
341714  95.704  -69.875  52.842  1
341715  95.729  -69.883  52.829  1
341716  95.755  -69.891  52.806  1
341717  95.781  -69.899  52.784  1
341718  95.808  -69.907  52.763  1
341719  95.833  -69.915  52.744  1
341720  95.860  -69.924  52.720  1
341721  95.886  -69.934  52.696  1
341722  95.912  -69.944  52.676  1
341723  95.938  -69.953  52.660  1
341724  95.964  -69.963  52.643  1
341725  95.990  -69.973  52.625  1
341726  96.016  -69.983  52.607  1
341727  96.047  -69.988  52.590  1
341728  96.078  -69.993  52.569  1
341729  96.108  -70.000  52.542  1
341730  96.136  -70.012  52.515  1
341731  96.166  -70.024  52.491  1
341732  96.194  -70.037  52.472  1
341733  96.223  -70.049  52.449  1
341734  96.252  -70.061  52.424  1
341735  96.281  -70.072  52.399  1
341736  96.310  -70.084  52.378  1
341737  96.342  -70.095  52.361  1
341738  96.378  -70.104  52.346  1
341739  96.413  -70.114  52.332  1
341740  96.449  -70.123  52.319  1
341741  96.487  -70.127  52.308  1
341742  96.527  -70.125  52.299  1
341743  96.568  -70.123  52.291  1
341744  96.608  -70.121  52.282  1
341745  96.645  -70.125  52.273  1
341746  96.680  -70.132  52.263  1
341747  96.718  -70.143  52.250  1
341748  96.755  -70.159  52.236  1
341749  96.794  -70.174  52.221  1
341750  96.832  -70.189  52.205  1
341751  96.870  -70.204  52.199  1
341752  96.908  -70.219  52.198  1
341753  96.946  -70.232  52.199  1
341754  96.982  -70.240  52.195  1
341755  97.022  -70.252  52.184  1
341756  97.064  -70.265  52.168  1
341757  97.106  -70.279  52.146  1
341758  97.147  -70.291  52.123  1
341759  97.187  -70.303  52.100  1
341760  97.225  -70.312  52.079  1
341761  97.254  -70.325  52.060  1
341762  97.279  -70.344  52.040  1
341763  97.302  -70.362  52.013  1
341764  97.326  -70.379  51.987  1
341765  97.351  -70.397  51.961  1
341766  97.374  -70.415  51.935  1
341767  97.397  -70.433  51.906  1
341768  97.418  -70.443  51.876  1
341769  97.440  -70.452  51.841  1
341770  97.461  -70.460  51.803  1
341771  97.483  -70.469  51.767  1
341772  97.505  -70.478  51.729  1
341773  97.538  -70.475  51.694  1
341774  97.573  -70.469  51.657  1
341775  97.608  -70.464  51.615  1
341776  97.643  -70.458  51.569  1
341777  97.677  -70.456  51.521  1
341778  97.710  -70.457  51.474  1
341779  97.742  -70.460  51.431  1
341780  97.776  -70.459  51.392  1
341781  97.810  -70.457  51.354  1
341782  97.845  -70.456  51.313  1
341783  97.879  -70.454  51.268  1
341784  97.913  -70.453  51.220  1
341785  97.947  -70.452  51.169  1
341786  97.982  -70.450  51.118  1
341787  98.016  -70.449  51.068  1
341788  98.050  -70.447  51.019  1
341789  98.084  -70.446  50.971  1
341790  98.119  -70.445  50.927  1
341791  98.153  -70.444  50.884  1
341792  98.186  -70.442  50.840  1
341793  98.221  -70.441  50.790  1
341794  98.255  -70.439  50.737  1
341795  98.289  -70.438  50.682  1
341796  98.323  -70.437  50.625  1
341797  98.358  -70.435  50.569  1
341798  98.394  -70.434  50.515  1
341799  98.432  -70.438  50.462  1
341800  98.471  -70.444  50.408  1
341801  98.509  -70.453  50.352  1
341802  98.547  -70.463  50.293  1
341803  98.585  -70.472  50.234  1
341804  98.624  -70.481  50.176  1
341805  98.662  -70.490  50.118  1
341806  98.700  -70.499  50.061  1
341807  98.738  -70.508  50.003  1
341808  98.776  -70.517  49.946  1
341809  98.814  -70.526  49.889  1
341810  98.853  -70.535  49.832  1
341811  98.892  -70.547  49.774  1
341812  98.933  -70.560  49.716  1
341813  98.974  -70.572  49.657  1
341814  99.014  -70.585  49.599  1
341815  99.054  -70.597  49.542  1
341816  99.091  -70.607  49.488  1
341817  99.127  -70.618  49.435  1
341818  99.163  -70.629  49.384  1
341819  99.198  -70.642  49.333  1
341820  99.230  -70.659  49.283  1
341821  99.262  -70.676  49.235  1
341822  99.294  -70.692  49.187  1
341823  99.326  -70.709  49.142  1
341824  99.358  -70.726  49.098  1
341825  99.390  -70.742  49.054  1
341826  99.422  -70.758  49.012  1
341827  99.454  -70.770  48.971  1
341828  99.487  -70.782  48.934  1
341829  99.519  -70.794  48.897  1
341830  99.552  -70.805  48.860  1
341831  99.586  -70.809  48.824  1
341832  99.622  -70.812  48.790  1
341833  99.656  -70.815  48.758  1
341834  99.692  -70.818  48.729  1
341835  99.727  -70.822  48.700  1
341836  99.765  -70.829  48.671  1
341837  99.802  -70.837  48.640  1
341838  99.839  -70.845  48.609  1
341839  99.871  -70.855  48.579  1
341840  99.904  -70.865  48.543  1
341841  99.936  -70.876  48.505  1
341842  99.969  -70.886  48.465  1
341843  100.002  -70.899  48.423  1
341844  100.039  -70.920  48.381  1
341845  100.075  -70.940  48.340  1
341846  100.112  -70.960  48.299  1
341847  100.148  -70.980  48.259  1
341848  100.185  -71.001  48.218  1
341849  100.221  -71.021  48.177  1
341850  100.258  -71.041  48.135  1
341851  100.294  -71.061  48.093  1
341852  100.332  -71.074  48.052  1
341853  100.371  -71.083  48.010  1
341854  100.410  -71.090  47.968  1
341855  100.449  -71.099  47.927  1
341856  100.486  -71.108  47.886  1
341857  100.524  -71.116  47.846  1
341858  100.561  -71.124  47.804  1
341859  100.599  -71.133  47.764  1
341860  100.636  -71.142  47.727  1
341861  100.674  -71.151  47.692  1
341862  100.712  -71.159  47.655  1
341863  100.750  -71.168  47.618  1
341864  100.787  -71.177  47.583  1
341865  100.825  -71.186  47.548  1
341866  100.862  -71.194  47.514  1
341867  100.900  -71.203  47.479  1
341868  100.938  -71.212  47.445  1
341869  100.976  -71.221  47.412  1
341870  101.040  -71.237  47.380  1
341871  101.085  -71.251  47.347  1
341872  101.115  -71.262  47.315  1
341873  101.145  -71.273  47.283  1
341874  101.176  -71.284  47.249  1
341875  101.205  -71.296  47.218  1
341876  101.231  -71.314  47.185  1
341877  101.251  -71.339  47.150  1
341878  101.276  -71.361  47.114  1
341879  101.314  -71.376  47.075  1
341880  101.353  -71.391  47.034  1
341881  101.392  -71.406  46.993  1
341882  101.430  -71.421  46.950  1
341883  101.469  -71.436  46.906  1
341884  101.507  -71.451  46.862  1
341885  101.546  -71.466  46.817  1
341886  101.585  -71.481  46.773  1
341887  101.621  -71.488  46.730  1
341888  101.656  -71.494  46.688  1
341889  101.692  -71.498  46.645  1
341890  101.729  -71.503  46.602  1
341891  101.768  -71.517  46.558  1
341892  101.811  -71.536  46.513  1
341893  101.864  -71.565  46.468  1
341894  101.920  -71.598  46.422  1
341895  101.918  -71.582  46.377  1
341896  101.920  -71.574  46.335  1
341897  101.922  -71.566  46.294  1
341898  101.924  -71.559  46.254  1
341899  101.955  -71.560  46.214  1
341900  101.984  -71.562  46.174  1
341901  102.015  -71.563  46.136  1
341902  102.044  -71.565  46.097  1
341903  102.075  -71.566  46.059  1
341904  102.105  -71.568  46.023  1
341905  102.134  -71.569  45.986  1
341906  102.165  -71.571  45.951  1
341907  102.194  -71.572  45.915  1
341908  102.225  -71.575  45.881  1
341909  102.254  -71.576  45.846  1
342304  91.812  -70.243  55.196  3
342305  91.870  -70.272  55.190  3
342306  91.927  -70.309  55.184  3
342307  91.978  -70.367  55.177  3
342308  92.028  -70.343  55.168  3
342309  92.079  -70.318  55.161  3
342310  92.130  -70.293  55.153  3
342311  92.180  -70.269  55.144  3
342312  92.232  -70.239  55.137  3
342313  92.278  -70.205  55.128  3
342314  92.317  -70.174  55.119  3
342315  92.357  -70.145  55.109  3
342316  92.395  -70.127  55.101  3
342317  92.431  -70.134  55.095  3
342318  92.466  -70.140  55.090  3
342319  92.502  -70.146  55.085  3
342320  92.538  -70.152  55.080  3
342321  92.574  -70.159  55.075  3
342322  92.610  -70.165  55.070  3
342323  92.646  -70.164  55.060  3
342324  92.690  -70.159  55.043  3
342325  92.733  -70.153  55.021  3
342326  92.777  -70.149  54.996  3
342327  92.821  -70.143  54.971  3
342328  92.865  -70.139  54.944  3
342329  92.913  -70.131  54.914  3
342330  92.969  -70.118  54.878  3
342331  93.026  -70.105  54.834  3
342332  93.080  -70.092  54.785  3
342333  93.117  -70.065  54.731  3
342334  93.153  -70.037  54.673  3
342335  93.190  -70.010  54.612  3
342336  93.225  -69.986  54.554  3
342337  93.254  -69.978  54.500  3
342338  93.282  -69.971  54.449  3
342339  93.311  -69.963  54.404  3
342340  93.340  -69.955  54.361  3
342341  93.369  -69.947  54.320  3
342342  93.398  -69.939  54.281  3
342343  93.427  -69.932  54.244  3
342344  93.456  -69.924  54.208  3
342345  93.485  -69.917  54.172  3
342346  93.513  -69.909  54.135  3
342347  93.543  -69.902  54.100  3
342348  93.571  -69.894  54.065  3
342388  94.867  -69.864  52.873  1
342389  94.899  -69.861  52.859  1
342390  94.930  -69.858  52.847  1
342391  94.962  -69.855  52.836  1
342392  94.993  -69.852  52.829  1
342393  95.025  -69.849  52.824  1
342394  95.056  -69.846  52.821  1
342395  95.088  -69.843  52.821  1
342396  95.119  -69.840  52.825  1
342397  95.151  -69.838  52.832  1
342398  95.182  -69.835  52.843  1
342399  95.214  -69.832  52.861  1
342400  95.246  -69.829  52.885  1
342401  95.277  -69.826  52.914  1
342402  95.312  -69.821  52.942  1
342403  95.348  -69.817  52.961  1
342404  95.385  -69.812  52.967  1
342405  95.420  -69.808  52.963  1
342406  95.457  -69.803  52.952  1
342407  95.492  -69.805  52.938  1
342408  95.528  -69.809  52.920  1
342409  95.564  -69.813  52.903  1
342410  95.600  -69.817  52.890  1
342411  95.635  -69.822  52.878  1
342412  95.669  -69.827  52.869  1
342413  95.687  -69.830  52.862  1
342414  95.706  -69.835  52.856  1
342415  95.725  -69.839  52.849  1
342416  95.743  -69.842  52.836  1
342417  95.774  -69.853  52.814  1
342418  95.801  -69.861  52.795  1
342419  95.827  -69.870  52.776  1
342420  95.852  -69.877  52.756  1
342421  95.879  -69.886  52.733  1
342422  95.905  -69.894  52.710  1
342423  95.931  -69.902  52.690  1
342424  95.957  -69.910  52.674  1
342425  95.983  -69.918  52.657  1
342426  96.009  -69.927  52.637  1
342427  96.035  -69.937  52.618  1
342428  96.062  -69.946  52.600  1
342429  96.093  -69.953  52.580  1
342430  96.121  -69.965  52.554  1
342431  96.151  -69.977  52.526  1
342432  96.179  -69.990  52.502  1
342433  96.208  -70.002  52.483  1
342434  96.237  -70.014  52.458  1
342435  96.266  -70.026  52.432  1
342436  96.295  -70.037  52.408  1
342437  96.324  -70.049  52.389  1
342438  96.356  -70.060  52.373  1
342439  96.391  -70.070  52.357  1
342440  96.427  -70.079  52.341  1
342441  96.464  -70.083  52.328  1
342442  96.505  -70.082  52.318  1
342443  96.545  -70.080  52.309  1
342444  96.584  -70.082  52.299  1
342445  96.619  -70.089  52.289  1
342446  96.654  -70.096  52.280  1
342447  96.689  -70.102  52.269  1
342448  96.726  -70.115  52.257  1
342449  96.764  -70.130  52.244  1
342450  96.803  -70.145  52.228  1
342451  96.840  -70.160  52.211  1
342452  96.879  -70.175  52.202  1
342453  96.915  -70.187  52.199  1
342454  96.952  -70.194  52.198  1
342455  96.988  -70.202  52.192  1
342456  97.028  -70.214  52.179  1
342457  97.071  -70.228  52.160  1
342458  97.113  -70.242  52.137  1
342459  97.155  -70.256  52.115  1
342460  97.197  -70.269  52.096  1
342461  97.236  -70.280  52.078  1
342462  97.262  -70.297  52.059  1
342463  97.286  -70.314  52.040  1
342464  97.310  -70.332  52.012  1
342465  97.334  -70.346  51.987  1
342466  97.358  -70.359  51.962  1
342467  97.382  -70.373  51.936  1
342468  97.408  -70.391  51.906  1
342469  97.432  -70.400  51.874  1
342470  97.453  -70.409  51.836  1
342471  97.474  -70.417  51.797  1
342472  97.496  -70.426  51.760  1
342473  97.518  -70.435  51.721  1
342474  97.550  -70.432  51.685  1
342475  97.586  -70.427  51.648  1
342476  97.620  -70.421  51.608  1
342477  97.656  -70.416  51.563  1
342478  97.689  -70.416  51.517  1
342479  97.722  -70.418  51.470  1
342480  97.754  -70.419  51.424  1
342481  97.788  -70.419  51.382  1
342482  97.822  -70.418  51.343  1
342483  97.856  -70.416  51.303  1
342484  97.890  -70.415  51.259  1
342485  97.925  -70.414  51.212  1
342486  97.959  -70.413  51.162  1
342487  97.993  -70.411  51.111  1
342488  98.027  -70.409  51.059  1
342489  98.062  -70.408  51.009  1
342490  98.096  -70.406  50.958  1
342491  98.130  -70.405  50.912  1
342492  98.164  -70.404  50.869  1
342493  98.198  -70.403  50.827  1
342494  98.232  -70.401  50.777  1
342495  98.267  -70.400  50.726  1
342496  98.301  -70.398  50.671  1
342497  98.335  -70.397  50.615  1
342498  98.369  -70.396  50.558  1
342499  98.403  -70.395  50.502  1
342500  98.436  -70.402  50.447  1
342501  98.474  -70.411  50.392  1
342502  98.512  -70.420  50.337  1
342503  98.551  -70.429  50.279  1
342504  98.589  -70.438  50.221  1
342505  98.627  -70.447  50.166  1
342506  98.665  -70.456  50.112  1
342507  98.703  -70.466  50.055  1
342508  98.741  -70.475  49.999  1
342509  98.780  -70.484  49.942  1
342510  98.818  -70.493  49.884  1
342511  98.856  -70.503  49.828  1
342512  98.897  -70.515  49.770  1
342513  98.937  -70.527  49.712  1
342514  98.978  -70.540  49.654  1
342515  99.019  -70.552  49.594  1
342516  99.059  -70.564  49.539  1
342517  99.097  -70.576  49.485  1
342518  99.133  -70.586  49.433  1
342519  99.169  -70.597  49.381  1
342520  99.206  -70.608  49.331  1
342521  99.241  -70.621  49.282  1
342522  99.273  -70.638  49.233  1
342523  99.305  -70.654  49.187  1
342524  99.337  -70.671  49.143  1
342525  99.369  -70.688  49.099  1
342526  99.401  -70.704  49.056  1
342527  99.433  -70.720  49.014  1
342528  99.466  -70.731  48.975  1
342529  99.498  -70.743  48.938  1
342530  99.530  -70.754  48.903  1
342531  99.563  -70.767  48.867  1
342532  99.597  -70.772  48.833  1
342533  99.632  -70.775  48.801  1
342534  99.667  -70.778  48.772  1
342535  99.703  -70.783  48.743  1
342536  99.740  -70.791  48.715  1
342537  99.778  -70.798  48.687  1
342538  99.816  -70.806  48.656  1
342539  99.851  -70.815  48.624  1
342540  99.884  -70.825  48.591  1
342541  99.916  -70.835  48.556  1
342542  99.948  -70.845  48.517  1
342543  99.980  -70.855  48.478  1
342544  100.012  -70.865  48.437  1
342545  100.046  -70.878  48.396  1
342546  100.082  -70.898  48.357  1
342547  100.119  -70.918  48.318  1
342548  100.155  -70.939  48.279  1
342549  100.192  -70.959  48.240  1
342550  100.228  -70.979  48.198  1
342551  100.266  -70.999  48.157  1
342552  100.307  -71.015  48.116  1
342553  100.346  -71.030  48.075  1
342554  100.379  -71.039  48.033  1
342555  100.414  -71.048  47.991  1
342556  100.454  -71.055  47.951  1
342557  100.493  -71.064  47.911  1
342558  100.532  -71.071  47.870  1
342559  100.571  -71.079  47.830  1
342560  100.611  -71.087  47.790  1
342561  100.650  -71.095  47.753  1
342562  100.689  -71.103  47.717  1
342563  100.728  -71.111  47.680  1
342564  100.768  -71.118  47.644  1
342565  100.806  -71.127  47.609  1
342566  100.844  -71.136  47.574  1
342567  100.881  -71.144  47.539  1
342568  100.919  -71.153  47.505  1
342569  100.957  -71.162  47.471  1
342570  100.994  -71.171  47.436  1
342571  101.047  -71.183  47.404  1
342572  101.078  -71.195  47.370  1
342573  101.108  -71.206  47.337  1
342574  101.138  -71.218  47.305  1
342575  101.169  -71.229  47.271  1
342576  101.198  -71.240  47.240  1
342577  101.229  -71.252  47.207  1
342578  101.250  -71.274  47.172  1
342579  101.283  -71.293  47.133  1
342580  101.321  -71.308  47.093  1
342581  101.360  -71.322  47.052  1
342582  101.398  -71.337  47.010  1
342583  101.437  -71.353  46.968  1
342584  101.476  -71.368  46.924  1
342585  101.514  -71.383  46.879  1
342586  101.553  -71.398  46.833  1
342587  101.591  -71.413  46.788  1
342588  101.630  -71.428  46.744  1
342589  101.669  -71.443  46.702  1
342590  101.706  -71.453  46.658  1
342591  101.742  -71.458  46.613  1
342592  101.783  -71.475  46.566  1
342593  101.840  -71.507  46.520  1
342594  101.896  -71.541  46.473  1
342595  101.904  -71.530  46.427  1
342596  101.906  -71.522  46.383  1
342597  101.908  -71.515  46.340  1
342598  101.910  -71.507  46.300  1
342599  101.939  -71.508  46.260  1
342600  101.968  -71.509  46.220  1
342601  101.998  -71.511  46.180  1
342602  102.028  -71.513  46.141  1
342603  102.058  -71.515  46.103  1
342604  102.088  -71.516  46.065  1
342605  102.118  -71.518  46.029  1
342606  102.149  -71.519  45.993  1
342607  102.178  -71.521  45.957  1
342608  102.208  -71.522  45.921  1
342609  102.238  -71.524  45.886  1
343006  91.864  -70.244  55.190  3
343007  91.920  -70.284  55.184  3
343008  91.970  -70.337  55.176  3
343009  92.021  -70.313  55.168  3
343010  92.072  -70.289  55.160  3
343011  92.123  -70.265  55.151  3
343012  92.173  -70.240  55.142  3
343013  92.225  -70.208  55.134  3
343014  92.269  -70.174  55.125  3
343015  92.308  -70.145  55.114  3
343016  92.348  -70.115  55.104  3
343017  92.387  -70.085  55.094  3
343018  92.424  -70.077  55.086  3
343019  92.460  -70.083  55.077  3
343020  92.496  -70.090  55.071  3
343021  92.531  -70.096  55.065  3
343022  92.568  -70.102  55.060  3
343023  92.603  -70.109  55.055  3
343024  92.639  -70.115  55.046  3
343025  92.684  -70.114  55.031  3
343026  92.727  -70.109  55.012  3
343027  92.771  -70.103  54.987  3
343028  92.815  -70.098  54.961  3
343029  92.859  -70.092  54.936  3
343030  92.910  -70.087  54.908  3
343031  92.963  -70.080  54.876  3
343032  93.019  -70.068  54.834  3
343033  93.076  -70.055  54.788  3
343034  93.119  -70.033  54.736  3
343035  93.155  -70.005  54.679  3
343036  93.192  -69.978  54.618  3
343037  93.228  -69.951  54.561  3
343038  93.261  -69.933  54.508  3
343039  93.290  -69.924  54.456  3
343040  93.319  -69.917  54.411  3
343041  93.348  -69.909  54.368  3
343042  93.376  -69.902  54.328  3
343043  93.406  -69.894  54.289  3
343044  93.434  -69.886  54.253  3
343045  93.464  -69.879  54.216  3
343046  93.492  -69.871  54.181  3
343047  93.521  -69.864  54.146  3
343048  93.550  -69.857  54.110  3
343049  93.583  -69.858  54.075  3
343088  94.841  -69.809  52.893  1
343089  94.872  -69.806  52.879  1
343090  94.904  -69.804  52.864  1
343091  94.935  -69.801  52.851  1
343092  94.967  -69.798  52.840  1
343093  94.998  -69.795  52.832  1
343094  95.030  -69.792  52.827  1
343095  95.061  -69.789  52.824  1
343096  95.093  -69.786  52.824  1
343097  95.124  -69.783  52.827  1
343098  95.156  -69.780  52.835  1
343099  95.188  -69.776  52.846  1
343100  95.219  -69.773  52.863  1
343101  95.251  -69.770  52.888  1
343102  95.283  -69.767  52.916  1
343103  95.320  -69.763  52.944  1
343104  95.356  -69.758  52.965  1
343105  95.392  -69.754  52.974  1
343106  95.427  -69.758  52.975  1
343107  95.463  -69.763  52.967  1
343108  95.499  -69.767  52.953  1
343109  95.535  -69.772  52.935  1
343110  95.570  -69.776  52.919  1
343111  95.606  -69.781  52.905  1
343112  95.641  -69.785  52.892  1
343113  95.677  -69.789  52.881  1
343114  95.707  -69.794  52.872  1
343115  95.726  -69.798  52.865  1
343116  95.745  -69.802  52.858  1
343117  95.763  -69.806  52.845  1
343118  95.788  -69.813  52.825  1
343119  95.819  -69.823  52.807  1
343120  95.846  -69.832  52.790  1
343121  95.872  -69.840  52.771  1
343122  95.898  -69.848  52.748  1
343123  95.924  -69.856  52.724  1
343124  95.950  -69.864  52.703  1
343125  95.976  -69.873  52.687  1
343126  96.002  -69.881  52.670  1
343127  96.028  -69.889  52.649  1
343128  96.054  -69.897  52.629  1
343129  96.080  -69.905  52.611  1
343130  96.107  -69.918  52.591  1
343131  96.135  -69.930  52.564  1
343132  96.164  -69.942  52.536  1
343133  96.193  -69.955  52.511  1
343134  96.222  -69.967  52.492  1
343135  96.251  -69.979  52.467  1
343136  96.280  -69.991  52.442  1
343137  96.309  -70.002  52.419  1
343138  96.337  -70.015  52.402  1
343139  96.369  -70.026  52.386  1
343140  96.405  -70.035  52.369  1
343141  96.442  -70.041  52.353  1
343142  96.482  -70.040  52.339  1
343143  96.522  -70.039  52.328  1
343144  96.557  -70.046  52.319  1
343145  96.592  -70.053  52.308  1
343146  96.627  -70.060  52.297  1
343147  96.663  -70.067  52.288  1
343148  96.698  -70.074  52.276  1
343149  96.735  -70.087  52.264  1
343150  96.773  -70.102  52.250  1
343151  96.811  -70.116  52.234  1
343152  96.850  -70.131  52.216  1
343153  96.886  -70.140  52.205  1
343154  96.922  -70.149  52.199  1
343155  96.958  -70.156  52.195  1
343156  96.995  -70.164  52.186  1
343157  97.034  -70.175  52.172  1
343158  97.077  -70.190  52.154  1
343159  97.119  -70.204  52.135  1
343160  97.161  -70.218  52.117  1
343161  97.204  -70.232  52.101  1
343162  97.245  -70.243  52.084  1
343163  97.270  -70.254  52.066  1
343164  97.294  -70.267  52.046  1
343165  97.318  -70.280  52.018  1
343166  97.343  -70.293  51.991  1
343167  97.366  -70.309  51.965  1
343168  97.388  -70.334  51.937  1
343169  97.416  -70.347  51.907  1
343170  97.445  -70.356  51.875  1
343171  97.466  -70.365  51.837  1
343172  97.488  -70.374  51.796  1
343173  97.510  -70.383  51.756  1
343174  97.531  -70.391  51.717  1
343175  97.563  -70.390  51.679  1
343176  97.598  -70.384  51.640  1
343177  97.634  -70.378  51.601  1
343178  97.668  -70.374  51.557  1
343179  97.701  -70.376  51.512  1
343180  97.733  -70.378  51.467  1
343181  97.766  -70.380  51.422  1
343182  97.799  -70.380  51.379  1
343183  97.833  -70.378  51.339  1
343184  97.868  -70.377  51.297  1
343185  97.902  -70.375  51.252  1
343186  97.936  -70.374  51.205  1
343187  97.970  -70.373  51.155  1
343188  98.005  -70.372  51.104  1
343189  98.038  -70.370  51.054  1
343190  98.073  -70.369  51.004  1
343191  98.107  -70.367  50.952  1
343192  98.141  -70.366  50.904  1
343193  98.175  -70.365  50.858  1
343194  98.210  -70.363  50.812  1
343195  98.244  -70.362  50.762  1
343196  98.278  -70.360  50.710  1
343197  98.312  -70.359  50.656  1
343198  98.347  -70.357  50.601  1
343199  98.380  -70.357  50.546  1
343200  98.410  -70.365  50.490  1
343201  98.440  -70.370  50.436  1
343202  98.478  -70.378  50.382  1
343203  98.516  -70.387  50.328  1
343204  98.554  -70.396  50.273  1
343205  98.592  -70.405  50.218  1
343206  98.630  -70.414  50.164  1
343207  98.668  -70.423  50.109  1
343208  98.707  -70.432  50.052  1
343209  98.745  -70.441  49.995  1
343210  98.783  -70.450  49.938  1
343211  98.821  -70.460  49.880  1
343212  98.860  -70.470  49.822  1
343213  98.901  -70.482  49.764  1
343214  98.942  -70.495  49.706  1
343215  98.982  -70.507  49.648  1
343216  99.023  -70.519  49.591  1
343217  99.064  -70.532  49.536  1
343218  99.103  -70.544  49.483  1
343219  99.139  -70.555  49.431  1
343220  99.176  -70.566  49.380  1
343221  99.212  -70.576  49.330  1
343222  99.249  -70.588  49.281  1
343223  99.284  -70.600  49.233  1
343224  99.316  -70.616  49.187  1
343225  99.348  -70.633  49.143  1
343226  99.380  -70.650  49.100  1
343227  99.412  -70.666  49.057  1
343228  99.444  -70.680  49.017  1
343229  99.476  -70.692  48.979  1
343230  99.509  -70.704  48.943  1
343231  99.541  -70.716  48.908  1
343232  99.573  -70.728  48.874  1
343233  99.607  -70.735  48.841  1
343234  99.642  -70.739  48.810  1
343235  99.679  -70.745  48.781  1
343236  99.716  -70.752  48.754  1
343237  99.754  -70.760  48.728  1
343238  99.791  -70.767  48.701  1
343239  99.829  -70.775  48.670  1
343240  99.863  -70.785  48.639  1
343241  99.895  -70.795  48.606  1
343242  99.927  -70.804  48.569  1
343243  99.960  -70.815  48.529  1
343244  99.992  -70.825  48.489  1
343245  100.025  -70.835  48.450  1
343246  100.057  -70.845  48.411  1
343247  100.089  -70.857  48.376  1
343248  100.126  -70.877  48.337  1
343249  100.162  -70.897  48.299  1
343250  100.199  -70.917  48.261  1
343251  100.237  -70.936  48.219  1
343252  100.279  -70.953  48.179  1
343253  100.321  -70.970  48.138  1
343254  100.361  -70.985  48.097  1
343255  100.394  -70.994  48.056  1
343256  100.428  -71.003  48.014  1
343257  100.461  -71.012  47.974  1
343258  100.497  -71.021  47.935  1
343259  100.537  -71.029  47.893  1
343260  100.576  -71.036  47.854  1
343261  100.615  -71.045  47.815  1
343262  100.654  -71.052  47.778  1
343263  100.693  -71.060  47.741  1
343264  100.733  -71.068  47.704  1
343265  100.772  -71.076  47.668  1
343266  100.811  -71.084  47.633  1
343267  100.850  -71.092  47.599  1
343268  100.890  -71.099  47.565  1
343269  100.929  -71.108  47.530  1
343270  100.968  -71.115  47.495  1
343271  101.007  -71.124  47.461  1
343272  101.045  -71.132  47.427  1
343273  101.074  -71.143  47.392  1
343274  101.104  -71.153  47.359  1
343275  101.133  -71.164  47.325  1
343276  101.162  -71.174  47.292  1
343277  101.192  -71.184  47.260  1
343278  101.221  -71.196  47.227  1
343279  101.251  -71.209  47.191  1
343280  101.289  -71.224  47.151  1
343281  101.328  -71.240  47.109  1
343282  101.367  -71.254  47.066  1
343283  101.406  -71.270  47.025  1
343284  101.445  -71.286  46.983  1
343285  101.484  -71.303  46.939  1
343286  101.523  -71.318  46.894  1
343287  101.562  -71.335  46.847  1
343288  101.602  -71.351  46.800  1
343289  101.640  -71.368  46.756  1
343290  101.680  -71.384  46.713  1
343291  101.719  -71.400  46.667  1
343292  101.759  -71.417  46.619  1
343293  101.815  -71.450  46.572  1
343294  101.872  -71.483  46.524  1
343295  101.894  -71.483  46.477  1
343296  101.893  -71.472  46.431  1
343297  101.894  -71.463  46.388  1
343298  101.896  -71.456  46.345  1
343299  101.922  -71.456  46.305  1
343300  101.952  -71.458  46.265  1
343301  101.982  -71.459  46.225  1
343302  102.012  -71.461  46.186  1
343303  102.042  -71.462  46.146  1
343304  102.072  -71.464  46.108  1
343305  102.102  -71.466  46.070  1
343306  102.132  -71.467  46.033  1
343307  102.162  -71.469  45.997  1
343308  102.192  -71.470  45.961  1
343309  102.222  -71.472  45.925  1
343708  91.913  -70.260  55.183  3
343709  91.963  -70.308  55.176  3
343710  92.014  -70.284  55.167  3
343711  92.065  -70.259  55.158  3
343712  92.116  -70.235  55.149  3
343713  92.166  -70.211  55.140  3
343714  92.218  -70.176  55.130  3
343715  92.260  -70.144  55.120  3
343716  92.299  -70.115  55.110  3
343717  92.339  -70.085  55.099  3
343718  92.378  -70.055  55.087  3
343719  92.417  -70.026  55.077  3
343720  92.453  -70.027  55.067  3
343721  92.489  -70.033  55.057  3
343722  92.525  -70.040  55.049  3
343723  92.561  -70.046  55.042  3
343724  92.597  -70.052  55.038  3
343725  92.633  -70.058  55.029  3
343726  92.677  -70.065  55.015  3
343727  92.721  -70.060  54.996  3
343728  92.765  -70.055  54.975  3
343729  92.809  -70.049  54.950  3
343730  92.856  -70.043  54.925  3
343731  92.909  -70.038  54.899  3
343732  92.961  -70.032  54.868  3
343733  93.015  -70.027  54.827  3
343734  93.069  -70.018  54.784  3
343735  93.121  -70.002  54.738  3
343736  93.157  -69.974  54.682  3
343737  93.194  -69.947  54.622  3
343738  93.230  -69.920  54.566  3
343739  93.267  -69.892  54.513  3
343740  93.297  -69.879  54.462  3
343741  93.327  -69.871  54.416  3
343742  93.355  -69.864  54.375  3
343743  93.384  -69.856  54.335  3
343744  93.413  -69.848  54.297  3
343745  93.442  -69.841  54.260  3
343746  93.472  -69.835  54.224  3
343747  93.505  -69.836  54.189  3
343748  93.538  -69.836  54.155  3
343749  93.571  -69.837  54.119  3
343750  93.604  -69.838  54.085  3
343789  94.846  -69.751  52.899  1
343790  94.877  -69.748  52.884  1
343791  94.909  -69.745  52.869  1
343792  94.941  -69.742  52.856  1
343793  94.972  -69.739  52.844  1
343794  95.003  -69.736  52.837  1
343795  95.035  -69.733  52.832  1
343796  95.066  -69.730  52.829  1
343797  95.098  -69.727  52.828  1
343798  95.130  -69.725  52.832  1
343799  95.161  -69.722  52.838  1
343800  95.193  -69.719  52.848  1
343801  95.224  -69.716  52.866  1
343802  95.256  -69.713  52.890  1
343803  95.291  -69.708  52.917  1
343804  95.327  -69.708  52.946  1
343805  95.362  -69.713  52.969  1
343806  95.398  -69.717  52.981  1
343807  95.433  -69.722  52.983  1
343808  95.469  -69.726  52.977  1
343809  95.505  -69.730  52.964  1
343810  95.541  -69.735  52.947  1
343811  95.577  -69.739  52.934  1
343812  95.612  -69.744  52.922  1
343813  95.648  -69.748  52.908  1
343814  95.683  -69.753  52.897  1
343815  95.719  -69.757  52.885  1
343816  95.746  -69.761  52.876  1
343817  95.764  -69.765  52.869  1
343818  95.783  -69.770  52.857  1
343819  95.802  -69.773  52.840  1
343820  95.832  -69.783  52.822  1
343821  95.864  -69.794  52.805  1
343822  95.891  -69.803  52.788  1
343823  95.917  -69.811  52.765  1
343824  95.943  -69.819  52.739  1
343825  95.969  -69.827  52.716  1
343826  95.995  -69.836  52.699  1
343827  96.021  -69.843  52.682  1
343828  96.047  -69.852  52.660  1
343829  96.073  -69.860  52.639  1
343830  96.099  -69.869  52.621  1
343831  96.126  -69.881  52.601  1
343832  96.154  -69.894  52.574  1
343833  96.181  -69.907  52.546  1
343834  96.208  -69.919  52.521  1
343835  96.236  -69.932  52.500  1
343836  96.265  -69.944  52.476  1
343837  96.294  -69.956  52.452  1
343838  96.322  -69.968  52.432  1
343839  96.352  -69.980  52.415  1
343840  96.383  -69.991  52.401  1
343841  96.419  -69.999  52.383  1
343842  96.459  -69.997  52.365  1
343843  96.495  -70.003  52.350  1
343844  96.530  -70.010  52.339  1
343845  96.566  -70.017  52.329  1
343846  96.601  -70.024  52.318  1
343847  96.636  -70.030  52.307  1
343848  96.671  -70.038  52.297  1
343849  96.707  -70.045  52.285  1
343850  96.744  -70.058  52.272  1
343851  96.782  -70.073  52.258  1
343852  96.820  -70.087  52.242  1
343853  96.856  -70.095  52.222  1
343854  96.892  -70.102  52.209  1
343855  96.929  -70.111  52.199  1
343856  96.965  -70.118  52.191  1
343857  97.001  -70.126  52.180  1
343858  97.041  -70.137  52.167  1
343859  97.083  -70.152  52.151  1
343860  97.125  -70.165  52.134  1
343861  97.168  -70.180  52.120  1
343862  97.210  -70.194  52.106  1
343863  97.249  -70.194  52.090  1
343864  97.278  -70.201  52.073  1
343865  97.302  -70.214  52.053  1
343866  97.326  -70.227  52.024  1
343867  97.350  -70.246  51.995  1
343868  97.372  -70.270  51.967  1
343869  97.394  -70.294  51.938  1
343870  97.424  -70.303  51.908  1
343871  97.455  -70.312  51.876  1
343872  97.480  -70.322  51.839  1
343873  97.502  -70.331  51.797  1
343874  97.523  -70.339  51.755  1
343875  97.545  -70.348  51.715  1
343876  97.576  -70.347  51.675  1
343877  97.611  -70.342  51.635  1
343878  97.646  -70.336  51.596  1
343879  97.680  -70.334  51.552  1
343880  97.712  -70.336  51.508  1
343881  97.745  -70.338  51.465  1
343882  97.778  -70.340  51.421  1
343883  97.811  -70.341  51.378  1
343884  97.845  -70.339  51.337  1
343885  97.879  -70.337  51.294  1
343886  97.914  -70.336  51.248  1
343887  97.947  -70.334  51.201  1
343888  97.982  -70.334  51.153  1
343889  98.016  -70.332  51.104  1
343890  98.050  -70.331  51.055  1
343891  98.084  -70.329  51.006  1
343892  98.119  -70.328  50.953  1
343893  98.153  -70.326  50.902  1
343894  98.187  -70.325  50.852  1
343895  98.221  -70.324  50.803  1
343896  98.255  -70.322  50.752  1
343897  98.290  -70.321  50.700  1
343898  98.324  -70.319  50.648  1
343899  98.357  -70.319  50.594  1
343900  98.387  -70.327  50.540  1
343901  98.417  -70.334  50.486  1
343902  98.447  -70.342  50.432  1
343903  98.481  -70.344  50.378  1
343904  98.519  -70.353  50.324  1
343905  98.558  -70.362  50.270  1
343906  98.595  -70.372  50.216  1
343907  98.634  -70.381  50.161  1
343908  98.672  -70.390  50.105  1
343909  98.710  -70.399  50.048  1
343910  98.748  -70.408  49.990  1
343911  98.787  -70.417  49.933  1
343912  98.825  -70.426  49.875  1
343913  98.865  -70.438  49.816  1
343914  98.906  -70.450  49.759  1
343915  98.946  -70.463  49.701  1
343916  98.987  -70.475  49.644  1
343917  99.027  -70.488  49.587  1
343918  99.068  -70.500  49.534  1
343919  99.109  -70.513  49.481  1
343920  99.145  -70.523  49.429  1
343921  99.182  -70.534  49.379  1
343922  99.218  -70.545  49.329  1
343923  99.255  -70.556  49.280  1
343924  99.291  -70.566  49.233  1
343925  99.327  -70.579  49.188  1
343926  99.359  -70.595  49.144  1
343927  99.391  -70.612  49.101  1
343928  99.423  -70.629  49.059  1
343929  99.455  -70.641  49.020  1
343930  99.487  -70.654  48.983  1
343931  99.519  -70.666  48.947  1
343932  99.552  -70.677  48.913  1
343933  99.584  -70.689  48.881  1
343934  99.618  -70.698  48.848  1
343935  99.655  -70.706  48.818  1
343936  99.693  -70.713  48.790  1
343937  99.730  -70.721  48.763  1
343938  99.768  -70.729  48.738  1
343939  99.805  -70.736  48.713  1
343940  99.842  -70.744  48.684  1
343941  99.874  -70.754  48.653  1
343942  99.907  -70.764  48.620  1
343943  99.939  -70.774  48.582  1
343944  99.972  -70.785  48.541  1
343945  100.004  -70.795  48.501  1
343946  100.036  -70.804  48.463  1
343947  100.068  -70.815  48.426  1
343948  100.101  -70.825  48.393  1
343949  100.133  -70.836  48.356  1
343950  100.170  -70.855  48.318  1
343951  100.209  -70.874  48.281  1
343952  100.250  -70.890  48.239  1
343953  100.292  -70.907  48.199  1
343954  100.334  -70.923  48.160  1
343955  100.375  -70.940  48.119  1
343956  100.409  -70.949  48.078  1
343957  100.442  -70.958  48.037  1
343958  100.476  -70.967  47.997  1
343959  100.509  -70.977  47.957  1
343960  100.543  -70.986  47.916  1
343961  100.580  -70.994  47.877  1
343962  100.619  -71.002  47.838  1
343963  100.658  -71.010  47.801  1
343964  100.698  -71.017  47.765  1
343965  100.737  -71.026  47.727  1
343966  100.776  -71.033  47.691  1
343967  100.816  -71.041  47.656  1
343968  100.855  -71.049  47.622  1
343969  100.894  -71.057  47.589  1
343970  100.933  -71.065  47.553  1
343971  100.973  -71.073  47.519  1
343972  101.011  -71.081  47.484  1
343973  101.047  -71.091  47.448  1
343974  101.079  -71.101  47.413  1
343975  101.109  -71.111  47.378  1
343976  101.138  -71.122  47.345  1
343977  101.168  -71.133  47.311  1
343978  101.197  -71.143  47.277  1
343979  101.227  -71.153  47.243  1
343980  101.260  -71.169  47.207  1
343981  101.313  -71.190  47.168  1
343982  101.352  -71.206  47.125  1
343983  101.392  -71.222  47.081  1
343984  101.431  -71.239  47.036  1
343985  101.470  -71.255  46.992  1
343986  101.509  -71.271  46.948  1
343987  101.548  -71.287  46.902  1
343988  101.588  -71.304  46.857  1
343989  101.627  -71.320  46.811  1
343990  101.666  -71.337  46.766  1
343991  101.705  -71.353  46.719  1
343992  101.744  -71.369  46.671  1
343993  101.790  -71.392  46.624  1
343994  101.847  -71.425  46.577  1
343995  101.896  -71.451  46.528  1
343996  101.879  -71.420  46.482  1
343997  101.881  -71.412  46.437  1
343998  101.883  -71.405  46.393  1
343999  101.906  -71.404  46.352  1
344000  101.936  -71.406  46.311  1
344001  101.966  -71.407  46.270  1
344002  101.996  -71.409  46.230  1
344003  102.026  -71.410  46.191  1
344004  102.056  -71.412  46.151  1
344005  102.086  -71.413  46.113  1
344006  102.116  -71.415  46.075  1
344007  102.146  -71.416  46.037  1
344008  102.176  -71.418  46.001  1
344009  102.206  -71.420  45.965  1
344409  91.906  -70.235  55.182  3
344410  91.957  -70.278  55.175  3
344411  92.007  -70.254  55.166  3
344412  92.058  -70.230  55.156  3
344413  92.109  -70.206  55.147  3
344414  92.159  -70.181  55.137  3
344415  92.211  -70.144  55.126  3
344416  92.250  -70.115  55.116  3
344417  92.290  -70.084  55.104  3
344418  92.330  -70.055  55.093  3
344419  92.369  -70.025  55.080  3
344420  92.408  -69.996  55.067  3
344421  92.447  -69.971  55.056  3
344422  92.483  -69.977  55.045  3
344423  92.518  -69.983  55.034  3
344424  92.555  -69.990  55.025  3
344425  92.590  -69.996  55.018  3
344426  92.626  -70.002  55.007  3
344427  92.670  -70.011  54.993  3
344428  92.715  -70.011  54.978  3
344429  92.759  -70.006  54.958  3
344430  92.803  -70.001  54.933  3
344431  92.855  -69.995  54.907  3
344432  92.908  -69.990  54.882  3
344433  92.960  -69.983  54.850  3
344434  93.014  -69.978  54.812  3
344435  93.067  -69.972  54.771  3
344436  93.120  -69.966  54.726  3
344437  93.159  -69.943  54.677  3
344438  93.196  -69.916  54.621  3
344439  93.232  -69.889  54.566  3
344440  93.269  -69.861  54.515  3
344441  93.305  -69.834  54.466  3
344442  93.334  -69.826  54.420  3
344443  93.363  -69.818  54.379  3
344444  93.393  -69.814  54.341  3
344445  93.426  -69.814  54.303  3
344446  93.459  -69.814  54.267  3
344447  93.492  -69.815  54.231  3
344448  93.525  -69.816  54.196  3
344449  93.558  -69.816  54.162  3
344450  93.589  -69.813  54.128  3
344451  93.621  -69.810  54.094  3
344489  94.819  -69.701  52.921  1
344490  94.850  -69.698  52.905  1
344491  94.882  -69.696  52.890  1
344492  94.913  -69.694  52.875  1
344493  94.945  -69.691  52.862  1
344494  94.976  -69.689  52.850  1
344495  95.007  -69.686  52.842  1
344496  95.039  -69.684  52.837  1
344497  95.070  -69.682  52.834  1
344498  95.102  -69.679  52.833  1
344499  95.133  -69.677  52.836  1
344500  95.165  -69.675  52.842  1
344501  95.196  -69.672  52.851  1
344502  95.228  -69.670  52.870  1
344503  95.267  -69.669  52.894  1
344504  95.297  -69.667  52.921  1
344505  95.333  -69.671  52.950  1
344506  95.369  -69.676  52.975  1
344507  95.404  -69.680  52.988  1
344508  95.440  -69.685  52.991  1
344509  95.475  -69.689  52.986  1
344510  95.511  -69.694  52.974  1
344511  95.547  -69.698  52.959  1
344512  95.583  -69.702  52.949  1
344513  95.618  -69.707  52.939  1
344514  95.654  -69.711  52.927  1
344515  95.689  -69.716  52.917  1
344516  95.725  -69.720  52.905  1
344517  95.761  -69.725  52.894  1
344518  95.784  -69.729  52.883  1
344519  95.803  -69.733  52.872  1
344520  95.822  -69.737  52.854  1
344521  95.846  -69.744  52.836  1
344522  95.877  -69.754  52.821  1
344523  95.908  -69.764  52.807  1
344524  95.936  -69.773  52.785  1
344525  95.962  -69.782  52.758  1
344526  95.988  -69.790  52.732  1
344527  96.014  -69.798  52.711  1
344528  96.040  -69.806  52.693  1
344529  96.066  -69.814  52.671  1
344530  96.092  -69.822  52.649  1
344531  96.118  -69.832  52.629  1
344532  96.146  -69.845  52.609  1
344533  96.173  -69.857  52.583  1
344534  96.200  -69.870  52.556  1
344535  96.228  -69.882  52.531  1
344536  96.255  -69.895  52.509  1
344537  96.282  -69.908  52.486  1
344538  96.309  -69.920  52.465  1
344539  96.337  -69.933  52.446  1
344540  96.365  -69.945  52.431  1
344541  96.396  -69.956  52.416  1
344542  96.434  -69.960  52.397  1
344543  96.469  -69.967  52.378  1
344544  96.504  -69.974  52.362  1
344545  96.539  -69.981  52.351  1
344546  96.574  -69.988  52.341  1
344547  96.609  -69.995  52.331  1
344548  96.645  -70.002  52.319  1
344549  96.680  -70.008  52.308  1
344550  96.715  -70.015  52.296  1
344551  96.753  -70.029  52.283  1
344552  96.790  -70.042  52.268  1
344553  96.826  -70.049  52.252  1
344554  96.863  -70.057  52.230  1
344555  96.899  -70.065  52.213  1
344556  96.935  -70.073  52.199  1
344557  96.971  -70.080  52.189  1
344558  97.008  -70.088  52.176  1
344559  97.047  -70.099  52.164  1
344560  97.089  -70.114  52.151  1
344561  97.132  -70.127  52.137  1
344562  97.174  -70.142  52.123  1
344563  97.214  -70.148  52.109  1
344564  97.252  -70.146  52.095  1
344565  97.287  -70.149  52.079  1
344566  97.310  -70.162  52.060  1
344567  97.333  -70.183  52.031  1
344568  97.356  -70.206  52.000  1
344569  97.378  -70.231  51.969  1
344570  97.402  -70.251  51.939  1
344571  97.432  -70.260  51.909  1
344572  97.463  -70.269  51.877  1
344573  97.493  -70.278  51.840  1
344574  97.515  -70.287  51.799  1
344575  97.536  -70.296  51.758  1
344576  97.558  -70.305  51.715  1
344577  97.588  -70.305  51.674  1
344578  97.624  -70.300  51.633  1
344579  97.659  -70.293  51.593  1
344580  97.691  -70.294  51.551  1
344581  97.724  -70.297  51.508  1
344582  97.756  -70.298  51.465  1
344583  97.789  -70.300  51.423  1
344584  97.822  -70.301  51.380  1
344585  97.857  -70.300  51.338  1
344586  97.890  -70.298  51.293  1
344587  97.925  -70.297  51.247  1
344588  97.959  -70.295  51.201  1
344589  97.993  -70.294  51.155  1
344590  98.027  -70.293  51.109  1
344591  98.062  -70.291  51.063  1
344592  98.096  -70.290  51.013  1
344593  98.130  -70.288  50.959  1
344594  98.164  -70.287  50.905  1
344595  98.199  -70.285  50.852  1
344596  98.233  -70.284  50.798  1
344597  98.267  -70.283  50.747  1
344598  98.301  -70.281  50.696  1
344599  98.335  -70.281  50.646  1
344600  98.364  -70.289  50.594  1
344601  98.394  -70.297  50.541  1
344602  98.424  -70.304  50.488  1
344603  98.454  -70.312  50.434  1
344604  98.485  -70.311  50.380  1
344605  98.522  -70.320  50.326  1
344606  98.561  -70.329  50.270  1
344607  98.599  -70.338  50.214  1
344608  98.637  -70.347  50.157  1
344609  98.675  -70.356  50.101  1
344610  98.714  -70.366  50.043  1
344611  98.752  -70.375  49.985  1
344612  98.790  -70.384  49.927  1
344613  98.829  -70.394  49.869  1
344614  98.869  -70.406  49.811  1
344615  98.910  -70.418  49.754  1
344616  98.950  -70.431  49.697  1
344617  98.991  -70.443  49.640  1
344618  99.031  -70.455  49.583  1
344619  99.072  -70.468  49.531  1
344620  99.113  -70.480  49.479  1
344621  99.151  -70.491  49.427  1
344622  99.188  -70.503  49.376  1
344623  99.224  -70.513  49.328  1
344624  99.261  -70.524  49.280  1
344625  99.297  -70.535  49.233  1
344626  99.334  -70.546  49.189  1
344627  99.369  -70.557  49.146  1
344628  99.402  -70.574  49.102  1
344629  99.433  -70.591  49.062  1
344630  99.466  -70.603  49.024  1
344631  99.498  -70.615  48.986  1
344632  99.531  -70.626  48.951  1
344633  99.564  -70.638  48.918  1
344634  99.603  -70.645  48.886  1
344635  99.634  -70.658  48.856  1
344636  99.666  -70.670  48.826  1
344637  99.704  -70.678  48.797  1
344638  99.742  -70.685  48.771  1
344639  99.779  -70.694  48.748  1
344640  99.817  -70.701  48.724  1
344641  99.853  -70.710  48.697  1
344642  99.886  -70.720  48.666  1
344643  99.918  -70.730  48.631  1
344644  99.950  -70.741  48.591  1
344645  99.982  -70.751  48.552  1
344646  100.015  -70.761  48.514  1
344647  100.047  -70.772  48.478  1
344648  100.079  -70.782  48.442  1
344649  100.112  -70.792  48.408  1
344650  100.144  -70.802  48.372  1
344651  100.180  -70.812  48.336  1
344652  100.222  -70.828  48.297  1
344653  100.264  -70.845  48.256  1
344654  100.305  -70.861  48.219  1
344655  100.347  -70.877  48.180  1
344656  100.388  -70.894  48.140  1
344657  100.423  -70.905  48.097  1
344658  100.457  -70.914  48.059  1
344659  100.490  -70.923  48.020  1
344660  100.524  -70.932  47.979  1
344661  100.557  -70.941  47.937  1
344662  100.591  -70.950  47.900  1
344663  100.624  -70.959  47.862  1
344664  100.663  -70.967  47.824  1
344665  100.702  -70.975  47.788  1
344666  100.742  -70.983  47.749  1
344667  100.781  -70.991  47.712  1
344668  100.820  -70.999  47.678  1
344669  100.859  -71.007  47.644  1
344670  100.899  -71.014  47.611  1
344671  100.938  -71.023  47.576  1
344672  100.977  -71.030  47.541  1
344673  101.013  -71.039  47.506  1
344674  101.048  -71.050  47.469  1
344675  101.084  -71.060  47.435  1
344676  101.115  -71.071  47.399  1
344677  101.144  -71.080  47.364  1
344678  101.173  -71.091  47.330  1
344679  101.202  -71.102  47.295  1
344680  101.233  -71.115  47.258  1
344681  101.268  -71.133  47.221  1
344682  101.320  -71.153  47.181  1
344683  101.373  -71.174  47.138  1
344684  101.417  -71.191  47.093  1
344685  101.456  -71.208  47.047  1
344686  101.495  -71.224  47.002  1
344687  101.534  -71.240  46.958  1
344688  101.573  -71.256  46.913  1
344689  101.613  -71.273  46.868  1
344690  101.652  -71.289  46.822  1
344691  101.691  -71.306  46.776  1
344692  101.730  -71.321  46.726  1
344693  101.769  -71.338  46.678  1
344694  101.823  -71.368  46.629  1
344695  101.879  -71.400  46.582  1
344696  101.865  -71.368  46.533  1
344697  101.867  -71.361  46.488  1
344698  101.869  -71.353  46.443  1
344699  101.890  -71.352  46.399  1
344700  101.920  -71.353  46.357  1
344701  101.950  -71.355  46.316  1
344702  101.980  -71.356  46.276  1
344703  102.010  -71.359  46.235  1
344704  102.040  -71.360  46.195  1
344705  102.070  -71.362  46.157  1
344706  102.100  -71.363  46.117  1
344707  102.130  -71.365  46.079  1
344708  102.160  -71.366  46.043  1
344709  102.190  -71.368  46.007  1
345111  91.950  -70.250  55.173  3
345112  92.001  -70.225  55.164  3
345113  92.051  -70.200  55.154  3
345114  92.102  -70.176  55.143  3
345115  92.153  -70.151  55.132  3
345116  92.202  -70.114  55.122  3
345117  92.241  -70.084  55.111  3
345118  92.281  -70.055  55.098  3
345119  92.320  -70.025  55.085  3
345120  92.360  -69.995  55.072  3
345121  92.399  -69.965  55.058  3
345122  92.438  -69.936  55.045  3
345123  92.476  -69.921  55.033  3
345124  92.512  -69.927  55.019  3
345125  92.548  -69.933  55.008  3
345126  92.584  -69.939  54.997  3
345127  92.620  -69.946  54.984  3
345128  92.663  -69.955  54.970  3
345129  92.709  -69.964  54.956  3
345130  92.753  -69.958  54.936  3
345131  92.801  -69.952  54.911  3
345132  92.854  -69.946  54.885  3
345133  92.907  -69.941  54.860  3
345134  92.959  -69.935  54.827  3
345135  93.011  -69.929  54.790  3
345136  93.061  -69.922  54.750  3
345137  93.112  -69.915  54.707  3
345138  93.151  -69.893  54.661  3
345139  93.189  -69.868  54.610  3
345140  93.227  -69.844  54.559  3
345141  93.265  -69.819  54.510  3
345142  93.302  -69.795  54.464  3
345143  93.339  -69.789  54.422  3
345144  93.371  -69.788  54.382  3
345145  93.403  -69.786  54.343  3
345146  93.434  -69.783  54.306  3
345147  93.466  -69.781  54.270  3
345148  93.497  -69.779  54.235  3
345149  93.529  -69.776  54.201  3
345150  93.560  -69.773  54.167  3
345151  93.591  -69.771  54.135  3
345152  93.623  -69.769  54.101  3
345190  94.818  -69.679  52.929  1
345191  94.849  -69.676  52.912  1
345192  94.881  -69.674  52.896  1
345193  94.912  -69.672  52.882  1
345194  94.944  -69.670  52.869  1
345195  94.975  -69.667  52.857  1
345196  95.006  -69.664  52.848  1
345197  95.038  -69.662  52.842  1
345198  95.069  -69.660  52.839  1
345199  95.101  -69.657  52.838  1
345200  95.132  -69.655  52.840  1
345201  95.164  -69.653  52.846  1
345202  95.195  -69.651  52.856  1
345203  95.228  -69.648  52.876  1
345204  95.289  -69.653  52.899  1
345205  95.317  -69.648  52.926  1
345206  95.345  -69.642  52.954  1
345207  95.375  -69.639  52.980  1
345208  95.410  -69.643  52.994  1
345209  95.446  -69.648  52.998  1
345210  95.482  -69.652  52.994  1
345211  95.518  -69.657  52.983  1
345212  95.553  -69.661  52.970  1
345213  95.589  -69.666  52.963  1
345214  95.624  -69.670  52.956  1
345215  95.660  -69.674  52.947  1
345216  95.696  -69.679  52.938  1
345217  95.731  -69.683  52.927  1
345218  95.767  -69.688  52.915  1
345219  95.803  -69.692  52.901  1
345220  95.823  -69.696  52.888  1
345221  95.841  -69.700  52.869  1
345222  95.860  -69.704  52.851  1
345223  95.891  -69.714  52.836  1
345224  95.922  -69.725  52.824  1
345225  95.953  -69.736  52.802  1
345226  95.981  -69.744  52.776  1
345227  96.007  -69.752  52.750  1
345228  96.033  -69.761  52.727  1
345229  96.059  -69.769  52.707  1
345230  96.085  -69.776  52.683  1
345231  96.111  -69.785  52.660  1
345232  96.138  -69.795  52.638  1
345233  96.165  -69.808  52.619  1
345234  96.192  -69.820  52.594  1
345235  96.220  -69.833  52.569  1
345236  96.247  -69.845  52.546  1
345237  96.274  -69.858  52.523  1
345238  96.302  -69.870  52.502  1
345239  96.329  -69.883  52.481  1
345240  96.356  -69.895  52.462  1
345241  96.382  -69.908  52.447  1
345242  96.413  -69.918  52.431  1
345243  96.450  -69.925  52.412  1
345244  96.484  -69.933  52.391  1
345245  96.518  -69.941  52.374  1
345246  96.551  -69.949  52.363  1
345247  96.586  -69.957  52.354  1
345248  96.619  -69.964  52.344  1
345249  96.653  -69.973  52.333  1
345250  96.688  -69.980  52.320  1
345251  96.724  -69.986  52.309  1
345252  96.760  -69.996  52.295  1
345253  96.797  -70.004  52.279  1
345254  96.833  -70.011  52.264  1
345255  96.869  -70.019  52.242  1
345256  96.905  -70.027  52.223  1
345257  96.942  -70.035  52.207  1
345258  96.978  -70.043  52.195  1
345259  97.014  -70.050  52.182  1
345260  97.053  -70.062  52.168  1
345261  97.096  -70.075  52.154  1
345262  97.138  -70.090  52.141  1
345263  97.180  -70.102  52.129  1
345264  97.218  -70.100  52.119  1
345265  97.256  -70.098  52.107  1
345266  97.294  -70.096  52.092  1
345267  97.317  -70.119  52.073  1
345268  97.339  -70.143  52.043  1
345269  97.362  -70.167  52.010  1
345270  97.384  -70.190  51.976  1
345271  97.410  -70.207  51.941  1
345272  97.441  -70.216  51.908  1
345273  97.471  -70.225  51.876  1
345274  97.502  -70.234  51.840  1
345275  97.528  -70.243  51.801  1
345276  97.550  -70.253  51.760  1
345277  97.572  -70.262  51.721  1
345278  97.601  -70.262  51.682  1
345279  97.636  -70.257  51.644  1
345280  97.670  -70.253  51.607  1
345281  97.703  -70.255  51.566  1
345282  97.736  -70.256  51.524  1
345283  97.768  -70.259  51.482  1
345284  97.801  -70.260  51.439  1
345285  97.833  -70.262  51.396  1
345286  97.868  -70.260  51.352  1
345287  97.902  -70.259  51.308  1
345288  97.936  -70.257  51.262  1
345289  97.970  -70.256  51.218  1
345290  98.005  -70.254  51.174  1
345291  98.039  -70.253  51.128  1
345292  98.073  -70.252  51.080  1
345293  98.107  -70.250  51.030  1
345294  98.142  -70.249  50.974  1
345295  98.176  -70.247  50.918  1
345296  98.210  -70.246  50.864  1
345297  98.244  -70.245  50.810  1
345298  98.278  -70.243  50.759  1
345299  98.312  -70.243  50.709  1
345300  98.342  -70.251  50.658  1
345301  98.371  -70.259  50.605  1
345302  98.402  -70.267  50.552  1
345303  98.431  -70.275  50.497  1
345304  98.461  -70.282  50.442  1
345305  98.492  -70.284  50.387  1
345306  98.526  -70.287  50.331  1
345307  98.564  -70.296  50.273  1
345308  98.602  -70.305  50.215  1
345309  98.641  -70.314  50.157  1
345310  98.679  -70.323  50.099  1
345311  98.717  -70.332  50.042  1
345312  98.755  -70.341  49.984  1
345313  98.793  -70.350  49.926  1
345314  98.833  -70.361  49.868  1
345315  98.873  -70.373  49.809  1
345316  98.914  -70.386  49.751  1
345317  98.954  -70.398  49.694  1
345318  98.995  -70.410  49.637  1
345319  99.035  -70.423  49.582  1
345320  99.076  -70.435  49.530  1
345321  99.117  -70.447  49.478  1
345322  99.157  -70.460  49.426  1
345323  99.194  -70.471  49.375  1
345324  99.230  -70.481  49.327  1
345325  99.267  -70.493  49.279  1
345326  99.303  -70.503  49.234  1
345327  99.340  -70.514  49.190  1
345328  99.376  -70.525  49.147  1
345329  99.412  -70.536  49.104  1
345330  99.444  -70.552  49.065  1
345331  99.477  -70.564  49.027  1
345332  99.512  -70.574  48.990  1
345333  99.551  -70.581  48.956  1
345334  99.590  -70.588  48.924  1
345335  99.622  -70.601  48.893  1
345336  99.653  -70.614  48.863  1
345337  99.684  -70.628  48.833  1
345338  99.715  -70.641  48.805  1
345339  99.753  -70.648  48.778  1
345340  99.790  -70.656  48.754  1
345341  99.828  -70.664  48.732  1
345342  99.863  -70.673  48.706  1
345343  99.896  -70.683  48.676  1
345344  99.928  -70.694  48.642  1
345345  99.960  -70.704  48.603  1
345346  99.992  -70.714  48.564  1
345347  100.025  -70.724  48.528  1
345348  100.057  -70.735  48.492  1
345349  100.090  -70.744  48.457  1
345350  100.123  -70.754  48.422  1
345351  100.156  -70.763  48.387  1
345352  100.192  -70.773  48.352  1
345353  100.234  -70.784  48.314  1
345354  100.277  -70.798  48.274  1
345355  100.318  -70.815  48.237  1
345356  100.360  -70.832  48.199  1
345357  100.402  -70.848  48.159  1
345358  100.438  -70.860  48.117  1
345359  100.471  -70.869  48.079  1
345360  100.505  -70.878  48.041  1
345361  100.538  -70.887  48.001  1
345362  100.572  -70.896  47.960  1
345363  100.605  -70.905  47.924  1
345364  100.639  -70.914  47.886  1
345365  100.673  -70.923  47.848  1
345366  100.706  -70.933  47.811  1
345367  100.746  -70.940  47.772  1
345368  100.785  -70.948  47.736  1
345369  100.824  -70.956  47.701  1
345370  100.863  -70.964  47.667  1
345371  100.903  -70.972  47.633  1
345372  100.942  -70.980  47.598  1
345373  100.980  -70.989  47.563  1
345374  101.015  -70.999  47.528  1
345375  101.050  -71.009  47.490  1
345376  101.085  -71.019  47.457  1
345377  101.120  -71.029  47.421  1
345378  101.149  -71.039  47.384  1
345379  101.179  -71.050  47.349  1
345380  101.208  -71.061  47.312  1
345381  101.240  -71.078  47.273  1
345382  101.275  -71.096  47.234  1
345383  101.328  -71.116  47.193  1
345384  101.380  -71.136  47.149  1
345385  101.433  -71.157  47.104  1
345386  101.481  -71.176  47.058  1
345387  101.520  -71.193  47.013  1
345388  101.559  -71.209  46.969  1
345389  101.599  -71.225  46.925  1
345390  101.638  -71.241  46.880  1
345391  101.677  -71.258  46.833  1
345392  101.716  -71.274  46.785  1
345393  101.755  -71.290  46.736  1
345394  101.798  -71.310  46.686  1
345395  101.854  -71.343  46.636  1
345396  101.853  -71.321  46.587  1
345397  101.852  -71.309  46.539  1
345398  101.854  -71.302  46.493  1
345399  101.874  -71.300  46.448  1
345400  101.904  -71.302  46.405  1
345401  101.934  -71.303  46.362  1
345402  101.964  -71.305  46.321  1
345403  101.994  -71.306  46.281  1
345404  102.024  -71.308  46.241  1
345405  102.054  -71.309  46.201  1
345406  102.084  -71.311  46.161  1
345407  102.114  -71.312  46.122  1
345408  102.144  -71.314  46.084  1
345409  102.174  -71.315  46.048  1
345814  92.044  -70.171  55.152  3
345815  92.095  -70.146  55.140  3
345816  92.146  -70.119  55.129  3
345817  92.193  -70.084  55.117  3
345818  92.232  -70.054  55.105  3
345819  92.272  -70.024  55.092  3
345820  92.311  -69.995  55.078  3
345821  92.351  -69.965  55.064  3
345822  92.390  -69.936  55.049  3
345823  92.429  -69.905  55.035  3
345824  92.469  -69.876  55.020  3
345825  92.506  -69.870  55.006  3
345826  92.542  -69.877  54.991  3
345827  92.577  -69.883  54.978  3
345828  92.613  -69.889  54.962  3
345829  92.656  -69.898  54.946  3
345830  92.702  -69.908  54.930  3
345831  92.747  -69.910  54.909  3
345832  92.800  -69.904  54.885  3
345833  92.851  -69.897  54.859  3
345834  92.901  -69.891  54.832  3
345835  92.951  -69.884  54.799  3
345836  93.002  -69.877  54.763  3
345837  93.053  -69.870  54.725  3
345838  93.103  -69.864  54.684  3
345839  93.142  -69.841  54.640  3
345840  93.180  -69.816  54.594  3
345841  93.217  -69.792  54.548  3
345842  93.255  -69.767  54.503  3
345843  93.293  -69.751  54.461  3
345844  93.329  -69.754  54.421  3
345845  93.365  -69.758  54.382  3
345846  93.401  -69.762  54.344  3
345847  93.434  -69.761  54.308  3
345848  93.465  -69.759  54.272  3
345849  93.497  -69.757  54.238  3
345850  93.528  -69.754  54.205  3
345851  93.560  -69.752  54.172  3
345852  93.591  -69.749  54.139  3
345853  93.622  -69.747  54.106  3
345890  94.786  -69.660  52.955  1
345891  94.817  -69.657  52.938  1
345892  94.849  -69.654  52.921  1
345893  94.880  -69.652  52.905  1
345894  94.912  -69.650  52.890  1
345895  94.943  -69.648  52.876  1
345896  94.974  -69.645  52.864  1
345897  95.006  -69.643  52.855  1
345898  95.037  -69.641  52.849  1
345899  95.069  -69.639  52.845  1
345900  95.100  -69.635  52.844  1
345901  95.132  -69.633  52.845  1
345902  95.163  -69.631  52.851  1
345903  95.195  -69.629  52.861  1
345904  95.269  -69.638  52.881  1
345905  95.312  -69.636  52.904  1
345906  95.340  -69.631  52.929  1
345907  95.368  -69.626  52.957  1
345908  95.395  -69.620  52.983  1
345909  95.423  -69.615  52.998  1
345910  95.452  -69.611  53.004  1
345911  95.488  -69.615  53.003  1
345912  95.524  -69.620  52.993  1
345913  95.559  -69.624  52.981  1
345914  95.595  -69.629  52.976  1
345915  95.630  -69.633  52.973  1
345916  95.666  -69.638  52.968  1
345917  95.702  -69.642  52.961  1
345918  95.738  -69.646  52.952  1
345919  95.773  -69.651  52.939  1
345920  95.809  -69.655  52.923  1
345921  95.843  -69.660  52.906  1
345922  95.862  -69.664  52.886  1
345923  95.880  -69.667  52.867  1
345924  95.904  -69.675  52.850  1
345925  95.936  -69.685  52.838  1
345926  95.967  -69.695  52.817  1
345927  95.998  -69.706  52.793  1
345928  96.026  -69.715  52.767  1
345929  96.052  -69.723  52.743  1
345930  96.079  -69.731  52.721  1
345931  96.104  -69.739  52.696  1
345932  96.130  -69.748  52.671  1
345933  96.157  -69.758  52.649  1
345934  96.184  -69.770  52.629  1
345935  96.212  -69.783  52.606  1
345936  96.239  -69.795  52.583  1
345937  96.266  -69.808  52.561  1
345938  96.294  -69.821  52.540  1
345939  96.321  -69.833  52.520  1
345940  96.347  -69.846  52.498  1
345941  96.371  -69.858  52.478  1
345942  96.394  -69.871  52.463  1
345943  96.427  -69.880  52.446  1
345944  96.472  -69.885  52.425  1
345945  96.508  -69.892  52.404  1
345946  96.542  -69.900  52.385  1
345947  96.576  -69.908  52.374  1
345948  96.610  -69.916  52.367  1
345949  96.644  -69.924  52.358  1
345950  96.675  -69.932  52.346  1
345951  96.703  -69.940  52.333  1
345952  96.735  -69.951  52.321  1
345953  96.768  -69.959  52.307  1
345954  96.803  -69.966  52.291  1
345955  96.839  -69.974  52.277  1
345956  96.875  -69.981  52.255  1
345957  96.911  -69.990  52.235  1
345958  96.948  -69.997  52.219  1
345959  96.984  -70.005  52.207  1
345960  97.020  -70.012  52.194  1
345961  97.060  -70.024  52.180  1
345962  97.102  -70.037  52.164  1
345963  97.144  -70.052  52.149  1
345964  97.183  -70.054  52.137  1
345965  97.222  -70.052  52.129  1
345966  97.259  -70.052  52.118  1
345967  97.295  -70.062  52.103  1
345968  97.323  -70.079  52.084  1
345969  97.345  -70.103  52.054  1
345970  97.368  -70.127  52.019  1
345971  97.390  -70.151  51.983  1
345972  97.418  -70.164  51.946  1
345973  97.449  -70.173  51.912  1
345974  97.479  -70.182  51.879  1
345975  97.510  -70.191  51.844  1
345976  97.540  -70.200  51.807  1
345977  97.564  -70.209  51.769  1
345978  97.585  -70.218  51.732  1
345979  97.613  -70.220  51.696  1
345980  97.649  -70.214  51.660  1
345981  97.682  -70.213  51.626  1
345982  97.715  -70.215  51.586  1
345983  97.747  -70.217  51.545  1
345984  97.780  -70.219  51.503  1
345985  97.812  -70.221  51.459  1
345986  97.845  -70.222  51.416  1
345987  97.879  -70.221  51.372  1
345988  97.914  -70.219  51.327  1
345989  97.948  -70.218  51.281  1
345990  97.982  -70.216  51.237  1
345991  98.016  -70.215  51.193  1
345992  98.051  -70.214  51.146  1
345993  98.085  -70.212  51.097  1
345994  98.119  -70.211  51.048  1
345995  98.153  -70.209  50.992  1
345996  98.187  -70.208  50.936  1
345997  98.221  -70.206  50.880  1
345998  98.255  -70.206  50.826  1
345999  98.289  -70.206  50.774  1
346000  98.319  -70.214  50.724  1
346001  98.349  -70.221  50.671  1
346002  98.378  -70.229  50.616  1
346003  98.409  -70.237  50.561  1
346004  98.438  -70.244  50.506  1
346005  98.468  -70.252  50.449  1
346006  98.498  -70.258  50.392  1
346007  98.529  -70.253  50.335  1
346008  98.568  -70.262  50.276  1
346009  98.606  -70.272  50.217  1
346010  98.644  -70.281  50.159  1
346011  98.683  -70.290  50.101  1
346012  98.720  -70.299  50.043  1
346013  98.759  -70.308  49.984  1
346014  98.797  -70.317  49.925  1
346015  98.837  -70.328  49.866  1
346016  98.877  -70.341  49.808  1
346017  98.918  -70.353  49.750  1
346018  98.959  -70.366  49.692  1
346019  98.999  -70.378  49.636  1
346020  99.040  -70.391  49.580  1
346021  99.080  -70.403  49.529  1
346022  99.121  -70.416  49.476  1
346023  99.162  -70.428  49.425  1
346024  99.200  -70.439  49.374  1
346025  99.236  -70.450  49.326  1
346026  99.273  -70.461  49.279  1
346027  99.309  -70.472  49.234  1
346028  99.346  -70.482  49.190  1
346029  99.382  -70.494  49.147  1
346030  99.419  -70.504  49.106  1
346031  99.460  -70.510  49.067  1
346032  99.499  -70.516  49.030  1
346033  99.538  -70.524  48.993  1
346034  99.577  -70.531  48.961  1
346035  99.610  -70.543  48.929  1
346036  99.641  -70.557  48.898  1
346037  99.671  -70.569  48.869  1
346038  99.702  -70.583  48.840  1
346039  99.733  -70.597  48.812  1
346040  99.764  -70.610  48.786  1
346041  99.801  -70.619  48.761  1
346042  99.839  -70.626  48.739  1
346043  99.873  -70.636  48.714  1
346044  99.905  -70.646  48.685  1
346045  99.938  -70.657  48.651  1
346046  99.970  -70.666  48.614  1
346047  100.003  -70.676  48.577  1
346048  100.036  -70.686  48.542  1
346049  100.069  -70.695  48.507  1
346050  100.102  -70.705  48.472  1
346051  100.135  -70.714  48.436  1
346052  100.168  -70.723  48.401  1
346053  100.203  -70.733  48.367  1
346054  100.246  -70.745  48.331  1
346055  100.289  -70.756  48.294  1
346056  100.332  -70.769  48.255  1
346057  100.373  -70.785  48.216  1
346058  100.415  -70.802  48.177  1
346059  100.452  -70.814  48.137  1
346060  100.486  -70.824  48.099  1
346061  100.519  -70.833  48.061  1
346062  100.553  -70.842  48.022  1
346063  100.586  -70.851  47.985  1
346064  100.620  -70.861  47.948  1
346065  100.653  -70.870  47.911  1
346066  100.687  -70.879  47.873  1
346067  100.720  -70.888  47.835  1
346068  100.754  -70.897  47.797  1
346069  100.789  -70.906  47.761  1
346070  100.829  -70.914  47.725  1
346071  100.868  -70.921  47.691  1
346072  100.907  -70.930  47.656  1
346073  100.946  -70.937  47.620  1
346074  100.981  -70.948  47.585  1
346075  101.016  -70.958  47.548  1
346076  101.052  -70.967  47.511  1
346077  101.087  -70.978  47.477  1
346078  101.122  -70.988  47.441  1
346079  101.155  -70.998  47.405  1
346080  101.184  -71.008  47.368  1
346081  101.215  -71.024  47.329  1
346082  101.247  -71.041  47.287  1
346083  101.283  -71.059  47.244  1
346084  101.335  -71.080  47.201  1
346085  101.388  -71.100  47.157  1
346086  101.441  -71.121  47.112  1
346087  101.493  -71.141  47.068  1
346088  101.545  -71.162  47.024  1
346089  101.585  -71.177  46.980  1
346090  101.624  -71.194  46.935  1
346091  101.663  -71.210  46.890  1
346092  101.702  -71.227  46.843  1
346093  101.741  -71.243  46.794  1
346094  101.780  -71.259  46.743  1
346095  101.830  -71.285  46.693  1
346096  101.856  -71.289  46.642  1
346097  101.839  -71.259  46.593  1
346098  101.841  -71.250  46.544  1
346099  101.858  -71.248  46.499  1
346100  101.888  -71.249  46.454  1
346101  101.918  -71.251  46.411  1
346102  101.948  -71.252  46.368  1
346103  101.978  -71.254  46.326  1
346104  102.007  -71.256  46.286  1
346105  102.038  -71.257  46.246  1
346106  102.068  -71.259  46.206  1
346107  102.098  -71.260  46.166  1
346108  102.128  -71.262  46.128  1
346109  102.158  -71.263  46.090  1
346516  92.088  -70.118  55.137  3
346517  92.139  -70.087  55.125  3
346518  92.184  -70.054  55.112  3
346519  92.223  -70.024  55.099  3
346520  92.263  -69.994  55.085  3
346521  92.302  -69.964  55.070  3
346522  92.342  -69.935  55.055  3
346523  92.381  -69.905  55.039  3
346524  92.420  -69.876  55.024  3
346525  92.459  -69.845  55.008  3
346526  92.499  -69.816  54.992  3
346527  92.535  -69.820  54.975  3
346528  92.571  -69.827  54.960  3
346529  92.606  -69.833  54.942  3
346530  92.648  -69.841  54.923  3
346531  92.695  -69.851  54.903  3
346532  92.741  -69.858  54.881  3
346533  92.792  -69.853  54.856  3
346534  92.842  -69.846  54.829  3
346535  92.893  -69.839  54.801  3
346536  92.943  -69.833  54.770  3
346537  92.993  -69.827  54.735  3
346538  93.044  -69.820  54.699  3
346539  93.094  -69.813  54.661  3
346540  93.132  -69.789  54.619  3
346541  93.170  -69.764  54.578  3
346542  93.208  -69.739  54.536  3
346543  93.246  -69.715  54.495  3
346544  93.282  -69.717  54.455  3
346545  93.318  -69.720  54.417  3
346546  93.354  -69.724  54.379  3
346547  93.391  -69.728  54.343  3
346548  93.427  -69.731  54.307  3
346549  93.463  -69.735  54.273  3
346550  93.496  -69.735  54.240  3
346551  93.528  -69.733  54.207  3
346552  93.559  -69.730  54.175  3
346553  93.590  -69.728  54.142  3
346554  93.622  -69.726  54.110  3
346590  94.754  -69.640  52.985  1
346591  94.785  -69.638  52.965  1
346592  94.817  -69.635  52.947  1
346593  94.848  -69.633  52.930  1
346594  94.880  -69.631  52.914  1
346595  94.911  -69.628  52.899  1
346596  94.943  -69.626  52.885  1
346597  94.974  -69.623  52.873  1
346598  95.005  -69.621  52.864  1
346599  95.037  -69.619  52.858  1
346600  95.068  -69.617  52.853  1
346601  95.100  -69.614  52.852  1
346602  95.131  -69.612  52.853  1
346603  95.163  -69.609  52.858  1
346604  95.218  -69.613  52.867  1
346605  95.307  -69.626  52.885  1
346606  95.334  -69.620  52.906  1
346607  95.362  -69.615  52.930  1
346608  95.390  -69.609  52.956  1
346609  95.418  -69.604  52.981  1
346610  95.446  -69.598  52.998  1
346611  95.474  -69.593  53.007  1
346612  95.501  -69.588  53.010  1
346613  95.530  -69.583  53.003  1
346614  95.565  -69.587  52.995  1
346615  95.601  -69.591  52.989  1
346616  95.637  -69.596  52.987  1
346617  95.672  -69.601  52.986  1
346618  95.708  -69.605  52.983  1
346619  95.744  -69.610  52.977  1
346620  95.779  -69.614  52.966  1
346621  95.815  -69.618  52.950  1
346622  95.850  -69.623  52.929  1
346623  95.882  -69.627  52.906  1
346624  95.900  -69.631  52.884  1
346625  95.919  -69.635  52.863  1
346626  95.949  -69.645  52.850  1
346627  95.980  -69.656  52.831  1
346628  96.012  -69.666  52.807  1
346629  96.043  -69.676  52.782  1
346630  96.072  -69.686  52.759  1
346631  96.098  -69.694  52.734  1
346632  96.123  -69.702  52.707  1
346633  96.150  -69.710  52.682  1
346634  96.176  -69.720  52.659  1
346635  96.203  -69.733  52.639  1
346636  96.231  -69.746  52.619  1
346637  96.258  -69.758  52.599  1
346638  96.286  -69.771  52.578  1
346639  96.313  -69.784  52.559  1
346640  96.336  -69.796  52.537  1
346641  96.360  -69.809  52.515  1
346642  96.384  -69.821  52.494  1
346643  96.407  -69.834  52.477  1
346644  96.441  -69.843  52.458  1
346645  96.485  -69.848  52.437  1
346646  96.531  -69.852  52.416  1
346647  96.567  -69.860  52.396  1
346648  96.595  -69.867  52.386  1
346649  96.624  -69.876  52.379  1
346650  96.653  -69.884  52.370  1
346651  96.682  -69.892  52.357  1
346652  96.713  -69.902  52.344  1
346653  96.746  -69.914  52.332  1
346654  96.780  -69.924  52.318  1
346655  96.813  -69.930  52.304  1
346656  96.847  -69.936  52.290  1
346657  96.882  -69.943  52.270  1
346658  96.918  -69.952  52.251  1
346659  96.954  -69.959  52.236  1
346660  96.991  -69.967  52.226  1
346661  97.027  -69.975  52.214  1
346662  97.066  -69.986  52.198  1
346663  97.108  -69.999  52.180  1
346664  97.149  -70.008  52.160  1
346665  97.187  -70.005  52.146  1
346666  97.224  -70.008  52.138  1
346667  97.260  -70.018  52.126  1
346668  97.296  -70.027  52.111  1
346669  97.329  -70.040  52.093  1
346670  97.351  -70.064  52.061  1
346671  97.374  -70.087  52.027  1
346672  97.396  -70.111  51.990  1
346673  97.427  -70.121  51.953  1
346674  97.457  -70.130  51.919  1
346675  97.488  -70.139  51.886  1
346676  97.518  -70.148  51.852  1
346677  97.548  -70.157  51.817  1
346678  97.577  -70.166  51.783  1
346679  97.598  -70.174  51.748  1
346680  97.626  -70.178  51.714  1
346681  97.661  -70.171  51.681  1
346682  97.694  -70.174  51.648  1
346683  97.726  -70.175  51.609  1
346684  97.759  -70.178  51.568  1
346685  97.791  -70.179  51.526  1
346686  97.824  -70.181  51.482  1
346687  97.857  -70.183  51.437  1
346688  97.891  -70.181  51.393  1
346689  97.925  -70.180  51.348  1
346690  97.959  -70.178  51.302  1
346691  97.994  -70.177  51.257  1
346692  98.028  -70.175  51.210  1
346693  98.062  -70.174  51.162  1
346694  98.096  -70.173  51.114  1
346695  98.130  -70.171  51.064  1
346696  98.164  -70.170  51.010  1
346697  98.199  -70.168  50.954  1
346698  98.233  -70.167  50.899  1
346699  98.266  -70.168  50.844  1
346700  98.296  -70.176  50.790  1
346701  98.326  -70.184  50.739  1
346702  98.356  -70.191  50.684  1
346703  98.385  -70.199  50.627  1
346704  98.416  -70.206  50.570  1
346705  98.445  -70.214  50.513  1
346706  98.476  -70.221  50.455  1
346707  98.505  -70.229  50.397  1
346708  98.536  -70.226  50.340  1
346709  98.571  -70.229  50.280  1
346710  98.609  -70.238  50.221  1
346711  98.647  -70.247  50.163  1
346712  98.686  -70.256  50.105  1
346713  98.724  -70.265  50.045  1
346714  98.762  -70.275  49.985  1
346715  98.800  -70.284  49.925  1
346716  98.841  -70.297  49.866  1
346717  98.882  -70.309  49.807  1
346718  98.922  -70.322  49.749  1
346719  98.963  -70.334  49.691  1
346720  99.004  -70.346  49.635  1
346721  99.044  -70.359  49.579  1
346722  99.085  -70.371  49.528  1
346723  99.125  -70.383  49.475  1
346724  99.166  -70.396  49.423  1
346725  99.206  -70.408  49.373  1
346726  99.242  -70.419  49.325  1
346727  99.279  -70.429  49.278  1
346728  99.315  -70.441  49.233  1
346729  99.352  -70.451  49.190  1
346730  99.389  -70.462  49.147  1
346731  99.425  -70.472  49.108  1
346732  99.473  -70.472  49.070  1
346733  99.520  -70.471  49.033  1
346734  99.564  -70.474  48.997  1
346735  99.598  -70.485  48.964  1
346736  99.629  -70.498  48.932  1
346737  99.660  -70.512  48.902  1
346738  99.691  -70.525  48.873  1
346739  99.721  -70.539  48.845  1
346740  99.752  -70.553  48.819  1
346741  99.783  -70.566  48.794  1
346742  99.814  -70.580  48.771  1
346743  99.850  -70.589  48.749  1
346744  99.883  -70.599  48.723  1
346745  99.916  -70.609  48.692  1
346746  99.948  -70.619  48.658  1
346747  99.982  -70.628  48.622  1
346748  100.015  -70.637  48.588  1
346749  100.048  -70.647  48.555  1
346750  100.081  -70.656  48.522  1
346751  100.114  -70.666  48.487  1
346752  100.147  -70.675  48.450  1
346753  100.181  -70.685  48.415  1
346754  100.214  -70.694  48.382  1
346755  100.258  -70.705  48.348  1
346756  100.300  -70.717  48.312  1
346757  100.343  -70.728  48.273  1
346758  100.387  -70.739  48.234  1
346759  100.428  -70.756  48.195  1
346760  100.467  -70.770  48.158  1
346761  100.500  -70.779  48.121  1
346762  100.534  -70.788  48.082  1
346763  100.567  -70.798  48.043  1
346764  100.601  -70.807  48.006  1
346765  100.634  -70.816  47.971  1
346766  100.668  -70.825  47.934  1
346767  100.701  -70.834  47.896  1
346768  100.735  -70.843  47.859  1
346769  100.768  -70.852  47.819  1
346770  100.802  -70.861  47.781  1
346771  100.836  -70.870  47.746  1
346772  100.872  -70.879  47.713  1
346773  100.911  -70.887  47.678  1
346774  100.948  -70.896  47.642  1
346775  100.983  -70.906  47.606  1
346776  101.018  -70.917  47.568  1
346777  101.053  -70.927  47.530  1
346778  101.089  -70.936  47.495  1
346779  101.123  -70.947  47.458  1
346780  101.159  -70.957  47.422  1
346781  101.191  -70.970  47.384  1
346782  101.222  -70.987  47.344  1
346783  101.253  -71.005  47.301  1
346784  101.290  -71.022  47.258  1
346785  101.343  -71.042  47.214  1
346786  101.395  -71.063  47.168  1
346787  101.448  -71.083  47.123  1
346788  101.500  -71.104  47.078  1
346789  101.553  -71.124  47.034  1
346790  101.606  -71.145  46.990  1
346791  101.649  -71.162  46.944  1
346792  101.688  -71.179  46.897  1
346793  101.727  -71.195  46.850  1
346794  101.766  -71.212  46.800  1
346795  101.806  -71.227  46.749  1
346796  101.858  -71.257  46.698  1
346797  101.825  -71.207  46.648  1
346798  101.827  -71.199  46.598  1
346799  101.841  -71.196  46.549  1
346800  101.872  -71.197  46.504  1
346801  101.902  -71.199  46.459  1
346802  101.932  -71.200  46.416  1
346803  101.962  -71.202  46.373  1
346804  101.991  -71.204  46.331  1
346805  102.022  -71.205  46.290  1
346806  102.052  -71.207  46.250  1
346807  102.082  -71.209  46.210  1
346808  102.112  -71.210  46.171  1
346809  102.141  -71.212  46.133  1
347218  92.133  -70.055  55.119  3
347219  92.175  -70.024  55.107  3
347220  92.214  -69.994  55.092  3
347221  92.253  -69.964  55.077  3
347222  92.293  -69.935  55.061  3
347223  92.333  -69.905  55.045  3
347224  92.372  -69.875  55.028  3
347225  92.411  -69.845  55.012  3
347226  92.450  -69.816  54.996  3
347227  92.490  -69.786  54.980  3
347228  92.528  -69.764  54.960  3
347229  92.564  -69.770  54.943  3
347230  92.600  -69.776  54.924  3
347231  92.641  -69.784  54.904  3
347232  92.687  -69.794  54.881  3
347233  92.735  -69.798  54.857  3
347234  92.783  -69.801  54.832  3
347235  92.834  -69.795  54.805  3
347236  92.884  -69.789  54.777  3
347237  92.934  -69.782  54.746  3
347238  92.985  -69.775  54.713  3
347239  93.035  -69.768  54.678  3
347240  93.085  -69.761  54.643  3
347241  93.123  -69.736  54.604  3
347242  93.160  -69.712  54.565  3
347243  93.199  -69.687  54.526  3
347244  93.235  -69.678  54.488  3
347245  93.272  -69.682  54.449  3
347246  93.308  -69.686  54.413  3
347247  93.344  -69.689  54.377  3
347248  93.380  -69.693  54.341  3
347249  93.416  -69.697  54.306  3
347250  93.452  -69.701  54.273  3
347251  93.488  -69.704  54.241  3
347252  93.524  -69.708  54.209  3
347253  93.558  -69.708  54.177  3
347254  93.589  -69.706  54.145  3
347255  93.621  -69.704  54.114  3
347291  94.753  -69.618  52.996  1
347292  94.784  -69.616  52.975  1
347293  94.816  -69.613  52.958  1
347294  94.847  -69.611  52.941  1
347295  94.879  -69.609  52.925  1
347296  94.910  -69.607  52.910  1
347297  94.942  -69.604  52.894  1
347298  94.973  -69.602  52.883  1
347299  95.004  -69.599  52.874  1
347300  95.036  -69.597  52.867  1
347301  95.067  -69.595  52.863  1
347302  95.099  -69.592  52.861  1
347303  95.130  -69.590  52.863  1
347304  95.168  -69.589  52.867  1
347305  95.259  -69.602  52.875  1
347306  95.329  -69.609  52.889  1
347307  95.357  -69.604  52.909  1
347308  95.385  -69.598  52.931  1
347309  95.413  -69.593  52.953  1
347310  95.441  -69.588  52.977  1
347311  95.468  -69.582  52.996  1
347312  95.496  -69.576  53.009  1
347313  95.524  -69.571  53.015  1
347314  95.552  -69.566  53.012  1
347315  95.580  -69.560  53.007  1
347316  95.607  -69.555  53.002  1
347317  95.643  -69.559  53.000  1
347318  95.679  -69.563  53.001  1
347319  95.714  -69.568  53.001  1
347320  95.750  -69.573  52.998  1
347321  95.785  -69.577  52.990  1
347322  95.821  -69.582  52.976  1
347323  95.857  -69.586  52.954  1
347324  95.893  -69.590  52.928  1
347325  95.920  -69.595  52.902  1
347326  95.939  -69.598  52.878  1
347327  95.963  -69.605  52.862  1
347328  95.994  -69.616  52.844  1
347329  96.025  -69.626  52.822  1
347330  96.056  -69.636  52.798  1
347331  96.088  -69.647  52.774  1
347332  96.117  -69.657  52.746  1
347333  96.143  -69.664  52.720  1
347334  96.169  -69.673  52.694  1
347335  96.195  -69.684  52.671  1
347336  96.223  -69.696  52.651  1
347337  96.250  -69.709  52.632  1
347338  96.277  -69.722  52.613  1
347339  96.302  -69.734  52.594  1
347340  96.326  -69.747  52.575  1
347341  96.349  -69.759  52.554  1
347342  96.373  -69.772  52.531  1
347343  96.397  -69.784  52.508  1
347344  96.420  -69.797  52.490  1
347345  96.454  -69.806  52.469  1
347346  96.499  -69.811  52.447  1
347347  96.544  -69.814  52.426  1
347348  96.574  -69.820  52.407  1
347349  96.603  -69.827  52.395  1
347350  96.631  -69.836  52.387  1
347351  96.661  -69.843  52.377  1
347352  96.691  -69.853  52.364  1
347353  96.725  -69.865  52.350  1
347354  96.758  -69.878  52.338  1
347355  96.791  -69.889  52.325  1
347356  96.824  -69.895  52.312  1
347357  96.858  -69.901  52.299  1
347358  96.891  -69.907  52.279  1
347359  96.925  -69.914  52.263  1
347360  96.961  -69.921  52.251  1
347361  96.997  -69.929  52.243  1
347362  97.033  -69.937  52.232  1
347363  97.072  -69.947  52.218  1
347364  97.114  -69.961  52.198  1
347365  97.153  -69.959  52.174  1
347366  97.189  -69.965  52.156  1
347367  97.225  -69.974  52.143  1
347368  97.261  -69.984  52.129  1
347369  97.297  -69.993  52.113  1
347370  97.332  -70.003  52.094  1
347371  97.357  -70.024  52.065  1
347372  97.380  -70.048  52.033  1
347373  97.404  -70.068  51.998  1
347374  97.435  -70.077  51.963  1
347375  97.465  -70.086  51.931  1
347376  97.496  -70.095  51.900  1
347377  97.526  -70.104  51.867  1
347378  97.557  -70.113  51.833  1
347379  97.587  -70.122  51.800  1
347380  97.612  -70.131  51.766  1
347381  97.639  -70.135  51.732  1
347382  97.673  -70.132  51.699  1
347383  97.706  -70.134  51.665  1
347384  97.738  -70.136  51.626  1
347385  97.771  -70.137  51.585  1
347386  97.803  -70.140  51.542  1
347387  97.836  -70.141  51.498  1
347388  97.868  -70.143  51.453  1
347389  97.902  -70.142  51.410  1
347390  97.937  -70.140  51.364  1
347391  97.971  -70.139  51.316  1
347392  98.005  -70.137  51.270  1
347393  98.039  -70.136  51.222  1
347394  98.073  -70.134  51.174  1
347395  98.107  -70.134  51.126  1
347396  98.142  -70.132  51.077  1
347397  98.176  -70.130  51.022  1
347398  98.210  -70.129  50.967  1
347399  98.243  -70.130  50.911  1
347400  98.273  -70.138  50.857  1
347401  98.303  -70.146  50.802  1
347402  98.333  -70.153  50.748  1
347403  98.363  -70.161  50.692  1
347404  98.393  -70.168  50.634  1
347405  98.423  -70.176  50.576  1
347406  98.452  -70.184  50.518  1
347407  98.483  -70.191  50.459  1
347408  98.512  -70.199  50.401  1
347409  98.543  -70.199  50.343  1
347410  98.575  -70.196  50.285  1
347411  98.613  -70.205  50.226  1
347412  98.651  -70.214  50.168  1
347413  98.689  -70.223  50.109  1
347414  98.727  -70.232  50.049  1
347415  98.766  -70.241  49.988  1
347416  98.805  -70.252  49.927  1
347417  98.846  -70.264  49.866  1
347418  98.886  -70.277  49.806  1
347419  98.927  -70.289  49.747  1
347420  98.967  -70.301  49.689  1
347421  99.008  -70.314  49.632  1
347422  99.049  -70.326  49.577  1
347423  99.089  -70.338  49.525  1
347424  99.130  -70.351  49.473  1
347425  99.170  -70.363  49.422  1
347426  99.211  -70.375  49.372  1
347427  99.249  -70.387  49.324  1
347428  99.285  -70.398  49.278  1
347429  99.322  -70.409  49.233  1
347430  99.358  -70.419  49.190  1
347431  99.395  -70.430  49.148  1
347432  99.438  -70.433  49.108  1
347433  99.486  -70.433  49.070  1
347434  99.533  -70.432  49.033  1
347435  99.577  -70.435  48.998  1
347436  99.614  -70.453  48.966  1
347437  99.645  -70.466  48.933  1
347438  99.676  -70.478  48.902  1
347439  99.707  -70.491  48.874  1
347440  99.738  -70.504  48.847  1
347441  99.769  -70.517  48.823  1
347442  99.800  -70.530  48.799  1
347443  99.831  -70.543  48.777  1
347444  99.862  -70.556  48.754  1
347445  99.895  -70.560  48.726  1
347446  99.927  -70.569  48.695  1
347447  99.961  -70.579  48.663  1
347448  99.994  -70.588  48.628  1
347449  100.027  -70.598  48.599  1
347450  100.060  -70.607  48.567  1
347451  100.093  -70.616  48.534  1
347452  100.126  -70.626  48.499  1
347453  100.159  -70.635  48.460  1
347454  100.193  -70.645  48.426  1
347455  100.226  -70.654  48.395  1
347456  100.269  -70.666  48.363  1
347457  100.312  -70.677  48.327  1
347458  100.355  -70.688  48.289  1
347459  100.398  -70.700  48.251  1
347460  100.441  -70.711  48.213  1
347461  100.481  -70.725  48.176  1
347462  100.515  -70.734  48.139  1
347463  100.548  -70.743  48.099  1
347464  100.582  -70.752  48.061  1
347465  100.615  -70.761  48.026  1
347466  100.649  -70.771  47.991  1
347467  100.682  -70.780  47.954  1
347468  100.716  -70.789  47.915  1
347469  100.750  -70.798  47.877  1
347470  100.783  -70.807  47.838  1
347471  100.818  -70.817  47.800  1
347472  100.852  -70.827  47.765  1
347473  100.887  -70.837  47.732  1
347474  100.918  -70.846  47.697  1
347475  100.954  -70.855  47.661  1
347476  100.990  -70.866  47.624  1
347477  101.026  -70.876  47.586  1
347478  101.062  -70.886  47.548  1
347479  101.099  -70.896  47.510  1
347480  101.134  -70.906  47.473  1
347481  101.170  -70.917  47.436  1
347482  101.198  -70.933  47.398  1
347483  101.229  -70.951  47.357  1
347484  101.260  -70.967  47.315  1
347485  101.298  -70.986  47.272  1
347486  101.350  -71.006  47.227  1
347487  101.403  -71.027  47.180  1
347488  101.456  -71.047  47.134  1
347489  101.508  -71.068  47.089  1
347490  101.560  -71.088  47.044  1
347491  101.613  -71.108  46.999  1
347492  101.666  -71.129  46.951  1
347493  101.713  -71.148  46.902  1
347494  101.752  -71.164  46.853  1
347495  101.792  -71.180  46.803  1
347496  101.837  -71.203  46.754  1
347497  101.813  -71.158  46.703  1
347498  101.813  -71.148  46.652  1
347499  101.825  -71.144  46.602  1
347500  101.855  -71.146  46.554  1
347501  101.886  -71.147  46.507  1
347502  101.915  -71.149  46.463  1
347503  101.946  -71.150  46.419  1
347504  101.975  -71.152  46.377  1
347505  102.006  -71.153  46.335  1
347506  102.036  -71.155  46.295  1
347507  102.065  -71.156  46.254  1
347508  102.096  -71.158  46.214  1
347509  102.125  -71.159  46.173  1
347510  102.156  -71.161  46.135  1
347920  92.166  -69.993  55.101  3
347921  92.205  -69.964  55.085  3
347922  92.244  -69.934  55.070  3
347923  92.284  -69.905  55.053  3
347924  92.323  -69.875  55.037  3
347925  92.363  -69.845  55.020  3
347926  92.402  -69.815  55.002  3
347927  92.441  -69.786  54.985  3
347928  92.481  -69.756  54.967  3
347929  92.520  -69.726  54.947  3
347930  92.558  -69.714  54.929  3
347931  92.593  -69.720  54.909  3
347932  92.634  -69.728  54.888  3
347933  92.680  -69.737  54.864  3
347934  92.728  -69.739  54.840  3
347935  92.776  -69.742  54.813  3
347936  92.825  -69.744  54.785  3
347937  92.875  -69.737  54.758  3
347938  92.925  -69.730  54.727  3
347939  92.976  -69.724  54.695  3
347940  93.026  -69.717  54.662  3
347941  93.075  -69.709  54.628  3
347942  93.113  -69.684  54.591  3
347943  93.151  -69.660  54.554  3
347944  93.189  -69.640  54.518  3
347945  93.225  -69.644  54.481  3
347946  93.261  -69.648  54.444  3
347947  93.297  -69.651  54.409  3
347948  93.333  -69.654  54.374  3
347949  93.369  -69.658  54.339  3
347950  93.406  -69.662  54.305  3
347951  93.442  -69.666  54.272  3
347952  93.478  -69.670  54.240  3
347953  93.514  -69.673  54.208  3
347954  93.550  -69.677  54.177  3
347955  93.586  -69.681  54.146  3
347956  93.620  -69.682  54.116  3
347991  94.721  -69.599  53.031  1
347992  94.752  -69.597  53.009  1
347993  94.784  -69.595  52.987  1
347994  94.815  -69.591  52.970  1
347995  94.847  -69.589  52.953  1
347996  94.878  -69.587  52.937  1
347997  94.910  -69.585  52.922  1
347998  94.941  -69.582  52.907  1
347999  94.972  -69.580  52.895  1
348000  95.004  -69.578  52.885  1
348001  95.035  -69.576  52.879  1
348002  95.067  -69.573  52.874  1
348003  95.098  -69.570  52.873  1
348004  95.130  -69.568  52.874  1
348005  95.209  -69.578  52.878  1
348006  95.301  -69.591  52.885  1
348007  95.352  -69.593  52.896  1
348008  95.380  -69.588  52.912  1
348009  95.407  -69.582  52.930  1
348010  95.436  -69.576  52.951  1
348011  95.463  -69.571  52.974  1
348012  95.491  -69.566  52.993  1
348013  95.519  -69.560  53.007  1
348014  95.546  -69.555  53.016  1
348015  95.574  -69.550  53.018  1
348016  95.602  -69.544  53.017  1
348017  95.630  -69.538  53.015  1
348018  95.658  -69.533  53.013  1
348019  95.686  -69.528  53.012  1
348020  95.721  -69.531  53.015  1
348021  95.756  -69.535  53.016  1
348022  95.792  -69.540  53.013  1
348023  95.827  -69.544  53.003  1
348024  95.863  -69.549  52.980  1
348025  95.899  -69.554  52.952  1
348026  95.935  -69.557  52.923  1
348027  95.959  -69.562  52.895  1
348028  95.977  -69.566  52.874  1
348029  96.008  -69.576  52.857  1
348030  96.039  -69.586  52.837  1
348031  96.070  -69.597  52.813  1
348032  96.101  -69.607  52.787  1
348033  96.132  -69.617  52.759  1
348034  96.162  -69.627  52.733  1
348035  96.188  -69.635  52.708  1
348036  96.215  -69.647  52.684  1
348037  96.242  -69.660  52.664  1
348038  96.268  -69.672  52.646  1
348039  96.292  -69.685  52.629  1
348040  96.315  -69.697  52.611  1
348041  96.338  -69.710  52.591  1
348042  96.362  -69.722  52.570  1
348043  96.386  -69.735  52.547  1
348044  96.409  -69.747  52.524  1
348045  96.433  -69.760  52.503  1
348046  96.468  -69.768  52.481  1
348047  96.513  -69.773  52.458  1
348048  96.551  -69.776  52.437  1
348049  96.581  -69.780  52.419  1
348050  96.610  -69.787  52.406  1
348051  96.639  -69.795  52.395  1
348052  96.669  -69.805  52.384  1
348053  96.702  -69.817  52.370  1
348054  96.736  -69.829  52.356  1
348055  96.769  -69.842  52.344  1
348056  96.803  -69.853  52.332  1
348057  96.836  -69.860  52.319  1
348058  96.869  -69.866  52.306  1
348059  96.903  -69.872  52.288  1
348060  96.936  -69.878  52.274  1
348061  96.969  -69.884  52.265  1
348062  97.004  -69.891  52.258  1
348063  97.040  -69.899  52.249  1
348064  97.079  -69.909  52.235  1
348065  97.118  -69.913  52.214  1
348066  97.154  -69.922  52.188  1
348067  97.190  -69.931  52.164  1
348068  97.226  -69.940  52.147  1
348069  97.261  -69.950  52.131  1
348070  97.297  -69.959  52.115  1
348071  97.333  -69.969  52.096  1
348072  97.363  -69.984  52.069  1
348073  97.386  -70.008  52.039  1
348074  97.413  -70.024  52.006  1
348075  97.443  -70.033  51.972  1
348076  97.473  -70.043  51.942  1
348077  97.504  -70.052  51.913  1
348078  97.534  -70.061  51.881  1
348079  97.565  -70.070  51.849  1
348080  97.595  -70.079  51.816  1
348081  97.626  -70.088  51.782  1
348082  97.651  -70.093  51.748  1
348083  97.684  -70.092  51.714  1
348084  97.717  -70.094  51.679  1
348085  97.749  -70.096  51.638  1
348086  97.782  -70.098  51.596  1
348087  97.815  -70.099  51.552  1
348088  97.847  -70.102  51.508  1
348089  97.880  -70.103  51.463  1
348090  97.914  -70.102  51.419  1
348091  97.948  -70.101  51.372  1
348092  97.982  -70.099  51.323  1
348093  98.016  -70.098  51.276  1
348094  98.051  -70.096  51.227  1
348095  98.085  -70.095  51.180  1
348096  98.119  -70.094  51.132  1
348097  98.153  -70.093  51.083  1
348098  98.187  -70.091  51.029  1
348099  98.220  -70.093  50.974  1
348100  98.250  -70.100  50.919  1
348101  98.280  -70.108  50.863  1
348102  98.310  -70.115  50.807  1
348103  98.340  -70.123  50.751  1
348104  98.370  -70.130  50.695  1
348105  98.400  -70.138  50.636  1
348106  98.430  -70.146  50.578  1
348107  98.459  -70.153  50.519  1
348108  98.490  -70.161  50.460  1
348109  98.519  -70.168  50.402  1
348110  98.550  -70.172  50.346  1
348111  98.580  -70.167  50.288  1
348112  98.616  -70.171  50.229  1
348113  98.654  -70.181  50.170  1
348114  98.693  -70.190  50.110  1
348115  98.731  -70.199  50.048  1
348116  98.769  -70.208  49.987  1
348117  98.809  -70.219  49.926  1
348118  98.850  -70.232  49.865  1
348119  98.890  -70.244  49.805  1
348120  98.931  -70.256  49.745  1
348121  98.972  -70.269  49.687  1
348122  99.012  -70.281  49.630  1
348123  99.053  -70.293  49.575  1
348124  99.093  -70.306  49.522  1
348125  99.134  -70.319  49.471  1
348126  99.174  -70.331  49.420  1
348127  99.215  -70.344  49.371  1
348128  99.255  -70.356  49.323  1
348129  99.291  -70.366  49.277  1
348130  99.328  -70.377  49.233  1
348131  99.364  -70.388  49.190  1
348132  99.404  -70.395  49.148  1
348133  99.451  -70.394  49.108  1
348134  99.499  -70.394  49.070  1
348135  99.541  -70.398  49.033  1
348136  99.585  -70.402  48.999  1
348137  99.628  -70.419  48.966  1
348138  99.659  -70.441  48.933  1
348139  99.691  -70.454  48.902  1
348140  99.721  -70.467  48.874  1
348141  99.753  -70.480  48.847  1
348142  99.783  -70.493  48.823  1
348143  99.815  -70.506  48.801  1
348144  99.845  -70.519  48.779  1
348145  99.876  -70.532  48.756  1
348146  99.908  -70.532  48.727  1
348147  99.940  -70.532  48.697  1
348148  99.973  -70.540  48.666  1
348149  100.006  -70.549  48.634  1
348150  100.039  -70.559  48.608  1
348151  100.072  -70.568  48.578  1
348152  100.105  -70.578  48.545  1
348153  100.138  -70.587  48.508  1
348154  100.171  -70.597  48.469  1
348155  100.204  -70.606  48.436  1
348156  100.238  -70.615  48.406  1
348157  100.280  -70.626  48.376  1
348158  100.324  -70.638  48.341  1
348159  100.366  -70.649  48.302  1
348160  100.409  -70.660  48.266  1
348161  100.453  -70.672  48.230  1
348162  100.498  -70.684  48.193  1
348163  100.538  -70.695  48.153  1
348164  100.572  -70.704  48.113  1
348165  100.607  -70.713  48.077  1
348166  100.641  -70.723  48.044  1
348167  100.676  -70.733  48.010  1
348168  100.710  -70.743  47.971  1
348169  100.745  -70.753  47.931  1
348170  100.779  -70.763  47.890  1
348171  100.814  -70.773  47.855  1
348172  100.848  -70.782  47.818  1
348173  100.882  -70.792  47.782  1
348174  100.908  -70.808  47.748  1
348175  100.937  -70.816  47.713  1
348176  100.970  -70.820  47.676  1
348177  101.004  -70.825  47.639  1
348178  101.040  -70.836  47.601  1
348179  101.076  -70.845  47.562  1
348180  101.112  -70.855  47.523  1
348181  101.148  -70.866  47.484  1
348182  101.179  -70.880  47.446  1
348183  101.206  -70.897  47.408  1
348184  101.236  -70.914  47.369  1
348185  101.267  -70.931  47.327  1
348186  101.305  -70.948  47.284  1
348187  101.358  -70.969  47.239  1
348188  101.410  -70.989  47.191  1
348189  101.463  -71.010  47.143  1
348190  101.516  -71.030  47.095  1
348191  101.568  -71.051  47.047  1
348192  101.620  -71.071  47.000  1
348193  101.673  -71.092  46.953  1
348194  101.726  -71.112  46.906  1
348195  101.777  -71.133  46.859  1
348196  101.817  -71.149  46.811  1
348197  101.816  -71.127  46.760  1
348198  101.799  -71.096  46.707  1
348199  101.809  -71.092  46.655  1
348200  101.839  -71.093  46.604  1
348201  101.870  -71.095  46.556  1
348202  101.899  -71.096  46.509  1
348203  101.929  -71.098  46.465  1
348204  101.959  -71.099  46.421  1
348205  101.989  -71.101  46.379  1
348206  102.020  -71.102  46.338  1
348207  102.049  -71.104  46.297  1
348208  102.080  -71.105  46.257  1
348209  102.109  -71.107  46.216  1
348210  102.139  -71.108  46.176  1
348621  92.157  -69.964  55.095  3
348622  92.196  -69.934  55.079  3
348623  92.235  -69.904  55.062  3
348624  92.275  -69.874  55.045  3
348625  92.314  -69.845  55.028  3
348626  92.354  -69.815  55.010  3
348627  92.393  -69.786  54.992  3
348628  92.432  -69.755  54.974  3
348629  92.472  -69.726  54.956  3
348630  92.511  -69.696  54.935  3
348631  92.550  -69.667  54.915  3
348632  92.587  -69.664  54.895  3
348633  92.626  -69.671  54.875  3
348634  92.673  -69.678  54.851  3
348635  92.722  -69.680  54.826  3
348636  92.770  -69.682  54.800  3
348637  92.818  -69.685  54.771  3
348638  92.866  -69.686  54.743  3
348639  92.917  -69.679  54.713  3
348640  92.967  -69.673  54.683  3
348641  93.017  -69.666  54.651  3
348642  93.066  -69.657  54.617  3
348643  93.104  -69.632  54.581  3
348644  93.142  -69.607  54.546  3
348645  93.178  -69.605  54.510  3
348646  93.214  -69.609  54.474  3
348647  93.251  -69.613  54.439  3
348648  93.287  -69.617  54.404  3
348649  93.323  -69.620  54.369  3
348650  93.359  -69.624  54.336  3
348651  93.395  -69.628  54.302  3
348652  93.431  -69.632  54.271  3
348653  93.468  -69.635  54.238  3
348654  93.503  -69.639  54.207  3
348655  93.540  -69.642  54.177  3
348656  93.576  -69.646  54.146  3
348657  93.612  -69.650  54.116  3
348692  94.720  -69.577  53.044  1
348693  94.752  -69.575  53.023  1
348694  94.783  -69.573  53.001  1
348695  94.815  -69.570  52.984  1
348696  94.846  -69.568  52.967  1
348697  94.878  -69.565  52.951  1
348698  94.909  -69.563  52.936  1
348699  94.941  -69.560  52.920  1
348700  94.972  -69.558  52.908  1
348701  95.003  -69.556  52.899  1
348702  95.035  -69.554  52.893  1
348703  95.066  -69.551  52.888  1
348704  95.098  -69.549  52.886  1
348705  95.158  -69.554  52.887  1
348706  95.250  -69.567  52.890  1
348707  95.342  -69.580  52.896  1
348708  95.375  -69.576  52.906  1
348709  95.402  -69.571  52.918  1
348710  95.430  -69.566  52.932  1
348711  95.458  -69.560  52.950  1
348712  95.486  -69.555  52.970  1
348713  95.514  -69.549  52.988  1
348714  95.541  -69.544  53.003  1
348715  95.569  -69.538  53.013  1
348716  95.597  -69.533  53.020  1
348717  95.625  -69.528  53.026  1
348718  95.653  -69.523  53.028  1
348719  95.680  -69.517  53.028  1
348720  95.708  -69.511  53.026  1
348721  95.736  -69.506  53.027  1
348722  95.764  -69.501  53.030  1
348723  95.798  -69.503  53.031  1
348724  95.834  -69.507  53.026  1
348725  95.869  -69.512  53.008  1
348726  95.905  -69.516  52.979  1
348727  95.941  -69.521  52.947  1
348728  95.976  -69.526  52.915  1
348729  95.997  -69.529  52.888  1
348730  96.021  -69.536  52.871  1
348731  96.052  -69.547  52.850  1
348732  96.084  -69.557  52.825  1
348733  96.115  -69.567  52.798  1
348734  96.146  -69.578  52.772  1
348735  96.177  -69.588  52.748  1
348736  96.207  -69.598  52.723  1
348737  96.233  -69.610  52.699  1
348738  96.257  -69.623  52.678  1
348739  96.281  -69.635  52.661  1
348740  96.304  -69.648  52.645  1
348741  96.328  -69.660  52.627  1
348742  96.352  -69.673  52.609  1
348743  96.375  -69.685  52.586  1
348744  96.399  -69.698  52.563  1
348745  96.422  -69.710  52.541  1
348746  96.446  -69.723  52.517  1
348747  96.481  -69.731  52.495  1
348748  96.526  -69.736  52.472  1
348749  96.557  -69.738  52.451  1
348750  96.588  -69.740  52.433  1
348751  96.617  -69.747  52.418  1
348752  96.647  -69.756  52.405  1
348753  96.680  -69.768  52.391  1
348754  96.714  -69.780  52.376  1
348755  96.747  -69.792  52.361  1
348756  96.781  -69.805  52.350  1
348757  96.814  -69.817  52.338  1
348758  96.848  -69.824  52.325  1
348759  96.881  -69.830  52.313  1
348760  96.914  -69.837  52.297  1
348761  96.948  -69.843  52.286  1
348762  96.981  -69.849  52.278  1
348763  97.014  -69.855  52.273  1
348764  97.047  -69.861  52.266  1
348765  97.083  -69.869  52.250  1
348766  97.119  -69.878  52.229  1
348767  97.155  -69.888  52.202  1
348768  97.190  -69.897  52.173  1
348769  97.227  -69.907  52.151  1
348770  97.262  -69.916  52.132  1
348771  97.298  -69.925  52.115  1
348772  97.334  -69.935  52.098  1
348773  97.369  -69.945  52.073  1
348774  97.392  -69.968  52.045  1
348775  97.421  -69.980  52.013  1
348776  97.451  -69.990  51.981  1
348777  97.481  -69.999  51.953  1
348778  97.512  -70.008  51.925  1
348779  97.542  -70.017  51.895  1
348780  97.573  -70.026  51.864  1
348781  97.603  -70.035  51.831  1
348782  97.634  -70.044  51.796  1
348783  97.664  -70.050  51.761  1
348784  97.696  -70.052  51.727  1
348785  97.729  -70.054  51.690  1
348786  97.761  -70.056  51.646  1
348787  97.794  -70.058  51.602  1
348788  97.826  -70.060  51.557  1
348789  97.859  -70.062  51.512  1
348790  97.891  -70.064  51.468  1
348791  97.925  -70.063  51.422  1
348792  97.959  -70.062  51.375  1
348793  97.994  -70.060  51.325  1
348794  98.028  -70.058  51.277  1
348795  98.062  -70.057  51.228  1
348796  98.096  -70.055  51.180  1
348797  98.131  -70.055  51.133  1
348798  98.165  -70.053  51.085  1
348799  98.198  -70.055  51.032  1
348800  98.227  -70.062  50.977  1
348801  98.257  -70.070  50.921  1
348802  98.287  -70.077  50.864  1
348803  98.317  -70.085  50.806  1
348804  98.347  -70.093  50.751  1
348805  98.377  -70.100  50.693  1
348806  98.407  -70.108  50.634  1
348807  98.437  -70.115  50.576  1
348808  98.466  -70.123  50.517  1
348809  98.497  -70.131  50.459  1
348810  98.526  -70.139  50.402  1
348811  98.557  -70.146  50.347  1
348812  98.587  -70.140  50.290  1
348813  98.620  -70.138  50.230  1
348814  98.658  -70.147  50.169  1
348815  98.696  -70.156  50.108  1
348816  98.734  -70.165  50.045  1
348817  98.773  -70.174  49.984  1
348818  98.813  -70.187  49.923  1
348819  98.854  -70.199  49.863  1
348820  98.895  -70.212  49.802  1
348821  98.935  -70.225  49.743  1
348822  98.976  -70.237  49.685  1
348823  99.016  -70.250  49.628  1
348824  99.057  -70.262  49.572  1
348825  99.097  -70.274  49.520  1
348826  99.138  -70.287  49.469  1
348827  99.179  -70.299  49.419  1
348828  99.219  -70.311  49.370  1
348829  99.260  -70.324  49.322  1
348830  99.297  -70.334  49.276  1
348831  99.334  -70.346  49.232  1
348832  99.370  -70.356  49.190  1
348833  99.417  -70.356  49.148  1
348834  99.463  -70.357  49.107  1
348835  99.505  -70.361  49.069  1
348836  99.548  -70.366  49.033  1
348837  99.594  -70.369  48.998  1
348838  99.642  -70.375  48.965  1
348839  99.674  -70.414  48.932  1
348840  99.705  -70.429  48.901  1
348841  99.736  -70.442  48.872  1
348842  99.767  -70.455  48.845  1
348843  99.798  -70.468  48.820  1
348844  99.829  -70.481  48.797  1
348845  99.860  -70.494  48.777  1
348846  99.891  -70.507  48.756  1
348847  99.922  -70.508  48.729  1
348848  99.954  -70.508  48.700  1
348849  99.986  -70.508  48.671  1
348850  100.018  -70.510  48.640  1
348851  100.051  -70.519  48.614  1
348852  100.084  -70.529  48.585  1
348853  100.117  -70.538  48.552  1
348854  100.150  -70.547  48.516  1
348855  100.184  -70.557  48.476  1
348856  100.216  -70.566  48.445  1
348857  100.250  -70.576  48.417  1
348858  100.292  -70.587  48.388  1
348859  100.335  -70.598  48.354  1
348860  100.378  -70.610  48.316  1
348861  100.421  -70.621  48.279  1
348862  100.467  -70.633  48.243  1
348863  100.515  -70.646  48.204  1
348864  100.565  -70.659  48.164  1
348865  100.603  -70.669  48.126  1
348866  100.637  -70.679  48.090  1
348867  100.671  -70.688  48.057  1
348868  100.706  -70.698  48.020  1
348869  100.741  -70.708  47.980  1
348870  100.775  -70.718  47.941  1
348871  100.810  -70.727  47.904  1
348872  100.844  -70.737  47.870  1
348873  100.879  -70.747  47.833  1
348874  100.901  -70.765  47.797  1
348875  100.923  -70.782  47.761  1
348876  100.956  -70.785  47.724  1
348877  100.989  -70.789  47.685  1
348878  101.022  -70.792  47.647  1
348879  101.054  -70.796  47.609  1
348880  101.090  -70.805  47.570  1
348881  101.126  -70.815  47.532  1
348882  101.160  -70.827  47.493  1
348883  101.188  -70.844  47.454  1
348884  101.215  -70.861  47.416  1
348885  101.243  -70.877  47.377  1
348886  101.274  -70.894  47.336  1
348887  101.313  -70.912  47.293  1
348888  101.365  -70.933  47.247  1
348889  101.418  -70.953  47.199  1
348890  101.471  -70.974  47.150  1
348891  101.523  -70.994  47.101  1
348892  101.575  -71.014  47.053  1
348893  101.628  -71.035  47.004  1
348894  101.681  -71.055  46.958  1
348895  101.733  -71.076  46.911  1
348896  101.785  -71.096  46.864  1
348897  101.818  -71.095  46.816  1
348898  101.785  -71.046  46.763  1
348899  101.793  -71.039  46.709  1
348900  101.823  -71.041  46.656  1
348901  101.853  -71.042  46.605  1
348902  101.883  -71.044  46.557  1
348903  101.913  -71.046  46.511  1
348904  101.943  -71.047  46.466  1
348905  101.973  -71.049  46.423  1
348906  102.004  -71.051  46.381  1
348907  102.033  -71.052  46.339  1
348908  102.063  -71.054  46.299  1
348909  102.093  -71.055  46.258  1
348910  102.123  -71.057  46.217  1
349323  92.187  -69.904  55.072  3
349324  92.226  -69.874  55.055  3
349325  92.266  -69.845  55.037  3
349326  92.305  -69.814  55.018  3
349327  92.345  -69.785  55.000  3
349328  92.384  -69.755  54.981  3
349329  92.423  -69.726  54.963  3
349330  92.462  -69.696  54.944  3
349331  92.502  -69.666  54.924  3
349332  92.541  -69.636  54.903  3
349333  92.580  -69.607  54.882  3
349334  92.619  -69.614  54.861  3
349335  92.667  -69.618  54.837  3
349336  92.715  -69.621  54.813  3
349337  92.763  -69.623  54.787  3
349338  92.811  -69.626  54.758  3
349339  92.859  -69.628  54.730  3
349340  92.908  -69.629  54.701  3
349341  92.958  -69.622  54.671  3
349342  93.009  -69.615  54.640  3
349343  93.057  -69.604  54.607  3
349344  93.094  -69.579  54.573  3
349345  93.132  -69.567  54.538  3
349346  93.167  -69.571  54.502  3
349347  93.204  -69.575  54.466  3
349348  93.240  -69.579  54.431  3
349349  93.276  -69.582  54.397  3
349350  93.312  -69.585  54.364  3
349351  93.348  -69.589  54.331  3
349352  93.384  -69.593  54.297  3
349353  93.421  -69.597  54.265  3
349354  93.457  -69.601  54.234  3
349355  93.493  -69.604  54.204  3
349356  93.529  -69.608  54.173  3
349357  93.565  -69.612  54.144  3
349358  93.602  -69.616  54.115  3
349392  94.688  -69.558  53.079  1
349393  94.719  -69.555  53.058  1
349394  94.751  -69.553  53.037  1
349395  94.782  -69.551  53.016  1
349396  94.814  -69.548  52.999  1
349397  94.845  -69.546  52.982  1
349398  94.877  -69.544  52.966  1
349399  94.908  -69.541  52.950  1
349400  94.939  -69.539  52.935  1
349401  94.971  -69.536  52.924  1
349402  95.002  -69.534  52.915  1
349403  95.034  -69.532  52.909  1
349404  95.065  -69.529  52.904  1
349405  95.107  -69.529  52.901  1
349406  95.199  -69.543  52.901  1
349407  95.291  -69.557  52.903  1
349408  95.369  -69.566  52.908  1
349409  95.397  -69.560  52.917  1
349410  95.425  -69.554  52.926  1
349411  95.453  -69.549  52.936  1
349412  95.480  -69.544  52.949  1
349413  95.508  -69.538  52.967  1
349414  95.536  -69.533  52.983  1
349415  95.564  -69.528  52.997  1
349416  95.592  -69.523  53.009  1
349417  95.619  -69.516  53.021  1
349418  95.648  -69.511  53.031  1
349419  95.675  -69.506  53.038  1
349420  95.703  -69.501  53.042  1
349421  95.731  -69.495  53.041  1
349422  95.758  -69.490  53.040  1
349423  95.787  -69.485  53.045  1
349424  95.814  -69.479  53.049  1
349425  95.842  -69.473  53.048  1
349426  95.876  -69.475  53.032  1
349427  95.911  -69.479  53.004  1
349428  95.947  -69.484  52.971  1
349429  95.982  -69.488  52.937  1
349430  96.018  -69.493  52.905  1
349431  96.036  -69.497  52.884  1
349432  96.066  -69.507  52.862  1
349433  96.097  -69.517  52.838  1
349434  96.128  -69.528  52.810  1
349435  96.160  -69.538  52.786  1
349436  96.191  -69.548  52.763  1
349437  96.218  -69.562  52.738  1
349438  96.244  -69.574  52.713  1
349439  96.270  -69.585  52.691  1
349440  96.294  -69.598  52.675  1
349441  96.317  -69.610  52.660  1
349442  96.341  -69.623  52.643  1
349443  96.364  -69.635  52.624  1
349444  96.388  -69.648  52.603  1
349445  96.411  -69.660  52.580  1
349446  96.435  -69.673  52.558  1
349447  96.459  -69.686  52.537  1
349448  96.495  -69.694  52.515  1
349449  96.534  -69.697  52.494  1
349450  96.565  -69.699  52.472  1
349451  96.595  -69.701  52.452  1
349452  96.625  -69.707  52.436  1
349453  96.658  -69.719  52.420  1
349454  96.692  -69.732  52.404  1
349455  96.725  -69.744  52.387  1
349456  96.759  -69.756  52.373  1
349457  96.792  -69.768  52.360  1
349458  96.825  -69.781  52.349  1
349459  96.859  -69.789  52.337  1
349460  96.892  -69.795  52.325  1
349461  96.926  -69.801  52.309  1
349462  96.959  -69.808  52.299  1
349463  96.992  -69.814  52.292  1
349464  97.025  -69.820  52.287  1
349465  97.056  -69.827  52.277  1
349466  97.088  -69.834  52.261  1
349467  97.123  -69.843  52.239  1
349468  97.158  -69.853  52.211  1
349469  97.192  -69.863  52.180  1
349470  97.227  -69.873  52.155  1
349471  97.263  -69.882  52.134  1
349472  97.299  -69.891  52.116  1
349473  97.335  -69.901  52.100  1
349474  97.371  -69.910  52.076  1
349475  97.398  -69.928  52.047  1
349476  97.429  -69.937  52.017  1
349477  97.459  -69.946  51.987  1
349478  97.490  -69.955  51.960  1
349479  97.520  -69.964  51.934  1
349480  97.550  -69.974  51.906  1
349481  97.581  -69.983  51.874  1
349482  97.611  -69.993  51.840  1
349483  97.641  -70.003  51.806  1
349484  97.673  -70.010  51.770  1
349485  97.708  -70.013  51.732  1
349486  97.740  -70.015  51.693  1
349487  97.773  -70.017  51.647  1
349488  97.805  -70.018  51.601  1
349489  97.838  -70.020  51.555  1
349490  97.870  -70.022  51.510  1
349491  97.903  -70.024  51.464  1
349492  97.937  -70.024  51.420  1
349493  97.971  -70.022  51.373  1
349494  98.005  -70.021  51.324  1
349495  98.039  -70.019  51.274  1
349496  98.074  -70.018  51.224  1
349497  98.108  -70.016  51.175  1
349498  98.142  -70.015  51.127  1
349499  98.174  -70.017  51.079  1
349500  98.205  -70.024  51.026  1
349501  98.234  -70.032  50.972  1
349502  98.265  -70.040  50.916  1
349503  98.294  -70.047  50.858  1
349504  98.324  -70.055  50.800  1
349505  98.354  -70.062  50.744  1
349506  98.384  -70.070  50.686  1
349507  98.414  -70.078  50.627  1
349508  98.444  -70.086  50.569  1
349509  98.474  -70.093  50.513  1
349510  98.504  -70.101  50.457  1
349511  98.533  -70.109  50.402  1
349512  98.564  -70.116  50.346  1
349513  98.594  -70.113  50.288  1
349514  98.625  -70.108  50.227  1
349515  98.661  -70.114  50.165  1
349516  98.700  -70.123  50.102  1
349517  98.737  -70.132  50.040  1
349518  98.777  -70.143  49.978  1
349519  98.817  -70.155  49.918  1
349520  98.858  -70.168  49.857  1
349521  98.899  -70.180  49.797  1
349522  98.939  -70.192  49.739  1
349523  98.980  -70.205  49.682  1
349524  99.020  -70.217  49.625  1
349525  99.061  -70.229  49.571  1
349526  99.102  -70.242  49.518  1
349527  99.142  -70.254  49.467  1
349528  99.183  -70.266  49.417  1
349529  99.224  -70.279  49.369  1
349530  99.264  -70.291  49.321  1
349531  99.303  -70.303  49.275  1
349532  99.340  -70.314  49.231  1
349533  99.383  -70.318  49.188  1
349534  99.427  -70.320  49.146  1
349535  99.470  -70.324  49.107  1
349536  99.512  -70.328  49.068  1
349537  99.554  -70.332  49.030  1
349538  99.602  -70.335  48.995  1
349539  99.652  -70.338  48.961  1
349540  99.688  -70.370  48.930  1
349541  99.719  -70.404  48.899  1
349542  99.750  -70.417  48.870  1
349543  99.781  -70.430  48.842  1
349544  99.812  -70.443  48.818  1
349545  99.843  -70.456  48.796  1
349546  99.874  -70.469  48.775  1
349547  99.905  -70.481  48.754  1
349548  99.937  -70.484  48.728  1
349549  99.969  -70.484  48.701  1
349550  100.000  -70.484  48.673  1
349551  100.032  -70.484  48.644  1
349552  100.064  -70.484  48.617  1
349553  100.096  -70.490  48.587  1
349554  100.129  -70.499  48.555  1
349555  100.162  -70.508  48.518  1
349556  100.195  -70.518  48.483  1
349557  100.228  -70.527  48.453  1
349558  100.262  -70.537  48.425  1
349559  100.303  -70.547  48.397  1
349560  100.346  -70.559  48.364  1
349561  100.390  -70.570  48.326  1
349562  100.434  -70.582  48.290  1
349563  100.484  -70.595  48.254  1
349564  100.533  -70.608  48.213  1
349565  100.582  -70.620  48.173  1
349566  100.631  -70.633  48.136  1
349567  100.668  -70.644  48.102  1
349568  100.702  -70.654  48.068  1
349569  100.737  -70.663  48.030  1
349570  100.771  -70.673  47.991  1
349571  100.805  -70.682  47.954  1
349572  100.840  -70.692  47.918  1
349573  100.874  -70.703  47.884  1
349574  100.895  -70.722  47.847  1
349575  100.915  -70.742  47.810  1
349576  100.943  -70.752  47.773  1
349577  100.975  -70.755  47.735  1
349578  101.008  -70.759  47.694  1
349579  101.041  -70.762  47.654  1
349580  101.073  -70.766  47.615  1
349581  101.106  -70.769  47.577  1
349582  101.140  -70.775  47.539  1
349583  101.169  -70.790  47.499  1
349584  101.197  -70.807  47.461  1
349585  101.225  -70.823  47.423  1
349586  101.252  -70.840  47.384  1
349587  101.281  -70.857  47.343  1
349588  101.321  -70.876  47.299  1
349589  101.373  -70.896  47.253  1
349590  101.425  -70.917  47.205  1
349591  101.478  -70.936  47.155  1
349592  101.531  -70.957  47.107  1
349593  101.583  -70.977  47.059  1
349594  101.633  -70.991  47.011  1
349595  101.684  -71.005  46.964  1
349596  101.735  -71.020  46.917  1
349597  101.785  -71.034  46.868  1
349598  101.773  -70.996  46.818  1
349599  101.777  -70.988  46.765  1
349600  101.807  -70.989  46.709  1
349601  101.837  -70.991  46.656  1
349602  101.867  -70.992  46.605  1
349603  101.897  -70.994  46.557  1
349604  101.927  -70.995  46.512  1
349605  101.957  -70.997  46.468  1
349606  101.987  -70.999  46.425  1
349607  102.017  -71.000  46.383  1
349608  102.047  -71.002  46.341  1
349609  102.077  -71.003  46.300  1
349610  102.107  -71.005  46.260  1
349611  102.137  -71.006  46.220  1
350024  92.178  -69.874  55.065  3
350025  92.217  -69.844  55.048  3
350026  92.257  -69.814  55.029  3
350027  92.296  -69.785  55.009  3
350028  92.336  -69.754  54.991  3
350029  92.375  -69.725  54.971  3
350030  92.414  -69.695  54.952  3
350031  92.453  -69.666  54.933  3
350032  92.493  -69.636  54.912  3
350033  92.532  -69.606  54.890  3
350034  92.571  -69.576  54.869  3
350035  92.612  -69.557  54.847  3
350036  92.660  -69.559  54.825  3
350037  92.708  -69.562  54.800  3
350038  92.757  -69.564  54.774  3
350039  92.804  -69.566  54.746  3
350040  92.853  -69.569  54.717  3
350041  92.901  -69.571  54.689  3
350042  92.950  -69.570  54.660  3
350043  93.000  -69.564  54.629  3
350044  93.047  -69.552  54.598  3
350045  93.085  -69.529  54.564  3
350046  93.121  -69.532  54.529  3
350047  93.157  -69.536  54.492  3
350048  93.193  -69.540  54.457  3
350049  93.229  -69.544  54.423  3
350050  93.266  -69.548  54.389  3
350051  93.302  -69.551  54.356  3
350052  93.338  -69.555  54.324  3
350053  93.374  -69.559  54.290  3
350054  93.410  -69.563  54.259  3
350055  93.446  -69.566  54.228  3
350056  93.482  -69.570  54.198  3
350057  93.518  -69.573  54.168  3
350092  94.656  -69.538  53.115  1
350093  94.687  -69.536  53.094  1
350094  94.719  -69.534  53.073  1
350095  94.750  -69.532  53.052  1
350096  94.782  -69.529  53.032  1
350097  94.813  -69.526  53.015  1
350098  94.845  -69.524  52.999  1
350099  94.876  -69.522  52.983  1
350100  94.907  -69.519  52.968  1
350101  94.939  -69.517  52.954  1
350102  94.970  -69.515  52.942  1
350103  95.002  -69.513  52.933  1
350104  95.033  -69.510  52.926  1
350105  95.065  -69.507  52.922  1
350106  95.148  -69.519  52.919  1
350107  95.241  -69.532  52.917  1
350108  95.333  -69.545  52.918  1
350109  95.392  -69.549  52.921  1
350110  95.419  -69.544  52.929  1
350111  95.448  -69.538  52.938  1
350112  95.475  -69.533  52.945  1
350113  95.503  -69.527  52.950  1
350114  95.531  -69.522  52.964  1
350115  95.558  -69.516  52.978  1
350116  95.587  -69.511  52.993  1
350117  95.614  -69.506  53.006  1
350118  95.642  -69.501  53.020  1
350119  95.670  -69.495  53.033  1
350120  95.698  -69.490  53.045  1
350121  95.726  -69.484  53.052  1
350122  95.753  -69.479  53.055  1
350123  95.781  -69.473  53.055  1
350124  95.809  -69.468  53.060  1
350125  95.837  -69.463  53.066  1
350126  95.865  -69.457  53.066  1
350127  95.892  -69.452  53.053  1
350128  95.920  -69.446  53.027  1
350129  95.953  -69.447  52.995  1
350130  95.988  -69.451  52.959  1
350131  96.024  -69.456  52.924  1
350132  96.056  -69.460  52.898  1
350133  96.080  -69.467  52.874  1
350134  96.111  -69.477  52.850  1
350135  96.143  -69.488  52.822  1
350136  96.173  -69.498  52.799  1
350137  96.200  -69.513  52.776  1
350138  96.223  -69.529  52.752  1
350139  96.248  -69.541  52.726  1
350140  96.274  -69.552  52.706  1
350141  96.301  -69.563  52.691  1
350142  96.327  -69.575  52.676  1
350143  96.354  -69.585  52.660  1
350144  96.377  -69.598  52.640  1
350145  96.401  -69.610  52.620  1
350146  96.425  -69.623  52.599  1
350147  96.448  -69.636  52.578  1
350148  96.472  -69.648  52.560  1
350149  96.508  -69.656  52.539  1
350150  96.541  -69.659  52.518  1
350151  96.571  -69.661  52.496  1
350152  96.603  -69.665  52.473  1
350153  96.636  -69.673  52.455  1
350154  96.669  -69.685  52.437  1
350155  96.703  -69.696  52.419  1
350156  96.737  -69.707  52.401  1
350157  96.770  -69.720  52.386  1
350158  96.804  -69.732  52.374  1
350159  96.837  -69.745  52.362  1
350160  96.870  -69.754  52.350  1
350161  96.904  -69.761  52.337  1
350162  96.937  -69.767  52.321  1
350163  96.969  -69.773  52.311  1
350164  97.001  -69.780  52.303  1
350165  97.032  -69.787  52.296  1
350166  97.064  -69.794  52.284  1
350167  97.096  -69.800  52.268  1
350168  97.129  -69.808  52.246  1
350169  97.164  -69.818  52.218  1
350170  97.198  -69.827  52.188  1
350171  97.233  -69.837  52.160  1
350172  97.268  -69.847  52.136  1
350173  97.303  -69.857  52.116  1
350174  97.338  -69.866  52.100  1
350175  97.373  -69.876  52.075  1
350176  97.406  -69.885  52.047  1
350177  97.436  -69.895  52.018  1
350178  97.466  -69.905  51.990  1
350179  97.496  -69.914  51.964  1
350180  97.526  -69.924  51.940  1
350181  97.557  -69.934  51.912  1
350182  97.587  -69.944  51.880  1
350183  97.616  -69.954  51.846  1
350184  97.647  -69.964  51.810  1
350185  97.681  -69.969  51.773  1
350186  97.717  -69.972  51.734  1
350187  97.752  -69.975  51.694  1
350188  97.785  -69.977  51.648  1
350189  97.817  -69.979  51.602  1
350190  97.850  -69.980  51.556  1
350191  97.882  -69.983  51.512  1
350192  97.915  -69.984  51.468  1
350193  97.948  -69.983  51.425  1
350194  97.983  -69.983  51.378  1
350195  98.017  -69.981  51.329  1
350196  98.051  -69.980  51.280  1
350197  98.085  -69.978  51.230  1
350198  98.120  -69.977  51.179  1
350199  98.152  -69.979  51.127  1
350200  98.181  -69.986  51.076  1
350201  98.212  -69.994  51.021  1
350202  98.241  -70.002  50.965  1
350203  98.272  -70.009  50.909  1
350204  98.301  -70.017  50.853  1
350205  98.332  -70.025  50.797  1
350206  98.361  -70.033  50.742  1
350207  98.391  -70.040  50.685  1
350208  98.421  -70.048  50.627  1
350209  98.451  -70.055  50.568  1
350210  98.481  -70.063  50.510  1
350211  98.511  -70.071  50.455  1
350212  98.541  -70.078  50.399  1
350213  98.571  -70.086  50.344  1
350214  98.601  -70.087  50.284  1
350215  98.632  -70.081  50.222  1
350216  98.664  -70.080  50.160  1
350217  98.703  -70.090  50.097  1
350218  98.741  -70.099  50.035  1
350219  98.781  -70.110  49.974  1
350220  98.822  -70.123  49.913  1
350221  98.862  -70.135  49.853  1
350222  98.903  -70.147  49.793  1
350223  98.944  -70.160  49.736  1
350224  98.984  -70.172  49.679  1
350225  99.025  -70.184  49.623  1
350226  99.065  -70.197  49.569  1
350227  99.106  -70.209  49.517  1
350228  99.147  -70.221  49.466  1
350229  99.187  -70.234  49.416  1
350230  99.228  -70.246  49.368  1
350231  99.269  -70.259  49.321  1
350232  99.309  -70.272  49.274  1
350233  99.349  -70.280  49.229  1
350234  99.392  -70.283  49.187  1
350235  99.434  -70.287  49.145  1
350236  99.476  -70.291  49.105  1
350237  99.518  -70.295  49.066  1
350238  99.560  -70.299  49.028  1
350239  99.611  -70.302  48.991  1
350240  99.660  -70.305  48.958  1
350241  99.701  -70.326  48.926  1
350242  99.733  -70.365  48.896  1
350243  99.765  -70.392  48.866  1
350244  99.795  -70.405  48.838  1
350245  99.827  -70.418  48.814  1
350246  99.857  -70.431  48.793  1
350247  99.889  -70.444  48.772  1
350248  99.919  -70.456  48.750  1
350249  99.951  -70.460  48.725  1
350250  99.983  -70.460  48.699  1
350251  100.014  -70.460  48.672  1
350252  100.046  -70.460  48.644  1
350253  100.078  -70.460  48.617  1
350254  100.110  -70.460  48.587  1
350255  100.141  -70.460  48.554  1
350256  100.174  -70.469  48.518  1
350257  100.207  -70.478  48.488  1
350258  100.241  -70.488  48.460  1
350259  100.274  -70.497  48.432  1
350260  100.315  -70.508  48.405  1
350261  100.358  -70.519  48.372  1
350262  100.402  -70.532  48.335  1
350263  100.452  -70.544  48.299  1
350264  100.501  -70.557  48.262  1
350265  100.550  -70.569  48.220  1
350266  100.599  -70.582  48.181  1
350267  100.648  -70.595  48.146  1
350268  100.697  -70.608  48.112  1
350269  100.733  -70.618  48.078  1
350270  100.767  -70.628  48.039  1
350271  100.802  -70.638  48.002  1
350272  100.836  -70.648  47.967  1
350273  100.867  -70.660  47.931  1
350274  100.888  -70.679  47.897  1
350275  100.909  -70.698  47.859  1
350276  100.930  -70.717  47.821  1
350277  100.962  -70.722  47.783  1
350278  100.994  -70.725  47.745  1
350279  101.027  -70.729  47.704  1
350280  101.060  -70.732  47.661  1
350281  101.093  -70.735  47.620  1
350282  101.125  -70.739  47.581  1
350283  101.152  -70.743  47.543  1
350284  101.179  -70.757  47.502  1
350285  101.206  -70.773  47.463  1
350286  101.234  -70.788  47.426  1
350287  101.261  -70.804  47.388  1
350288  101.289  -70.820  47.347  1
350289  101.328  -70.839  47.304  1
350290  101.380  -70.858  47.258  1
350291  101.430  -70.872  47.209  1
350292  101.481  -70.886  47.160  1
350293  101.532  -70.901  47.111  1
350294  101.583  -70.915  47.062  1
350295  101.633  -70.930  47.015  1
350296  101.684  -70.944  46.968  1
350297  101.735  -70.958  46.920  1
350298  101.775  -70.964  46.870  1
350299  101.761  -70.936  46.818  1
350300  101.791  -70.937  46.764  1
350301  101.821  -70.939  46.707  1
350302  101.851  -70.940  46.654  1
350303  101.881  -70.942  46.604  1
350304  101.911  -70.943  46.557  1
350305  101.941  -70.945  46.513  1
350306  101.971  -70.946  46.468  1
350307  102.001  -70.948  46.425  1
350308  102.031  -70.949  46.383  1
350309  102.061  -70.951  46.341  1
350310  102.091  -70.952  46.301  1
350311  102.121  -70.954  46.261  1
350725  92.169  -69.844  55.058  3
350726  92.208  -69.814  55.040  3
350727  92.247  -69.784  55.020  3
350728  92.287  -69.754  55.000  3
350729  92.326  -69.725  54.981  3
350730  92.366  -69.695  54.961  3
350731  92.405  -69.665  54.941  3
350732  92.444  -69.635  54.921  3
350733  92.484  -69.606  54.900  3
350734  92.523  -69.576  54.877  3
350735  92.562  -69.547  54.855  3
350736  92.607  -69.532  54.832  3
350737  92.655  -69.524  54.809  3
350738  92.702  -69.516  54.785  3
350739  92.750  -69.510  54.759  3
350740  92.798  -69.507  54.733  3
350741  92.846  -69.510  54.705  3
350742  92.894  -69.512  54.676  3
350743  92.942  -69.514  54.647  3
350744  92.992  -69.513  54.618  3
350745  93.038  -69.500  54.588  3
350746  93.074  -69.494  54.553  3
350747  93.111  -69.498  54.518  3
350748  93.147  -69.502  54.482  3
350749  93.183  -69.506  54.446  3
350750  93.219  -69.509  54.413  3
350751  93.255  -69.513  54.379  3
350752  93.291  -69.516  54.347  3
350753  93.327  -69.520  54.315  3
350754  93.363  -69.524  54.283  3
350755  93.400  -69.528  54.252  3
350756  93.436  -69.532  54.221  3
350757  93.472  -69.535  54.191  3
350792  94.624  -69.519  53.151  1
350793  94.655  -69.516  53.130  1
350794  94.687  -69.514  53.110  1
350795  94.718  -69.512  53.089  1
350796  94.750  -69.510  53.069  1
350797  94.781  -69.507  53.049  1
350798  94.813  -69.505  53.033  1
350799  94.844  -69.502  53.017  1
350800  94.876  -69.500  53.002  1
350801  94.907  -69.497  52.987  1
350802  94.938  -69.495  52.973  1
350803  94.970  -69.493  52.962  1
350804  95.001  -69.491  52.953  1
350805  95.033  -69.488  52.946  1
350806  95.098  -69.494  52.942  1
350807  95.190  -69.508  52.939  1
350808  95.282  -69.521  52.937  1
350809  95.374  -69.535  52.936  1
350810  95.414  -69.532  52.937  1
350811  95.442  -69.527  52.943  1
350812  95.470  -69.522  52.950  1
350813  95.498  -69.516  52.956  1
350814  95.526  -69.511  52.961  1
350815  95.553  -69.506  52.970  1
350816  95.581  -69.501  52.980  1
350817  95.609  -69.494  52.991  1
350818  95.637  -69.489  53.004  1
350819  95.665  -69.484  53.019  1
350820  95.692  -69.479  53.034  1
350821  95.720  -69.473  53.048  1
350822  95.748  -69.468  53.059  1
350823  95.776  -69.463  53.066  1
350824  95.804  -69.457  53.068  1
350825  95.831  -69.451  53.073  1
350826  95.860  -69.446  53.078  1
350827  95.887  -69.441  53.079  1
350828  95.915  -69.435  53.069  1
350829  95.943  -69.430  53.047  1
350830  95.970  -69.425  53.017  1
350831  95.999  -69.419  52.982  1
350832  96.030  -69.419  52.946  1
350833  96.066  -69.423  52.916  1
350834  96.095  -69.428  52.889  1
350835  96.125  -69.438  52.863  1
350836  96.156  -69.448  52.834  1
350837  96.183  -69.462  52.810  1
350838  96.203  -69.480  52.786  1
350839  96.227  -69.495  52.763  1
350840  96.252  -69.508  52.739  1
350841  96.278  -69.519  52.721  1
350842  96.305  -69.530  52.709  1
350843  96.331  -69.541  52.696  1
350844  96.358  -69.553  52.680  1
350845  96.384  -69.564  52.661  1
350846  96.410  -69.576  52.641  1
350847  96.437  -69.586  52.621  1
350848  96.461  -69.599  52.602  1
350849  96.484  -69.611  52.588  1
350850  96.517  -69.618  52.566  1
350851  96.548  -69.622  52.544  1
350852  96.581  -69.628  52.521  1
350853  96.613  -69.634  52.496  1
350854  96.646  -69.642  52.474  1
350855  96.679  -69.654  52.454  1
350856  96.713  -69.665  52.435  1
350857  96.747  -69.676  52.416  1
350858  96.781  -69.687  52.402  1
350859  96.814  -69.698  52.389  1
350860  96.848  -69.710  52.377  1
350861  96.881  -69.720  52.364  1
350862  96.912  -69.726  52.349  1
350863  96.945  -69.733  52.333  1
350864  96.976  -69.740  52.322  1
350865  97.008  -69.746  52.312  1
350866  97.040  -69.753  52.302  1
350867  97.072  -69.760  52.288  1
350868  97.103  -69.767  52.272  1
350869  97.135  -69.773  52.250  1
350870  97.170  -69.783  52.223  1
350871  97.205  -69.792  52.195  1
350872  97.239  -69.801  52.165  1
350873  97.275  -69.811  52.138  1
350874  97.309  -69.821  52.116  1
350875  97.344  -69.831  52.097  1
350876  97.379  -69.840  52.072  1
350877  97.411  -69.848  52.045  1
350878  97.442  -69.855  52.016  1
350879  97.472  -69.865  51.989  1
350880  97.502  -69.875  51.965  1
350881  97.532  -69.885  51.942  1
350882  97.563  -69.895  51.915  1
350883  97.592  -69.905  51.883  1
350884  97.623  -69.914  51.848  1
350885  97.653  -69.924  51.810  1
350886  97.688  -69.928  51.772  1
350887  97.725  -69.931  51.734  1
350888  97.761  -69.934  51.694  1
350889  97.796  -69.937  51.649  1
350890  97.828  -69.939  51.604  1
350891  97.861  -69.941  51.559  1
350892  97.893  -69.942  51.517  1
350893  97.926  -69.945  51.476  1
350894  97.960  -69.944  51.434  1
350895  97.994  -69.943  51.388  1
350896  98.028  -69.942  51.339  1
350897  98.062  -69.940  51.290  1
350898  98.096  -69.939  51.239  1
350899  98.129  -69.941  51.186  1
350900  98.159  -69.949  51.131  1
350901  98.189  -69.956  51.075  1
350902  98.219  -69.964  51.018  1
350903  98.248  -69.972  50.961  1
350904  98.279  -69.980  50.905  1
350905  98.308  -69.987  50.849  1
350906  98.339  -69.995  50.797  1
350907  98.368  -70.002  50.744  1
350908  98.398  -70.010  50.688  1
350909  98.428  -70.018  50.629  1
350910  98.458  -70.025  50.569  1
350911  98.488  -70.033  50.510  1
350912  98.518  -70.040  50.452  1
350913  98.548  -70.048  50.396  1
350914  98.578  -70.055  50.341  1
350915  98.608  -70.060  50.279  1
350916  98.639  -70.055  50.217  1
350917  98.669  -70.049  50.155  1
350918  98.706  -70.056  50.093  1
350919  98.745  -70.065  50.030  1
350920  98.786  -70.078  49.969  1
350921  98.826  -70.090  49.908  1
350922  98.867  -70.102  49.849  1
350923  98.907  -70.115  49.790  1
350924  98.948  -70.127  49.732  1
350925  98.989  -70.140  49.676  1
350926  99.029  -70.152  49.621  1
350927  99.070  -70.165  49.568  1
350928  99.111  -70.177  49.517  1
350929  99.151  -70.190  49.466  1
350930  99.192  -70.202  49.416  1
350931  99.232  -70.215  49.367  1
350932  99.277  -70.228  49.320  1
350933  99.316  -70.240  49.273  1
350934  99.356  -70.246  49.228  1
350935  99.398  -70.250  49.185  1
350936  99.440  -70.254  49.144  1
350937  99.482  -70.258  49.104  1
350938  99.524  -70.262  49.064  1
350939  99.569  -70.265  49.025  1
350940  99.619  -70.268  48.988  1
350941  99.668  -70.272  48.954  1
350942  99.715  -70.282  48.923  1
350943  99.747  -70.321  48.891  1
350944  99.779  -70.359  48.861  1
350945  99.810  -70.380  48.832  1
350946  99.841  -70.393  48.809  1
350947  99.872  -70.406  48.787  1
350948  99.903  -70.419  48.765  1
350949  99.934  -70.431  48.743  1
350950  99.965  -70.435  48.719  1
350951  99.997  -70.435  48.693  1
350952  100.028  -70.435  48.667  1
350953  100.060  -70.435  48.639  1
350954  100.092  -70.435  48.612  1
350955  100.124  -70.436  48.582  1
350956  100.155  -70.436  48.549  1
350957  100.187  -70.436  48.517  1
350958  100.219  -70.439  48.490  1
350959  100.253  -70.449  48.464  1
350960  100.286  -70.458  48.438  1
350961  100.326  -70.469  48.411  1
350962  100.370  -70.481  48.379  1
350963  100.419  -70.494  48.343  1
350964  100.469  -70.506  48.306  1
350965  100.518  -70.519  48.268  1
350966  100.567  -70.532  48.228  1
350967  100.616  -70.544  48.194  1
350968  100.665  -70.557  48.159  1
350969  100.714  -70.570  48.124  1
350970  100.763  -70.583  48.089  1
350971  100.797  -70.593  48.051  1
350972  100.832  -70.603  48.016  1
350973  100.860  -70.616  47.980  1
350974  100.881  -70.635  47.944  1
350975  100.902  -70.655  47.907  1
350976  100.923  -70.674  47.869  1
350977  100.948  -70.688  47.829  1
350978  100.981  -70.691  47.789  1
350979  101.013  -70.695  47.749  1
350980  101.046  -70.698  47.707  1
350981  101.079  -70.701  47.664  1
350982  101.108  -70.705  47.622  1
350983  101.135  -70.710  47.581  1
350984  101.162  -70.713  47.543  1
350985  101.190  -70.727  47.502  1
350986  101.217  -70.742  47.464  1
350987  101.245  -70.758  47.427  1
350988  101.272  -70.773  47.389  1
350989  101.299  -70.789  47.348  1
350990  101.332  -70.804  47.304  1
350991  101.381  -70.811  47.258  1
350992  101.431  -70.816  47.209  1
350993  101.481  -70.825  47.160  1
350994  101.532  -70.839  47.111  1
350995  101.583  -70.854  47.062  1
350996  101.633  -70.868  47.015  1
350997  101.684  -70.883  46.969  1
350998  101.734  -70.897  46.920  1
350999  101.745  -70.883  46.869  1
351000  101.775  -70.885  46.816  1
351001  101.805  -70.886  46.759  1
351002  101.835  -70.888  46.703  1
351003  101.865  -70.889  46.651  1
351004  101.895  -70.891  46.603  1
351005  101.925  -70.892  46.557  1
351006  101.955  -70.895  46.512  1
351007  101.985  -70.896  46.469  1
351008  102.015  -70.898  46.426  1
351009  102.045  -70.899  46.383  1
351010  102.075  -70.901  46.342  1
351011  102.105  -70.902  46.302  1
351427  92.199  -69.784  55.031  3
351428  92.238  -69.754  55.012  3
351429  92.278  -69.724  54.991  3
351430  92.317  -69.695  54.971  3
351431  92.357  -69.665  54.951  3
351432  92.396  -69.635  54.930  3
351433  92.435  -69.605  54.909  3
351434  92.475  -69.576  54.887  3
351435  92.514  -69.546  54.864  3
351436  92.556  -69.523  54.841  3
351437  92.603  -69.515  54.817  3
351438  92.651  -69.508  54.793  3
351439  92.698  -69.501  54.769  3
351440  92.746  -69.493  54.744  3
351441  92.793  -69.485  54.717  3
351442  92.841  -69.478  54.689  3
351443  92.888  -69.470  54.661  3
351444  92.936  -69.463  54.632  3
351445  92.984  -69.458  54.604  3
351446  93.027  -69.456  54.573  3
351447  93.064  -69.460  54.540  3
351448  93.100  -69.463  54.505  3
351449  93.136  -69.467  54.469  3
351450  93.172  -69.471  54.434  3
351451  93.208  -69.475  54.401  3
351452  93.245  -69.479  54.368  3
351453  93.281  -69.482  54.336  3
351454  93.317  -69.486  54.304  3
351455  93.353  -69.490  54.272  3
351456  93.389  -69.493  54.242  3
351457  93.425  -69.497  54.212  3
351458  93.462  -69.501  54.183  3
351493  94.623  -69.497  53.165  1
351494  94.654  -69.495  53.146  1
351495  94.686  -69.492  53.126  1
351496  94.717  -69.490  53.107  1
351497  94.749  -69.488  53.087  1
351498  94.780  -69.485  53.067  1
351499  94.812  -69.483  53.052  1
351500  94.843  -69.481  53.037  1
351501  94.875  -69.479  53.021  1
351502  94.906  -69.476  53.006  1
351503  94.937  -69.473  52.994  1
351504  94.969  -69.471  52.982  1
351505  95.000  -69.469  52.974  1
351506  95.047  -69.470  52.968  1
351507  95.139  -69.484  52.964  1
351508  95.231  -69.497  52.961  1
351509  95.323  -69.510  52.958  1
351510  95.409  -69.522  52.957  1
351511  95.437  -69.516  52.957  1
351512  95.465  -69.511  52.960  1
351513  95.492  -69.506  52.965  1
351514  95.520  -69.500  52.971  1
351515  95.548  -69.494  52.978  1
351516  95.576  -69.489  52.983  1
351517  95.604  -69.484  52.990  1
351518  95.631  -69.479  52.999  1
351519  95.660  -69.473  53.010  1
351520  95.687  -69.468  53.023  1
351521  95.715  -69.462  53.037  1
351522  95.743  -69.457  53.050  1
351523  95.770  -69.451  53.063  1
351524  95.799  -69.446  53.074  1
351525  95.826  -69.441  53.079  1
351526  95.854  -69.435  53.085  1
351527  95.882  -69.430  53.089  1
351528  95.910  -69.425  53.090  1
351529  95.938  -69.419  53.080  1
351530  95.965  -69.413  53.060  1
351531  95.993  -69.408  53.032  1
351532  96.021  -69.403  52.998  1
351533  96.049  -69.397  52.961  1
351534  96.077  -69.392  52.930  1
351535  96.108  -69.391  52.902  1
351536  96.138  -69.397  52.875  1
351537  96.165  -69.412  52.847  1
351538  96.186  -69.430  52.820  1
351539  96.208  -69.447  52.796  1
351540  96.232  -69.462  52.774  1
351541  96.256  -69.475  52.754  1
351542  96.283  -69.486  52.740  1
351543  96.309  -69.497  52.729  1
351544  96.335  -69.508  52.717  1
351545  96.362  -69.519  52.702  1
351546  96.388  -69.531  52.683  1
351547  96.415  -69.542  52.662  1
351548  96.441  -69.554  52.643  1
351549  96.467  -69.565  52.627  1
351550  96.494  -69.576  52.611  1
351551  96.526  -69.584  52.590  1
351552  96.558  -69.590  52.567  1
351553  96.590  -69.596  52.542  1
351554  96.623  -69.603  52.518  1
351555  96.656  -69.611  52.495  1
351556  96.689  -69.623  52.474  1
351557  96.723  -69.634  52.454  1
351558  96.757  -69.645  52.435  1
351559  96.791  -69.656  52.419  1
351560  96.824  -69.667  52.403  1
351561  96.855  -69.671  52.387  1
351562  96.888  -69.682  52.371  1
351563  96.920  -69.692  52.354  1
351564  96.952  -69.699  52.339  1
351565  96.984  -69.706  52.325  1
351566  97.016  -69.713  52.313  1
351567  97.047  -69.720  52.300  1
351568  97.079  -69.726  52.284  1
351569  97.111  -69.733  52.267  1
351570  97.143  -69.739  52.246  1
351571  97.176  -69.747  52.220  1
351572  97.211  -69.757  52.192  1
351573  97.246  -69.767  52.163  1
351574  97.281  -69.776  52.135  1
351575  97.315  -69.786  52.109  1
351576  97.350  -69.795  52.088  1
351577  97.384  -69.805  52.062  1
351578  97.416  -69.811  52.035  1
351579  97.447  -69.818  52.007  1
351580  97.478  -69.826  51.981  1
351581  97.508  -69.836  51.959  1
351582  97.538  -69.845  51.938  1
351583  97.568  -69.855  51.912  1
351584  97.598  -69.865  51.881  1
351585  97.629  -69.875  51.845  1
351586  97.660  -69.883  51.806  1
351587  97.696  -69.887  51.768  1
351588  97.732  -69.890  51.730  1
351589  97.769  -69.893  51.691  1
351590  97.805  -69.896  51.648  1
351591  97.840  -69.899  51.605  1
351592  97.873  -69.901  51.564  1
351593  97.905  -69.903  51.524  1
351594  97.938  -69.905  51.484  1
351595  97.971  -69.905  51.443  1
351596  98.005  -69.903  51.398  1
351597  98.039  -69.902  51.350  1
351598  98.074  -69.901  51.300  1
351599  98.106  -69.903  51.248  1
351600  98.136  -69.911  51.194  1
351601  98.166  -69.919  51.138  1
351602  98.196  -69.927  51.083  1
351603  98.226  -69.934  51.025  1
351604  98.255  -69.942  50.967  1
351605  98.286  -69.949  50.911  1
351606  98.315  -69.957  50.855  1
351607  98.346  -69.964  50.803  1
351608  98.375  -69.972  50.748  1
351609  98.405  -69.980  50.691  1
351610  98.435  -69.987  50.632  1
351611  98.465  -69.995  50.570  1
351612  98.495  -70.002  50.510  1
351613  98.525  -70.010  50.450  1
351614  98.555  -70.018  50.393  1
351615  98.585  -70.025  50.337  1
351616  98.615  -70.033  50.274  1
351617  98.645  -70.027  50.213  1
351618  98.676  -70.022  50.150  1
351619  98.710  -70.023  50.087  1
351620  98.749  -70.033  50.025  1
351621  98.790  -70.046  49.965  1
351622  98.831  -70.058  49.905  1
351623  98.871  -70.071  49.845  1
351624  98.912  -70.083  49.788  1
351625  98.952  -70.096  49.731  1
351626  98.994  -70.108  49.675  1
351627  99.039  -70.121  49.620  1
351628  99.084  -70.135  49.567  1
351629  99.129  -70.149  49.515  1
351630  99.174  -70.162  49.464  1
351631  99.219  -70.176  49.414  1
351632  99.256  -70.187  49.366  1
351633  99.289  -70.198  49.318  1
351634  99.324  -70.206  49.271  1
351635  99.362  -70.212  49.226  1
351636  99.405  -70.217  49.184  1
351637  99.446  -70.221  49.143  1
351638  99.489  -70.225  49.102  1
351639  99.531  -70.229  49.062  1
351640  99.577  -70.232  49.023  1
351641  99.627  -70.235  48.985  1
351642  99.677  -70.238  48.950  1
351643  99.727  -70.241  48.917  1
351644  99.760  -70.277  48.884  1
351645  99.792  -70.315  48.852  1
351646  99.824  -70.354  48.823  1
351647  99.855  -70.369  48.797  1
351648  99.886  -70.381  48.773  1
351649  99.917  -70.394  48.750  1
351650  99.948  -70.407  48.728  1
351651  99.980  -70.411  48.704  1
351652  100.011  -70.411  48.680  1
351653  100.043  -70.412  48.656  1
351654  100.075  -70.412  48.630  1
351655  100.107  -70.412  48.603  1
351656  100.138  -70.412  48.575  1
351657  100.170  -70.412  48.545  1
351658  100.202  -70.412  48.515  1
351659  100.233  -70.412  48.490  1
351660  100.265  -70.412  48.465  1
351661  100.298  -70.419  48.440  1
351662  100.338  -70.430  48.413  1
351663  100.388  -70.443  48.382  1
351664  100.436  -70.455  48.347  1
351665  100.486  -70.468  48.310  1
351666  100.535  -70.481  48.273  1
351667  100.584  -70.494  48.235  1
351668  100.633  -70.507  48.202  1
351669  100.683  -70.519  48.169  1
351670  100.732  -70.532  48.134  1
351671  100.781  -70.545  48.098  1
351672  100.828  -70.557  48.061  1
351673  100.854  -70.573  48.025  1
351674  100.875  -70.593  47.988  1
351675  100.896  -70.612  47.951  1
351676  100.916  -70.632  47.912  1
351677  100.937  -70.651  47.873  1
351678  100.967  -70.658  47.832  1
351679  101.000  -70.661  47.791  1
351680  101.033  -70.665  47.750  1
351681  101.064  -70.668  47.707  1
351682  101.092  -70.673  47.664  1
351683  101.119  -70.676  47.621  1
351684  101.146  -70.680  47.579  1
351685  101.173  -70.685  47.539  1
351686  101.200  -70.697  47.500  1
351687  101.228  -70.712  47.463  1
351688  101.255  -70.728  47.426  1
351689  101.282  -70.743  47.388  1
351690  101.312  -70.758  47.346  1
351691  101.346  -70.774  47.301  1
351692  101.383  -70.788  47.255  1
351693  101.433  -70.793  47.206  1
351694  101.483  -70.798  47.157  1
351695  101.533  -70.804  47.108  1
351696  101.584  -70.809  47.060  1
351697  101.633  -70.815  47.013  1
351698  101.684  -70.821  46.967  1
351699  101.733  -70.834  46.917  1
351700  101.759  -70.833  46.865  1
351701  101.789  -70.835  46.810  1
351702  101.819  -70.836  46.752  1
351703  101.849  -70.838  46.697  1
351704  101.879  -70.839  46.647  1
351705  101.909  -70.841  46.600  1
351706  101.939  -70.842  46.556  1
351707  101.969  -70.844  46.511  1
351708  101.999  -70.845  46.468  1
351709  102.029  -70.847  46.426  1
351710  102.059  -70.848  46.383  1
351711  102.089  -70.850  46.342  1
351712  102.119  -70.851  46.302  1
352128  92.190  -69.754  55.024  3
352129  92.229  -69.724  55.003  3
352130  92.269  -69.695  54.982  3
352131  92.308  -69.664  54.961  3
352132  92.348  -69.635  54.940  3
352133  92.387  -69.605  54.918  3
352134  92.426  -69.576  54.896  3
352135  92.465  -69.546  54.873  3
352136  92.505  -69.516  54.850  3
352137  92.552  -69.507  54.826  3
352138  92.599  -69.499  54.802  3
352139  92.647  -69.491  54.777  3
352140  92.694  -69.484  54.753  3
352141  92.742  -69.476  54.728  3
352142  92.789  -69.469  54.701  3
352143  92.837  -69.462  54.672  3
352144  92.884  -69.454  54.645  3
352145  92.932  -69.447  54.617  3
352146  92.979  -69.438  54.588  3
352147  93.021  -69.430  54.557  3
352148  93.056  -69.431  54.524  3
352149  93.090  -69.432  54.490  3
352150  93.126  -69.433  54.455  3
352151  93.162  -69.436  54.421  3
352152  93.198  -69.440  54.388  3
352153  93.234  -69.444  54.356  3
352154  93.270  -69.447  54.324  3
352155  93.306  -69.451  54.292  3
352156  93.342  -69.455  54.261  3
352157  93.378  -69.459  54.231  3
352158  93.415  -69.463  54.202  3
352159  93.451  -69.466  54.173  3
352193  94.591  -69.478  53.199  1
352194  94.622  -69.476  53.180  1
352195  94.654  -69.473  53.162  1
352196  94.685  -69.471  53.143  1
352197  94.717  -69.469  53.124  1
352198  94.748  -69.466  53.105  1
352199  94.780  -69.463  53.087  1
352200  94.811  -69.461  53.072  1
352201  94.842  -69.459  53.057  1
352202  94.874  -69.457  53.043  1
352203  94.905  -69.454  53.029  1
352204  94.937  -69.452  53.017  1
352205  94.968  -69.450  53.007  1
352206  95.000  -69.447  52.999  1
352207  95.089  -69.460  52.993  1
352208  95.181  -69.472  52.990  1
352209  95.273  -69.486  52.987  1
352210  95.365  -69.500  52.983  1
352211  95.431  -69.505  52.981  1
352212  95.460  -69.500  52.980  1
352213  95.487  -69.494  52.983  1
352214  95.515  -69.489  52.987  1
352215  95.543  -69.484  52.994  1
352216  95.570  -69.479  53.002  1
352217  95.599  -69.473  53.007  1
352218  95.626  -69.467  53.012  1
352219  95.654  -69.462  53.018  1
352220  95.682  -69.457  53.026  1
352221  95.710  -69.451  53.033  1
352222  95.738  -69.446  53.042  1
352223  95.765  -69.441  53.053  1
352224  95.793  -69.435  53.065  1
352225  95.820  -69.429  53.079  1
352226  95.848  -69.424  53.088  1
352227  95.875  -69.418  53.095  1
352228  95.902  -69.413  53.099  1
352229  95.930  -69.407  53.099  1
352230  95.957  -69.401  53.089  1
352231  95.984  -69.395  53.069  1
352232  96.012  -69.390  53.042  1
352233  96.039  -69.384  53.009  1
352234  96.066  -69.378  52.972  1
352235  96.093  -69.372  52.941  1
352236  96.120  -69.366  52.913  1
352237  96.148  -69.361  52.887  1
352238  96.169  -69.380  52.859  1
352239  96.189  -69.398  52.831  1
352240  96.213  -69.413  52.807  1
352241  96.236  -69.428  52.788  1
352242  96.261  -69.441  52.773  1
352243  96.287  -69.453  52.763  1
352244  96.314  -69.464  52.752  1
352245  96.340  -69.476  52.740  1
352246  96.366  -69.487  52.726  1
352247  96.393  -69.498  52.707  1
352248  96.419  -69.509  52.685  1
352249  96.445  -69.520  52.666  1
352250  96.472  -69.532  52.650  1
352251  96.507  -69.544  52.633  1
352252  96.537  -69.551  52.612  1
352253  96.568  -69.559  52.588  1
352254  96.600  -69.565  52.563  1
352255  96.632  -69.571  52.539  1
352256  96.666  -69.580  52.515  1
352257  96.699  -69.591  52.493  1
352258  96.733  -69.603  52.472  1
352259  96.767  -69.614  52.451  1
352260  96.799  -69.620  52.432  1
352261  96.830  -69.625  52.413  1
352262  96.861  -69.629  52.393  1
352263  96.894  -69.644  52.373  1
352264  96.928  -69.659  52.355  1
352265  96.960  -69.666  52.339  1
352266  96.992  -69.673  52.323  1
352267  97.023  -69.679  52.308  1
352268  97.055  -69.686  52.293  1
352269  97.087  -69.692  52.275  1
352270  97.118  -69.699  52.257  1
352271  97.150  -69.705  52.235  1
352272  97.182  -69.712  52.210  1
352273  97.217  -69.722  52.182  1
352274  97.252  -69.731  52.153  1
352275  97.287  -69.741  52.124  1
352276  97.321  -69.751  52.097  1
352277  97.356  -69.760  52.074  1
352278  97.388  -69.767  52.048  1
352279  97.420  -69.775  52.021  1
352280  97.452  -69.782  51.995  1
352281  97.483  -69.789  51.969  1
352282  97.514  -69.796  51.950  1
352283  97.544  -69.806  51.930  1
352284  97.574  -69.816  51.906  1
352285  97.604  -69.826  51.875  1
352286  97.634  -69.836  51.839  1
352287  97.667  -69.842  51.802  1
352288  97.704  -69.845  51.764  1
352289  97.740  -69.848  51.726  1
352290  97.776  -69.852  51.689  1
352291  97.812  -69.855  51.648  1
352292  97.849  -69.858  51.607  1
352293  97.884  -69.861  51.568  1
352294  97.917  -69.863  51.530  1
352295  97.949  -69.865  51.491  1
352296  97.983  -69.865  51.450  1
352297  98.017  -69.864  51.406  1
352298  98.051  -69.863  51.357  1
352299  98.083  -69.866  51.307  1
352300  98.113  -69.874  51.253  1
352301  98.143  -69.881  51.198  1
352302  98.173  -69.889  51.142  1
352303  98.203  -69.896  51.086  1
352304  98.233  -69.904  51.027  1
352305  98.263  -69.911  50.971  1
352306  98.293  -69.919  50.915  1
352307  98.322  -69.927  50.860  1
352308  98.353  -69.934  50.807  1
352309  98.382  -69.942  50.750  1
352310  98.412  -69.949  50.692  1
352311  98.442  -69.957  50.632  1
352312  98.472  -69.964  50.570  1
352313  98.502  -69.972  50.510  1
352314  98.532  -69.980  50.451  1
352315  98.562  -69.988  50.392  1
352316  98.592  -69.996  50.335  1
352317  98.622  -70.003  50.273  1
352318  98.652  -70.001  50.212  1
352319  98.683  -69.996  50.150  1
352320  98.714  -69.990  50.086  1
352321  98.756  -70.002  50.024  1
352322  98.801  -70.015  49.963  1
352323  98.846  -70.029  49.903  1
352324  98.891  -70.043  49.843  1
352325  98.936  -70.056  49.786  1
352326  98.981  -70.070  49.730  1
352327  99.026  -70.083  49.674  1
352328  99.071  -70.097  49.618  1
352329  99.116  -70.111  49.565  1
352330  99.161  -70.124  49.513  1
352331  99.196  -70.135  49.463  1
352332  99.229  -70.145  49.413  1
352333  99.262  -70.156  49.365  1
352334  99.294  -70.165  49.316  1
352335  99.332  -70.172  49.269  1
352336  99.370  -70.179  49.224  1
352337  99.411  -70.184  49.182  1
352338  99.453  -70.187  49.140  1
352339  99.495  -70.192  49.099  1
352340  99.538  -70.196  49.059  1
352341  99.585  -70.199  49.020  1
352342  99.635  -70.202  48.981  1
352343  99.686  -70.205  48.946  1
352344  99.735  -70.208  48.911  1
352345  99.774  -70.233  48.877  1
352346  99.806  -70.272  48.844  1
352347  99.838  -70.310  48.814  1
352348  99.869  -70.344  48.785  1
352349  99.901  -70.356  48.758  1
352350  99.931  -70.369  48.734  1
352351  99.963  -70.382  48.711  1
352352  99.994  -70.388  48.687  1
352353  100.025  -70.388  48.665  1
352354  100.057  -70.388  48.643  1
352355  100.089  -70.388  48.620  1
352356  100.121  -70.388  48.593  1
352357  100.152  -70.388  48.567  1
352358  100.184  -70.388  48.539  1
352359  100.216  -70.388  48.511  1
352360  100.248  -70.388  48.486  1
352361  100.279  -70.388  48.462  1
352362  100.311  -70.386  48.437  1
352363  100.355  -70.395  48.411  1
352364  100.404  -70.408  48.381  1
352365  100.453  -70.421  48.348  1
352366  100.502  -70.434  48.312  1
352367  100.551  -70.447  48.276  1
352368  100.600  -70.460  48.240  1
352369  100.649  -70.474  48.207  1
352370  100.698  -70.487  48.174  1
352371  100.748  -70.500  48.139  1
352372  100.797  -70.513  48.103  1
352373  100.845  -70.526  48.068  1
352374  100.867  -70.549  48.030  1
352375  100.889  -70.569  47.992  1
352376  100.910  -70.588  47.953  1
352377  100.931  -70.607  47.912  1
352378  100.954  -70.624  47.872  1
352379  100.986  -70.628  47.831  1
352380  101.019  -70.631  47.789  1
352381  101.048  -70.635  47.748  1
352382  101.075  -70.639  47.705  1
352383  101.102  -70.643  47.661  1
352384  101.129  -70.647  47.617  1
352385  101.156  -70.651  47.573  1
352386  101.183  -70.655  47.533  1
352387  101.211  -70.666  47.496  1
352388  101.238  -70.682  47.460  1
352389  101.266  -70.698  47.423  1
352390  101.293  -70.713  47.384  1
352391  101.325  -70.728  47.339  1
352392  101.360  -70.743  47.294  1
352393  101.394  -70.759  47.248  1
352394  101.435  -70.770  47.200  1
352395  101.486  -70.775  47.151  1
352396  101.536  -70.781  47.101  1
352397  101.586  -70.786  47.052  1
352398  101.636  -70.792  47.004  1
352399  101.686  -70.797  46.957  1
352400  101.732  -70.796  46.906  1
352401  101.778  -70.795  46.853  1
352402  101.809  -70.792  46.798  1
352403  101.835  -70.789  46.742  1
352404  101.863  -70.787  46.691  1
352405  101.893  -70.789  46.642  1
352406  101.922  -70.790  46.596  1
352407  101.953  -70.792  46.552  1
352408  101.983  -70.793  46.508  1
352409  102.013  -70.795  46.466  1
352410  102.043  -70.796  46.424  1
352411  102.073  -70.798  46.382  1
352412  102.103  -70.799  46.341  1
352830  92.220  -69.694  54.995  3
352831  92.260  -69.664  54.973  3
352832  92.299  -69.635  54.952  3
352833  92.338  -69.605  54.930  3
352834  92.378  -69.575  54.907  3
352835  92.417  -69.545  54.885  3
352836  92.456  -69.516  54.861  3
352837  92.500  -69.497  54.837  3
352838  92.548  -69.490  54.813  3
352839  92.595  -69.482  54.788  3
352840  92.643  -69.475  54.762  3
352841  92.690  -69.467  54.737  3
352842  92.738  -69.460  54.711  3
352843  92.785  -69.453  54.684  3
352844  92.833  -69.445  54.656  3
352845  92.880  -69.438  54.629  3
352846  92.928  -69.429  54.600  3
352847  92.972  -69.418  54.571  3
352848  93.015  -69.408  54.540  3
352849  93.050  -69.409  54.507  3
352850  93.085  -69.410  54.474  3
352851  93.120  -69.410  54.440  3
352852  93.155  -69.411  54.407  3
352853  93.190  -69.412  54.375  3
352854  93.225  -69.413  54.343  3
352855  93.260  -69.413  54.311  3
352856  93.296  -69.417  54.279  3
352857  93.332  -69.420  54.249  3
352858  93.368  -69.424  54.220  3
352859  93.404  -69.428  54.191  3
352860  93.440  -69.432  54.162  3
352893  94.559  -69.459  53.234  1
352894  94.591  -69.456  53.214  1
352895  94.622  -69.454  53.196  1
352896  94.653  -69.451  53.178  1
352897  94.685  -69.449  53.160  1
352898  94.716  -69.447  53.142  1
352899  94.748  -69.444  53.124  1
352900  94.779  -69.442  53.108  1
352901  94.811  -69.440  53.093  1
352902  94.842  -69.437  53.079  1
352903  94.874  -69.435  53.066  1
352904  94.905  -69.432  53.053  1
352905  94.936  -69.430  53.042  1
352906  94.968  -69.428  53.033  1
352907  95.038  -69.435  53.026  1
352908  95.130  -69.449  53.021  1
352909  95.222  -69.462  53.019  1
352910  95.314  -69.476  53.016  1
352911  95.399  -69.482  53.013  1
352912  95.441  -69.476  53.010  1
352913  95.466  -69.474  53.008  1
352914  95.494  -69.469  53.009  1
352915  95.522  -69.463  53.013  1
352916  95.549  -69.458  53.018  1
352917  95.577  -69.453  53.026  1
352918  95.604  -69.447  53.034  1
352919  95.632  -69.442  53.040  1
352920  95.659  -69.436  53.045  1
352921  95.686  -69.431  53.051  1
352922  95.713  -69.425  53.058  1
352923  95.741  -69.419  53.066  1
352924  95.768  -69.413  53.075  1
352925  95.796  -69.408  53.086  1
352926  95.823  -69.402  53.095  1
352927  95.850  -69.397  53.104  1
352928  95.877  -69.391  53.110  1
352929  95.904  -69.385  53.112  1
352930  95.932  -69.379  53.107  1
352931  95.959  -69.374  53.094  1
352932  95.986  -69.368  53.072  1
352933  96.014  -69.363  53.044  1
352934  96.041  -69.356  53.011  1
352935  96.068  -69.351  52.977  1
352936  96.096  -69.345  52.948  1
352937  96.123  -69.340  52.920  1
352938  96.150  -69.334  52.894  1
352939  96.172  -69.348  52.869  1
352940  96.194  -69.365  52.844  1
352941  96.218  -69.380  52.823  1
352942  96.241  -69.394  52.808  1
352943  96.265  -69.409  52.799  1
352944  96.292  -69.420  52.789  1
352945  96.318  -69.432  52.778  1
352946  96.344  -69.442  52.766  1
352947  96.371  -69.454  52.751  1
352948  96.397  -69.465  52.732  1
352949  96.424  -69.476  52.709  1
352950  96.451  -69.488  52.688  1
352951  96.485  -69.500  52.671  1
352952  96.519  -69.511  52.653  1
352953  96.549  -69.519  52.631  1
352954  96.580  -69.526  52.607  1
352955  96.610  -69.534  52.582  1
352956  96.643  -69.540  52.558  1
352957  96.676  -69.549  52.535  1
352958  96.710  -69.560  52.512  1
352959  96.742  -69.568  52.488  1
352960  96.773  -69.573  52.465  1
352961  96.804  -69.578  52.441  1
352962  96.835  -69.583  52.419  1
352963  96.867  -69.589  52.395  1
352964  96.901  -69.605  52.372  1
352965  96.935  -69.622  52.353  1
352966  96.967  -69.632  52.335  1
352967  96.999  -69.639  52.316  1
352968  97.031  -69.645  52.298  1
352969  97.063  -69.652  52.281  1
352970  97.094  -69.659  52.261  1
352971  97.126  -69.665  52.242  1
352972  97.158  -69.671  52.221  1
352973  97.189  -69.678  52.195  1
352974  97.223  -69.686  52.168  1
352975  97.258  -69.696  52.139  1
352976  97.293  -69.705  52.109  1
352977  97.327  -69.715  52.082  1
352978  97.362  -69.724  52.058  1
352979  97.393  -69.731  52.032  1
352980  97.425  -69.738  52.006  1
352981  97.456  -69.745  51.981  1
352982  97.488  -69.751  51.957  1
352983  97.519  -69.758  51.940  1
352984  97.550  -69.767  51.921  1
352985  97.580  -69.776  51.898  1
352986  97.610  -69.786  51.869  1
352987  97.640  -69.796  51.834  1
352988  97.675  -69.801  51.798  1
352989  97.711  -69.805  51.761  1
352990  97.747  -69.808  51.724  1
352991  97.784  -69.811  51.688  1
352992  97.820  -69.814  51.647  1
352993  97.856  -69.817  51.609  1
352994  97.892  -69.820  51.572  1
352995  97.929  -69.823  51.535  1
352996  97.961  -69.825  51.496  1
352997  97.994  -69.826  51.455  1
352998  98.028  -69.824  51.410  1
352999  98.061  -69.828  51.361  1
353000  98.090  -69.836  51.310  1
353001  98.120  -69.843  51.256  1
353002  98.150  -69.851  51.200  1
353003  98.180  -69.858  51.143  1
353004  98.210  -69.866  51.087  1
353005  98.240  -69.874  51.028  1
353006  98.270  -69.881  50.973  1
353007  98.300  -69.889  50.920  1
353008  98.329  -69.896  50.864  1
353009  98.360  -69.904  50.808  1
353010  98.389  -69.911  50.750  1
353011  98.420  -69.919  50.691  1
353012  98.449  -69.927  50.631  1
353013  98.479  -69.935  50.570  1
353014  98.509  -69.942  50.511  1
353015  98.539  -69.949  50.452  1
353016  98.570  -69.956  50.393  1
353017  98.601  -69.964  50.335  1
353018  98.632  -69.971  50.274  1
353019  98.667  -69.973  50.212  1
353020  98.702  -69.966  50.150  1
353021  98.736  -69.960  50.087  1
353022  98.784  -69.975  50.024  1
353023  98.832  -69.990  49.963  1
353024  98.878  -70.005  49.902  1
353025  98.923  -70.018  49.842  1
353026  98.968  -70.032  49.785  1
353027  99.013  -70.046  49.728  1
353028  99.058  -70.059  49.672  1
353029  99.103  -70.073  49.617  1
353030  99.136  -70.083  49.564  1
353031  99.168  -70.093  49.512  1
353032  99.201  -70.103  49.461  1
353033  99.234  -70.113  49.412  1
353034  99.267  -70.123  49.362  1
353035  99.303  -70.131  49.313  1
353036  99.340  -70.138  49.266  1
353037  99.378  -70.145  49.222  1
353038  99.417  -70.150  49.179  1
353039  99.460  -70.155  49.136  1
353040  99.502  -70.159  49.095  1
353041  99.544  -70.162  49.056  1
353042  99.593  -70.165  49.016  1
353043  99.644  -70.168  48.977  1
353044  99.694  -70.171  48.941  1
353045  99.744  -70.174  48.905  1
353046  99.788  -70.189  48.870  1
353047  99.820  -70.228  48.836  1
353048  99.851  -70.267  48.805  1
353049  99.884  -70.306  48.773  1
353050  99.915  -70.331  48.745  1
353051  99.946  -70.344  48.718  1
353052  99.977  -70.357  48.693  1
353053  100.008  -70.363  48.670  1
353054  100.040  -70.363  48.648  1
353055  100.072  -70.363  48.627  1
353056  100.104  -70.363  48.607  1
353057  100.135  -70.363  48.583  1
353058  100.167  -70.363  48.557  1
353059  100.199  -70.363  48.531  1
353060  100.230  -70.363  48.504  1
353061  100.262  -70.362  48.477  1
353062  100.292  -70.356  48.452  1
353063  100.328  -70.356  48.426  1
353064  100.371  -70.366  48.401  1
353065  100.419  -70.378  48.376  1
353066  100.469  -70.391  48.346  1
353067  100.517  -70.405  48.312  1
353068  100.567  -70.418  48.276  1
353069  100.616  -70.431  48.239  1
353070  100.665  -70.444  48.206  1
353071  100.714  -70.457  48.172  1
353072  100.763  -70.470  48.136  1
353073  100.812  -70.484  48.099  1
353074  100.856  -70.497  48.063  1
353075  100.870  -70.515  48.023  1
353076  100.900  -70.542  47.984  1
353077  100.924  -70.564  47.944  1
353078  100.945  -70.584  47.902  1
353079  100.973  -70.594  47.861  1
353080  101.004  -70.597  47.821  1
353081  101.031  -70.602  47.780  1
353082  101.058  -70.606  47.738  1
353083  101.086  -70.610  47.695  1
353084  101.113  -70.614  47.652  1
353085  101.140  -70.618  47.608  1
353086  101.167  -70.622  47.565  1
353087  101.194  -70.626  47.526  1
353088  101.221  -70.636  47.491  1
353089  101.249  -70.651  47.455  1
353090  101.276  -70.667  47.417  1
353091  101.305  -70.682  47.375  1
353092  101.339  -70.698  47.329  1
353093  101.374  -70.713  47.283  1
353094  101.408  -70.729  47.237  1
353095  101.443  -70.744  47.190  1
353096  101.488  -70.752  47.141  1
353097  101.538  -70.757  47.090  1
353098  101.588  -70.763  47.039  1
353099  101.638  -70.768  46.989  1
353100  101.684  -70.767  46.940  1
353101  101.730  -70.765  46.888  1
353102  101.775  -70.764  46.836  1
353103  101.821  -70.763  46.783  1
353104  101.866  -70.761  46.730  1
353105  101.892  -70.758  46.682  1
353106  101.919  -70.756  46.635  1
353107  101.946  -70.753  46.590  1
353108  101.973  -70.751  46.547  1
353109  102.000  -70.748  46.504  1
353110  102.027  -70.745  46.462  1
353111  102.056  -70.746  46.420  1
353112  102.087  -70.748  46.379  1
353531  92.211  -69.664  54.987  3
353532  92.250  -69.634  54.965  3
353533  92.290  -69.604  54.942  3
353534  92.329  -69.575  54.920  3
353535  92.369  -69.545  54.897  3
353536  92.408  -69.515  54.875  3
353537  92.448  -69.488  54.850  3
353538  92.496  -69.481  54.825  3
353539  92.544  -69.473  54.799  3
353540  92.591  -69.466  54.774  3
353541  92.639  -69.459  54.748  3
353542  92.686  -69.451  54.722  3
353543  92.734  -69.444  54.696  3
353544  92.781  -69.436  54.668  3
353545  92.829  -69.429  54.640  3
353546  92.876  -69.421  54.612  3
353547  92.921  -69.409  54.583  3
353548  92.966  -69.397  54.554  3
353549  93.010  -69.385  54.523  3
353550  93.045  -69.386  54.491  3
353551  93.079  -69.388  54.459  3
353552  93.115  -69.388  54.425  3
353553  93.149  -69.389  54.392  3
353554  93.185  -69.390  54.361  3
353555  93.219  -69.391  54.329  3
353556  93.254  -69.391  54.299  3
353557  93.289  -69.392  54.268  3
353558  93.324  -69.393  54.237  3
353559  93.359  -69.394  54.208  3
353560  93.394  -69.394  54.180  3
353561  93.430  -69.397  54.151  3
353594  94.558  -69.437  53.249  1
353595  94.590  -69.435  53.229  1
353596  94.621  -69.432  53.213  1
353597  94.652  -69.429  53.195  1
353598  94.684  -69.427  53.178  1
353599  94.715  -69.425  53.161  1
353600  94.747  -69.422  53.144  1
353601  94.778  -69.420  53.129  1
353602  94.810  -69.418  53.114  1
353603  94.841  -69.416  53.102  1
353604  94.873  -69.413  53.090  1
353605  94.904  -69.410  53.078  1
353606  94.935  -69.408  53.068  1
353607  94.987  -69.411  53.060  1
353608  95.079  -69.425  53.054  1
353609  95.171  -69.438  53.051  1
353610  95.263  -69.451  53.050  1
353611  95.345  -69.454  53.048  1
353612  95.407  -69.439  53.045  1
353613  95.443  -69.434  53.042  1
353614  95.469  -69.433  53.039  1
353615  95.494  -69.433  53.039  1
353616  95.521  -69.432  53.040  1
353617  95.548  -69.427  53.044  1
353618  95.576  -69.422  53.050  1
353619  95.603  -69.416  53.059  1
353620  95.631  -69.411  53.066  1
353621  95.659  -69.406  53.072  1
353622  95.686  -69.400  53.078  1
353623  95.714  -69.395  53.084  1
353624  95.742  -69.391  53.092  1
353625  95.769  -69.385  53.101  1
353626  95.797  -69.380  53.109  1
353627  95.825  -69.375  53.116  1
353628  95.852  -69.369  53.123  1
353629  95.880  -69.363  53.127  1
353630  95.907  -69.358  53.127  1
353631  95.934  -69.352  53.119  1
353632  95.961  -69.347  53.102  1
353633  95.988  -69.341  53.078  1
353634  96.016  -69.335  53.048  1
353635  96.043  -69.329  53.016  1
353636  96.071  -69.324  52.984  1
353637  96.098  -69.318  52.955  1
353638  96.125  -69.313  52.929  1
353639  96.152  -69.306  52.904  1
353640  96.176  -69.316  52.882  1
353641  96.199  -69.331  52.861  1
353642  96.222  -69.347  52.844  1
353643  96.246  -69.361  52.832  1
353644  96.269  -69.375  52.827  1
353645  96.296  -69.387  52.817  1
353646  96.322  -69.398  52.804  1
353647  96.348  -69.410  52.790  1
353648  96.375  -69.421  52.777  1
353649  96.401  -69.432  52.757  1
353650  96.430  -69.444  52.734  1
353651  96.464  -69.456  52.712  1
353652  96.499  -69.468  52.692  1
353653  96.531  -69.478  52.672  1
353654  96.561  -69.485  52.648  1
353655  96.592  -69.493  52.625  1
353656  96.622  -69.501  52.601  1
353657  96.653  -69.508  52.578  1
353658  96.685  -69.516  52.553  1
353659  96.717  -69.522  52.527  1
353660  96.748  -69.526  52.500  1
353661  96.779  -69.531  52.474  1
353662  96.810  -69.536  52.448  1
353663  96.841  -69.541  52.421  1
353664  96.873  -69.551  52.395  1
353665  96.907  -69.567  52.369  1
353666  96.941  -69.583  52.347  1
353667  96.974  -69.598  52.326  1
353668  97.007  -69.605  52.305  1
353669  97.038  -69.612  52.285  1
353670  97.070  -69.619  52.264  1
353671  97.102  -69.625  52.245  1
353672  97.134  -69.631  52.224  1
353673  97.165  -69.638  52.201  1
353674  97.196  -69.644  52.175  1
353675  97.229  -69.651  52.148  1
353676  97.264  -69.660  52.119  1
353677  97.299  -69.670  52.092  1
353678  97.333  -69.679  52.066  1
353679  97.366  -69.688  52.043  1
353680  97.397  -69.695  52.017  1
353681  97.429  -69.701  51.990  1
353682  97.461  -69.708  51.965  1
353683  97.492  -69.715  51.943  1
353684  97.524  -69.722  51.927  1
353685  97.555  -69.729  51.910  1
353686  97.586  -69.737  51.889  1
353687  97.616  -69.747  51.862  1
353688  97.646  -69.757  51.829  1
353689  97.682  -69.761  51.795  1
353690  97.719  -69.764  51.759  1
353691  97.755  -69.767  51.723  1
353692  97.791  -69.770  51.688  1
353693  97.827  -69.773  51.648  1
353694  97.864  -69.776  51.611  1
353695  97.900  -69.780  51.575  1
353696  97.936  -69.783  51.538  1
353697  97.972  -69.786  51.499  1
353698  98.006  -69.786  51.457  1
353699  98.037  -69.790  51.411  1
353700  98.068  -69.798  51.361  1
353701  98.097  -69.805  51.307  1
353702  98.127  -69.813  51.252  1
353703  98.157  -69.820  51.196  1
353704  98.187  -69.828  51.141  1
353705  98.217  -69.836  51.086  1
353706  98.248  -69.842  51.031  1
353707  98.279  -69.849  50.977  1
353708  98.309  -69.857  50.922  1
353709  98.340  -69.864  50.866  1
353710  98.371  -69.870  50.807  1
353711  98.402  -69.877  50.748  1
353712  98.433  -69.884  50.689  1
353713  98.463  -69.891  50.630  1
353714  98.494  -69.899  50.570  1
353715  98.525  -69.905  50.511  1
353716  98.556  -69.912  50.452  1
353717  98.586  -69.919  50.393  1
353718  98.617  -69.926  50.334  1
353719  98.650  -69.935  50.272  1
353720  98.691  -69.942  50.210  1
353721  98.725  -69.936  50.146  1
353722  98.761  -69.933  50.083  1
353723  98.809  -69.947  50.020  1
353724  98.856  -69.962  49.959  1
353725  98.904  -69.977  49.899  1
353726  98.952  -69.992  49.841  1
353727  99.000  -70.007  49.784  1
353728  99.043  -70.021  49.727  1
353729  99.076  -70.030  49.671  1
353730  99.109  -70.040  49.616  1
353731  99.141  -70.051  49.563  1
353732  99.174  -70.061  49.511  1
353733  99.207  -70.071  49.460  1
353734  99.239  -70.081  49.410  1
353735  99.273  -70.090  49.360  1
353736  99.311  -70.097  49.312  1
353737  99.349  -70.104  49.265  1
353738  99.386  -70.111  49.220  1
353739  99.424  -70.118  49.176  1
353740  99.466  -70.121  49.133  1
353741  99.508  -70.125  49.091  1
353742  99.552  -70.129  49.051  1
353743  99.602  -70.132  49.011  1
353744  99.652  -70.135  48.972  1
353745  99.702  -70.138  48.936  1
353746  99.752  -70.141  48.898  1
353747  99.801  -70.146  48.863  1
353748  99.833  -70.184  48.828  1
353749  99.865  -70.223  48.795  1
353750  99.897  -70.262  48.764  1
353751  99.929  -70.300  48.734  1
353752  99.960  -70.319  48.705  1
353753  99.991  -70.332  48.678  1
353754  100.022  -70.339  48.653  1
353755  100.054  -70.339  48.629  1
353756  100.086  -70.339  48.607  1
353757  100.118  -70.339  48.586  1
353758  100.149  -70.339  48.563  1
353759  100.181  -70.339  48.539  1
353760  100.213  -70.339  48.514  1
353761  100.244  -70.333  48.488  1
353762  100.274  -70.327  48.460  1
353763  100.304  -70.320  48.434  1
353764  100.346  -70.328  48.410  1
353765  100.390  -70.338  48.387  1
353766  100.435  -70.349  48.365  1
353767  100.484  -70.362  48.337  1
353768  100.533  -70.375  48.305  1
353769  100.582  -70.388  48.268  1
353770  100.631  -70.401  48.230  1
353771  100.680  -70.415  48.196  1
353772  100.729  -70.428  48.162  1
353773  100.778  -70.441  48.126  1
353774  100.828  -70.454  48.089  1
353775  100.866  -70.468  48.053  1
353776  100.878  -70.484  48.012  1
353777  100.903  -70.508  47.972  1
353778  100.932  -70.535  47.932  1
353779  100.960  -70.560  47.892  1
353780  100.988  -70.564  47.849  1
353781  101.015  -70.569  47.809  1
353782  101.042  -70.572  47.768  1
353783  101.069  -70.576  47.726  1
353784  101.096  -70.581  47.683  1
353785  101.123  -70.585  47.641  1
353786  101.150  -70.589  47.597  1
353787  101.178  -70.593  47.554  1
353788  101.204  -70.597  47.517  1
353789  101.232  -70.606  47.483  1
353790  101.259  -70.621  47.447  1
353791  101.286  -70.637  47.407  1
353792  101.318  -70.652  47.364  1
353793  101.353  -70.667  47.317  1
353794  101.388  -70.682  47.271  1
353795  101.422  -70.698  47.225  1
353796  101.457  -70.713  47.178  1
353797  101.491  -70.729  47.130  1
353798  101.540  -70.735  47.078  1
353799  101.590  -70.739  47.025  1
353800  101.636  -70.738  46.972  1
353801  101.682  -70.736  46.920  1
353802  101.728  -70.735  46.868  1
353803  101.773  -70.733  46.817  1
353804  101.819  -70.732  46.768  1
353805  101.865  -70.730  46.718  1
353806  101.911  -70.729  46.672  1
353807  101.949  -70.727  46.628  1
353808  101.976  -70.724  46.584  1
353809  102.003  -70.722  46.541  1
353810  102.030  -70.719  46.498  1
353811  102.057  -70.717  46.456  1
353812  102.084  -70.713  46.415  1
353813  102.111  -70.711  46.375  1
354233  92.241  -69.604  54.956  3
354234  92.281  -69.574  54.934  3
354235  92.320  -69.544  54.911  3
354236  92.359  -69.515  54.888  3
354237  92.399  -69.485  54.864  3
354238  92.444  -69.472  54.839  3
354239  92.492  -69.465  54.813  3
354240  92.540  -69.457  54.787  3
354241  92.587  -69.450  54.762  3
354242  92.635  -69.442  54.735  3
354243  92.682  -69.435  54.708  3
354244  92.730  -69.427  54.681  3
354245  92.777  -69.419  54.653  3
354246  92.825  -69.412  54.624  3
354247  92.869  -69.400  54.596  3
354248  92.914  -69.388  54.567  3
354249  92.958  -69.376  54.538  3
354250  93.003  -69.365  54.506  3
354251  93.039  -69.364  54.475  3
354252  93.074  -69.365  54.443  3
354253  93.109  -69.366  54.410  3
354254  93.144  -69.366  54.378  3
354255  93.179  -69.367  54.346  3
354256  93.214  -69.368  54.315  3
354257  93.249  -69.369  54.284  3
354258  93.284  -69.370  54.254  3
354259  93.319  -69.371  54.224  3
354260  93.354  -69.372  54.195  3
354261  93.389  -69.372  54.167  3
354262  93.424  -69.373  54.140  3
354294  94.526  -69.417  53.282  1
354295  94.557  -69.415  53.263  1
354296  94.589  -69.413  53.245  1
354297  94.620  -69.410  53.229  1
354298  94.652  -69.408  53.213  1
354299  94.683  -69.406  53.196  1
354300  94.715  -69.403  53.180  1
354301  94.746  -69.400  53.165  1
354302  94.777  -69.398  53.150  1
354303  94.809  -69.396  53.137  1
354304  94.840  -69.394  53.125  1
354305  94.872  -69.391  53.115  1
354306  94.903  -69.389  53.104  1
354307  94.936  -69.387  53.096  1
354308  95.029  -69.400  53.090  1
354309  95.120  -69.413  53.085  1
354310  95.212  -69.427  53.084  1
354311  95.291  -69.427  53.084  1
354312  95.352  -69.411  53.083  1
354313  95.414  -69.396  53.082  1
354314  95.446  -69.392  53.079  1
354315  95.472  -69.392  53.075  1
354316  95.497  -69.391  53.072  1
354317  95.523  -69.391  53.070  1
354318  95.549  -69.391  53.070  1
354319  95.574  -69.391  53.071  1
354320  95.602  -69.385  53.078  1
354321  95.630  -69.380  53.088  1
354322  95.658  -69.375  53.100  1
354323  95.685  -69.369  53.108  1
354324  95.712  -69.364  53.112  1
354325  95.740  -69.359  53.120  1
354326  95.768  -69.353  53.129  1
354327  95.796  -69.348  53.136  1
354328  95.823  -69.343  53.142  1
354329  95.851  -69.338  53.146  1
354330  95.879  -69.333  53.147  1
354331  95.906  -69.328  53.143  1
354332  95.934  -69.322  53.133  1
354333  95.962  -69.317  53.110  1
354334  95.989  -69.312  53.083  1
354335  96.017  -69.306  53.054  1
354336  96.044  -69.301  53.023  1
354337  96.072  -69.296  52.994  1
354338  96.100  -69.291  52.965  1
354339  96.127  -69.285  52.939  1
354340  96.155  -69.280  52.917  1
354341  96.180  -69.284  52.898  1
354342  96.203  -69.298  52.881  1
354343  96.227  -69.313  52.867  1
354344  96.250  -69.328  52.857  1
354345  96.274  -69.342  52.854  1
354346  96.300  -69.354  52.845  1
354347  96.326  -69.365  52.831  1
354348  96.353  -69.376  52.816  1
354349  96.379  -69.388  52.802  1
354350  96.408  -69.399  52.783  1
354351  96.443  -69.412  52.759  1
354352  96.477  -69.424  52.735  1
354353  96.511  -69.436  52.713  1
354354  96.543  -69.445  52.691  1
354355  96.573  -69.453  52.667  1
354356  96.604  -69.460  52.644  1
354357  96.634  -69.468  52.620  1
354358  96.663  -69.476  52.596  1
354359  96.693  -69.482  52.568  1
354360  96.723  -69.485  52.540  1
354361  96.754  -69.488  52.511  1
354362  96.785  -69.490  52.481  1
354363  96.816  -69.494  52.452  1
354364  96.847  -69.499  52.422  1
354365  96.880  -69.513  52.392  1
354366  96.913  -69.529  52.364  1
354367  96.948  -69.544  52.340  1
354368  96.981  -69.560  52.316  1
354369  97.014  -69.571  52.293  1
354370  97.046  -69.578  52.271  1
354371  97.078  -69.585  52.249  1
354372  97.109  -69.591  52.228  1
354373  97.141  -69.598  52.207  1
354374  97.172  -69.604  52.183  1
354375  97.204  -69.610  52.156  1
354376  97.236  -69.617  52.130  1
354377  97.270  -69.625  52.102  1
354378  97.305  -69.635  52.075  1
354379  97.339  -69.644  52.051  1
354380  97.371  -69.651  52.029  1
354381  97.402  -69.658  52.002  1
354382  97.434  -69.665  51.974  1
354383  97.465  -69.672  51.949  1
354384  97.497  -69.679  51.927  1
354385  97.528  -69.686  51.912  1
354386  97.560  -69.692  51.897  1
354387  97.591  -69.699  51.878  1
354388  97.622  -69.707  51.854  1
354389  97.653  -69.716  51.823  1
354390  97.690  -69.719  51.792  1
354391  97.726  -69.723  51.757  1
354392  97.762  -69.726  51.722  1
354393  97.799  -69.729  51.687  1
354394  97.835  -69.732  51.648  1
354395  97.871  -69.735  51.611  1
354396  97.908  -69.738  51.574  1
354397  97.945  -69.742  51.536  1
354398  97.983  -69.745  51.496  1
354399  98.018  -69.750  51.454  1
354400  98.049  -69.757  51.407  1
354401  98.079  -69.764  51.355  1
354402  98.110  -69.770  51.301  1
354403  98.141  -69.777  51.246  1
354404  98.172  -69.785  51.191  1
354405  98.203  -69.792  51.137  1
354406  98.233  -69.798  51.086  1
354407  98.264  -69.805  51.032  1
354408  98.295  -69.812  50.979  1
354409  98.325  -69.819  50.924  1
354410  98.356  -69.827  50.866  1
354411  98.387  -69.833  50.806  1
354412  98.418  -69.840  50.748  1
354413  98.449  -69.847  50.689  1
354414  98.480  -69.854  50.629  1
354415  98.510  -69.861  50.569  1
354416  98.541  -69.868  50.510  1
354417  98.572  -69.875  50.451  1
354418  98.602  -69.882  50.391  1
354419  98.634  -69.889  50.331  1
354420  98.672  -69.902  50.266  1
354421  98.714  -69.911  50.203  1
354422  98.748  -69.905  50.140  1
354423  98.786  -69.905  50.077  1
354424  98.834  -69.919  50.014  1
354425  98.881  -69.934  49.955  1
354426  98.929  -69.949  49.897  1
354427  98.977  -69.964  49.840  1
354428  99.023  -69.979  49.784  1
354429  99.046  -69.991  49.727  1
354430  99.079  -70.000  49.670  1
354431  99.113  -70.010  49.615  1
354432  99.146  -70.019  49.561  1
354433  99.179  -70.029  49.509  1
354434  99.212  -70.039  49.458  1
354435  99.245  -70.049  49.408  1
354436  99.281  -70.056  49.358  1
354437  99.319  -70.063  49.310  1
354438  99.357  -70.070  49.263  1
354439  99.395  -70.077  49.217  1
354440  99.432  -70.083  49.173  1
354441  99.473  -70.088  49.130  1
354442  99.514  -70.093  49.088  1
354443  99.560  -70.096  49.047  1
354444  99.610  -70.099  49.006  1
354445  99.660  -70.102  48.967  1
354446  99.710  -70.105  48.929  1
354447  99.760  -70.108  48.892  1
354448  99.810  -70.111  48.856  1
354449  99.847  -70.140  48.821  1
354450  99.879  -70.179  48.787  1
354451  99.911  -70.218  48.755  1
354452  99.943  -70.256  48.724  1
354453  99.975  -70.294  48.694  1
354454  100.005  -70.307  48.665  1
354455  100.037  -70.315  48.638  1
354456  100.068  -70.315  48.612  1
354457  100.100  -70.315  48.588  1
354458  100.132  -70.315  48.564  1
354459  100.163  -70.315  48.541  1
354460  100.194  -70.309  48.518  1
354461  100.225  -70.303  48.493  1
354462  100.256  -70.297  48.468  1
354463  100.286  -70.290  48.441  1
354464  100.322  -70.290  48.415  1
354465  100.365  -70.300  48.392  1
354466  100.409  -70.310  48.371  1
354467  100.453  -70.320  48.352  1
354468  100.499  -70.332  48.326  1
354469  100.548  -70.346  48.294  1
354470  100.598  -70.359  48.258  1
354471  100.646  -70.372  48.218  1
354472  100.696  -70.385  48.183  1
354473  100.745  -70.398  48.148  1
354474  100.794  -70.411  48.112  1
354475  100.843  -70.425  48.075  1
354476  100.877  -70.438  48.039  1
354477  100.888  -70.454  48.000  1
354478  100.905  -70.474  47.959  1
354479  100.935  -70.501  47.919  1
354480  100.965  -70.526  47.881  1
354481  100.996  -70.533  47.838  1
354482  101.025  -70.539  47.796  1
354483  101.052  -70.544  47.754  1
354484  101.079  -70.547  47.712  1
354485  101.107  -70.551  47.669  1
354486  101.134  -70.556  47.628  1
354487  101.161  -70.560  47.585  1
354488  101.188  -70.564  47.543  1
354489  101.215  -70.568  47.504  1
354490  101.242  -70.576  47.470  1
354491  101.270  -70.591  47.434  1
354492  101.298  -70.607  47.394  1
354493  101.332  -70.622  47.349  1
354494  101.367  -70.637  47.301  1
354495  101.401  -70.652  47.258  1
354496  101.436  -70.667  47.213  1
354497  101.470  -70.682  47.166  1
354498  101.505  -70.698  47.118  1
354499  101.542  -70.710  47.067  1
354500  101.588  -70.708  47.013  1
354501  101.633  -70.707  46.958  1
354502  101.679  -70.706  46.904  1
354503  101.725  -70.704  46.853  1
354504  101.771  -70.703  46.804  1
354505  101.817  -70.701  46.757  1
354506  101.863  -70.700  46.709  1
354507  101.908  -70.698  46.664  1
354508  101.954  -70.697  46.620  1
354509  102.000  -70.695  46.577  1
354510  102.033  -70.693  46.535  1
354511  102.060  -70.691  46.492  1
354512  102.087  -70.688  46.451  1
354513  102.114  -70.685  46.411  1
354935  92.272  -69.544  54.926  3
354936  92.311  -69.515  54.902  3
354937  92.350  -69.485  54.878  3
354938  92.392  -69.463  54.854  3
354939  92.440  -69.456  54.828  3
354940  92.488  -69.448  54.802  3
354941  92.535  -69.441  54.775  3
354942  92.583  -69.433  54.749  3
354943  92.631  -69.425  54.722  3
354944  92.678  -69.418  54.694  3
354945  92.725  -69.411  54.667  3
354946  92.773  -69.403  54.638  3
354947  92.818  -69.391  54.610  3
354948  92.862  -69.379  54.581  3
354949  92.907  -69.368  54.551  3
354950  92.952  -69.356  54.521  3
354951  92.996  -69.344  54.490  3
354952  93.034  -69.342  54.458  3
354953  93.069  -69.343  54.426  3
354954  93.103  -69.344  54.395  3
354955  93.138  -69.344  54.362  3
354956  93.174  -69.345  54.331  3
354957  93.208  -69.346  54.300  3
354958  93.243  -69.347  54.269  3
354959  93.278  -69.347  54.239  3
354960  93.313  -69.348  54.210  3
354961  93.348  -69.349  54.181  3
354962  93.383  -69.350  54.154  3
354963  93.418  -69.350  54.128  3
354994  94.494  -69.398  53.315  1
354995  94.526  -69.396  53.297  1
354996  94.557  -69.393  53.279  1
354997  94.588  -69.391  53.261  1
354998  94.620  -69.388  53.246  1
354999  94.651  -69.386  53.230  1
355000  94.683  -69.384  53.215  1
355001  94.714  -69.382  53.200  1
355002  94.746  -69.379  53.186  1
355003  94.777  -69.377  53.172  1
355004  94.809  -69.374  53.160  1
355005  94.840  -69.372  53.150  1
355006  94.871  -69.369  53.140  1
355007  94.903  -69.367  53.131  1
355008  94.978  -69.376  53.124  1
355009  95.070  -69.389  53.119  1
355010  95.162  -69.403  53.116  1
355011  95.237  -69.400  53.116  1
355012  95.298  -69.384  53.117  1
355013  95.359  -69.368  53.118  1
355014  95.421  -69.353  53.118  1
355015  95.449  -69.351  53.117  1
355016  95.475  -69.350  53.112  1
355017  95.500  -69.350  53.110  1
355018  95.526  -69.350  53.109  1
355019  95.552  -69.350  53.108  1
355020  95.578  -69.349  53.108  1
355021  95.603  -69.349  53.109  1
355022  95.628  -69.348  53.112  1
355023  95.656  -69.343  53.118  1
355024  95.684  -69.338  53.127  1
355025  95.711  -69.333  53.135  1
355026  95.739  -69.328  53.146  1
355027  95.767  -69.322  53.156  1
355028  95.795  -69.317  53.163  1
355029  95.822  -69.312  53.169  1
355030  95.850  -69.306  53.171  1
355031  95.877  -69.301  53.168  1
355032  95.905  -69.296  53.158  1
355033  95.933  -69.291  53.142  1
355034  95.960  -69.285  53.115  1
355035  95.988  -69.280  53.086  1
355036  96.016  -69.275  53.059  1
355037  96.043  -69.270  53.033  1
355038  96.071  -69.265  53.004  1
355039  96.099  -69.259  52.979  1
355040  96.126  -69.254  52.956  1
355041  96.154  -69.249  52.935  1
355042  96.182  -69.251  52.920  1
355043  96.208  -69.265  52.903  1
355044  96.232  -69.279  52.891  1
355045  96.255  -69.294  52.883  1
355046  96.278  -69.309  52.879  1
355047  96.304  -69.321  52.871  1
355048  96.331  -69.332  52.857  1
355049  96.357  -69.344  52.842  1
355050  96.387  -69.355  52.826  1
355051  96.421  -69.367  52.807  1
355052  96.455  -69.380  52.784  1
355053  96.490  -69.392  52.759  1
355054  96.524  -69.404  52.735  1
355055  96.554  -69.412  52.712  1
355056  96.585  -69.419  52.688  1
355057  96.615  -69.427  52.664  1
355058  96.644  -69.435  52.639  1
355059  96.673  -69.443  52.611  1
355060  96.702  -69.450  52.581  1
355061  96.732  -69.455  52.550  1
355062  96.763  -69.457  52.519  1
355063  96.793  -69.460  52.486  1
355064  96.824  -69.463  52.454  1
355065  96.855  -69.466  52.421  1
355066  96.887  -69.475  52.388  1
355067  96.920  -69.490  52.358  1
355068  96.954  -69.506  52.332  1
355069  96.988  -69.523  52.306  1
355070  97.022  -69.538  52.281  1
355071  97.053  -69.544  52.258  1
355072  97.085  -69.551  52.235  1
355073  97.117  -69.557  52.213  1
355074  97.148  -69.563  52.191  1
355075  97.180  -69.570  52.166  1
355076  97.212  -69.576  52.139  1
355077  97.243  -69.582  52.114  1
355078  97.276  -69.590  52.086  1
355079  97.311  -69.600  52.060  1
355080  97.344  -69.607  52.037  1
355081  97.375  -69.614  52.015  1
355082  97.407  -69.621  51.986  1
355083  97.438  -69.628  51.958  1
355084  97.470  -69.635  51.932  1
355085  97.501  -69.642  51.911  1
355086  97.533  -69.648  51.897  1
355087  97.564  -69.656  51.883  1
355088  97.596  -69.663  51.867  1
355089  97.628  -69.670  51.845  1
355090  97.661  -69.675  51.817  1
355091  97.698  -69.678  51.787  1
355092  97.736  -69.682  51.755  1
355093  97.774  -69.686  51.720  1
355094  97.812  -69.689  51.685  1
355095  97.850  -69.692  51.646  1
355096  97.888  -69.695  51.608  1
355097  97.926  -69.699  51.571  1
355098  97.964  -69.703  51.532  1
355099  97.990  -69.708  51.490  1
355100  98.023  -69.715  51.447  1
355101  98.065  -69.720  51.399  1
355102  98.095  -69.726  51.347  1
355103  98.127  -69.733  51.292  1
355104  98.157  -69.740  51.238  1
355105  98.188  -69.747  51.185  1
355106  98.219  -69.754  51.134  1
355107  98.249  -69.761  51.085  1
355108  98.280  -69.768  51.032  1
355109  98.311  -69.775  50.978  1
355110  98.342  -69.782  50.923  1
355111  98.373  -69.789  50.864  1
355112  98.404  -69.796  50.805  1
355113  98.434  -69.803  50.747  1
355114  98.465  -69.810  50.687  1
355115  98.496  -69.817  50.626  1
355116  98.526  -69.823  50.567  1
355117  98.557  -69.830  50.507  1
355118  98.588  -69.838  50.447  1
355119  98.619  -69.845  50.386  1
355120  98.650  -69.852  50.324  1
355121  98.695  -69.869  50.258  1
355122  98.737  -69.881  50.194  1
355123  98.772  -69.875  50.132  1
355124  98.811  -69.877  50.070  1
355125  98.859  -69.891  50.008  1
355126  98.906  -69.906  49.951  1
355127  98.954  -69.921  49.895  1
355128  99.002  -69.936  49.840  1
355129  99.031  -69.949  49.783  1
355130  99.055  -69.961  49.725  1
355131  99.082  -69.971  49.669  1
355132  99.115  -69.981  49.613  1
355133  99.148  -69.990  49.559  1
355134  99.182  -70.000  49.507  1
355135  99.215  -70.009  49.456  1
355136  99.248  -70.019  49.406  1
355137  99.288  -70.024  49.356  1
355138  99.327  -70.029  49.308  1
355139  99.365  -70.036  49.261  1
355140  99.403  -70.043  49.215  1
355141  99.440  -70.049  49.170  1
355142  99.479  -70.055  49.127  1
355143  99.521  -70.059  49.084  1
355144  99.569  -70.062  49.042  1
355145  99.619  -70.065  49.002  1
355146  99.668  -70.068  48.961  1
355147  99.719  -70.071  48.922  1
355148  99.769  -70.074  48.886  1
355149  99.819  -70.077  48.849  1
355150  99.861  -70.096  48.814  1
355151  99.893  -70.135  48.780  1
355152  99.924  -70.174  48.747  1
355153  99.957  -70.212  48.715  1
355154  99.988  -70.251  48.683  1
355155  100.020  -70.283  48.653  1
355156  100.051  -70.290  48.625  1
355157  100.083  -70.291  48.597  1
355158  100.115  -70.291  48.569  1
355159  100.145  -70.286  48.542  1
355160  100.176  -70.280  48.518  1
355161  100.207  -70.274  48.493  1
355162  100.237  -70.267  48.468  1
355163  100.268  -70.261  48.444  1
355164  100.298  -70.255  48.419  1
355165  100.341  -70.263  48.396  1
355166  100.384  -70.273  48.375  1
355167  100.428  -70.283  48.357  1
355168  100.471  -70.293  48.338  1
355169  100.514  -70.303  48.311  1
355170  100.564  -70.316  48.281  1
355171  100.613  -70.329  48.246  1
355172  100.662  -70.342  48.207  1
355173  100.711  -70.356  48.169  1
355174  100.760  -70.369  48.133  1
355175  100.810  -70.381  48.097  1
355176  100.858  -70.395  48.061  1
355177  100.887  -70.409  48.025  1
355178  100.899  -70.425  47.986  1
355179  100.910  -70.441  47.947  1
355180  100.938  -70.466  47.908  1
355181  100.968  -70.490  47.868  1
355182  100.999  -70.497  47.828  1
355183  101.030  -70.505  47.786  1
355184  101.060  -70.512  47.743  1
355185  101.090  -70.519  47.699  1
355186  101.117  -70.522  47.658  1
355187  101.144  -70.526  47.615  1
355188  101.172  -70.531  47.572  1
355189  101.199  -70.535  47.530  1
355190  101.226  -70.539  47.489  1
355191  101.253  -70.545  47.452  1
355192  101.280  -70.561  47.415  1
355193  101.312  -70.576  47.374  1
355194  101.346  -70.591  47.329  1
355195  101.381  -70.607  47.284  1
355196  101.415  -70.622  47.242  1
355197  101.450  -70.637  47.197  1
355198  101.484  -70.654  47.150  1
355199  101.518  -70.667  47.103  1
355200  101.554  -70.671  47.054  1
355201  101.591  -70.675  47.002  1
355202  101.631  -70.676  46.947  1
355203  101.677  -70.675  46.892  1
355204  101.723  -70.673  46.841  1
355205  101.769  -70.672  46.793  1
355206  101.815  -70.671  46.746  1
355207  101.861  -70.670  46.701  1
355208  101.906  -70.668  46.656  1
355209  101.952  -70.666  46.613  1
355210  101.998  -70.665  46.570  1
355211  102.044  -70.663  46.528  1
355212  102.090  -70.662  46.486  1
355213  102.117  -70.660  46.446  1
355637  92.302  -69.485  54.894  3
355638  92.341  -69.455  54.869  3
355639  92.388  -69.447  54.844  3
355640  92.436  -69.439  54.818  3
355641  92.484  -69.432  54.791  3
355642  92.531  -69.424  54.764  3
355643  92.579  -69.417  54.737  3
355644  92.627  -69.410  54.709  3
355645  92.674  -69.402  54.681  3
355646  92.721  -69.394  54.654  3
355647  92.766  -69.382  54.624  3
355648  92.811  -69.371  54.595  3
355649  92.856  -69.359  54.565  3
355650  92.900  -69.347  54.535  3
355651  92.945  -69.335  54.505  3
355652  92.990  -69.323  54.474  3
355653  93.028  -69.319  54.442  3
355654  93.063  -69.320  54.410  3
355655  93.098  -69.321  54.378  3
355656  93.133  -69.322  54.346  3
355657  93.168  -69.322  54.315  3
355658  93.203  -69.324  54.284  3
355659  93.238  -69.325  54.253  3
355660  93.273  -69.325  54.224  3
355661  93.307  -69.326  54.195  3
355662  93.343  -69.327  54.166  3
355663  93.377  -69.328  54.140  3
355664  93.413  -69.328  54.115  3
355694  94.462  -69.378  53.346  1
355695  94.493  -69.376  53.328  1
355696  94.525  -69.374  53.311  1
355697  94.556  -69.372  53.294  1
355698  94.588  -69.369  53.277  1
355699  94.619  -69.366  53.263  1
355700  94.650  -69.364  53.248  1
355701  94.682  -69.362  53.234  1
355702  94.713  -69.360  53.220  1
355703  94.745  -69.357  53.207  1
355704  94.776  -69.355  53.194  1
355705  94.808  -69.353  53.184  1
355706  94.839  -69.350  53.175  1
355707  94.871  -69.347  53.166  1
355708  94.927  -69.352  53.159  1
355709  95.019  -69.365  53.153  1
355710  95.111  -69.378  53.149  1
355711  95.182  -69.372  53.146  1
355712  95.244  -69.356  53.148  1
355713  95.306  -69.341  53.150  1
355714  95.367  -69.325  53.152  1
355715  95.426  -69.310  53.154  1
355716  95.452  -69.309  53.153  1
355717  95.477  -69.309  53.149  1
355718  95.503  -69.309  53.147  1
355719  95.529  -69.309  53.147  1
355720  95.554  -69.308  53.148  1
355721  95.580  -69.308  53.149  1
355722  95.606  -69.307  53.146  1
355723  95.631  -69.306  53.144  1
355724  95.657  -69.306  53.144  1
355725  95.683  -69.306  53.148  1
355726  95.710  -69.301  53.156  1
355727  95.738  -69.296  53.168  1
355728  95.765  -69.291  53.180  1
355729  95.793  -69.285  53.189  1
355730  95.821  -69.280  53.195  1
355731  95.848  -69.275  53.194  1
355732  95.876  -69.270  53.187  1
355733  95.904  -69.265  53.174  1
355734  95.932  -69.259  53.154  1
355735  95.959  -69.254  53.128  1
355736  95.987  -69.249  53.102  1
355737  96.015  -69.244  53.077  1
355738  96.042  -69.238  53.052  1
355739  96.070  -69.233  53.025  1
355740  96.097  -69.228  53.000  1
355741  96.125  -69.222  52.976  1
355742  96.153  -69.218  52.955  1
355743  96.180  -69.221  52.944  1
355744  96.208  -69.234  52.930  1
355745  96.236  -69.246  52.921  1
355746  96.260  -69.261  52.915  1
355747  96.283  -69.275  52.909  1
355748  96.309  -69.288  52.897  1
355749  96.335  -69.299  52.883  1
355750  96.365  -69.311  52.867  1
355751  96.399  -69.323  52.850  1
355752  96.434  -69.335  52.830  1
355753  96.468  -69.348  52.808  1
355754  96.503  -69.360  52.783  1
355755  96.536  -69.371  52.759  1
355756  96.567  -69.378  52.736  1
355757  96.595  -69.387  52.710  1
355758  96.624  -69.394  52.683  1
355759  96.654  -69.402  52.655  1
355760  96.683  -69.410  52.624  1
355761  96.712  -69.417  52.591  1
355762  96.741  -69.425  52.558  1
355763  96.771  -69.428  52.525  1
355764  96.802  -69.430  52.489  1
355765  96.832  -69.433  52.455  1
355766  96.863  -69.436  52.420  1
355767  96.895  -69.445  52.387  1
355768  96.928  -69.456  52.356  1
355769  96.960  -69.468  52.328  1
355770  96.995  -69.484  52.301  1
355771  97.028  -69.500  52.275  1
355772  97.061  -69.510  52.251  1
355773  97.093  -69.517  52.227  1
355774  97.124  -69.523  52.204  1
355775  97.156  -69.530  52.181  1
355776  97.187  -69.536  52.156  1
355777  97.219  -69.542  52.129  1
355778  97.251  -69.549  52.102  1
355779  97.283  -69.555  52.075  1
355780  97.317  -69.564  52.049  1
355781  97.349  -69.571  52.023  1
355782  97.380  -69.578  51.999  1
355783  97.412  -69.585  51.969  1
355784  97.443  -69.591  51.941  1
355785  97.474  -69.598  51.916  1
355786  97.506  -69.606  51.895  1
355787  97.537  -69.613  51.881  1
355788  97.568  -69.620  51.869  1
355789  97.599  -69.628  51.853  1
355790  97.633  -69.633  51.832  1
355791  97.674  -69.636  51.807  1
355792  97.718  -69.639  51.779  1
355793  97.755  -69.643  51.748  1
355794  97.794  -69.647  51.714  1
355795  97.831  -69.650  51.680  1
355796  97.870  -69.654  51.640  1
355797  97.908  -69.657  51.601  1
355798  97.945  -69.660  51.562  1
355799  97.968  -69.667  51.523  1
355800  97.991  -69.673  51.481  1
355801  98.028  -69.680  51.436  1
355802  98.073  -69.685  51.387  1
355803  98.112  -69.689  51.334  1
355804  98.143  -69.696  51.281  1
355805  98.173  -69.703  51.230  1
355806  98.204  -69.710  51.179  1
355807  98.235  -69.717  51.130  1
355808  98.266  -69.724  51.081  1
355809  98.296  -69.731  51.028  1
355810  98.327  -69.738  50.974  1
355811  98.358  -69.745  50.917  1
355812  98.389  -69.751  50.859  1
355813  98.420  -69.758  50.800  1
355814  98.450  -69.766  50.741  1
355815  98.481  -69.773  50.681  1
355816  98.512  -69.780  50.619  1
355817  98.543  -69.786  50.559  1
355818  98.574  -69.793  50.498  1
355819  98.604  -69.800  50.436  1
355820  98.635  -69.808  50.374  1
355821  98.673  -69.819  50.310  1
355822  98.717  -69.836  50.246  1
355823  98.761  -69.851  50.183  1
355824  98.795  -69.845  50.121  1
355825  98.836  -69.848  50.062  1
355826  98.883  -69.864  50.005  1
355827  98.931  -69.878  49.949  1
355828  98.979  -69.893  49.894  1
355829  99.017  -69.907  49.838  1
355830  99.040  -69.919  49.780  1
355831  99.063  -69.930  49.722  1
355832  99.086  -69.942  49.666  1
355833  99.118  -69.952  49.611  1
355834  99.151  -69.961  49.557  1
355835  99.184  -69.971  49.505  1
355836  99.217  -69.980  49.453  1
355837  99.251  -69.990  49.403  1
355838  99.290  -69.995  49.354  1
355839  99.331  -69.999  49.305  1
355840  99.371  -70.003  49.257  1
355841  99.411  -70.008  49.211  1
355842  99.448  -70.015  49.166  1
355843  99.486  -70.022  49.121  1
355844  99.527  -70.026  49.079  1
355845  99.577  -70.029  49.037  1
355846  99.627  -70.032  48.996  1
355847  99.677  -70.035  48.955  1
355848  99.727  -70.038  48.917  1
355849  99.777  -70.041  48.879  1
355850  99.827  -70.044  48.842  1
355851  99.874  -70.052  48.806  1
355852  99.906  -70.091  48.772  1
355853  99.938  -70.130  48.737  1
355854  99.970  -70.168  48.704  1
355855  100.002  -70.207  48.672  1
355856  100.034  -70.246  48.641  1
355857  100.065  -70.267  48.612  1
355858  100.097  -70.262  48.582  1
355859  100.127  -70.256  48.553  1
355860  100.157  -70.250  48.526  1
355861  100.188  -70.244  48.500  1
355862  100.219  -70.237  48.475  1
355863  100.250  -70.231  48.450  1
355864  100.280  -70.225  48.426  1
355865  100.316  -70.225  48.401  1
355866  100.359  -70.235  48.379  1
355867  100.403  -70.246  48.358  1
355868  100.446  -70.256  48.339  1
355869  100.490  -70.265  48.321  1
355870  100.534  -70.275  48.294  1
355871  100.579  -70.287  48.265  1
355872  100.628  -70.300  48.231  1
355873  100.678  -70.312  48.194  1
355874  100.726  -70.326  48.156  1
355875  100.776  -70.339  48.119  1
355876  100.825  -70.352  48.083  1
355877  100.874  -70.366  48.047  1
355878  100.898  -70.380  48.011  1
355879  100.909  -70.396  47.972  1
355880  100.920  -70.411  47.934  1
355881  100.940  -70.432  47.895  1
355882  100.971  -70.454  47.855  1
355883  101.001  -70.461  47.816  1
355884  101.032  -70.469  47.774  1
355885  101.063  -70.476  47.731  1
355886  101.094  -70.483  47.688  1
355887  101.125  -70.491  47.649  1
355888  101.155  -70.497  47.607  1
355889  101.182  -70.501  47.564  1
355890  101.209  -70.506  47.521  1
355891  101.236  -70.510  47.478  1
355892  101.263  -70.515  47.437  1
355893  101.291  -70.531  47.396  1
355894  101.325  -70.546  47.353  1
355895  101.360  -70.561  47.308  1
355896  101.394  -70.576  47.266  1
355897  101.428  -70.594  47.223  1
355898  101.461  -70.613  47.179  1
355899  101.496  -70.623  47.133  1
355900  101.533  -70.627  47.086  1
355901  101.569  -70.631  47.039  1
355902  101.605  -70.635  46.989  1
355903  101.642  -70.638  46.936  1
355904  101.678  -70.643  46.881  1
355905  101.721  -70.643  46.831  1
355906  101.767  -70.641  46.783  1
355907  101.813  -70.640  46.737  1
355908  101.858  -70.638  46.692  1
355909  101.904  -70.637  46.649  1
355910  101.950  -70.635  46.605  1
355911  101.996  -70.635  46.563  1
355912  102.042  -70.633  46.522  1
355913  102.088  -70.632  46.481  1
355914  102.133  -70.630  46.441  1
356339  92.337  -69.438  54.859  3
356340  92.384  -69.430  54.835  3
356341  92.432  -69.422  54.809  3
356342  92.480  -69.416  54.781  3
356343  92.527  -69.408  54.753  3
356344  92.575  -69.400  54.726  3
356345  92.622  -69.393  54.698  3
356346  92.670  -69.385  54.669  3
356347  92.715  -69.374  54.641  3
356348  92.760  -69.362  54.611  3
356349  92.804  -69.350  54.581  3
356350  92.849  -69.338  54.551  3
356351  92.894  -69.326  54.520  3
356352  92.938  -69.315  54.490  3
356353  92.983  -69.303  54.459  3
356354  93.022  -69.297  54.427  3
356355  93.058  -69.298  54.394  3
356356  93.092  -69.299  54.361  3
356357  93.127  -69.300  54.330  3
356358  93.162  -69.300  54.299  3
356359  93.197  -69.301  54.268  3
356360  93.232  -69.302  54.238  3
356361  93.267  -69.303  54.209  3
356362  93.302  -69.303  54.180  3
356363  93.337  -69.304  54.152  3
356364  93.372  -69.305  54.126  3
356365  93.407  -69.306  54.101  3
356395  94.461  -69.356  53.359  1
356396  94.492  -69.354  53.342  1
356397  94.524  -69.352  53.326  1
356398  94.555  -69.350  53.310  1
356399  94.587  -69.347  53.294  1
356400  94.618  -69.345  53.280  1
356401  94.650  -69.343  53.267  1
356402  94.681  -69.340  53.253  1
356403  94.712  -69.338  53.240  1
356404  94.744  -69.335  53.228  1
356405  94.775  -69.333  53.216  1
356406  94.807  -69.331  53.206  1
356407  94.838  -69.328  53.199  1
356408  94.876  -69.328  53.193  1
356409  94.968  -69.341  53.187  1
356410  95.060  -69.354  53.182  1
356411  95.128  -69.344  53.179  1
356412  95.189  -69.328  53.178  1
356413  95.251  -69.313  53.180  1
356414  95.313  -69.297  53.182  1
356415  95.374  -69.281  53.185  1
356416  95.429  -69.269  53.186  1
356417  95.455  -69.269  53.186  1
356418  95.480  -69.268  53.182  1
356419  95.506  -69.268  53.182  1
356420  95.532  -69.267  53.184  1
356421  95.557  -69.267  53.187  1
356422  95.583  -69.266  53.190  1
356423  95.609  -69.266  53.189  1
356424  95.634  -69.266  53.185  1
356425  95.660  -69.265  53.178  1
356426  95.686  -69.265  53.171  1
356427  95.711  -69.264  53.175  1
356428  95.737  -69.264  53.188  1
356429  95.764  -69.259  53.202  1
356430  95.792  -69.254  53.214  1
356431  95.820  -69.249  53.218  1
356432  95.847  -69.244  53.214  1
356433  95.875  -69.238  53.205  1
356434  95.903  -69.233  53.189  1
356435  95.930  -69.228  53.167  1
356436  95.958  -69.222  53.146  1
356437  95.985  -69.218  53.125  1
356438  96.013  -69.212  53.101  1
356439  96.041  -69.207  53.075  1
356440  96.068  -69.202  53.049  1
356441  96.096  -69.197  53.022  1
356442  96.124  -69.191  52.998  1
356443  96.152  -69.186  52.978  1
356444  96.179  -69.190  52.970  1
356445  96.207  -69.203  52.960  1
356446  96.235  -69.215  52.953  1
356447  96.262  -69.228  52.947  1
356448  96.288  -69.242  52.939  1
356449  96.313  -69.255  52.924  1
356450  96.344  -69.267  52.909  1
356451  96.378  -69.279  52.892  1
356452  96.412  -69.291  52.874  1
356453  96.447  -69.303  52.853  1
356454  96.481  -69.316  52.831  1
356455  96.517  -69.328  52.807  1
356456  96.547  -69.338  52.781  1
356457  96.576  -69.346  52.757  1
356458  96.605  -69.353  52.729  1
356459  96.634  -69.361  52.699  1
356460  96.663  -69.369  52.667  1
356461  96.692  -69.377  52.633  1
356462  96.721  -69.385  52.599  1
356463  96.750  -69.392  52.564  1
356464  96.780  -69.397  52.528  1
356465  96.811  -69.400  52.490  1
356466  96.841  -69.403  52.454  1
356467  96.872  -69.406  52.419  1
356468  96.904  -69.415  52.385  1
356469  96.937  -69.426  52.355  1
356470  96.969  -69.437  52.327  1
356471  97.002  -69.447  52.299  1
356472  97.035  -69.461  52.272  1
356473  97.069  -69.477  52.246  1
356474  97.100  -69.484  52.221  1
356475  97.132  -69.490  52.196  1
356476  97.163  -69.496  52.172  1
356477  97.195  -69.502  52.146  1
356478  97.227  -69.509  52.118  1
356479  97.258  -69.515  52.090  1
356480  97.290  -69.521  52.063  1
356481  97.321  -69.528  52.035  1
356482  97.352  -69.535  52.007  1
356483  97.383  -69.543  51.980  1
356484  97.414  -69.551  51.950  1
356485  97.445  -69.558  51.921  1
356486  97.476  -69.565  51.896  1
356487  97.508  -69.573  51.876  1
356488  97.538  -69.580  51.862  1
356489  97.570  -69.587  51.850  1
356490  97.605  -69.591  51.835  1
356491  97.640  -69.595  51.815  1
356492  97.683  -69.598  51.792  1
356493  97.727  -69.601  51.764  1
356494  97.771  -69.604  51.735  1
356495  97.813  -69.608  51.703  1
356496  97.852  -69.611  51.670  1
356497  97.889  -69.615  51.631  1
356498  97.924  -69.619  51.592  1
356499  97.946  -69.625  51.551  1
356500  97.969  -69.631  51.510  1
356501  97.992  -69.637  51.467  1
356502  98.033  -69.645  51.421  1
356503  98.078  -69.650  51.373  1
356504  98.122  -69.654  51.322  1
356505  98.159  -69.659  51.271  1
356506  98.190  -69.666  51.221  1
356507  98.220  -69.673  51.173  1
356508  98.251  -69.679  51.124  1
356509  98.282  -69.686  51.074  1
356510  98.313  -69.694  51.020  1
356511  98.344  -69.701  50.964  1
356512  98.374  -69.707  50.906  1
356513  98.405  -69.714  50.847  1
356514  98.436  -69.721  50.789  1
356515  98.466  -69.728  50.730  1
356516  98.497  -69.736  50.669  1
356517  98.528  -69.742  50.608  1
356518  98.559  -69.749  50.546  1
356519  98.590  -69.756  50.483  1
356520  98.621  -69.763  50.420  1
356521  98.651  -69.770  50.358  1
356522  98.695  -69.786  50.295  1
356523  98.739  -69.803  50.232  1
356524  98.784  -69.820  50.171  1
356525  98.818  -69.814  50.112  1
356526  98.861  -69.820  50.056  1
356527  98.909  -69.836  50.000  1
356528  98.956  -69.850  49.945  1
356529  99.002  -69.865  49.889  1
356530  99.025  -69.877  49.833  1
356531  99.048  -69.889  49.774  1
356532  99.071  -69.901  49.717  1
356533  99.094  -69.912  49.661  1
356534  99.120  -69.924  49.606  1
356535  99.153  -69.933  49.552  1
356536  99.187  -69.942  49.500  1
356537  99.220  -69.952  49.449  1
356538  99.254  -69.961  49.400  1
356539  99.292  -69.967  49.351  1
356540  99.333  -69.971  49.301  1
356541  99.374  -69.974  49.253  1
356542  99.414  -69.979  49.207  1
356543  99.455  -69.983  49.162  1
356544  99.494  -69.988  49.116  1
356545  99.535  -69.993  49.073  1
356546  99.585  -69.996  49.031  1
356547  99.635  -69.999  48.990  1
356548  99.685  -70.002  48.949  1
356549  99.735  -70.005  48.911  1
356550  99.785  -70.008  48.872  1
356551  99.835  -70.011  48.835  1
356552  99.886  -70.014  48.798  1
356553  99.920  -70.047  48.762  1
356554  99.952  -70.086  48.728  1
356555  99.984  -70.124  48.694  1
356556  100.015  -70.163  48.662  1
356557  100.047  -70.203  48.630  1
356558  100.075  -70.237  48.600  1
356559  100.106  -70.231  48.569  1
356560  100.136  -70.225  48.540  1
356561  100.168  -70.218  48.511  1
356562  100.198  -70.212  48.485  1
356563  100.229  -70.205  48.460  1
356564  100.260  -70.198  48.435  1
356565  100.290  -70.192  48.410  1
356566  100.335  -70.198  48.385  1
356567  100.379  -70.208  48.363  1
356568  100.422  -70.218  48.342  1
356569  100.466  -70.228  48.323  1
356570  100.509  -70.237  48.304  1
356571  100.552  -70.247  48.278  1
356572  100.596  -70.257  48.249  1
356573  100.644  -70.270  48.216  1
356574  100.693  -70.283  48.181  1
356575  100.742  -70.297  48.144  1
356576  100.791  -70.309  48.107  1
356577  100.840  -70.322  48.070  1
356578  100.889  -70.336  48.034  1
356579  100.908  -70.351  47.997  1
356580  100.920  -70.366  47.959  1
356581  100.931  -70.382  47.921  1
356582  100.943  -70.398  47.883  1
356583  100.973  -70.418  47.844  1
356584  101.004  -70.425  47.803  1
356585  101.035  -70.433  47.762  1
356586  101.066  -70.440  47.721  1
356587  101.097  -70.447  47.680  1
356588  101.127  -70.455  47.643  1
356589  101.158  -70.462  47.602  1
356590  101.189  -70.469  47.560  1
356591  101.219  -70.476  47.517  1
356592  101.247  -70.481  47.472  1
356593  101.274  -70.485  47.424  1
356594  101.305  -70.500  47.378  1
356595  101.339  -70.516  47.332  1
356596  101.373  -70.533  47.287  1
356597  101.406  -70.552  47.245  1
356598  101.439  -70.571  47.202  1
356599  101.474  -70.579  47.157  1
356600  101.511  -70.583  47.112  1
356601  101.547  -70.587  47.067  1
356602  101.584  -70.591  47.021  1
356603  101.620  -70.595  46.972  1
356604  101.656  -70.599  46.921  1
356605  101.693  -70.603  46.867  1
356606  101.729  -70.607  46.819  1
356607  101.765  -70.610  46.773  1
356608  101.810  -70.610  46.728  1
356609  101.856  -70.608  46.684  1
356610  101.902  -70.607  46.641  1
356611  101.948  -70.605  46.598  1
356612  101.993  -70.604  46.556  1
356613  102.039  -70.602  46.515  1
356614  102.085  -70.601  46.474  1
357041  92.380  -69.414  54.826  3
357042  92.428  -69.407  54.800  3
357043  92.476  -69.399  54.772  3
357044  92.523  -69.391  54.743  3
357045  92.571  -69.384  54.716  3
357046  92.618  -69.376  54.687  3
357047  92.663  -69.365  54.657  3
357048  92.708  -69.353  54.629  3
357049  92.753  -69.341  54.598  3
357050  92.797  -69.329  54.568  3
357051  92.842  -69.318  54.537  3
357052  92.886  -69.306  54.507  3
357053  92.931  -69.294  54.475  3
357054  92.976  -69.282  54.444  3
357055  93.017  -69.275  54.412  3
357056  93.052  -69.275  54.378  3
357057  93.087  -69.276  54.346  3
357058  93.122  -69.277  54.314  3
357059  93.157  -69.278  54.282  3
357060  93.192  -69.279  54.252  3
357061  93.227  -69.280  54.222  3
357062  93.262  -69.281  54.193  3
357063  93.296  -69.281  54.165  3
357064  93.332  -69.282  54.139  3
357065  93.366  -69.283  54.113  3
357095  94.425  -69.332  53.388  1
357096  94.461  -69.335  53.372  1
357097  94.492  -69.333  53.356  1
357098  94.523  -69.330  53.341  1
357099  94.555  -69.328  53.325  1
357100  94.586  -69.325  53.310  1
357101  94.618  -69.323  53.297  1
357102  94.649  -69.321  53.285  1
357103  94.681  -69.319  53.273  1
357104  94.712  -69.316  53.261  1
357105  94.744  -69.314  53.249  1
357106  94.775  -69.311  53.238  1
357107  94.806  -69.309  53.230  1
357108  94.838  -69.306  53.224  1
357109  94.918  -69.317  53.220  1
357110  95.010  -69.330  53.214  1
357111  95.073  -69.317  53.211  1
357112  95.135  -69.301  53.209  1
357113  95.197  -69.285  53.209  1
357114  95.258  -69.269  53.211  1
357115  95.320  -69.254  53.214  1
357116  95.382  -69.238  53.215  1
357117  95.432  -69.228  53.216  1
357118  95.458  -69.227  53.216  1
357119  95.483  -69.227  53.213  1
357120  95.509  -69.226  53.213  1
357121  95.535  -69.225  53.216  1
357122  95.560  -69.225  53.219  1
357123  95.586  -69.225  53.222  1
357124  95.612  -69.225  53.223  1
357125  95.637  -69.224  53.220  1
357126  95.663  -69.224  53.214  1
357127  95.689  -69.223  53.209  1
357128  95.714  -69.223  53.204  1
357129  95.740  -69.222  53.208  1
357130  95.765  -69.222  53.218  1
357131  95.791  -69.222  53.228  1
357132  95.818  -69.218  53.231  1
357133  95.846  -69.212  53.227  1
357134  95.874  -69.207  53.217  1
357135  95.901  -69.202  53.203  1
357136  95.929  -69.197  53.184  1
357137  95.957  -69.191  53.167  1
357138  95.984  -69.186  53.148  1
357139  96.012  -69.181  53.126  1
357140  96.040  -69.175  53.100  1
357141  96.067  -69.170  53.070  1
357142  96.095  -69.165  53.042  1
357143  96.122  -69.160  53.019  1
357144  96.150  -69.155  53.004  1
357145  96.178  -69.160  53.001  1
357146  96.206  -69.172  52.994  1
357147  96.234  -69.185  52.987  1
357148  96.261  -69.198  52.978  1
357149  96.289  -69.210  52.966  1
357150  96.324  -69.223  52.951  1
357151  96.360  -69.236  52.935  1
357152  96.395  -69.248  52.918  1
357153  96.431  -69.261  52.899  1
357154  96.466  -69.274  52.877  1
357155  96.501  -69.286  52.854  1
357156  96.527  -69.295  52.829  1
357157  96.552  -69.303  52.802  1
357158  96.584  -69.312  52.776  1
357159  96.615  -69.321  52.744  1
357160  96.644  -69.328  52.711  1
357161  96.673  -69.336  52.677  1
357162  96.702  -69.344  52.640  1
357163  96.731  -69.351  52.604  1
357164  96.760  -69.360  52.567  1
357165  96.789  -69.367  52.529  1
357166  96.819  -69.371  52.488  1
357167  96.850  -69.373  52.452  1
357168  96.881  -69.376  52.417  1
357169  96.912  -69.385  52.384  1
357170  96.945  -69.396  52.355  1
357171  96.977  -69.407  52.327  1
357172  97.010  -69.418  52.298  1
357173  97.043  -69.429  52.270  1
357174  97.075  -69.440  52.242  1
357175  97.108  -69.450  52.216  1
357176  97.139  -69.456  52.190  1
357177  97.170  -69.463  52.163  1
357178  97.201  -69.469  52.136  1
357179  97.231  -69.476  52.107  1
357180  97.261  -69.482  52.079  1
357181  97.292  -69.488  52.049  1
357182  97.323  -69.495  52.019  1
357183  97.354  -69.503  51.990  1
357184  97.385  -69.510  51.960  1
357185  97.416  -69.517  51.930  1
357186  97.447  -69.525  51.901  1
357187  97.478  -69.532  51.875  1
357188  97.510  -69.540  51.855  1
357189  97.542  -69.545  51.841  1
357190  97.577  -69.550  51.829  1
357191  97.612  -69.554  51.815  1
357192  97.649  -69.557  51.795  1
357193  97.693  -69.560  51.772  1
357194  97.736  -69.563  51.746  1
357195  97.780  -69.566  51.718  1
357196  97.823  -69.570  51.688  1
357197  97.867  -69.573  51.658  1
357198  97.902  -69.577  51.620  1
357199  97.925  -69.583  51.580  1
357200  97.947  -69.589  51.539  1
357201  97.970  -69.595  51.496  1
357202  97.993  -69.601  51.452  1
357203  98.038  -69.610  51.407  1
357204  98.084  -69.616  51.359  1
357205  98.128  -69.619  51.309  1
357206  98.172  -69.623  51.260  1
357207  98.206  -69.629  51.212  1
357208  98.236  -69.635  51.163  1
357209  98.267  -69.642  51.114  1
357210  98.298  -69.649  51.063  1
357211  98.329  -69.656  51.007  1
357212  98.360  -69.664  50.950  1
357213  98.390  -69.670  50.891  1
357214  98.421  -69.677  50.831  1
357215  98.452  -69.684  50.773  1
357216  98.483  -69.691  50.714  1
357217  98.514  -69.698  50.654  1
357218  98.545  -69.705  50.592  1
357219  98.575  -69.712  50.529  1
357220  98.606  -69.719  50.466  1
357221  98.637  -69.726  50.403  1
357222  98.673  -69.736  50.341  1
357223  98.717  -69.754  50.279  1
357224  98.762  -69.770  50.218  1
357225  98.806  -69.787  50.160  1
357226  98.842  -69.784  50.104  1
357227  98.886  -69.792  50.050  1
357228  98.933  -69.808  49.994  1
357229  98.981  -69.823  49.938  1
357230  99.010  -69.835  49.883  1
357231  99.033  -69.847  49.826  1
357232  99.056  -69.858  49.767  1
357233  99.079  -69.870  49.711  1
357234  99.102  -69.883  49.655  1
357235  99.126  -69.894  49.601  1
357236  99.156  -69.905  49.547  1
357237  99.190  -69.914  49.495  1
357238  99.223  -69.924  49.445  1
357239  99.256  -69.933  49.395  1
357240  99.295  -69.938  49.346  1
357241  99.335  -69.942  49.296  1
357242  99.376  -69.946  49.249  1
357243  99.416  -69.950  49.203  1
357244  99.457  -69.954  49.157  1
357245  99.497  -69.958  49.112  1
357246  99.542  -69.965  49.068  1
357247  99.592  -69.965  49.026  1
357248  99.644  -69.965  48.984  1
357249  99.694  -69.968  48.942  1
357250  99.744  -69.971  48.904  1
357251  99.794  -69.974  48.865  1
357252  99.844  -69.977  48.827  1
357253  99.894  -69.980  48.790  1
357254  99.933  -70.003  48.753  1
357255  99.966  -70.042  48.719  1
357256  99.997  -70.080  48.685  1
357257  100.029  -70.121  48.653  1
357258  100.060  -70.161  48.621  1
357259  100.085  -70.190  48.589  1
357260  100.113  -70.204  48.558  1
357261  100.144  -70.197  48.528  1
357262  100.174  -70.190  48.498  1
357263  100.205  -70.184  48.472  1
357264  100.237  -70.177  48.447  1
357265  100.267  -70.171  48.421  1
357266  100.300  -70.165  48.396  1
357267  100.348  -70.173  48.371  1
357268  100.397  -70.181  48.348  1
357269  100.441  -70.190  48.328  1
357270  100.484  -70.200  48.308  1
357271  100.528  -70.210  48.289  1
357272  100.571  -70.220  48.264  1
357273  100.615  -70.230  48.235  1
357274  100.659  -70.240  48.203  1
357275  100.708  -70.253  48.169  1
357276  100.757  -70.267  48.135  1
357277  100.807  -70.280  48.097  1
357278  100.855  -70.293  48.059  1
357279  100.905  -70.306  48.023  1
357280  100.919  -70.322  47.986  1
357281  100.930  -70.337  47.948  1
357282  100.941  -70.353  47.912  1
357283  100.953  -70.369  47.876  1
357284  100.976  -70.382  47.839  1
357285  101.007  -70.390  47.798  1
357286  101.038  -70.397  47.757  1
357287  101.068  -70.404  47.716  1
357288  101.099  -70.412  47.675  1
357289  101.130  -70.419  47.637  1
357290  101.161  -70.426  47.596  1
357291  101.192  -70.433  47.553  1
357292  101.222  -70.441  47.509  1
357293  101.253  -70.448  47.464  1
357294  101.284  -70.455  47.417  1
357295  101.317  -70.473  47.369  1
357296  101.350  -70.492  47.320  1
357297  101.384  -70.511  47.272  1
357298  101.417  -70.530  47.226  1
357299  101.453  -70.535  47.180  1
357300  101.489  -70.539  47.136  1
357301  101.526  -70.544  47.091  1
357302  101.562  -70.547  47.047  1
357303  101.598  -70.551  47.001  1
357304  101.634  -70.555  46.953  1
357305  101.671  -70.559  46.903  1
357306  101.707  -70.563  46.853  1
357307  101.744  -70.566  46.807  1
357308  101.780  -70.570  46.762  1
357309  101.816  -70.574  46.717  1
357310  101.854  -70.577  46.674  1
357311  101.900  -70.576  46.632  1
357312  101.946  -70.575  46.590  1
357313  101.991  -70.573  46.549  1
357314  102.037  -70.572  46.508  1
357743  92.424  -69.390  54.791  3
357744  92.472  -69.382  54.763  3
357745  92.519  -69.375  54.734  3
357746  92.567  -69.368  54.706  3
357747  92.612  -69.356  54.677  3
357748  92.656  -69.344  54.647  3
357749  92.701  -69.333  54.617  3
357750  92.746  -69.321  54.587  3
357751  92.790  -69.309  54.556  3
357752  92.835  -69.297  54.525  3
357753  92.880  -69.285  54.494  3
357754  92.924  -69.273  54.463  3
357755  92.969  -69.262  54.431  3
357756  93.011  -69.253  54.398  3
357757  93.047  -69.253  54.364  3
357758  93.081  -69.254  54.332  3
357759  93.116  -69.255  54.300  3
357760  93.151  -69.256  54.269  3
357761  93.186  -69.256  54.238  3
357762  93.221  -69.257  54.208  3
357763  93.256  -69.258  54.180  3
357764  93.291  -69.259  54.152  3
357765  93.326  -69.260  54.125  3
357796  94.415  -69.298  53.401  1
357797  94.451  -69.302  53.385  1
357798  94.487  -69.306  53.370  1
357799  94.523  -69.309  53.355  1
357800  94.554  -69.306  53.340  1
357801  94.585  -69.303  53.325  1
357802  94.617  -69.301  53.314  1
357803  94.648  -69.299  53.302  1
357804  94.680  -69.297  53.291  1
357805  94.711  -69.294  53.280  1
357806  94.743  -69.292  53.271  1
357807  94.774  -69.290  53.261  1
357808  94.806  -69.288  53.254  1
357809  94.867  -69.293  53.250  1
357810  94.958  -69.305  53.246  1
357811  95.020  -69.289  53.241  1
357812  95.081  -69.273  53.239  1
357813  95.142  -69.258  53.238  1
357814  95.204  -69.242  53.238  1
357815  95.266  -69.226  53.241  1
357816  95.327  -69.211  53.244  1
357817  95.389  -69.195  53.245  1
357818  95.435  -69.186  53.244  1
357819  95.461  -69.186  53.245  1
357820  95.486  -69.185  53.243  1
357821  95.512  -69.184  53.244  1
357822  95.538  -69.184  53.246  1
357823  95.563  -69.184  53.249  1
357824  95.589  -69.184  53.252  1
357825  95.614  -69.183  53.254  1
357826  95.640  -69.183  53.252  1
357827  95.666  -69.182  53.247  1
357828  95.691  -69.182  53.241  1
357829  95.717  -69.181  53.234  1
357830  95.743  -69.181  53.232  1
357831  95.768  -69.181  53.236  1
357832  95.794  -69.180  53.242  1
357833  95.820  -69.180  53.242  1
357834  95.845  -69.179  53.236  1
357835  95.873  -69.175  53.225  1
357836  95.900  -69.170  53.211  1
357837  95.928  -69.165  53.194  1
357838  95.956  -69.160  53.180  1
357839  95.983  -69.155  53.164  1
357840  96.011  -69.150  53.144  1
357841  96.038  -69.144  53.120  1
357842  96.066  -69.139  53.091  1
357843  96.094  -69.134  53.065  1
357844  96.121  -69.128  53.045  1
357845  96.149  -69.123  53.032  1
357846  96.177  -69.130  53.029  1
357847  96.204  -69.142  53.023  1
357848  96.232  -69.155  53.013  1
357849  96.260  -69.167  52.999  1
357850  96.291  -69.177  52.984  1
357851  96.329  -69.186  52.968  1
357852  96.373  -69.203  52.951  1
357853  96.415  -69.219  52.934  1
357854  96.451  -69.231  52.916  1
357855  96.486  -69.244  52.893  1
357856  96.518  -69.255  52.867  1
357857  96.529  -69.258  52.839  1
357858  96.556  -69.266  52.810  1
357859  96.588  -69.275  52.780  1
357860  96.620  -69.285  52.747  1
357861  96.652  -69.294  52.713  1
357862  96.682  -69.303  52.676  1
357863  96.712  -69.311  52.639  1
357864  96.741  -69.319  52.602  1
357865  96.770  -69.326  52.564  1
357866  96.799  -69.334  52.526  1
357867  96.828  -69.341  52.487  1
357868  96.859  -69.344  52.450  1
357869  96.889  -69.346  52.415  1
357870  96.922  -69.355  52.383  1
357871  96.954  -69.366  52.355  1
357872  96.986  -69.377  52.327  1
357873  97.019  -69.388  52.298  1
357874  97.051  -69.399  52.268  1
357875  97.083  -69.408  52.239  1
357876  97.111  -69.416  52.212  1
357877  97.141  -69.423  52.184  1
357878  97.172  -69.429  52.156  1
357879  97.203  -69.436  52.127  1
357880  97.233  -69.442  52.096  1
357881  97.263  -69.448  52.064  1
357882  97.294  -69.455  52.033  1
357883  97.325  -69.463  52.002  1
357884  97.356  -69.469  51.970  1
357885  97.387  -69.477  51.940  1
357886  97.418  -69.485  51.909  1
357887  97.449  -69.492  51.880  1
357888  97.480  -69.500  51.855  1
357889  97.515  -69.504  51.834  1
357890  97.549  -69.508  51.819  1
357891  97.584  -69.512  51.806  1
357892  97.619  -69.516  51.790  1
357893  97.659  -69.519  51.771  1
357894  97.702  -69.523  51.748  1
357895  97.746  -69.526  51.723  1
357896  97.789  -69.529  51.698  1
357897  97.833  -69.532  51.672  1
357898  97.874  -69.535  51.644  1
357899  97.903  -69.541  51.607  1
357900  97.926  -69.548  51.568  1
357901  97.948  -69.554  51.527  1
357902  97.971  -69.560  51.483  1
357903  97.996  -69.566  51.439  1
357904  98.043  -69.575  51.393  1
357905  98.089  -69.582  51.345  1
357906  98.133  -69.585  51.296  1
357907  98.177  -69.588  51.247  1
357908  98.221  -69.591  51.199  1
357909  98.253  -69.598  51.150  1
357910  98.284  -69.605  51.099  1
357911  98.314  -69.612  51.047  1
357912  98.345  -69.619  50.989  1
357913  98.376  -69.626  50.930  1
357914  98.407  -69.633  50.870  1
357915  98.437  -69.640  50.810  1
357916  98.468  -69.647  50.750  1
357917  98.499  -69.654  50.692  1
357918  98.530  -69.660  50.633  1
357919  98.561  -69.667  50.572  1
357920  98.591  -69.675  50.510  1
357921  98.622  -69.682  50.448  1
357922  98.653  -69.689  50.386  1
357923  98.695  -69.704  50.325  1
357924  98.739  -69.720  50.266  1
357925  98.784  -69.737  50.209  1
357926  98.829  -69.754  50.151  1
357927  98.865  -69.754  50.096  1
357928  98.911  -69.764  50.042  1
357929  98.958  -69.780  49.987  1
357930  98.996  -69.793  49.930  1
357931  99.019  -69.805  49.873  1
357932  99.042  -69.817  49.816  1
357933  99.065  -69.829  49.759  1
357934  99.088  -69.840  49.704  1
357935  99.111  -69.852  49.649  1
357936  99.134  -69.864  49.595  1
357937  99.159  -69.876  49.542  1
357938  99.192  -69.885  49.490  1
357939  99.225  -69.895  49.439  1
357940  99.259  -69.904  49.389  1
357941  99.297  -69.910  49.340  1
357942  99.338  -69.914  49.292  1
357943  99.378  -69.917  49.244  1
357944  99.419  -69.921  49.198  1
357945  99.459  -69.926  49.152  1
357946  99.501  -69.931  49.107  1
357947  99.548  -69.941  49.063  1
357948  99.593  -69.950  49.019  1
357949  99.645  -69.949  48.976  1
357950  99.697  -69.947  48.934  1
357951  99.749  -69.945  48.895  1
357952  99.801  -69.943  48.857  1
357953  99.852  -69.944  48.819  1
357954  99.902  -69.947  48.781  1
357955  99.947  -69.959  48.744  1
357956  99.979  -69.999  48.709  1
357957  100.010  -70.039  48.674  1
357958  100.042  -70.080  48.642  1
357959  100.070  -70.114  48.611  1
357960  100.096  -70.143  48.579  1
357961  100.121  -70.173  48.548  1
357962  100.151  -70.169  48.517  1
357963  100.182  -70.162  48.486  1
357964  100.213  -70.156  48.460  1
357965  100.244  -70.149  48.434  1
357966  100.274  -70.143  48.408  1
357967  100.312  -70.141  48.384  1
357968  100.360  -70.149  48.359  1
357969  100.409  -70.156  48.338  1
357970  100.457  -70.164  48.318  1
357971  100.503  -70.172  48.297  1
357972  100.547  -70.183  48.274  1
357973  100.590  -70.193  48.249  1
357974  100.634  -70.203  48.219  1
357975  100.677  -70.212  48.188  1
357976  100.724  -70.224  48.155  1
357977  100.773  -70.237  48.122  1
357978  100.822  -70.250  48.085  1
357979  100.871  -70.263  48.050  1
357980  100.918  -70.277  48.015  1
357981  100.929  -70.292  47.978  1
357982  100.941  -70.308  47.940  1
357983  100.952  -70.324  47.904  1
357984  100.964  -70.339  47.868  1
357985  100.989  -70.350  47.831  1
357986  101.015  -70.361  47.791  1
357987  101.046  -70.369  47.750  1
357988  101.077  -70.376  47.708  1
357989  101.108  -70.384  47.667  1
357990  101.139  -70.391  47.627  1
357991  101.170  -70.399  47.584  1
357992  101.201  -70.406  47.540  1
357993  101.232  -70.414  47.495  1
357994  101.263  -70.422  47.451  1
357995  101.295  -70.432  47.404  1
357996  101.328  -70.451  47.355  1
357997  101.361  -70.470  47.305  1
357998  101.395  -70.488  47.255  1
357999  101.431  -70.491  47.206  1
358000  101.467  -70.496  47.160  1
358001  101.503  -70.500  47.115  1
358002  101.540  -70.503  47.071  1
358003  101.576  -70.507  47.026  1
358004  101.613  -70.511  46.980  1
358005  101.649  -70.515  46.933  1
358006  101.685  -70.519  46.885  1
358007  101.722  -70.522  46.839  1
358008  101.758  -70.526  46.794  1
358009  101.795  -70.530  46.750  1
358010  101.831  -70.534  46.707  1
358011  101.868  -70.538  46.664  1
358012  101.904  -70.542  46.622  1
358013  101.944  -70.544  46.581  1
358014  101.989  -70.542  46.541  1
358015  102.035  -70.541  46.500  1
358446  92.515  -69.359  54.727  3
358447  92.560  -69.347  54.697  3
358448  92.605  -69.336  54.668  3
358449  92.650  -69.324  54.639  3
358450  92.694  -69.312  54.607  3
358451  92.739  -69.300  54.577  3
358452  92.784  -69.288  54.546  3
358453  92.828  -69.276  54.514  3
358454  92.873  -69.265  54.483  3
358455  92.918  -69.253  54.451  3
358456  92.962  -69.240  54.418  3
358457  93.006  -69.230  54.385  3
358458  93.041  -69.231  54.352  3
358459  93.076  -69.232  54.320  3
358460  93.111  -69.233  54.288  3
358461  93.146  -69.234  54.256  3
358462  93.181  -69.234  54.226  3
358463  93.216  -69.235  54.196  3
358464  93.251  -69.236  54.168  3
358465  93.285  -69.237  54.140  3
358497  94.404  -69.263  53.413  1
358498  94.440  -69.267  53.398  1
358499  94.476  -69.271  53.383  1
358500  94.512  -69.275  53.369  1
358501  94.549  -69.278  53.356  1
358502  94.585  -69.282  53.342  1
358503  94.616  -69.280  53.331  1
358504  94.648  -69.278  53.320  1
358505  94.679  -69.275  53.310  1
358506  94.710  -69.272  53.300  1
358507  94.742  -69.270  53.290  1
358508  94.773  -69.268  53.282  1
358509  94.816  -69.269  53.277  1
358510  94.904  -69.277  53.275  1
358511  94.965  -69.262  53.272  1
358512  95.027  -69.246  53.267  1
358513  95.088  -69.230  53.264  1
358514  95.150  -69.215  53.262  1
358515  95.211  -69.199  53.263  1
358516  95.273  -69.183  53.267  1
358517  95.334  -69.168  53.270  1
358518  95.396  -69.152  53.271  1
358519  95.438  -69.144  53.272  1
358520  95.463  -69.144  53.273  1
358521  95.489  -69.143  53.273  1
358522  95.515  -69.143  53.273  1
358523  95.540  -69.143  53.275  1
358524  95.566  -69.143  53.278  1
358525  95.592  -69.142  53.281  1
358526  95.617  -69.142  53.281  1
358527  95.643  -69.141  53.280  1
358528  95.669  -69.141  53.276  1
358529  95.694  -69.140  53.269  1
358530  95.720  -69.140  53.261  1
358531  95.746  -69.140  53.258  1
358532  95.771  -69.139  53.257  1
358533  95.797  -69.139  53.256  1
358534  95.823  -69.138  53.251  1
358535  95.848  -69.138  53.241  1
358536  95.874  -69.137  53.229  1
358537  95.900  -69.137  53.215  1
358538  95.926  -69.134  53.201  1
358539  95.954  -69.128  53.189  1
358540  95.982  -69.123  53.175  1
358541  96.010  -69.118  53.159  1
358542  96.037  -69.112  53.137  1
358543  96.065  -69.107  53.111  1
358544  96.093  -69.103  53.088  1
358545  96.120  -69.097  53.070  1
358546  96.148  -69.092  53.060  1
358547  96.176  -69.099  53.055  1
358548  96.203  -69.112  53.047  1
358549  96.231  -69.124  53.033  1
358550  96.261  -69.134  53.015  1
358551  96.296  -69.140  52.996  1
358552  96.332  -69.148  52.977  1
358553  96.377  -69.165  52.960  1
358554  96.420  -69.181  52.944  1
358555  96.464  -69.199  52.927  1
358556  96.506  -69.214  52.902  1
358557  96.520  -69.218  52.874  1
358558  96.532  -69.221  52.843  1
358559  96.560  -69.229  52.812  1
358560  96.592  -69.239  52.779  1
358561  96.624  -69.249  52.745  1
358562  96.656  -69.258  52.710  1
358563  96.688  -69.268  52.673  1
358564  96.720  -69.277  52.635  1
358565  96.750  -69.286  52.597  1
358566  96.780  -69.294  52.559  1
358567  96.808  -69.301  52.520  1
358568  96.837  -69.309  52.482  1
358569  96.868  -69.313  52.446  1
358570  96.898  -69.316  52.413  1
358571  96.930  -69.325  52.382  1
358572  96.962  -69.336  52.353  1
358573  96.995  -69.347  52.325  1
358574  97.028  -69.358  52.295  1
358575  97.058  -69.366  52.264  1
358576  97.088  -69.373  52.233  1
358577  97.116  -69.381  52.204  1
358578  97.144  -69.389  52.174  1
358579  97.174  -69.396  52.144  1
358580  97.204  -69.403  52.113  1
358581  97.235  -69.409  52.081  1
358582  97.265  -69.416  52.048  1
358583  97.296  -69.422  52.016  1
358584  97.327  -69.429  51.983  1
358585  97.358  -69.437  51.951  1
358586  97.389  -69.444  51.921  1
358587  97.420  -69.452  51.890  1
358588  97.453  -69.458  51.861  1
358589  97.488  -69.462  51.836  1
358590  97.522  -69.466  51.815  1
358591  97.557  -69.470  51.798  1
358592  97.591  -69.475  51.782  1
358593  97.626  -69.479  51.766  1
358594  97.668  -69.482  51.746  1
358595  97.712  -69.485  51.725  1
358596  97.755  -69.488  51.704  1
358597  97.799  -69.491  51.682  1
358598  97.843  -69.494  51.658  1
358599  97.873  -69.500  51.632  1
358600  97.901  -69.506  51.596  1
358601  97.927  -69.512  51.557  1
358602  97.949  -69.518  51.514  1
358603  97.972  -69.524  51.470  1
358604  98.001  -69.531  51.426  1
358605  98.048  -69.539  51.380  1
358606  98.094  -69.547  51.332  1
358607  98.139  -69.551  51.282  1
358608  98.182  -69.554  51.233  1
358609  98.227  -69.557  51.184  1
358610  98.269  -69.561  51.134  1
358611  98.300  -69.568  51.082  1
358612  98.331  -69.575  51.028  1
358613  98.361  -69.582  50.970  1
358614  98.392  -69.588  50.910  1
358615  98.423  -69.595  50.850  1
358616  98.454  -69.603  50.790  1
358617  98.485  -69.610  50.730  1
358618  98.515  -69.617  50.672  1
358619  98.546  -69.623  50.613  1
358620  98.577  -69.630  50.553  1
358621  98.607  -69.637  50.492  1
358622  98.638  -69.645  50.431  1
358623  98.673  -69.654  50.371  1
358624  98.717  -69.671  50.312  1
358625  98.762  -69.688  50.255  1
358626  98.806  -69.704  50.199  1
358627  98.851  -69.721  50.142  1
358628  98.889  -69.723  50.087  1
358629  98.936  -69.736  50.032  1
358630  98.981  -69.751  49.977  1
358631  99.004  -69.763  49.920  1
358632  99.027  -69.775  49.864  1
358633  99.050  -69.786  49.807  1
358634  99.073  -69.798  49.752  1
358635  99.096  -69.811  49.697  1
358636  99.119  -69.822  49.643  1
358637  99.142  -69.834  49.589  1
358638  99.165  -69.845  49.536  1
358639  99.195  -69.856  49.485  1
358640  99.228  -69.866  49.435  1
358641  99.261  -69.875  49.385  1
358642  99.299  -69.881  49.336  1
358643  99.340  -69.885  49.288  1
358644  99.380  -69.889  49.240  1
358645  99.421  -69.893  49.194  1
358646  99.462  -69.898  49.148  1
358647  99.507  -69.907  49.102  1
358648  99.554  -69.916  49.058  1
358649  99.600  -69.926  49.014  1
358650  99.646  -69.934  48.970  1
358651  99.698  -69.932  48.927  1
358652  99.750  -69.930  48.888  1
358653  99.802  -69.929  48.849  1
358654  99.854  -69.927  48.810  1
358655  99.906  -69.925  48.772  1
358656  99.958  -69.922  48.735  1
358657  99.992  -69.957  48.698  1
358658  100.023  -69.998  48.664  1
358659  100.054  -70.038  48.632  1
358660  100.080  -70.068  48.601  1
358661  100.106  -70.097  48.570  1
358662  100.131  -70.127  48.538  1
358663  100.158  -70.141  48.506  1
358664  100.189  -70.134  48.476  1
358665  100.220  -70.128  48.449  1
358666  100.251  -70.121  48.423  1
358667  100.282  -70.115  48.397  1
358668  100.324  -70.118  48.372  1
358669  100.372  -70.124  48.348  1
358670  100.421  -70.132  48.328  1
358671  100.469  -70.140  48.308  1
358672  100.517  -70.147  48.286  1
358673  100.565  -70.155  48.260  1
358674  100.609  -70.165  48.234  1
358675  100.652  -70.174  48.206  1
358676  100.696  -70.184  48.175  1
358677  100.740  -70.194  48.142  1
358678  100.788  -70.208  48.108  1
358679  100.837  -70.221  48.075  1
358680  100.887  -70.234  48.041  1
358681  100.929  -70.247  48.006  1
358682  100.940  -70.263  47.969  1
358683  100.952  -70.278  47.931  1
358684  100.963  -70.294  47.895  1
358685  100.986  -70.306  47.859  1
358686  101.011  -70.317  47.822  1
358687  101.037  -70.328  47.781  1
358688  101.063  -70.339  47.740  1
358689  101.089  -70.350  47.698  1
358690  101.118  -70.359  47.656  1
358691  101.149  -70.366  47.614  1
358692  101.180  -70.374  47.568  1
358693  101.211  -70.381  47.523  1
358694  101.243  -70.389  47.478  1
358695  101.273  -70.397  47.432  1
358696  101.305  -70.409  47.386  1
358697  101.339  -70.428  47.337  1
358698  101.373  -70.444  47.287  1
358699  101.409  -70.448  47.237  1
358700  101.446  -70.452  47.187  1
358701  101.482  -70.456  47.140  1
358702  101.518  -70.460  47.094  1
358703  101.555  -70.463  47.050  1
358704  101.591  -70.467  47.005  1
358705  101.627  -70.471  46.959  1
358706  101.664  -70.475  46.914  1
358707  101.700  -70.478  46.869  1
358708  101.737  -70.482  46.824  1
358709  101.773  -70.486  46.780  1
358710  101.809  -70.491  46.737  1
358711  101.845  -70.494  46.695  1
358712  101.882  -70.498  46.654  1
358713  101.918  -70.502  46.612  1
358714  101.955  -70.506  46.572  1
358715  101.991  -70.510  46.531  1
359149  92.598  -69.316  54.661  3
359150  92.643  -69.303  54.632  3
359151  92.688  -69.291  54.600  3
359152  92.732  -69.280  54.569  3
359153  92.777  -69.268  54.538  3
359154  92.821  -69.256  54.506  3
359155  92.866  -69.244  54.474  3
359156  92.911  -69.232  54.440  3
359157  92.955  -69.220  54.408  3
359158  93.000  -69.209  54.375  3
359159  93.036  -69.209  54.341  3
359160  93.070  -69.209  54.309  3
359161  93.105  -69.210  54.277  3
359162  93.140  -69.211  54.246  3
359163  93.175  -69.212  54.215  3
359164  93.210  -69.212  54.186  3
359165  93.245  -69.213  54.157  3
359197  94.363  -69.240  53.438  1
359198  94.398  -69.240  53.424  1
359199  94.433  -69.241  53.410  1
359200  94.468  -69.242  53.396  1
359201  94.503  -69.243  53.383  1
359202  94.538  -69.244  53.370  1
359203  94.574  -69.247  53.357  1
359204  94.610  -69.251  53.347  1
359205  94.646  -69.255  53.337  1
359206  94.679  -69.253  53.327  1
359207  94.710  -69.251  53.318  1
359208  94.741  -69.248  53.311  1
359209  94.773  -69.246  53.303  1
359210  94.849  -69.250  53.299  1
359211  94.911  -69.234  53.297  1
359212  94.972  -69.219  53.294  1
359213  95.034  -69.203  53.289  1
359214  95.096  -69.187  53.285  1
359215  95.157  -69.172  53.283  1
359216  95.218  -69.156  53.285  1
359217  95.280  -69.140  53.289  1
359218  95.342  -69.125  53.292  1
359219  95.403  -69.109  53.294  1
359220  95.441  -69.103  53.295  1
359221  95.466  -69.103  53.297  1
359222  95.492  -69.103  53.296  1
359223  95.518  -69.102  53.296  1
359224  95.543  -69.102  53.295  1
359225  95.569  -69.101  53.296  1
359226  95.595  -69.101  53.296  1
359227  95.620  -69.100  53.295  1
359228  95.646  -69.100  53.293  1
359229  95.672  -69.099  53.290  1
359230  95.697  -69.099  53.285  1
359231  95.723  -69.099  53.278  1
359232  95.749  -69.098  53.273  1
359233  95.774  -69.098  53.270  1
359234  95.800  -69.097  53.265  1
359235  95.826  -69.097  53.256  1
359236  95.851  -69.096  53.242  1
359237  95.877  -69.096  53.228  1
359238  95.902  -69.096  53.215  1
359239  95.928  -69.096  53.203  1
359240  95.954  -69.095  53.193  1
359241  95.981  -69.092  53.182  1
359242  96.009  -69.087  53.168  1
359243  96.036  -69.081  53.150  1
359244  96.063  -69.076  53.128  1
359245  96.091  -69.071  53.109  1
359246  96.119  -69.065  53.095  1
359247  96.147  -69.060  53.086  1
359248  96.174  -69.068  53.078  1
359249  96.202  -69.081  53.065  1
359250  96.231  -69.093  53.048  1
359251  96.266  -69.098  53.025  1
359252  96.301  -69.103  52.999  1
359253  96.336  -69.110  52.978  1
359254  96.380  -69.127  52.962  1
359255  96.424  -69.143  52.948  1
359256  96.468  -69.161  52.932  1
359257  96.507  -69.176  52.906  1
359258  96.522  -69.181  52.876  1
359259  96.534  -69.184  52.843  1
359260  96.564  -69.193  52.807  1
359261  96.596  -69.203  52.773  1
359262  96.628  -69.212  52.739  1
359263  96.660  -69.222  52.703  1
359264  96.692  -69.231  52.666  1
359265  96.724  -69.240  52.628  1
359266  96.756  -69.250  52.590  1
359267  96.788  -69.260  52.551  1
359268  96.818  -69.269  52.513  1
359269  96.847  -69.276  52.475  1
359270  96.876  -69.284  52.442  1
359271  96.907  -69.287  52.411  1
359272  96.939  -69.295  52.381  1
359273  96.971  -69.306  52.350  1
359274  97.004  -69.317  52.321  1
359275  97.033  -69.324  52.289  1
359276  97.063  -69.331  52.256  1
359277  97.092  -69.338  52.225  1
359278  97.120  -69.346  52.194  1
359279  97.148  -69.354  52.162  1
359280  97.176  -69.363  52.130  1
359281  97.206  -69.369  52.098  1
359282  97.237  -69.376  52.065  1
359283  97.267  -69.382  52.032  1
359284  97.298  -69.389  51.999  1
359285  97.329  -69.397  51.965  1
359286  97.360  -69.404  51.934  1
359287  97.391  -69.412  51.904  1
359288  97.425  -69.416  51.874  1
359289  97.460  -69.420  51.845  1
359290  97.495  -69.425  51.820  1
359291  97.529  -69.429  51.798  1
359292  97.564  -69.433  51.779  1
359293  97.598  -69.437  51.762  1
359294  97.634  -69.441  51.744  1
359295  97.677  -69.444  51.725  1
359296  97.721  -69.447  51.706  1
359297  97.764  -69.450  51.688  1
359298  97.808  -69.454  51.668  1
359299  97.843  -69.458  51.646  1
359300  97.871  -69.464  51.620  1
359301  97.900  -69.470  51.585  1
359302  97.928  -69.476  51.545  1
359303  97.950  -69.482  51.503  1
359304  97.973  -69.488  51.459  1
359305  98.006  -69.496  51.414  1
359306  98.053  -69.504  51.367  1
359307  98.100  -69.513  51.319  1
359308  98.144  -69.516  51.269  1
359309  98.188  -69.519  51.218  1
359310  98.232  -69.523  51.168  1
359311  98.276  -69.526  51.117  1
359312  98.316  -69.531  51.064  1
359313  98.347  -69.538  51.009  1
359314  98.377  -69.544  50.951  1
359315  98.408  -69.551  50.891  1
359316  98.439  -69.558  50.831  1
359317  98.470  -69.565  50.771  1
359318  98.501  -69.573  50.712  1
359319  98.531  -69.579  50.654  1
359320  98.562  -69.586  50.595  1
359321  98.593  -69.593  50.535  1
359322  98.624  -69.600  50.475  1
359323  98.654  -69.607  50.415  1
359324  98.695  -69.621  50.357  1
359325  98.739  -69.638  50.300  1
359326  98.784  -69.654  50.245  1
359327  98.829  -69.672  50.189  1
359328  98.873  -69.689  50.133  1
359329  98.913  -69.694  50.077  1
359330  98.960  -69.708  50.022  1
359331  98.989  -69.721  49.967  1
359332  99.012  -69.733  49.911  1
359333  99.035  -69.745  49.855  1
359334  99.058  -69.757  49.799  1
359335  99.081  -69.768  49.745  1
359336  99.104  -69.780  49.691  1
359337  99.127  -69.792  49.637  1
359338  99.150  -69.804  49.584  1
359339  99.173  -69.816  49.531  1
359340  99.197  -69.827  49.479  1
359341  99.230  -69.837  49.430  1
359342  99.264  -69.846  49.381  1
359343  99.301  -69.853  49.332  1
359344  99.342  -69.857  49.284  1
359345  99.382  -69.861  49.237  1
359346  99.423  -69.864  49.190  1
359347  99.468  -69.873  49.144  1
359348  99.513  -69.883  49.098  1
359349  99.560  -69.892  49.053  1
359350  99.606  -69.901  49.009  1
359351  99.651  -69.911  48.965  1
359352  99.699  -69.917  48.921  1
359353  99.751  -69.916  48.880  1
359354  99.803  -69.914  48.841  1
359355  99.855  -69.912  48.801  1
359356  99.907  -69.910  48.762  1
359357  99.959  -69.905  48.725  1
359358  100.004  -69.916  48.688  1
359359  100.036  -69.956  48.654  1
359360  100.064  -69.992  48.622  1
359361  100.090  -70.021  48.591  1
359362  100.116  -70.051  48.561  1
359363  100.141  -70.080  48.528  1
359364  100.167  -70.110  48.496  1
359365  100.197  -70.107  48.466  1
359366  100.227  -70.100  48.440  1
359367  100.258  -70.093  48.413  1
359368  100.289  -70.087  48.387  1
359369  100.336  -70.093  48.362  1
359370  100.385  -70.101  48.339  1
359371  100.433  -70.109  48.318  1
359372  100.481  -70.115  48.298  1
359373  100.529  -70.123  48.276  1
359374  100.577  -70.130  48.250  1
359375  100.626  -70.138  48.223  1
359376  100.671  -70.147  48.195  1
359377  100.715  -70.157  48.165  1
359378  100.758  -70.167  48.132  1
359379  100.804  -70.178  48.098  1
359380  100.853  -70.191  48.064  1
359381  100.902  -70.204  48.030  1
359382  100.939  -70.218  47.994  1
359383  100.951  -70.234  47.957  1
359384  100.962  -70.250  47.919  1
359385  100.982  -70.262  47.882  1
359386  101.007  -70.273  47.845  1
359387  101.033  -70.284  47.806  1
359388  101.059  -70.295  47.766  1
359389  101.085  -70.306  47.726  1
359390  101.110  -70.317  47.684  1
359391  101.136  -70.328  47.641  1
359392  101.162  -70.339  47.598  1
359393  101.191  -70.348  47.552  1
359394  101.221  -70.356  47.505  1
359395  101.253  -70.363  47.458  1
359396  101.284  -70.371  47.411  1
359397  101.317  -70.388  47.362  1
359398  101.351  -70.400  47.313  1
359399  101.387  -70.404  47.264  1
359400  101.424  -70.408  47.215  1
359401  101.460  -70.412  47.165  1
359402  101.496  -70.416  47.118  1
359403  101.533  -70.419  47.073  1
359404  101.569  -70.423  47.029  1
359405  101.606  -70.427  46.985  1
359406  101.642  -70.431  46.941  1
359407  101.678  -70.434  46.897  1
359408  101.714  -70.439  46.853  1
359409  101.751  -70.443  46.810  1
359410  101.787  -70.447  46.768  1
359411  101.824  -70.450  46.726  1
359412  101.860  -70.454  46.684  1
359413  101.896  -70.458  46.643  1
359414  101.933  -70.462  46.602  1
359415  101.969  -70.466  46.563  1
359854  92.770  -69.247  54.531  3
359855  92.814  -69.235  54.499  3
359856  92.859  -69.223  54.467  3
359857  92.904  -69.212  54.433  3
359858  92.948  -69.200  54.400  3
359859  92.993  -69.187  54.367  3
359860  93.030  -69.187  54.334  3
359861  93.065  -69.187  54.301  3
359862  93.100  -69.188  54.269  3
359863  93.135  -69.189  54.237  3
359864  93.169  -69.190  54.206  3
359865  93.205  -69.190  54.177  3
359898  94.358  -69.218  53.448  1
359899  94.393  -69.219  53.435  1
359900  94.428  -69.219  53.422  1
359901  94.463  -69.220  53.408  1
359902  94.498  -69.221  53.395  1
359903  94.533  -69.222  53.383  1
359904  94.567  -69.222  53.372  1
359905  94.603  -69.223  53.362  1
359906  94.637  -69.224  53.353  1
359907  94.673  -69.225  53.344  1
359908  94.708  -69.228  53.336  1
359909  94.741  -69.227  53.332  1
359910  94.795  -69.222  53.325  1
359911  94.856  -69.206  53.320  1
359912  94.918  -69.190  53.316  1
359913  94.980  -69.175  53.313  1
359914  95.041  -69.159  53.307  1
359915  95.103  -69.143  53.303  1
359916  95.165  -69.128  53.301  1
359917  95.226  -69.112  53.304  1
359918  95.287  -69.096  53.308  1
359919  95.349  -69.081  53.311  1
359920  95.411  -69.065  53.312  1
359921  95.444  -69.062  53.314  1
359922  95.469  -69.062  53.315  1
359923  95.495  -69.061  53.313  1
359924  95.521  -69.061  53.312  1
359925  95.546  -69.060  53.309  1
359926  95.572  -69.060  53.306  1
359927  95.598  -69.059  53.302  1
359928  95.623  -69.059  53.301  1
359929  95.649  -69.059  53.299  1
359930  95.675  -69.058  53.295  1
359931  95.700  -69.058  53.292  1
359932  95.726  -69.057  53.286  1
359933  95.751  -69.057  53.281  1
359934  95.777  -69.056  53.276  1
359935  95.803  -69.056  53.269  1
359936  95.828  -69.056  53.258  1
359937  95.854  -69.056  53.242  1
359938  95.880  -69.055  53.225  1
359939  95.905  -69.054  53.210  1
359940  95.931  -69.054  53.200  1
359941  95.957  -69.053  53.191  1
359942  95.982  -69.053  53.183  1
359943  96.008  -69.052  53.173  1
359944  96.035  -69.049  53.158  1
359945  96.062  -69.045  53.138  1
359946  96.090  -69.040  53.122  1
359947  96.118  -69.034  53.110  1
359948  96.146  -69.029  53.101  1
359949  96.173  -69.038  53.092  1
359950  96.201  -69.050  53.076  1
359951  96.236  -69.056  53.054  1
359952  96.270  -69.062  53.029  1
359953  96.305  -69.067  53.000  1
359954  96.340  -69.072  52.976  1
359955  96.384  -69.089  52.958  1
359956  96.428  -69.106  52.944  1
359957  96.470  -69.122  52.929  1
359958  96.504  -69.137  52.906  1
359959  96.524  -69.144  52.877  1
359960  96.536  -69.147  52.843  1
359961  96.568  -69.156  52.805  1
359962  96.600  -69.166  52.768  1
359963  96.632  -69.176  52.731  1
359964  96.664  -69.185  52.693  1
359965  96.696  -69.195  52.656  1
359966  96.728  -69.204  52.617  1
359967  96.760  -69.214  52.580  1
359968  96.792  -69.224  52.542  1
359969  96.824  -69.233  52.505  1
359970  96.856  -69.243  52.468  1
359971  96.886  -69.250  52.436  1
359972  96.915  -69.256  52.405  1
359973  96.947  -69.265  52.374  1
359974  96.979  -69.275  52.343  1
359975  97.009  -69.282  52.312  1
359976  97.038  -69.289  52.278  1
359977  97.068  -69.296  52.245  1
359978  97.097  -69.303  52.213  1
359979  97.125  -69.311  52.180  1
359980  97.153  -69.319  52.147  1
359981  97.181  -69.328  52.115  1
359982  97.209  -69.336  52.082  1
359983  97.238  -69.343  52.048  1
359984  97.269  -69.350  52.015  1
359985  97.300  -69.356  51.982  1
359986  97.331  -69.364  51.950  1
359987  97.363  -69.370  51.919  1
359988  97.397  -69.375  51.890  1
359989  97.432  -69.378  51.860  1
359990  97.467  -69.383  51.832  1
359991  97.502  -69.387  51.807  1
359992  97.536  -69.391  51.786  1
359993  97.571  -69.395  51.766  1
359994  97.605  -69.400  51.749  1
359995  97.643  -69.403  51.730  1
359996  97.686  -69.407  51.711  1
359997  97.730  -69.410  51.693  1
359998  97.774  -69.413  51.676  1
359999  97.813  -69.416  51.656  1
360000  97.842  -69.422  51.635  1
360001  97.870  -69.429  51.608  1
360002  97.899  -69.435  51.574  1
360003  97.928  -69.441  51.535  1
360004  97.951  -69.447  51.493  1
360005  97.974  -69.453  51.450  1
360006  98.011  -69.460  51.404  1
360007  98.058  -69.469  51.357  1
360008  98.105  -69.478  51.307  1
360009  98.149  -69.482  51.256  1
360010  98.194  -69.485  51.204  1
360011  98.237  -69.488  51.152  1
360012  98.282  -69.491  51.099  1
360013  98.326  -69.495  51.046  1
360014  98.363  -69.501  50.992  1
360015  98.393  -69.507  50.933  1
360016  98.425  -69.514  50.874  1
360017  98.455  -69.521  50.815  1
360018  98.486  -69.528  50.756  1
360019  98.517  -69.535  50.698  1
360020  98.548  -69.542  50.639  1
360021  98.578  -69.549  50.579  1
360022  98.609  -69.556  50.520  1
360023  98.640  -69.563  50.460  1
360024  98.673  -69.571  50.401  1
360025  98.717  -69.588  50.344  1
360026  98.762  -69.605  50.288  1
360027  98.806  -69.622  50.233  1
360028  98.851  -69.639  50.178  1
360029  98.896  -69.656  50.123  1
360030  98.938  -69.666  50.068  1
360031  98.975  -69.679  50.013  1
360032  98.998  -69.691  49.958  1
360033  99.021  -69.703  49.902  1
360034  99.044  -69.714  49.847  1
360035  99.067  -69.726  49.793  1
360036  99.090  -69.739  49.739  1
360037  99.113  -69.750  49.685  1
360038  99.136  -69.762  49.631  1
360039  99.159  -69.774  49.578  1
360040  99.182  -69.786  49.525  1
360041  99.205  -69.798  49.475  1
360042  99.233  -69.808  49.426  1
360043  99.266  -69.817  49.377  1
360044  99.303  -69.824  49.328  1
360045  99.344  -69.828  49.281  1
360046  99.384  -69.833  49.233  1
360047  99.428  -69.839  49.187  1
360048  99.474  -69.848  49.141  1
360049  99.519  -69.858  49.094  1
360050  99.566  -69.867  49.049  1
360051  99.612  -69.877  49.004  1
360052  99.657  -69.886  48.960  1
360053  99.704  -69.895  48.916  1
360054  99.752  -69.901  48.875  1
360055  99.803  -69.899  48.833  1
360056  99.855  -69.898  48.793  1
360057  99.908  -69.894  48.754  1
360058  99.960  -69.889  48.715  1
360059  100.013  -69.884  48.679  1
360060  100.049  -69.915  48.645  1
360061  100.074  -69.946  48.612  1
360062  100.100  -69.975  48.580  1
360063  100.126  -70.005  48.549  1
360064  100.151  -70.034  48.518  1
360065  100.177  -70.063  48.486  1
360066  100.204  -70.079  48.456  1
360067  100.234  -70.072  48.429  1
360068  100.266  -70.065  48.402  1
360069  100.299  -70.062  48.376  1
360070  100.348  -70.069  48.351  1
360071  100.396  -70.077  48.328  1
360072  100.444  -70.084  48.307  1
360073  100.493  -70.092  48.286  1
360074  100.541  -70.099  48.264  1
360075  100.590  -70.106  48.238  1
360076  100.638  -70.114  48.211  1
360077  100.686  -70.121  48.182  1
360078  100.734  -70.130  48.151  1
360079  100.777  -70.140  48.118  1
360080  100.821  -70.149  48.085  1
360081  100.868  -70.162  48.050  1
360082  100.917  -70.174  48.014  1
360083  100.950  -70.189  47.977  1
360084  100.961  -70.205  47.940  1
360085  100.978  -70.218  47.902  1
360086  101.004  -70.229  47.864  1
360087  101.030  -70.240  47.827  1
360088  101.055  -70.251  47.788  1
360089  101.081  -70.262  47.749  1
360090  101.107  -70.273  47.709  1
360091  101.132  -70.284  47.667  1
360092  101.158  -70.295  47.624  1
360093  101.184  -70.306  47.580  1
360094  101.209  -70.317  47.534  1
360095  101.235  -70.328  47.487  1
360096  101.263  -70.337  47.440  1
360097  101.294  -70.347  47.392  1
360098  101.329  -70.356  47.342  1
360099  101.365  -70.360  47.292  1
360100  101.402  -70.364  47.242  1
360101  101.439  -70.368  47.192  1
360102  101.475  -70.372  47.144  1
360103  101.511  -70.375  47.097  1
360104  101.547  -70.379  47.053  1
360105  101.584  -70.383  47.009  1
360106  101.620  -70.387  46.966  1
360107  101.656  -70.391  46.923  1
360108  101.693  -70.395  46.881  1
360109  101.729  -70.399  46.839  1
360110  101.766  -70.403  46.797  1
360111  101.802  -70.406  46.756  1
360112  101.838  -70.410  46.714  1
360113  101.875  -70.414  46.673  1
360114  101.911  -70.418  46.633  1
360115  101.948  -70.422  46.592  1
360116  101.984  -70.425  46.554  1
360599  94.352  -69.195  53.456  1
360600  94.387  -69.196  53.444  1
360601  94.422  -69.197  53.432  1
360602  94.457  -69.197  53.419  1
360603  94.492  -69.199  53.407  1
360604  94.527  -69.200  53.395  1
360605  94.562  -69.200  53.384  1
360606  94.597  -69.201  53.375  1
360607  94.632  -69.202  53.367  1
360608  94.667  -69.203  53.359  1
360609  94.702  -69.203  53.353  1
360610  94.755  -69.171  53.350  1
360611  94.808  -69.166  53.344  1
360612  94.864  -69.163  53.337  1
360613  94.925  -69.147  53.332  1
360614  94.987  -69.132  53.327  1
360615  95.049  -69.116  53.321  1
360616  95.110  -69.100  53.317  1
360617  95.172  -69.085  53.316  1
360618  95.233  -69.069  53.318  1
360619  95.295  -69.053  53.321  1
360620  95.356  -69.038  53.322  1
360621  95.418  -69.022  53.323  1
360622  95.447  -69.021  53.325  1
360623  95.472  -69.020  53.325  1
360624  95.498  -69.020  53.323  1
360625  95.524  -69.019  53.320  1
360626  95.549  -69.019  53.315  1
360627  95.574  -69.018  53.308  1
360628  95.600  -69.018  53.301  1
360629  95.626  -69.018  53.298  1
360630  95.652  -69.017  53.296  1
360631  95.677  -69.017  53.294  1
360632  95.703  -69.016  53.292  1
360633  95.729  -69.016  53.287  1
360634  95.754  -69.015  53.282  1
360635  95.780  -69.015  53.277  1
360636  95.806  -69.015  53.270  1
360637  95.831  -69.015  53.259  1
360638  95.857  -69.014  53.242  1
360639  95.883  -69.013  53.222  1
360640  95.908  -69.013  53.204  1
360641  95.934  -69.012  53.195  1
360642  95.960  -69.012  53.188  1
360643  95.985  -69.012  53.183  1
360644  96.011  -69.012  53.175  1
360645  96.037  -69.011  53.162  1
360646  96.062  -69.011  53.145  1
360647  96.089  -69.008  53.132  1
360648  96.116  -69.002  53.122  1
360649  96.144  -68.997  53.114  1
360650  96.172  -69.008  53.102  1
360651  96.206  -69.014  53.083  1
360652  96.241  -69.019  53.058  1
360653  96.275  -69.024  53.030  1
360654  96.310  -69.031  53.000  1
360655  96.345  -69.036  52.974  1
360656  96.388  -69.051  52.955  1
360657  96.432  -69.068  52.941  1
360658  96.468  -69.083  52.925  1
360659  96.501  -69.097  52.904  1
360660  96.527  -69.107  52.876  1
360661  96.540  -69.111  52.842  1
360662  96.572  -69.120  52.803  1
360663  96.604  -69.130  52.762  1
360664  96.636  -69.140  52.723  1
360665  96.668  -69.149  52.684  1
360666  96.700  -69.159  52.645  1
360667  96.732  -69.168  52.606  1
360668  96.764  -69.178  52.568  1
360669  96.796  -69.187  52.532  1
360670  96.828  -69.197  52.495  1
360671  96.860  -69.206  52.459  1
360672  96.892  -69.215  52.428  1
360673  96.925  -69.225  52.397  1
360674  96.955  -69.233  52.366  1
360675  96.984  -69.240  52.334  1
360676  97.013  -69.247  52.302  1
360677  97.042  -69.254  52.267  1
360678  97.072  -69.261  52.232  1
360679  97.101  -69.268  52.199  1
360680  97.129  -69.276  52.166  1
360681  97.157  -69.284  52.132  1
360682  97.185  -69.293  52.100  1
360683  97.213  -69.301  52.066  1
360684  97.241  -69.309  52.032  1
360685  97.271  -69.316  51.999  1
360686  97.302  -69.323  51.968  1
360687  97.335  -69.328  51.937  1
360688  97.370  -69.333  51.907  1
360689  97.404  -69.337  51.878  1
360690  97.439  -69.341  51.850  1
360691  97.474  -69.345  51.824  1
360692  97.509  -69.350  51.800  1
360693  97.543  -69.353  51.779  1
360694  97.578  -69.358  51.761  1
360695  97.612  -69.362  51.744  1
360696  97.652  -69.366  51.726  1
360697  97.696  -69.369  51.707  1
360698  97.740  -69.372  51.688  1
360699  97.783  -69.375  51.669  1
360700  97.811  -69.381  51.649  1
360701  97.840  -69.387  51.627  1
360702  97.869  -69.393  51.601  1
360703  97.898  -69.399  51.566  1
360704  97.927  -69.405  51.527  1
360705  97.952  -69.411  51.486  1
360706  97.975  -69.417  51.442  1
360707  98.016  -69.425  51.396  1
360708  98.063  -69.434  51.349  1
360709  98.110  -69.442  51.299  1
360710  98.155  -69.447  51.246  1
360711  98.199  -69.450  51.193  1
360712  98.243  -69.454  51.140  1
360713  98.287  -69.457  51.086  1
360714  98.331  -69.460  51.032  1
360715  98.375  -69.464  50.977  1
360716  98.410  -69.470  50.918  1
360717  98.441  -69.477  50.860  1
360718  98.472  -69.484  50.801  1
360719  98.502  -69.491  50.743  1
360720  98.533  -69.497  50.684  1
360721  98.564  -69.504  50.625  1
360722  98.594  -69.512  50.566  1
360723  98.626  -69.519  50.507  1
360724  98.656  -69.526  50.448  1
360725  98.695  -69.538  50.390  1
360726  98.740  -69.555  50.334  1
360727  98.784  -69.572  50.279  1
360728  98.829  -69.589  50.224  1
360729  98.873  -69.606  50.170  1
360730  98.918  -69.623  50.115  1
360731  98.960  -69.637  50.060  1
360732  98.983  -69.649  50.005  1
360733  99.006  -69.661  49.950  1
360734  99.029  -69.673  49.896  1
360735  99.052  -69.685  49.841  1
360736  99.075  -69.696  49.787  1
360737  99.098  -69.708  49.732  1
360738  99.121  -69.720  49.678  1
360739  99.144  -69.732  49.625  1
360740  99.167  -69.744  49.573  1
360741  99.190  -69.755  49.521  1
360742  99.213  -69.767  49.472  1
360743  99.236  -69.780  49.422  1
360744  99.269  -69.789  49.373  1
360745  99.305  -69.795  49.325  1
360746  99.346  -69.800  49.277  1
360747  99.387  -69.805  49.230  1
360748  99.434  -69.814  49.184  1
360749  99.480  -69.823  49.138  1
360750  99.526  -69.833  49.091  1
360751  99.572  -69.842  49.046  1
360752  99.618  -69.852  49.000  1
360753  99.664  -69.861  48.955  1
360754  99.710  -69.870  48.911  1
360755  99.756  -69.880  48.869  1
360756  99.804  -69.885  48.827  1
360757  99.856  -69.882  48.786  1
360758  99.909  -69.877  48.746  1
360759  99.962  -69.873  48.706  1
360760  100.014  -69.867  48.670  1
360761  100.059  -69.870  48.635  1
360762  100.084  -69.899  48.602  1
360763  100.110  -69.929  48.569  1
360764  100.136  -69.958  48.537  1
360765  100.161  -69.987  48.506  1
360766  100.187  -70.017  48.476  1
360767  100.212  -70.046  48.445  1
360768  100.242  -70.044  48.418  1
360769  100.273  -70.038  48.391  1
360770  100.312  -70.037  48.364  1
360771  100.360  -70.045  48.339  1
360772  100.408  -70.052  48.315  1
360773  100.457  -70.060  48.293  1
360774  100.505  -70.068  48.271  1
360775  100.553  -70.075  48.247  1
360776  100.602  -70.083  48.222  1
360777  100.650  -70.090  48.195  1
360778  100.698  -70.097  48.166  1
360779  100.747  -70.105  48.134  1
360780  100.795  -70.112  48.101  1
360781  100.840  -70.121  48.069  1
360782  100.884  -70.132  48.033  1
360783  100.933  -70.145  47.995  1
360784  100.960  -70.159  47.957  1
360785  100.975  -70.174  47.920  1
360786  101.000  -70.185  47.882  1
360787  101.026  -70.196  47.845  1
360788  101.052  -70.207  47.807  1
360789  101.077  -70.218  47.769  1
360790  101.103  -70.229  47.730  1
360791  101.129  -70.240  47.690  1
360792  101.155  -70.251  47.648  1
360793  101.180  -70.262  47.604  1
360794  101.205  -70.273  47.561  1
360795  101.231  -70.284  47.515  1
360796  101.251  -70.296  47.468  1
360797  101.270  -70.308  47.422  1
360798  101.306  -70.312  47.375  1
360799  101.344  -70.316  47.325  1
360800  101.380  -70.320  47.273  1
360801  101.416  -70.324  47.221  1
360802  101.453  -70.328  47.171  1
360803  101.489  -70.331  47.123  1
360804  101.526  -70.335  47.077  1
360805  101.562  -70.339  47.034  1
360806  101.598  -70.344  46.991  1
360807  101.635  -70.347  46.949  1
360808  101.671  -70.351  46.907  1
360809  101.707  -70.355  46.866  1
360810  101.744  -70.359  46.825  1
360811  101.780  -70.362  46.784  1
360812  101.817  -70.366  46.743  1
360813  101.853  -70.370  46.703  1
360814  101.889  -70.374  46.662  1
360815  101.925  -70.378  46.622  1
360816  101.962  -70.381  46.583  1
361300  94.347  -69.173  53.465  1
361301  94.382  -69.174  53.452  1
361302  94.417  -69.175  53.441  1
361303  94.452  -69.175  53.429  1
361304  94.487  -69.176  53.417  1
361305  94.522  -69.177  53.406  1
361306  94.557  -69.178  53.395  1
361307  94.592  -69.178  53.387  1
361308  94.626  -69.179  53.379  1
361309  94.679  -69.148  53.372  1
361310  94.732  -69.115  53.367  1
361311  94.784  -69.081  53.364  1
361312  94.837  -69.065  53.358  1
361313  94.890  -69.072  53.351  1
361314  94.943  -69.078  53.345  1
361315  94.995  -69.085  53.339  1
361316  95.056  -69.073  53.333  1
361317  95.117  -69.057  53.329  1
361318  95.179  -69.042  53.326  1
361319  95.241  -69.026  53.325  1
361320  95.302  -69.010  53.326  1
361321  95.364  -68.994  53.326  1
361322  95.423  -68.980  53.326  1
361323  95.449  -68.979  53.326  1
361324  95.475  -68.979  53.327  1
361325  95.500  -68.978  53.323  1
361326  95.526  -68.978  53.318  1
361327  95.552  -68.977  53.312  1
361328  95.578  -68.977  53.307  1
361329  95.603  -68.977  53.302  1
361330  95.629  -68.976  53.301  1
361331  95.655  -68.976  53.301  1
361332  95.680  -68.975  53.299  1
361333  95.706  -68.975  53.295  1
361334  95.732  -68.974  53.287  1
361335  95.757  -68.974  53.279  1
361336  95.783  -68.974  53.273  1
361337  95.809  -68.973  53.269  1
361338  95.834  -68.973  53.260  1
361339  95.860  -68.972  53.244  1
361340  95.886  -68.972  53.224  1
361341  95.911  -68.971  53.201  1
361342  95.937  -68.971  53.190  1
361343  95.963  -68.971  53.186  1
361344  95.988  -68.971  53.182  1
361345  96.014  -68.970  53.175  1
361346  96.039  -68.970  53.162  1
361347  96.065  -68.969  53.148  1
361348  96.091  -68.968  53.139  1
361349  96.116  -68.968  53.132  1
361350  96.143  -68.966  53.124  1
361351  96.176  -68.972  53.110  1
361352  96.210  -68.977  53.087  1
361353  96.245  -68.983  53.059  1
361354  96.280  -68.988  53.028  1
361355  96.315  -68.993  52.998  1
361356  96.349  -68.999  52.972  1
361357  96.391  -69.013  52.953  1
361358  96.432  -69.029  52.938  1
361359  96.465  -69.043  52.921  1
361360  96.499  -69.058  52.901  1
361361  96.529  -69.070  52.874  1
361362  96.544  -69.074  52.840  1
361363  96.576  -69.084  52.801  1
361364  96.608  -69.093  52.758  1
361365  96.640  -69.103  52.715  1
361366  96.672  -69.112  52.674  1
361367  96.704  -69.122  52.634  1
361368  96.736  -69.131  52.594  1
361369  96.768  -69.141  52.556  1
361370  96.800  -69.151  52.520  1
361371  96.832  -69.160  52.484  1
361372  96.865  -69.170  52.448  1
361373  96.900  -69.181  52.417  1
361374  96.934  -69.192  52.387  1
361375  96.965  -69.200  52.357  1
361376  96.993  -69.206  52.325  1
361377  97.020  -69.213  52.290  1
361378  97.048  -69.219  52.254  1
361379  97.077  -69.226  52.219  1
361380  97.106  -69.233  52.186  1
361381  97.134  -69.241  52.152  1
361382  97.162  -69.250  52.118  1
361383  97.189  -69.258  52.084  1
361384  97.218  -69.266  52.050  1
361385  97.246  -69.274  52.016  1
361386  97.274  -69.282  51.984  1
361387  97.308  -69.287  51.953  1
361388  97.342  -69.291  51.924  1
361389  97.377  -69.295  51.895  1
361390  97.412  -69.300  51.867  1
361391  97.446  -69.303  51.842  1
361392  97.481  -69.308  51.819  1
361393  97.515  -69.312  51.797  1
361394  97.550  -69.316  51.777  1
361395  97.585  -69.320  51.761  1
361396  97.619  -69.325  51.745  1
361397  97.662  -69.328  51.728  1
361398  97.706  -69.331  51.709  1
361399  97.749  -69.334  51.687  1
361400  97.782  -69.339  51.666  1
361401  97.810  -69.345  51.645  1
361402  97.839  -69.351  51.622  1
361403  97.868  -69.357  51.595  1
361404  97.896  -69.363  51.559  1
361405  97.925  -69.369  51.520  1
361406  97.954  -69.375  51.479  1
361407  97.977  -69.382  51.435  1
361408  98.021  -69.390  51.388  1
361409  98.068  -69.399  51.340  1
361410  98.115  -69.407  51.290  1
361411  98.160  -69.413  51.237  1
361412  98.204  -69.416  51.183  1
361413  98.248  -69.419  51.128  1
361414  98.293  -69.423  51.074  1
361415  98.337  -69.426  51.019  1
361416  98.381  -69.429  50.964  1
361417  98.425  -69.433  50.905  1
361418  98.457  -69.440  50.847  1
361419  98.488  -69.447  50.788  1
361420  98.518  -69.454  50.730  1
361421  98.549  -69.460  50.671  1
361422  98.580  -69.467  50.613  1
361423  98.611  -69.474  50.554  1
361424  98.642  -69.482  50.495  1
361425  98.673  -69.488  50.438  1
361426  98.717  -69.505  50.381  1
361427  98.762  -69.523  50.325  1
361428  98.806  -69.539  50.271  1
361429  98.851  -69.556  50.216  1
361430  98.896  -69.573  50.162  1
361431  98.934  -69.587  50.107  1
361432  98.961  -69.601  50.053  1
361433  98.986  -69.611  49.998  1
361434  99.011  -69.624  49.943  1
361435  99.036  -69.640  49.889  1
361436  99.060  -69.654  49.835  1
361437  99.083  -69.667  49.780  1
361438  99.106  -69.678  49.725  1
361439  99.129  -69.690  49.672  1
361440  99.152  -69.702  49.620  1
361441  99.175  -69.714  49.568  1
361442  99.198  -69.726  49.517  1
361443  99.221  -69.737  49.468  1
361444  99.244  -69.749  49.419  1
361445  99.271  -69.760  49.370  1
361446  99.307  -69.767  49.322  1
361447  99.348  -69.771  49.274  1
361448  99.394  -69.780  49.227  1
361449  99.440  -69.790  49.181  1
361450  99.486  -69.799  49.135  1
361451  99.532  -69.808  49.088  1
361452  99.578  -69.818  49.042  1
361453  99.624  -69.827  48.997  1
361454  99.670  -69.837  48.951  1
361455  99.716  -69.846  48.906  1
361456  99.762  -69.855  48.864  1
361457  99.808  -69.862  48.822  1
361458  99.854  -69.875  48.780  1
361459  99.905  -69.876  48.739  1
361460  99.956  -69.877  48.699  1
361461  100.006  -69.878  48.661  1
361462  100.054  -69.885  48.626  1
361463  100.102  -69.892  48.591  1
361464  100.125  -69.895  48.558  1
361465  100.145  -69.912  48.526  1
361466  100.171  -69.941  48.494  1
361467  100.197  -69.971  48.463  1
361468  100.222  -70.000  48.434  1
361469  100.250  -70.017  48.406  1
361470  100.280  -70.010  48.379  1
361471  100.324  -70.013  48.351  1
361472  100.372  -70.021  48.324  1
361473  100.420  -70.028  48.299  1
361474  100.469  -70.036  48.275  1
361475  100.517  -70.043  48.251  1
361476  100.565  -70.051  48.226  1
361477  100.614  -70.058  48.201  1
361478  100.662  -70.066  48.174  1
361479  100.710  -70.074  48.145  1
361480  100.759  -70.080  48.113  1
361481  100.807  -70.088  48.080  1
361482  100.855  -70.096  48.048  1
361483  100.902  -70.104  48.011  1
361484  100.948  -70.115  47.973  1
361485  100.971  -70.130  47.936  1
361486  100.997  -70.141  47.898  1
361487  101.022  -70.152  47.861  1
361488  101.048  -70.163  47.824  1
361489  101.073  -70.174  47.786  1
361490  101.099  -70.185  47.748  1
361491  101.120  -70.197  47.709  1
361492  101.139  -70.209  47.668  1
361493  101.158  -70.221  47.626  1
361494  101.177  -70.233  47.582  1
361495  101.196  -70.244  47.537  1
361496  101.214  -70.256  47.490  1
361497  101.241  -70.263  47.444  1
361498  101.276  -70.264  47.397  1
361499  101.316  -70.268  47.351  1
361500  101.354  -70.274  47.301  1
361501  101.393  -70.279  47.250  1
361502  101.431  -70.284  47.200  1
361503  101.467  -70.287  47.151  1
361504  101.504  -70.291  47.105  1
361505  101.540  -70.296  47.060  1
361506  101.576  -70.300  47.017  1
361507  101.613  -70.303  46.976  1
361508  101.650  -70.307  46.934  1
361509  101.686  -70.311  46.893  1
361510  101.722  -70.315  46.852  1
361511  101.758  -70.319  46.812  1
361512  101.795  -70.322  46.772  1
361513  101.831  -70.326  46.731  1
361514  101.868  -70.330  46.692  1
361515  101.904  -70.334  46.652  1
361516  101.940  -70.338  46.613  1
362001  94.341  -69.150  53.472  1
362002  94.377  -69.151  53.461  1
362003  94.411  -69.152  53.449  1
362004  94.446  -69.153  53.438  1
362005  94.481  -69.154  53.427  1
362006  94.516  -69.155  53.416  1
362007  94.551  -69.156  53.406  1
362008  94.603  -69.125  53.397  1
362009  94.655  -69.091  53.390  1
362010  94.708  -69.059  53.383  1
362011  94.761  -69.025  53.378  1
362012  94.815  -68.992  53.374  1
362013  94.867  -68.965  53.369  1
362014  94.920  -68.971  53.363  1
362015  94.973  -68.978  53.357  1
362016  95.026  -68.984  53.351  1
362017  95.078  -68.991  53.345  1
362018  95.131  -68.998  53.340  1
362019  95.186  -68.998  53.335  1
362020  95.248  -68.983  53.332  1
362021  95.309  -68.967  53.331  1
362022  95.371  -68.951  53.329  1
362023  95.426  -68.938  53.328  1
362024  95.452  -68.938  53.326  1
362025  95.478  -68.937  53.326  1
362026  95.503  -68.936  53.322  1
362027  95.529  -68.936  53.318  1
362028  95.555  -68.936  53.315  1
362029  95.581  -68.936  53.313  1
362030  95.606  -68.935  53.311  1
362031  95.632  -68.935  53.309  1
362032  95.658  -68.934  53.307  1
362033  95.683  -68.934  53.302  1
362034  95.709  -68.933  53.294  1
362035  95.735  -68.933  53.286  1
362036  95.760  -68.933  53.279  1
362037  95.786  -68.932  53.275  1
362038  95.812  -68.932  53.272  1
362039  95.837  -68.931  53.262  1
362040  95.863  -68.931  53.246  1
362041  95.888  -68.930  53.225  1
362042  95.914  -68.931  53.201  1
362043  95.940  -68.932  53.190  1
362044  95.966  -68.933  53.185  1
362045  95.992  -68.933  53.181  1
362046  96.019  -68.935  53.174  1
362047  96.044  -68.936  53.162  1
362048  96.071  -68.936  53.149  1
362049  96.097  -68.937  53.142  1
362050  96.122  -68.938  53.139  1
362051  96.144  -68.936  53.133  1
362052  96.179  -68.940  53.117  1
362053  96.215  -68.943  53.090  1
362054  96.250  -68.946  53.059  1
362055  96.285  -68.952  53.026  1
362056  96.320  -68.957  52.994  1
362057  96.355  -68.962  52.970  1
362058  96.395  -68.975  52.951  1
362059  96.430  -68.990  52.933  1
362060  96.463  -69.004  52.912  1
362061  96.496  -69.018  52.891  1
362062  96.529  -69.032  52.866  1
362063  96.548  -69.038  52.836  1
362064  96.580  -69.047  52.799  1
362065  96.612  -69.057  52.754  1
362066  96.644  -69.067  52.708  1
362067  96.676  -69.076  52.663  1
362068  96.708  -69.086  52.620  1
362069  96.740  -69.095  52.581  1
362070  96.773  -69.106  52.543  1
362071  96.808  -69.116  52.507  1
362072  96.842  -69.128  52.473  1
362073  96.877  -69.138  52.439  1
362074  96.911  -69.150  52.408  1
362075  96.946  -69.160  52.377  1
362076  96.977  -69.168  52.346  1
362077  97.005  -69.175  52.313  1
362078  97.032  -69.181  52.278  1
362079  97.060  -69.187  52.240  1
362080  97.088  -69.193  52.205  1
362081  97.115  -69.198  52.171  1
362082  97.142  -69.203  52.138  1
362083  97.171  -69.212  52.103  1
362084  97.199  -69.219  52.069  1
362085  97.227  -69.228  52.036  1
362086  97.255  -69.236  52.003  1
362087  97.285  -69.243  51.970  1
362088  97.316  -69.249  51.939  1
362089  97.349  -69.253  51.911  1
362090  97.384  -69.258  51.884  1
362091  97.419  -69.262  51.861  1
362092  97.453  -69.266  51.838  1
362093  97.488  -69.270  51.817  1
362094  97.522  -69.275  51.798  1
362095  97.557  -69.278  51.782  1
362096  97.592  -69.283  51.767  1
362097  97.628  -69.287  51.753  1
362098  97.671  -69.290  51.737  1
362099  97.715  -69.293  51.715  1
362100  97.751  -69.297  51.693  1
362101  97.780  -69.303  51.671  1
362102  97.809  -69.309  51.648  1
362103  97.838  -69.316  51.622  1
362104  97.866  -69.322  51.592  1
362105  97.895  -69.328  51.554  1
362106  97.924  -69.334  51.514  1
362107  97.953  -69.340  51.471  1
362108  97.979  -69.346  51.427  1
362109  98.026  -69.355  51.379  1
362110  98.073  -69.363  51.332  1
362111  98.120  -69.372  51.281  1
362112  98.166  -69.378  51.228  1
362113  98.210  -69.382  51.172  1
362114  98.254  -69.385  51.118  1
362115  98.298  -69.388  51.063  1
362116  98.342  -69.392  51.007  1
362117  98.386  -69.395  50.951  1
362118  98.430  -69.398  50.893  1
362119  98.473  -69.402  50.834  1
362120  98.504  -69.410  50.776  1
362121  98.534  -69.416  50.717  1
362122  98.566  -69.423  50.658  1
362123  98.596  -69.430  50.601  1
362124  98.627  -69.437  50.543  1
362125  98.658  -69.444  50.486  1
362126  98.695  -69.456  50.429  1
362127  98.740  -69.472  50.374  1
362128  98.784  -69.489  50.318  1
362129  98.829  -69.507  50.264  1
362130  98.873  -69.523  50.209  1
362131  98.904  -69.533  50.154  1
362132  98.926  -69.540  50.099  1
362133  98.955  -69.558  50.045  1
362134  98.983  -69.573  49.990  1
362135  99.008  -69.583  49.936  1
362136  99.032  -69.593  49.881  1
362137  99.058  -69.603  49.827  1
362138  99.083  -69.618  49.772  1
362139  99.108  -69.635  49.719  1
362140  99.133  -69.651  49.667  1
362141  99.159  -69.668  49.615  1
362142  99.184  -69.684  49.564  1
362143  99.207  -69.695  49.514  1
362144  99.230  -69.707  49.465  1
362145  99.253  -69.719  49.416  1
362146  99.276  -69.731  49.367  1
362147  99.310  -69.739  49.319  1
362148  99.354  -69.746  49.271  1
362149  99.400  -69.756  49.223  1
362150  99.446  -69.765  49.177  1
362151  99.492  -69.775  49.132  1
362152  99.538  -69.782  49.086  1
362153  99.583  -69.785  49.039  1
362154  99.629  -69.788  48.993  1
362155  99.675  -69.792  48.947  1
362156  99.724  -69.804  48.901  1
362157  99.773  -69.817  48.858  1
362158  99.814  -69.843  48.815  1
362159  99.854  -69.870  48.773  1
362160  99.897  -69.888  48.731  1
362161  99.947  -69.889  48.691  1
362162  99.997  -69.892  48.652  1
362163  100.045  -69.899  48.616  1
362164  100.092  -69.907  48.581  1
362165  100.140  -69.914  48.547  1
362166  100.174  -69.919  48.514  1
362167  100.190  -69.921  48.482  1
362168  100.207  -69.924  48.450  1
362169  100.232  -69.954  48.419  1
362170  100.258  -69.983  48.392  1
362171  100.287  -69.982  48.366  1
362172  100.336  -69.990  48.339  1
362173  100.384  -69.997  48.311  1
362174  100.432  -70.004  48.284  1
362175  100.481  -70.011  48.257  1
362176  100.529  -70.019  48.230  1
362177  100.577  -70.027  48.203  1
362178  100.626  -70.034  48.175  1
362179  100.674  -70.042  48.147  1
362180  100.722  -70.049  48.117  1
362181  100.771  -70.057  48.086  1
362182  100.819  -70.065  48.054  1
362183  100.867  -70.071  48.023  1
362184  100.915  -70.079  47.988  1
362185  100.964  -70.087  47.951  1
362186  100.988  -70.098  47.913  1
362187  101.007  -70.110  47.874  1
362188  101.027  -70.121  47.837  1
362189  101.046  -70.134  47.801  1
362190  101.064  -70.146  47.764  1
362191  101.084  -70.157  47.725  1
362192  101.103  -70.169  47.685  1
362193  101.122  -70.181  47.644  1
362194  101.140  -70.193  47.601  1
362195  101.159  -70.205  47.556  1
362196  101.183  -70.213  47.510  1
362197  101.212  -70.218  47.464  1
362198  101.245  -70.220  47.417  1
362199  101.287  -70.221  47.370  1
362200  101.326  -70.226  47.323  1
362201  101.364  -70.231  47.275  1
362202  101.403  -70.237  47.226  1
362203  101.442  -70.242  47.178  1
362204  101.481  -70.247  47.132  1
362205  101.519  -70.252  47.087  1
362206  101.555  -70.256  47.043  1
362207  101.591  -70.259  47.001  1
362208  101.627  -70.263  46.960  1
362209  101.664  -70.267  46.920  1
362210  101.700  -70.271  46.879  1
362211  101.737  -70.275  46.839  1
362212  101.773  -70.278  46.799  1
362213  101.809  -70.282  46.760  1
362214  101.846  -70.287  46.720  1
362215  101.882  -70.290  46.682  1
362216  101.918  -70.294  46.643  1
362217  101.955  -70.298  46.603  1
362703  94.371  -69.129  53.467  1
362704  94.406  -69.130  53.456  1
362705  94.440  -69.131  53.445  1
362706  94.476  -69.131  53.434  1
362707  94.527  -69.102  53.424  1
362708  94.580  -69.068  53.415  1
362709  94.633  -69.035  53.406  1
362710  94.686  -69.002  53.399  1
362711  94.739  -68.969  53.392  1
362712  94.791  -68.936  53.386  1
362713  94.844  -68.902  53.380  1
362714  94.897  -68.870  53.376  1
362715  94.950  -68.871  53.371  1
362716  95.003  -68.877  53.367  1
362717  95.056  -68.884  53.365  1
362718  95.108  -68.890  53.358  1
362719  95.161  -68.897  53.351  1
362720  95.214  -68.903  53.345  1
362721  95.267  -68.910  53.340  1
362722  95.320  -68.917  53.338  1
362723  95.378  -68.908  53.334  1
362724  95.429  -68.897  53.331  1
362725  95.455  -68.896  53.327  1
362726  95.481  -68.896  53.325  1
362727  95.507  -68.896  53.321  1
362728  95.532  -68.895  53.321  1
362729  95.558  -68.895  53.324  1
362730  95.584  -68.894  53.328  1
362731  95.609  -68.895  53.326  1
362732  95.635  -68.896  53.320  1
362733  95.662  -68.897  53.312  1
362734  95.687  -68.898  53.302  1
362735  95.713  -68.899  53.291  1
362736  95.740  -68.899  53.285  1
362737  95.766  -68.901  53.281  1
362738  95.792  -68.902  53.280  1
362739  95.818  -68.902  53.275  1
362740  95.844  -68.903  53.262  1
362741  95.870  -68.905  53.245  1
362742  95.896  -68.905  53.224  1
362743  95.922  -68.906  53.201  1
362744  95.948  -68.907  53.189  1
362745  95.974  -68.908  53.183  1
362746  96.000  -68.909  53.179  1
362747  96.026  -68.910  53.173  1
362748  96.052  -68.911  53.161  1
362749  96.078  -68.911  53.148  1
362750  96.104  -68.913  53.144  1
362751  96.127  -68.912  53.144  1
362752  96.147  -68.908  53.138  1
362753  96.182  -68.911  53.121  1
362754  96.218  -68.915  53.093  1
362755  96.253  -68.918  53.059  1
362756  96.288  -68.921  53.023  1
362757  96.324  -68.924  52.990  1
362758  96.359  -68.927  52.967  1
362759  96.393  -68.936  52.947  1
362760  96.427  -68.950  52.927  1
362761  96.460  -68.965  52.903  1
362762  96.493  -68.979  52.882  1
362763  96.527  -68.993  52.859  1
362764  96.552  -69.002  52.832  1
362765  96.584  -69.011  52.796  1
362766  96.616  -69.021  52.751  1
362767  96.648  -69.031  52.703  1
362768  96.682  -69.040  52.656  1
362769  96.716  -69.052  52.610  1
362770  96.751  -69.062  52.569  1
362771  96.785  -69.074  52.531  1
362772  96.819  -69.084  52.496  1
362773  96.854  -69.095  52.463  1
362774  96.888  -69.106  52.429  1
362775  96.923  -69.117  52.397  1
362776  96.957  -69.128  52.365  1
362777  96.990  -69.137  52.333  1
362778  97.017  -69.143  52.299  1
362779  97.045  -69.150  52.264  1
362780  97.073  -69.156  52.226  1
362781  97.100  -69.162  52.190  1
362782  97.127  -69.165  52.157  1
362783  97.153  -69.168  52.123  1
362784  97.180  -69.173  52.088  1
362785  97.209  -69.181  52.055  1
362786  97.237  -69.189  52.022  1
362787  97.265  -69.197  51.989  1
362788  97.296  -69.203  51.957  1
362789  97.327  -69.209  51.928  1
362790  97.359  -69.215  51.902  1
362791  97.391  -69.220  51.878  1
362792  97.426  -69.225  51.859  1
362793  97.460  -69.228  51.840  1
362794  97.495  -69.233  51.823  1
362795  97.529  -69.237  51.809  1
362796  97.564  -69.241  51.796  1
362797  97.599  -69.245  51.783  1
362798  97.637  -69.249  51.768  1
362799  97.680  -69.252  51.750  1
362800  97.721  -69.256  51.728  1
362801  97.750  -69.262  51.704  1
362802  97.779  -69.268  51.679  1
362803  97.808  -69.274  51.651  1
362804  97.837  -69.280  51.621  1
362805  97.865  -69.286  51.588  1
362806  97.894  -69.292  51.548  1
362807  97.923  -69.298  51.506  1
362808  97.951  -69.304  51.462  1
362809  97.984  -69.311  51.417  1
362810  98.031  -69.319  51.369  1
362811  98.078  -69.328  51.321  1
362812  98.125  -69.337  51.271  1
362813  98.171  -69.344  51.218  1
362814  98.215  -69.347  51.162  1
362815  98.260  -69.351  51.107  1
362816  98.303  -69.354  51.051  1
362817  98.348  -69.357  50.995  1
362818  98.391  -69.361  50.939  1
362819  98.436  -69.364  50.880  1
362820  98.480  -69.368  50.821  1
362821  98.520  -69.372  50.762  1
362822  98.551  -69.379  50.705  1
362823  98.582  -69.386  50.648  1
362824  98.613  -69.393  50.592  1
362825  98.643  -69.400  50.536  1
362826  98.674  -69.407  50.480  1
362827  98.717  -69.422  50.424  1
362828  98.762  -69.440  50.369  1
362829  98.806  -69.457  50.314  1
362830  98.851  -69.473  50.258  1
362831  98.873  -69.480  50.203  1
362832  98.896  -69.486  50.147  1
362833  98.918  -69.494  50.091  1
362834  98.949  -69.516  50.037  1
362835  98.979  -69.535  49.983  1
362836  99.004  -69.545  49.929  1
362837  99.029  -69.555  49.875  1
362838  99.055  -69.565  49.821  1
362839  99.079  -69.575  49.768  1
362840  99.104  -69.585  49.715  1
362841  99.130  -69.596  49.663  1
362842  99.155  -69.613  49.612  1
362843  99.180  -69.629  49.561  1
362844  99.205  -69.646  49.511  1
362845  99.231  -69.662  49.462  1
362846  99.256  -69.679  49.413  1
362847  99.281  -69.695  49.364  1
362848  99.314  -69.707  49.316  1
362849  99.359  -69.710  49.267  1
362850  99.405  -69.713  49.220  1
362851  99.451  -69.716  49.173  1
362852  99.497  -69.719  49.127  1
362853  99.543  -69.721  49.082  1
362854  99.591  -69.733  49.035  1
362855  99.641  -69.745  48.988  1
362856  99.690  -69.758  48.942  1
362857  99.737  -69.773  48.896  1
362858  99.777  -69.798  48.852  1
362859  99.818  -69.825  48.809  1
362860  99.858  -69.852  48.767  1
362861  99.898  -69.877  48.725  1
362862  99.940  -69.900  48.684  1
362863  99.988  -69.907  48.644  1
362864  100.035  -69.914  48.607  1
362865  100.083  -69.921  48.571  1
362866  100.131  -69.929  48.536  1
362867  100.178  -69.936  48.502  1
362868  100.223  -69.942  48.469  1
362869  100.240  -69.945  48.436  1
362870  100.256  -69.947  48.405  1
362871  100.272  -69.949  48.378  1
362872  100.299  -69.958  48.352  1
362873  100.348  -69.965  48.325  1
362874  100.394  -69.972  48.298  1
362875  100.439  -69.980  48.271  1
362876  100.485  -69.987  48.241  1
362877  100.531  -69.994  48.212  1
362878  100.577  -70.002  48.182  1
362879  100.623  -70.008  48.152  1
362880  100.668  -70.016  48.122  1
362881  100.714  -70.024  48.092  1
362882  100.760  -70.030  48.060  1
362883  100.806  -70.038  48.029  1
362884  100.852  -70.045  47.998  1
362885  100.898  -70.052  47.963  1
362886  100.944  -70.060  47.927  1
362887  100.971  -70.070  47.889  1
362888  100.990  -70.082  47.851  1
362889  101.009  -70.094  47.813  1
362890  101.029  -70.105  47.777  1
362891  101.047  -70.118  47.741  1
362892  101.066  -70.130  47.702  1
362893  101.086  -70.141  47.661  1
362894  101.105  -70.153  47.619  1
362895  101.125  -70.164  47.574  1
362896  101.154  -70.168  47.529  1
362897  101.183  -70.173  47.483  1
362898  101.214  -70.176  47.437  1
362899  101.257  -70.174  47.388  1
362900  101.297  -70.178  47.340  1
362901  101.336  -70.184  47.294  1
362902  101.375  -70.189  47.248  1
362903  101.413  -70.194  47.202  1
362904  101.452  -70.199  47.157  1
362905  101.491  -70.204  47.113  1
362906  101.530  -70.209  47.068  1
362907  101.568  -70.215  47.027  1
362908  101.606  -70.219  46.986  1
362909  101.642  -70.223  46.945  1
362910  101.678  -70.227  46.905  1
362911  101.715  -70.231  46.866  1
362912  101.751  -70.234  46.826  1
362913  101.787  -70.239  46.786  1
362914  101.824  -70.243  46.747  1
362915  101.861  -70.246  46.709  1
362916  101.897  -70.250  46.670  1
362917  101.933  -70.254  46.632  1
363404  94.365  -69.106  53.472  1
363405  94.400  -69.108  53.462  1
363406  94.451  -69.078  53.451  1
363407  94.504  -69.046  53.441  1
363408  94.557  -69.012  53.432  1
363409  94.610  -68.979  53.423  1
363410  94.663  -68.946  53.414  1
363411  94.715  -68.913  53.406  1
363412  94.768  -68.880  53.399  1
363413  94.821  -68.846  53.393  1
363414  94.875  -68.813  53.387  1
363415  94.927  -68.780  53.382  1
363416  94.980  -68.770  53.379  1
363417  95.033  -68.777  53.377  1
363418  95.086  -68.783  53.377  1
363419  95.138  -68.790  53.370  1
363420  95.191  -68.796  53.364  1
363421  95.244  -68.803  53.357  1
363422  95.286  -68.819  53.351  1
363423  95.328  -68.836  53.347  1
363424  95.370  -68.853  53.344  1
363425  95.428  -68.861  53.341  1
363426  95.461  -68.864  53.336  1
363427  95.487  -68.866  53.333  1
363428  95.513  -68.867  53.332  1
363429  95.539  -68.868  53.333  1
363430  95.565  -68.868  53.336  1
363431  95.591  -68.870  53.336  1
363432  95.617  -68.871  53.330  1
363433  95.643  -68.871  53.321  1
363434  95.669  -68.872  53.309  1
363435  95.695  -68.873  53.296  1
363436  95.721  -68.874  53.290  1
363437  95.747  -68.875  53.289  1
363438  95.773  -68.876  53.287  1
363439  95.799  -68.877  53.282  1
363440  95.825  -68.878  53.274  1
363441  95.851  -68.879  53.257  1
363442  95.877  -68.880  53.239  1
363443  95.903  -68.880  53.219  1
363444  95.930  -68.881  53.194  1
363445  95.955  -68.883  53.184  1
363446  95.981  -68.883  53.180  1
363447  96.008  -68.884  53.177  1
363448  96.034  -68.885  53.171  1
363449  96.059  -68.886  53.158  1
363450  96.086  -68.887  53.146  1
363451  96.111  -68.887  53.142  1
363452  96.128  -68.883  53.144  1
363453  96.150  -68.880  53.139  1
363454  96.185  -68.883  53.122  1
363455  96.220  -68.886  53.094  1
363456  96.256  -68.889  53.059  1
363457  96.291  -68.893  53.021  1
363458  96.326  -68.896  52.987  1
363459  96.361  -68.900  52.964  1
363460  96.394  -68.908  52.943  1
363461  96.427  -68.919  52.921  1
363462  96.459  -68.930  52.895  1
363463  96.491  -68.941  52.873  1
363464  96.524  -68.953  52.852  1
363465  96.556  -68.965  52.826  1
363466  96.590  -68.976  52.792  1
363467  96.624  -68.987  52.748  1
363468  96.659  -68.998  52.699  1
363469  96.693  -69.009  52.649  1
363470  96.728  -69.019  52.602  1
363471  96.762  -69.031  52.559  1
363472  96.797  -69.041  52.521  1
363473  96.831  -69.052  52.487  1
363474  96.866  -69.063  52.454  1
363475  96.900  -69.074  52.419  1
363476  96.935  -69.085  52.385  1
363477  96.969  -69.096  52.352  1
363478  97.002  -69.106  52.319  1
363479  97.029  -69.112  52.285  1
363480  97.057  -69.118  52.249  1
363481  97.085  -69.125  52.211  1
363482  97.112  -69.131  52.176  1
363483  97.139  -69.133  52.142  1
363484  97.165  -69.135  52.108  1
363485  97.191  -69.137  52.074  1
363486  97.219  -69.143  52.042  1
363487  97.247  -69.150  52.010  1
363488  97.275  -69.159  51.976  1
363489  97.306  -69.165  51.947  1
363490  97.338  -69.170  51.920  1
363491  97.369  -69.175  51.896  1
363492  97.400  -69.181  51.874  1
363493  97.433  -69.187  51.860  1
363494  97.467  -69.191  51.845  1
363495  97.502  -69.195  51.833  1
363496  97.536  -69.199  51.823  1
363497  97.571  -69.203  51.813  1
363498  97.606  -69.207  51.801  1
363499  97.646  -69.211  51.785  1
363500  97.690  -69.214  51.765  1
363501  97.720  -69.220  51.742  1
363502  97.749  -69.226  51.716  1
363503  97.778  -69.232  51.687  1
363504  97.806  -69.238  51.655  1
363505  97.835  -69.244  51.621  1
363506  97.864  -69.250  51.585  1
363507  97.892  -69.256  51.542  1
363508  97.923  -69.262  51.499  1
363509  97.957  -69.269  51.454  1
363510  97.995  -69.276  51.407  1
363511  98.035  -69.284  51.358  1
363512  98.083  -69.293  51.310  1
363513  98.130  -69.302  51.260  1
363514  98.176  -69.310  51.207  1
363515  98.221  -69.313  51.151  1
363516  98.265  -69.316  51.096  1
363517  98.309  -69.320  51.040  1
363518  98.353  -69.323  50.984  1
363519  98.397  -69.327  50.928  1
363520  98.441  -69.330  50.869  1
363521  98.485  -69.333  50.810  1
363522  98.529  -69.337  50.752  1
363523  98.567  -69.341  50.695  1
363524  98.598  -69.348  50.641  1
363525  98.629  -69.356  50.586  1
363526  98.659  -69.363  50.531  1
363527  98.695  -69.373  50.475  1
363528  98.740  -69.390  50.420  1
363529  98.784  -69.407  50.364  1
363530  98.821  -69.420  50.309  1
363531  98.843  -69.426  50.253  1
363532  98.865  -69.433  50.197  1
363533  98.887  -69.439  50.140  1
363534  98.912  -69.451  50.084  1
363535  98.943  -69.472  50.030  1
363536  98.975  -69.494  49.977  1
363537  99.001  -69.508  49.922  1
363538  99.026  -69.518  49.869  1
363539  99.051  -69.527  49.817  1
363540  99.076  -69.537  49.764  1
363541  99.101  -69.547  49.712  1
363542  99.126  -69.557  49.660  1
363543  99.151  -69.566  49.610  1
363544  99.177  -69.576  49.559  1
363545  99.202  -69.591  49.509  1
363546  99.227  -69.607  49.460  1
363547  99.252  -69.623  49.411  1
363548  99.277  -69.640  49.362  1
363549  99.319  -69.646  49.313  1
363550  99.364  -69.649  49.265  1
363551  99.410  -69.652  49.216  1
363552  99.458  -69.661  49.169  1
363553  99.507  -69.674  49.123  1
363554  99.557  -69.686  49.077  1
363555  99.606  -69.698  49.031  1
363556  99.655  -69.711  48.985  1
363557  99.701  -69.728  48.938  1
363558  99.742  -69.754  48.892  1
363559  99.782  -69.780  48.848  1
363560  99.822  -69.807  48.804  1
363561  99.862  -69.833  48.761  1
363562  99.907  -69.853  48.718  1
363563  99.956  -69.867  48.677  1
363564  100.000  -69.883  48.636  1
363565  100.043  -69.898  48.598  1
363566  100.086  -69.913  48.561  1
363567  100.130  -69.928  48.525  1
363568  100.173  -69.943  48.489  1
363569  100.216  -69.958  48.455  1
363570  100.264  -69.964  48.422  1
363571  100.289  -69.968  48.390  1
363572  100.288  -69.946  48.363  1
363573  100.307  -69.938  48.336  1
363574  100.343  -69.942  48.310  1
363575  100.380  -69.947  48.285  1
363576  100.418  -69.952  48.258  1
363577  100.464  -69.960  48.227  1
363578  100.509  -69.968  48.197  1
363579  100.555  -69.974  48.165  1
363580  100.601  -69.982  48.132  1
363581  100.647  -69.989  48.100  1
363582  100.693  -69.996  48.068  1
363583  100.739  -70.004  48.037  1
363584  100.784  -70.011  48.006  1
363585  100.830  -70.018  47.971  1
363586  100.876  -70.025  47.937  1
363587  100.922  -70.033  47.901  1
363588  100.954  -70.043  47.865  1
363589  100.973  -70.054  47.827  1
363590  100.992  -70.066  47.789  1
363591  101.011  -70.078  47.753  1
363592  101.030  -70.090  47.716  1
363593  101.049  -70.102  47.678  1
363594  101.068  -70.113  47.636  1
363595  101.096  -70.119  47.591  1
363596  101.125  -70.124  47.546  1
363597  101.155  -70.128  47.501  1
363598  101.184  -70.132  47.457  1
363599  101.223  -70.130  47.410  1
363600  101.268  -70.130  47.362  1
363601  101.307  -70.136  47.316  1
363602  101.346  -70.141  47.270  1
363603  101.385  -70.146  47.225  1
363604  101.423  -70.151  47.181  1
363605  101.462  -70.156  47.138  1
363606  101.501  -70.162  47.095  1
363607  101.539  -70.167  47.051  1
363608  101.578  -70.172  47.011  1
363609  101.617  -70.178  46.970  1
363610  101.656  -70.183  46.930  1
363611  101.693  -70.187  46.890  1
363612  101.730  -70.191  46.851  1
363613  101.766  -70.195  46.813  1
363614  101.802  -70.199  46.774  1
363615  101.838  -70.203  46.735  1
363616  101.875  -70.206  46.698  1
363617  101.911  -70.210  46.659  1
364105  94.375  -69.056  53.477  1
364106  94.428  -69.022  53.467  1
364107  94.481  -68.990  53.458  1
364108  94.534  -68.956  53.448  1
364109  94.586  -68.923  53.438  1
364110  94.639  -68.889  53.429  1
364111  94.693  -68.857  53.420  1
364112  94.746  -68.824  53.413  1
364113  94.799  -68.790  53.406  1
364114  94.851  -68.757  53.399  1
364115  94.904  -68.723  53.393  1
364116  94.957  -68.692  53.388  1
364117  94.991  -68.696  53.386  1
364118  95.027  -68.711  53.386  1
364119  95.068  -68.728  53.387  1
364120  95.110  -68.745  53.381  1
364121  95.152  -68.762  53.375  1
364122  95.194  -68.779  53.369  1
364123  95.235  -68.796  53.362  1
364124  95.277  -68.813  53.357  1
364125  95.319  -68.830  53.353  1
364126  95.398  -68.824  53.349  1
364127  95.457  -68.833  53.344  1
364128  95.494  -68.841  53.341  1
364129  95.520  -68.842  53.341  1
364130  95.546  -68.842  53.343  1
364131  95.572  -68.844  53.345  1
364132  95.599  -68.845  53.341  1
364133  95.624  -68.846  53.331  1
364134  95.651  -68.846  53.320  1
364135  95.677  -68.848  53.308  1
364136  95.702  -68.849  53.296  1
364137  95.729  -68.849  53.296  1
364138  95.755  -68.850  53.298  1
364139  95.780  -68.851  53.295  1
364140  95.807  -68.852  53.286  1
364141  95.833  -68.853  53.272  1
364142  95.859  -68.854  53.251  1
364143  95.885  -68.855  53.231  1
364144  95.911  -68.856  53.210  1
364145  95.937  -68.857  53.187  1
364146  95.963  -68.858  53.175  1
364147  95.989  -68.858  53.172  1
364148  96.015  -68.859  53.171  1
364149  96.041  -68.861  53.165  1
364150  96.067  -68.861  53.152  1
364151  96.093  -68.862  53.140  1
364152  96.112  -68.858  53.138  1
364153  96.129  -68.854  53.141  1
364154  96.152  -68.852  53.137  1
364155  96.187  -68.855  53.121  1
364156  96.223  -68.858  53.094  1
364157  96.258  -68.861  53.059  1
364158  96.294  -68.864  53.022  1
364159  96.328  -68.869  52.985  1
364160  96.362  -68.874  52.957  1
364161  96.395  -68.881  52.933  1
364162  96.428  -68.893  52.909  1
364163  96.460  -68.904  52.882  1
364164  96.493  -68.915  52.861  1
364165  96.523  -68.927  52.840  1
364166  96.564  -68.934  52.815  1
364167  96.601  -68.943  52.784  1
364168  96.636  -68.955  52.740  1
364169  96.670  -68.965  52.691  1
364170  96.705  -68.977  52.641  1
364171  96.739  -68.987  52.594  1
364172  96.774  -68.998  52.552  1
364173  96.808  -69.009  52.516  1
364174  96.842  -69.020  52.481  1
364175  96.877  -69.031  52.446  1
364176  96.911  -69.042  52.409  1
364177  96.946  -69.052  52.374  1
364178  96.980  -69.064  52.340  1
364179  97.014  -69.074  52.305  1
364180  97.042  -69.080  52.269  1
364181  97.070  -69.087  52.234  1
364182  97.097  -69.093  52.197  1
364183  97.124  -69.098  52.162  1
364184  97.151  -69.100  52.128  1
364185  97.177  -69.103  52.096  1
364186  97.203  -69.104  52.062  1
364187  97.229  -69.106  52.031  1
364188  97.257  -69.112  52.000  1
364189  97.286  -69.119  51.968  1
364190  97.317  -69.125  51.940  1
364191  97.349  -69.131  51.915  1
364192  97.380  -69.137  51.894  1
364193  97.412  -69.142  51.877  1
364194  97.443  -69.147  51.865  1
364195  97.474  -69.153  51.855  1
364196  97.509  -69.157  51.848  1
364197  97.543  -69.162  51.841  1
364198  97.578  -69.165  51.832  1
364199  97.613  -69.170  51.819  1
364200  97.656  -69.173  51.803  1
364201  97.690  -69.178  51.782  1
364202  97.719  -69.184  51.756  1
364203  97.747  -69.190  51.726  1
364204  97.776  -69.197  51.695  1
364205  97.805  -69.203  51.660  1
364206  97.835  -69.209  51.623  1
364207  97.867  -69.214  51.583  1
364208  97.899  -69.220  51.537  1
364209  97.933  -69.226  51.492  1
364210  97.971  -69.234  51.445  1
364211  98.009  -69.242  51.397  1
364212  98.047  -69.250  51.347  1
364213  98.088  -69.258  51.298  1
364214  98.135  -69.266  51.247  1
364215  98.181  -69.275  51.194  1
364216  98.226  -69.279  51.140  1
364217  98.270  -69.282  51.085  1
364218  98.314  -69.285  51.029  1
364219  98.358  -69.289  50.973  1
364220  98.403  -69.292  50.917  1
364221  98.447  -69.296  50.859  1
364222  98.491  -69.299  50.801  1
364223  98.535  -69.302  50.744  1
364224  98.579  -69.306  50.690  1
364225  98.614  -69.311  50.636  1
364226  98.645  -69.318  50.582  1
364227  98.675  -69.325  50.528  1
364228  98.717  -69.340  50.472  1
364229  98.762  -69.357  50.415  1
364230  98.791  -69.366  50.360  1
364231  98.812  -69.373  50.304  1
364232  98.835  -69.379  50.247  1
364233  98.857  -69.386  50.191  1
364234  98.878  -69.392  50.134  1
364235  98.906  -69.408  50.080  1
364236  98.937  -69.430  50.026  1
364237  98.969  -69.452  49.972  1
364238  98.998  -69.470  49.918  1
364239  99.023  -69.480  49.865  1
364240  99.048  -69.490  49.813  1
364241  99.073  -69.500  49.761  1
364242  99.098  -69.510  49.709  1
364243  99.123  -69.519  49.658  1
364244  99.148  -69.529  49.608  1
364245  99.173  -69.539  49.558  1
364246  99.198  -69.549  49.508  1
364247  99.223  -69.558  49.458  1
364248  99.248  -69.569  49.409  1
364249  99.277  -69.582  49.360  1
364250  99.325  -69.590  49.311  1
364251  99.374  -69.603  49.262  1
364252  99.424  -69.615  49.213  1
364253  99.473  -69.627  49.166  1
364254  99.522  -69.640  49.120  1
364255  99.571  -69.652  49.073  1
364256  99.621  -69.664  49.027  1
364257  99.665  -69.684  48.981  1
364258  99.706  -69.710  48.934  1
364259  99.746  -69.736  48.888  1
364260  99.786  -69.762  48.844  1
364261  99.829  -69.785  48.799  1
364262  99.878  -69.799  48.756  1
364263  99.927  -69.813  48.713  1
364264  99.976  -69.827  48.670  1
364265  100.021  -69.842  48.628  1
364266  100.065  -69.858  48.588  1
364267  100.108  -69.873  48.551  1
364268  100.151  -69.888  48.514  1
364269  100.194  -69.903  48.477  1
364270  100.237  -69.919  48.442  1
364271  100.280  -69.934  48.408  1
364272  100.290  -69.944  48.375  1
364273  100.287  -69.919  48.346  1
364274  100.317  -69.919  48.317  1
364275  100.353  -69.924  48.290  1
364276  100.390  -69.929  48.264  1
364277  100.427  -69.933  48.239  1
364278  100.464  -69.939  48.209  1
364279  100.500  -69.943  48.177  1
364280  100.537  -69.949  48.144  1
364281  100.579  -69.955  48.111  1
364282  100.625  -69.962  48.079  1
364283  100.671  -69.969  48.047  1
364284  100.717  -69.977  48.014  1
364285  100.763  -69.983  47.981  1
364286  100.808  -69.991  47.948  1
364287  100.854  -69.999  47.912  1
364288  100.900  -70.005  47.877  1
364289  100.937  -70.015  47.841  1
364290  100.956  -70.026  47.803  1
364291  100.975  -70.038  47.764  1
364292  100.994  -70.050  47.728  1
364293  101.013  -70.062  47.692  1
364294  101.038  -70.069  47.654  1
364295  101.067  -70.074  47.613  1
364296  101.096  -70.079  47.567  1
364297  101.125  -70.083  47.520  1
364298  101.155  -70.088  47.474  1
364299  101.193  -70.087  47.430  1
364300  101.238  -70.084  47.384  1
364301  101.278  -70.088  47.339  1
364302  101.317  -70.093  47.293  1
364303  101.356  -70.098  47.249  1
364304  101.395  -70.103  47.205  1
364305  101.433  -70.109  47.162  1
364306  101.472  -70.114  47.120  1
364307  101.510  -70.119  47.078  1
364308  101.549  -70.124  47.036  1
364309  101.588  -70.130  46.996  1
364310  101.627  -70.134  46.955  1
364311  101.666  -70.140  46.915  1
364312  101.704  -70.145  46.876  1
364313  101.743  -70.150  46.838  1
364314  101.780  -70.155  46.800  1
364315  101.817  -70.159  46.762  1
364316  101.853  -70.162  46.724  1
364807  94.458  -68.933  53.471  1
364808  94.511  -68.900  53.462  1
364809  94.564  -68.867  53.453  1
364810  94.617  -68.833  53.443  1
364811  94.670  -68.800  53.434  1
364812  94.722  -68.767  53.426  1
364813  94.775  -68.734  53.419  1
364814  94.828  -68.701  53.411  1
364815  94.876  -68.684  53.404  1
364816  94.922  -68.674  53.398  1
364817  94.967  -68.665  53.394  1
364818  94.987  -68.689  53.391  1
364819  95.012  -68.703  53.392  1
364820  95.039  -68.714  53.393  1
364821  95.065  -68.724  53.390  1
364822  95.101  -68.739  53.385  1
364823  95.142  -68.755  53.379  1
364824  95.184  -68.773  53.373  1
364825  95.226  -68.789  53.366  1
364826  95.280  -68.799  53.360  1
364827  95.362  -68.792  53.354  1
364828  95.434  -68.792  53.350  1
364829  95.484  -68.806  53.348  1
364830  95.528  -68.817  53.349  1
364831  95.554  -68.818  53.351  1
364832  95.580  -68.819  53.351  1
364833  95.606  -68.820  53.344  1
364834  95.632  -68.821  53.330  1
364835  95.658  -68.822  53.318  1
364836  95.684  -68.823  53.308  1
364837  95.710  -68.824  53.300  1
364838  95.736  -68.824  53.306  1
364839  95.762  -68.826  53.309  1
364840  95.788  -68.827  53.304  1
364841  95.814  -68.827  53.291  1
364842  95.840  -68.828  53.270  1
364843  95.867  -68.829  53.246  1
364844  95.892  -68.830  53.223  1
364845  95.918  -68.831  53.201  1
364846  95.945  -68.832  53.179  1
364847  95.970  -68.833  53.164  1
364848  95.996  -68.834  53.162  1
364849  96.023  -68.835  53.161  1
364850  96.049  -68.836  53.155  1
364851  96.075  -68.836  53.142  1
364852  96.095  -68.834  53.132  1
364853  96.113  -68.830  53.131  1
364854  96.130  -68.825  53.135  1
364855  96.155  -68.824  53.132  1
364856  96.190  -68.827  53.117  1
364857  96.226  -68.830  53.091  1
364858  96.260  -68.833  53.058  1
364859  96.295  -68.838  53.022  1
364860  96.329  -68.842  52.983  1
364861  96.363  -68.847  52.952  1
364862  96.396  -68.855  52.924  1
364863  96.429  -68.866  52.897  1
364864  96.461  -68.877  52.870  1
364865  96.490  -68.891  52.847  1
364866  96.526  -68.901  52.825  1
364867  96.568  -68.905  52.802  1
364868  96.608  -68.914  52.771  1
364869  96.648  -68.922  52.729  1
364870  96.682  -68.933  52.682  1
364871  96.717  -68.944  52.633  1
364872  96.751  -68.955  52.587  1
364873  96.786  -68.966  52.545  1
364874  96.820  -68.977  52.509  1
364875  96.855  -68.988  52.473  1
364876  96.889  -68.999  52.438  1
364877  96.923  -69.010  52.399  1
364878  96.958  -69.021  52.363  1
364879  96.992  -69.031  52.326  1
364880  97.026  -69.042  52.290  1
364881  97.054  -69.049  52.254  1
364882  97.082  -69.055  52.220  1
364883  97.109  -69.061  52.184  1
364884  97.137  -69.065  52.149  1
364885  97.163  -69.068  52.115  1
364886  97.189  -69.069  52.083  1
364887  97.215  -69.071  52.051  1
364888  97.241  -69.074  52.021  1
364889  97.267  -69.076  51.992  1
364890  97.297  -69.080  51.963  1
364891  97.328  -69.086  51.937  1
364892  97.360  -69.091  51.916  1
364893  97.391  -69.097  51.898  1
364894  97.423  -69.103  51.885  1
364895  97.454  -69.109  51.877  1
364896  97.485  -69.114  51.871  1
364897  97.517  -69.119  51.865  1
364898  97.550  -69.124  51.858  1
364899  97.585  -69.128  51.849  1
364900  97.621  -69.132  51.836  1
364901  97.660  -69.136  51.818  1
364902  97.689  -69.143  51.795  1
364903  97.718  -69.149  51.768  1
364904  97.746  -69.155  51.736  1
364905  97.778  -69.160  51.701  1
364906  97.810  -69.166  51.664  1
364907  97.843  -69.172  51.623  1
364908  97.875  -69.178  51.581  1
364909  97.910  -69.184  51.534  1
364910  97.947  -69.192  51.487  1
364911  97.986  -69.200  51.439  1
364912  98.023  -69.207  51.390  1
364913  98.061  -69.215  51.340  1
364914  98.099  -69.223  51.290  1
364915  98.140  -69.231  51.239  1
364916  98.186  -69.240  51.185  1
364917  98.232  -69.244  51.131  1
364918  98.276  -69.248  51.075  1
364919  98.320  -69.251  51.020  1
364920  98.364  -69.255  50.964  1
364921  98.408  -69.258  50.908  1
364922  98.452  -69.261  50.852  1
364923  98.496  -69.265  50.796  1
364924  98.540  -69.268  50.741  1
364925  98.584  -69.271  50.688  1
364926  98.629  -69.275  50.635  1
364927  98.661  -69.281  50.581  1
364928  98.695  -69.291  50.525  1
364929  98.738  -69.306  50.469  1
364930  98.761  -69.313  50.412  1
364931  98.782  -69.319  50.355  1
364932  98.804  -69.326  50.299  1
364933  98.826  -69.332  50.243  1
364934  98.848  -69.339  50.186  1
364935  98.870  -69.345  50.131  1
364936  98.901  -69.366  50.077  1
364937  98.932  -69.388  50.023  1
364938  98.962  -69.409  49.969  1
364939  98.994  -69.431  49.916  1
364940  99.020  -69.442  49.864  1
364941  99.045  -69.452  49.813  1
364942  99.070  -69.462  49.761  1
364943  99.095  -69.472  49.709  1
364944  99.120  -69.482  49.658  1
364945  99.145  -69.491  49.608  1
364946  99.170  -69.501  49.557  1
364947  99.195  -69.511  49.507  1
364948  99.220  -69.521  49.456  1
364949  99.259  -69.527  49.407  1
364950  99.290  -69.544  49.358  1
364951  99.340  -69.556  49.309  1
364952  99.389  -69.569  49.260  1
364953  99.438  -69.581  49.211  1
364954  99.488  -69.593  49.164  1
364955  99.537  -69.606  49.117  1
364956  99.586  -69.618  49.070  1
364957  99.630  -69.639  49.024  1
364958  99.670  -69.666  48.978  1
364959  99.710  -69.692  48.931  1
364960  99.752  -69.716  48.885  1
364961  99.800  -69.730  48.840  1
364962  99.849  -69.745  48.795  1
364963  99.899  -69.759  48.751  1
364964  99.947  -69.773  48.707  1
364965  99.996  -69.788  48.664  1
364966  100.043  -69.802  48.621  1
364967  100.086  -69.817  48.581  1
364968  100.129  -69.833  48.542  1
364969  100.173  -69.848  48.504  1
364970  100.215  -69.864  48.467  1
364971  100.259  -69.879  48.430  1
364972  100.275  -69.894  48.395  1
364973  100.287  -69.910  48.361  1
364974  100.290  -69.895  48.331  1
364975  100.327  -69.900  48.300  1
364976  100.364  -69.905  48.271  1
364977  100.401  -69.910  48.243  1
364978  100.437  -69.914  48.216  1
364979  100.474  -69.920  48.186  1
364980  100.510  -69.924  48.155  1
364981  100.547  -69.930  48.123  1
364982  100.583  -69.934  48.091  1
364983  100.620  -69.939  48.059  1
364984  100.657  -69.944  48.026  1
364985  100.695  -69.949  47.992  1
364986  100.741  -69.957  47.957  1
364987  100.786  -69.964  47.924  1
364988  100.832  -69.971  47.888  1
364989  100.878  -69.979  47.853  1
364990  100.920  -69.986  47.817  1
364991  100.939  -69.999  47.779  1
364992  100.958  -70.010  47.739  1
364993  100.980  -70.020  47.703  1
364994  101.009  -70.024  47.667  1
364995  101.038  -70.029  47.629  1
364996  101.067  -70.033  47.588  1
364997  101.097  -70.038  47.542  1
364998  101.125  -70.043  47.495  1
364999  101.162  -70.043  47.449  1
365000  101.204  -70.040  47.404  1
365001  101.250  -70.040  47.361  1
365002  101.288  -70.045  47.317  1
365003  101.327  -70.050  47.273  1
365004  101.366  -70.055  47.230  1
365005  101.405  -70.061  47.186  1
365006  101.443  -70.066  47.144  1
365007  101.482  -70.071  47.103  1
365008  101.521  -70.077  47.062  1
365009  101.559  -70.081  47.021  1
365010  101.598  -70.087  46.981  1
365011  101.637  -70.092  46.941  1
365012  101.676  -70.097  46.902  1
365013  101.714  -70.102  46.864  1
365014  101.753  -70.108  46.826  1
365015  101.792  -70.113  46.787  1
365016  101.830  -70.118  46.750  1
365433  91.379  -69.196  54.860  1
365434  91.437  -69.225  54.852  1
365435  91.495  -69.256  54.845  1
365436  91.545  -69.316  54.837  1
365437  91.596  -69.375  54.828  1
365508  94.488  -68.843  53.474  1
365509  94.541  -68.811  53.465  1
365510  94.594  -68.777  53.456  1
365511  94.646  -68.744  53.447  1
365512  94.699  -68.711  53.438  1
365513  94.750  -68.685  53.431  1
365514  94.796  -68.676  53.423  1
365515  94.841  -68.666  53.415  1
365516  94.887  -68.656  53.408  1
365517  94.932  -68.647  53.402  1
365518  94.965  -68.654  53.398  1
365519  94.985  -68.678  53.395  1
365520  95.007  -68.700  53.395  1
365521  95.033  -68.710  53.395  1
365522  95.060  -68.720  53.394  1
365523  95.086  -68.731  53.391  1
365524  95.113  -68.742  53.385  1
365525  95.139  -68.752  53.379  1
365526  95.175  -68.766  53.373  1
365527  95.245  -68.767  53.365  1
365528  95.326  -68.759  53.357  1
365529  95.408  -68.752  53.350  1
365530  95.462  -68.764  53.348  1
365531  95.513  -68.780  53.348  1
365532  95.561  -68.793  53.349  1
365533  95.588  -68.794  53.348  1
365534  95.614  -68.796  53.340  1
365535  95.639  -68.796  53.326  1
365536  95.666  -68.797  53.313  1
365537  95.692  -68.798  53.305  1
365538  95.718  -68.799  53.306  1
365539  95.744  -68.800  53.316  1
365540  95.770  -68.801  53.319  1
365541  95.796  -68.802  53.314  1
365542  95.822  -68.802  53.298  1
365543  95.848  -68.804  53.275  1
365544  95.874  -68.805  53.248  1
365545  95.900  -68.805  53.219  1
365546  95.926  -68.806  53.192  1
365547  95.952  -68.808  53.169  1
365548  95.978  -68.808  53.154  1
365549  96.004  -68.809  53.149  1
365550  96.030  -68.810  53.147  1
365551  96.056  -68.811  53.141  1
365552  96.079  -68.810  53.129  1
365553  96.096  -68.805  53.121  1
365554  96.113  -68.801  53.122  1
365555  96.130  -68.796  53.127  1
365556  96.158  -68.796  53.122  1
365557  96.193  -68.799  53.109  1
365558  96.228  -68.803  53.086  1
365559  96.262  -68.808  53.055  1
365560  96.296  -68.811  53.020  1
365561  96.330  -68.816  52.981  1
365562  96.364  -68.821  52.948  1
365563  96.398  -68.828  52.916  1
365564  96.430  -68.839  52.885  1
365565  96.458  -68.854  52.858  1
365566  96.487  -68.868  52.831  1
365567  96.530  -68.872  52.808  1
365568  96.572  -68.877  52.785  1
365569  96.612  -68.885  52.756  1
365570  96.653  -68.893  52.717  1
365571  96.693  -68.901  52.671  1
365572  96.728  -68.912  52.624  1
365573  96.762  -68.923  52.580  1
365574  96.797  -68.934  52.538  1
365575  96.831  -68.945  52.501  1
365576  96.866  -68.955  52.464  1
365577  96.900  -68.967  52.428  1
365578  96.935  -68.977  52.388  1
365579  96.969  -68.989  52.351  1
365580  97.004  -68.999  52.312  1
365581  97.038  -69.010  52.275  1
365582  97.066  -69.017  52.239  1
365583  97.094  -69.023  52.206  1
365584  97.121  -69.029  52.171  1
365585  97.148  -69.033  52.136  1
365586  97.174  -69.035  52.103  1
365587  97.201  -69.037  52.071  1
365588  97.227  -69.039  52.040  1
365589  97.253  -69.041  52.012  1
365590  97.278  -69.041  51.986  1
365591  97.304  -69.043  51.960  1
365592  97.336  -69.048  51.937  1
365593  97.368  -69.053  51.919  1
365594  97.400  -69.059  51.905  1
365595  97.433  -69.064  51.894  1
365596  97.465  -69.069  51.890  1
365597  97.496  -69.074  51.886  1
365598  97.527  -69.081  51.881  1
365599  97.559  -69.086  51.874  1
365600  97.592  -69.090  51.864  1
365601  97.630  -69.094  51.850  1
365602  97.659  -69.100  51.832  1
365603  97.689  -69.106  51.807  1
365604  97.722  -69.112  51.778  1
365605  97.754  -69.118  51.744  1
365606  97.786  -69.124  51.707  1
365607  97.818  -69.129  51.667  1
365608  97.851  -69.135  51.624  1
365609  97.886  -69.142  51.581  1
365610  97.924  -69.150  51.532  1
365611  97.962  -69.157  51.483  1
365612  98.000  -69.165  51.434  1
365613  98.037  -69.173  51.384  1
365614  98.076  -69.181  51.334  1
365615  98.113  -69.189  51.284  1
365616  98.152  -69.197  51.233  1
365617  98.192  -69.205  51.178  1
365618  98.237  -69.210  51.124  1
365619  98.281  -69.214  51.068  1
365620  98.325  -69.217  51.012  1
365621  98.369  -69.220  50.957  1
365622  98.414  -69.224  50.902  1
365623  98.457  -69.227  50.847  1
365624  98.502  -69.230  50.794  1
365625  98.546  -69.234  50.741  1
365626  98.590  -69.237  50.688  1
365627  98.634  -69.240  50.634  1
365628  98.677  -69.244  50.580  1
365629  98.708  -69.253  50.524  1
365630  98.730  -69.259  50.467  1
365631  98.752  -69.266  50.410  1
365632  98.774  -69.272  50.353  1
365633  98.796  -69.279  50.297  1
365634  98.818  -69.285  50.241  1
365635  98.840  -69.292  50.184  1
365636  98.863  -69.301  50.129  1
365637  98.895  -69.323  50.076  1
365638  98.926  -69.344  50.022  1
365639  98.957  -69.366  49.968  1
365640  98.988  -69.388  49.916  1
365641  99.016  -69.404  49.865  1
365642  99.042  -69.414  49.813  1
365643  99.067  -69.424  49.762  1
365644  99.091  -69.434  49.711  1
365645  99.117  -69.444  49.659  1
365646  99.142  -69.454  49.608  1
365647  99.167  -69.463  49.557  1
365648  99.192  -69.473  49.505  1
365649  99.248  -69.476  49.454  1
365650  99.284  -69.490  49.405  1
365651  99.305  -69.510  49.355  1
365652  99.354  -69.523  49.306  1
365653  99.404  -69.535  49.258  1
365654  99.453  -69.547  49.210  1
365655  99.502  -69.560  49.162  1
365656  99.552  -69.572  49.115  1
365657  99.593  -69.595  49.068  1
365658  99.634  -69.621  49.021  1
365659  99.674  -69.648  48.975  1
365660  99.723  -69.662  48.929  1
365661  99.772  -69.676  48.882  1
365662  99.821  -69.691  48.837  1
365663  99.870  -69.705  48.792  1
365664  99.919  -69.719  48.747  1
365665  99.968  -69.733  48.702  1
365666  100.017  -69.748  48.659  1
365667  100.065  -69.762  48.615  1
365668  100.108  -69.777  48.574  1
365669  100.151  -69.793  48.535  1
365670  100.194  -69.808  48.495  1
365671  100.237  -69.823  48.456  1
365672  100.258  -69.839  48.419  1
365673  100.269  -69.855  48.383  1
365674  100.281  -69.870  48.348  1
365675  100.301  -69.877  48.316  1
365676  100.337  -69.881  48.284  1
365677  100.374  -69.886  48.252  1
365678  100.411  -69.891  48.221  1
365679  100.447  -69.896  48.191  1
365680  100.484  -69.901  48.161  1
365681  100.521  -69.906  48.131  1
365682  100.557  -69.911  48.101  1
365683  100.594  -69.916  48.071  1
365684  100.631  -69.921  48.040  1
365685  100.668  -69.926  48.007  1
365686  100.704  -69.930  47.971  1
365687  100.741  -69.935  47.934  1
365688  100.777  -69.940  47.900  1
365689  100.814  -69.945  47.865  1
365690  100.856  -69.952  47.831  1
365691  100.902  -69.958  47.795  1
365692  100.922  -69.971  47.756  1
365693  100.951  -69.975  47.714  1
365694  100.980  -69.980  47.675  1
365695  101.009  -69.984  47.637  1
365696  101.039  -69.989  47.598  1
365697  101.067  -69.993  47.557  1
365698  101.097  -69.998  47.513  1
365699  101.132  -69.999  47.470  1
365700  101.172  -69.996  47.427  1
365701  101.218  -69.994  47.383  1
365702  101.260  -69.997  47.341  1
365703  101.299  -70.002  47.298  1
365704  101.337  -70.008  47.255  1
365705  101.376  -70.013  47.212  1
365706  101.414  -70.018  47.170  1
365707  101.453  -70.024  47.129  1
365708  101.492  -70.028  47.088  1
365709  101.531  -70.033  47.047  1
365710  101.569  -70.039  47.007  1
365711  101.608  -70.044  46.966  1
365712  101.647  -70.049  46.928  1
365713  101.686  -70.055  46.889  1
365714  101.724  -70.060  46.851  1
365715  101.763  -70.065  46.813  1
366133  91.314  -69.138  54.859  1
366134  91.373  -69.167  54.853  1
366135  91.431  -69.197  54.846  1
366136  91.488  -69.231  54.839  1
366137  91.539  -69.291  54.832  1
366138  91.589  -69.350  54.824  1
366139  91.640  -69.410  54.814  1
366140  91.691  -69.391  54.803  1
366141  91.733  -69.360  54.791  1
366142  91.772  -69.331  54.777  1
366143  91.811  -69.301  54.762  1
366144  91.852  -69.275  54.747  1
366210  94.571  -68.721  53.467  1
366211  94.624  -68.688  53.458  1
366212  94.670  -68.676  53.450  1
366213  94.715  -68.667  53.440  1
366214  94.761  -68.658  53.433  1
366215  94.807  -68.648  53.426  1
366216  94.852  -68.639  53.419  1
366217  94.898  -68.629  53.412  1
366218  94.942  -68.620  53.406  1
366219  94.963  -68.644  53.401  1
366220  94.983  -68.667  53.398  1
366221  95.004  -68.691  53.396  1
366222  95.028  -68.707  53.396  1
366223  95.054  -68.717  53.396  1
366224  95.081  -68.727  53.393  1
366225  95.107  -68.738  53.388  1
366226  95.134  -68.747  53.382  1
366227  95.169  -68.735  53.376  1
366228  95.209  -68.734  53.368  1
366229  95.291  -68.727  53.359  1
366230  95.373  -68.720  53.350  1
366231  95.440  -68.723  53.346  1
366232  95.490  -68.738  53.345  1
366233  95.540  -68.752  53.344  1
366234  95.591  -68.767  53.341  1
366235  95.621  -68.770  53.333  1
366236  95.647  -68.771  53.322  1
366237  95.673  -68.772  53.311  1
366238  95.699  -68.774  53.303  1
366239  95.725  -68.774  53.306  1
366240  95.751  -68.775  53.318  1
366241  95.777  -68.776  53.321  1
366242  95.803  -68.777  53.315  1
366243  95.829  -68.778  53.299  1
366244  95.855  -68.779  53.274  1
366245  95.882  -68.780  53.244  1
366246  95.907  -68.780  53.213  1
366247  95.934  -68.782  53.183  1
366248  95.960  -68.783  53.159  1
366249  95.985  -68.783  53.144  1
366250  96.012  -68.784  53.137  1
366251  96.038  -68.786  53.133  1
366252  96.062  -68.786  53.126  1
366253  96.080  -68.781  53.115  1
366254  96.097  -68.777  53.109  1
366255  96.114  -68.772  53.109  1
366256  96.131  -68.767  53.113  1
366257  96.160  -68.767  53.109  1
366258  96.194  -68.772  53.095  1
366259  96.229  -68.777  53.073  1
366260  96.263  -68.781  53.045  1
366261  96.297  -68.786  53.013  1
366262  96.331  -68.790  52.978  1
366263  96.365  -68.795  52.946  1
366264  96.397  -68.803  52.915  1
366265  96.426  -68.817  52.884  1
366266  96.454  -68.832  52.851  1
366267  96.490  -68.840  52.819  1
366268  96.533  -68.844  52.791  1
366269  96.576  -68.849  52.764  1
366270  96.617  -68.856  52.737  1
366271  96.657  -68.864  52.701  1
366272  96.698  -68.872  52.660  1
366273  96.739  -68.880  52.615  1
366274  96.774  -68.891  52.570  1
366275  96.809  -68.902  52.529  1
366276  96.843  -68.913  52.491  1
366277  96.878  -68.924  52.453  1
366278  96.912  -68.934  52.415  1
366279  96.946  -68.946  52.376  1
366280  96.981  -68.956  52.337  1
366281  97.015  -68.968  52.298  1
366282  97.050  -68.978  52.261  1
366283  97.079  -68.985  52.225  1
366284  97.106  -68.991  52.192  1
366285  97.134  -68.998  52.157  1
366286  97.160  -69.000  52.123  1
366287  97.186  -69.002  52.090  1
366288  97.213  -69.004  52.059  1
366289  97.239  -69.006  52.031  1
366290  97.264  -69.007  52.007  1
366291  97.286  -69.003  51.983  1
366292  97.312  -69.005  51.960  1
366293  97.344  -69.011  51.940  1
366294  97.375  -69.016  51.925  1
366295  97.407  -69.021  51.914  1
366296  97.440  -69.027  51.907  1
366297  97.471  -69.032  51.904  1
366298  97.504  -69.037  51.899  1
366299  97.536  -69.043  51.893  1
366300  97.568  -69.048  51.886  1
366301  97.600  -69.052  51.875  1
366302  97.633  -69.059  51.861  1
366303  97.665  -69.064  51.842  1
366304  97.697  -69.070  51.817  1
366305  97.729  -69.075  51.786  1
366306  97.762  -69.081  51.750  1
366307  97.794  -69.087  51.710  1
366308  97.826  -69.093  51.669  1
366309  97.862  -69.099  51.626  1
366310  97.900  -69.107  51.581  1
366311  97.938  -69.115  51.532  1
366312  97.976  -69.123  51.481  1
366313  98.014  -69.131  51.430  1
366314  98.052  -69.139  51.380  1
366315  98.090  -69.147  51.328  1
366316  98.128  -69.154  51.278  1
366317  98.166  -69.162  51.227  1
366318  98.203  -69.169  51.173  1
366319  98.243  -69.174  51.119  1
366320  98.287  -69.177  51.065  1
366321  98.332  -69.180  51.009  1
366322  98.376  -69.182  50.952  1
366323  98.420  -69.185  50.898  1
366324  98.464  -69.188  50.846  1
366325  98.509  -69.191  50.795  1
366326  98.553  -69.194  50.743  1
366327  98.597  -69.197  50.691  1
366328  98.641  -69.200  50.635  1
366329  98.683  -69.209  50.580  1
366330  98.700  -69.206  50.525  1
366331  98.722  -69.212  50.467  1
366332  98.743  -69.219  50.409  1
366333  98.766  -69.225  50.353  1
366334  98.787  -69.231  50.297  1
366335  98.809  -69.238  50.241  1
366336  98.831  -69.244  50.186  1
366337  98.858  -69.259  50.130  1
366338  98.888  -69.280  50.076  1
366339  98.920  -69.302  50.023  1
366340  98.951  -69.323  49.970  1
366341  98.982  -69.345  49.918  1
366342  99.013  -69.366  49.866  1
366343  99.039  -69.377  49.815  1
366344  99.063  -69.387  49.764  1
366345  99.088  -69.397  49.713  1
366346  99.114  -69.407  49.661  1
366347  99.138  -69.416  49.610  1
366348  99.174  -69.423  49.557  1
366349  99.238  -69.424  49.505  1
366350  99.284  -69.434  49.454  1
366351  99.302  -69.454  49.403  1
366352  99.321  -69.476  49.353  1
366353  99.369  -69.488  49.304  1
366354  99.418  -69.501  49.256  1
366355  99.468  -69.513  49.208  1
366356  99.517  -69.526  49.161  1
366357  99.558  -69.551  49.113  1
366358  99.598  -69.577  49.066  1
366359  99.645  -69.594  49.018  1
366360  99.694  -69.608  48.972  1
366361  99.743  -69.623  48.926  1
366362  99.792  -69.636  48.880  1
366363  99.841  -69.651  48.834  1
366364  99.890  -69.665  48.789  1
366365  99.939  -69.679  48.744  1
366366  99.988  -69.694  48.699  1
366367  100.037  -69.708  48.654  1
366368  100.086  -69.722  48.610  1
366369  100.129  -69.738  48.569  1
366370  100.173  -69.753  48.528  1
366371  100.215  -69.768  48.488  1
366372  100.240  -69.783  48.448  1
366373  100.252  -69.799  48.410  1
366374  100.264  -69.814  48.373  1
366375  100.282  -69.822  48.337  1
366376  100.310  -69.827  48.303  1
366377  100.346  -69.833  48.270  1
366378  100.383  -69.839  48.237  1
366379  100.420  -69.844  48.205  1
366380  100.456  -69.849  48.173  1
366381  100.493  -69.855  48.141  1
366382  100.530  -69.861  48.111  1
366383  100.566  -69.866  48.080  1
366384  100.603  -69.872  48.049  1
366385  100.640  -69.877  48.017  1
366386  100.677  -69.883  47.983  1
366387  100.713  -69.889  47.948  1
366388  100.750  -69.894  47.912  1
366389  100.786  -69.899  47.878  1
366390  100.823  -69.905  47.842  1
366391  100.860  -69.911  47.808  1
366392  100.893  -69.925  47.772  1
366393  100.922  -69.930  47.732  1
366394  100.952  -69.935  47.691  1
366395  100.980  -69.939  47.652  1
366396  101.009  -69.944  47.613  1
366397  101.039  -69.949  47.574  1
366398  101.068  -69.953  47.533  1
366399  101.102  -69.955  47.490  1
366400  101.141  -69.952  47.448  1
366401  101.184  -69.950  47.407  1
366402  101.231  -69.949  47.365  1
366403  101.270  -69.955  47.323  1
366404  101.309  -69.960  47.281  1
366405  101.347  -69.965  47.239  1
366406  101.386  -69.971  47.197  1
366407  101.424  -69.975  47.155  1
366408  101.463  -69.980  47.114  1
366409  101.502  -69.986  47.073  1
366410  101.541  -69.991  47.032  1
366411  101.580  -69.996  46.993  1
366412  101.618  -70.002  46.953  1
366413  101.657  -70.007  46.915  1
366414  101.695  -70.012  46.877  1
366832  91.191  -69.051  54.860  1
366833  91.250  -69.081  54.856  1
366834  91.308  -69.109  54.852  1
366835  91.367  -69.139  54.846  1
366836  91.425  -69.168  54.841  1
366837  91.481  -69.206  54.835  1
366838  91.532  -69.266  54.828  1
366839  91.583  -69.326  54.820  1
366840  91.633  -69.386  54.810  1
366841  91.684  -69.360  54.800  1
366842  91.724  -69.330  54.788  1
366843  91.763  -69.300  54.775  1
366844  91.802  -69.271  54.760  1
366845  91.848  -69.259  54.745  1
366846  91.896  -69.251  54.729  1
366911  94.589  -68.668  53.469  1
366912  94.635  -68.659  53.460  1
366913  94.680  -68.649  53.452  1
366914  94.726  -68.639  53.443  1
366915  94.771  -68.630  53.435  1
366916  94.817  -68.620  53.428  1
366917  94.862  -68.611  53.421  1
366918  94.908  -68.601  53.414  1
366919  94.940  -68.610  53.408  1
366920  94.961  -68.633  53.402  1
366921  94.981  -68.657  53.398  1
366922  95.002  -68.681  53.397  1
366923  95.023  -68.703  53.397  1
366924  95.049  -68.714  53.395  1
366925  95.075  -68.724  53.392  1
366926  95.109  -68.717  53.388  1
366927  95.144  -68.704  53.382  1
366928  95.179  -68.692  53.375  1
366929  95.213  -68.688  53.367  1
366930  95.255  -68.694  53.358  1
366931  95.337  -68.687  53.349  1
366932  95.417  -68.681  53.343  1
366933  95.467  -68.696  53.339  1
366934  95.518  -68.711  53.336  1
366935  95.568  -68.726  53.332  1
366936  95.619  -68.740  53.325  1
366937  95.655  -68.747  53.319  1
366938  95.681  -68.748  53.310  1
366939  95.707  -68.749  53.302  1
366940  95.733  -68.749  53.302  1
366941  95.759  -68.750  53.313  1
366942  95.785  -68.752  53.316  1
366943  95.811  -68.752  53.310  1
366944  95.837  -68.753  53.296  1
366945  95.863  -68.754  53.270  1
366946  95.889  -68.755  53.239  1
366947  95.915  -68.756  53.206  1
366948  95.941  -68.757  53.175  1
366949  95.967  -68.758  53.152  1
366950  95.993  -68.758  53.137  1
366951  96.019  -68.760  53.128  1
366952  96.045  -68.761  53.121  1
366953  96.063  -68.757  53.113  1
366954  96.081  -68.752  53.103  1
366955  96.098  -68.747  53.097  1
366956  96.115  -68.742  53.095  1
366957  96.135  -68.739  53.096  1
366958  96.164  -68.742  53.092  1
366959  96.193  -68.750  53.078  1
366960  96.224  -68.757  53.057  1
366961  96.257  -68.763  53.031  1
366962  96.291  -68.768  53.002  1
366963  96.324  -68.774  52.971  1
366964  96.358  -68.779  52.940  1
366965  96.391  -68.785  52.911  1
366966  96.421  -68.796  52.880  1
366967  96.452  -68.808  52.844  1
366968  96.495  -68.812  52.809  1
366969  96.537  -68.816  52.776  1
366970  96.580  -68.820  52.745  1
366971  96.621  -68.828  52.717  1
366972  96.662  -68.836  52.684  1
366973  96.702  -68.844  52.647  1
366974  96.743  -68.852  52.605  1
366975  96.784  -68.860  52.560  1
366976  96.820  -68.870  52.519  1
366977  96.855  -68.880  52.480  1
366978  96.889  -68.892  52.442  1
366979  96.924  -68.902  52.403  1
366980  96.958  -68.913  52.363  1
366981  96.993  -68.924  52.323  1
366982  97.027  -68.935  52.284  1
366983  97.062  -68.946  52.247  1
366984  97.091  -68.953  52.211  1
366985  97.118  -68.960  52.178  1
366986  97.146  -68.965  52.144  1
366987  97.172  -68.968  52.110  1
366988  97.198  -68.969  52.079  1
366989  97.225  -68.971  52.049  1
366990  97.250  -68.974  52.024  1
366991  97.272  -68.970  52.002  1
366992  97.294  -68.966  51.982  1
366993  97.320  -68.968  51.962  1
366994  97.352  -68.974  51.947  1
366995  97.382  -68.980  51.936  1
366996  97.414  -68.985  51.929  1
366997  97.446  -68.990  51.924  1
366998  97.478  -68.995  51.921  1
366999  97.511  -69.000  51.914  1
367000  97.543  -69.005  51.905  1
367001  97.575  -69.011  51.896  1
367002  97.607  -69.016  51.882  1
367003  97.640  -69.021  51.866  1
367004  97.673  -69.027  51.847  1
367005  97.705  -69.033  51.822  1
367006  97.737  -69.039  51.790  1
367007  97.770  -69.044  51.755  1
367008  97.802  -69.050  51.715  1
367009  97.839  -69.057  51.674  1
367010  97.876  -69.065  51.630  1
367011  97.915  -69.073  51.586  1
367012  97.952  -69.081  51.535  1
367013  97.991  -69.089  51.484  1
367014  98.028  -69.096  51.432  1
367015  98.065  -69.103  51.379  1
367016  98.101  -69.109  51.326  1
367017  98.137  -69.115  51.273  1
367018  98.173  -69.121  51.219  1
367019  98.209  -69.127  51.164  1
367020  98.252  -69.130  51.110  1
367021  98.296  -69.133  51.057  1
367022  98.341  -69.136  51.003  1
367023  98.384  -69.139  50.949  1
367024  98.429  -69.142  50.898  1
367025  98.473  -69.144  50.848  1
367026  98.517  -69.147  50.797  1
367027  98.562  -69.150  50.745  1
367028  98.606  -69.153  50.692  1
367029  98.647  -69.165  50.636  1
367030  98.687  -69.178  50.581  1
367031  98.706  -69.176  50.525  1
367032  98.715  -69.168  50.468  1
367033  98.735  -69.172  50.411  1
367034  98.757  -69.178  50.355  1
367035  98.779  -69.184  50.300  1
367036  98.801  -69.191  50.245  1
367037  98.823  -69.197  50.190  1
367038  98.852  -69.215  50.134  1
367039  98.883  -69.237  50.079  1
367040  98.914  -69.259  50.025  1
367041  98.945  -69.281  49.972  1
367042  98.976  -69.302  49.919  1
367043  99.007  -69.324  49.868  1
367044  99.035  -69.339  49.817  1
367045  99.060  -69.349  49.766  1
367046  99.085  -69.359  49.714  1
367047  99.110  -69.369  49.662  1
367048  99.163  -69.372  49.609  1
367049  99.227  -69.372  49.557  1
367050  99.285  -69.378  49.505  1
367051  99.303  -69.398  49.453  1
367052  99.321  -69.419  49.402  1
367053  99.339  -69.441  49.352  1
367054  99.384  -69.454  49.303  1
367055  99.433  -69.466  49.254  1
367056  99.482  -69.480  49.206  1
367057  99.522  -69.506  49.159  1
367058  99.567  -69.526  49.111  1
367059  99.616  -69.539  49.063  1
367060  99.665  -69.554  49.016  1
367061  99.714  -69.568  48.969  1
367062  99.763  -69.582  48.922  1
367063  99.812  -69.597  48.876  1
367064  99.861  -69.611  48.830  1
367065  99.910  -69.626  48.786  1
367066  99.960  -69.639  48.740  1
367067  100.008  -69.654  48.695  1
367068  100.057  -69.668  48.650  1
367069  100.106  -69.682  48.606  1
367070  100.151  -69.698  48.564  1
367071  100.194  -69.713  48.522  1
367072  100.222  -69.728  48.481  1
367073  100.234  -69.744  48.440  1
367074  100.251  -69.754  48.401  1
367075  100.270  -69.758  48.363  1
367076  100.289  -69.764  48.326  1
367077  100.318  -69.769  48.291  1
367078  100.354  -69.775  48.257  1
367079  100.391  -69.780  48.223  1
367080  100.428  -69.786  48.190  1
367081  100.465  -69.792  48.156  1
367082  100.501  -69.797  48.124  1
367083  100.538  -69.802  48.092  1
367084  100.575  -69.808  48.061  1
367085  100.611  -69.814  48.029  1
367086  100.648  -69.820  47.996  1
367087  100.685  -69.825  47.961  1
367088  100.721  -69.830  47.926  1
367089  100.758  -69.836  47.891  1
367090  100.795  -69.842  47.856  1
367091  100.833  -69.865  47.821  1
367092  100.864  -69.880  47.786  1
367093  100.894  -69.885  47.749  1
367094  100.922  -69.889  47.710  1
367095  100.952  -69.894  47.670  1
367096  100.981  -69.899  47.631  1
367097  101.009  -69.904  47.592  1
367098  101.039  -69.908  47.552  1
367099  101.071  -69.911  47.512  1
367100  101.111  -69.908  47.471  1
367101  101.150  -69.906  47.430  1
367102  101.199  -69.905  47.389  1
367103  101.241  -69.907  47.348  1
367104  101.280  -69.912  47.306  1
367105  101.319  -69.917  47.265  1
367106  101.357  -69.923  47.224  1
367107  101.396  -69.927  47.182  1
367108  101.434  -69.933  47.141  1
367109  101.473  -69.938  47.099  1
367110  101.512  -69.943  47.059  1
367111  101.551  -69.949  47.019  1
367112  101.590  -69.954  46.980  1
367113  101.628  -69.959  46.942  1
367114  101.667  -69.964  46.903  1
367532  91.127  -68.993  54.858  1
367533  91.185  -69.023  54.853  1
367534  91.244  -69.052  54.849  1
367535  91.302  -69.081  54.846  1
367536  91.361  -69.111  54.842  1
367537  91.419  -69.140  54.837  1
367538  91.474  -69.181  54.832  1
367539  91.525  -69.241  54.826  1
367540  91.576  -69.301  54.818  1
367541  91.627  -69.357  54.809  1
367542  91.675  -69.330  54.798  1
367543  91.715  -69.300  54.786  1
367544  91.754  -69.270  54.773  1
367545  91.797  -69.250  54.758  1
367546  91.844  -69.242  54.743  1
367547  91.891  -69.234  54.727  1
367548  91.936  -69.222  54.712  1
367613  94.645  -68.631  53.462  1
367614  94.691  -68.622  53.453  1
367615  94.737  -68.612  53.444  1
367616  94.782  -68.603  53.437  1
367617  94.828  -68.593  53.429  1
367618  94.873  -68.583  53.422  1
367619  94.917  -68.576  53.415  1
367620  94.938  -68.599  53.409  1
367621  94.959  -68.623  53.403  1
367622  94.979  -68.646  53.398  1
367623  95.000  -68.670  53.396  1
367624  95.021  -68.694  53.396  1
367625  95.049  -68.698  53.393  1
367626  95.084  -68.686  53.389  1
367627  95.119  -68.673  53.384  1
367628  95.154  -68.661  53.377  1
367629  95.189  -68.648  53.370  1
367630  95.224  -68.641  53.362  1
367631  95.255  -68.649  53.353  1
367632  95.302  -68.654  53.344  1
367633  95.384  -68.647  53.337  1
367634  95.445  -68.654  53.332  1
367635  95.495  -68.669  53.329  1
367636  95.546  -68.684  53.326  1
367637  95.597  -68.698  53.322  1
367638  95.647  -68.714  53.316  1
367639  95.688  -68.723  53.306  1
367640  95.714  -68.723  53.296  1
367641  95.740  -68.725  53.292  1
367642  95.766  -68.726  53.301  1
367643  95.793  -68.727  53.304  1
367644  95.818  -68.727  53.300  1
367645  95.844  -68.729  53.288  1
367646  95.871  -68.730  53.263  1
367647  95.897  -68.730  53.231  1
367648  95.922  -68.731  53.199  1
367649  95.949  -68.732  53.170  1
367650  95.975  -68.733  53.148  1
367651  96.001  -68.734  53.133  1
367652  96.027  -68.735  53.122  1
367653  96.047  -68.732  53.114  1
367654  96.064  -68.727  53.104  1
367655  96.081  -68.723  53.094  1
367656  96.098  -68.718  53.085  1
367657  96.122  -68.716  53.080  1
367658  96.151  -68.714  53.078  1
367659  96.179  -68.714  53.070  1
367660  96.208  -68.722  53.057  1
367661  96.238  -68.730  53.038  1
367662  96.268  -68.737  53.014  1
367663  96.297  -68.745  52.989  1
367664  96.327  -68.752  52.961  1
367665  96.356  -68.760  52.932  1
367666  96.386  -68.767  52.903  1
367667  96.416  -68.774  52.873  1
367668  96.456  -68.780  52.837  1
367669  96.499  -68.783  52.800  1
367670  96.541  -68.787  52.764  1
367671  96.584  -68.792  52.729  1
367672  96.625  -68.799  52.697  1
367673  96.666  -68.808  52.667  1
367674  96.707  -68.815  52.632  1
367675  96.747  -68.824  52.592  1
367676  96.788  -68.831  52.549  1
367677  96.828  -68.839  52.508  1
367678  96.866  -68.849  52.469  1
367679  96.901  -68.859  52.430  1
367680  96.935  -68.871  52.390  1
367681  96.970  -68.881  52.348  1
367682  97.004  -68.892  52.308  1
367683  97.038  -68.903  52.269  1
367684  97.073  -68.914  52.233  1
367685  97.103  -68.922  52.198  1
367686  97.131  -68.928  52.164  1
367687  97.158  -68.933  52.131  1
367688  97.184  -68.934  52.099  1
367689  97.210  -68.936  52.069  1
367690  97.236  -68.939  52.042  1
367691  97.259  -68.936  52.019  1
367692  97.281  -68.932  51.999  1
367693  97.302  -68.929  51.982  1
367694  97.329  -68.930  51.966  1
367695  97.360  -68.936  51.955  1
367696  97.390  -68.942  51.949  1
367697  97.422  -68.948  51.944  1
367698  97.453  -68.953  51.941  1
367699  97.486  -68.958  51.938  1
367700  97.518  -68.964  51.928  1
367701  97.549  -68.969  51.916  1
367702  97.582  -68.974  51.904  1
367703  97.614  -68.979  51.888  1
367704  97.647  -68.985  51.870  1
367705  97.680  -68.990  51.849  1
367706  97.713  -68.996  51.824  1
367707  97.745  -69.002  51.792  1
367708  97.778  -69.008  51.757  1
367709  97.815  -69.015  51.718  1
367710  97.853  -69.023  51.676  1
367711  97.889  -69.030  51.632  1
367712  97.926  -69.036  51.587  1
367713  97.962  -69.042  51.536  1
367714  97.998  -69.047  51.484  1
367715  98.034  -69.053  51.430  1
367716  98.071  -69.059  51.376  1
367717  98.107  -69.065  51.322  1
367718  98.143  -69.071  51.267  1
367719  98.179  -69.078  51.211  1
367720  98.216  -69.084  51.155  1
367721  98.261  -69.087  51.101  1
367722  98.305  -69.089  51.048  1
367723  98.349  -69.092  50.996  1
367724  98.393  -69.095  50.946  1
367725  98.438  -69.098  50.899  1
367726  98.482  -69.101  50.851  1
367727  98.526  -69.103  50.800  1
367728  98.570  -69.108  50.748  1
367729  98.610  -69.121  50.694  1
367730  98.651  -69.133  50.638  1
367731  98.691  -69.146  50.583  1
367732  98.713  -69.146  50.527  1
367733  98.722  -69.137  50.470  1
367734  98.731  -69.130  50.413  1
367735  98.748  -69.131  50.357  1
367736  98.771  -69.137  50.302  1
367737  98.792  -69.144  50.248  1
367738  98.815  -69.151  50.194  1
367739  98.846  -69.173  50.136  1
367740  98.877  -69.194  50.081  1
367741  98.908  -69.216  50.026  1
367742  98.939  -69.237  49.972  1
367743  98.971  -69.259  49.919  1
367744  99.002  -69.281  49.868  1
367745  99.032  -69.301  49.817  1
367746  99.057  -69.311  49.766  1
367747  99.089  -69.319  49.714  1
367748  99.153  -69.320  49.661  1
367749  99.217  -69.321  49.608  1
367750  99.285  -69.322  49.555  1
367751  99.303  -69.342  49.503  1
367752  99.321  -69.363  49.451  1
367753  99.339  -69.385  49.400  1
367754  99.357  -69.406  49.350  1
367755  99.399  -69.420  49.301  1
367756  99.446  -69.435  49.252  1
367757  99.490  -69.457  49.204  1
367758  99.539  -69.471  49.157  1
367759  99.587  -69.485  49.109  1
367760  99.637  -69.500  49.061  1
367761  99.686  -69.514  49.013  1
367762  99.734  -69.529  48.966  1
367763  99.784  -69.542  48.919  1
367764  99.833  -69.557  48.872  1
367765  99.881  -69.571  48.827  1
367766  99.931  -69.585  48.782  1
367767  99.980  -69.600  48.737  1
367768  100.028  -69.614  48.691  1
367769  100.077  -69.628  48.647  1
367770  100.127  -69.642  48.601  1
367771  100.172  -69.657  48.558  1
367772  100.205  -69.673  48.516  1
367773  100.219  -69.686  48.474  1
367774  100.239  -69.690  48.433  1
367775  100.258  -69.695  48.393  1
367776  100.277  -69.701  48.354  1
367777  100.296  -69.706  48.316  1
367778  100.326  -69.711  48.280  1
367779  100.363  -69.717  48.245  1
367780  100.400  -69.722  48.210  1
367781  100.436  -69.728  48.176  1
367782  100.473  -69.733  48.142  1
367783  100.509  -69.739  48.108  1
367784  100.546  -69.745  48.074  1
367785  100.583  -69.750  48.042  1
367786  100.620  -69.756  48.011  1
367787  100.656  -69.761  47.976  1
367788  100.693  -69.767  47.941  1
367789  100.730  -69.773  47.906  1
367790  100.766  -69.789  47.871  1
367791  100.804  -69.810  47.836  1
367792  100.834  -69.825  47.801  1
367793  100.864  -69.840  47.765  1
367794  100.894  -69.845  47.728  1
367795  100.923  -69.849  47.690  1
367796  100.952  -69.854  47.651  1
367797  100.981  -69.858  47.613  1
367798  101.010  -69.864  47.574  1
367799  101.041  -69.867  47.535  1
367800  101.080  -69.864  47.495  1
367801  101.120  -69.862  47.455  1
367802  101.165  -69.861  47.414  1
367803  101.212  -69.859  47.374  1
367804  101.251  -69.864  47.333  1
367805  101.290  -69.870  47.292  1
367806  101.328  -69.874  47.251  1
367807  101.367  -69.880  47.209  1
367808  101.406  -69.885  47.168  1
367809  101.445  -69.890  47.126  1
367810  101.483  -69.895  47.087  1
367811  101.522  -69.901  47.047  1
367812  101.561  -69.906  47.007  1
367813  101.599  -69.911  46.968  1
368232  91.075  -68.945  54.852  1
368233  91.121  -68.965  54.850  1
368234  91.179  -68.995  54.846  1
368235  91.238  -69.024  54.843  1
368236  91.296  -69.053  54.840  1
368237  91.355  -69.083  54.838  1
368238  91.413  -69.112  54.834  1
368239  91.467  -69.157  54.829  1
368240  91.518  -69.217  54.824  1
368241  91.569  -69.277  54.816  1
368242  91.619  -69.328  54.807  1
368243  91.666  -69.300  54.796  1
368244  91.706  -69.270  54.784  1
368245  91.745  -69.240  54.771  1
368246  91.793  -69.234  54.756  1
368247  91.840  -69.225  54.741  1
368248  91.884  -69.213  54.725  1
368249  91.929  -69.202  54.710  1
368250  91.974  -69.190  54.694  1
368267  92.733  -68.988  54.324  1
368268  92.777  -68.976  54.297  1
368269  92.822  -68.964  54.269  1
368314  94.656  -68.604  53.463  1
368315  94.702  -68.595  53.453  1
368316  94.747  -68.585  53.445  1
368317  94.793  -68.575  53.438  1
368318  94.838  -68.566  53.430  1
368319  94.884  -68.556  53.423  1
368320  94.915  -68.565  53.416  1
368321  94.936  -68.589  53.409  1
368322  94.957  -68.612  53.403  1
368323  94.977  -68.636  53.397  1
368324  94.998  -68.660  53.394  1
368325  95.021  -68.674  53.394  1
368326  95.051  -68.663  53.391  1
368327  95.090  -68.647  53.386  1
368328  95.128  -68.631  53.380  1
368329  95.164  -68.618  53.372  1
368330  95.198  -68.606  53.364  1
368331  95.234  -68.594  53.356  1
368332  95.266  -68.602  53.347  1
368333  95.298  -68.611  53.339  1
368334  95.348  -68.614  53.332  1
368335  95.422  -68.612  53.326  1
368336  95.473  -68.627  53.321  1
368337  95.523  -68.642  53.317  1
368338  95.574  -68.657  53.314  1
368339  95.624  -68.671  53.308  1
368340  95.675  -68.686  53.299  1
368341  95.722  -68.699  53.287  1
368342  95.748  -68.700  53.282  1
368343  95.774  -68.701  53.289  1
368344  95.800  -68.701  53.292  1
368345  95.826  -68.703  53.288  1
368346  95.852  -68.704  53.278  1
368347  95.878  -68.705  53.255  1
368348  95.904  -68.705  53.224  1
368349  95.930  -68.707  53.193  1
368350  95.956  -68.708  53.167  1
368351  95.982  -68.708  53.148  1
368352  96.008  -68.709  53.136  1
368353  96.030  -68.708  53.128  1
368354  96.047  -68.703  53.120  1
368355  96.065  -68.698  53.108  1
368356  96.082  -68.694  53.094  1
368357  96.110  -68.692  53.081  1
368358  96.138  -68.692  53.070  1
368359  96.167  -68.690  53.061  1
368360  96.195  -68.689  53.050  1
368361  96.224  -68.694  53.036  1
368362  96.254  -68.701  53.018  1
368363  96.283  -68.709  52.997  1
368364  96.313  -68.717  52.975  1
368365  96.342  -68.724  52.950  1
368366  96.372  -68.732  52.922  1
368367  96.401  -68.739  52.893  1
368368  96.431  -68.747  52.862  1
368369  96.461  -68.752  52.827  1
368370  96.503  -68.755  52.791  1
368371  96.545  -68.759  52.754  1
368372  96.588  -68.763  52.717  1
368373  96.629  -68.770  52.681  1
368374  96.670  -68.779  52.649  1
368375  96.711  -68.786  52.614  1
368376  96.751  -68.795  52.576  1
368377  96.792  -68.802  52.535  1
368378  96.832  -68.811  52.493  1
368379  96.873  -68.818  52.454  1
368380  96.912  -68.827  52.415  1
368381  96.947  -68.838  52.375  1
368382  96.981  -68.849  52.333  1
368383  97.016  -68.860  52.293  1
368384  97.050  -68.871  52.255  1
368385  97.085  -68.882  52.219  1
368386  97.115  -68.890  52.184  1
368387  97.143  -68.896  52.151  1
368388  97.170  -68.900  52.119  1
368389  97.196  -68.902  52.088  1
368390  97.222  -68.904  52.060  1
368391  97.245  -68.902  52.036  1
368392  97.267  -68.899  52.016  1
368393  97.289  -68.895  51.999  1
368394  97.310  -68.891  51.984  1
368395  97.337  -68.893  51.972  1
368396  97.368  -68.899  51.966  1
368397  97.398  -68.904  51.963  1
368398  97.430  -68.910  51.960  1
368399  97.460  -68.916  51.957  1
368400  97.492  -68.921  51.952  1
368401  97.524  -68.927  51.940  1
368402  97.557  -68.932  51.925  1
368403  97.589  -68.937  51.909  1
368404  97.621  -68.943  51.891  1
368405  97.654  -68.948  51.871  1
368406  97.687  -68.954  51.849  1
368407  97.720  -68.959  51.823  1
368408  97.753  -68.965  51.791  1
368409  97.787  -68.968  51.756  1
368410  97.823  -68.974  51.718  1
368411  97.860  -68.980  51.676  1
368412  97.896  -68.987  51.631  1
368413  97.932  -68.993  51.584  1
368414  97.968  -68.999  51.533  1
368415  98.004  -69.005  51.479  1
368416  98.040  -69.011  51.425  1
368417  98.077  -69.017  51.369  1
368418  98.113  -69.023  51.314  1
368419  98.149  -69.029  51.259  1
368420  98.185  -69.035  51.202  1
368421  98.225  -69.040  51.146  1
368422  98.269  -69.043  51.090  1
368423  98.313  -69.046  51.039  1
368424  98.358  -69.049  50.990  1
368425  98.402  -69.051  50.944  1
368426  98.446  -69.054  50.901  1
368427  98.491  -69.057  50.854  1
368428  98.533  -69.064  50.804  1
368429  98.574  -69.076  50.752  1
368430  98.614  -69.089  50.698  1
368431  98.655  -69.101  50.642  1
368432  98.695  -69.114  50.586  1
368433  98.719  -69.115  50.530  1
368434  98.728  -69.107  50.472  1
368435  98.737  -69.099  50.415  1
368436  98.746  -69.091  50.359  1
368437  98.762  -69.090  50.304  1
368438  98.784  -69.097  50.249  1
368439  98.809  -69.109  50.194  1
368440  98.840  -69.130  50.137  1
368441  98.871  -69.152  50.080  1
368442  98.903  -69.173  50.024  1
368443  98.933  -69.195  49.970  1
368444  98.964  -69.217  49.916  1
368445  98.996  -69.238  49.865  1
368446  99.027  -69.260  49.814  1
368447  99.078  -69.268  49.763  1
368448  99.142  -69.269  49.710  1
368449  99.206  -69.269  49.657  1
368450  99.285  -69.265  49.605  1
368451  99.303  -69.286  49.552  1
368452  99.322  -69.307  49.499  1
368453  99.340  -69.328  49.448  1
368454  99.358  -69.350  49.397  1
368455  99.376  -69.370  49.347  1
368456  99.412  -69.388  49.298  1
368457  99.461  -69.403  49.249  1
368458  99.510  -69.417  49.200  1
368459  99.559  -69.432  49.153  1
368460  99.608  -69.445  49.106  1
368461  99.657  -69.460  49.058  1
368462  99.706  -69.474  49.010  1
368463  99.755  -69.488  48.964  1
368464  99.804  -69.503  48.917  1
368465  99.853  -69.517  48.871  1
368466  99.902  -69.532  48.825  1
368467  99.951  -69.545  48.779  1
368468  100.000  -69.560  48.733  1
368469  100.049  -69.574  48.688  1
368470  100.098  -69.588  48.644  1
368471  100.147  -69.603  48.597  1
368472  100.188  -69.617  48.554  1
368473  100.207  -69.622  48.511  1
368474  100.226  -69.627  48.469  1
368475  100.246  -69.632  48.427  1
368476  100.265  -69.638  48.386  1
368477  100.284  -69.642  48.345  1
368478  100.303  -69.648  48.306  1
368479  100.335  -69.653  48.270  1
368480  100.371  -69.659  48.234  1
368481  100.408  -69.664  48.198  1
368482  100.444  -69.670  48.164  1
368483  100.481  -69.676  48.129  1
368484  100.518  -69.681  48.094  1
368485  100.555  -69.686  48.061  1
368486  100.592  -69.692  48.028  1
368487  100.628  -69.698  47.995  1
368488  100.665  -69.703  47.961  1
368489  100.701  -69.720  47.926  1
368490  100.743  -69.758  47.890  1
368491  100.773  -69.754  47.855  1
368492  100.805  -69.770  47.820  1
368493  100.836  -69.795  47.785  1
368494  100.864  -69.800  47.749  1
368495  100.894  -69.805  47.712  1
368496  100.923  -69.809  47.674  1
368497  100.952  -69.814  47.635  1
368498  100.981  -69.818  47.597  1
368499  101.010  -69.823  47.559  1
368500  101.050  -69.820  47.520  1
368501  101.090  -69.818  47.480  1
368502  101.131  -69.817  47.440  1
368503  101.179  -69.814  47.399  1
368504  101.222  -69.817  47.359  1
368505  101.261  -69.821  47.319  1
368506  101.299  -69.827  47.278  1
368507  101.338  -69.832  47.237  1
368508  101.377  -69.837  47.196  1
368509  101.416  -69.842  47.154  1
368510  101.455  -69.848  47.113  1
368511  101.493  -69.853  47.074  1
368512  101.532  -69.858  47.035  1
368513  101.570  -69.863  46.996  1
368931  91.001  -68.891  54.850  1
368932  91.032  -68.902  54.846  1
368933  91.063  -68.912  54.844  1
368934  91.115  -68.937  54.842  1
368935  91.173  -68.967  54.840  1
368936  91.232  -68.996  54.838  1
368937  91.290  -69.025  54.836  1
368938  91.349  -69.055  54.834  1
368939  91.406  -69.084  54.831  1
368940  91.460  -69.132  54.827  1
368941  91.511  -69.192  54.822  1
368942  91.562  -69.252  54.814  1
368943  91.612  -69.298  54.805  1
368944  91.657  -69.269  54.794  1
368945  91.696  -69.240  54.782  1
368946  91.741  -69.225  54.770  1
368947  91.788  -69.216  54.755  1
368948  91.833  -69.205  54.739  1
368949  91.877  -69.193  54.724  1
368950  91.922  -69.181  54.708  1
368951  91.967  -69.169  54.693  1
368952  92.011  -69.157  54.678  1
368967  92.681  -68.979  54.355  1
368968  92.726  -68.967  54.328  1
368969  92.771  -68.955  54.301  1
368970  92.815  -68.943  54.274  1
368971  92.860  -68.931  54.246  1
368972  92.905  -68.920  54.220  1
368973  92.949  -68.908  54.192  1
368974  92.993  -68.897  54.164  1
368975  93.028  -68.898  54.136  1
368976  93.063  -68.899  54.109  1
368977  93.098  -68.899  54.081  1
368978  93.133  -68.900  54.055  1
369016  94.712  -68.567  53.455  1
369017  94.758  -68.557  53.446  1
369018  94.804  -68.548  53.438  1
369019  94.849  -68.538  53.431  1
369020  94.893  -68.531  53.423  1
369021  94.913  -68.554  53.416  1
369022  94.934  -68.578  53.410  1
369023  94.955  -68.601  53.402  1
369024  94.975  -68.626  53.396  1
369025  94.996  -68.649  53.391  1
369026  95.026  -68.639  53.390  1
369027  95.057  -68.627  53.386  1
369028  95.091  -68.614  53.382  1
369029  95.129  -68.598  53.376  1
369030  95.168  -68.582  53.368  1
369031  95.206  -68.566  53.358  1
369032  95.243  -68.551  53.349  1
369033  95.276  -68.554  53.340  1
369034  95.308  -68.564  53.333  1
369035  95.340  -68.573  53.327  1
369036  95.394  -68.574  53.320  1
369037  95.450  -68.586  53.314  1
369038  95.501  -68.600  53.308  1
369039  95.551  -68.615  53.302  1
369040  95.602  -68.629  53.297  1
369041  95.653  -68.645  53.288  1
369042  95.703  -68.659  53.278  1
369043  95.753  -68.674  53.274  1
369044  95.781  -68.676  53.279  1
369045  95.808  -68.677  53.280  1
369046  95.833  -68.678  53.277  1
369047  95.860  -68.679  53.268  1
369048  95.886  -68.680  53.248  1
369049  95.912  -68.681  53.217  1
369050  95.938  -68.682  53.189  1
369051  95.964  -68.683  53.168  1
369052  95.990  -68.683  53.154  1
369053  96.014  -68.683  53.147  1
369054  96.031  -68.679  53.140  1
369055  96.048  -68.674  53.132  1
369056  96.069  -68.670  53.118  1
369057  96.098  -68.670  53.103  1
369058  96.126  -68.668  53.087  1
369059  96.154  -68.667  53.071  1
369060  96.182  -68.666  53.055  1
369061  96.211  -68.665  53.038  1
369062  96.240  -68.666  53.022  1
369063  96.269  -68.673  53.003  1
369064  96.299  -68.681  52.981  1
369065  96.328  -68.689  52.961  1
369066  96.358  -68.696  52.937  1
369067  96.387  -68.704  52.911  1
369068  96.416  -68.711  52.882  1
369069  96.446  -68.718  52.850  1
369070  96.476  -68.723  52.815  1
369071  96.507  -68.727  52.778  1
369072  96.549  -68.731  52.741  1
369073  96.592  -68.735  52.704  1
369074  96.633  -68.742  52.666  1
369075  96.674  -68.750  52.632  1
369076  96.715  -68.758  52.596  1
369077  96.755  -68.766  52.558  1
369078  96.796  -68.774  52.519  1
369079  96.837  -68.782  52.478  1
369080  96.877  -68.790  52.438  1
369081  96.918  -68.798  52.399  1
369082  96.958  -68.806  52.360  1
369083  96.993  -68.817  52.319  1
369084  97.027  -68.828  52.280  1
369085  97.062  -68.839  52.243  1
369086  97.096  -68.850  52.207  1
369087  97.127  -68.858  52.172  1
369088  97.155  -68.864  52.141  1
369089  97.182  -68.867  52.110  1
369090  97.208  -68.869  52.082  1
369091  97.232  -68.868  52.056  1
369092  97.253  -68.864  52.034  1
369093  97.275  -68.861  52.017  1
369094  97.297  -68.858  52.004  1
369095  97.319  -68.854  51.992  1
369096  97.345  -68.855  51.983  1
369097  97.376  -68.861  51.981  1
369098  97.406  -68.867  51.980  1
369099  97.438  -68.873  51.978  1
369100  97.468  -68.879  51.972  1
369101  97.499  -68.884  51.965  1
369102  97.531  -68.889  51.948  1
369103  97.564  -68.895  51.930  1
369104  97.596  -68.900  51.910  1
369105  97.628  -68.905  51.887  1
369106  97.661  -68.911  51.865  1
369107  97.694  -68.917  51.842  1
369108  97.727  -68.922  51.815  1
369109  97.761  -68.926  51.782  1
369110  97.796  -68.929  51.747  1
369111  97.830  -68.933  51.707  1
369112  97.866  -68.938  51.664  1
369113  97.902  -68.944  51.619  1
369114  97.938  -68.950  51.571  1
369115  97.974  -68.956  51.519  1
369116  98.011  -68.962  51.465  1
369117  98.046  -68.968  51.409  1
369118  98.083  -68.974  51.354  1
369119  98.119  -68.980  51.299  1
369120  98.155  -68.987  51.244  1
369121  98.192  -68.993  51.190  1
369122  98.234  -68.996  51.137  1
369123  98.278  -68.999  51.086  1
369124  98.322  -69.002  51.036  1
369125  98.366  -69.005  50.988  1
369126  98.411  -69.008  50.943  1
369127  98.455  -69.011  50.900  1
369128  98.497  -69.019  50.853  1
369129  98.537  -69.032  50.803  1
369130  98.578  -69.044  50.751  1
369131  98.618  -69.057  50.696  1
369132  98.659  -69.069  50.641  1
369133  98.699  -69.082  50.585  1
369134  98.725  -69.085  50.529  1
369135  98.734  -69.077  50.472  1
369136  98.744  -69.069  50.414  1
369137  98.753  -69.061  50.358  1
369138  98.762  -69.053  50.302  1
369139  98.776  -69.050  50.246  1
369140  98.803  -69.065  50.191  1
369141  98.834  -69.087  50.134  1
369142  98.865  -69.109  50.078  1
369143  98.912  -69.134  50.022  1
369144  98.959  -69.160  49.967  1
369145  99.005  -69.186  49.913  1
369146  99.052  -69.212  49.861  1
369147  99.103  -69.230  49.810  1
369148  99.165  -69.230  49.758  1
369149  99.202  -69.236  49.706  1
369150  99.225  -69.245  49.654  1
369151  99.278  -69.248  49.601  1
369152  99.297  -69.269  49.549  1
369153  99.315  -69.290  49.497  1
369154  99.334  -69.310  49.447  1
369155  99.354  -69.329  49.396  1
369156  99.384  -69.339  49.346  1
369157  99.421  -69.349  49.296  1
369158  99.473  -69.357  49.247  1
369159  99.522  -69.372  49.198  1
369160  99.571  -69.386  49.152  1
369161  99.620  -69.400  49.105  1
369162  99.669  -69.415  49.058  1
369163  99.718  -69.429  49.010  1
369164  99.767  -69.443  48.964  1
369165  99.816  -69.457  48.917  1
369166  99.865  -69.472  48.870  1
369167  99.914  -69.486  48.824  1
369168  99.963  -69.501  48.777  1
369169  100.011  -69.514  48.732  1
369170  100.061  -69.529  48.686  1
369171  100.110  -69.543  48.640  1
369172  100.158  -69.557  48.594  1
369173  100.186  -69.566  48.550  1
369174  100.214  -69.564  48.507  1
369175  100.233  -69.569  48.463  1
369176  100.253  -69.574  48.421  1
369177  100.272  -69.579  48.379  1
369178  100.291  -69.585  48.338  1
369179  100.310  -69.589  48.298  1
369180  100.343  -69.595  48.260  1
369181  100.379  -69.601  48.224  1
369182  100.416  -69.606  48.188  1
369183  100.453  -69.612  48.152  1
369184  100.490  -69.617  48.117  1
369185  100.526  -69.623  48.082  1
369186  100.563  -69.629  48.049  1
369187  100.600  -69.634  48.015  1
369188  100.636  -69.651  47.982  1
369189  100.673  -69.668  47.947  1
369190  100.713  -69.702  47.912  1
369191  100.744  -69.699  47.877  1
369192  100.775  -69.715  47.841  1
369193  100.807  -69.751  47.807  1
369194  100.836  -69.755  47.771  1
369195  100.865  -69.760  47.735  1
369196  100.894  -69.764  47.698  1
369197  100.923  -69.769  47.660  1
369198  100.952  -69.773  47.621  1
369199  100.981  -69.778  47.583  1
369200  101.020  -69.776  47.545  1
369201  101.059  -69.774  47.506  1
369202  101.099  -69.773  47.467  1
369203  101.145  -69.770  47.426  1
369204  101.194  -69.768  47.385  1
369205  101.233  -69.773  47.345  1
369206  101.271  -69.779  47.305  1
369207  101.310  -69.784  47.264  1
369208  101.348  -69.789  47.224  1
369209  101.387  -69.795  47.183  1
369210  101.426  -69.800  47.142  1
369211  101.465  -69.805  47.101  1
369212  101.503  -69.810  47.061  1
369631  90.957  -68.849  54.845  1
369632  90.989  -68.859  54.841  1
369633  91.020  -68.869  54.838  1
369634  91.051  -68.880  54.837  1
369635  91.109  -68.909  54.836  1
369636  91.167  -68.938  54.835  1
369637  91.226  -68.968  54.834  1
369638  91.284  -68.997  54.834  1
369639  91.343  -69.026  54.832  1
369640  91.400  -69.056  54.830  1
369641  91.453  -69.108  54.827  1
369642  91.504  -69.168  54.822  1
369643  91.555  -69.227  54.814  1
369644  91.605  -69.269  54.805  1
369645  91.648  -69.240  54.794  1
369646  91.689  -69.215  54.781  1
369647  91.737  -69.208  54.768  1
369648  91.781  -69.196  54.754  1
369649  91.826  -69.184  54.739  1
369650  91.871  -69.172  54.723  1
369651  91.915  -69.160  54.708  1
369652  91.960  -69.149  54.693  1
369653  92.005  -69.137  54.677  1
369666  92.585  -68.982  54.410  1
369667  92.630  -68.971  54.385  1
369668  92.674  -68.958  54.359  1
369669  92.719  -68.946  54.333  1
369670  92.764  -68.935  54.306  1
369671  92.808  -68.923  54.280  1
369672  92.853  -68.911  54.253  1
369673  92.898  -68.899  54.227  1
369674  92.942  -68.887  54.200  1
369675  92.987  -68.875  54.172  1
369676  93.022  -68.875  54.145  1
369677  93.057  -68.877  54.118  1
369678  93.092  -68.877  54.090  1
369679  93.127  -68.878  54.064  1
369680  93.162  -68.879  54.037  1
369717  94.723  -68.539  53.456  1
369718  94.768  -68.530  53.446  1
369719  94.814  -68.520  53.438  1
369720  94.859  -68.511  53.430  1
369721  94.891  -68.520  53.423  1
369722  94.911  -68.544  53.416  1
369723  94.932  -68.567  53.409  1
369724  94.953  -68.592  53.401  1
369725  94.973  -68.615  53.394  1
369726  95.001  -68.614  53.389  1
369727  95.031  -68.602  53.385  1
369728  95.062  -68.592  53.381  1
369729  95.093  -68.580  53.376  1
369730  95.130  -68.565  53.370  1
369731  95.168  -68.549  53.362  1
369732  95.207  -68.532  53.353  1
369733  95.245  -68.517  53.343  1
369734  95.277  -68.505  53.334  1
369735  95.312  -68.514  53.328  1
369736  95.348  -68.524  53.321  1
369737  95.383  -68.534  53.313  1
369738  95.427  -68.544  53.306  1
369739  95.478  -68.558  53.298  1
369740  95.529  -68.573  53.289  1
369741  95.579  -68.588  53.282  1
369742  95.630  -68.603  53.275  1
369743  95.680  -68.617  53.269  1
369744  95.731  -68.633  53.269  1
369745  95.781  -68.647  53.273  1
369746  95.815  -68.652  53.273  1
369747  95.841  -68.653  53.269  1
369748  95.867  -68.654  53.259  1
369749  95.893  -68.655  53.240  1
369750  95.919  -68.656  53.212  1
369751  95.945  -68.657  53.188  1
369752  95.971  -68.658  53.173  1
369753  95.997  -68.659  53.170  1
369754  96.015  -68.654  53.167  1
369755  96.032  -68.650  53.161  1
369756  96.057  -68.648  53.151  1
369757  96.085  -68.646  53.136  1
369758  96.113  -68.645  53.120  1
369759  96.142  -68.644  53.104  1
369760  96.170  -68.643  53.084  1
369761  96.198  -68.642  53.062  1
369762  96.227  -68.641  53.036  1
369763  96.255  -68.639  53.014  1
369764  96.285  -68.645  52.991  1
369765  96.314  -68.653  52.969  1
369766  96.343  -68.661  52.948  1
369767  96.373  -68.668  52.925  1
369768  96.402  -68.676  52.898  1
369769  96.432  -68.683  52.868  1
369770  96.462  -68.689  52.836  1
369771  96.491  -68.694  52.801  1
369772  96.522  -68.698  52.765  1
369773  96.553  -68.702  52.728  1
369774  96.596  -68.706  52.691  1
369775  96.638  -68.714  52.653  1
369776  96.678  -68.721  52.616  1
369777  96.719  -68.730  52.579  1
369778  96.759  -68.737  52.541  1
369779  96.800  -68.745  52.502  1
369780  96.841  -68.753  52.462  1
369781  96.882  -68.761  52.423  1
369782  96.922  -68.769  52.384  1
369783  96.963  -68.777  52.346  1
369784  97.004  -68.785  52.306  1
369785  97.039  -68.796  52.269  1
369786  97.073  -68.807  52.232  1
369787  97.108  -68.817  52.196  1
369788  97.140  -68.827  52.162  1
369789  97.167  -68.833  52.132  1
369790  97.193  -68.834  52.104  1
369791  97.218  -68.834  52.078  1
369792  97.240  -68.831  52.055  1
369793  97.261  -68.827  52.036  1
369794  97.284  -68.824  52.022  1
369795  97.305  -68.820  52.011  1
369796  97.327  -68.816  52.003  1
369797  97.353  -68.817  51.996  1
369798  97.384  -68.823  51.997  1
369799  97.415  -68.829  51.997  1
369800  97.446  -68.835  51.995  1
369801  97.476  -68.841  51.988  1
369802  97.507  -68.847  51.976  1
369803  97.538  -68.853  51.957  1
369804  97.571  -68.858  51.934  1
369805  97.602  -68.864  51.910  1
369806  97.635  -68.869  51.884  1
369807  97.668  -68.874  51.859  1
369808  97.702  -68.880  51.833  1
369809  97.736  -68.883  51.804  1
369810  97.770  -68.886  51.769  1
369811  97.804  -68.889  51.733  1
369812  97.839  -68.893  51.692  1
369813  97.873  -68.896  51.648  1
369814  97.908  -68.902  51.602  1
369815  97.944  -68.908  51.554  1
369816  97.981  -68.913  51.500  1
369817  98.017  -68.919  51.446  1
369818  98.053  -68.925  51.391  1
369819  98.089  -68.931  51.336  1
369820  98.126  -68.937  51.282  1
369821  98.161  -68.943  51.230  1
369822  98.198  -68.949  51.179  1
369823  98.242  -68.952  51.129  1
369824  98.287  -68.955  51.081  1
369825  98.331  -68.958  51.033  1
369826  98.375  -68.961  50.987  1
369827  98.419  -68.964  50.942  1
369828  98.460  -68.975  50.898  1
369829  98.501  -68.987  50.850  1
369830  98.541  -69.000  50.799  1
369831  98.582  -69.012  50.746  1
369832  98.622  -69.025  50.691  1
369833  98.663  -69.037  50.637  1
369834  98.703  -69.050  50.582  1
369835  98.732  -69.055  50.526  1
369836  98.741  -69.046  50.469  1
369837  98.750  -69.039  50.412  1
369838  98.760  -69.031  50.355  1
369839  98.769  -69.023  50.299  1
369840  98.778  -69.015  50.243  1
369841  98.812  -69.029  50.188  1
369842  98.855  -69.056  50.132  1
369843  98.910  -69.082  50.076  1
369844  98.966  -69.109  50.020  1
369845  99.021  -69.137  49.965  1
369846  99.076  -69.164  49.910  1
369847  99.132  -69.190  49.857  1
369848  99.158  -69.201  49.805  1
369849  99.182  -69.211  49.754  1
369850  99.206  -69.220  49.702  1
369851  99.230  -69.229  49.651  1
369852  99.257  -69.237  49.599  1
369853  99.285  -69.254  49.548  1
369854  99.306  -69.273  49.497  1
369855  99.336  -69.284  49.446  1
369856  99.366  -69.294  49.395  1
369857  99.397  -69.304  49.345  1
369858  99.427  -69.314  49.295  1
369859  99.478  -69.322  49.245  1
369860  99.529  -69.330  49.197  1
369861  99.581  -69.340  49.151  1
369862  99.630  -69.354  49.105  1
369863  99.679  -69.368  49.058  1
369864  99.728  -69.382  49.010  1
369865  99.777  -69.397  48.964  1
369866  99.826  -69.411  48.917  1
369867  99.874  -69.425  48.870  1
369868  99.924  -69.440  48.823  1
369869  99.973  -69.454  48.776  1
369870  100.021  -69.468  48.730  1
369871  100.070  -69.482  48.684  1
369872  100.120  -69.497  48.638  1
369873  100.152  -69.507  48.590  1
369874  100.177  -69.516  48.546  1
369875  100.208  -69.515  48.502  1
369876  100.240  -69.511  48.458  1
369877  100.260  -69.516  48.415  1
369878  100.279  -69.521  48.373  1
369879  100.298  -69.526  48.332  1
369880  100.317  -69.532  48.291  1
369881  100.351  -69.537  48.251  1
369882  100.388  -69.543  48.215  1
369883  100.424  -69.548  48.178  1
369884  100.461  -69.554  48.142  1
369885  100.498  -69.560  48.107  1
369886  100.535  -69.565  48.071  1
369887  100.571  -69.582  48.037  1
369888  100.608  -69.599  48.003  1
369889  100.651  -69.645  47.969  1
369890  100.684  -69.647  47.935  1
369891  100.714  -69.644  47.901  1
369892  100.745  -69.660  47.865  1
369893  100.777  -69.700  47.829  1
369894  100.807  -69.710  47.795  1
369895  100.836  -69.715  47.759  1
369896  100.865  -69.720  47.723  1
369897  100.894  -69.724  47.686  1
369898  100.923  -69.729  47.648  1
369899  100.952  -69.733  47.609  1
369900  100.989  -69.733  47.571  1
369901  101.029  -69.730  47.533  1
369902  101.068  -69.729  47.495  1
369903  101.112  -69.726  47.455  1
369904  101.160  -69.724  47.415  1
369905  101.203  -69.726  47.374  1
369906  101.242  -69.731  47.334  1
369907  101.281  -69.736  47.294  1
369908  101.320  -69.742  47.253  1
369909  101.358  -69.747  47.213  1
369910  101.397  -69.751  47.172  1
369911  101.436  -69.757  47.131  1
370330  90.883  -68.795  54.843  1
370331  90.914  -68.805  54.837  1
370332  90.945  -68.816  54.834  1
370333  90.976  -68.827  54.832  1
370334  91.008  -68.837  54.830  1
370335  91.045  -68.852  54.830  1
370336  91.103  -68.881  54.830  1
370337  91.161  -68.910  54.830  1
370338  91.220  -68.940  54.831  1
370339  91.278  -68.969  54.832  1
370340  91.336  -68.998  54.831  1
370341  91.394  -69.027  54.830  1
370342  91.446  -69.083  54.828  1
370343  91.497  -69.143  54.823  1
370344  91.548  -69.203  54.815  1
370345  91.599  -69.240  54.805  1
370346  91.639  -69.209  54.794  1
370347  91.685  -69.199  54.781  1
370348  91.730  -69.187  54.767  1
370349  91.775  -69.175  54.752  1
370350  91.819  -69.163  54.737  1
370351  91.864  -69.152  54.721  1
370352  91.909  -69.140  54.705  1
370353  91.953  -69.128  54.691  1
370354  91.998  -69.116  54.676  1
370366  92.533  -68.974  54.437  1
370367  92.578  -68.962  54.413  1
370368  92.623  -68.949  54.389  1
370369  92.667  -68.938  54.364  1
370370  92.712  -68.926  54.339  1
370371  92.757  -68.914  54.312  1
370372  92.801  -68.902  54.286  1
370373  92.846  -68.890  54.261  1
370374  92.891  -68.878  54.236  1
370375  92.935  -68.867  54.209  1
370376  92.980  -68.855  54.181  1
370377  93.017  -68.853  54.154  1
370378  93.052  -68.854  54.127  1
370379  93.087  -68.855  54.100  1
370380  93.122  -68.855  54.074  1
370381  93.157  -68.856  54.046  1
370382  93.192  -68.857  54.018  1
370418  94.734  -68.512  53.456  1
370419  94.779  -68.503  53.446  1
370420  94.825  -68.493  53.437  1
370421  94.868  -68.486  53.430  1
370422  94.889  -68.510  53.423  1
370423  94.909  -68.533  53.415  1
370424  94.930  -68.557  53.407  1
370425  94.951  -68.581  53.399  1
370426  94.976  -68.589  53.392  1
370427  95.006  -68.577  53.386  1
370428  95.037  -68.567  53.380  1
370429  95.067  -68.556  53.375  1
370430  95.098  -68.545  53.370  1
370431  95.131  -68.532  53.363  1
370432  95.169  -68.516  53.356  1
370433  95.207  -68.500  53.347  1
370434  95.246  -68.483  53.337  1
370435  95.280  -68.471  53.328  1
370436  95.307  -68.464  53.321  1
370437  95.341  -68.472  53.315  1
370438  95.377  -68.482  53.306  1
370439  95.416  -68.494  53.298  1
370440  95.462  -68.512  53.289  1
370441  95.508  -68.530  53.279  1
370442  95.557  -68.546  53.271  1
370443  95.607  -68.561  53.264  1
370444  95.658  -68.576  53.260  1
370445  95.708  -68.591  53.262  1
370446  95.759  -68.605  53.264  1
370447  95.809  -68.620  53.262  1
370448  95.848  -68.629  53.257  1
370449  95.875  -68.629  53.246  1
370450  95.901  -68.630  53.227  1
370451  95.927  -68.631  53.205  1
370452  95.953  -68.633  53.190  1
370453  95.979  -68.633  53.185  1
370454  95.998  -68.630  53.188  1
370455  96.016  -68.626  53.186  1
370456  96.044  -68.624  53.178  1
370457  96.073  -68.623  53.166  1
370458  96.101  -68.622  53.148  1
370459  96.129  -68.621  53.132  1
370460  96.158  -68.620  53.115  1
370461  96.186  -68.619  53.096  1
370462  96.215  -68.617  53.075  1
370463  96.243  -68.617  53.048  1
370464  96.271  -68.615  53.020  1
370465  96.300  -68.618  52.992  1
370466  96.329  -68.626  52.964  1
370467  96.359  -68.633  52.940  1
370468  96.388  -68.641  52.916  1
370469  96.418  -68.648  52.889  1
370470  96.447  -68.656  52.859  1
370471  96.477  -68.661  52.826  1
370472  96.507  -68.665  52.791  1
370473  96.537  -68.670  52.754  1
370474  96.567  -68.674  52.717  1
370475  96.600  -68.678  52.680  1
370476  96.642  -68.685  52.642  1
370477  96.682  -68.693  52.604  1
370478  96.723  -68.701  52.565  1
370479  96.763  -68.709  52.525  1
370480  96.804  -68.717  52.485  1
370481  96.845  -68.725  52.446  1
370482  96.886  -68.733  52.408  1
370483  96.927  -68.741  52.369  1
370484  96.967  -68.749  52.332  1
370485  97.008  -68.757  52.295  1
370486  97.048  -68.764  52.259  1
370487  97.085  -68.774  52.223  1
370488  97.119  -68.786  52.188  1
370489  97.152  -68.796  52.155  1
370490  97.179  -68.799  52.127  1
370491  97.205  -68.801  52.100  1
370492  97.226  -68.797  52.076  1
370493  97.248  -68.793  52.056  1
370494  97.270  -68.789  52.041  1
370495  97.292  -68.786  52.030  1
370496  97.313  -68.783  52.023  1
370497  97.335  -68.779  52.018  1
370498  97.361  -68.780  52.013  1
370499  97.392  -68.786  52.015  1
370500  97.423  -68.792  52.014  1
370501  97.454  -68.798  52.011  1
370502  97.485  -68.803  52.002  1
370503  97.516  -68.809  51.988  1
370504  97.546  -68.815  51.965  1
370505  97.577  -68.821  51.939  1
370506  97.609  -68.827  51.910  1
370507  97.642  -68.832  51.882  1
370508  97.676  -68.836  51.853  1
370509  97.710  -68.839  51.823  1
370510  97.744  -68.843  51.790  1
370511  97.779  -68.846  51.754  1
370512  97.813  -68.850  51.715  1
370513  97.847  -68.853  51.673  1
370514  97.881  -68.857  51.629  1
370515  97.916  -68.860  51.581  1
370516  97.950  -68.864  51.530  1
370517  97.987  -68.871  51.476  1
370518  98.023  -68.877  51.422  1
370519  98.059  -68.883  51.369  1
370520  98.095  -68.889  51.316  1
370521  98.132  -68.895  51.265  1
370522  98.168  -68.901  51.219  1
370523  98.207  -68.905  51.172  1
370524  98.251  -68.908  51.124  1
370525  98.295  -68.911  51.076  1
370526  98.340  -68.915  51.031  1
370527  98.383  -68.918  50.985  1
370528  98.424  -68.930  50.939  1
370529  98.464  -68.943  50.893  1
370530  98.505  -68.955  50.843  1
370531  98.546  -68.968  50.791  1
370532  98.586  -68.980  50.738  1
370533  98.626  -68.993  50.684  1
370534  98.667  -69.005  50.630  1
370535  98.707  -69.018  50.576  1
370536  98.738  -69.024  50.521  1
370537  98.747  -69.016  50.466  1
370538  98.757  -69.009  50.410  1
370539  98.766  -69.000  50.352  1
370540  98.775  -68.993  50.295  1
370541  98.793  -68.990  50.240  1
370542  98.841  -69.003  50.186  1
370543  98.875  -69.021  50.130  1
370544  98.892  -69.044  50.074  1
370545  98.929  -69.069  50.018  1
370546  98.984  -69.096  49.963  1
370547  99.039  -69.123  49.907  1
370548  99.082  -69.143  49.853  1
370549  99.114  -69.157  49.800  1
370550  99.146  -69.171  49.749  1
370551  99.178  -69.185  49.699  1
370552  99.210  -69.199  49.649  1
370553  99.259  -69.215  49.599  1
370554  99.288  -69.228  49.548  1
370555  99.319  -69.237  49.496  1
370556  99.349  -69.248  49.445  1
370557  99.379  -69.258  49.395  1
370558  99.409  -69.269  49.344  1
370559  99.439  -69.279  49.294  1
370560  99.482  -69.288  49.246  1
370561  99.534  -69.296  49.198  1
370562  99.586  -69.303  49.152  1
370563  99.638  -69.311  49.106  1
370564  99.689  -69.322  49.059  1
370565  99.738  -69.336  49.011  1
370566  99.787  -69.350  48.965  1
370567  99.836  -69.365  48.918  1
370568  99.885  -69.378  48.870  1
370569  99.934  -69.393  48.822  1
370570  99.983  -69.407  48.776  1
370571  100.031  -69.422  48.729  1
370572  100.080  -69.436  48.682  1
370573  100.119  -69.448  48.636  1
370574  100.145  -69.457  48.588  1
370575  100.171  -69.466  48.542  1
370576  100.199  -69.469  48.498  1
370577  100.231  -69.465  48.454  1
370578  100.263  -69.461  48.410  1
370579  100.286  -69.463  48.368  1
370580  100.305  -69.469  48.325  1
370581  100.324  -69.473  48.284  1
370582  100.359  -69.479  48.246  1
370583  100.396  -69.485  48.208  1
370584  100.433  -69.490  48.170  1
370585  100.470  -69.496  48.134  1
370586  100.506  -69.513  48.098  1
370587  100.543  -69.531  48.061  1
370588  100.579  -69.548  48.027  1
370589  100.623  -69.595  47.993  1
370590  100.653  -69.591  47.959  1
370591  100.684  -69.588  47.925  1
370592  100.715  -69.606  47.890  1
370593  100.748  -69.645  47.854  1
370594  100.778  -69.665  47.819  1
370595  100.807  -69.670  47.785  1
370596  100.836  -69.674  47.749  1
370597  100.865  -69.679  47.713  1
370598  100.894  -69.684  47.676  1
370599  100.923  -69.689  47.638  1
370600  100.959  -69.689  47.600  1
370601  100.998  -69.686  47.562  1
370602  101.038  -69.685  47.524  1
370603  101.078  -69.682  47.485  1
370604  101.126  -69.680  47.445  1
370605  101.174  -69.679  47.405  1
370606  101.213  -69.683  47.365  1
370607  101.252  -69.689  47.325  1
370608  101.291  -69.694  47.284  1
370609  101.330  -69.699  47.244  1
370610  101.369  -69.704  47.203  1
371031  90.871  -68.763  54.832  1
371032  90.902  -68.774  54.827  1
371033  90.933  -68.783  54.825  1
371034  90.964  -68.794  54.824  1
371035  90.996  -68.805  54.824  1
371036  91.038  -68.824  54.825  1
371037  91.097  -68.852  54.826  1
371038  91.155  -68.882  54.827  1
371039  91.214  -68.911  54.828  1
371040  91.272  -68.940  54.831  1
371041  91.330  -68.970  54.831  1
371042  91.388  -68.999  54.830  1
371043  91.440  -69.058  54.828  1
371044  91.490  -69.118  54.823  1
371045  91.541  -69.178  54.815  1
371046  91.590  -69.209  54.805  1
371047  91.634  -69.190  54.793  1
371048  91.678  -69.178  54.780  1
371049  91.723  -69.166  54.766  1
371050  91.768  -69.155  54.750  1
371051  91.812  -69.143  54.734  1
371052  91.857  -69.131  54.718  1
371053  91.901  -69.119  54.703  1
371054  91.946  -69.107  54.688  1
371055  91.991  -69.095  54.673  1
371065  92.437  -68.977  54.487  1
371066  92.482  -68.965  54.464  1
371067  92.527  -68.953  54.441  1
371068  92.571  -68.941  54.418  1
371069  92.616  -68.929  54.395  1
371070  92.661  -68.918  54.369  1
371071  92.705  -68.905  54.345  1
371072  92.750  -68.893  54.319  1
371073  92.795  -68.882  54.294  1
371074  92.839  -68.870  54.270  1
371075  92.884  -68.858  54.244  1
371076  92.929  -68.846  54.218  1
371077  92.973  -68.834  54.192  1
371078  93.011  -68.831  54.165  1
371079  93.046  -68.832  54.138  1
371080  93.081  -68.833  54.111  1
371081  93.116  -68.833  54.084  1
371082  93.151  -68.834  54.057  1
371083  93.186  -68.835  54.029  1
371084  93.221  -68.836  54.001  1
371119  94.744  -68.485  53.455  1
371120  94.790  -68.475  53.445  1
371121  94.835  -68.466  53.437  1
371122  94.866  -68.476  53.430  1
371123  94.887  -68.499  53.421  1
371124  94.907  -68.523  53.413  1
371125  94.928  -68.547  53.405  1
371126  94.950  -68.564  53.397  1
371127  94.981  -68.553  53.389  1
371128  95.011  -68.542  53.382  1
371129  95.042  -68.531  53.375  1
371130  95.072  -68.520  53.370  1
371131  95.103  -68.509  53.364  1
371132  95.133  -68.498  53.357  1
371133  95.170  -68.483  53.347  1
371134  95.208  -68.466  53.338  1
371135  95.247  -68.451  53.330  1
371136  95.283  -68.436  53.321  1
371137  95.310  -68.429  53.314  1
371138  95.337  -68.423  53.308  1
371139  95.371  -68.429  53.299  1
371140  95.409  -68.441  53.290  1
371141  95.455  -68.460  53.281  1
371142  95.501  -68.477  53.270  1
371143  95.547  -68.495  53.262  1
371144  95.593  -68.513  53.256  1
371145  95.639  -68.532  53.253  1
371146  95.686  -68.548  53.253  1
371147  95.736  -68.564  53.252  1
371148  95.787  -68.578  53.248  1
371149  95.837  -68.593  53.242  1
371150  95.882  -68.604  53.232  1
371151  95.908  -68.606  53.213  1
371152  95.935  -68.607  53.196  1
371153  95.960  -68.607  53.189  1
371154  95.982  -68.605  53.193  1
371155  96.004  -68.602  53.200  1
371156  96.032  -68.601  53.198  1
371157  96.060  -68.600  53.189  1
371158  96.089  -68.599  53.175  1
371159  96.117  -68.598  53.156  1
371160  96.146  -68.597  53.139  1
371161  96.174  -68.595  53.121  1
371162  96.202  -68.595  53.102  1
371163  96.230  -68.593  53.081  1
371164  96.259  -68.592  53.055  1
371165  96.287  -68.591  53.024  1
371166  96.315  -68.590  52.991  1
371167  96.345  -68.598  52.960  1
371168  96.374  -68.605  52.933  1
371169  96.404  -68.613  52.908  1
371170  96.433  -68.620  52.881  1
371171  96.463  -68.628  52.850  1
371172  96.493  -68.632  52.817  1
371173  96.523  -68.636  52.781  1
371174  96.552  -68.641  52.744  1
371175  96.583  -68.645  52.706  1
371176  96.612  -68.649  52.670  1
371177  96.641  -68.651  52.632  1
371178  96.683  -68.661  52.593  1
371179  96.726  -68.671  52.552  1
371180  96.768  -68.680  52.512  1
371181  96.808  -68.688  52.472  1
371182  96.849  -68.696  52.433  1
371183  96.890  -68.704  52.394  1
371184  96.931  -68.712  52.357  1
371185  96.971  -68.720  52.320  1
371186  97.012  -68.728  52.283  1
371187  97.052  -68.736  52.247  1
371188  97.093  -68.744  52.213  1
371189  97.131  -68.753  52.179  1
371190  97.165  -68.764  52.148  1
371191  97.191  -68.767  52.124  1
371192  97.213  -68.763  52.100  1
371193  97.235  -68.760  52.079  1
371194  97.256  -68.756  52.062  1
371195  97.278  -68.752  52.050  1
371196  97.300  -68.749  52.042  1
371197  97.321  -68.745  52.038  1
371198  97.344  -68.742  52.035  1
371199  97.369  -68.742  52.033  1
371200  97.400  -68.748  52.034  1
371201  97.431  -68.754  52.032  1
371202  97.462  -68.760  52.026  1
371203  97.493  -68.766  52.015  1
371204  97.524  -68.772  51.996  1
371205  97.555  -68.778  51.971  1
371206  97.585  -68.784  51.943  1
371207  97.616  -68.789  51.912  1
371208  97.650  -68.793  51.881  1
371209  97.684  -68.797  51.848  1
371210  97.719  -68.800  51.815  1
371211  97.753  -68.804  51.778  1
371212  97.787  -68.807  51.738  1
371213  97.821  -68.811  51.697  1
371214  97.856  -68.814  51.654  1
371215  97.889  -68.817  51.608  1
371216  97.924  -68.821  51.559  1
371217  97.958  -68.824  51.509  1
371218  97.993  -68.828  51.455  1
371219  98.029  -68.834  51.403  1
371220  98.065  -68.840  51.351  1
371221  98.101  -68.846  51.301  1
371222  98.138  -68.852  51.254  1
371223  98.174  -68.858  51.209  1
371224  98.215  -68.862  51.163  1
371225  98.260  -68.865  51.116  1
371226  98.304  -68.868  51.069  1
371227  98.347  -68.874  51.023  1
371228  98.387  -68.886  50.976  1
371229  98.428  -68.899  50.928  1
371230  98.468  -68.911  50.882  1
371231  98.509  -68.924  50.832  1
371232  98.550  -68.936  50.779  1
371233  98.590  -68.949  50.725  1
371234  98.630  -68.962  50.672  1
371235  98.671  -68.974  50.618  1
371236  98.711  -68.987  50.564  1
371237  98.744  -68.994  50.509  1
371238  98.754  -68.986  50.455  1
371239  98.763  -68.978  50.400  1
371240  98.772  -68.970  50.343  1
371241  98.781  -68.962  50.288  1
371242  98.812  -68.966  50.233  1
371243  98.859  -68.980  50.178  1
371244  98.907  -68.993  50.123  1
371245  98.938  -69.012  50.068  1
371246  98.955  -69.035  50.014  1
371247  98.972  -69.059  49.960  1
371248  98.998  -69.081  49.905  1
371249  99.048  -69.097  49.852  1
371250  99.100  -69.115  49.799  1
371251  99.152  -69.131  49.747  1
371252  99.204  -69.149  49.697  1
371253  99.242  -69.167  49.648  1
371254  99.265  -69.185  49.599  1
371255  99.293  -69.193  49.549  1
371256  99.331  -69.202  49.498  1
371257  99.361  -69.212  49.447  1
371258  99.391  -69.223  49.396  1
371259  99.421  -69.233  49.346  1
371260  99.451  -69.244  49.296  1
371261  99.486  -69.253  49.247  1
371262  99.539  -69.261  49.200  1
371263  99.590  -69.269  49.153  1
371264  99.642  -69.277  49.107  1
371265  99.695  -69.284  49.060  1
371266  99.747  -69.292  49.014  1
371267  99.797  -69.304  48.967  1
371268  99.846  -69.318  48.919  1
371269  99.895  -69.332  48.871  1
371270  99.943  -69.347  48.825  1
371271  99.993  -69.361  48.777  1
371272  100.042  -69.375  48.729  1
371273  100.086  -69.388  48.682  1
371274  100.112  -69.397  48.635  1
371275  100.137  -69.407  48.586  1
371276  100.163  -69.416  48.540  1
371277  100.191  -69.422  48.495  1
371278  100.222  -69.418  48.450  1
371279  100.254  -69.414  48.407  1
371280  100.285  -69.410  48.363  1
371281  100.312  -69.410  48.320  1
371282  100.331  -69.416  48.278  1
371283  100.368  -69.421  48.240  1
371284  100.405  -69.427  48.201  1
371285  100.441  -69.444  48.163  1
371286  100.477  -69.462  48.126  1
371287  100.514  -69.479  48.090  1
371288  100.559  -69.529  48.053  1
371289  100.594  -69.540  48.018  1
371290  100.624  -69.536  47.984  1
371291  100.654  -69.533  47.950  1
371292  100.686  -69.551  47.916  1
371293  100.717  -69.591  47.881  1
371294  100.749  -69.620  47.845  1
371295  100.778  -69.625  47.810  1
371296  100.807  -69.629  47.776  1
371297  100.836  -69.634  47.741  1
371298  100.865  -69.639  47.704  1
371299  100.894  -69.643  47.667  1
371300  100.928  -69.645  47.629  1
371301  100.968  -69.642  47.591  1
371302  101.008  -69.641  47.553  1
371303  101.047  -69.639  47.515  1
371304  101.093  -69.636  47.476  1
371305  101.140  -69.635  47.436  1
371306  101.185  -69.635  47.397  1
371307  101.223  -69.641  47.356  1
371308  101.262  -69.646  47.316  1
371309  101.301  -69.651  47.275  1
371731  90.828  -68.720  54.827  1
371732  90.859  -68.730  54.822  1
371733  90.890  -68.741  54.818  1
371734  90.922  -68.752  54.816  1
371735  90.952  -68.762  54.816  1
371736  90.983  -68.773  54.818  1
371737  91.032  -68.796  54.821  1
371738  91.091  -68.824  54.823  1
371739  91.149  -68.854  54.825  1
371740  91.208  -68.883  54.828  1
371741  91.266  -68.912  54.831  1
371742  91.324  -68.942  54.832  1
371743  91.382  -68.974  54.831  1
371744  91.433  -69.034  54.830  1
371745  91.484  -69.093  54.824  1
371746  91.534  -69.153  54.815  1
371747  91.582  -69.181  54.803  1
371748  91.627  -69.170  54.791  1
371749  91.671  -69.158  54.778  1
371750  91.716  -69.146  54.763  1
371751  91.761  -69.134  54.747  1
371752  91.805  -69.122  54.731  1
371753  91.850  -69.110  54.714  1
371754  91.895  -69.099  54.699  1
371755  91.939  -69.087  54.685  1
371756  91.984  -69.074  54.670  1
371765  92.386  -68.968  54.512  1
371766  92.431  -68.956  54.490  1
371767  92.475  -68.944  54.468  1
371768  92.520  -68.932  54.445  1
371769  92.565  -68.921  54.423  1
371770  92.609  -68.908  54.401  1
371771  92.654  -68.896  54.376  1
371772  92.699  -68.885  54.353  1
371773  92.743  -68.873  54.328  1
371774  92.788  -68.861  54.304  1
371775  92.833  -68.849  54.280  1
371776  92.877  -68.837  54.255  1
371777  92.922  -68.825  54.229  1
371778  92.967  -68.814  54.202  1
371779  93.006  -68.808  54.176  1
371780  93.041  -68.809  54.149  1
371781  93.076  -68.810  54.123  1
371782  93.111  -68.811  54.096  1
371783  93.146  -68.811  54.068  1
371784  93.181  -68.813  54.040  1
371785  93.215  -68.814  54.012  1
371820  94.755  -68.457  53.454  1
371821  94.801  -68.448  53.444  1
371822  94.843  -68.441  53.436  1
371823  94.864  -68.465  53.428  1
371824  94.885  -68.488  53.420  1
371825  94.905  -68.513  53.411  1
371826  94.926  -68.536  53.403  1
371827  94.956  -68.528  53.394  1
371828  94.986  -68.517  53.386  1
371829  95.017  -68.506  53.378  1
371830  95.047  -68.495  53.370  1
371831  95.077  -68.484  53.364  1
371832  95.108  -68.473  53.357  1
371833  95.138  -68.462  53.349  1
371834  95.171  -68.450  53.340  1
371835  95.209  -68.434  53.332  1
371836  95.248  -68.417  53.324  1
371837  95.286  -68.402  53.315  1
371838  95.313  -68.395  53.306  1
371839  95.339  -68.388  53.299  1
371840  95.366  -68.382  53.290  1
371841  95.402  -68.389  53.282  1
371842  95.448  -68.407  53.273  1
371843  95.493  -68.425  53.263  1
371844  95.540  -68.443  53.256  1
371845  95.586  -68.461  53.250  1
371846  95.631  -68.479  53.245  1
371847  95.678  -68.497  53.241  1
371848  95.724  -68.515  53.237  1
371849  95.769  -68.532  53.231  1
371850  95.816  -68.551  53.224  1
371851  95.865  -68.566  53.215  1
371852  95.916  -68.581  53.198  1
371853  95.942  -68.582  53.185  1
371854  95.965  -68.581  53.183  1
371855  95.991  -68.579  53.191  1
371856  96.020  -68.578  53.201  1
371857  96.048  -68.577  53.200  1
371858  96.076  -68.576  53.191  1
371859  96.105  -68.575  53.177  1
371860  96.133  -68.573  53.158  1
371861  96.161  -68.573  53.139  1
371862  96.189  -68.571  53.121  1
371863  96.218  -68.570  53.102  1
371864  96.246  -68.569  53.082  1
371865  96.274  -68.568  53.056  1
371866  96.303  -68.567  53.023  1
371867  96.331  -68.566  52.990  1
371868  96.360  -68.570  52.957  1
371869  96.390  -68.577  52.928  1
371870  96.419  -68.585  52.902  1
371871  96.449  -68.592  52.873  1
371872  96.478  -68.599  52.842  1
371873  96.508  -68.603  52.808  1
371874  96.538  -68.607  52.771  1
371875  96.568  -68.612  52.733  1
371876  96.598  -68.617  52.695  1
371877  96.624  -68.620  52.660  1
371878  96.650  -68.622  52.621  1
371879  96.678  -68.620  52.581  1
371880  96.712  -68.622  52.541  1
371881  96.754  -68.633  52.500  1
371882  96.797  -68.642  52.461  1
371883  96.840  -68.653  52.421  1
371884  96.883  -68.664  52.383  1
371885  96.926  -68.673  52.346  1
371886  96.969  -68.684  52.309  1
371887  97.012  -68.695  52.271  1
371888  97.054  -68.705  52.237  1
371889  97.097  -68.715  52.203  1
371890  97.138  -68.723  52.172  1
371891  97.177  -68.732  52.144  1
371892  97.199  -68.730  52.123  1
371893  97.221  -68.726  52.102  1
371894  97.243  -68.722  52.084  1
371895  97.264  -68.718  52.070  1
371896  97.286  -68.715  52.061  1
371897  97.308  -68.711  52.056  1
371898  97.330  -68.708  52.054  1
371899  97.352  -68.704  52.054  1
371900  97.377  -68.705  52.053  1
371901  97.408  -68.711  52.053  1
371902  97.439  -68.717  52.049  1
371903  97.470  -68.723  52.040  1
371904  97.501  -68.728  52.026  1
371905  97.532  -68.734  52.005  1
371906  97.563  -68.740  51.976  1
371907  97.594  -68.746  51.945  1
371908  97.626  -68.752  51.913  1
371909  97.659  -68.755  51.879  1
371910  97.693  -68.758  51.843  1
371911  97.727  -68.761  51.807  1
371912  97.761  -68.764  51.767  1
371913  97.796  -68.767  51.725  1
371914  97.830  -68.770  51.681  1
371915  97.864  -68.774  51.636  1
371916  97.898  -68.777  51.589  1
371917  97.932  -68.781  51.540  1
371918  97.967  -68.784  51.490  1
371919  98.001  -68.788  51.438  1
371920  98.035  -68.792  51.387  1
371921  98.071  -68.797  51.337  1
371922  98.107  -68.803  51.289  1
371923  98.144  -68.809  51.243  1
371924  98.180  -68.815  51.199  1
371925  98.224  -68.818  51.153  1
371926  98.268  -68.821  51.106  1
371927  98.310  -68.830  51.059  1
371928  98.351  -68.842  51.012  1
371929  98.391  -68.855  50.965  1
371930  98.432  -68.867  50.917  1
371931  98.473  -68.880  50.870  1
371932  98.513  -68.892  50.819  1
371933  98.554  -68.905  50.766  1
371934  98.594  -68.917  50.712  1
371935  98.635  -68.930  50.659  1
371936  98.675  -68.942  50.605  1
371937  98.715  -68.955  50.551  1
371938  98.751  -68.964  50.497  1
371939  98.760  -68.955  50.442  1
371940  98.769  -68.948  50.388  1
371941  98.779  -68.940  50.333  1
371942  98.788  -68.932  50.279  1
371943  98.831  -68.943  50.224  1
371944  98.878  -68.956  50.169  1
371945  98.925  -68.970  50.114  1
371946  98.973  -68.983  50.060  1
371947  99.001  -69.002  50.007  1
371948  99.017  -69.026  49.954  1
371949  99.044  -69.047  49.901  1
371950  99.096  -69.065  49.848  1
371951  99.148  -69.082  49.796  1
371952  99.200  -69.099  49.745  1
371953  99.226  -69.118  49.695  1
371954  99.249  -69.137  49.648  1
371955  99.269  -69.153  49.600  1
371956  99.290  -69.162  49.551  1
371957  99.338  -69.168  49.500  1
371958  99.373  -69.177  49.449  1
371959  99.404  -69.187  49.398  1
371960  99.434  -69.197  49.349  1
371961  99.464  -69.208  49.300  1
371962  99.494  -69.219  49.250  1
371963  99.543  -69.226  49.202  1
371964  99.595  -69.234  49.155  1
371965  99.647  -69.242  49.109  1
371966  99.699  -69.250  49.062  1
371967  99.751  -69.258  49.016  1
371968  99.803  -69.266  48.969  1
371969  99.855  -69.273  48.920  1
371970  99.905  -69.286  48.873  1
371971  99.954  -69.300  48.827  1
371972  100.003  -69.315  48.779  1
371973  100.052  -69.328  48.730  1
371974  100.079  -69.338  48.682  1
371975  100.105  -69.347  48.635  1
371976  100.130  -69.357  48.586  1
371977  100.155  -69.366  48.539  1
371978  100.182  -69.375  48.493  1
371979  100.213  -69.371  48.447  1
371980  100.245  -69.368  48.403  1
371981  100.276  -69.364  48.358  1
371982  100.308  -69.360  48.314  1
371983  100.339  -69.358  48.273  1
371984  100.376  -69.375  48.234  1
371985  100.412  -69.393  48.194  1
371986  100.449  -69.410  48.156  1
371987  100.485  -69.427  48.119  1
371988  100.533  -69.488  48.082  1
371989  100.564  -69.485  48.045  1
371990  100.594  -69.481  48.010  1
371991  100.624  -69.478  47.976  1
371992  100.655  -69.497  47.943  1
371993  100.688  -69.535  47.908  1
371994  100.720  -69.575  47.874  1
371995  100.749  -69.580  47.837  1
371996  100.778  -69.585  47.802  1
371997  100.807  -69.589  47.768  1
371998  100.836  -69.594  47.732  1
371999  100.865  -69.598  47.696  1
372000  100.898  -69.601  47.659  1
372001  100.937  -69.598  47.621  1
372002  100.977  -69.597  47.583  1
372003  101.017  -69.595  47.545  1
372004  101.058  -69.592  47.507  1
372005  101.107  -69.591  47.468  1
372006  101.155  -69.588  47.429  1
372007  101.195  -69.593  47.390  1
372008  101.234  -69.598  47.348  1
372432  90.816  -68.687  54.815  1
372433  90.847  -68.698  54.812  1
372434  90.878  -68.708  54.810  1
372435  90.909  -68.719  54.809  1
372436  90.941  -68.730  54.810  1
372437  90.971  -68.740  54.812  1
372438  91.026  -68.767  54.817  1
372439  91.085  -68.796  54.820  1
372440  91.143  -68.826  54.824  1
372441  91.202  -68.855  54.827  1
372442  91.260  -68.884  54.832  1
372443  91.318  -68.914  54.834  1
372444  91.375  -68.949  54.834  1
372445  91.426  -69.009  54.832  1
372446  91.476  -69.068  54.825  1
372447  91.527  -69.128  54.815  1
372448  91.576  -69.148  54.802  1
372449  91.620  -69.143  54.789  1
372450  91.665  -69.137  54.775  1
372451  91.709  -69.125  54.759  1
372452  91.754  -69.113  54.743  1
372453  91.799  -69.102  54.727  1
372454  91.843  -69.090  54.710  1
372455  91.888  -69.078  54.695  1
372456  91.933  -69.066  54.681  1
372457  91.977  -69.054  54.667  1
372464  92.290  -68.971  54.556  1
372465  92.335  -68.959  54.536  1
372466  92.379  -68.947  54.515  1
372467  92.424  -68.935  54.493  1
372468  92.469  -68.924  54.472  1
372469  92.513  -68.911  54.451  1
372470  92.558  -68.899  54.429  1
372471  92.602  -68.888  54.407  1
372472  92.647  -68.876  54.384  1
372473  92.692  -68.864  54.360  1
372474  92.736  -68.852  54.337  1
372475  92.781  -68.840  54.314  1
372476  92.826  -68.828  54.291  1
372477  92.870  -68.817  54.267  1
372478  92.915  -68.805  54.241  1
372479  92.959  -68.793  54.214  1
372480  93.000  -68.786  54.188  1
372481  93.035  -68.787  54.161  1
372482  93.070  -68.788  54.135  1
372483  93.105  -68.789  54.108  1
372484  93.140  -68.789  54.080  1
372485  93.175  -68.790  54.051  1
372486  93.210  -68.791  54.023  1
372487  93.245  -68.792  53.994  1
372521  94.765  -68.430  53.453  1
372522  94.811  -68.420  53.443  1
372523  94.841  -68.431  53.435  1
372524  94.862  -68.454  53.427  1
372525  94.883  -68.478  53.418  1
372526  94.903  -68.502  53.409  1
372527  94.930  -68.503  53.400  1
372528  94.961  -68.492  53.391  1
372529  94.991  -68.481  53.382  1
372530  95.022  -68.470  53.374  1
372531  95.052  -68.459  53.365  1
372532  95.083  -68.448  53.358  1
372533  95.113  -68.437  53.351  1
372534  95.144  -68.426  53.343  1
372535  95.174  -68.415  53.335  1
372536  95.210  -68.401  53.327  1
372537  95.249  -68.385  53.318  1
372538  95.287  -68.369  53.309  1
372539  95.315  -68.360  53.300  1
372540  95.342  -68.354  53.291  1
372541  95.369  -68.347  53.282  1
372542  95.398  -68.346  53.273  1
372543  95.440  -68.357  53.265  1
372544  95.485  -68.375  53.257  1
372545  95.532  -68.393  53.250  1
372546  95.578  -68.410  53.245  1
372547  95.623  -68.429  53.239  1
372548  95.670  -68.446  53.233  1
372549  95.715  -68.464  53.225  1
372550  95.762  -68.482  53.217  1
372551  95.808  -68.500  53.208  1
372552  95.854  -68.517  53.197  1
372553  95.900  -68.535  53.183  1
372554  95.946  -68.553  53.174  1
372555  95.979  -68.556  53.173  1
372556  96.007  -68.555  53.180  1
372557  96.036  -68.554  53.189  1
372558  96.064  -68.553  53.189  1
372559  96.092  -68.551  53.183  1
372560  96.120  -68.551  53.170  1
372561  96.149  -68.549  53.152  1
372562  96.177  -68.548  53.133  1
372563  96.205  -68.547  53.114  1
372564  96.234  -68.546  53.094  1
372565  96.262  -68.545  53.073  1
372566  96.291  -68.544  53.048  1
372567  96.319  -68.542  53.016  1
372568  96.347  -68.542  52.982  1
372569  96.376  -68.542  52.948  1
372570  96.405  -68.549  52.921  1
372571  96.435  -68.557  52.895  1
372572  96.464  -68.564  52.866  1
372573  96.494  -68.570  52.835  1
372574  96.524  -68.574  52.799  1
372575  96.554  -68.579  52.761  1
372576  96.584  -68.583  52.723  1
372577  96.610  -68.586  52.685  1
372578  96.636  -68.589  52.648  1
372579  96.661  -68.592  52.609  1
372580  96.689  -68.592  52.570  1
372581  96.717  -68.590  52.530  1
372582  96.746  -68.589  52.490  1
372583  96.783  -68.594  52.451  1
372584  96.825  -68.604  52.413  1
372585  96.868  -68.614  52.375  1
372586  96.911  -68.625  52.338  1
372587  96.954  -68.635  52.301  1
372588  96.997  -68.645  52.263  1
372589  97.040  -68.656  52.229  1
372590  97.085  -68.667  52.197  1
372591  97.134  -68.683  52.168  1
372592  97.183  -68.698  52.144  1
372593  97.207  -68.693  52.125  1
372594  97.229  -68.689  52.106  1
372595  97.251  -68.685  52.090  1
372596  97.273  -68.681  52.079  1
372597  97.295  -68.677  52.073  1
372598  97.316  -68.674  52.072  1
372599  97.338  -68.670  52.073  1
372600  97.360  -68.667  52.074  1
372601  97.385  -68.667  52.073  1
372602  97.416  -68.673  52.071  1
372603  97.447  -68.679  52.064  1
372604  97.478  -68.685  52.052  1
372605  97.509  -68.691  52.036  1
372606  97.540  -68.697  52.013  1
372607  97.572  -68.702  51.981  1
372608  97.604  -68.708  51.946  1
372609  97.636  -68.714  51.911  1
372610  97.669  -68.717  51.875  1
372611  97.703  -68.720  51.837  1
372612  97.736  -68.723  51.798  1
372613  97.770  -68.725  51.758  1
372614  97.804  -68.728  51.714  1
372615  97.839  -68.731  51.668  1
372616  97.872  -68.735  51.620  1
372617  97.907  -68.738  51.572  1
372618  97.941  -68.741  51.523  1
372619  97.975  -68.745  51.475  1
372620  98.009  -68.749  51.425  1
372621  98.044  -68.752  51.375  1
372622  98.078  -68.755  51.327  1
372623  98.114  -68.761  51.279  1
372624  98.150  -68.767  51.232  1
372625  98.189  -68.772  51.188  1
372626  98.233  -68.775  51.143  1
372627  98.274  -68.785  51.094  1
372628  98.314  -68.798  51.048  1
372629  98.355  -68.810  50.999  1
372630  98.395  -68.823  50.951  1
372631  98.436  -68.835  50.904  1
372632  98.477  -68.848  50.855  1
372633  98.517  -68.860  50.804  1
372634  98.558  -68.873  50.751  1
372635  98.598  -68.885  50.698  1
372636  98.639  -68.898  50.645  1
372637  98.679  -68.910  50.591  1
372638  98.719  -68.923  50.537  1
372639  98.757  -68.933  50.483  1
372640  98.767  -68.925  50.429  1
372641  98.776  -68.918  50.376  1
372642  98.785  -68.909  50.322  1
372643  98.803  -68.907  50.267  1
372644  98.850  -68.920  50.212  1
372645  98.897  -68.933  50.157  1
372646  98.944  -68.946  50.103  1
372647  98.991  -68.959  50.051  1
372648  99.039  -68.973  49.998  1
372649  99.064  -68.993  49.946  1
372650  99.091  -69.015  49.894  1
372651  99.144  -69.032  49.843  1
372652  99.187  -69.049  49.792  1
372653  99.210  -69.068  49.743  1
372654  99.232  -69.087  49.695  1
372655  99.255  -69.107  49.649  1
372656  99.274  -69.120  49.602  1
372657  99.290  -69.131  49.553  1
372658  99.335  -69.137  49.503  1
372659  99.382  -69.143  49.452  1
372660  99.416  -69.152  49.402  1
372661  99.446  -69.162  49.353  1
372662  99.476  -69.172  49.304  1
372663  99.506  -69.183  49.255  1
372664  99.547  -69.192  49.204  1
372665  99.599  -69.200  49.157  1
372666  99.651  -69.208  49.111  1
372667  99.703  -69.215  49.065  1
372668  99.755  -69.223  49.018  1
372669  99.807  -69.231  48.971  1
372670  99.859  -69.239  48.923  1
372671  99.911  -69.247  48.875  1
372672  99.964  -69.254  48.829  1
372673  100.012  -69.268  48.781  1
372674  100.046  -69.279  48.733  1
372675  100.071  -69.288  48.684  1
372676  100.097  -69.297  48.636  1
372677  100.123  -69.306  48.587  1
372678  100.148  -69.316  48.539  1
372679  100.174  -69.325  48.492  1
372680  100.204  -69.325  48.446  1
372681  100.236  -69.321  48.400  1
372682  100.267  -69.317  48.355  1
372683  100.305  -69.316  48.310  1
372684  100.347  -69.324  48.268  1
372685  100.384  -69.341  48.228  1
372686  100.420  -69.358  48.188  1
372687  100.467  -69.413  48.150  1
372688  100.503  -69.432  48.112  1
372689  100.534  -69.429  48.076  1
372690  100.564  -69.425  48.038  1
372691  100.595  -69.422  48.004  1
372692  100.626  -69.442  47.970  1
372693  100.658  -69.481  47.935  1
372694  100.690  -69.520  47.901  1
372695  100.720  -69.535  47.865  1
372696  100.749  -69.540  47.830  1
372697  100.778  -69.544  47.794  1
372698  100.808  -69.549  47.760  1
372699  100.836  -69.554  47.725  1
372700  100.867  -69.557  47.688  1
372701  100.907  -69.555  47.652  1
372702  100.947  -69.553  47.614  1
372703  100.986  -69.551  47.576  1
372704  101.026  -69.548  47.539  1
372705  101.073  -69.547  47.501  1
372706  101.121  -69.544  47.462  1
372707  101.166  -69.544  47.422  1
373132  90.773  -68.645  54.809  1
373133  90.804  -68.655  54.804  1
373134  90.835  -68.666  54.802  1
373135  90.866  -68.676  54.801  1
373136  90.897  -68.687  54.802  1
373137  90.929  -68.697  54.804  1
373138  90.962  -68.710  54.807  1
373139  91.020  -68.739  54.812  1
373140  91.079  -68.768  54.818  1
373141  91.137  -68.798  54.823  1
373142  91.195  -68.827  54.828  1
373143  91.254  -68.856  54.833  1
373144  91.312  -68.885  54.837  1
373145  91.368  -68.924  54.838  1
373146  91.419  -68.984  54.835  1
373147  91.469  -69.044  54.826  1
373148  91.520  -69.092  54.814  1
373149  91.570  -69.090  54.801  1
373150  91.613  -69.090  54.786  1
373151  91.658  -69.086  54.771  1
373152  91.702  -69.080  54.754  1
373153  91.747  -69.074  54.738  1
373154  91.792  -69.068  54.722  1
373155  91.837  -69.063  54.705  1
373156  91.881  -69.057  54.690  1
373157  91.926  -69.046  54.677  1
373158  91.970  -69.034  54.663  1
373159  92.015  -69.021  54.650  1
373164  92.238  -68.962  54.574  1
373165  92.283  -68.950  54.556  1
373166  92.328  -68.939  54.537  1
373167  92.372  -68.927  54.518  1
373168  92.417  -68.915  54.497  1
373169  92.461  -68.903  54.477  1
373170  92.506  -68.891  54.456  1
373171  92.551  -68.879  54.435  1
373172  92.595  -68.868  54.415  1
373173  92.640  -68.855  54.392  1
373174  92.685  -68.843  54.370  1
373175  92.729  -68.832  54.348  1
373176  92.774  -68.820  54.326  1
373177  92.819  -68.808  54.303  1
373178  92.863  -68.796  54.279  1
373179  92.908  -68.784  54.253  1
373180  92.953  -68.772  54.227  1
373181  92.995  -68.764  54.200  1
373182  93.029  -68.764  54.174  1
373183  93.065  -68.765  54.147  1
373184  93.099  -68.766  54.120  1
373185  93.135  -68.767  54.092  1
373186  93.169  -68.768  54.064  1
373187  93.205  -68.769  54.034  1
373188  93.239  -68.770  54.005  1
373189  93.274  -68.770  53.977  1
373222  94.776  -68.402  53.453  1
373223  94.819  -68.397  53.443  1
373224  94.839  -68.420  53.434  1
373225  94.860  -68.444  53.425  1
373226  94.881  -68.468  53.417  1
373227  94.905  -68.478  53.407  1
373228  94.935  -68.467  53.397  1
373229  94.966  -68.456  53.388  1
373230  94.996  -68.445  53.378  1
373231  95.027  -68.434  53.369  1
373232  95.057  -68.423  53.360  1
373233  95.088  -68.412  53.353  1
373234  95.118  -68.401  53.346  1
373235  95.149  -68.390  53.340  1
373236  95.180  -68.379  53.332  1
373237  95.211  -68.368  53.323  1
373238  95.249  -68.352  53.314  1
373239  95.288  -68.335  53.304  1
373240  95.318  -68.326  53.295  1
373241  95.345  -68.319  53.285  1
373242  95.372  -68.313  53.275  1
373243  95.402  -68.318  53.266  1
373244  95.443  -68.329  53.259  1
373245  95.483  -68.340  53.252  1
373246  95.524  -68.350  53.245  1
373247  95.568  -68.365  53.240  1
373248  95.614  -68.383  53.234  1
373249  95.660  -68.401  53.226  1
373250  95.706  -68.419  53.216  1
373251  95.752  -68.436  53.205  1
373252  95.798  -68.454  53.193  1
373253  95.844  -68.472  53.182  1
373254  95.890  -68.490  53.171  1
373255  95.936  -68.507  53.165  1
373256  95.974  -68.515  53.164  1
373257  96.011  -68.520  53.168  1
373258  96.047  -68.526  53.174  1
373259  96.080  -68.529  53.175  1
373260  96.108  -68.527  53.171  1
373261  96.136  -68.526  53.161  1
373262  96.165  -68.525  53.146  1
373263  96.193  -68.524  53.127  1
373264  96.222  -68.523  53.107  1
373265  96.250  -68.522  53.086  1
373266  96.278  -68.520  53.063  1
373267  96.306  -68.520  53.037  1
373268  96.335  -68.518  53.006  1
373269  96.363  -68.517  52.972  1
373270  96.391  -68.516  52.939  1
373271  96.420  -68.521  52.912  1
373272  96.450  -68.529  52.885  1
373273  96.479  -68.536  52.857  1
373274  96.510  -68.542  52.826  1
373275  96.539  -68.546  52.791  1
373276  96.569  -68.550  52.752  1
373277  96.596  -68.554  52.713  1
373278  96.621  -68.557  52.674  1
373279  96.647  -68.560  52.636  1
373280  96.673  -68.563  52.598  1
373281  96.699  -68.564  52.559  1
373282  96.728  -68.562  52.520  1
373283  96.756  -68.560  52.481  1
373284  96.785  -68.558  52.443  1
373285  96.813  -68.557  52.407  1
373286  96.854  -68.565  52.370  1
373287  96.896  -68.576  52.332  1
373288  96.942  -68.588  52.295  1
373289  96.991  -68.603  52.256  1
373290  97.040  -68.618  52.223  1
373291  97.089  -68.633  52.192  1
373292  97.138  -68.648  52.166  1
373293  97.187  -68.664  52.144  1
373294  97.214  -68.661  52.127  1
373295  97.236  -68.655  52.111  1
373296  97.259  -68.649  52.099  1
373297  97.281  -68.644  52.092  1
373298  97.303  -68.640  52.090  1
373299  97.324  -68.636  52.091  1
373300  97.346  -68.633  52.094  1
373301  97.368  -68.629  52.096  1
373302  97.393  -68.629  52.094  1
373303  97.424  -68.636  52.088  1
373304  97.455  -68.642  52.077  1
373305  97.486  -68.647  52.061  1
373306  97.518  -68.653  52.040  1
373307  97.549  -68.658  52.012  1
373308  97.582  -68.664  51.978  1
373309  97.613  -68.670  51.942  1
373310  97.646  -68.675  51.906  1
373311  97.678  -68.680  51.868  1
373312  97.712  -68.683  51.830  1
373313  97.746  -68.685  51.792  1
373314  97.780  -68.687  51.750  1
373315  97.813  -68.690  51.706  1
373316  97.847  -68.692  51.658  1
373317  97.881  -68.695  51.610  1
373318  97.915  -68.698  51.562  1
373319  97.949  -68.701  51.515  1
373320  97.984  -68.705  51.467  1
373321  98.018  -68.708  51.417  1
373322  98.052  -68.712  51.368  1
373323  98.087  -68.716  51.319  1
373324  98.121  -68.719  51.271  1
373325  98.156  -68.724  51.223  1
373326  98.197  -68.728  51.177  1
373327  98.237  -68.741  51.130  1
373328  98.278  -68.753  51.080  1
373329  98.318  -68.766  51.032  1
373330  98.359  -68.778  50.983  1
373331  98.400  -68.791  50.935  1
373332  98.440  -68.803  50.887  1
373333  98.481  -68.816  50.839  1
373334  98.521  -68.828  50.786  1
373335  98.562  -68.841  50.733  1
373336  98.602  -68.853  50.681  1
373337  98.643  -68.866  50.629  1
373338  98.683  -68.878  50.576  1
373339  98.723  -68.891  50.523  1
373340  98.764  -68.903  50.470  1
373341  98.773  -68.895  50.417  1
373342  98.782  -68.887  50.363  1
373343  98.791  -68.879  50.309  1
373344  98.822  -68.883  50.255  1
373345  98.869  -68.896  50.202  1
373346  98.916  -68.910  50.148  1
373347  98.963  -68.923  50.095  1
373348  99.010  -68.936  50.044  1
373349  99.057  -68.949  49.992  1
373350  99.104  -68.963  49.940  1
373351  99.140  -68.982  49.890  1
373352  99.170  -69.000  49.841  1
373353  99.193  -69.020  49.790  1
373354  99.216  -69.039  49.740  1
373355  99.239  -69.058  49.692  1
373356  99.262  -69.077  49.647  1
373357  99.278  -69.087  49.602  1
373358  99.295  -69.098  49.555  1
373359  99.331  -69.106  49.506  1
373360  99.379  -69.111  49.456  1
373361  99.427  -69.117  49.407  1
373362  99.458  -69.127  49.357  1
373363  99.488  -69.137  49.307  1
373364  99.518  -69.147  49.258  1
373365  99.551  -69.157  49.209  1
373366  99.604  -69.165  49.162  1
373367  99.655  -69.173  49.115  1
373368  99.708  -69.181  49.069  1
373369  99.760  -69.189  49.022  1
373370  99.811  -69.197  48.975  1
373371  99.864  -69.204  48.927  1
373372  99.916  -69.212  48.879  1
373373  99.968  -69.220  48.832  1
373374  100.017  -69.226  48.785  1
373375  100.043  -69.232  48.736  1
373376  100.065  -69.239  48.687  1
373377  100.089  -69.247  48.638  1
373378  100.115  -69.256  48.589  1
373379  100.141  -69.266  48.540  1
373380  100.167  -69.275  48.491  1
373381  100.195  -69.278  48.444  1
373382  100.227  -69.274  48.398  1
373383  100.270  -69.275  48.351  1
373384  100.316  -69.278  48.306  1
373385  100.355  -69.289  48.263  1
373386  100.392  -69.306  48.223  1
373387  100.443  -69.380  48.183  1
373388  100.474  -69.377  48.144  1
373389  100.504  -69.374  48.107  1
373390  100.534  -69.370  48.070  1
373391  100.565  -69.367  48.032  1
373392  100.596  -69.388  47.998  1
373393  100.628  -69.426  47.963  1
373394  100.661  -69.466  47.928  1
373395  100.691  -69.490  47.894  1
373396  100.720  -69.494  47.858  1
373397  100.749  -69.499  47.823  1
373398  100.778  -69.504  47.787  1
373399  100.808  -69.509  47.753  1
373400  100.837  -69.513  47.718  1
373401  100.877  -69.511  47.682  1
373402  100.916  -69.509  47.645  1
373403  100.956  -69.507  47.608  1
373404  100.996  -69.504  47.570  1
373405  101.039  -69.503  47.533  1
373406  101.088  -69.501  47.495  1
373833  90.760  -68.612  54.799  1
373834  90.792  -68.623  54.795  1
373835  90.823  -68.633  54.793  1
373836  90.854  -68.644  54.793  1
373837  90.885  -68.654  54.795  1
373838  90.917  -68.665  54.798  1
373839  90.956  -68.681  54.804  1
373840  91.014  -68.711  54.810  1
373841  91.073  -68.740  54.816  1
373842  91.131  -68.769  54.822  1
373843  91.189  -68.799  54.830  1
373844  91.248  -68.828  54.837  1
373845  91.306  -68.857  54.842  1
373846  91.361  -68.899  54.843  1
373847  91.412  -68.959  54.838  1
373848  91.462  -69.019  54.826  1
373849  91.513  -69.034  54.812  1
373850  91.563  -69.033  54.797  1
373851  91.608  -69.032  54.782  1
373852  91.651  -69.033  54.766  1
373853  91.695  -69.028  54.749  1
373854  91.740  -69.023  54.732  1
373855  91.785  -69.017  54.715  1
373856  91.829  -69.012  54.700  1
373857  91.874  -69.005  54.685  1
373858  91.919  -69.000  54.672  1
373859  91.963  -68.994  54.659  1
373860  92.008  -68.989  54.646  1
373864  92.187  -68.953  54.588  1
373865  92.231  -68.942  54.573  1
373866  92.276  -68.930  54.556  1
373867  92.321  -68.918  54.539  1
373868  92.365  -68.906  54.520  1
373869  92.410  -68.894  54.502  1
373870  92.455  -68.882  54.481  1
373871  92.499  -68.871  54.461  1
373872  92.544  -68.858  54.442  1
373873  92.589  -68.846  54.422  1
373874  92.633  -68.835  54.401  1
373875  92.678  -68.823  54.380  1
373876  92.723  -68.811  54.359  1
373877  92.767  -68.799  54.338  1
373878  92.812  -68.787  54.316  1
373879  92.857  -68.775  54.292  1
373880  92.901  -68.764  54.267  1
373881  92.946  -68.752  54.241  1
373882  92.989  -68.742  54.214  1
373883  93.024  -68.742  54.187  1
373884  93.059  -68.743  54.160  1
373885  93.094  -68.744  54.132  1
373886  93.129  -68.745  54.105  1
373887  93.164  -68.745  54.075  1
373888  93.199  -68.746  54.047  1
373889  93.234  -68.747  54.018  1
373890  93.269  -68.748  53.990  1
373891  93.312  -68.733  53.962  1
373923  94.787  -68.375  53.453  1
373924  94.817  -68.386  53.444  1
373925  94.837  -68.410  53.434  1
373926  94.858  -68.433  53.424  1
373927  94.880  -68.453  53.415  1
373928  94.910  -68.442  53.405  1
373929  94.941  -68.431  53.395  1
373930  94.971  -68.420  53.384  1
373931  95.001  -68.409  53.374  1
373932  95.032  -68.398  53.365  1
373933  95.062  -68.387  53.356  1
373934  95.093  -68.376  53.348  1
373935  95.124  -68.366  53.340  1
373936  95.154  -68.354  53.333  1
373937  95.185  -68.344  53.327  1
373938  95.215  -68.332  53.319  1
373939  95.250  -68.319  53.311  1
373940  95.288  -68.303  53.301  1
373941  95.321  -68.291  53.291  1
373942  95.348  -68.285  53.280  1
373943  95.375  -68.278  53.270  1
373944  95.406  -68.290  53.262  1
373945  95.446  -68.301  53.256  1
373946  95.486  -68.312  53.249  1
373947  95.527  -68.322  53.241  1
373948  95.568  -68.333  53.234  1
373949  95.609  -68.344  53.227  1
373950  95.651  -68.355  53.218  1
373951  95.696  -68.373  53.207  1
373952  95.743  -68.391  53.196  1
373953  95.789  -68.409  53.184  1
373954  95.835  -68.426  53.173  1
373955  95.881  -68.445  53.164  1
373956  95.926  -68.462  53.158  1
373957  95.965  -68.470  53.156  1
373958  96.002  -68.476  53.155  1
373959  96.038  -68.482  53.157  1
373960  96.075  -68.487  53.158  1
373961  96.111  -68.492  53.156  1
373962  96.148  -68.498  53.150  1
373963  96.181  -68.501  53.140  1
373964  96.209  -68.500  53.121  1
373965  96.237  -68.498  53.099  1
373966  96.266  -68.498  53.077  1
373967  96.294  -68.496  53.052  1
373968  96.322  -68.495  53.024  1
373969  96.350  -68.494  52.992  1
373970  96.379  -68.493  52.959  1
373971  96.407  -68.492  52.928  1
373972  96.436  -68.493  52.900  1
373973  96.465  -68.501  52.874  1
373974  96.495  -68.508  52.846  1
373975  96.525  -68.513  52.814  1
373976  96.555  -68.517  52.781  1
373977  96.582  -68.520  52.742  1
373978  96.608  -68.523  52.702  1
373979  96.633  -68.526  52.662  1
373980  96.659  -68.529  52.624  1
373981  96.684  -68.532  52.586  1
373982  96.710  -68.535  52.548  1
373983  96.738  -68.533  52.510  1
373984  96.766  -68.532  52.472  1
373985  96.795  -68.529  52.436  1
373986  96.822  -68.528  52.401  1
373987  96.851  -68.526  52.365  1
373988  96.895  -68.536  52.326  1
373989  96.946  -68.553  52.288  1
373990  96.995  -68.568  52.251  1
373991  97.043  -68.583  52.218  1
373992  97.093  -68.598  52.189  1
373993  97.142  -68.614  52.165  1
373994  97.191  -68.629  52.145  1
373995  97.221  -68.629  52.130  1
373996  97.243  -68.623  52.119  1
373997  97.265  -68.617  52.110  1
373998  97.288  -68.611  52.107  1
373999  97.310  -68.604  52.108  1
374000  97.333  -68.599  52.112  1
374001  97.355  -68.595  52.116  1
374002  97.376  -68.592  52.118  1
374003  97.401  -68.592  52.114  1
374004  97.433  -68.598  52.103  1
374005  97.463  -68.604  52.087  1
374006  97.496  -68.609  52.066  1
374007  97.527  -68.615  52.041  1
374008  97.560  -68.620  52.009  1
374009  97.591  -68.626  51.973  1
374010  97.624  -68.632  51.936  1
374011  97.655  -68.637  51.899  1
374012  97.687  -68.642  51.862  1
374013  97.722  -68.645  51.824  1
374014  97.755  -68.647  51.785  1
374015  97.789  -68.650  51.744  1
374016  97.823  -68.652  51.699  1
374017  97.857  -68.655  51.650  1
374018  97.890  -68.658  51.603  1
374019  97.925  -68.660  51.555  1
374020  97.958  -68.663  51.508  1
374021  97.992  -68.666  51.460  1
374022  98.026  -68.669  51.410  1
374023  98.061  -68.673  51.360  1
374024  98.095  -68.676  51.310  1
374025  98.131  -68.681  51.261  1
374026  98.167  -68.686  51.213  1
374027  98.201  -68.696  51.165  1
374028  98.241  -68.709  51.116  1
374029  98.282  -68.721  51.065  1
374030  98.322  -68.734  51.015  1
374031  98.363  -68.746  50.965  1
374032  98.404  -68.759  50.916  1
374033  98.444  -68.771  50.867  1
374034  98.485  -68.784  50.818  1
374035  98.525  -68.796  50.765  1
374036  98.566  -68.809  50.714  1
374037  98.606  -68.821  50.663  1
374038  98.647  -68.834  50.612  1
374039  98.687  -68.846  50.561  1
374040  98.727  -68.859  50.510  1
374041  98.768  -68.871  50.458  1
374042  98.779  -68.864  50.405  1
374043  98.788  -68.857  50.351  1
374044  98.798  -68.849  50.297  1
374045  98.841  -68.860  50.244  1
374046  98.888  -68.873  50.192  1
374047  98.935  -68.886  50.139  1
374048  98.982  -68.899  50.089  1
374049  99.029  -68.913  50.038  1
374050  99.076  -68.926  49.987  1
374051  99.123  -68.938  49.936  1
374052  99.154  -68.952  49.887  1
374053  99.177  -68.971  49.838  1
374054  99.200  -68.990  49.787  1
374055  99.222  -69.009  49.738  1
374056  99.245  -69.027  49.691  1
374057  99.266  -69.045  49.645  1
374058  99.283  -69.056  49.600  1
374059  99.299  -69.066  49.554  1
374060  99.328  -69.074  49.506  1
374061  99.376  -69.080  49.458  1
374062  99.424  -69.086  49.410  1
374063  99.471  -69.091  49.360  1
374064  99.501  -69.102  49.311  1
374065  99.531  -69.112  49.261  1
374066  99.561  -69.122  49.214  1
374067  99.608  -69.131  49.167  1
374068  99.660  -69.138  49.121  1
374069  99.712  -69.147  49.074  1
374070  99.764  -69.154  49.027  1
374071  99.816  -69.162  48.980  1
374072  99.868  -69.170  48.932  1
374073  99.920  -69.178  48.883  1
374074  99.970  -69.184  48.836  1
374075  100.016  -69.190  48.789  1
374076  100.051  -69.195  48.740  1
374077  100.073  -69.201  48.690  1
374078  100.096  -69.208  48.641  1
374079  100.117  -69.214  48.591  1
374080  100.139  -69.220  48.541  1
374081  100.161  -69.227  48.491  1
374082  100.189  -69.232  48.442  1
374083  100.234  -69.234  48.395  1
374084  100.280  -69.237  48.348  1
374085  100.326  -69.239  48.302  1
374086  100.374  -69.298  48.259  1
374087  100.413  -69.325  48.218  1
374088  100.443  -69.322  48.178  1
374089  100.474  -69.319  48.140  1
374090  100.504  -69.315  48.102  1
374091  100.535  -69.312  48.064  1
374092  100.566  -69.333  48.027  1
374093  100.599  -69.372  47.991  1
374094  100.631  -69.411  47.956  1
374095  100.662  -69.445  47.922  1
374096  100.691  -69.450  47.887  1
374097  100.720  -69.454  47.852  1
374098  100.750  -69.459  47.816  1
374099  100.778  -69.463  47.781  1
374100  100.808  -69.469  47.746  1
374101  100.846  -69.467  47.711  1
374102  100.886  -69.465  47.675  1
374103  100.925  -69.463  47.639  1
374104  100.965  -69.460  47.602  1
374105  101.005  -69.459  47.564  1
374534  90.749  -68.580  54.789  1
374535  90.780  -68.591  54.785  1
374536  90.811  -68.601  54.785  1
374537  90.842  -68.611  54.786  1
374538  90.873  -68.622  54.789  1
374539  90.904  -68.633  54.794  1
374540  90.950  -68.653  54.800  1
374541  91.008  -68.683  54.807  1
374542  91.067  -68.712  54.814  1
374543  91.125  -68.741  54.822  1
374544  91.183  -68.770  54.831  1
374545  91.242  -68.799  54.840  1
374546  91.300  -68.829  54.845  1
374547  91.354  -68.875  54.845  1
374548  91.405  -68.935  54.839  1
374549  91.455  -68.979  54.824  1
374550  91.506  -68.977  54.808  1
374551  91.556  -68.975  54.792  1
374552  91.604  -68.974  54.776  1
374553  91.646  -68.975  54.760  1
374554  91.688  -68.976  54.743  1
374555  91.733  -68.971  54.726  1
374556  91.778  -68.965  54.709  1
374557  91.822  -68.960  54.693  1
374558  91.867  -68.954  54.679  1
374559  91.912  -68.949  54.666  1
374560  91.956  -68.943  54.654  1
374561  92.001  -68.937  54.641  1
374564  92.135  -68.921  54.602  1
374565  92.180  -68.915  54.588  1
374566  92.225  -68.909  54.573  1
374567  92.269  -68.903  54.557  1
374568  92.314  -68.897  54.541  1
374569  92.359  -68.886  54.524  1
374570  92.403  -68.874  54.506  1
374571  92.448  -68.861  54.486  1
374572  92.493  -68.850  54.467  1
374573  92.537  -68.838  54.448  1
374574  92.582  -68.826  54.431  1
374575  92.627  -68.814  54.411  1
374576  92.671  -68.802  54.391  1
374577  92.716  -68.790  54.371  1
374578  92.761  -68.779  54.351  1
374579  92.805  -68.767  54.330  1
374580  92.850  -68.755  54.307  1
374581  92.895  -68.743  54.281  1
374582  92.939  -68.731  54.254  1
374583  92.984  -68.719  54.227  1
374584  93.019  -68.720  54.201  1
374585  93.054  -68.720  54.173  1
374586  93.088  -68.722  54.145  1
374587  93.124  -68.723  54.117  1
374588  93.158  -68.723  54.088  1
374589  93.194  -68.724  54.059  1
374590  93.236  -68.710  54.030  1
374591  93.289  -68.676  54.002  1
374592  93.339  -68.653  53.974  1
374593  93.384  -68.644  53.947  1
374597  93.567  -68.605  53.845  1
374598  93.613  -68.596  53.822  1
374599  93.658  -68.586  53.799  1
374600  93.704  -68.577  53.778  1
374601  93.749  -68.567  53.758  1
374602  93.795  -68.557  53.738  1
374603  93.840  -68.548  53.719  1
374604  93.886  -68.538  53.701  1
374605  93.931  -68.529  53.684  1
374606  93.977  -68.520  53.669  1
374607  94.023  -68.510  53.653  1
374608  94.068  -68.501  53.638  1
374609  94.114  -68.491  53.625  1
374610  94.159  -68.482  53.612  1
374611  94.205  -68.472  53.597  1
374624  94.794  -68.352  53.453  1
374625  94.815  -68.376  53.444  1
374626  94.835  -68.399  53.434  1
374627  94.855  -68.423  53.424  1
374628  94.885  -68.417  53.413  1
374629  94.915  -68.406  53.403  1
374630  94.946  -68.395  53.392  1
374631  94.976  -68.385  53.381  1
374632  95.007  -68.373  53.370  1
374633  95.037  -68.363  53.361  1
374634  95.068  -68.351  53.351  1
374635  95.098  -68.341  53.342  1
374636  95.129  -68.329  53.333  1
374637  95.160  -68.319  53.325  1
374638  95.190  -68.307  53.319  1
374639  95.220  -68.297  53.312  1
374640  95.251  -68.286  53.305  1
374641  95.289  -68.269  53.296  1
374642  95.324  -68.256  53.285  1
374643  95.350  -68.250  53.274  1
374644  95.379  -68.248  53.265  1
374645  95.411  -68.262  53.257  1
374646  95.449  -68.273  53.252  1
374647  95.489  -68.284  53.245  1
374648  95.531  -68.295  53.237  1
374649  95.571  -68.306  53.229  1
374650  95.612  -68.316  53.220  1
374651  95.653  -68.327  53.210  1
374652  95.694  -68.338  53.200  1
374653  95.735  -68.348  53.190  1
374654  95.779  -68.363  53.179  1
374655  95.825  -68.381  53.169  1
374656  95.871  -68.399  53.162  1
374657  95.917  -68.416  53.156  1
374658  95.956  -68.426  53.151  1
374659  95.993  -68.431  53.147  1
374660  96.029  -68.437  53.146  1
374661  96.066  -68.442  53.145  1
374662  96.102  -68.448  53.142  1
374663  96.138  -68.454  53.138  1
374664  96.175  -68.459  53.127  1
374665  96.212  -68.464  53.110  1
374666  96.248  -68.470  53.091  1
374667  96.282  -68.473  53.069  1
374668  96.310  -68.472  53.044  1
374669  96.338  -68.471  53.013  1
374670  96.367  -68.470  52.979  1
374671  96.395  -68.469  52.945  1
374672  96.423  -68.467  52.913  1
374673  96.452  -68.466  52.887  1
374674  96.481  -68.473  52.860  1
374675  96.511  -68.479  52.831  1
374676  96.540  -68.484  52.801  1
374677  96.568  -68.488  52.767  1
374678  96.594  -68.491  52.728  1
374679  96.619  -68.494  52.689  1
374680  96.645  -68.497  52.650  1
374681  96.668  -68.498  52.612  1
374682  96.690  -68.499  52.574  1
374683  96.719  -68.504  52.536  1
374684  96.749  -68.507  52.499  1
374685  96.775  -68.501  52.463  1
374686  96.803  -68.499  52.427  1
374687  96.831  -68.498  52.393  1
374688  96.859  -68.495  52.356  1
374689  96.887  -68.494  52.319  1
374690  96.940  -68.511  52.282  1
374691  96.993  -68.529  52.246  1
374692  97.047  -68.548  52.215  1
374693  97.096  -68.564  52.189  1
374694  97.146  -68.579  52.166  1
374695  97.194  -68.594  52.148  1
374696  97.227  -68.596  52.137  1
374697  97.250  -68.590  52.129  1
374698  97.272  -68.584  52.124  1
374699  97.295  -68.578  52.123  1
374700  97.317  -68.572  52.128  1
374701  97.339  -68.566  52.136  1
374702  97.362  -68.560  52.140  1
374703  97.384  -68.554  52.139  1
374704  97.409  -68.554  52.133  1
374705  97.441  -68.560  52.116  1
374706  97.473  -68.566  52.095  1
374707  97.505  -68.571  52.069  1
374708  97.537  -68.576  52.040  1
374709  97.569  -68.582  52.004  1
374710  97.601  -68.588  51.966  1
374711  97.633  -68.593  51.929  1
374712  97.665  -68.599  51.892  1
374713  97.697  -68.604  51.856  1
374714  97.731  -68.607  51.818  1
374715  97.765  -68.610  51.779  1
374716  97.799  -68.612  51.738  1
374717  97.832  -68.615  51.693  1
374718  97.866  -68.617  51.644  1
374719  97.900  -68.620  51.597  1
374720  97.934  -68.623  51.551  1
374721  97.968  -68.625  51.503  1
374722  98.005  -68.630  51.453  1
374723  98.042  -68.636  51.403  1
374724  98.079  -68.642  51.352  1
374725  98.115  -68.647  51.300  1
374726  98.151  -68.652  51.249  1
374727  98.172  -68.656  51.201  1
374728  98.215  -68.664  51.152  1
374729  98.250  -68.676  51.100  1
374730  98.286  -68.689  51.047  1
374731  98.326  -68.702  50.996  1
374732  98.367  -68.714  50.944  1
374733  98.408  -68.727  50.893  1
374734  98.448  -68.739  50.843  1
374735  98.489  -68.752  50.793  1
374736  98.529  -68.764  50.743  1
374737  98.570  -68.777  50.694  1
374738  98.610  -68.789  50.644  1
374739  98.651  -68.802  50.594  1
374740  98.691  -68.814  50.545  1
374741  98.731  -68.827  50.497  1
374742  98.772  -68.839  50.446  1
374743  98.786  -68.834  50.393  1
374744  98.795  -68.827  50.339  1
374745  98.813  -68.824  50.286  1
374746  98.860  -68.836  50.234  1
374747  98.907  -68.850  50.182  1
374748  98.954  -68.863  50.131  1
374749  99.001  -68.877  50.084  1
374750  99.048  -68.889  50.034  1
374751  99.090  -68.896  49.984  1
374752  99.120  -68.887  49.934  1
374753  99.157  -68.918  49.885  1
374754  99.183  -68.940  49.834  1
374755  99.206  -68.959  49.784  1
374756  99.229  -68.979  49.736  1
374757  99.252  -68.998  49.690  1
374758  99.271  -69.012  49.642  1
374759  99.287  -69.023  49.597  1
374760  99.304  -69.034  49.550  1
374761  99.325  -69.043  49.503  1
374762  99.372  -69.049  49.457  1
374763  99.420  -69.054  49.411  1
374764  99.468  -69.060  49.363  1
374765  99.513  -69.066  49.314  1
374766  99.543  -69.077  49.266  1
374767  99.573  -69.087  49.220  1
374768  99.612  -69.096  49.173  1
374769  99.664  -69.104  49.127  1
374770  99.716  -69.112  49.080  1
374771  99.768  -69.119  49.034  1
374772  99.820  -69.128  48.986  1
374773  99.872  -69.135  48.938  1
374774  99.924  -69.143  48.889  1
374775  99.970  -69.148  48.841  1
374776  100.015  -69.153  48.792  1
374777  100.060  -69.158  48.743  1
374778  100.082  -69.164  48.693  1
374779  100.104  -69.171  48.644  1
374780  100.126  -69.177  48.592  1
374781  100.148  -69.183  48.543  1
374782  100.170  -69.189  48.492  1
374783  100.210  -69.208  48.442  1
374784  100.261  -69.234  48.392  1
374785  100.307  -69.238  48.345  1
374786  100.353  -69.273  48.299  1
374787  100.384  -69.269  48.256  1
374788  100.414  -69.266  48.214  1
374789  100.444  -69.263  48.175  1
374790  100.475  -69.259  48.136  1
374791  100.505  -69.256  48.097  1
374792  100.537  -69.278  48.059  1
374793  100.569  -69.317  48.022  1
374794  100.601  -69.356  47.987  1
374795  100.633  -69.395  47.951  1
374796  100.662  -69.405  47.916  1
374797  100.692  -69.410  47.882  1
374798  100.720  -69.414  47.846  1
374799  100.750  -69.419  47.811  1
374800  100.779  -69.423  47.776  1
374801  100.816  -69.423  47.741  1
374802  100.855  -69.421  47.705  1
374803  100.895  -69.419  47.670  1
374804  100.935  -69.417  47.634  1
375234  90.706  -68.537  54.787  1
375235  90.737  -68.548  54.782  1
375236  90.768  -68.558  54.778  1
375237  90.799  -68.569  54.778  1
375238  90.830  -68.579  54.780  1
375239  90.861  -68.590  54.785  1
375240  90.892  -68.601  54.790  1
375241  90.944  -68.625  54.797  1
375242  91.002  -68.654  54.804  1
375243  91.061  -68.683  54.812  1
375244  91.119  -68.713  54.823  1
375245  91.177  -68.742  54.833  1
375246  91.235  -68.771  54.843  1
375247  91.294  -68.801  54.848  1
375248  91.347  -68.850  54.846  1
375249  91.398  -68.910  54.837  1
375250  91.448  -68.921  54.821  1
375251  91.498  -68.920  54.803  1
375252  91.548  -68.918  54.786  1
375253  91.599  -68.916  54.770  1
375254  91.642  -68.917  54.753  1
375255  91.684  -68.918  54.736  1
375256  91.726  -68.918  54.719  1
375257  91.770  -68.914  54.702  1
375258  91.815  -68.908  54.687  1
375259  91.860  -68.902  54.673  1
375260  91.905  -68.897  54.660  1
375261  91.949  -68.892  54.648  1
375262  91.994  -68.886  54.636  1
375264  92.083  -68.874  54.611  1
375265  92.128  -68.869  54.599  1
375266  92.173  -68.863  54.587  1
375267  92.217  -68.858  54.573  1
375268  92.262  -68.852  54.558  1
375269  92.307  -68.846  54.542  1
375270  92.352  -68.840  54.526  1
375271  92.397  -68.835  54.510  1
375272  92.441  -68.829  54.491  1
375273  92.486  -68.824  54.474  1
375274  92.530  -68.817  54.457  1
375275  92.575  -68.805  54.440  1
375276  92.620  -68.793  54.421  1
375277  92.664  -68.782  54.403  1
375278  92.709  -68.770  54.384  1
375279  92.754  -68.758  54.365  1
375280  92.798  -68.746  54.344  1
375281  92.843  -68.734  54.323  1
375282  92.887  -68.722  54.297  1
375283  92.932  -68.711  54.269  1
375284  92.977  -68.698  54.241  1
375285  93.013  -68.698  54.214  1
375286  93.048  -68.698  54.186  1
375287  93.083  -68.699  54.158  1
375288  93.118  -68.700  54.130  1
375289  93.160  -68.687  54.101  1
375290  93.213  -68.654  54.071  1
375291  93.259  -68.645  54.042  1
375292  93.304  -68.636  54.014  1
375293  93.350  -68.626  53.987  1
375294  93.396  -68.617  53.960  1
375296  93.487  -68.597  53.908  1
375297  93.532  -68.588  53.883  1
375298  93.578  -68.578  53.859  1
375299  93.623  -68.569  53.836  1
375300  93.669  -68.559  53.813  1
375301  93.714  -68.549  53.792  1
375302  93.760  -68.540  53.772  1
375303  93.805  -68.530  53.752  1
375304  93.851  -68.521  53.733  1
375305  93.897  -68.511  53.715  1
375306  93.942  -68.501  53.697  1
375307  93.988  -68.492  53.681  1
375308  94.034  -68.482  53.664  1
375309  94.079  -68.473  53.649  1
375310  94.125  -68.463  53.635  1
375311  94.170  -68.454  53.620  1
375312  94.216  -68.445  53.606  1
375313  94.261  -68.435  53.593  1
375325  94.792  -68.341  53.454  1
375326  94.813  -68.365  53.443  1
375327  94.833  -68.389  53.433  1
375328  94.859  -68.392  53.423  1
375329  94.890  -68.382  53.412  1
375330  94.920  -68.370  53.401  1
375331  94.951  -68.360  53.389  1
375332  94.981  -68.348  53.378  1
375333  95.012  -68.338  53.366  1
375334  95.043  -68.326  53.356  1
375335  95.073  -68.316  53.346  1
375336  95.104  -68.304  53.336  1
375337  95.134  -68.294  53.325  1
375338  95.165  -68.283  53.315  1
375339  95.195  -68.272  53.308  1
375340  95.226  -68.261  53.302  1
375341  95.256  -68.250  53.296  1
375342  95.290  -68.237  53.288  1
375343  95.327  -68.222  53.277  1
375344  95.353  -68.216  53.267  1
375345  95.383  -68.220  53.259  1
375346  95.415  -68.234  53.251  1
375347  95.452  -68.246  53.247  1
375348  95.492  -68.256  53.240  1
375349  95.534  -68.267  53.232  1
375350  95.574  -68.278  53.224  1
375351  95.615  -68.288  53.214  1
375352  95.657  -68.299  53.204  1
375353  95.697  -68.310  53.194  1
375354  95.738  -68.320  53.184  1
375355  95.779  -68.332  53.174  1
375356  95.820  -68.342  53.166  1
375357  95.862  -68.353  53.159  1
375358  95.907  -68.371  53.153  1
375359  95.948  -68.381  53.147  1
375360  95.984  -68.387  53.138  1
375361  96.021  -68.392  53.133  1
375362  96.057  -68.398  53.129  1
375363  96.093  -68.403  53.126  1
375364  96.130  -68.409  53.121  1
375365  96.166  -68.414  53.111  1
375366  96.203  -68.419  53.096  1
375367  96.239  -68.426  53.077  1
375368  96.276  -68.431  53.056  1
375369  96.312  -68.436  53.029  1
375370  96.348  -68.442  52.997  1
375371  96.383  -68.445  52.962  1
375372  96.411  -68.444  52.928  1
375373  96.439  -68.443  52.897  1
375374  96.467  -68.441  52.870  1
375375  96.497  -68.445  52.843  1
375376  96.526  -68.451  52.815  1
375377  96.554  -68.454  52.784  1
375378  96.580  -68.457  52.751  1
375379  96.604  -68.460  52.713  1
375380  96.627  -68.461  52.675  1
375381  96.650  -68.463  52.637  1
375382  96.672  -68.463  52.599  1
375383  96.697  -68.466  52.562  1
375384  96.728  -68.471  52.525  1
375385  96.759  -68.476  52.489  1
375386  96.789  -68.479  52.453  1
375387  96.814  -68.473  52.419  1
375388  96.839  -68.467  52.384  1
375389  96.868  -68.466  52.349  1
375390  96.895  -68.463  52.312  1
375391  96.931  -68.467  52.276  1
375392  96.984  -68.486  52.241  1
375393  97.038  -68.504  52.213  1
375394  97.092  -68.523  52.189  1
375395  97.146  -68.541  52.170  1
375396  97.198  -68.559  52.153  1
375397  97.234  -68.564  52.145  1
375398  97.256  -68.557  52.140  1
375399  97.279  -68.551  52.139  1
375400  97.301  -68.546  52.142  1
375401  97.324  -68.541  52.149  1
375402  97.347  -68.536  52.155  1
375403  97.369  -68.531  52.157  1
375404  97.391  -68.526  52.152  1
375405  97.417  -68.520  52.141  1
375406  97.450  -68.523  52.120  1
375407  97.483  -68.527  52.095  1
375408  97.515  -68.533  52.065  1
375409  97.547  -68.538  52.032  1
375410  97.579  -68.544  51.996  1
375411  97.611  -68.550  51.958  1
375412  97.643  -68.555  51.920  1
375413  97.675  -68.560  51.883  1
375414  97.707  -68.567  51.847  1
375415  97.740  -68.570  51.810  1
375416  97.774  -68.572  51.772  1
375417  97.808  -68.575  51.732  1
375418  97.842  -68.577  51.686  1
375419  97.876  -68.579  51.638  1
375420  97.910  -68.582  51.591  1
375421  97.947  -68.588  51.543  1
375422  97.986  -68.595  51.494  1
375423  98.024  -68.601  51.444  1
375424  98.062  -68.608  51.391  1
375425  98.098  -68.614  51.337  1
375426  98.135  -68.619  51.283  1
375427  98.171  -68.624  51.230  1
375428  98.176  -68.626  51.179  1
375429  98.224  -68.633  51.130  1
375430  98.264  -68.645  51.079  1
375431  98.300  -68.657  51.026  1
375432  98.335  -68.670  50.972  1
375433  98.371  -68.683  50.919  1
375434  98.412  -68.695  50.866  1
375435  98.452  -68.708  50.814  1
375436  98.493  -68.720  50.763  1
375437  98.533  -68.733  50.715  1
375438  98.574  -68.745  50.667  1
375439  98.614  -68.758  50.620  1
375440  98.655  -68.770  50.573  1
375441  98.695  -68.783  50.526  1
375442  98.735  -68.796  50.479  1
375443  98.776  -68.808  50.429  1
375444  98.792  -68.804  50.378  1
375445  98.801  -68.796  50.328  1
375446  98.832  -68.800  50.276  1
375447  98.879  -68.813  50.224  1
375448  98.926  -68.827  50.174  1
375449  98.973  -68.839  50.125  1
375450  99.020  -68.853  50.079  1
375451  99.058  -68.855  50.029  1
375452  99.087  -68.846  49.979  1
375453  99.120  -68.847  49.930  1
375454  99.157  -68.882  49.881  1
375455  99.190  -68.911  49.830  1
375456  99.212  -68.930  49.780  1
375457  99.235  -68.949  49.731  1
375458  99.258  -68.968  49.684  1
375459  99.275  -68.980  49.637  1
375460  99.292  -68.990  49.591  1
375461  99.308  -69.001  49.545  1
375462  99.325  -69.012  49.499  1
375463  99.369  -69.018  49.455  1
375464  99.417  -69.023  49.408  1
375465  99.465  -69.029  49.361  1
375466  99.512  -69.034  49.314  1
375467  99.555  -69.041  49.267  1
375468  99.585  -69.052  49.222  1
375469  99.617  -69.062  49.177  1
375470  99.668  -69.069  49.131  1
375471  99.720  -69.078  49.086  1
375472  99.773  -69.085  49.040  1
375473  99.825  -69.093  48.992  1
375474  99.876  -69.101  48.943  1
375475  99.923  -69.106  48.893  1
375476  99.969  -69.111  48.845  1
375477  100.014  -69.116  48.795  1
375478  100.060  -69.121  48.745  1
375479  100.090  -69.127  48.695  1
375480  100.112  -69.133  48.644  1
375481  100.134  -69.140  48.592  1
375482  100.156  -69.146  48.542  1
375483  100.179  -69.153  48.491  1
375484  100.230  -69.178  48.440  1
375485  100.281  -69.205  48.390  1
375486  100.323  -69.218  48.342  1
375487  100.354  -69.214  48.296  1
375488  100.384  -69.211  48.252  1
375489  100.414  -69.208  48.211  1
375490  100.445  -69.204  48.171  1
375491  100.475  -69.201  48.132  1
375492  100.507  -69.224  48.093  1
375493  100.539  -69.262  48.055  1
375494  100.571  -69.301  48.018  1
375495  100.603  -69.341  47.982  1
375496  100.633  -69.360  47.947  1
375497  100.662  -69.365  47.912  1
375498  100.692  -69.369  47.877  1
375499  100.721  -69.374  47.841  1
375500  100.750  -69.378  47.806  1
375501  100.785  -69.379  47.771  1
375502  100.825  -69.377  47.736  1
375503  100.865  -69.375  47.701  1
375935  90.693  -68.505  54.779  1
375936  90.725  -68.516  54.774  1
375937  90.756  -68.526  54.772  1
375938  90.787  -68.536  54.772  1
375939  90.818  -68.547  54.776  1
375940  90.849  -68.557  54.781  1
375941  90.880  -68.568  54.787  1
375942  90.938  -68.597  54.794  1
375943  90.996  -68.626  54.802  1
375944  91.054  -68.655  54.812  1
375945  91.113  -68.685  54.821  1
375946  91.171  -68.714  54.834  1
375947  91.229  -68.743  54.842  1
375948  91.288  -68.773  54.845  1
375949  91.340  -68.826  54.842  1
375950  91.391  -68.866  54.832  1
375951  91.441  -68.864  54.814  1
375952  91.491  -68.862  54.797  1
375953  91.541  -68.861  54.780  1
375954  91.591  -68.859  54.762  1
375955  91.637  -68.859  54.746  1
375956  91.679  -68.860  54.730  1
375957  91.721  -68.861  54.713  1
375958  91.764  -68.861  54.695  1
375959  91.808  -68.857  54.680  1
375960  91.853  -68.852  54.666  1
375961  91.897  -68.846  54.653  1
375962  91.942  -68.840  54.642  1
375963  91.987  -68.834  54.631  1
375964  92.031  -68.829  54.620  1
375965  92.076  -68.823  54.608  1
375966  92.121  -68.817  54.596  1
375967  92.165  -68.811  54.585  1
375968  92.210  -68.806  54.572  1
375969  92.255  -68.800  54.559  1
375970  92.300  -68.795  54.544  1
375971  92.345  -68.789  54.528  1
375972  92.389  -68.783  54.513  1
375973  92.434  -68.777  54.497  1
375974  92.479  -68.772  54.481  1
375975  92.523  -68.766  54.465  1
375976  92.568  -68.761  54.450  1
375977  92.613  -68.755  54.434  1
375978  92.657  -68.749  54.416  1
375979  92.702  -68.744  54.398  1
375980  92.747  -68.737  54.379  1
375981  92.791  -68.726  54.358  1
375982  92.836  -68.714  54.336  1
375983  92.881  -68.701  54.310  1
375984  92.925  -68.690  54.282  1
375985  92.970  -68.678  54.254  1
375986  93.008  -68.675  54.225  1
375987  93.043  -68.676  54.197  1
375988  93.084  -68.664  54.169  1
375989  93.133  -68.646  54.141  1
375990  93.178  -68.637  54.112  1
375991  93.224  -68.627  54.083  1
375992  93.269  -68.617  54.054  1
375993  93.315  -68.608  54.027  1
375994  93.360  -68.598  54.000  1
375995  93.406  -68.589  53.974  1
375996  93.451  -68.579  53.947  1
375997  93.497  -68.570  53.922  1
375998  93.543  -68.560  53.897  1
375999  93.588  -68.551  53.874  1
376000  93.634  -68.542  53.851  1
376001  93.680  -68.532  53.828  1
376002  93.725  -68.522  53.807  1
376003  93.771  -68.513  53.787  1
376004  93.816  -68.503  53.767  1
376005  93.862  -68.493  53.748  1
376006  93.907  -68.484  53.729  1
376007  93.953  -68.474  53.710  1
376008  93.998  -68.465  53.693  1
376009  94.044  -68.455  53.677  1
376010  94.089  -68.445  53.661  1
376011  94.135  -68.436  53.645  1
376012  94.181  -68.426  53.629  1
376013  94.226  -68.417  53.614  1
376014  94.272  -68.407  53.601  1
376015  94.318  -68.398  53.587  1
376016  94.363  -68.388  53.572  1
376027  94.811  -68.354  53.444  1
376028  94.834  -68.367  53.433  1
376029  94.864  -68.357  53.423  1
376030  94.895  -68.345  53.411  1
376031  94.926  -68.335  53.399  1
376032  94.956  -68.323  53.387  1
376033  94.987  -68.313  53.375  1
376034  95.017  -68.301  53.362  1
376035  95.048  -68.291  53.351  1
376036  95.078  -68.280  53.341  1
376037  95.109  -68.269  53.329  1
376038  95.139  -68.258  53.318  1
376039  95.170  -68.247  53.308  1
376040  95.200  -68.236  53.298  1
376041  95.231  -68.225  53.290  1
376042  95.261  -68.214  53.284  1
376043  95.292  -68.203  53.277  1
376044  95.329  -68.188  53.267  1
376045  95.356  -68.181  53.258  1
376046  95.388  -68.192  53.249  1
376047  95.420  -68.205  53.242  1
376048  95.455  -68.218  53.238  1
376049  95.496  -68.228  53.233  1
376050  95.537  -68.239  53.227  1
376051  95.578  -68.250  53.219  1
376052  95.618  -68.260  53.210  1
376053  95.660  -68.271  53.200  1
376054  95.700  -68.282  53.190  1
376055  95.741  -68.293  53.179  1
376056  95.782  -68.303  53.169  1
376057  95.823  -68.314  53.161  1
376058  95.864  -68.325  53.156  1
376059  95.905  -68.334  53.149  1
376060  95.943  -68.340  53.141  1
376061  95.979  -68.345  53.129  1
376062  96.015  -68.350  53.119  1
376063  96.051  -68.355  53.111  1
376064  96.087  -68.360  53.106  1
376065  96.122  -68.365  53.100  1
376066  96.158  -68.370  53.091  1
376067  96.194  -68.376  53.076  1
376068  96.231  -68.381  53.058  1
376069  96.267  -68.386  53.036  1
376070  96.303  -68.391  53.009  1
376071  96.340  -68.398  52.977  1
376072  96.376  -68.403  52.943  1
376073  96.413  -68.408  52.910  1
376074  96.449  -68.414  52.879  1
376075  96.483  -68.417  52.852  1
376076  96.512  -68.416  52.825  1
376077  96.540  -68.422  52.797  1
376078  96.564  -68.423  52.766  1
376079  96.586  -68.425  52.734  1
376080  96.609  -68.426  52.697  1
376081  96.631  -68.427  52.660  1
376082  96.654  -68.428  52.623  1
376083  96.676  -68.429  52.586  1
376084  96.707  -68.434  52.550  1
376085  96.737  -68.438  52.514  1
376086  96.768  -68.443  52.478  1
376087  96.799  -68.448  52.442  1
376088  96.828  -68.450  52.410  1
376089  96.853  -68.445  52.377  1
376090  96.879  -68.439  52.342  1
376091  96.904  -68.433  52.306  1
376092  96.932  -68.432  52.271  1
376093  96.976  -68.442  52.239  1
376094  97.030  -68.460  52.213  1
376095  97.083  -68.479  52.191  1
376096  97.139  -68.504  52.174  1
376097  97.198  -68.529  52.160  1
376098  97.239  -68.534  52.154  1
376099  97.263  -68.532  52.152  1
376100  97.286  -68.526  52.154  1
376101  97.308  -68.521  52.160  1
376102  97.331  -68.517  52.167  1
376103  97.354  -68.511  52.171  1
376104  97.376  -68.506  52.169  1
376105  97.398  -68.501  52.160  1
376106  97.423  -68.495  52.144  1
376107  97.454  -68.492  52.119  1
376108  97.488  -68.495  52.090  1
376109  97.522  -68.498  52.058  1
376110  97.556  -68.501  52.024  1
376111  97.589  -68.506  51.987  1
376112  97.621  -68.511  51.949  1
376113  97.653  -68.517  51.911  1
376114  97.685  -68.523  51.875  1
376115  97.717  -68.528  51.838  1
376116  97.750  -68.532  51.802  1
376117  97.784  -68.535  51.765  1
376118  97.817  -68.537  51.725  1
376119  97.852  -68.539  51.680  1
376120  97.889  -68.546  51.631  1
376121  97.928  -68.552  51.583  1
376122  97.966  -68.559  51.533  1
376123  98.005  -68.566  51.482  1
376124  98.043  -68.573  51.432  1
376125  98.082  -68.579  51.376  1
376126  98.118  -68.585  51.320  1
376127  98.154  -68.590  51.265  1
376128  98.176  -68.593  51.210  1
376129  98.181  -68.595  51.158  1
376130  98.231  -68.603  51.107  1
376131  98.278  -68.612  51.056  1
376132  98.313  -68.625  51.003  1
376133  98.349  -68.638  50.949  1
376134  98.384  -68.650  50.896  1
376135  98.420  -68.663  50.842  1
376136  98.456  -68.676  50.790  1
376137  98.497  -68.689  50.740  1
376138  98.537  -68.701  50.690  1
376139  98.578  -68.714  50.642  1
376140  98.618  -68.726  50.595  1
376141  98.659  -68.739  50.549  1
376142  98.699  -68.751  50.503  1
376143  98.740  -68.763  50.458  1
376144  98.780  -68.776  50.410  1
376145  98.798  -68.774  50.362  1
376146  98.808  -68.766  50.313  1
376147  98.851  -68.777  50.263  1
376148  98.898  -68.790  50.214  1
376149  98.945  -68.803  50.165  1
376150  98.992  -68.817  50.120  1
376151  99.025  -68.812  50.073  1
376152  99.055  -68.804  50.025  1
376153  99.085  -68.795  49.975  1
376154  99.120  -68.811  49.926  1
376155  99.158  -68.846  49.878  1
376156  99.196  -68.880  49.828  1
376157  99.219  -68.899  49.778  1
376158  99.241  -68.918  49.728  1
376159  99.264  -68.936  49.680  1
376160  99.280  -68.947  49.632  1
376161  99.296  -68.958  49.586  1
376162  99.313  -68.968  49.540  1
376163  99.329  -68.979  49.495  1
376164  99.365  -68.987  49.451  1
376165  99.413  -68.992  49.405  1
376166  99.462  -68.997  49.359  1
376167  99.509  -69.003  49.313  1
376168  99.557  -69.009  49.267  1
376169  99.598  -69.016  49.223  1
376170  99.628  -69.026  49.179  1
376171  99.673  -69.035  49.135  1
376172  99.725  -69.043  49.091  1
376173  99.777  -69.050  49.045  1
376174  99.829  -69.059  48.996  1
376175  99.876  -69.064  48.947  1
376176  99.922  -69.069  48.897  1
376177  99.968  -69.074  48.848  1
376178  100.013  -69.079  48.798  1
376179  100.059  -69.084  48.747  1
376180  100.099  -69.090  48.696  1
376181  100.121  -69.096  48.644  1
376182  100.143  -69.102  48.591  1
376183  100.164  -69.109  48.540  1
376184  100.199  -69.123  48.489  1
376185  100.250  -69.149  48.438  1
376186  100.288  -69.186  48.388  1
376187  100.324  -69.159  48.339  1
376188  100.354  -69.156  48.293  1
376189  100.385  -69.153  48.249  1
376190  100.415  -69.149  48.208  1
376191  100.445  -69.146  48.168  1
376192  100.477  -69.169  48.128  1
376193  100.509  -69.208  48.089  1
376194  100.541  -69.247  48.052  1
376195  100.573  -69.286  48.014  1
376196  100.605  -69.315  47.977  1
376197  100.634  -69.320  47.942  1
376198  100.662  -69.325  47.908  1
376199  100.692  -69.329  47.872  1
376200  100.721  -69.334  47.836  1
376201  100.755  -69.335  47.802  1
376202  100.795  -69.333  47.766  1
376636  90.681  -68.473  54.771  1
376637  90.713  -68.483  54.768  1
376638  90.744  -68.494  54.766  1
376639  90.775  -68.504  54.767  1
376640  90.806  -68.515  54.771  1
376641  90.837  -68.526  54.777  1
376642  90.874  -68.539  54.784  1
376643  90.932  -68.569  54.792  1
376644  90.990  -68.598  54.801  1
376645  91.048  -68.627  54.810  1
376646  91.107  -68.657  54.819  1
376647  91.165  -68.686  54.832  1
376648  91.223  -68.715  54.838  1
376649  91.282  -68.745  54.840  1
376650  91.333  -68.801  54.836  1
376651  91.383  -68.808  54.824  1
376652  91.434  -68.807  54.807  1
376653  91.484  -68.805  54.790  1
376654  91.534  -68.804  54.773  1
376655  91.584  -68.802  54.756  1
376656  91.633  -68.801  54.738  1
376657  91.674  -68.802  54.722  1
376658  91.717  -68.802  54.705  1
376659  91.759  -68.803  54.688  1
376660  91.801  -68.804  54.673  1
376661  91.845  -68.800  54.659  1
376662  91.890  -68.794  54.647  1
376663  91.935  -68.789  54.635  1
376664  91.980  -68.783  54.625  1
376665  92.024  -68.777  54.615  1
376666  92.069  -68.771  54.604  1
376667  92.113  -68.766  54.593  1
376668  92.158  -68.760  54.583  1
376669  92.203  -68.755  54.571  1
376670  92.248  -68.749  54.559  1
376671  92.293  -68.743  54.545  1
376672  92.337  -68.737  54.530  1
376673  92.382  -68.732  54.516  1
376674  92.427  -68.727  54.502  1
376675  92.472  -68.720  54.488  1
376676  92.516  -68.715  54.474  1
376677  92.561  -68.709  54.461  1
376678  92.605  -68.704  54.447  1
376679  92.650  -68.698  54.430  1
376680  92.695  -68.692  54.411  1
376681  92.740  -68.686  54.392  1
376682  92.784  -68.681  54.370  1
376683  92.829  -68.675  54.348  1
376684  92.874  -68.670  54.322  1
376685  92.919  -68.664  54.294  1
376686  92.964  -68.658  54.265  1
376687  93.006  -68.648  54.236  1
376688  93.052  -68.638  54.208  1
376689  93.097  -68.629  54.180  1
376690  93.143  -68.619  54.152  1
376691  93.189  -68.609  54.123  1
376692  93.234  -68.600  54.094  1
376693  93.280  -68.590  54.066  1
376694  93.326  -68.581  54.039  1
376695  93.371  -68.571  54.012  1
376696  93.417  -68.561  53.987  1
376697  93.462  -68.552  53.961  1
376698  93.508  -68.542  53.936  1
376699  93.553  -68.533  53.912  1
376700  93.599  -68.523  53.889  1
376701  93.644  -68.513  53.866  1
376702  93.690  -68.504  53.844  1
376703  93.735  -68.495  53.823  1
376704  93.781  -68.485  53.803  1
376705  93.827  -68.476  53.782  1
376706  93.872  -68.466  53.763  1
376707  93.918  -68.457  53.744  1
376708  93.964  -68.447  53.725  1
376709  94.009  -68.437  53.707  1
376710  94.055  -68.428  53.689  1
376711  94.100  -68.418  53.673  1
376712  94.146  -68.409  53.657  1
376713  94.191  -68.399  53.640  1
376714  94.237  -68.389  53.624  1
376715  94.282  -68.380  53.609  1
376716  94.328  -68.370  53.594  1
376717  94.373  -68.361  53.579  1
376718  94.419  -68.351  53.565  1
376729  94.839  -68.332  53.434  1
376730  94.870  -68.320  53.423  1
376731  94.900  -68.310  53.411  1
376732  94.931  -68.299  53.398  1
376733  94.961  -68.288  53.385  1
376734  94.992  -68.277  53.373  1
376735  95.023  -68.266  53.359  1
376736  95.053  -68.255  53.347  1
376737  95.084  -68.244  53.335  1
376738  95.114  -68.233  53.323  1
376739  95.144  -68.222  53.310  1
376740  95.175  -68.211  53.299  1
376741  95.205  -68.200  53.288  1
376742  95.236  -68.189  53.279  1
376743  95.267  -68.178  53.271  1
376744  95.297  -68.167  53.264  1
376745  95.330  -68.155  53.255  1
376746  95.360  -68.150  53.246  1
376747  95.392  -68.163  53.237  1
376748  95.424  -68.177  53.230  1
376749  95.458  -68.190  53.226  1
376750  95.499  -68.200  53.221  1
376751  95.540  -68.211  53.216  1
376752  95.581  -68.222  53.208  1
376753  95.622  -68.233  53.199  1
376754  95.663  -68.244  53.190  1
376755  95.703  -68.254  53.180  1
376756  95.745  -68.265  53.170  1
376757  95.785  -68.275  53.160  1
376758  95.826  -68.285  53.153  1
376759  95.867  -68.292  53.144  1
376760  95.908  -68.300  53.135  1
376761  95.944  -68.305  53.125  1
376762  95.982  -68.310  53.112  1
376763  96.019  -68.316  53.101  1
376764  96.054  -68.320  53.093  1
376765  96.090  -68.325  53.085  1
376766  96.126  -68.331  53.076  1
376767  96.162  -68.335  53.064  1
376768  96.198  -68.341  53.049  1
376769  96.234  -68.346  53.030  1
376770  96.269  -68.350  53.008  1
376771  96.305  -68.356  52.984  1
376772  96.341  -68.360  52.952  1
376773  96.377  -68.366  52.919  1
376774  96.412  -68.371  52.888  1
376775  96.449  -68.376  52.858  1
376776  96.484  -68.381  52.832  1
376777  96.520  -68.385  52.805  1
376778  96.545  -68.388  52.777  1
376779  96.568  -68.389  52.747  1
376780  96.590  -68.390  52.714  1
376781  96.613  -68.391  52.680  1
376782  96.636  -68.392  52.644  1
376783  96.658  -68.394  52.609  1
376784  96.684  -68.397  52.573  1
376785  96.715  -68.401  52.537  1
376786  96.746  -68.406  52.503  1
376787  96.777  -68.410  52.467  1
376788  96.807  -68.415  52.432  1
376789  96.838  -68.420  52.401  1
376790  96.867  -68.422  52.368  1
376791  96.892  -68.416  52.335  1
376792  96.918  -68.410  52.302  1
376793  96.943  -68.405  52.270  1
376794  96.968  -68.400  52.239  1
376795  97.026  -68.433  52.215  1
376796  97.086  -68.476  52.195  1
376797  97.145  -68.491  52.179  1
376798  97.202  -68.491  52.167  1
376799  97.236  -68.497  52.163  1
376800  97.270  -68.506  52.165  1
376801  97.293  -68.502  52.170  1
376802  97.315  -68.497  52.177  1
376803  97.338  -68.492  52.183  1
376804  97.361  -68.486  52.183  1
376805  97.383  -68.481  52.176  1
376806  97.405  -68.476  52.162  1
376807  97.429  -68.470  52.142  1
376808  97.459  -68.463  52.114  1
376809  97.493  -68.463  52.082  1
376810  97.526  -68.466  52.048  1
376811  97.560  -68.470  52.013  1
376812  97.594  -68.473  51.976  1
376813  97.628  -68.477  51.939  1
376814  97.661  -68.480  51.902  1
376815  97.695  -68.485  51.866  1
376816  97.727  -68.490  51.829  1
376817  97.759  -68.495  51.794  1
376818  97.793  -68.497  51.758  1
376819  97.832  -68.504  51.719  1
376820  97.870  -68.510  51.673  1
376821  97.909  -68.517  51.624  1
376822  97.947  -68.523  51.572  1
376823  97.986  -68.530  51.520  1
376824  98.024  -68.537  51.468  1
376825  98.063  -68.543  51.416  1
376826  98.101  -68.550  51.359  1
376827  98.138  -68.556  51.302  1
376828  98.174  -68.561  51.246  1
376829  98.180  -68.563  51.190  1
376830  98.189  -68.565  51.136  1
376831  98.238  -68.573  51.084  1
376832  98.289  -68.580  51.032  1
376833  98.327  -68.592  50.979  1
376834  98.363  -68.605  50.927  1
376835  98.398  -68.618  50.874  1
376836  98.434  -68.631  50.822  1
376837  98.469  -68.643  50.770  1
376838  98.505  -68.656  50.720  1
376839  98.541  -68.669  50.668  1
376840  98.582  -68.682  50.618  1
376841  98.622  -68.694  50.570  1
376842  98.663  -68.707  50.525  1
376843  98.703  -68.719  50.480  1
376844  98.744  -68.731  50.436  1
376845  98.784  -68.744  50.391  1
376846  98.805  -68.743  50.344  1
376847  98.822  -68.740  50.297  1
376848  98.869  -68.754  50.249  1
376849  98.917  -68.767  50.203  1
376850  98.963  -68.780  50.158  1
376851  98.993  -68.770  50.114  1
376852  99.023  -68.761  50.068  1
376853  99.053  -68.753  50.021  1
376854  99.083  -68.744  49.972  1
376855  99.120  -68.775  49.924  1
376856  99.158  -68.809  49.876  1
376857  99.196  -68.844  49.827  1
376858  99.225  -68.870  49.778  1
376859  99.248  -68.889  49.728  1
376860  99.268  -68.904  49.678  1
376861  99.284  -68.915  49.628  1
376862  99.301  -68.925  49.580  1
376863  99.317  -68.936  49.535  1
376864  99.334  -68.946  49.490  1
376865  99.362  -68.955  49.445  1
376866  99.410  -68.961  49.402  1
376867  99.458  -68.966  49.357  1
376868  99.506  -68.972  49.311  1
376869  99.554  -68.977  49.267  1
376870  99.602  -68.983  49.224  1
376871  99.640  -68.991  49.181  1
376872  99.677  -69.000  49.138  1
376873  99.729  -69.009  49.094  1
376874  99.781  -69.016  49.047  1
376875  99.830  -69.022  48.999  1
376876  99.875  -69.027  48.950  1
376877  99.921  -69.032  48.900  1
376878  99.967  -69.037  48.850  1
376879  100.012  -69.043  48.800  1
376880  100.058  -69.047  48.748  1
376881  100.104  -69.052  48.695  1
376882  100.129  -69.059  48.642  1
376883  100.151  -69.065  48.590  1
376884  100.173  -69.071  48.536  1
376885  100.219  -69.093  48.485  1
376886  100.266  -69.123  48.435  1
376887  100.294  -69.103  48.383  1
376888  100.325  -69.100  48.336  1
376889  100.355  -69.097  48.290  1
376890  100.385  -69.093  48.247  1
376891  100.416  -69.090  48.206  1
376892  100.447  -69.115  48.165  1
376893  100.479  -69.153  48.126  1
376894  100.511  -69.192  48.086  1
376895  100.544  -69.231  48.048  1
376896  100.575  -69.270  48.011  1
376897  100.605  -69.275  47.975  1
376898  100.634  -69.279  47.939  1
376899  100.663  -69.284  47.903  1
376900  100.692  -69.289  47.867  1
376901  100.724  -69.291  47.833  1
377337  90.669  -68.440  54.766  1
377338  90.700  -68.451  54.764  1
377339  90.732  -68.461  54.763  1
377340  90.763  -68.472  54.765  1
377341  90.794  -68.482  54.769  1
377342  90.825  -68.493  54.774  1
377343  90.867  -68.511  54.781  1
377344  90.926  -68.541  54.790  1
377345  90.984  -68.570  54.799  1
377346  91.042  -68.599  54.808  1
377347  91.101  -68.628  54.818  1
377348  91.159  -68.658  54.827  1
377349  91.217  -68.687  54.833  1
377350  91.276  -68.717  54.833  1
377351  91.326  -68.753  54.829  1
377352  91.376  -68.752  54.815  1
377353  91.427  -68.750  54.800  1
377354  91.476  -68.748  54.783  1
377355  91.527  -68.746  54.766  1
377356  91.577  -68.745  54.749  1
377357  91.627  -68.743  54.731  1
377358  91.670  -68.743  54.714  1
377359  91.712  -68.744  54.697  1
377360  91.754  -68.745  54.680  1
377361  91.797  -68.745  54.665  1
377362  91.839  -68.747  54.652  1
377363  91.883  -68.742  54.640  1
377364  91.928  -68.737  54.629  1
377365  91.972  -68.731  54.619  1
377366  92.017  -68.726  54.610  1
377367  92.062  -68.720  54.600  1
377368  92.106  -68.714  54.590  1
377369  92.151  -68.708  54.580  1
377370  92.196  -68.703  54.569  1
377371  92.241  -68.697  54.558  1
377372  92.285  -68.692  54.546  1
377373  92.330  -68.686  54.533  1
377374  92.375  -68.680  54.520  1
377375  92.420  -68.675  54.507  1
377376  92.464  -68.669  54.495  1
377377  92.509  -68.664  54.484  1
377378  92.554  -68.658  54.474  1
377379  92.598  -68.652  54.459  1
377380  92.643  -68.646  54.443  1
377381  92.688  -68.641  54.424  1
377382  92.732  -68.635  54.403  1
377383  92.777  -68.629  54.380  1
377384  92.822  -68.623  54.357  1
377385  92.867  -68.618  54.331  1
377386  92.912  -68.612  54.303  1
377387  92.960  -68.610  54.275  1
377388  93.010  -68.607  54.246  1
377389  93.060  -68.604  54.218  1
377390  93.108  -68.601  54.190  1
377391  93.154  -68.592  54.162  1
377392  93.199  -68.582  54.133  1
377393  93.245  -68.573  54.105  1
377394  93.290  -68.563  54.077  1
377395  93.336  -68.553  54.050  1
377396  93.381  -68.544  54.023  1
377397  93.427  -68.534  53.999  1
377398  93.473  -68.525  53.974  1
377399  93.518  -68.515  53.950  1
377400  93.564  -68.505  53.927  1
377401  93.610  -68.496  53.904  1
377402  93.655  -68.486  53.882  1
377403  93.701  -68.477  53.860  1
377404  93.746  -68.467  53.839  1
377405  93.792  -68.457  53.819  1
377406  93.837  -68.448  53.798  1
377407  93.883  -68.438  53.778  1
377408  93.928  -68.429  53.759  1
377409  93.974  -68.419  53.740  1
377410  94.019  -68.410  53.721  1
377411  94.065  -68.401  53.703  1
377412  94.111  -68.391  53.686  1
377413  94.156  -68.381  53.669  1
377414  94.202  -68.372  53.651  1
377415  94.248  -68.362  53.635  1
377416  94.293  -68.353  53.618  1
377417  94.339  -68.343  53.603  1
377418  94.384  -68.333  53.587  1
377419  94.430  -68.324  53.571  1
377420  94.475  -68.314  53.557  1
377421  94.521  -68.305  53.542  1
377430  94.844  -68.296  53.435  1
377431  94.875  -68.285  53.423  1
377432  94.906  -68.274  53.410  1
377433  94.936  -68.263  53.398  1
377434  94.967  -68.252  53.385  1
377435  94.997  -68.241  53.371  1
377436  95.028  -68.230  53.357  1
377437  95.058  -68.219  53.344  1
377438  95.089  -68.208  53.330  1
377439  95.119  -68.197  53.316  1
377440  95.149  -68.186  53.303  1
377441  95.180  -68.175  53.291  1
377442  95.211  -68.164  53.278  1
377443  95.241  -68.153  53.268  1
377444  95.272  -68.142  53.258  1
377445  95.303  -68.131  53.249  1
377446  95.333  -68.121  53.241  1
377447  95.365  -68.122  53.232  1
377448  95.397  -68.135  53.223  1
377449  95.429  -68.149  53.216  1
377450  95.461  -68.162  53.211  1
377451  95.502  -68.173  53.206  1
377452  95.543  -68.184  53.200  1
377453  95.584  -68.194  53.193  1
377454  95.625  -68.205  53.184  1
377455  95.666  -68.216  53.175  1
377456  95.706  -68.226  53.167  1
377457  95.748  -68.235  53.158  1
377458  95.788  -68.243  53.148  1
377459  95.829  -68.250  53.140  1
377460  95.870  -68.258  53.129  1
377461  95.910  -68.266  53.118  1
377462  95.945  -68.270  53.106  1
377463  95.983  -68.275  53.093  1
377464  96.021  -68.281  53.082  1
377465  96.058  -68.286  53.074  1
377466  96.094  -68.291  53.065  1
377467  96.130  -68.296  53.053  1
377468  96.166  -68.301  53.039  1
377469  96.201  -68.306  53.022  1
377470  96.237  -68.311  53.002  1
377471  96.273  -68.316  52.980  1
377472  96.309  -68.321  52.956  1
377473  96.345  -68.326  52.926  1
377474  96.381  -68.331  52.896  1
377475  96.416  -68.336  52.867  1
377476  96.452  -68.341  52.838  1
377477  96.488  -68.346  52.812  1
377478  96.524  -68.351  52.785  1
377479  96.549  -68.353  52.756  1
377480  96.572  -68.354  52.726  1
377481  96.594  -68.356  52.695  1
377482  96.617  -68.357  52.662  1
377483  96.640  -68.358  52.628  1
377484  96.663  -68.360  52.594  1
377485  96.693  -68.364  52.560  1
377486  96.724  -68.369  52.526  1
377487  96.755  -68.373  52.492  1
377488  96.786  -68.378  52.458  1
377489  96.816  -68.383  52.424  1
377490  96.847  -68.388  52.393  1
377491  96.878  -68.392  52.362  1
377492  96.906  -68.393  52.329  1
377493  96.932  -68.388  52.298  1
377494  96.957  -68.382  52.268  1
377495  96.982  -68.376  52.240  1
377496  97.033  -68.446  52.217  1
377497  97.092  -68.453  52.199  1
377498  97.150  -68.453  52.185  1
377499  97.199  -68.454  52.176  1
377500  97.234  -68.459  52.175  1
377501  97.267  -68.468  52.178  1
377502  97.300  -68.477  52.184  1
377503  97.322  -68.472  52.191  1
377504  97.345  -68.466  52.192  1
377505  97.368  -68.461  52.186  1
377506  97.390  -68.456  52.174  1
377507  97.413  -68.451  52.155  1
377508  97.435  -68.446  52.131  1
377509  97.466  -68.438  52.102  1
377510  97.497  -68.432  52.069  1
377511  97.530  -68.435  52.035  1
377512  97.564  -68.438  52.000  1
377513  97.598  -68.442  51.964  1
377514  97.632  -68.445  51.928  1
377515  97.665  -68.449  51.891  1
377516  97.699  -68.452  51.855  1
377517  97.733  -68.456  51.819  1
377518  97.768  -68.460  51.785  1
377519  97.810  -68.467  51.748  1
377520  97.851  -68.475  51.708  1
377521  97.889  -68.481  51.661  1
377522  97.928  -68.488  51.609  1
377523  97.966  -68.495  51.557  1
377524  98.005  -68.501  51.504  1
377525  98.043  -68.507  51.451  1
377526  98.082  -68.514  51.397  1
377527  98.120  -68.521  51.338  1
377528  98.158  -68.527  51.280  1
377529  98.180  -68.531  51.223  1
377530  98.184  -68.532  51.167  1
377531  98.196  -68.535  51.112  1
377532  98.246  -68.542  51.059  1
377533  98.296  -68.551  51.007  1
377534  98.342  -68.560  50.955  1
377535  98.377  -68.573  50.903  1
377536  98.413  -68.586  50.852  1
377537  98.448  -68.598  50.801  1
377538  98.483  -68.611  50.750  1
377539  98.519  -68.623  50.701  1
377540  98.554  -68.636  50.650  1
377541  98.589  -68.649  50.601  1
377542  98.626  -68.662  50.555  1
377543  98.667  -68.675  50.510  1
377544  98.707  -68.687  50.465  1
377545  98.748  -68.699  50.422  1
377546  98.788  -68.712  50.376  1
377547  98.811  -68.713  50.329  1
377548  98.841  -68.717  50.285  1
377549  98.888  -68.730  50.240  1
377550  98.931  -68.737  50.196  1
377551  98.960  -68.729  50.153  1
377552  98.991  -68.720  50.109  1
377553  99.020  -68.711  50.062  1
377554  99.050  -68.702  50.015  1
377555  99.082  -68.705  49.967  1
377556  99.120  -68.739  49.920  1
377557  99.158  -68.774  49.872  1
377558  99.196  -68.808  49.823  1
377559  99.231  -68.839  49.774  1
377560  99.255  -68.858  49.724  1
377561  99.273  -68.871  49.674  1
377562  99.289  -68.882  49.624  1
377563  99.305  -68.893  49.577  1
377564  99.322  -68.903  49.530  1
377565  99.338  -68.914  49.483  1
377566  99.359  -68.924  49.439  1
377567  99.407  -68.930  49.396  1
377568  99.454  -68.935  49.353  1
377569  99.502  -68.940  49.310  1
377570  99.550  -68.946  49.266  1
377571  99.598  -68.952  49.224  1
377572  99.646  -68.957  49.182  1
377573  99.683  -68.965  49.139  1
377574  99.733  -68.974  49.094  1
377575  99.783  -68.980  49.047  1
377576  99.829  -68.985  48.999  1
377577  99.874  -68.990  48.950  1
377578  99.920  -68.996  48.900  1
377579  99.966  -69.000  48.851  1
377580  100.012  -69.005  48.799  1
377581  100.057  -69.011  48.747  1
377582  100.103  -69.015  48.694  1
377583  100.137  -69.021  48.640  1
377584  100.159  -69.027  48.587  1
377585  100.188  -69.038  48.534  1
377586  100.239  -69.064  48.482  1
377587  100.264  -69.048  48.431  1
377588  100.294  -69.045  48.380  1
377589  100.325  -69.042  48.332  1
377590  100.355  -69.038  48.287  1
377591  100.386  -69.035  48.244  1
377592  100.417  -69.060  48.203  1
377593  100.450  -69.099  48.163  1
377594  100.482  -69.137  48.123  1
377595  100.514  -69.177  48.084  1
377596  100.546  -69.215  48.045  1
377597  100.576  -69.230  48.007  1
377598  100.605  -69.234  47.971  1
377599  100.634  -69.239  47.936  1
377600  100.663  -69.244  47.900  1
377601  100.694  -69.247  47.864  1
378038  90.657  -68.408  54.762  1
378039  90.688  -68.419  54.760  1
378040  90.720  -68.429  54.761  1
378041  90.751  -68.439  54.763  1
378042  90.782  -68.450  54.767  1
378043  90.813  -68.460  54.772  1
378044  90.861  -68.483  54.780  1
378045  90.920  -68.512  54.789  1
378046  90.978  -68.542  54.799  1
378047  91.036  -68.571  54.807  1
378048  91.095  -68.600  54.816  1
378049  91.153  -68.629  54.823  1
378050  91.211  -68.659  54.828  1
378051  91.269  -68.692  54.828  1
378052  91.319  -68.696  54.821  1
378053  91.369  -68.694  54.808  1
378054  91.419  -68.692  54.792  1
378055  91.469  -68.691  54.776  1
378056  91.520  -68.689  54.759  1
378057  91.570  -68.687  54.742  1
378058  91.620  -68.686  54.724  1
378059  91.665  -68.686  54.707  1
378060  91.708  -68.686  54.691  1
378061  91.750  -68.687  54.673  1
378062  91.792  -68.688  54.658  1
378063  91.834  -68.689  54.645  1
378064  91.876  -68.689  54.633  1
378065  91.921  -68.686  54.622  1
378066  91.965  -68.680  54.613  1
378067  92.010  -68.674  54.605  1
378068  92.055  -68.668  54.596  1
378069  92.099  -68.663  54.587  1
378070  92.144  -68.658  54.578  1
378071  92.189  -68.651  54.568  1
378072  92.233  -68.646  54.558  1
378073  92.278  -68.640  54.547  1
378074  92.323  -68.635  54.536  1
378075  92.368  -68.629  54.524  1
378076  92.412  -68.623  54.513  1
378077  92.457  -68.617  54.503  1
378078  92.502  -68.612  54.493  1
378079  92.547  -68.606  54.483  1
378080  92.591  -68.601  54.469  1
378081  92.636  -68.595  54.452  1
378082  92.681  -68.589  54.432  1
378083  92.725  -68.583  54.411  1
378084  92.770  -68.578  54.388  1
378085  92.815  -68.572  54.364  1
378086  92.862  -68.568  54.339  1
378087  92.911  -68.566  54.311  1
378088  92.960  -68.563  54.282  1
378089  93.010  -68.560  54.253  1
378090  93.060  -68.557  54.225  1
378091  93.110  -68.554  54.197  1
378092  93.158  -68.552  54.170  1
378093  93.207  -68.549  54.142  1
378094  93.256  -68.545  54.114  1
378095  93.301  -68.535  54.087  1
378096  93.347  -68.526  54.061  1
378097  93.393  -68.517  54.035  1
378098  93.438  -68.507  54.012  1
378099  93.484  -68.497  53.988  1
378100  93.529  -68.488  53.964  1
378101  93.575  -68.478  53.941  1
378102  93.620  -68.469  53.919  1
378103  93.666  -68.459  53.898  1
378104  93.711  -68.449  53.876  1
378105  93.757  -68.440  53.855  1
378106  93.802  -68.430  53.835  1
378107  93.848  -68.421  53.814  1
378108  93.894  -68.411  53.794  1
378109  93.939  -68.401  53.775  1
378110  93.985  -68.392  53.755  1
378111  94.031  -68.382  53.736  1
378112  94.076  -68.373  53.717  1
378113  94.122  -68.363  53.700  1
378114  94.167  -68.354  53.682  1
378115  94.213  -68.344  53.663  1
378116  94.258  -68.335  53.646  1
378117  94.304  -68.325  53.629  1
378118  94.349  -68.316  53.611  1
378119  94.395  -68.306  53.595  1
378120  94.440  -68.297  53.578  1
378121  94.486  -68.287  53.563  1
378122  94.532  -68.277  53.548  1
378123  94.577  -68.268  53.533  1
378132  94.880  -68.249  53.424  1
378133  94.911  -68.238  53.411  1
378134  94.942  -68.227  53.397  1
378135  94.972  -68.216  53.383  1
378136  95.002  -68.205  53.368  1
378137  95.033  -68.194  53.354  1
378138  95.063  -68.183  53.340  1
378139  95.094  -68.172  53.325  1
378140  95.124  -68.161  53.310  1
378141  95.155  -68.150  53.296  1
378142  95.185  -68.139  53.283  1
378143  95.216  -68.128  53.269  1
378144  95.247  -68.118  53.256  1
378145  95.277  -68.106  53.246  1
378146  95.306  -68.095  53.237  1
378147  95.331  -68.083  53.228  1
378148  95.368  -68.094  53.219  1
378149  95.401  -68.107  53.210  1
378150  95.433  -68.120  53.200  1
378151  95.466  -68.134  53.194  1
378152  95.505  -68.145  53.187  1
378153  95.546  -68.156  53.181  1
378154  95.587  -68.166  53.173  1
378155  95.628  -68.177  53.164  1
378156  95.669  -68.186  53.155  1
378157  95.709  -68.194  53.148  1
378158  95.750  -68.201  53.140  1
378159  95.791  -68.209  53.131  1
378160  95.832  -68.216  53.121  1
378161  95.873  -68.224  53.109  1
378162  95.913  -68.231  53.097  1
378163  95.946  -68.235  53.085  1
378164  95.984  -68.241  53.072  1
378165  96.022  -68.246  53.064  1
378166  96.059  -68.251  53.055  1
378167  96.097  -68.256  53.045  1
378168  96.134  -68.261  53.032  1
378169  96.170  -68.266  53.015  1
378170  96.205  -68.272  52.996  1
378171  96.241  -68.276  52.975  1
378172  96.277  -68.282  52.951  1
378173  96.313  -68.287  52.927  1
378174  96.348  -68.291  52.901  1
378175  96.384  -68.297  52.873  1
378176  96.420  -68.301  52.846  1
378177  96.456  -68.307  52.819  1
378178  96.492  -68.312  52.792  1
378179  96.528  -68.316  52.764  1
378180  96.553  -68.319  52.735  1
378181  96.576  -68.320  52.706  1
378182  96.599  -68.321  52.676  1
378183  96.621  -68.322  52.644  1
378184  96.644  -68.323  52.612  1
378185  96.671  -68.327  52.580  1
378186  96.702  -68.332  52.548  1
378187  96.733  -68.336  52.515  1
378188  96.764  -68.341  52.481  1
378189  96.795  -68.346  52.448  1
378190  96.825  -68.350  52.416  1
378191  96.856  -68.355  52.386  1
378192  96.887  -68.360  52.356  1
378193  96.918  -68.364  52.324  1
378194  96.946  -68.364  52.294  1
378195  96.971  -68.359  52.265  1
378196  96.997  -68.354  52.239  1
378197  97.037  -68.398  52.219  1
378198  97.097  -68.414  52.203  1
378199  97.155  -68.414  52.191  1
378200  97.196  -68.416  52.184  1
378201  97.232  -68.421  52.186  1
378202  97.264  -68.430  52.190  1
378203  97.298  -68.439  52.197  1
378204  97.329  -68.447  52.202  1
378205  97.352  -68.441  52.199  1
378206  97.375  -68.436  52.188  1
378207  97.397  -68.432  52.170  1
378208  97.420  -68.426  52.147  1
378209  97.442  -68.421  52.120  1
378210  97.472  -68.413  52.089  1
378211  97.503  -68.406  52.056  1
378212  97.534  -68.404  52.022  1
378213  97.568  -68.407  51.987  1
378214  97.602  -68.410  51.951  1
378215  97.636  -68.414  51.915  1
378216  97.670  -68.417  51.879  1
378217  97.704  -68.421  51.844  1
378218  97.737  -68.424  51.810  1
378219  97.772  -68.429  51.775  1
378220  97.811  -68.435  51.738  1
378221  97.853  -68.443  51.697  1
378222  97.895  -68.450  51.649  1
378223  97.937  -68.457  51.596  1
378224  97.979  -68.464  51.543  1
378225  98.020  -68.472  51.490  1
378226  98.062  -68.479  51.435  1
378227  98.101  -68.485  51.381  1
378228  98.140  -68.492  51.323  1
378229  98.177  -68.498  51.265  1
378230  98.184  -68.500  51.209  1
378231  98.189  -68.501  51.151  1
378232  98.203  -68.504  51.096  1
378233  98.253  -68.512  51.043  1
378234  98.303  -68.520  50.989  1
378235  98.353  -68.528  50.936  1
378236  98.391  -68.540  50.883  1
378237  98.426  -68.553  50.832  1
378238  98.462  -68.566  50.782  1
378239  98.497  -68.579  50.733  1
378240  98.533  -68.592  50.686  1
378241  98.568  -68.604  50.638  1
378242  98.603  -68.617  50.592  1
378243  98.639  -68.629  50.547  1
378244  98.674  -68.642  50.502  1
378245  98.711  -68.655  50.456  1
378246  98.752  -68.667  50.412  1
378247  98.792  -68.680  50.366  1
378248  98.817  -68.683  50.321  1
378249  98.860  -68.694  50.278  1
378250  98.899  -68.695  50.234  1
378251  98.928  -68.686  50.190  1
378252  98.958  -68.678  50.147  1
378253  98.988  -68.669  50.103  1
378254  99.018  -68.660  50.055  1
378255  99.048  -68.651  50.007  1
378256  99.082  -68.668  49.960  1
378257  99.121  -68.702  49.913  1
378258  99.158  -68.737  49.865  1
378259  99.197  -68.771  49.817  1
378260  99.234  -68.806  49.769  1
378261  99.261  -68.828  49.720  1
378262  99.277  -68.839  49.670  1
378263  99.293  -68.850  49.621  1
378264  99.310  -68.861  49.573  1
378265  99.327  -68.871  49.525  1
378266  99.343  -68.882  49.478  1
378267  99.359  -68.893  49.433  1
378268  99.403  -68.899  49.390  1
378269  99.451  -68.904  49.348  1
378270  99.499  -68.909  49.306  1
378271  99.547  -68.915  49.264  1
378272  99.595  -68.921  49.223  1
378273  99.643  -68.926  49.181  1
378274  99.691  -68.931  49.138  1
378275  99.736  -68.939  49.094  1
378276  99.782  -68.943  49.047  1
378277  99.828  -68.949  48.998  1
378278  99.874  -68.954  48.949  1
378279  99.919  -68.958  48.900  1
378280  99.965  -68.964  48.850  1
378281  100.011  -68.969  48.798  1
378282  100.057  -68.974  48.745  1
378283  100.102  -68.979  48.692  1
378284  100.146  -68.984  48.638  1
378285  100.168  -68.990  48.583  1
378286  100.208  -69.009  48.531  1
378287  100.223  -69.046  48.478  1
378288  100.265  -68.990  48.427  1
378289  100.295  -68.987  48.377  1
378290  100.326  -68.983  48.330  1
378291  100.356  -68.980  48.285  1
378292  100.388  -69.005  48.242  1
378293  100.420  -69.044  48.201  1
378294  100.452  -69.083  48.160  1
378295  100.484  -69.121  48.120  1
378296  100.516  -69.161  48.081  1
378297  100.547  -69.185  48.042  1
378298  100.576  -69.190  48.003  1
378299  100.605  -69.194  47.968  1
378300  100.634  -69.199  47.932  1
378301  100.664  -69.203  47.897  1
378739  90.645  -68.376  54.759  1
378740  90.676  -68.386  54.757  1
378741  90.708  -68.397  54.759  1
378742  90.739  -68.407  54.762  1
378743  90.770  -68.418  54.766  1
378744  90.801  -68.429  54.772  1
378745  90.855  -68.455  54.780  1
378746  90.913  -68.484  54.790  1
378747  90.972  -68.513  54.799  1
378748  91.030  -68.542  54.807  1
378749  91.089  -68.572  54.814  1
378750  91.147  -68.601  54.821  1
378751  91.205  -68.630  54.824  1
378752  91.261  -68.643  54.822  1
378753  91.312  -68.639  54.814  1
378754  91.362  -68.637  54.801  1
378755  91.412  -68.636  54.785  1
378756  91.462  -68.633  54.769  1
378757  91.512  -68.632  54.751  1
378758  91.563  -68.630  54.734  1
378759  91.612  -68.628  54.716  1
378760  91.661  -68.627  54.699  1
378761  91.703  -68.628  54.683  1
378762  91.745  -68.629  54.667  1
378763  91.787  -68.629  54.652  1
378764  91.829  -68.630  54.637  1
378765  91.872  -68.631  54.626  1
378766  91.914  -68.632  54.616  1
378767  91.958  -68.628  54.608  1
378768  92.003  -68.623  54.600  1
378769  92.048  -68.617  54.592  1
378770  92.092  -68.611  54.584  1
378771  92.137  -68.606  54.575  1
378772  92.181  -68.600  54.567  1
378773  92.226  -68.595  54.558  1
378774  92.271  -68.589  54.548  1
378775  92.316  -68.583  54.538  1
378776  92.360  -68.577  54.528  1
378777  92.405  -68.572  54.519  1
378778  92.450  -68.566  54.510  1
378779  92.495  -68.560  54.501  1
378780  92.540  -68.554  54.490  1
378781  92.584  -68.549  54.475  1
378782  92.629  -68.543  54.458  1
378783  92.673  -68.538  54.438  1
378784  92.718  -68.532  54.417  1
378785  92.763  -68.526  54.394  1
378786  92.812  -68.524  54.370  1
378787  92.862  -68.521  54.344  1
378788  92.911  -68.519  54.316  1
378789  92.960  -68.517  54.287  1
378790  93.010  -68.513  54.259  1
378791  93.060  -68.510  54.231  1
378792  93.110  -68.508  54.204  1
378793  93.159  -68.505  54.177  1
378794  93.209  -68.502  54.150  1
378795  93.258  -68.500  54.123  1
378796  93.306  -68.497  54.097  1
378797  93.355  -68.494  54.071  1
378798  93.403  -68.488  54.047  1
378799  93.448  -68.479  54.024  1
378800  93.494  -68.470  54.001  1
378801  93.540  -68.460  53.978  1
378802  93.585  -68.451  53.956  1
378803  93.631  -68.441  53.934  1
378804  93.677  -68.432  53.913  1
378805  93.722  -68.422  53.893  1
378806  93.768  -68.413  53.872  1
378807  93.813  -68.403  53.851  1
378808  93.859  -68.393  53.831  1
378809  93.904  -68.384  53.811  1
378810  93.950  -68.374  53.791  1
378811  93.995  -68.365  53.771  1
378812  94.041  -68.355  53.751  1
378813  94.086  -68.345  53.733  1
378814  94.132  -68.336  53.714  1
378815  94.178  -68.326  53.695  1
378816  94.223  -68.317  53.677  1
378817  94.269  -68.307  53.658  1
378818  94.315  -68.297  53.640  1
378819  94.360  -68.288  53.621  1
378820  94.406  -68.278  53.603  1
378821  94.451  -68.269  53.586  1
378822  94.497  -68.260  53.569  1
378823  94.542  -68.250  53.554  1
378824  94.588  -68.241  53.539  1
378825  94.633  -68.231  53.524  1
378826  94.679  -68.221  53.511  1
378834  94.916  -68.202  53.412  1
378835  94.947  -68.191  53.397  1
378836  94.977  -68.180  53.381  1
378837  95.007  -68.169  53.366  1
378838  95.038  -68.158  53.351  1
378839  95.068  -68.147  53.336  1
378840  95.099  -68.136  53.320  1
378841  95.130  -68.125  53.305  1
378842  95.160  -68.115  53.290  1
378843  95.191  -68.103  53.275  1
378844  95.221  -68.093  53.260  1
378845  95.247  -68.080  53.246  1
378846  95.272  -68.067  53.235  1
378847  95.297  -68.053  53.224  1
378848  95.331  -68.056  53.214  1
378849  95.368  -68.065  53.205  1
378850  95.403  -68.079  53.195  1
378851  95.438  -68.092  53.186  1
378852  95.470  -68.106  53.178  1
378853  95.508  -68.117  53.169  1
378854  95.549  -68.128  53.161  1
378855  95.590  -68.137  53.152  1
378856  95.631  -68.144  53.142  1
378857  95.672  -68.152  53.133  1
378858  95.712  -68.159  53.124  1
378859  95.753  -68.167  53.116  1
378860  95.794  -68.175  53.106  1
378861  95.834  -68.182  53.096  1
378862  95.875  -68.190  53.085  1
378863  95.916  -68.197  53.074  1
378864  95.947  -68.200  53.063  1
378865  95.985  -68.206  53.052  1
378866  96.023  -68.211  53.046  1
378867  96.060  -68.216  53.038  1
378868  96.098  -68.222  53.027  1
378869  96.136  -68.227  53.013  1
378870  96.173  -68.231  52.995  1
378871  96.209  -68.237  52.976  1
378872  96.245  -68.242  52.953  1
378873  96.281  -68.247  52.928  1
378874  96.317  -68.252  52.904  1
378875  96.353  -68.257  52.878  1
378876  96.388  -68.262  52.851  1
378877  96.424  -68.267  52.825  1
378878  96.460  -68.272  52.798  1
378879  96.496  -68.277  52.772  1
378880  96.531  -68.282  52.743  1
378881  96.558  -68.285  52.714  1
378882  96.580  -68.285  52.685  1
378883  96.603  -68.287  52.658  1
378884  96.625  -68.288  52.628  1
378885  96.650  -68.290  52.597  1
378886  96.680  -68.294  52.566  1
378887  96.711  -68.299  52.535  1
378888  96.742  -68.303  52.503  1
378889  96.772  -68.308  52.471  1
378890  96.803  -68.313  52.439  1
378891  96.834  -68.318  52.408  1
378892  96.865  -68.322  52.380  1
378893  96.896  -68.327  52.350  1
378894  96.927  -68.332  52.320  1
378895  96.957  -68.337  52.290  1
378896  96.985  -68.336  52.263  1
378897  97.010  -68.330  52.238  1
378898  97.041  -68.343  52.220  1
378899  97.101  -68.376  52.206  1
378900  97.158  -68.376  52.196  1
378901  97.194  -68.379  52.192  1
378902  97.229  -68.383  52.195  1
378903  97.262  -68.392  52.201  1
378904  97.295  -68.402  52.206  1
378905  97.328  -68.411  52.210  1
378906  97.359  -68.417  52.203  1
378907  97.382  -68.412  52.186  1
378908  97.404  -68.407  52.164  1
378909  97.427  -68.401  52.138  1
378910  97.449  -68.396  52.108  1
378911  97.478  -68.389  52.075  1
378912  97.509  -68.382  52.042  1
378913  97.539  -68.374  52.008  1
378914  97.573  -68.376  51.972  1
378915  97.606  -68.379  51.937  1
378916  97.640  -68.382  51.901  1
378917  97.674  -68.385  51.865  1
378918  97.708  -68.389  51.832  1
378919  97.742  -68.394  51.800  1
378920  97.777  -68.398  51.765  1
378921  97.813  -68.404  51.728  1
378922  97.855  -68.410  51.686  1
378923  97.896  -68.418  51.637  1
378924  97.938  -68.425  51.584  1
378925  97.980  -68.432  51.531  1
378926  98.022  -68.439  51.477  1
378927  98.064  -68.447  51.422  1
378928  98.105  -68.454  51.368  1
378929  98.147  -68.461  51.312  1
378930  98.173  -68.466  51.256  1
378931  98.189  -68.470  51.200  1
378932  98.193  -68.471  51.142  1
378933  98.210  -68.474  51.086  1
378934  98.260  -68.482  51.032  1
378935  98.310  -68.490  50.977  1
378936  98.361  -68.498  50.921  1
378937  98.405  -68.507  50.866  1
378938  98.440  -68.520  50.816  1
378939  98.476  -68.533  50.767  1
378940  98.511  -68.546  50.720  1
378941  98.547  -68.559  50.675  1
378942  98.582  -68.572  50.631  1
378943  98.618  -68.585  50.587  1
378944  98.653  -68.598  50.543  1
378945  98.689  -68.610  50.497  1
378946  98.724  -68.623  50.451  1
378947  98.759  -68.636  50.405  1
378948  98.796  -68.648  50.361  1
378949  98.832  -68.657  50.317  1
378950  98.866  -68.653  50.275  1
378951  98.896  -68.645  50.230  1
378952  98.926  -68.636  50.186  1
378953  98.955  -68.626  50.141  1
378954  98.986  -68.618  50.095  1
378955  99.015  -68.609  50.047  1
378956  99.046  -68.601  49.998  1
378957  99.083  -68.632  49.950  1
378958  99.121  -68.667  49.902  1
378959  99.159  -68.701  49.855  1
378960  99.197  -68.736  49.809  1
378961  99.235  -68.770  49.762  1
378962  99.265  -68.796  49.714  1
378963  99.282  -68.807  49.666  1
378964  99.298  -68.817  49.618  1
378965  99.314  -68.828  49.569  1
378966  99.331  -68.839  49.520  1
378967  99.347  -68.849  49.473  1
378968  99.364  -68.860  49.427  1
378969  99.400  -68.868  49.384  1
378970  99.448  -68.873  49.343  1
378971  99.496  -68.878  49.302  1
378972  99.544  -68.883  49.260  1
378973  99.591  -68.889  49.219  1
378974  99.645  -68.893  49.178  1
378975  99.701  -68.896  49.136  1
378976  99.744  -68.904  49.093  1
378977  99.794  -68.909  49.047  1
378978  99.836  -68.913  48.997  1
378979  99.877  -68.918  48.948  1
378980  99.919  -68.922  48.898  1
378981  99.964  -68.927  48.847  1
378982  100.010  -68.932  48.796  1
378983  100.056  -68.937  48.743  1
378984  100.102  -68.942  48.689  1
378985  100.147  -68.947  48.634  1
378986  100.177  -68.953  48.580  1
378987  100.193  -69.009  48.527  1
378988  100.235  -68.934  48.475  1
378989  100.265  -68.931  48.423  1
378990  100.296  -68.927  48.374  1
378991  100.326  -68.924  48.328  1
378992  100.358  -68.951  48.283  1
378993  100.390  -68.990  48.240  1
378994  100.422  -69.028  48.198  1
378995  100.454  -69.067  48.157  1
378996  100.486  -69.106  48.118  1
378997  100.518  -69.140  48.079  1
378998  100.547  -69.145  48.039  1
378999  100.576  -69.150  48.001  1
379000  100.605  -69.154  47.964  1
379001  100.634  -69.159  47.928  1
379440  90.634  -68.344  54.759  1
379441  90.664  -68.354  54.758  1
379442  90.695  -68.364  54.759  1
379443  90.727  -68.375  54.762  1
379444  90.758  -68.385  54.768  1
379445  90.791  -68.398  54.774  1
379446  90.849  -68.426  54.782  1
379447  90.907  -68.456  54.791  1
379448  90.966  -68.485  54.799  1
379449  91.024  -68.514  54.806  1
379450  91.083  -68.544  54.813  1
379451  91.141  -68.573  54.819  1
379452  91.202  -68.605  54.820  1
379453  91.253  -68.595  54.817  1
379454  91.304  -68.583  54.807  1
379455  91.355  -68.579  54.795  1
379456  91.405  -68.578  54.779  1
379457  91.455  -68.576  54.762  1
379458  91.505  -68.575  54.744  1
379459  91.555  -68.573  54.727  1
379460  91.605  -68.571  54.709  1
379461  91.656  -68.570  54.692  1
379462  91.699  -68.570  54.676  1
379463  91.741  -68.570  54.660  1
379464  91.783  -68.572  54.645  1
379465  91.825  -68.573  54.632  1
379466  91.867  -68.573  54.620  1
379467  91.910  -68.574  54.611  1
379468  91.952  -68.575  54.603  1
379469  91.996  -68.571  54.595  1
379470  92.040  -68.566  54.588  1
379471  92.085  -68.560  54.580  1
379472  92.130  -68.554  54.573  1
379473  92.174  -68.548  54.566  1
379474  92.219  -68.543  54.558  1
379475  92.264  -68.537  54.550  1
379476  92.308  -68.532  54.540  1
379477  92.353  -68.526  54.532  1
379478  92.398  -68.520  54.524  1
379479  92.443  -68.514  54.516  1
379480  92.488  -68.509  54.507  1
379481  92.532  -68.503  54.495  1
379482  92.577  -68.498  54.479  1
379483  92.622  -68.492  54.461  1
379484  92.666  -68.486  54.442  1
379485  92.714  -68.482  54.421  1
379486  92.763  -68.480  54.398  1
379487  92.812  -68.477  54.375  1
379488  92.862  -68.475  54.349  1
379489  92.911  -68.472  54.320  1
379490  92.960  -68.470  54.292  1
379491  93.010  -68.466  54.264  1
379492  93.060  -68.464  54.237  1
379493  93.110  -68.461  54.209  1
379494  93.160  -68.458  54.183  1
379495  93.210  -68.456  54.156  1
379496  93.259  -68.453  54.130  1
379497  93.307  -68.450  54.105  1
379498  93.356  -68.448  54.081  1
379499  93.405  -68.445  54.058  1
379500  93.454  -68.441  54.036  1
379501  93.503  -68.439  54.013  1
379502  93.550  -68.432  53.991  1
379503  93.596  -68.423  53.970  1
379504  93.641  -68.413  53.949  1
379505  93.687  -68.404  53.929  1
379506  93.732  -68.394  53.909  1
379507  93.778  -68.385  53.889  1
379508  93.824  -68.376  53.868  1
379509  93.869  -68.366  53.848  1
379510  93.915  -68.357  53.828  1
379511  93.961  -68.347  53.808  1
379512  94.006  -68.337  53.788  1
379513  94.052  -68.328  53.768  1
379514  94.097  -68.318  53.749  1
379515  94.143  -68.309  53.729  1
379516  94.188  -68.299  53.709  1
379517  94.234  -68.289  53.689  1
379518  94.279  -68.280  53.670  1
379519  94.325  -68.270  53.651  1
379520  94.370  -68.261  53.632  1
379521  94.416  -68.251  53.613  1
379522  94.462  -68.241  53.594  1
379523  94.507  -68.232  53.577  1
379524  94.553  -68.222  53.560  1
379525  94.599  -68.213  53.544  1
379526  94.644  -68.203  53.529  1
379527  94.690  -68.194  53.515  1
379528  94.718  -68.207  53.502  1
379536  94.952  -68.155  53.397  1
379537  94.982  -68.144  53.381  1
379538  95.013  -68.133  53.365  1
379539  95.043  -68.122  53.348  1
379540  95.074  -68.112  53.332  1
379541  95.104  -68.100  53.316  1
379542  95.135  -68.090  53.300  1
379543  95.164  -68.078  53.284  1
379544  95.188  -68.065  53.267  1
379545  95.213  -68.052  53.252  1
379546  95.238  -68.038  53.237  1
379547  95.263  -68.025  53.224  1
379548  95.293  -68.020  53.212  1
379549  95.330  -68.028  53.200  1
379550  95.367  -68.037  53.190  1
379551  95.402  -68.050  53.181  1
379552  95.438  -68.064  53.172  1
379553  95.473  -68.078  53.163  1
379554  95.511  -68.087  53.152  1
379555  95.552  -68.095  53.142  1
379556  95.593  -68.103  53.132  1
379557  95.633  -68.110  53.121  1
379558  95.674  -68.118  53.111  1
379559  95.715  -68.125  53.101  1
379560  95.756  -68.133  53.092  1
379561  95.797  -68.141  53.082  1
379562  95.837  -68.148  53.071  1
379563  95.878  -68.156  53.061  1
379564  95.918  -68.163  53.051  1
379565  95.949  -68.166  53.041  1
379566  95.986  -68.171  53.032  1
379567  96.024  -68.176  53.026  1
379568  96.061  -68.181  53.018  1
379569  96.099  -68.187  53.007  1
379570  96.137  -68.192  52.993  1
379571  96.175  -68.197  52.975  1
379572  96.213  -68.202  52.956  1
379573  96.249  -68.207  52.934  1
379574  96.285  -68.213  52.909  1
379575  96.320  -68.217  52.885  1
379576  96.356  -68.222  52.858  1
379577  96.392  -68.228  52.831  1
379578  96.428  -68.232  52.803  1
379579  96.464  -68.238  52.777  1
379580  96.500  -68.242  52.751  1
379581  96.535  -68.247  52.723  1
379582  96.562  -68.250  52.694  1
379583  96.585  -68.251  52.667  1
379584  96.607  -68.252  52.640  1
379585  96.629  -68.253  52.612  1
379586  96.659  -68.257  52.583  1
379587  96.689  -68.262  52.553  1
379588  96.720  -68.266  52.523  1
379589  96.751  -68.271  52.492  1
379590  96.782  -68.276  52.461  1
379591  96.812  -68.281  52.430  1
379592  96.843  -68.285  52.399  1
379593  96.874  -68.290  52.371  1
379594  96.904  -68.294  52.343  1
379595  96.935  -68.300  52.314  1
379596  96.966  -68.304  52.286  1
379597  96.997  -68.309  52.260  1
379598  97.024  -68.307  52.239  1
379599  97.049  -68.302  52.224  1
379600  97.106  -68.337  52.212  1
379601  97.155  -68.338  52.203  1
379602  97.191  -68.341  52.200  1
379603  97.227  -68.345  52.202  1
379604  97.260  -68.355  52.207  1
379605  97.293  -68.364  52.212  1
379606  97.326  -68.373  52.213  1
379607  97.359  -68.382  52.202  1
379608  97.389  -68.387  52.183  1
379609  97.411  -68.382  52.158  1
379610  97.434  -68.376  52.130  1
379611  97.456  -68.371  52.098  1
379612  97.485  -68.364  52.064  1
379613  97.515  -68.357  52.031  1
379614  97.545  -68.350  51.996  1
379615  97.577  -68.344  51.960  1
379616  97.610  -68.347  51.925  1
379617  97.644  -68.350  51.889  1
379618  97.678  -68.354  51.853  1
379619  97.712  -68.358  51.821  1
379620  97.747  -68.363  51.790  1
379621  97.781  -68.367  51.756  1
379622  97.816  -68.372  51.718  1
379623  97.856  -68.379  51.677  1
379624  97.898  -68.385  51.629  1
379625  97.940  -68.393  51.578  1
379626  97.982  -68.400  51.524  1
379627  98.023  -68.407  51.471  1
379628  98.065  -68.415  51.418  1
379629  98.105  -68.422  51.366  1
379630  98.127  -68.426  51.311  1
379631  98.150  -68.431  51.254  1
379632  98.172  -68.435  51.197  1
379633  98.195  -68.440  51.140  1
379634  98.217  -68.444  51.083  1
379635  98.267  -68.452  51.028  1
379636  98.315  -68.460  50.973  1
379637  98.361  -68.470  50.917  1
379638  98.408  -68.479  50.863  1
379639  98.445  -68.491  50.812  1
379640  98.481  -68.504  50.764  1
379641  98.516  -68.517  50.717  1
379642  98.552  -68.529  50.671  1
379643  98.587  -68.542  50.628  1
379644  98.623  -68.555  50.584  1
379645  98.658  -68.568  50.540  1
379646  98.694  -68.580  50.494  1
379647  98.729  -68.593  50.447  1
379648  98.764  -68.606  50.401  1
379649  98.800  -68.619  50.355  1
379650  98.834  -68.617  50.311  1
379651  98.863  -68.602  50.267  1
379652  98.894  -68.594  50.223  1
379653  98.923  -68.585  50.178  1
379654  98.953  -68.576  50.132  1
379655  98.983  -68.567  50.085  1
379656  99.013  -68.558  50.036  1
379657  99.045  -68.561  49.987  1
379658  99.083  -68.595  49.937  1
379659  99.121  -68.630  49.889  1
379660  99.159  -68.664  49.842  1
379661  99.201  -68.705  49.797  1
379662  99.244  -68.744  49.751  1
379663  99.279  -68.758  49.705  1
379664  99.300  -68.770  49.658  1
379665  99.312  -68.781  49.611  1
379666  99.325  -68.793  49.562  1
379667  99.338  -68.805  49.514  1
379668  99.352  -68.817  49.467  1
379669  99.368  -68.827  49.423  1
379670  99.397  -68.836  49.379  1
379671  99.444  -68.842  49.337  1
379672  99.500  -68.845  49.296  1
379673  99.556  -68.848  49.255  1
379674  99.613  -68.851  49.214  1
379675  99.669  -68.854  49.173  1
379676  99.715  -68.858  49.132  1
379677  99.749  -68.871  49.089  1
379678  99.802  -68.876  49.044  1
379679  99.856  -68.880  48.995  1
379680  99.905  -68.885  48.946  1
379681  99.946  -68.889  48.897  1
379682  99.987  -68.894  48.846  1
379683  100.028  -68.899  48.795  1
379684  100.070  -68.902  48.742  1
379685  100.111  -68.907  48.688  1
379686  100.153  -68.911  48.633  1
379687  100.171  -68.946  48.576  1
379688  100.201  -68.898  48.523  1
379689  100.235  -68.876  48.471  1
379690  100.266  -68.872  48.421  1
379691  100.296  -68.869  48.372  1
379692  100.328  -68.896  48.326  1
379693  100.360  -68.935  48.281  1
379694  100.392  -68.974  48.238  1
379695  100.424  -69.012  48.196  1
379696  100.457  -69.052  48.155  1
379697  100.489  -69.090  48.115  1
379698  100.518  -69.099  48.076  1
379699  100.547  -69.105  48.036  1
379700  100.576  -69.109  47.998  1
379701  100.605  -69.114  47.961  1
380140  90.590  -68.300  54.762  1
380141  90.621  -68.311  54.760  1
380142  90.653  -68.322  54.760  1
380143  90.683  -68.332  54.761  1
380144  90.715  -68.343  54.765  1
380145  90.746  -68.354  54.771  1
380146  90.785  -68.369  54.778  1
380147  90.843  -68.398  54.786  1
380148  90.901  -68.428  54.794  1
380149  90.960  -68.457  54.802  1
380150  91.018  -68.486  54.810  1
380151  91.077  -68.516  54.815  1
380152  91.135  -68.545  54.818  1
380153  91.193  -68.557  54.817  1
380154  91.244  -68.545  54.811  1
380155  91.296  -68.535  54.801  1
380156  91.347  -68.524  54.788  1
380157  91.397  -68.521  54.772  1
380158  91.448  -68.519  54.755  1
380159  91.498  -68.517  54.738  1
380160  91.548  -68.516  54.721  1
380161  91.598  -68.513  54.703  1
380162  91.648  -68.512  54.686  1
380163  91.694  -68.512  54.669  1
380164  91.736  -68.513  54.653  1
380165  91.778  -68.513  54.639  1
380166  91.820  -68.514  54.627  1
380167  91.863  -68.515  54.615  1
380168  91.905  -68.516  54.605  1
380169  91.947  -68.517  54.598  1
380170  91.989  -68.517  54.591  1
380171  92.033  -68.514  54.584  1
380172  92.078  -68.508  54.577  1
380173  92.123  -68.503  54.571  1
380174  92.167  -68.497  54.565  1
380175  92.212  -68.492  54.559  1
380176  92.257  -68.485  54.551  1
380177  92.301  -68.480  54.543  1
380178  92.346  -68.474  54.535  1
380179  92.391  -68.469  54.527  1
380180  92.436  -68.463  54.519  1
380181  92.480  -68.457  54.509  1
380182  92.525  -68.452  54.497  1
380183  92.570  -68.446  54.480  1
380184  92.615  -68.441  54.463  1
380185  92.664  -68.438  54.444  1
380186  92.714  -68.435  54.423  1
380187  92.763  -68.433  54.400  1
380188  92.812  -68.431  54.377  1
380189  92.862  -68.428  54.351  1
380190  92.911  -68.426  54.323  1
380191  92.960  -68.423  54.295  1
380192  93.010  -68.420  54.268  1
380193  93.060  -68.417  54.241  1
380194  93.110  -68.414  54.214  1
380195  93.160  -68.412  54.188  1
380196  93.210  -68.409  54.162  1
380197  93.260  -68.406  54.136  1
380198  93.308  -68.404  54.113  1
380199  93.357  -68.401  54.090  1
380200  93.407  -68.398  54.067  1
380201  93.455  -68.395  54.046  1
380202  93.504  -68.392  54.025  1
380203  93.553  -68.389  54.004  1
380204  93.602  -68.387  53.983  1
380205  93.651  -68.384  53.964  1
380206  93.698  -68.376  53.944  1
380207  93.744  -68.367  53.924  1
380208  93.789  -68.357  53.905  1
380209  93.835  -68.348  53.885  1
380210  93.880  -68.338  53.865  1
380211  93.926  -68.329  53.845  1
380212  93.971  -68.319  53.825  1
380213  94.017  -68.310  53.806  1
380214  94.062  -68.300  53.785  1
380215  94.108  -68.291  53.765  1
380216  94.153  -68.281  53.745  1
380217  94.199  -68.272  53.724  1
380218  94.245  -68.262  53.703  1
380219  94.290  -68.253  53.683  1
380220  94.336  -68.243  53.663  1
380221  94.382  -68.233  53.643  1
380222  94.427  -68.224  53.623  1
380223  94.473  -68.214  53.604  1
380224  94.518  -68.205  53.585  1
380225  94.564  -68.195  53.567  1
380226  94.609  -68.185  53.550  1
380227  94.655  -68.176  53.535  1
380228  94.695  -68.173  53.520  1
380229  94.715  -68.197  53.506  1
380230  94.743  -68.196  53.494  1
380231  94.774  -68.185  53.480  1
380237  94.957  -68.119  53.397  1
380238  94.987  -68.109  53.381  1
380239  95.018  -68.097  53.364  1
380240  95.048  -68.087  53.347  1
380241  95.079  -68.075  53.330  1
380242  95.105  -68.062  53.314  1
380243  95.130  -68.050  53.297  1
380244  95.155  -68.037  53.279  1
380245  95.180  -68.024  53.261  1
380246  95.204  -68.010  53.245  1
380247  95.229  -67.997  53.229  1
380248  95.254  -67.984  53.215  1
380249  95.292  -67.992  53.201  1
380250  95.330  -68.000  53.188  1
380251  95.367  -68.009  53.177  1
380252  95.402  -68.022  53.167  1
380253  95.438  -68.036  53.157  1
380254  95.473  -68.049  53.147  1
380255  95.514  -68.053  53.136  1
380256  95.555  -68.061  53.126  1
380257  95.596  -68.068  53.115  1
380258  95.636  -68.076  53.103  1
380259  95.677  -68.084  53.091  1
380260  95.718  -68.091  53.080  1
380261  95.758  -68.099  53.069  1
380262  95.799  -68.106  53.058  1
380263  95.840  -68.114  53.049  1
380264  95.881  -68.121  53.039  1
380265  95.920  -68.128  53.029  1
380266  95.951  -68.131  53.020  1
380267  95.986  -68.136  53.011  1
380268  96.025  -68.141  53.003  1
380269  96.062  -68.147  52.994  1
380270  96.100  -68.152  52.983  1
380271  96.138  -68.157  52.969  1
380272  96.176  -68.162  52.955  1
380273  96.214  -68.167  52.936  1
380274  96.251  -68.172  52.915  1
380275  96.289  -68.178  52.891  1
380276  96.324  -68.183  52.867  1
380277  96.360  -68.188  52.839  1
380278  96.396  -68.193  52.811  1
380279  96.432  -68.198  52.782  1
380280  96.467  -68.203  52.755  1
380281  96.503  -68.208  52.730  1
380282  96.539  -68.213  52.703  1
380283  96.566  -68.216  52.676  1
380284  96.589  -68.216  52.650  1
380285  96.611  -68.218  52.623  1
380286  96.637  -68.220  52.597  1
380287  96.667  -68.225  52.569  1
380288  96.698  -68.229  52.541  1
380289  96.729  -68.234  52.510  1
380290  96.759  -68.239  52.480  1
380291  96.791  -68.244  52.452  1
380292  96.821  -68.248  52.422  1
380293  96.852  -68.253  52.392  1
380294  96.883  -68.257  52.363  1
380295  96.913  -68.263  52.336  1
380296  96.944  -68.267  52.309  1
380297  96.975  -68.272  52.283  1
380298  97.006  -68.276  52.259  1
380299  97.036  -68.281  52.242  1
380300  97.064  -68.278  52.228  1
380301  97.111  -68.298  52.218  1
380302  97.153  -68.300  52.210  1
380303  97.189  -68.303  52.208  1
380304  97.224  -68.308  52.210  1
380305  97.257  -68.317  52.214  1
380306  97.291  -68.326  52.216  1
380307  97.324  -68.335  52.215  1
380308  97.357  -68.344  52.202  1
380309  97.390  -68.354  52.181  1
380310  97.418  -68.357  52.154  1
380311  97.441  -68.351  52.124  1
380312  97.463  -68.347  52.089  1
380313  97.491  -68.340  52.054  1
380314  97.521  -68.332  52.020  1
380315  97.552  -68.325  51.985  1
380316  97.582  -68.317  51.949  1
380317  97.615  -68.316  51.915  1
380318  97.649  -68.319  51.880  1
380319  97.682  -68.322  51.846  1
380320  97.717  -68.327  51.815  1
380321  97.751  -68.332  51.783  1
380322  97.786  -68.336  51.749  1
380323  97.820  -68.341  51.711  1
380324  97.858  -68.347  51.669  1
380325  97.899  -68.354  51.622  1
380326  97.941  -68.361  51.571  1
380327  97.983  -68.368  51.518  1
380328  98.025  -68.376  51.466  1
380329  98.059  -68.382  51.415  1
380330  98.082  -68.386  51.363  1
380331  98.104  -68.391  51.308  1
380332  98.126  -68.395  51.252  1
380333  98.151  -68.401  51.194  1
380334  98.185  -68.410  51.137  1
380335  98.218  -68.416  51.080  1
380336  98.257  -68.427  51.025  1
380337  98.304  -68.436  50.969  1
380338  98.350  -68.445  50.914  1
380339  98.396  -68.454  50.861  1
380340  98.442  -68.464  50.811  1
380341  98.478  -68.477  50.762  1
380342  98.513  -68.490  50.715  1
380343  98.549  -68.503  50.670  1
380344  98.584  -68.515  50.626  1
380345  98.619  -68.528  50.582  1
380346  98.655  -68.541  50.537  1
380347  98.690  -68.554  50.490  1
380348  98.725  -68.567  50.442  1
380349  98.761  -68.579  50.394  1
380350  98.798  -68.587  50.348  1
380351  98.833  -68.580  50.304  1
380352  98.862  -68.565  50.260  1
380353  98.891  -68.551  50.215  1
380354  98.921  -68.535  50.169  1
380355  98.951  -68.525  50.121  1
380356  98.981  -68.517  50.074  1
380357  99.011  -68.507  50.025  1
380358  99.046  -68.525  49.975  1
380359  99.083  -68.560  49.925  1
380360  99.127  -68.601  49.877  1
380361  99.176  -68.650  49.829  1
380362  99.219  -68.689  49.784  1
380363  99.250  -68.707  49.739  1
380364  99.285  -68.720  49.693  1
380365  99.325  -68.730  49.647  1
380366  99.338  -68.742  49.601  1
380367  99.350  -68.754  49.553  1
380368  99.363  -68.766  49.506  1
380369  99.375  -68.778  49.460  1
380370  99.388  -68.790  49.417  1
380371  99.411  -68.799  49.373  1
380372  99.468  -68.803  49.331  1
380373  99.523  -68.806  49.290  1
380374  99.580  -68.809  49.248  1
380375  99.636  -68.812  49.208  1
380376  99.692  -68.815  49.168  1
380377  99.726  -68.820  49.127  1
380378  99.754  -68.839  49.084  1
380379  99.808  -68.843  49.040  1
380380  99.861  -68.848  48.992  1
380381  99.915  -68.852  48.944  1
380382  99.969  -68.857  48.895  1
380383  100.014  -68.861  48.845  1
380384  100.056  -68.866  48.794  1
380385  100.097  -68.871  48.740  1
380386  100.139  -68.874  48.686  1
380387  100.148  -68.890  48.630  1
380388  100.158  -68.906  48.572  1
380389  100.206  -68.821  48.519  1
380390  100.236  -68.817  48.468  1
380391  100.267  -68.814  48.419  1
380392  100.298  -68.842  48.371  1
380393  100.330  -68.880  48.325  1
380394  100.362  -68.919  48.280  1
380395  100.395  -68.958  48.236  1
380396  100.427  -68.997  48.195  1
380397  100.459  -69.036  48.153  1
380398  100.489  -69.055  48.113  1
380399  100.518  -69.059  48.073  1
380400  100.547  -69.064  48.034  1
380401  100.576  -69.068  47.995  1
380841  90.578  -68.268  54.764  1
380842  90.609  -68.278  54.762  1
380843  90.641  -68.289  54.763  1
380844  90.672  -68.300  54.765  1
380845  90.702  -68.310  54.770  1
380846  90.734  -68.321  54.776  1
380847  90.779  -68.341  54.783  1
380848  90.837  -68.370  54.791  1
380849  90.895  -68.400  54.798  1
380850  90.954  -68.429  54.806  1
380851  91.012  -68.458  54.813  1
380852  91.071  -68.487  54.818  1
380853  91.134  -68.519  54.819  1
380854  91.184  -68.507  54.816  1
380855  91.236  -68.497  54.808  1
380856  91.287  -68.486  54.797  1
380857  91.338  -68.476  54.783  1
380858  91.390  -68.465  54.767  1
380859  91.440  -68.462  54.750  1
380860  91.491  -68.460  54.733  1
380861  91.541  -68.458  54.715  1
380862  91.591  -68.457  54.698  1
380863  91.641  -68.455  54.681  1
380864  91.689  -68.454  54.665  1
380865  91.731  -68.454  54.649  1
380866  91.774  -68.455  54.635  1
380867  91.816  -68.456  54.622  1
380868  91.858  -68.457  54.611  1
380869  91.900  -68.457  54.602  1
380870  91.942  -68.458  54.595  1
380871  91.985  -68.460  54.588  1
380872  92.027  -68.460  54.582  1
380873  92.071  -68.457  54.576  1
380874  92.116  -68.451  54.571  1
380875  92.160  -68.445  54.565  1
380876  92.205  -68.440  54.559  1
380877  92.249  -68.434  54.553  1
380878  92.294  -68.429  54.546  1
380879  92.339  -68.423  54.538  1
380880  92.384  -68.417  54.530  1
380881  92.428  -68.412  54.521  1
380882  92.473  -68.406  54.510  1
380883  92.518  -68.401  54.498  1
380884  92.566  -68.397  54.481  1
380885  92.615  -68.394  54.463  1
380886  92.664  -68.391  54.444  1
380887  92.714  -68.389  54.423  1
380888  92.763  -68.386  54.401  1
380889  92.812  -68.384  54.378  1
380890  92.862  -68.382  54.353  1
380891  92.911  -68.379  54.325  1
380892  92.960  -68.376  54.297  1
380893  93.010  -68.373  54.270  1
380894  93.060  -68.371  54.244  1
380895  93.110  -68.368  54.217  1
380896  93.160  -68.365  54.192  1
380897  93.210  -68.362  54.166  1
380898  93.260  -68.360  54.142  1
380899  93.310  -68.357  54.119  1
380900  93.359  -68.354  54.097  1
380901  93.408  -68.351  54.076  1
380902  93.457  -68.348  54.056  1
380903  93.505  -68.345  54.036  1
380904  93.554  -68.343  54.016  1
380905  93.603  -68.340  53.997  1
380906  93.652  -68.337  53.978  1
380907  93.701  -68.335  53.959  1
380908  93.750  -68.332  53.940  1
380909  93.799  -68.329  53.921  1
380910  93.845  -68.320  53.901  1
380911  93.891  -68.311  53.881  1
380912  93.936  -68.301  53.862  1
380913  93.982  -68.292  53.842  1
380914  94.028  -68.282  53.824  1
380915  94.073  -68.272  53.803  1
380916  94.119  -68.263  53.782  1
380917  94.164  -68.253  53.760  1
380918  94.210  -68.244  53.739  1
380919  94.255  -68.235  53.718  1
380920  94.301  -68.225  53.697  1
380921  94.346  -68.216  53.676  1
380922  94.392  -68.206  53.655  1
380923  94.437  -68.197  53.633  1
380924  94.483  -68.187  53.613  1
380925  94.529  -68.177  53.594  1
380926  94.574  -68.168  53.575  1
380927  94.620  -68.158  53.556  1
380928  94.666  -68.149  53.540  1
380929  94.693  -68.162  53.525  1
380930  94.718  -68.171  53.511  1
380931  94.749  -68.160  53.497  1
380932  94.779  -68.149  53.484  1
380933  94.810  -68.138  53.471  1
380939  94.993  -68.072  53.381  1
380940  95.021  -68.061  53.363  1
380941  95.046  -68.048  53.345  1
380942  95.071  -68.034  53.328  1
380943  95.096  -68.021  53.310  1
380944  95.121  -68.009  53.293  1
380945  95.145  -67.995  53.275  1
380946  95.171  -67.982  53.256  1
380947  95.195  -67.969  53.239  1
380948  95.220  -67.956  53.222  1
380949  95.253  -67.956  53.207  1
380950  95.291  -67.965  53.192  1
380951  95.329  -67.973  53.178  1
380952  95.367  -67.981  53.165  1
380953  95.402  -67.994  53.153  1
380954  95.437  -68.008  53.142  1
380955  95.474  -68.018  53.131  1
380956  95.516  -68.021  53.120  1
380957  95.557  -68.027  53.109  1
380958  95.598  -68.034  53.097  1
380959  95.639  -68.041  53.085  1
380960  95.680  -68.049  53.073  1
380961  95.721  -68.056  53.061  1
380962  95.761  -68.064  53.050  1
380963  95.802  -68.072  53.039  1
380964  95.842  -68.079  53.028  1
380965  95.883  -68.087  53.017  1
380966  95.922  -68.094  53.006  1
380967  95.953  -68.097  52.996  1
380968  95.987  -68.101  52.986  1
380969  96.025  -68.106  52.977  1
380970  96.063  -68.112  52.966  1
380971  96.101  -68.117  52.954  1
380972  96.139  -68.122  52.941  1
380973  96.177  -68.127  52.928  1
380974  96.215  -68.132  52.911  1
380975  96.252  -68.137  52.890  1
380976  96.290  -68.143  52.867  1
380977  96.328  -68.148  52.843  1
380978  96.364  -68.153  52.817  1
380979  96.400  -68.158  52.789  1
380980  96.436  -68.163  52.761  1
380981  96.471  -68.169  52.735  1
380982  96.507  -68.173  52.710  1
380983  96.543  -68.178  52.684  1
380984  96.571  -68.181  52.658  1
380985  96.593  -68.182  52.633  1
380986  96.615  -68.183  52.608  1
380987  96.646  -68.188  52.583  1
380988  96.676  -68.192  52.557  1
380989  96.707  -68.197  52.528  1
380990  96.738  -68.202  52.497  1
380991  96.768  -68.206  52.469  1
380992  96.799  -68.211  52.442  1
380993  96.830  -68.216  52.414  1
380994  96.861  -68.220  52.386  1
380995  96.891  -68.225  52.357  1
380996  96.922  -68.230  52.330  1
380997  96.953  -68.235  52.305  1
380998  96.984  -68.239  52.282  1
380999  97.015  -68.244  52.262  1
381000  97.045  -68.248  52.246  1
381001  97.076  -68.253  52.234  1
381002  97.114  -68.260  52.225  1
381003  97.150  -68.263  52.218  1
381004  97.186  -68.266  52.216  1
381005  97.222  -68.270  52.218  1
381006  97.255  -68.279  52.219  1
381007  97.288  -68.288  52.219  1
381008  97.321  -68.297  52.216  1
381009  97.354  -68.307  52.201  1
381010  97.387  -68.316  52.179  1
381011  97.421  -68.325  52.152  1
381012  97.448  -68.327  52.119  1
381013  97.470  -68.322  52.082  1
381014  97.497  -68.316  52.045  1
381015  97.527  -68.308  52.009  1
381016  97.558  -68.300  51.973  1
381017  97.589  -68.293  51.937  1
381018  97.619  -68.285  51.905  1
381019  97.653  -68.288  51.874  1
381020  97.687  -68.291  51.842  1
381021  97.721  -68.296  51.810  1
381022  97.756  -68.300  51.778  1
381023  97.791  -68.305  51.742  1
381024  97.825  -68.310  51.704  1
381025  97.860  -68.314  51.662  1
381026  97.901  -68.322  51.614  1
381027  97.943  -68.329  51.564  1
381028  97.985  -68.336  51.513  1
381029  98.013  -68.341  51.462  1
381030  98.036  -68.346  51.412  1
381031  98.058  -68.350  51.360  1
381032  98.091  -68.362  51.305  1
381033  98.126  -68.374  51.249  1
381034  98.159  -68.379  51.192  1
381035  98.191  -68.374  51.134  1
381036  98.224  -68.387  51.076  1
381037  98.257  -68.400  51.021  1
381038  98.293  -68.412  50.966  1
381039  98.339  -68.421  50.911  1
381040  98.385  -68.430  50.861  1
381041  98.432  -68.439  50.811  1
381042  98.474  -68.450  50.761  1
381043  98.510  -68.463  50.713  1
381044  98.545  -68.476  50.668  1
381045  98.580  -68.488  50.624  1
381046  98.616  -68.501  50.579  1
381047  98.651  -68.514  50.533  1
381048  98.687  -68.527  50.485  1
381049  98.722  -68.540  50.436  1
381050  98.759  -68.551  50.387  1
381051  98.798  -68.553  50.341  1
381052  98.831  -68.544  50.297  1
381053  98.860  -68.529  50.254  1
381054  98.890  -68.514  50.207  1
381055  98.920  -68.499  50.159  1
381056  98.949  -68.485  50.110  1
381057  98.979  -68.470  50.062  1
381058  99.008  -68.457  50.012  1
381059  99.054  -68.498  49.963  1
381060  99.102  -68.547  49.914  1
381061  99.151  -68.595  49.866  1
381062  99.195  -68.635  49.817  1
381063  99.224  -68.652  49.771  1
381064  99.254  -68.670  49.725  1
381065  99.290  -68.683  49.680  1
381066  99.331  -68.692  49.634  1
381067  99.363  -68.703  49.589  1
381068  99.375  -68.715  49.544  1
381069  99.388  -68.727  49.499  1
381070  99.401  -68.739  49.453  1
381071  99.413  -68.751  49.409  1
381072  99.435  -68.761  49.365  1
381073  99.491  -68.764  49.325  1
381074  99.547  -68.767  49.284  1
381075  99.604  -68.770  49.242  1
381076  99.660  -68.773  49.203  1
381077  99.703  -68.777  49.163  1
381078  99.735  -68.785  49.122  1
381079  99.761  -68.805  49.079  1
381080  99.813  -68.811  49.035  1
381081  99.867  -68.815  48.988  1
381082  99.920  -68.820  48.940  1
381083  99.974  -68.824  48.892  1
381084  100.028  -68.829  48.844  1
381085  100.081  -68.833  48.792  1
381086  100.124  -68.838  48.738  1
381087  100.125  -68.857  48.683  1
381088  100.121  -68.893  48.627  1
381089  100.176  -68.765  48.570  1
381090  100.206  -68.761  48.517  1
381091  100.237  -68.758  48.466  1
381092  100.268  -68.787  48.417  1
381093  100.300  -68.826  48.371  1
381094  100.333  -68.864  48.324  1
381095  100.365  -68.903  48.279  1
381096  100.397  -68.942  48.235  1
381097  100.429  -68.981  48.193  1
381098  100.460  -69.010  48.151  1
381099  100.489  -69.015  48.110  1
381100  100.519  -69.019  48.071  1
381101  100.547  -69.024  48.031  1
381541  90.535  -68.225  54.770  1
381542  90.566  -68.236  54.767  1
381543  90.597  -68.247  54.766  1
381544  90.628  -68.257  54.768  1
381545  90.660  -68.268  54.771  1
381546  90.691  -68.278  54.776  1
381547  90.722  -68.288  54.783  1
381548  90.773  -68.313  54.790  1
381549  90.831  -68.342  54.798  1
381550  90.889  -68.371  54.805  1
381551  90.948  -68.401  54.812  1
381552  91.006  -68.430  54.817  1
381553  91.067  -68.462  54.820  1
381554  91.125  -68.470  54.820  1
381555  91.176  -68.459  54.815  1
381556  91.228  -68.448  54.806  1
381557  91.279  -68.438  54.794  1
381558  91.330  -68.427  54.779  1
381559  91.382  -68.416  54.763  1
381560  91.433  -68.406  54.746  1
381561  91.484  -68.403  54.729  1
381562  91.533  -68.401  54.710  1
381563  91.584  -68.399  54.693  1
381564  91.634  -68.398  54.677  1
381565  91.684  -68.396  54.661  1
381566  91.727  -68.397  54.645  1
381567  91.769  -68.398  54.631  1
381568  91.811  -68.398  54.619  1
381569  91.854  -68.399  54.609  1
381570  91.895  -68.400  54.600  1
381571  91.938  -68.401  54.593  1
381572  91.980  -68.401  54.587  1
381573  92.022  -68.402  54.582  1
381574  92.065  -68.403  54.577  1
381575  92.108  -68.400  54.572  1
381576  92.153  -68.394  54.567  1
381577  92.198  -68.388  54.561  1
381578  92.242  -68.383  54.555  1
381579  92.287  -68.377  54.548  1
381580  92.332  -68.372  54.541  1
381581  92.376  -68.366  54.532  1
381582  92.421  -68.360  54.521  1
381583  92.467  -68.355  54.510  1
381584  92.516  -68.353  54.496  1
381585  92.566  -68.350  54.480  1
381586  92.615  -68.347  54.462  1
381587  92.664  -68.345  54.443  1
381588  92.714  -68.342  54.421  1
381589  92.763  -68.340  54.400  1
381590  92.812  -68.337  54.377  1
381591  92.862  -68.335  54.353  1
381592  92.911  -68.332  54.327  1
381593  92.960  -68.329  54.299  1
381594  93.010  -68.327  54.272  1
381595  93.060  -68.324  54.246  1
381596  93.110  -68.321  54.220  1
381597  93.160  -68.318  54.195  1
381598  93.210  -68.316  54.170  1
381599  93.260  -68.313  54.147  1
381600  93.310  -68.310  54.125  1
381601  93.360  -68.307  54.103  1
381602  93.409  -68.304  54.084  1
381603  93.458  -68.301  54.065  1
381604  93.506  -68.299  54.046  1
381605  93.555  -68.296  54.028  1
381606  93.605  -68.293  54.010  1
381607  93.653  -68.291  53.992  1
381608  93.702  -68.288  53.973  1
381609  93.751  -68.285  53.955  1
381610  93.800  -68.282  53.937  1
381611  93.849  -68.279  53.917  1
381612  93.898  -68.277  53.898  1
381613  93.947  -68.274  53.879  1
381614  93.992  -68.264  53.860  1
381615  94.038  -68.255  53.841  1
381616  94.083  -68.245  53.821  1
381617  94.129  -68.236  53.801  1
381618  94.175  -68.226  53.779  1
381619  94.220  -68.216  53.757  1
381620  94.266  -68.207  53.734  1
381621  94.312  -68.197  53.711  1
381622  94.357  -68.188  53.689  1
381623  94.403  -68.178  53.666  1
381624  94.448  -68.169  53.644  1
381625  94.494  -68.159  53.622  1
381626  94.539  -68.150  53.602  1
381627  94.585  -68.141  53.582  1
381628  94.630  -68.131  53.564  1
381629  94.671  -68.128  53.546  1
381630  94.693  -68.146  53.530  1
381631  94.723  -68.135  53.515  1
381632  94.754  -68.125  53.501  1
381633  94.784  -68.113  53.487  1
381634  94.815  -68.103  53.473  1
381635  94.845  -68.091  53.459  1
381636  94.876  -68.081  53.445  1
381641  95.013  -68.019  53.362  1
381642  95.037  -68.006  53.344  1
381643  95.062  -67.993  53.325  1
381644  95.087  -67.981  53.307  1
381645  95.112  -67.967  53.289  1
381646  95.137  -67.954  53.271  1
381647  95.162  -67.941  53.251  1
381648  95.187  -67.928  53.233  1
381649  95.215  -67.921  53.215  1
381650  95.253  -67.929  53.199  1
381651  95.290  -67.937  53.183  1
381652  95.328  -67.945  53.169  1
381653  95.366  -67.953  53.155  1
381654  95.402  -67.966  53.141  1
381655  95.437  -67.979  53.128  1
381656  95.476  -67.987  53.116  1
381657  95.518  -67.989  53.104  1
381658  95.559  -67.994  53.092  1
381659  95.601  -68.001  53.079  1
381660  95.641  -68.007  53.067  1
381661  95.682  -68.015  53.055  1
381662  95.723  -68.022  53.042  1
381663  95.764  -68.030  53.030  1
381664  95.805  -68.037  53.018  1
381665  95.845  -68.045  53.006  1
381666  95.886  -68.053  52.994  1
381667  95.924  -68.059  52.983  1
381668  95.955  -68.062  52.972  1
381669  95.988  -68.066  52.961  1
381670  96.026  -68.072  52.950  1
381671  96.064  -68.077  52.939  1
381672  96.102  -68.081  52.926  1
381673  96.139  -68.087  52.912  1
381674  96.178  -68.092  52.899  1
381675  96.216  -68.097  52.883  1
381676  96.253  -68.103  52.863  1
381677  96.291  -68.108  52.841  1
381678  96.329  -68.113  52.818  1
381679  96.367  -68.119  52.793  1
381680  96.403  -68.124  52.767  1
381681  96.439  -68.128  52.741  1
381682  96.475  -68.134  52.715  1
381683  96.511  -68.138  52.690  1
381684  96.547  -68.144  52.665  1
381685  96.575  -68.147  52.642  1
381686  96.597  -68.147  52.618  1
381687  96.623  -68.150  52.594  1
381688  96.654  -68.155  52.569  1
381689  96.685  -68.159  52.543  1
381690  96.716  -68.165  52.514  1
381691  96.747  -68.169  52.485  1
381692  96.778  -68.174  52.458  1
381693  96.808  -68.178  52.433  1
381694  96.839  -68.183  52.407  1
381695  96.870  -68.188  52.379  1
381696  96.900  -68.193  52.351  1
381697  96.931  -68.197  52.326  1
381698  96.962  -68.202  52.304  1
381699  96.993  -68.206  52.285  1
381700  97.023  -68.211  52.267  1
381701  97.053  -68.216  52.253  1
381702  97.081  -68.222  52.243  1
381703  97.113  -68.225  52.235  1
381704  97.148  -68.225  52.229  1
381705  97.184  -68.228  52.228  1
381706  97.220  -68.232  52.229  1
381707  97.253  -68.241  52.228  1
381708  97.286  -68.250  52.225  1
381709  97.319  -68.260  52.218  1
381710  97.352  -68.269  52.202  1
381711  97.385  -68.278  52.179  1
381712  97.418  -68.288  52.150  1
381713  97.451  -68.297  52.117  1
381714  97.477  -68.297  52.078  1
381715  97.503  -68.291  52.039  1
381716  97.534  -68.283  52.001  1
381717  97.564  -68.275  51.965  1
381718  97.595  -68.268  51.932  1
381719  97.626  -68.260  51.901  1
381720  97.657  -68.256  51.870  1
381721  97.691  -68.260  51.837  1
381722  97.726  -68.265  51.803  1
381723  97.760  -68.269  51.769  1
381724  97.795  -68.274  51.732  1
381725  97.829  -68.279  51.695  1
381726  97.864  -68.284  51.653  1
381727  97.902  -68.290  51.606  1
381728  97.944  -68.297  51.557  1
381729  97.967  -68.301  51.508  1
381730  97.998  -68.311  51.458  1
381731  98.032  -68.323  51.408  1
381732  98.067  -68.335  51.356  1
381733  98.101  -68.347  51.300  1
381734  98.134  -68.348  51.243  1
381735  98.165  -68.342  51.186  1
381736  98.198  -68.345  51.128  1
381737  98.231  -68.358  51.070  1
381738  98.265  -68.370  51.016  1
381739  98.298  -68.383  50.963  1
381740  98.331  -68.396  50.909  1
381741  98.374  -68.406  50.858  1
381742  98.421  -68.415  50.807  1
381743  98.467  -68.425  50.758  1
381744  98.506  -68.436  50.710  1
381745  98.541  -68.449  50.664  1
381746  98.577  -68.462  50.618  1
381747  98.613  -68.474  50.571  1
381748  98.648  -68.487  50.523  1
381749  98.684  -68.500  50.475  1
381750  98.719  -68.513  50.427  1
381751  98.759  -68.516  50.381  1
381752  98.798  -68.519  50.334  1
381753  98.830  -68.507  50.289  1
381754  98.859  -68.492  50.244  1
381755  98.888  -68.478  50.196  1
381756  98.918  -68.463  50.148  1
381757  98.950  -68.451  50.099  1
381758  98.989  -68.448  50.050  1
381759  99.029  -68.446  50.002  1
381760  99.077  -68.492  49.953  1
381761  99.126  -68.541  49.904  1
381762  99.169  -68.579  49.855  1
381763  99.199  -68.598  49.808  1
381764  99.229  -68.615  49.762  1
381765  99.259  -68.633  49.716  1
381766  99.296  -68.645  49.670  1
381767  99.337  -68.654  49.625  1
381768  99.376  -68.664  49.581  1
381769  99.401  -68.676  49.535  1
381770  99.413  -68.687  49.490  1
381771  99.426  -68.699  49.446  1
381772  99.438  -68.711  49.402  1
381773  99.458  -68.722  49.358  1
381774  99.515  -68.725  49.317  1
381775  99.571  -68.728  49.277  1
381776  99.627  -68.731  49.235  1
381777  99.680  -68.734  49.196  1
381778  99.714  -68.739  49.156  1
381779  99.745  -68.750  49.115  1
381780  99.770  -68.770  49.073  1
381781  99.819  -68.777  49.030  1
381782  99.872  -68.783  48.984  1
381783  99.925  -68.787  48.936  1
381784  99.979  -68.792  48.887  1
381785  100.033  -68.796  48.839  1
381786  100.086  -68.801  48.788  1
381787  100.108  -68.802  48.735  1
381788  100.098  -68.843  48.680  1
381789  100.136  -68.758  48.624  1
381790  100.177  -68.706  48.567  1
381791  100.207  -68.703  48.515  1
381792  100.239  -68.732  48.465  1
381793  100.271  -68.771  48.416  1
381794  100.303  -68.810  48.369  1
381795  100.335  -68.849  48.323  1
381796  100.367  -68.887  48.277  1
381797  100.399  -68.927  48.234  1
381798  100.431  -68.965  48.192  1
381799  100.461  -68.970  48.150  1
381800  100.489  -68.974  48.109  1
381801  100.519  -68.979  48.069  1
382241  90.492  -68.182  54.777  1
382242  90.523  -68.193  54.774  1
382243  90.554  -68.203  54.772  1
382244  90.585  -68.214  54.773  1
382245  90.616  -68.225  54.776  1
382246  90.648  -68.235  54.779  1
382247  90.679  -68.246  54.785  1
382248  90.710  -68.256  54.791  1
382249  90.766  -68.285  54.798  1
382250  90.825  -68.314  54.806  1
382251  90.883  -68.343  54.813  1
382252  90.942  -68.372  54.818  1
382253  91.000  -68.401  54.823  1
382254  91.065  -68.432  54.824  1
382255  91.116  -68.421  54.822  1
382256  91.168  -68.410  54.816  1
382257  91.219  -68.400  54.805  1
382258  91.271  -68.389  54.791  1
382259  91.322  -68.379  54.777  1
382260  91.373  -68.368  54.760  1
382261  91.425  -68.357  54.742  1
382262  91.476  -68.346  54.725  1
382263  91.526  -68.344  54.706  1
382264  91.577  -68.342  54.689  1
382265  91.627  -68.341  54.673  1
382266  91.677  -68.338  54.657  1
382267  91.722  -68.338  54.643  1
382268  91.765  -68.339  54.629  1
382269  91.807  -68.340  54.618  1
382270  91.849  -68.341  54.608  1
382271  91.891  -68.341  54.600  1
382272  91.933  -68.342  54.594  1
382273  91.976  -68.343  54.589  1
382274  92.018  -68.344  54.584  1
382275  92.060  -68.344  54.580  1
382276  92.102  -68.345  54.575  1
382277  92.146  -68.343  54.570  1
382278  92.191  -68.337  54.565  1
382279  92.235  -68.332  54.559  1
382280  92.280  -68.325  54.551  1
382281  92.324  -68.320  54.543  1
382282  92.369  -68.314  54.534  1
382283  92.418  -68.311  54.522  1
382284  92.467  -68.309  54.510  1
382285  92.516  -68.306  54.495  1
382286  92.566  -68.303  54.479  1
382287  92.615  -68.300  54.460  1
382288  92.664  -68.298  54.440  1
382289  92.714  -68.296  54.419  1
382290  92.763  -68.293  54.398  1
382291  92.812  -68.291  54.375  1
382292  92.861  -68.288  54.351  1
382293  92.911  -68.285  54.325  1
382294  92.960  -68.283  54.299  1
382295  93.010  -68.280  54.273  1
382296  93.060  -68.277  54.247  1
382297  93.110  -68.275  54.222  1
382298  93.160  -68.272  54.198  1
382299  93.210  -68.269  54.174  1
382300  93.260  -68.266  54.151  1
382301  93.310  -68.263  54.130  1
382302  93.360  -68.260  54.110  1
382303  93.410  -68.257  54.092  1
382304  93.459  -68.255  54.074  1
382305  93.508  -68.252  54.057  1
382306  93.557  -68.249  54.039  1
382307  93.606  -68.247  54.022  1
382308  93.654  -68.244  54.005  1
382309  93.703  -68.241  53.987  1
382310  93.752  -68.238  53.970  1
382311  93.801  -68.235  53.953  1
382312  93.850  -68.232  53.931  1
382313  93.899  -68.230  53.914  1
382314  93.948  -68.227  53.896  1
382315  93.997  -68.225  53.878  1
382316  94.046  -68.222  53.859  1
382317  94.094  -68.218  53.840  1
382318  94.140  -68.208  53.820  1
382319  94.185  -68.199  53.799  1
382320  94.231  -68.189  53.775  1
382321  94.276  -68.180  53.751  1
382322  94.322  -68.170  53.727  1
382323  94.367  -68.160  53.703  1
382324  94.413  -68.151  53.678  1
382325  94.459  -68.141  53.655  1
382326  94.504  -68.132  53.632  1
382327  94.550  -68.122  53.610  1
382328  94.596  -68.112  53.589  1
382329  94.641  -68.103  53.569  1
382330  94.668  -68.118  53.551  1
382331  94.698  -68.110  53.534  1
382332  94.729  -68.100  53.518  1
382333  94.759  -68.088  53.503  1
382334  94.789  -68.078  53.489  1
382335  94.820  -68.066  53.474  1
382336  94.850  -68.056  53.460  1
382337  94.879  -68.043  53.446  1
382338  94.904  -68.031  53.432  1
382339  94.929  -68.018  53.415  1
382340  94.954  -68.005  53.398  1
382341  94.979  -67.991  53.380  1
382342  95.003  -67.978  53.361  1
382343  95.028  -67.965  53.342  1
382344  95.053  -67.952  53.323  1
382345  95.078  -67.939  53.304  1
382346  95.103  -67.926  53.286  1
382347  95.128  -67.913  53.266  1
382348  95.153  -67.899  53.247  1
382349  95.178  -67.887  53.228  1
382350  95.214  -67.893  53.210  1
382351  95.252  -67.902  53.193  1
382352  95.290  -67.909  53.176  1
382353  95.328  -67.918  53.161  1
382354  95.366  -67.926  53.145  1
382355  95.402  -67.937  53.130  1
382356  95.437  -67.951  53.116  1
382357  95.478  -67.955  53.103  1
382358  95.520  -67.957  53.090  1
382359  95.562  -67.961  53.077  1
382360  95.603  -67.968  53.063  1
382361  95.644  -67.974  53.049  1
382362  95.685  -67.981  53.036  1
382363  95.726  -67.988  53.022  1
382364  95.766  -67.996  53.009  1
382365  95.807  -68.003  52.997  1
382366  95.848  -68.011  52.983  1
382367  95.889  -68.018  52.971  1
382368  95.926  -68.025  52.959  1
382369  95.956  -68.028  52.947  1
382370  95.989  -68.031  52.935  1
382371  96.027  -68.037  52.923  1
382372  96.065  -68.042  52.911  1
382373  96.103  -68.046  52.898  1
382374  96.141  -68.052  52.883  1
382375  96.178  -68.057  52.869  1
382376  96.216  -68.062  52.853  1
382377  96.254  -68.068  52.835  1
382378  96.292  -68.073  52.815  1
382379  96.330  -68.078  52.793  1
382380  96.368  -68.084  52.769  1
382381  96.405  -68.089  52.745  1
382382  96.443  -68.094  52.721  1
382383  96.479  -68.099  52.695  1
382384  96.515  -68.104  52.671  1
382385  96.550  -68.109  52.648  1
382386  96.579  -68.112  52.626  1
382387  96.602  -68.113  52.604  1
382388  96.632  -68.118  52.580  1
382389  96.663  -68.122  52.555  1
382390  96.694  -68.128  52.529  1
382391  96.725  -68.132  52.501  1
382392  96.755  -68.137  52.473  1
382393  96.786  -68.141  52.449  1
382394  96.817  -68.146  52.424  1
382395  96.848  -68.150  52.399  1
382396  96.879  -68.156  52.372  1
382397  96.909  -68.160  52.346  1
382398  96.938  -68.166  52.323  1
382399  96.966  -68.171  52.304  1
382400  96.994  -68.176  52.287  1
382401  97.022  -68.181  52.271  1
382402  97.050  -68.186  52.259  1
382403  97.082  -68.194  52.251  1
382404  97.115  -68.197  52.245  1
382405  97.147  -68.192  52.241  1
382406  97.181  -68.191  52.241  1
382407  97.217  -68.194  52.241  1
382408  97.250  -68.203  52.238  1
382409  97.283  -68.213  52.231  1
382410  97.316  -68.222  52.220  1
382411  97.350  -68.231  52.202  1
382412  97.383  -68.241  52.177  1
382413  97.416  -68.250  52.147  1
382414  97.449  -68.260  52.113  1
382415  97.482  -68.269  52.073  1
382416  97.509  -68.266  52.033  1
382417  97.540  -68.259  51.994  1
382418  97.571  -68.250  51.958  1
382419  97.601  -68.241  51.926  1
382420  97.633  -68.231  51.895  1
382421  97.665  -68.229  51.863  1
382422  97.700  -68.240  51.830  1
382423  97.734  -68.243  51.794  1
382424  97.768  -68.246  51.759  1
382425  97.802  -68.249  51.722  1
382426  97.836  -68.252  51.685  1
382427  97.870  -68.255  51.644  1
382428  97.903  -68.260  51.596  1
382429  97.938  -68.272  51.548  1
382430  97.973  -68.284  51.499  1
382431  98.007  -68.296  51.450  1
382432  98.042  -68.308  51.399  1
382433  98.077  -68.320  51.347  1
382434  98.108  -68.317  51.293  1
382435  98.140  -68.312  51.237  1
382436  98.171  -68.306  51.180  1
382437  98.204  -68.316  51.123  1
382438  98.238  -68.329  51.067  1
382439  98.271  -68.341  51.014  1
382440  98.304  -68.354  50.960  1
382441  98.338  -68.367  50.907  1
382442  98.371  -68.380  50.855  1
382443  98.410  -68.391  50.804  1
382444  98.456  -68.401  50.755  1
382445  98.503  -68.410  50.707  1
382446  98.538  -68.422  50.659  1
382447  98.574  -68.435  50.611  1
382448  98.609  -68.448  50.563  1
382449  98.645  -68.460  50.515  1
382450  98.680  -68.473  50.466  1
382451  98.718  -68.479  50.419  1
382452  98.758  -68.482  50.373  1
382453  98.798  -68.485  50.327  1
382454  98.828  -68.471  50.280  1
382455  98.858  -68.457  50.235  1
382456  98.896  -68.452  50.186  1
382457  98.935  -68.449  50.137  1
382458  98.974  -68.446  50.088  1
382459  99.013  -68.444  50.039  1
382460  99.053  -68.441  49.990  1
382461  99.101  -68.486  49.941  1
382462  99.144  -68.525  49.893  1
382463  99.174  -68.543  49.845  1
382464  99.204  -68.560  49.798  1
382465  99.234  -68.578  49.752  1
382466  99.264  -68.595  49.705  1
382467  99.302  -68.607  49.660  1
382468  99.342  -68.617  49.615  1
382469  99.382  -68.626  49.571  1
382470  99.422  -68.636  49.525  1
382471  99.438  -68.648  49.481  1
382472  99.451  -68.660  49.438  1
382473  99.464  -68.672  49.394  1
382474  99.482  -68.683  49.350  1
382475  99.539  -68.686  49.309  1
382476  99.594  -68.689  49.268  1
382477  99.651  -68.692  49.228  1
382478  99.691  -68.695  49.188  1
382479  99.725  -68.700  49.149  1
382480  99.754  -68.715  49.109  1
382481  99.779  -68.736  49.067  1
382482  99.824  -68.745  49.023  1
382483  99.877  -68.749  48.978  1
382484  99.931  -68.754  48.930  1
382485  99.984  -68.759  48.882  1
382486  100.038  -68.764  48.833  1
382487  100.085  -68.747  48.782  1
382488  100.098  -68.734  48.730  1
382489  100.092  -68.766  48.676  1
382490  100.147  -68.651  48.620  1
382491  100.177  -68.648  48.564  1
382492  100.209  -68.677  48.512  1
382493  100.241  -68.717  48.463  1
382494  100.273  -68.755  48.415  1
382495  100.305  -68.794  48.367  1
382496  100.337  -68.833  48.322  1
382497  100.369  -68.872  48.276  1
382498  100.402  -68.911  48.233  1
382499  100.431  -68.925  48.190  1
382500  100.461  -68.930  48.149  1
382501  100.490  -68.934  48.108  1
382941  90.449  -68.140  54.785  1
382942  90.480  -68.150  54.781  1
382943  90.511  -68.161  54.779  1
382944  90.542  -68.172  54.778  1
382945  90.573  -68.182  54.780  1
382946  90.604  -68.192  54.784  1
382947  90.636  -68.203  54.788  1
382948  90.667  -68.213  54.794  1
382949  90.702  -68.227  54.801  1
382950  90.760  -68.256  54.808  1
382951  90.819  -68.285  54.815  1
382952  90.877  -68.315  54.821  1
382953  90.936  -68.344  54.826  1
382954  91.002  -68.385  54.830  1
382955  91.057  -68.383  54.829  1
382956  91.108  -68.372  54.826  1
382957  91.160  -68.362  54.817  1
382958  91.211  -68.351  54.805  1
382959  91.262  -68.341  54.790  1
382960  91.313  -68.330  54.775  1
382961  91.365  -68.319  54.758  1
382962  91.416  -68.308  54.740  1
382963  91.467  -68.297  54.722  1
382964  91.519  -68.287  54.704  1
382965  91.569  -68.285  54.687  1
382966  91.619  -68.283  54.672  1
382967  91.669  -68.282  54.657  1
382968  91.718  -68.280  54.643  1
382969  91.760  -68.281  54.631  1
382970  91.802  -68.282  54.620  1
382971  91.844  -68.282  54.611  1
382972  91.886  -68.283  54.604  1
382973  91.929  -68.285  54.598  1
382974  91.971  -68.285  54.593  1
382975  92.013  -68.286  54.588  1
382976  92.056  -68.287  54.583  1
382977  92.097  -68.288  54.579  1
382978  92.140  -68.288  54.575  1
382979  92.183  -68.285  54.571  1
382980  92.228  -68.280  54.565  1
382981  92.273  -68.274  54.556  1
382982  92.319  -68.269  54.546  1
382983  92.369  -68.267  54.535  1
382984  92.418  -68.265  54.524  1
382985  92.467  -68.262  54.510  1
382986  92.516  -68.260  54.495  1
382987  92.566  -68.256  54.477  1
382988  92.615  -68.254  54.458  1
382989  92.664  -68.251  54.438  1
382990  92.714  -68.249  54.417  1
382991  92.763  -68.247  54.396  1
382992  92.812  -68.244  54.374  1
382993  92.861  -68.241  54.350  1
382994  92.911  -68.238  54.324  1
382995  92.960  -68.236  54.298  1
382996  93.010  -68.233  54.273  1
382997  93.060  -68.231  54.248  1
382998  93.110  -68.228  54.224  1
382999  93.160  -68.225  54.201  1
383000  93.210  -68.222  54.178  1
383001  93.260  -68.219  54.157  1
383002  93.310  -68.216  54.136  1
383003  93.360  -68.213  54.117  1
383004  93.410  -68.210  54.099  1
383005  93.460  -68.208  54.083  1
383006  93.509  -68.205  54.067  1
383007  93.558  -68.203  54.050  1
383008  93.607  -68.200  54.035  1
383009  93.655  -68.197  54.019  1
383010  93.704  -68.194  54.002  1
383011  93.753  -68.191  53.983  1
383012  93.802  -68.188  53.965  1
383013  93.851  -68.186  53.946  1
383014  93.900  -68.183  53.927  1
383015  93.949  -68.180  53.911  1
383016  93.998  -68.178  53.895  1
383017  94.047  -68.175  53.877  1
383018  94.096  -68.172  53.859  1
383019  94.145  -68.169  53.839  1
383020  94.194  -68.166  53.818  1
383021  94.242  -68.162  53.794  1
383022  94.287  -68.152  53.769  1
383023  94.333  -68.143  53.744  1
383024  94.379  -68.133  53.719  1
383025  94.424  -68.124  53.691  1
383026  94.470  -68.114  53.666  1
383027  94.515  -68.104  53.641  1
383028  94.561  -68.095  53.618  1
383029  94.606  -68.085  53.596  1
383030  94.645  -68.084  53.575  1
383031  94.673  -68.085  53.556  1
383032  94.703  -68.075  53.538  1
383033  94.734  -68.063  53.521  1
383034  94.764  -68.053  53.505  1
383035  94.794  -68.041  53.490  1
383036  94.820  -68.029  53.476  1
383037  94.845  -68.015  53.461  1
383038  94.870  -68.003  53.446  1
383039  94.895  -67.990  53.432  1
383040  94.920  -67.976  53.415  1
383041  94.945  -67.963  53.398  1
383042  94.970  -67.950  53.380  1
383043  94.994  -67.937  53.361  1
383044  95.020  -67.924  53.340  1
383045  95.044  -67.911  53.321  1
383046  95.069  -67.898  53.302  1
383047  95.094  -67.884  53.282  1
383048  95.119  -67.871  53.263  1
383049  95.144  -67.858  53.243  1
383050  95.176  -67.858  53.224  1
383051  95.214  -67.866  53.205  1
383052  95.252  -67.874  53.187  1
383053  95.289  -67.882  53.170  1
383054  95.327  -67.890  53.154  1
383055  95.365  -67.898  53.137  1
383056  95.401  -67.909  53.122  1
383057  95.438  -67.921  53.107  1
383058  95.480  -67.923  53.092  1
383059  95.522  -67.924  53.078  1
383060  95.564  -67.927  53.063  1
383061  95.605  -67.934  53.048  1
383062  95.647  -67.941  53.033  1
383063  95.687  -67.948  53.018  1
383064  95.729  -67.954  53.004  1
383065  95.769  -67.962  52.990  1
383066  95.810  -67.969  52.976  1
383067  95.851  -67.977  52.962  1
383068  95.891  -67.984  52.949  1
383069  95.928  -67.990  52.936  1
383070  95.958  -67.993  52.923  1
383071  95.990  -67.996  52.911  1
383072  96.028  -68.002  52.898  1
383073  96.066  -68.006  52.885  1
383074  96.104  -68.012  52.872  1
383075  96.142  -68.017  52.857  1
383076  96.179  -68.022  52.842  1
383077  96.217  -68.028  52.826  1
383078  96.255  -68.033  52.809  1
383079  96.293  -68.038  52.790  1
383080  96.331  -68.043  52.770  1
383081  96.369  -68.049  52.748  1
383082  96.406  -68.054  52.725  1
383083  96.444  -68.059  52.702  1
383084  96.482  -68.065  52.678  1
383085  96.519  -68.069  52.654  1
383086  96.554  -68.075  52.633  1
383087  96.583  -68.078  52.612  1
383088  96.611  -68.081  52.590  1
383089  96.642  -68.085  52.566  1
383090  96.672  -68.090  52.541  1
383091  96.703  -68.095  52.515  1
383092  96.734  -68.100  52.488  1
383093  96.764  -68.104  52.463  1
383094  96.794  -68.109  52.440  1
383095  96.822  -68.115  52.416  1
383096  96.850  -68.120  52.392  1
383097  96.878  -68.125  52.365  1
383098  96.906  -68.130  52.341  1
383099  96.935  -68.135  52.321  1
383100  96.963  -68.141  52.304  1
383101  96.991  -68.146  52.290  1
383102  97.019  -68.151  52.275  1
383103  97.051  -68.159  52.264  1
383104  97.084  -68.167  52.258  1
383105  97.117  -68.170  52.254  1
383106  97.149  -68.165  52.253  1
383107  97.181  -68.159  52.255  1
383108  97.215  -68.157  52.254  1
383109  97.248  -68.166  52.248  1
383110  97.281  -68.175  52.237  1
383111  97.314  -68.184  52.223  1
383112  97.347  -68.194  52.201  1
383113  97.380  -68.202  52.174  1
383114  97.413  -68.210  52.142  1
383115  97.446  -68.219  52.107  1
383116  97.479  -68.228  52.067  1
383117  97.516  -68.238  52.027  1
383118  97.547  -68.227  51.988  1
383119  97.578  -68.217  51.952  1
383120  97.609  -68.207  51.919  1
383121  97.640  -68.197  51.888  1
383122  97.673  -68.201  51.855  1
383123  97.709  -68.218  51.820  1
383124  97.743  -68.225  51.784  1
383125  97.777  -68.228  51.750  1
383126  97.811  -68.231  51.712  1
383127  97.845  -68.235  51.674  1
383128  97.879  -68.238  51.633  1
383129  97.914  -68.244  51.586  1
383130  97.948  -68.256  51.537  1
383131  97.983  -68.269  51.488  1
383132  98.017  -68.281  51.438  1
383133  98.052  -68.292  51.388  1
383134  98.083  -68.286  51.336  1
383135  98.114  -68.281  51.283  1
383136  98.146  -68.275  51.229  1
383137  98.177  -68.274  51.174  1
383138  98.211  -68.287  51.118  1
383139  98.244  -68.300  51.064  1
383140  98.278  -68.312  51.011  1
383141  98.311  -68.325  50.957  1
383142  98.345  -68.338  50.904  1
383143  98.378  -68.350  50.852  1
383144  98.411  -68.363  50.800  1
383145  98.445  -68.376  50.751  1
383146  98.492  -68.385  50.702  1
383147  98.535  -68.395  50.653  1
383148  98.571  -68.408  50.603  1
383149  98.606  -68.421  50.555  1
383150  98.641  -68.434  50.506  1
383151  98.678  -68.442  50.457  1
383152  98.718  -68.445  50.411  1
383153  98.758  -68.448  50.365  1
383154  98.797  -68.451  50.319  1
383155  98.839  -68.451  50.272  1
383156  98.880  -68.450  50.225  1
383157  98.920  -68.447  50.177  1
383158  98.959  -68.444  50.127  1
383159  98.998  -68.441  50.078  1
383160  99.038  -68.438  50.029  1
383161  99.077  -68.436  49.979  1
383162  99.119  -68.470  49.930  1
383163  99.149  -68.488  49.883  1
383164  99.179  -68.506  49.837  1
383165  99.209  -68.523  49.789  1
383166  99.239  -68.541  49.742  1
383167  99.269  -68.559  49.695  1
383168  99.308  -68.569  49.650  1
383169  99.348  -68.579  49.605  1
383170  99.388  -68.589  49.560  1
383171  99.428  -68.598  49.515  1
383172  99.464  -68.609  49.472  1
383173  99.477  -68.620  49.430  1
383174  99.489  -68.633  49.386  1
383175  99.506  -68.644  49.342  1
383176  99.562  -68.647  49.300  1
383177  99.618  -68.650  49.259  1
383178  99.668  -68.653  49.219  1
383179  99.702  -68.658  49.180  1
383180  99.737  -68.661  49.141  1
383181  99.763  -68.680  49.101  1
383182  99.788  -68.700  49.060  1
383183  99.829  -68.712  49.016  1
383184  99.883  -68.717  48.970  1
383185  99.936  -68.721  48.924  1
383186  99.990  -68.726  48.876  1
383187  100.043  -68.730  48.826  1
383188  100.077  -68.672  48.776  1
383189  100.087  -68.667  48.723  1
383190  100.114  -68.609  48.670  1
383191  100.147  -68.592  48.616  1
383192  100.179  -68.623  48.560  1
383193  100.211  -68.662  48.509  1
383194  100.243  -68.701  48.460  1
383195  100.275  -68.739  48.412  1
383196  100.308  -68.778  48.365  1
383197  100.340  -68.817  48.321  1
383198  100.372  -68.856  48.275  1
383199  100.403  -68.880  48.232  1
383200  100.431  -68.884  48.190  1
383201  100.461  -68.889  48.148  1
383642  90.437  -68.107  54.789  1
383643  90.468  -68.118  54.786  1
383644  90.499  -68.128  54.785  1
383645  90.530  -68.139  54.786  1
383646  90.561  -68.150  54.789  1
383647  90.592  -68.160  54.793  1
383648  90.623  -68.171  54.798  1
383649  90.655  -68.181  54.805  1
383650  90.696  -68.199  54.811  1
383651  90.754  -68.228  54.818  1
383652  90.813  -68.257  54.825  1
383653  90.871  -68.287  54.831  1
383654  90.931  -68.318  54.835  1
383655  90.997  -68.345  54.838  1
383656  91.048  -68.335  54.836  1
383657  91.100  -68.324  54.830  1
383658  91.151  -68.313  54.820  1
383659  91.203  -68.303  54.805  1
383660  91.254  -68.292  54.790  1
383661  91.305  -68.282  54.773  1
383662  91.357  -68.270  54.756  1
383663  91.408  -68.260  54.738  1
383664  91.459  -68.249  54.720  1
383665  91.511  -68.238  54.703  1
383666  91.562  -68.228  54.687  1
383667  91.612  -68.225  54.672  1
383668  91.662  -68.224  54.659  1
383669  91.713  -68.222  54.646  1
383670  91.755  -68.223  54.634  1
383671  91.797  -68.224  54.624  1
383672  91.840  -68.225  54.616  1
383673  91.882  -68.225  54.610  1
383674  91.924  -68.226  54.605  1
383675  91.966  -68.227  54.601  1
383676  92.009  -68.228  54.596  1
383677  92.051  -68.228  54.593  1
383678  92.093  -68.229  54.589  1
383679  92.135  -68.230  54.585  1
383680  92.177  -68.231  54.580  1
383681  92.221  -68.228  54.574  1
383682  92.270  -68.225  54.564  1
383683  92.319  -68.223  54.551  1
383684  92.368  -68.220  54.538  1
383685  92.418  -68.218  54.524  1
383686  92.467  -68.216  54.510  1
383687  92.516  -68.213  54.494  1
383688  92.566  -68.210  54.475  1
383689  92.615  -68.207  54.456  1
383690  92.664  -68.205  54.437  1
383691  92.714  -68.202  54.416  1
383692  92.763  -68.200  54.394  1
383693  92.812  -68.197  54.372  1
383694  92.861  -68.194  54.349  1
383695  92.911  -68.192  54.323  1
383696  92.960  -68.189  54.298  1
383697  93.009  -68.187  54.274  1
383698  93.060  -68.184  54.250  1
383699  93.110  -68.181  54.226  1
383700  93.160  -68.178  54.205  1
383701  93.210  -68.175  54.183  1
383702  93.260  -68.172  54.162  1
383703  93.310  -68.169  54.142  1
383704  93.360  -68.167  54.123  1
383705  93.410  -68.164  54.107  1
383706  93.461  -68.161  54.092  1
383707  93.510  -68.158  54.076  1
383708  93.559  -68.156  54.061  1
383709  93.608  -68.153  54.047  1
383710  93.656  -68.150  54.032  1
383711  93.706  -68.147  54.015  1
383712  93.755  -68.144  53.996  1
383713  93.803  -68.142  53.978  1
383714  93.852  -68.139  53.958  1
383715  93.901  -68.136  53.939  1
383716  93.950  -68.134  53.922  1
383717  93.999  -68.131  53.908  1
383718  94.048  -68.128  53.892  1
383719  94.097  -68.125  53.875  1
383720  94.146  -68.122  53.856  1
383721  94.195  -68.120  53.835  1
383722  94.244  -68.117  53.812  1
383723  94.292  -68.114  53.787  1
383724  94.341  -68.112  53.762  1
383725  94.389  -68.106  53.736  1
383726  94.434  -68.096  53.708  1
383727  94.480  -68.087  53.679  1
383728  94.526  -68.077  53.651  1
383729  94.571  -68.068  53.626  1
383730  94.617  -68.058  53.603  1
383731  94.647  -68.060  53.581  1
383732  94.678  -68.050  53.561  1
383733  94.708  -68.038  53.542  1
383734  94.737  -68.027  53.524  1
383735  94.762  -68.014  53.508  1
383736  94.786  -68.000  53.492  1
383737  94.812  -67.987  53.477  1
383738  94.836  -67.974  53.462  1
383739  94.861  -67.962  53.446  1
383740  94.886  -67.948  53.431  1
383741  94.911  -67.935  53.415  1
383742  94.936  -67.922  53.398  1
383743  94.961  -67.909  53.379  1
383744  94.986  -67.896  53.360  1
383745  95.011  -67.883  53.339  1
383746  95.035  -67.870  53.320  1
383747  95.060  -67.856  53.300  1
383748  95.085  -67.843  53.279  1
383749  95.110  -67.830  53.259  1
383750  95.138  -67.822  53.240  1
383751  95.176  -67.830  53.220  1
383752  95.213  -67.838  53.201  1
383753  95.251  -67.846  53.182  1
383754  95.289  -67.855  53.165  1
383755  95.327  -67.862  53.147  1
383756  95.365  -67.871  53.130  1
383757  95.401  -67.881  53.114  1
383758  95.440  -67.889  53.098  1
383759  95.482  -67.890  53.083  1
383760  95.525  -67.893  53.067  1
383761  95.566  -67.895  53.051  1
383762  95.608  -67.901  53.034  1
383763  95.649  -67.908  53.018  1
383764  95.690  -67.915  53.002  1
383765  95.731  -67.921  52.987  1
383766  95.772  -67.928  52.972  1
383767  95.813  -67.935  52.956  1
383768  95.853  -67.943  52.943  1
383769  95.894  -67.950  52.929  1
383770  95.930  -67.956  52.915  1
383771  95.960  -67.959  52.901  1
383772  95.991  -67.962  52.888  1
383773  96.029  -67.966  52.874  1
383774  96.067  -67.971  52.861  1
383775  96.105  -67.977  52.847  1
383776  96.143  -67.982  52.833  1
383777  96.180  -67.987  52.817  1
383778  96.218  -67.993  52.801  1
383779  96.256  -67.998  52.785  1
383780  96.294  -68.003  52.767  1
383781  96.331  -68.009  52.748  1
383782  96.370  -68.014  52.727  1
383783  96.407  -68.019  52.706  1
383784  96.445  -68.025  52.684  1
383785  96.483  -68.029  52.660  1
383786  96.521  -68.034  52.637  1
383787  96.558  -68.040  52.617  1
383788  96.589  -68.043  52.596  1
383789  96.619  -68.048  52.576  1
383790  96.650  -68.053  52.552  1
383791  96.678  -68.059  52.527  1
383792  96.707  -68.064  52.502  1
383793  96.735  -68.068  52.476  1
383794  96.763  -68.074  52.453  1
383795  96.791  -68.079  52.432  1
383796  96.819  -68.084  52.409  1
383797  96.848  -68.090  52.386  1
383798  96.876  -68.095  52.361  1
383799  96.904  -68.100  52.337  1
383800  96.932  -68.106  52.319  1
383801  96.960  -68.111  52.304  1
383802  96.988  -68.116  52.292  1
383803  97.020  -68.124  52.280  1
383804  97.053  -68.132  52.272  1
383805  97.086  -68.141  52.266  1
383806  97.119  -68.143  52.264  1
383807  97.151  -68.137  52.265  1
383808  97.183  -68.132  52.265  1
383809  97.218  -68.128  52.262  1
383810  97.249  -68.131  52.254  1
383811  97.280  -68.134  52.240  1
383812  97.311  -68.138  52.223  1
383813  97.344  -68.147  52.198  1
383814  97.377  -68.156  52.169  1
383815  97.410  -68.164  52.136  1
383816  97.446  -68.175  52.099  1
383817  97.484  -68.186  52.057  1
383818  97.521  -68.198  52.017  1
383819  97.554  -68.194  51.978  1
383820  97.585  -68.184  51.942  1
383821  97.616  -68.174  51.909  1
383822  97.647  -68.164  51.878  1
383823  97.681  -68.173  51.844  1
383824  97.717  -68.190  51.809  1
383825  97.753  -68.206  51.775  1
383826  97.787  -68.210  51.739  1
383827  97.821  -68.214  51.700  1
383828  97.855  -68.217  51.661  1
383829  97.889  -68.220  51.619  1
383830  97.923  -68.230  51.570  1
383831  97.958  -68.242  51.522  1
383832  97.993  -68.254  51.473  1
383833  98.026  -68.261  51.423  1
383834  98.058  -68.256  51.373  1
383835  98.089  -68.250  51.325  1
383836  98.120  -68.244  51.273  1
383837  98.152  -68.238  51.220  1
383838  98.184  -68.244  51.164  1
383839  98.218  -68.257  51.108  1
383840  98.251  -68.270  51.054  1
383841  98.285  -68.283  51.002  1
383842  98.318  -68.296  50.948  1
383843  98.351  -68.309  50.895  1
383844  98.385  -68.321  50.844  1
383845  98.418  -68.334  50.792  1
383846  98.451  -68.347  50.742  1
383847  98.485  -68.360  50.693  1
383848  98.527  -68.370  50.644  1
383849  98.567  -68.381  50.594  1
383850  98.602  -68.394  50.544  1
383851  98.639  -68.405  50.495  1
383852  98.678  -68.408  50.447  1
383853  98.717  -68.411  50.401  1
383854  98.755  -68.415  50.355  1
383855  98.791  -68.419  50.310  1
383856  98.830  -68.422  50.264  1
383857  98.872  -68.421  50.217  1
383858  98.916  -68.421  50.169  1
383859  98.958  -68.421  50.120  1
383860  99.001  -68.421  50.071  1
383861  99.044  -68.421  50.022  1
383862  99.088  -68.422  49.973  1
383863  99.124  -68.433  49.924  1
383864  99.154  -68.451  49.875  1
383865  99.184  -68.469  49.827  1
383866  99.214  -68.486  49.781  1
383867  99.244  -68.504  49.735  1
383868  99.274  -68.522  49.690  1
383869  99.314  -68.532  49.645  1
383870  99.354  -68.541  49.599  1
383871  99.394  -68.551  49.555  1
383872  99.434  -68.560  49.510  1
383873  99.474  -68.570  49.465  1
383874  99.502  -68.582  49.421  1
383875  99.514  -68.593  49.375  1
383876  99.529  -68.604  49.331  1
383877  99.586  -68.607  49.288  1
383878  99.642  -68.611  49.248  1
383879  99.679  -68.615  49.208  1
383880  99.713  -68.619  49.169  1
383881  99.747  -68.626  49.131  1
383882  99.772  -68.645  49.091  1
383883  99.797  -68.665  49.049  1
383884  99.834  -68.680  49.006  1
383885  99.888  -68.684  48.962  1
383886  99.941  -68.689  48.916  1
383887  99.995  -68.693  48.868  1
383888  100.037  -68.661  48.819  1
383889  100.070  -68.598  48.769  1
383890  100.077  -68.601  48.717  1
383891  100.118  -68.537  48.664  1
383892  100.149  -68.568  48.610  1
383893  100.181  -68.607  48.555  1
383894  100.213  -68.646  48.505  1
383895  100.246  -68.685  48.457  1
383896  100.278  -68.723  48.409  1
383897  100.310  -68.762  48.363  1
383898  100.342  -68.802  48.318  1
383899  100.373  -68.835  48.273  1
383900  100.403  -68.839  48.229  1
383901  100.432  -68.844  48.187  1
383902  100.461  -68.849  48.145  1
384342  90.393  -68.065  54.798  1
384343  90.425  -68.075  54.794  1
384344  90.456  -68.086  54.792  1
384345  90.487  -68.097  54.792  1
384346  90.518  -68.106  54.795  1
384347  90.549  -68.117  54.799  1
384348  90.580  -68.128  54.804  1
384349  90.611  -68.138  54.810  1
384350  90.643  -68.149  54.816  1
384351  90.690  -68.171  54.824  1
384352  90.748  -68.200  54.830  1
384353  90.807  -68.229  54.837  1
384354  90.865  -68.259  54.843  1
384355  90.937  -68.307  54.848  1
384356  90.989  -68.297  54.848  1
384357  91.040  -68.286  54.844  1
384358  91.091  -68.275  54.835  1
384359  91.143  -68.265  54.822  1
384360  91.194  -68.254  54.807  1
384361  91.245  -68.244  54.791  1
384362  91.297  -68.232  54.774  1
384363  91.348  -68.222  54.756  1
384364  91.399  -68.211  54.738  1
384365  91.451  -68.200  54.720  1
384366  91.502  -68.190  54.704  1
384367  91.554  -68.179  54.688  1
384368  91.605  -68.169  54.674  1
384369  91.655  -68.167  54.661  1
384370  91.705  -68.165  54.650  1
384371  91.750  -68.165  54.640  1
384372  91.793  -68.166  54.630  1
384373  91.835  -68.166  54.623  1
384374  91.877  -68.167  54.618  1
384375  91.920  -68.168  54.615  1
384376  91.962  -68.169  54.611  1
384377  92.004  -68.169  54.607  1
384378  92.046  -68.170  54.605  1
384379  92.088  -68.171  54.602  1
384380  92.131  -68.172  54.597  1
384381  92.171  -68.181  54.590  1
384382  92.212  -68.191  54.583  1
384383  92.258  -68.193  54.570  1
384384  92.307  -68.191  54.555  1
384385  92.356  -68.188  54.540  1
384386  92.406  -68.184  54.525  1
384387  92.455  -68.182  54.509  1
384388  92.504  -68.179  54.492  1
384389  92.554  -68.177  54.473  1
384390  92.603  -68.174  54.454  1
384391  92.653  -68.172  54.434  1
384392  92.702  -68.169  54.414  1
384393  92.752  -68.166  54.392  1
384394  92.801  -68.163  54.370  1
384395  92.850  -68.160  54.348  1
384396  92.901  -68.156  54.323  1
384397  92.959  -68.146  54.299  1
384398  93.006  -68.141  54.276  1
384399  93.059  -68.137  54.252  1
384400  93.110  -68.134  54.230  1
384401  93.160  -68.131  54.207  1
384402  93.210  -68.128  54.187  1
384403  93.260  -68.126  54.167  1
384404  93.310  -68.123  54.148  1
384405  93.360  -68.120  54.130  1
384406  93.410  -68.117  54.115  1
384407  93.461  -68.115  54.101  1
384408  93.510  -68.112  54.086  1
384409  93.560  -68.109  54.072  1
384410  93.609  -68.106  54.059  1
384411  93.658  -68.103  54.043  1
384412  93.707  -68.100  54.026  1
384413  93.756  -68.098  54.008  1
384414  93.804  -68.095  53.990  1
384415  93.853  -68.092  53.969  1
384416  93.902  -68.090  53.949  1
384417  93.951  -68.087  53.933  1
384418  94.000  -68.084  53.918  1
384419  94.049  -68.081  53.905  1
384420  94.098  -68.078  53.888  1
384421  94.147  -68.076  53.870  1
384422  94.196  -68.073  53.851  1
384423  94.245  -68.070  53.828  1
384424  94.294  -68.068  53.803  1
384425  94.343  -68.065  53.777  1
384426  94.392  -68.062  53.751  1
384427  94.440  -68.059  53.722  1
384428  94.489  -68.056  53.691  1
384429  94.536  -68.050  53.662  1
384430  94.582  -68.040  53.634  1
384431  94.622  -68.036  53.609  1
384432  94.652  -68.025  53.587  1
384433  94.678  -68.012  53.565  1
384434  94.703  -67.999  53.545  1
384435  94.728  -67.986  53.527  1
384436  94.753  -67.972  53.510  1
384437  94.778  -67.959  53.494  1
384438  94.803  -67.946  53.478  1
384439  94.827  -67.933  53.462  1
384440  94.852  -67.920  53.447  1
384441  94.877  -67.907  53.432  1
384442  94.902  -67.894  53.415  1
384443  94.927  -67.880  53.398  1
384444  94.952  -67.868  53.379  1
384445  94.977  -67.855  53.360  1
384446  95.001  -67.841  53.339  1
384447  95.027  -67.828  53.318  1
384448  95.051  -67.815  53.298  1
384449  95.076  -67.802  53.277  1
384450  95.101  -67.789  53.258  1
384451  95.137  -67.795  53.238  1
384452  95.175  -67.802  53.217  1
384453  95.213  -67.811  53.197  1
384454  95.251  -67.819  53.178  1
384455  95.288  -67.827  53.161  1
384456  95.326  -67.835  53.142  1
384457  95.364  -67.843  53.124  1
384458  95.401  -67.853  53.107  1
384459  95.442  -67.856  53.090  1
384460  95.484  -67.858  53.075  1
384461  95.527  -67.861  53.058  1
384462  95.568  -67.863  53.040  1
384463  95.610  -67.868  53.022  1
384464  95.651  -67.874  53.004  1
384465  95.692  -67.881  52.987  1
384466  95.733  -67.888  52.970  1
384467  95.774  -67.895  52.954  1
384468  95.815  -67.902  52.938  1
384469  95.856  -67.909  52.924  1
384470  95.897  -67.916  52.909  1
384471  95.932  -67.921  52.895  1
384472  95.962  -67.924  52.881  1
384473  95.992  -67.927  52.866  1
384474  96.030  -67.931  52.852  1
384475  96.067  -67.937  52.838  1
384476  96.106  -67.942  52.824  1
384477  96.144  -67.947  52.810  1
384478  96.181  -67.952  52.794  1
384479  96.219  -67.958  52.778  1
384480  96.257  -67.963  52.762  1
384481  96.295  -67.968  52.745  1
384482  96.332  -67.974  52.726  1
384483  96.370  -67.979  52.706  1
384484  96.408  -67.984  52.686  1
384485  96.446  -67.990  52.665  1
384486  96.484  -67.994  52.643  1
384487  96.521  -67.999  52.620  1
384488  96.556  -68.006  52.600  1
384489  96.591  -68.012  52.580  1
384490  96.619  -68.018  52.560  1
384491  96.647  -68.023  52.538  1
384492  96.675  -68.028  52.513  1
384493  96.703  -68.034  52.489  1
384494  96.732  -68.039  52.465  1
384495  96.760  -68.044  52.443  1
384496  96.788  -68.050  52.423  1
384497  96.816  -68.055  52.402  1
384498  96.844  -68.060  52.380  1
384499  96.873  -68.065  52.356  1
384500  96.901  -68.071  52.333  1
384501  96.929  -68.076  52.317  1
384502  96.957  -68.081  52.304  1
384503  96.989  -68.088  52.295  1
384504  97.022  -68.097  52.286  1
384505  97.055  -68.106  52.280  1
384506  97.088  -68.114  52.276  1
384507  97.121  -68.115  52.274  1
384508  97.153  -68.109  52.275  1
384509  97.185  -68.104  52.273  1
384510  97.225  -68.103  52.267  1
384511  97.256  -68.106  52.256  1
384512  97.287  -68.109  52.239  1
384513  97.317  -68.112  52.219  1
384514  97.348  -68.115  52.192  1
384515  97.378  -68.119  52.162  1
384516  97.413  -68.122  52.127  1
384517  97.451  -68.133  52.090  1
384518  97.488  -68.145  52.047  1
384519  97.526  -68.156  52.007  1
384520  97.562  -68.161  51.969  1
384521  97.592  -68.151  51.935  1
384522  97.623  -68.141  51.903  1
384523  97.654  -68.131  51.871  1
384524  97.689  -68.145  51.836  1
384525  97.725  -68.162  51.801  1
384526  97.761  -68.178  51.764  1
384527  97.797  -68.193  51.725  1
384528  97.830  -68.196  51.686  1
384529  97.865  -68.199  51.645  1
384530  97.898  -68.203  51.602  1
384531  97.933  -68.215  51.555  1
384532  97.967  -68.227  51.506  1
384533  98.001  -68.230  51.457  1
384534  98.032  -68.225  51.407  1
384535  98.063  -68.219  51.359  1
384536  98.095  -68.213  51.312  1
384537  98.126  -68.207  51.261  1
384538  98.158  -68.203  51.208  1
384539  98.191  -68.216  51.154  1
384540  98.224  -68.228  51.098  1
384541  98.258  -68.241  51.044  1
384542  98.291  -68.253  50.991  1
384543  98.324  -68.266  50.938  1
384544  98.358  -68.279  50.884  1
384545  98.391  -68.292  50.834  1
384546  98.425  -68.305  50.782  1
384547  98.458  -68.318  50.731  1
384548  98.492  -68.330  50.682  1
384549  98.525  -68.343  50.632  1
384550  98.562  -68.355  50.584  1
384551  98.599  -68.367  50.534  1
384552  98.638  -68.371  50.485  1
384553  98.675  -68.375  50.437  1
384554  98.712  -68.379  50.390  1
384555  98.749  -68.383  50.344  1
384556  98.786  -68.387  50.299  1
384557  98.822  -68.391  50.254  1
384558  98.863  -68.392  50.208  1
384559  98.906  -68.391  50.160  1
384560  98.949  -68.391  50.111  1
384561  98.992  -68.391  50.063  1
384562  99.035  -68.392  50.014  1
384563  99.081  -68.395  49.965  1
384564  99.127  -68.398  49.917  1
384565  99.159  -68.414  49.868  1
384566  99.189  -68.432  49.821  1
384567  99.219  -68.449  49.776  1
384568  99.249  -68.467  49.732  1
384569  99.280  -68.484  49.686  1
384570  99.320  -68.494  49.640  1
384571  99.360  -68.504  49.594  1
384572  99.400  -68.513  49.548  1
384573  99.440  -68.523  49.502  1
384574  99.480  -68.533  49.456  1
384575  99.520  -68.542  49.410  1
384576  99.540  -68.554  49.364  1
384577  99.553  -68.566  49.320  1
384578  99.610  -68.569  49.278  1
384579  99.656  -68.573  49.237  1
384580  99.690  -68.576  49.198  1
384581  99.724  -68.580  49.158  1
384582  99.756  -68.591  49.120  1
384583  99.781  -68.611  49.080  1
384584  99.807  -68.630  49.039  1
384585  99.840  -68.646  48.997  1
384586  99.893  -68.651  48.953  1
384587  99.947  -68.656  48.907  1
384588  99.997  -68.651  48.860  1
384589  100.030  -68.586  48.811  1
384590  100.062  -68.523  48.761  1
384591  100.087  -68.482  48.710  1
384592  100.120  -68.513  48.657  1
384593  100.151  -68.552  48.604  1
384594  100.184  -68.592  48.550  1
384595  100.216  -68.630  48.501  1
384596  100.248  -68.669  48.453  1
384597  100.280  -68.708  48.407  1
384598  100.312  -68.747  48.361  1
384599  100.344  -68.786  48.315  1
384600  100.373  -68.795  48.271  1
384601  100.403  -68.799  48.227  1
384602  100.432  -68.804  48.184  1
384603  100.469  -68.803  48.142  1
385042  90.350  -68.021  54.805  1
385043  90.381  -68.032  54.801  1
385044  90.412  -68.043  54.799  1
385045  90.444  -68.053  54.798  1
385046  90.475  -68.064  54.800  1
385047  90.506  -68.075  54.804  1
385048  90.537  -68.085  54.810  1
385049  90.569  -68.096  54.816  1
385050  90.599  -68.106  54.823  1
385051  90.630  -68.116  54.829  1
385052  90.684  -68.143  54.837  1
385053  90.742  -68.172  54.844  1
385054  90.801  -68.201  54.851  1
385055  90.866  -68.241  54.857  1
385056  90.929  -68.259  54.861  1
385057  90.980  -68.248  54.858  1
385058  91.032  -68.238  54.852  1
385059  91.083  -68.227  54.841  1
385060  91.135  -68.216  54.826  1
385061  91.186  -68.206  54.810  1
385062  91.237  -68.194  54.793  1
385063  91.289  -68.184  54.776  1
385064  91.340  -68.173  54.758  1
385065  91.391  -68.162  54.739  1
385066  91.442  -68.152  54.723  1
385067  91.494  -68.141  54.708  1
385068  91.545  -68.131  54.693  1
385069  91.596  -68.120  54.680  1
385070  91.648  -68.109  54.668  1
385071  91.698  -68.108  54.658  1
385072  91.746  -68.106  54.649  1
385073  91.788  -68.107  54.641  1
385074  91.830  -68.109  54.635  1
385075  91.873  -68.109  54.630  1
385076  91.915  -68.110  54.627  1
385077  91.957  -68.111  54.624  1
385078  91.999  -68.112  54.622  1
385079  92.041  -68.113  54.621  1
385080  92.082  -68.123  54.617  1
385081  92.122  -68.133  54.610  1
385082  92.162  -68.142  54.601  1
385083  92.203  -68.152  54.590  1
385084  92.243  -68.162  54.576  1
385085  92.290  -68.162  54.560  1
385086  92.340  -68.159  54.543  1
385087  92.389  -68.156  54.526  1
385088  92.439  -68.153  54.509  1
385089  92.488  -68.151  54.491  1
385090  92.537  -68.148  54.472  1
385091  92.587  -68.146  54.452  1
385092  92.636  -68.143  54.431  1
385093  92.686  -68.141  54.411  1
385094  92.735  -68.137  54.390  1
385095  92.792  -68.128  54.368  1
385096  92.850  -68.117  54.346  1
385097  92.909  -68.106  54.322  1
385098  92.967  -68.096  54.299  1
385099  93.009  -68.093  54.277  1
385100  93.053  -68.091  54.254  1
385101  93.105  -68.087  54.233  1
385102  93.157  -68.084  54.212  1
385103  93.209  -68.082  54.192  1
385104  93.260  -68.079  54.172  1
385105  93.310  -68.076  54.154  1
385106  93.360  -68.073  54.137  1
385107  93.410  -68.071  54.122  1
385108  93.460  -68.068  54.108  1
385109  93.510  -68.065  54.095  1
385110  93.560  -68.062  54.081  1
385111  93.610  -68.059  54.067  1
385112  93.659  -68.056  54.052  1
385113  93.708  -68.053  54.035  1
385114  93.757  -68.051  54.017  1
385115  93.805  -68.048  53.999  1
385116  93.854  -68.046  53.978  1
385117  93.904  -68.043  53.959  1
385118  93.953  -68.040  53.942  1
385119  94.001  -68.037  53.928  1
385120  94.050  -68.034  53.914  1
385121  94.099  -68.031  53.899  1
385122  94.148  -68.029  53.882  1
385123  94.197  -68.026  53.863  1
385124  94.246  -68.024  53.841  1
385125  94.295  -68.021  53.815  1
385126  94.344  -68.018  53.790  1
385127  94.393  -68.015  53.764  1
385128  94.441  -68.012  53.734  1
385129  94.490  -68.009  53.702  1
385130  94.539  -68.007  53.671  1
385131  94.584  -68.006  53.642  1
385132  94.619  -67.997  53.616  1
385133  94.644  -67.984  53.592  1
385134  94.669  -67.971  53.569  1
385135  94.694  -67.957  53.549  1
385136  94.719  -67.944  53.530  1
385137  94.744  -67.931  53.512  1
385138  94.769  -67.918  53.495  1
385139  94.793  -67.905  53.478  1
385140  94.819  -67.892  53.462  1
385141  94.843  -67.879  53.447  1
385142  94.868  -67.865  53.432  1
385143  94.893  -67.852  53.415  1
385144  94.918  -67.840  53.398  1
385145  94.943  -67.827  53.379  1
385146  94.968  -67.813  53.359  1
385147  94.993  -67.800  53.338  1
385148  95.018  -67.787  53.318  1
385149  95.042  -67.774  53.297  1
385150  95.067  -67.761  53.276  1
385151  95.099  -67.759  53.256  1
385152  95.137  -67.767  53.235  1
385153  95.175  -67.775  53.215  1
385154  95.212  -67.783  53.194  1
385155  95.250  -67.791  53.175  1
385156  95.288  -67.799  53.156  1
385157  95.326  -67.808  53.137  1
385158  95.364  -67.816  53.119  1
385159  95.402  -67.822  53.100  1
385160  95.445  -67.823  53.083  1
385161  95.487  -67.824  53.066  1
385162  95.530  -67.825  53.049  1
385163  95.572  -67.827  53.030  1
385164  95.613  -67.832  53.011  1
385165  95.654  -67.840  52.993  1
385166  95.695  -67.846  52.975  1
385167  95.736  -67.854  52.957  1
385168  95.776  -67.861  52.940  1
385169  95.818  -67.868  52.925  1
385170  95.859  -67.875  52.909  1
385171  95.900  -67.881  52.893  1
385172  95.934  -67.887  52.878  1
385173  95.964  -67.889  52.863  1
385174  95.994  -67.892  52.849  1
385175  96.031  -67.896  52.833  1
385176  96.068  -67.902  52.818  1
385177  96.106  -67.907  52.803  1
385178  96.144  -67.912  52.788  1
385179  96.182  -67.918  52.772  1
385180  96.220  -67.923  52.756  1
385181  96.258  -67.928  52.739  1
385182  96.296  -67.934  52.722  1
385183  96.333  -67.939  52.704  1
385184  96.371  -67.944  52.685  1
385185  96.408  -67.949  52.666  1
385186  96.443  -67.956  52.646  1
385187  96.478  -67.962  52.624  1
385188  96.514  -67.968  52.604  1
385189  96.549  -67.974  52.584  1
385190  96.584  -67.981  52.563  1
385191  96.616  -67.988  52.544  1
385192  96.644  -67.993  52.523  1
385193  96.672  -67.999  52.499  1
385194  96.700  -68.004  52.475  1
385195  96.729  -68.009  52.453  1
385196  96.757  -68.015  52.433  1
385197  96.785  -68.020  52.413  1
385198  96.813  -68.025  52.393  1
385199  96.841  -68.030  52.373  1
385200  96.870  -68.035  52.351  1
385201  96.898  -68.040  52.330  1
385202  96.926  -68.046  52.316  1
385203  96.957  -68.053  52.306  1
385204  96.991  -68.062  52.299  1
385205  97.024  -68.070  52.292  1
385206  97.057  -68.079  52.287  1
385207  97.090  -68.087  52.285  1
385208  97.123  -68.087  52.285  1
385209  97.155  -68.082  52.284  1
385210  97.187  -68.077  52.277  1
385211  97.232  -68.078  52.269  1
385212  97.262  -68.081  52.255  1
385213  97.293  -68.084  52.236  1
385214  97.324  -68.087  52.212  1
385215  97.355  -68.090  52.184  1
385216  97.387  -68.091  52.152  1
385217  97.421  -68.090  52.117  1
385218  97.455  -68.092  52.080  1
385219  97.493  -68.103  52.037  1
385220  97.531  -68.115  51.997  1
385221  97.569  -68.127  51.961  1
385222  97.599  -68.118  51.928  1
385223  97.631  -68.108  51.898  1
385224  97.662  -68.101  51.865  1
385225  97.698  -68.117  51.830  1
385226  97.733  -68.134  51.792  1
385227  97.769  -68.150  51.752  1
385228  97.805  -68.166  51.710  1
385229  97.840  -68.178  51.670  1
385230  97.874  -68.181  51.629  1
385231  97.908  -68.188  51.586  1
385232  97.943  -68.200  51.539  1
385233  97.975  -68.200  51.490  1
385234  98.006  -68.194  51.441  1
385235  98.038  -68.188  51.392  1
385236  98.069  -68.182  51.345  1
385237  98.100  -68.176  51.299  1
385238  98.132  -68.171  51.249  1
385239  98.164  -68.173  51.196  1
385240  98.198  -68.186  51.142  1
385241  98.231  -68.199  51.088  1
385242  98.265  -68.212  51.033  1
385243  98.298  -68.225  50.979  1
385244  98.332  -68.238  50.926  1
385245  98.365  -68.250  50.873  1
385246  98.398  -68.263  50.823  1
385247  98.432  -68.275  50.771  1
385248  98.465  -68.288  50.721  1
385249  98.498  -68.301  50.671  1
385250  98.531  -68.314  50.621  1
385251  98.565  -68.327  50.573  1
385252  98.601  -68.332  50.525  1
385253  98.633  -68.339  50.476  1
385254  98.670  -68.343  50.426  1
385255  98.707  -68.347  50.379  1
385256  98.743  -68.350  50.332  1
385257  98.780  -68.354  50.287  1
385258  98.817  -68.358  50.243  1
385259  98.854  -68.362  50.198  1
385260  98.897  -68.363  50.151  1
385261  98.939  -68.362  50.102  1
385262  98.983  -68.363  50.054  1
385263  99.028  -68.366  50.006  1
385264  99.074  -68.369  49.957  1
385265  99.120  -68.372  49.910  1
385266  99.164  -68.377  49.862  1
385267  99.194  -68.394  49.816  1
385268  99.224  -68.412  49.774  1
385269  99.254  -68.430  49.729  1
385270  99.286  -68.446  49.683  1
385271  99.326  -68.456  49.635  1
385272  99.366  -68.466  49.588  1
385273  99.406  -68.476  49.539  1
385274  99.446  -68.485  49.492  1
385275  99.486  -68.495  49.445  1
385276  99.526  -68.505  49.399  1
385277  99.565  -68.515  49.352  1
385278  99.577  -68.526  49.309  1
385279  99.632  -68.530  49.268  1
385280  99.667  -68.534  49.227  1
385281  99.701  -68.538  49.187  1
385282  99.736  -68.542  49.147  1
385283  99.765  -68.556  49.108  1
385284  99.790  -68.576  49.069  1
385285  99.816  -68.595  49.028  1
385286  99.845  -68.614  48.988  1
385287  99.899  -68.618  48.944  1
385288  99.952  -68.623  48.898  1
385289  99.990  -68.576  48.851  1
385290  100.022  -68.512  48.803  1
385291  100.055  -68.448  48.752  1
385292  100.089  -68.459  48.701  1
385293  100.122  -68.498  48.649  1
385294  100.154  -68.537  48.596  1
385295  100.186  -68.576  48.544  1
385296  100.218  -68.614  48.497  1
385297  100.250  -68.653  48.450  1
385298  100.282  -68.692  48.403  1
385299  100.315  -68.731  48.357  1
385300  100.345  -68.750  48.312  1
385301  100.374  -68.755  48.268  1
385302  100.403  -68.759  48.225  1
385303  100.439  -68.759  48.182  1
385742  90.307  -67.979  54.814  1
385743  90.338  -67.990  54.809  1
385744  90.369  -68.000  54.806  1
385745  90.400  -68.010  54.805  1
385746  90.432  -68.021  54.807  1
385747  90.463  -68.031  54.811  1
385748  90.494  -68.042  54.815  1
385749  90.525  -68.053  54.822  1
385750  90.556  -68.063  54.829  1
385751  90.588  -68.074  54.837  1
385752  90.620  -68.085  54.845  1
385753  90.678  -68.114  54.852  1
385754  90.736  -68.144  54.860  1
385755  90.795  -68.174  54.867  1
385756  90.869  -68.221  54.872  1
385757  90.921  -68.210  54.875  1
385758  90.972  -68.200  54.870  1
385759  91.023  -68.189  54.860  1
385760  91.075  -68.178  54.847  1
385761  91.126  -68.168  54.831  1
385762  91.177  -68.156  54.813  1
385763  91.229  -68.146  54.796  1
385764  91.280  -68.135  54.779  1
385765  91.331  -68.125  54.761  1
385766  91.383  -68.114  54.742  1
385767  91.434  -68.103  54.727  1
385768  91.486  -68.093  54.713  1
385769  91.537  -68.082  54.699  1
385770  91.588  -68.071  54.687  1
385771  91.640  -68.060  54.677  1
385772  91.690  -68.050  54.669  1
385773  91.741  -68.049  54.661  1
385774  91.784  -68.050  54.655  1
385775  91.826  -68.050  54.649  1
385776  91.868  -68.051  54.644  1
385777  91.911  -68.052  54.642  1
385778  91.952  -68.056  54.641  1
385779  91.992  -68.065  54.638  1
385780  92.033  -68.075  54.636  1
385781  92.073  -68.084  54.629  1
385782  92.113  -68.094  54.620  1
385783  92.154  -68.103  54.609  1
385784  92.195  -68.112  54.595  1
385785  92.235  -68.122  54.580  1
385786  92.275  -68.132  54.562  1
385787  92.323  -68.131  54.544  1
385788  92.373  -68.128  54.526  1
385789  92.422  -68.125  54.508  1
385790  92.472  -68.122  54.490  1
385791  92.521  -68.120  54.471  1
385792  92.571  -68.117  54.450  1
385793  92.625  -68.110  54.429  1
385794  92.683  -68.100  54.408  1
385795  92.741  -68.089  54.386  1
385796  92.799  -68.078  54.365  1
385797  92.858  -68.067  54.343  1
385798  92.916  -68.056  54.321  1
385799  92.974  -68.045  54.299  1
385800  93.012  -68.045  54.278  1
385801  93.047  -68.046  54.256  1
385802  93.099  -68.042  54.236  1
385803  93.152  -68.037  54.217  1
385804  93.204  -68.034  54.197  1
385805  93.256  -68.032  54.179  1
385806  93.307  -68.029  54.161  1
385807  93.359  -68.027  54.144  1
385808  93.410  -68.024  54.130  1
385809  93.460  -68.021  54.116  1
385810  93.510  -68.018  54.103  1
385811  93.560  -68.015  54.090  1
385812  93.611  -68.012  54.075  1
385813  93.660  -68.009  54.060  1
385814  93.709  -68.007  54.044  1
385815  93.758  -68.004  54.026  1
385816  93.806  -68.002  54.007  1
385817  93.856  -67.999  53.987  1
385818  93.905  -67.996  53.968  1
385819  93.954  -67.993  53.950  1
385820  94.002  -67.990  53.936  1
385821  94.051  -67.987  53.921  1
385822  94.100  -67.985  53.906  1
385823  94.149  -67.982  53.889  1
385824  94.198  -67.979  53.870  1
385825  94.247  -67.977  53.849  1
385826  94.296  -67.974  53.825  1
385827  94.345  -67.971  53.800  1
385828  94.390  -67.971  53.772  1
385829  94.436  -67.972  53.741  1
385830  94.482  -67.972  53.708  1
385831  94.519  -67.967  53.677  1
385832  94.555  -67.961  53.649  1
385833  94.592  -67.955  53.622  1
385834  94.628  -67.948  53.596  1
385835  94.657  -67.932  53.574  1
385836  94.685  -67.916  53.552  1
385837  94.710  -67.903  53.532  1
385838  94.735  -67.890  53.513  1
385839  94.760  -67.877  53.496  1
385840  94.785  -67.864  53.479  1
385841  94.810  -67.851  53.462  1
385842  94.834  -67.837  53.446  1
385843  94.859  -67.824  53.431  1
385844  94.884  -67.811  53.414  1
385845  94.909  -67.798  53.397  1
385846  94.934  -67.785  53.379  1
385847  94.959  -67.772  53.359  1
385848  94.984  -67.759  53.339  1
385849  95.008  -67.746  53.318  1
385850  95.034  -67.733  53.297  1
385851  95.060  -67.724  53.276  1
385852  95.099  -67.731  53.255  1
385853  95.136  -67.739  53.234  1
385854  95.174  -67.748  53.213  1
385855  95.212  -67.755  53.192  1
385856  95.250  -67.764  53.172  1
385857  95.287  -67.772  53.152  1
385858  95.326  -67.777  53.133  1
385859  95.367  -67.778  53.114  1
385860  95.408  -67.779  53.095  1
385861  95.450  -67.780  53.077  1
385862  95.492  -67.781  53.058  1
385863  95.535  -67.783  53.040  1
385864  95.577  -67.786  53.021  1
385865  95.617  -67.793  53.002  1
385866  95.658  -67.800  52.983  1
385867  95.699  -67.807  52.964  1
385868  95.740  -67.815  52.945  1
385869  95.781  -67.822  52.928  1
385870  95.822  -67.829  52.912  1
385871  95.863  -67.837  52.895  1
385872  95.903  -67.846  52.879  1
385873  95.937  -67.852  52.863  1
385874  95.966  -67.855  52.848  1
385875  95.996  -67.857  52.833  1
385876  96.032  -67.862  52.816  1
385877  96.070  -67.867  52.800  1
385878  96.107  -67.872  52.785  1
385879  96.145  -67.877  52.770  1
385880  96.183  -67.883  52.754  1
385881  96.221  -67.888  52.737  1
385882  96.259  -67.893  52.720  1
385883  96.295  -67.899  52.703  1
385884  96.330  -67.905  52.684  1
385885  96.365  -67.912  52.666  1
385886  96.400  -67.918  52.648  1
385887  96.436  -67.924  52.628  1
385888  96.470  -67.931  52.607  1
385889  96.506  -67.937  52.587  1
385890  96.541  -67.943  52.567  1
385891  96.576  -67.950  52.547  1
385892  96.610  -67.957  52.527  1
385893  96.642  -67.964  52.507  1
385894  96.670  -67.968  52.485  1
385895  96.698  -67.974  52.462  1
385896  96.726  -67.979  52.441  1
385897  96.754  -67.984  52.421  1
385898  96.783  -67.990  52.402  1
385899  96.811  -67.995  52.384  1
385900  96.839  -68.000  52.365  1
385901  96.867  -68.006  52.344  1
385902  96.895  -68.011  52.327  1
385903  96.926  -68.018  52.315  1
385904  96.959  -68.027  52.306  1
385905  96.993  -68.035  52.300  1
385906  97.026  -68.043  52.296  1
385907  97.059  -68.053  52.294  1
385908  97.092  -68.061  52.293  1
385909  97.125  -68.060  52.292  1
385910  97.157  -68.055  52.289  1
385911  97.195  -68.052  52.280  1
385912  97.239  -68.053  52.269  1
385913  97.270  -68.056  52.252  1
385914  97.300  -68.059  52.229  1
385915  97.330  -68.062  52.201  1
385916  97.362  -68.064  52.171  1
385917  97.396  -68.063  52.137  1
385918  97.430  -68.062  52.102  1
385919  97.463  -68.061  52.065  1
385920  97.498  -68.062  52.024  1
385921  97.535  -68.074  51.987  1
385922  97.573  -68.086  51.952  1
385923  97.607  -68.084  51.920  1
385924  97.638  -68.075  51.890  1
385925  97.670  -68.073  51.858  1
385926  97.706  -68.089  51.820  1
385927  97.741  -68.106  51.779  1
385928  97.777  -68.122  51.738  1
385929  97.813  -68.137  51.694  1
385930  97.849  -68.154  51.653  1
385931  97.884  -68.164  51.612  1
385932  97.918  -68.173  51.571  1
385933  97.950  -68.169  51.525  1
385934  97.981  -68.162  51.475  1
385935  98.012  -68.157  51.427  1
385936  98.044  -68.151  51.379  1
385937  98.075  -68.146  51.333  1
385938  98.106  -68.140  51.286  1
385939  98.138  -68.134  51.235  1
385940  98.171  -68.144  51.183  1
385941  98.205  -68.157  51.129  1
385942  98.238  -68.169  51.075  1
385943  98.271  -68.182  51.021  1
385944  98.305  -68.195  50.967  1
385945  98.338  -68.208  50.914  1
385946  98.371  -68.221  50.861  1
385947  98.405  -68.234  50.811  1
385948  98.438  -68.247  50.760  1
385949  98.472  -68.259  50.711  1
385950  98.505  -68.272  50.663  1
385951  98.538  -68.282  50.613  1
385952  98.573  -68.291  50.563  1
385953  98.607  -68.300  50.515  1
385954  98.647  -68.297  50.467  1
385955  98.688  -68.288  50.419  1
385956  98.718  -68.299  50.369  1
385957  98.747  -68.310  50.322  1
385958  98.776  -68.321  50.276  1
385959  98.812  -68.326  50.231  1
385960  98.849  -68.330  50.188  1
385961  98.887  -68.333  50.143  1
385962  98.930  -68.333  50.096  1
385963  98.976  -68.336  50.049  1
385964  99.022  -68.339  50.002  1
385965  99.068  -68.342  49.953  1
385966  99.113  -68.346  49.904  1
385967  99.159  -68.349  49.858  1
385968  99.199  -68.357  49.813  1
385969  99.228  -68.375  49.769  1
385970  99.259  -68.393  49.723  1
385971  99.291  -68.408  49.675  1
385972  99.332  -68.418  49.627  1
385973  99.371  -68.428  49.578  1
385974  99.412  -68.438  49.528  1
385975  99.451  -68.448  49.481  1
385976  99.492  -68.457  49.434  1
385977  99.532  -68.467  49.387  1
385978  99.572  -68.477  49.341  1
385979  99.603  -68.488  49.297  1
385980  99.643  -68.492  49.257  1
385981  99.678  -68.495  49.217  1
385982  99.712  -68.500  49.177  1
385983  99.747  -68.504  49.136  1
385984  99.774  -68.520  49.097  1
385985  99.800  -68.541  49.058  1
385986  99.825  -68.560  49.018  1
385987  99.851  -68.580  48.980  1
385988  99.904  -68.586  48.936  1
385989  99.949  -68.565  48.890  1
385990  99.982  -68.501  48.842  1
385991  100.020  -68.446  48.793  1
385992  100.060  -68.405  48.742  1
385993  100.092  -68.443  48.692  1
385994  100.124  -68.482  48.640  1
385995  100.156  -68.521  48.589  1
385996  100.188  -68.560  48.538  1
385997  100.220  -68.598  48.491  1
385998  100.253  -68.638  48.445  1
385999  100.285  -68.676  48.399  1
386000  100.316  -68.705  48.353  1
386001  100.345  -68.710  48.309  1
386002  100.374  -68.714  48.264  1
386003  100.408  -68.715  48.221  1
386004  100.448  -68.714  48.179  1
386443  90.295  -67.946  54.817  1
386444  90.326  -67.957  54.814  1
386445  90.358  -67.968  54.812  1
386446  90.388  -67.978  54.814  1
386447  90.419  -67.989  54.817  1
386448  90.451  -67.999  54.822  1
386449  90.482  -68.010  54.828  1
386450  90.513  -68.020  54.836  1
386451  90.544  -68.031  54.844  1
386452  90.576  -68.041  54.853  1
386453  90.614  -68.057  54.862  1
386454  90.672  -68.086  54.870  1
386455  90.730  -68.115  54.878  1
386456  90.802  -68.164  54.885  1
386457  90.870  -68.167  54.889  1
386458  90.923  -68.158  54.888  1
386459  90.972  -68.148  54.881  1
386460  91.023  -68.137  54.869  1
386461  91.073  -68.128  54.854  1
386462  91.122  -68.117  54.836  1
386463  91.172  -68.107  54.818  1
386464  91.223  -68.097  54.801  1
386465  91.273  -68.087  54.783  1
386466  91.323  -68.076  54.766  1
386467  91.374  -68.065  54.747  1
386468  91.426  -68.055  54.733  1
386469  91.477  -68.044  54.719  1
386470  91.528  -68.033  54.707  1
386471  91.580  -68.022  54.696  1
386472  91.631  -68.012  54.689  1
386473  91.682  -68.001  54.682  1
386474  91.734  -67.991  54.676  1
386475  91.779  -67.991  54.670  1
386476  91.821  -67.992  54.665  1
386477  91.863  -67.997  54.661  1
386478  91.903  -68.007  54.659  1
386479  91.943  -68.016  54.657  1
386480  91.984  -68.026  54.653  1
386481  92.024  -68.035  54.648  1
386482  92.065  -68.045  54.639  1
386483  92.105  -68.055  54.628  1
386484  92.146  -68.064  54.614  1
386485  92.186  -68.074  54.599  1
386486  92.226  -68.083  54.582  1
386487  92.267  -68.093  54.564  1
386488  92.307  -68.103  54.546  1
386489  92.357  -68.100  54.527  1
386490  92.406  -68.097  54.507  1
386491  92.457  -68.093  54.488  1
386492  92.515  -68.081  54.468  1
386493  92.574  -68.071  54.448  1
386494  92.632  -68.060  54.426  1
386495  92.690  -68.050  54.405  1
386496  92.748  -68.038  54.383  1
386497  92.807  -68.028  54.362  1
386498  92.865  -68.017  54.341  1
386499  92.923  -68.006  54.320  1
386500  92.980  -67.996  54.299  1
386501  93.014  -67.997  54.279  1
386502  93.049  -67.999  54.260  1
386503  93.092  -67.997  54.241  1
386504  93.145  -67.992  54.223  1
386505  93.199  -67.987  54.204  1
386506  93.251  -67.985  54.186  1
386507  93.302  -67.982  54.169  1
386508  93.354  -67.979  54.152  1
386509  93.406  -67.977  54.137  1
386510  93.458  -67.974  54.125  1
386511  93.510  -67.971  54.112  1
386512  93.560  -67.968  54.097  1
386513  93.611  -67.966  54.083  1
386514  93.660  -67.963  54.068  1
386515  93.710  -67.960  54.052  1
386516  93.759  -67.957  54.035  1
386517  93.808  -67.955  54.016  1
386518  93.857  -67.952  53.996  1
386519  93.906  -67.949  53.976  1
386520  93.955  -67.946  53.958  1
386521  94.003  -67.943  53.942  1
386522  94.052  -67.941  53.928  1
386523  94.102  -67.938  53.912  1
386524  94.149  -67.937  53.895  1
386525  94.195  -67.937  53.877  1
386526  94.241  -67.937  53.857  1
386527  94.286  -67.937  53.834  1
386528  94.332  -67.937  53.809  1
386529  94.378  -67.937  53.780  1
386530  94.418  -67.934  53.748  1
386531  94.454  -67.927  53.714  1
386532  94.490  -67.921  53.683  1
386533  94.527  -67.915  53.654  1
386534  94.563  -67.909  53.627  1
386535  94.600  -67.903  53.601  1
386536  94.636  -67.897  53.577  1
386537  94.666  -67.883  53.556  1
386538  94.694  -67.867  53.535  1
386539  94.723  -67.851  53.515  1
386540  94.751  -67.836  53.498  1
386541  94.776  -67.822  53.480  1
386542  94.801  -67.809  53.463  1
386543  94.826  -67.796  53.446  1
386544  94.850  -67.783  53.431  1
386545  94.875  -67.770  53.414  1
386546  94.900  -67.757  53.396  1
386547  94.925  -67.744  53.378  1
386548  94.950  -67.730  53.359  1
386549  94.975  -67.717  53.339  1
386550  95.000  -67.705  53.318  1
386551  95.025  -67.692  53.297  1
386552  95.060  -67.695  53.276  1
386553  95.098  -67.704  53.254  1
386554  95.135  -67.712  53.232  1
386555  95.173  -67.720  53.211  1
386556  95.211  -67.728  53.191  1
386557  95.251  -67.732  53.171  1
386558  95.291  -67.733  53.149  1
386559  95.332  -67.734  53.129  1
386560  95.373  -67.735  53.110  1
386561  95.413  -67.736  53.090  1
386562  95.455  -67.737  53.072  1
386563  95.497  -67.739  53.052  1
386564  95.540  -67.740  53.032  1
386565  95.581  -67.746  53.013  1
386566  95.622  -67.753  52.994  1
386567  95.663  -67.761  52.974  1
386568  95.703  -67.768  52.954  1
386569  95.744  -67.775  52.934  1
386570  95.785  -67.784  52.916  1
386571  95.826  -67.793  52.898  1
386572  95.867  -67.802  52.881  1
386573  95.907  -67.811  52.865  1
386574  95.942  -67.818  52.849  1
386575  95.969  -67.820  52.834  1
386576  95.998  -67.823  52.818  1
386577  96.033  -67.827  52.801  1
386578  96.071  -67.832  52.785  1
386579  96.108  -67.837  52.769  1
386580  96.146  -67.843  52.753  1
386581  96.181  -67.849  52.737  1
386582  96.217  -67.855  52.720  1
386583  96.252  -67.862  52.703  1
386584  96.287  -67.868  52.686  1
386585  96.322  -67.874  52.668  1
386586  96.357  -67.880  52.650  1
386587  96.392  -67.887  52.631  1
386588  96.428  -67.893  52.611  1
386589  96.463  -67.899  52.591  1
386590  96.498  -67.905  52.570  1
386591  96.533  -67.912  52.551  1
386592  96.568  -67.919  52.531  1
386593  96.602  -67.926  52.511  1
386594  96.637  -67.933  52.491  1
386595  96.667  -67.939  52.470  1
386596  96.695  -67.944  52.448  1
386597  96.723  -67.949  52.428  1
386598  96.751  -67.955  52.409  1
386599  96.780  -67.960  52.391  1
386600  96.808  -67.965  52.373  1
386601  96.836  -67.971  52.355  1
386602  96.864  -67.976  52.337  1
386603  96.895  -67.983  52.323  1
386604  96.928  -67.991  52.312  1
386605  96.961  -68.000  52.305  1
386606  96.995  -68.009  52.301  1
386607  97.028  -68.017  52.299  1
386608  97.061  -68.026  52.299  1
386609  97.094  -68.034  52.298  1
386610  97.126  -68.033  52.295  1
386611  97.159  -68.028  52.289  1
386612  97.203  -68.028  52.279  1
386613  97.245  -68.028  52.266  1
386614  97.276  -68.031  52.247  1
386615  97.307  -68.035  52.221  1
386616  97.337  -68.037  52.190  1
386617  97.371  -68.037  52.158  1
386618  97.405  -68.035  52.122  1
386619  97.438  -68.034  52.085  1
386620  97.472  -68.033  52.049  1
386621  97.506  -68.031  52.011  1
386622  97.540  -68.033  51.977  1
386623  97.578  -68.045  51.945  1
386624  97.614  -68.052  51.914  1
386625  97.645  -68.041  51.882  1
386626  97.678  -68.045  51.848  1
386627  97.714  -68.061  51.808  1
386628  97.749  -68.078  51.766  1
386629  97.785  -68.094  51.722  1
386630  97.821  -68.110  51.679  1
386631  97.857  -68.126  51.637  1
386632  97.892  -68.139  51.597  1
386633  97.924  -68.137  51.555  1
386634  97.955  -68.131  51.509  1
386635  97.987  -68.126  51.459  1
386636  98.018  -68.120  51.411  1
386637  98.050  -68.115  51.365  1
386638  98.081  -68.109  51.319  1
386639  98.112  -68.103  51.273  1
386640  98.144  -68.102  51.222  1
386641  98.178  -68.115  51.170  1
386642  98.211  -68.128  51.116  1
386643  98.244  -68.141  51.063  1
386644  98.278  -68.153  51.011  1
386645  98.311  -68.166  50.959  1
386646  98.345  -68.178  50.907  1
386647  98.378  -68.191  50.854  1
386648  98.412  -68.204  50.803  1
386649  98.445  -68.217  50.752  1
386650  98.479  -68.228  50.703  1
386651  98.512  -68.237  50.655  1
386652  98.546  -68.246  50.607  1
386653  98.580  -68.254  50.556  1
386654  98.616  -68.264  50.507  1
386655  98.652  -68.271  50.459  1
386656  98.693  -68.263  50.411  1
386657  98.734  -68.253  50.363  1
386658  98.774  -68.247  50.315  1
386659  98.803  -68.258  50.268  1
386660  98.833  -68.269  50.223  1
386661  98.862  -68.281  50.179  1
386662  98.891  -68.291  50.136  1
386663  98.925  -68.306  50.091  1
386664  98.970  -68.310  50.044  1
386665  99.015  -68.313  49.997  1
386666  99.061  -68.316  49.949  1
386667  99.106  -68.319  49.901  1
386668  99.152  -68.322  49.854  1
386669  99.198  -68.325  49.809  1
386670  99.233  -68.338  49.763  1
386671  99.263  -68.356  49.715  1
386672  99.297  -68.370  49.666  1
386673  99.337  -68.380  49.617  1
386674  99.377  -68.390  49.568  1
386675  99.417  -68.400  49.518  1
386676  99.457  -68.410  49.471  1
386677  99.497  -68.419  49.423  1
386678  99.538  -68.429  49.376  1
386679  99.577  -68.438  49.330  1
386680  99.611  -68.447  49.286  1
386681  99.655  -68.453  49.246  1
386682  99.689  -68.457  49.206  1
386683  99.723  -68.461  49.166  1
386684  99.758  -68.466  49.126  1
386685  99.783  -68.485  49.086  1
386686  99.809  -68.506  49.048  1
386687  99.835  -68.526  49.009  1
386688  99.860  -68.545  48.970  1
386689  99.909  -68.553  48.927  1
386690  99.942  -68.490  48.880  1
386691  99.985  -68.444  48.832  1
386692  100.028  -68.398  48.783  1
386693  100.062  -68.388  48.732  1
386694  100.094  -68.428  48.682  1
386695  100.126  -68.466  48.632  1
386696  100.158  -68.505  48.581  1
386697  100.191  -68.544  48.532  1
386698  100.223  -68.582  48.486  1
386699  100.255  -68.622  48.440  1
386700  100.287  -68.660  48.394  1
386701  100.316  -68.664  48.349  1
386702  100.345  -68.669  48.305  1
386703  100.378  -68.671  48.260  1
386704  100.417  -68.670  48.217  1
386705  100.457  -68.667  48.175  1
387143  90.252  -67.904  54.826  1
387144  90.283  -67.915  54.822  1
387145  90.314  -67.924  54.820  1
387146  90.345  -67.935  54.820  1
387147  90.377  -67.946  54.823  1
387148  90.407  -67.956  54.828  1
387149  90.439  -67.967  54.834  1
387150  90.470  -67.978  54.842  1
387151  90.501  -67.988  54.851  1
387152  90.532  -67.999  54.860  1
387153  90.564  -68.009  54.869  1
387154  90.607  -68.028  54.879  1
387155  90.666  -68.058  54.888  1
387156  90.731  -68.097  54.896  1
387157  90.801  -68.112  54.902  1
387158  90.868  -68.109  54.903  1
387159  90.929  -68.104  54.899  1
387160  90.978  -68.094  54.890  1
387161  91.029  -68.084  54.876  1
387162  91.079  -68.074  54.860  1
387163  91.129  -68.063  54.842  1
387164  91.179  -68.053  54.823  1
387165  91.229  -68.043  54.807  1
387166  91.279  -68.033  54.789  1
387167  91.328  -68.022  54.772  1
387168  91.379  -68.012  54.755  1
387169  91.429  -68.002  54.741  1
387170  91.478  -67.992  54.729  1
387171  91.529  -67.981  54.718  1
387172  91.579  -67.971  54.709  1
387173  91.629  -67.961  54.703  1
387174  91.679  -67.951  54.698  1
387175  91.729  -67.940  54.693  1
387176  91.774  -67.936  54.688  1
387177  91.815  -67.946  54.683  1
387178  91.855  -67.955  54.679  1
387179  91.895  -67.965  54.676  1
387180  91.936  -67.974  54.673  1
387181  91.977  -67.984  54.666  1
387182  92.017  -67.993  54.658  1
387183  92.057  -68.003  54.647  1
387184  92.098  -68.012  54.633  1
387185  92.138  -68.021  54.617  1
387186  92.178  -68.031  54.603  1
387187  92.219  -68.040  54.584  1
387188  92.260  -68.050  54.565  1
387189  92.300  -68.059  54.547  1
387190  92.348  -68.064  54.527  1
387191  92.406  -68.053  54.506  1
387192  92.464  -68.043  54.487  1
387193  92.523  -68.031  54.467  1
387194  92.581  -68.021  54.445  1
387195  92.639  -68.010  54.424  1
387196  92.698  -67.999  54.402  1
387197  92.756  -67.988  54.380  1
387198  92.814  -67.978  54.359  1
387199  92.872  -67.967  54.339  1
387200  92.931  -67.956  54.319  1
387201  92.983  -67.949  54.300  1
387202  93.017  -67.949  54.282  1
387203  93.052  -67.951  54.264  1
387204  93.087  -67.952  54.247  1
387205  93.139  -67.947  54.232  1
387206  93.192  -67.943  54.215  1
387207  93.245  -67.937  54.198  1
387208  93.297  -67.935  54.179  1
387209  93.349  -67.932  54.162  1
387210  93.401  -67.930  54.147  1
387211  93.453  -67.927  54.132  1
387212  93.505  -67.924  54.119  1
387213  93.557  -67.921  54.106  1
387214  93.609  -67.919  54.091  1
387215  93.660  -67.916  54.076  1
387216  93.710  -67.913  54.060  1
387217  93.760  -67.911  54.043  1
387218  93.809  -67.908  54.024  1
387219  93.858  -67.905  54.004  1
387220  93.907  -67.902  53.984  1
387221  93.954  -67.901  53.965  1
387222  94.000  -67.901  53.947  1
387223  94.046  -67.902  53.933  1
387224  94.091  -67.902  53.918  1
387225  94.137  -67.902  53.902  1
387226  94.183  -67.902  53.884  1
387227  94.228  -67.902  53.864  1
387228  94.274  -67.903  53.842  1
387229  94.317  -67.901  53.816  1
387230  94.353  -67.895  53.787  1
387231  94.389  -67.889  53.755  1
387232  94.425  -67.883  53.721  1
387233  94.462  -67.877  53.688  1
387234  94.498  -67.871  53.658  1
387235  94.535  -67.865  53.630  1
387236  94.571  -67.858  53.605  1
387237  94.607  -67.852  53.581  1
387238  94.643  -67.846  53.559  1
387239  94.675  -67.834  53.538  1
387240  94.704  -67.818  53.518  1
387241  94.732  -67.802  53.500  1
387242  94.761  -67.786  53.482  1
387243  94.789  -67.770  53.464  1
387244  94.817  -67.755  53.447  1
387245  94.841  -67.742  53.431  1
387246  94.866  -67.729  53.414  1
387247  94.891  -67.716  53.396  1
387248  94.916  -67.702  53.378  1
387249  94.941  -67.689  53.359  1
387250  94.966  -67.677  53.339  1
387251  94.991  -67.663  53.319  1
387252  95.022  -67.660  53.298  1
387253  95.059  -67.668  53.277  1
387254  95.097  -67.677  53.254  1
387255  95.135  -67.684  53.232  1
387256  95.175  -67.686  53.211  1
387257  95.216  -67.688  53.190  1
387258  95.257  -67.689  53.170  1
387259  95.298  -67.690  53.148  1
387260  95.338  -67.691  53.127  1
387261  95.379  -67.692  53.107  1
387262  95.419  -67.693  53.086  1
387263  95.460  -67.695  53.067  1
387264  95.502  -67.695  53.047  1
387265  95.544  -67.699  53.026  1
387266  95.585  -67.707  53.006  1
387267  95.626  -67.714  52.987  1
387268  95.667  -67.722  52.967  1
387269  95.707  -67.731  52.947  1
387270  95.748  -67.740  52.927  1
387271  95.789  -67.749  52.908  1
387272  95.830  -67.758  52.889  1
387273  95.871  -67.768  52.872  1
387274  95.911  -67.777  52.855  1
387275  95.947  -67.783  52.839  1
387276  95.974  -67.786  52.822  1
387277  96.001  -67.788  52.806  1
387278  96.033  -67.792  52.789  1
387279  96.068  -67.799  52.773  1
387280  96.103  -67.805  52.757  1
387281  96.138  -67.811  52.740  1
387282  96.174  -67.817  52.724  1
387283  96.208  -67.824  52.707  1
387284  96.244  -67.830  52.690  1
387285  96.279  -67.836  52.673  1
387286  96.314  -67.843  52.655  1
387287  96.349  -67.849  52.636  1
387288  96.384  -67.855  52.617  1
387289  96.419  -67.861  52.597  1
387290  96.455  -67.868  52.576  1
387291  96.490  -67.874  52.555  1
387292  96.525  -67.880  52.534  1
387293  96.559  -67.887  52.515  1
387294  96.594  -67.895  52.496  1
387295  96.628  -67.902  52.475  1
387296  96.663  -67.909  52.454  1
387297  96.692  -67.915  52.434  1
387298  96.720  -67.920  52.415  1
387299  96.748  -67.925  52.397  1
387300  96.777  -67.931  52.378  1
387301  96.805  -67.935  52.361  1
387302  96.833  -67.940  52.344  1
387303  96.864  -67.948  52.329  1
387304  96.897  -67.956  52.318  1
387305  96.930  -67.965  52.308  1
387306  96.963  -67.974  52.302  1
387307  96.997  -67.982  52.299  1
387308  97.030  -67.990  52.301  1
387309  97.063  -67.999  52.302  1
387310  97.096  -68.008  52.299  1
387311  97.129  -68.006  52.294  1
387312  97.164  -68.002  52.286  1
387313  97.211  -68.003  52.275  1
387314  97.252  -68.004  52.260  1
387315  97.283  -68.007  52.239  1
387316  97.313  -68.010  52.212  1
387317  97.347  -68.009  52.178  1
387318  97.380  -68.009  52.144  1
387319  97.414  -68.007  52.106  1
387320  97.447  -68.006  52.068  1
387321  97.481  -68.005  52.033  1
387322  97.514  -68.003  51.997  1
387323  97.548  -68.003  51.966  1
387324  97.582  -68.003  51.937  1
387325  97.620  -68.015  51.907  1
387326  97.652  -68.009  51.873  1
387327  97.686  -68.017  51.837  1
387328  97.722  -68.034  51.796  1
387329  97.758  -68.050  51.751  1
387330  97.794  -68.065  51.706  1
387331  97.828  -68.077  51.663  1
387332  97.862  -68.085  51.622  1
387333  97.896  -68.094  51.582  1
387334  97.930  -68.101  51.540  1
387335  97.961  -68.095  51.492  1
387336  97.993  -68.090  51.443  1
387337  98.024  -68.084  51.396  1
387338  98.056  -68.078  51.350  1
387339  98.087  -68.072  51.306  1
387340  98.119  -68.066  51.260  1
387341  98.151  -68.073  51.210  1
387342  98.184  -68.086  51.157  1
387343  98.218  -68.099  51.104  1
387344  98.251  -68.111  51.052  1
387345  98.285  -68.124  51.001  1
387346  98.318  -68.137  50.952  1
387347  98.352  -68.150  50.901  1
387348  98.385  -68.162  50.848  1
387349  98.418  -68.175  50.798  1
387350  98.452  -68.183  50.747  1
387351  98.486  -68.192  50.697  1
387352  98.520  -68.200  50.648  1
387353  98.554  -68.209  50.601  1
387354  98.588  -68.218  50.551  1
387355  98.624  -68.228  50.501  1
387356  98.659  -68.238  50.453  1
387357  98.698  -68.236  50.405  1
387358  98.739  -68.227  50.358  1
387359  98.781  -68.219  50.311  1
387360  98.821  -68.209  50.263  1
387361  98.859  -68.206  50.215  1
387362  98.888  -68.218  50.170  1
387363  98.918  -68.228  50.129  1
387364  98.952  -68.244  50.085  1
387365  98.987  -68.258  50.039  1
387366  99.021  -68.273  49.992  1
387367  99.056  -68.288  49.944  1
387368  99.099  -68.293  49.897  1
387369  99.145  -68.296  49.849  1
387370  99.191  -68.299  49.802  1
387371  99.236  -68.303  49.755  1
387372  99.268  -68.319  49.706  1
387373  99.303  -68.332  49.657  1
387374  99.343  -68.342  49.608  1
387375  99.383  -68.352  49.558  1
387376  99.423  -68.362  49.509  1
387377  99.464  -68.372  49.460  1
387378  99.498  -68.379  49.412  1
387379  99.532  -68.388  49.365  1
387380  99.566  -68.395  49.320  1
387381  99.600  -68.403  49.276  1
387382  99.647  -68.410  49.235  1
387383  99.694  -68.417  49.194  1
387384  99.735  -68.423  49.154  1
387385  99.767  -68.431  49.115  1
387386  99.792  -68.451  49.076  1
387387  99.818  -68.471  49.038  1
387388  99.844  -68.491  49.000  1
387389  99.869  -68.510  48.960  1
387390  99.907  -68.488  48.917  1
387391  99.950  -68.442  48.870  1
387392  99.994  -68.397  48.822  1
387393  100.037  -68.351  48.773  1
387394  100.064  -68.372  48.723  1
387395  100.097  -68.412  48.673  1
387396  100.129  -68.451  48.623  1
387397  100.161  -68.489  48.574  1
387398  100.193  -68.528  48.526  1
387399  100.225  -68.567  48.481  1
387400  100.257  -68.606  48.435  1
387401  100.287  -68.620  48.389  1
387402  100.316  -68.624  48.344  1
387403  100.347  -68.627  48.300  1
387404  100.387  -68.626  48.256  1
387405  100.427  -68.623  48.212  1
387844  90.239  -67.872  54.831  1
387845  90.271  -67.882  54.828  1
387846  90.302  -67.893  54.827  1
387847  90.333  -67.903  54.829  1
387848  90.365  -67.914  54.833  1
387849  90.396  -67.924  54.840  1
387850  90.427  -67.934  54.848  1
387851  90.458  -67.945  54.857  1
387852  90.489  -67.956  54.867  1
387853  90.520  -67.966  54.877  1
387854  90.551  -67.977  54.887  1
387855  90.601  -68.000  54.897  1
387856  90.660  -68.030  54.908  1
387857  90.732  -68.059  54.914  1
387858  90.799  -68.056  54.917  1
387859  90.866  -68.053  54.916  1
387860  90.933  -68.050  54.910  1
387861  90.984  -68.040  54.898  1
387862  91.035  -68.030  54.883  1
387863  91.085  -68.020  54.866  1
387864  91.135  -68.009  54.847  1
387865  91.185  -67.999  54.829  1
387866  91.235  -67.989  54.813  1
387867  91.285  -67.979  54.796  1
387868  91.334  -67.968  54.779  1
387869  91.385  -67.959  54.764  1
387870  91.435  -67.948  54.750  1
387871  91.485  -67.938  54.740  1
387872  91.535  -67.927  54.731  1
387873  91.585  -67.918  54.723  1
387874  91.635  -67.907  54.719  1
387875  91.685  -67.897  54.715  1
387876  91.730  -67.888  54.711  1
387877  91.772  -67.880  54.706  1
387878  91.812  -67.887  54.703  1
387879  91.853  -67.897  54.697  1
387880  91.893  -67.906  54.693  1
387881  91.934  -67.916  54.687  1
387882  91.974  -67.925  54.678  1
387883  92.014  -67.935  54.666  1
387884  92.055  -67.944  54.653  1
387885  92.095  -67.954  54.638  1
387886  92.136  -67.963  54.622  1
387887  92.176  -67.973  54.606  1
387888  92.217  -67.983  54.586  1
387889  92.257  -67.992  54.566  1
387890  92.306  -67.997  54.546  1
387891  92.360  -68.000  54.526  1
387892  92.414  -68.003  54.506  1
387893  92.472  -67.992  54.487  1
387894  92.530  -67.981  54.465  1
387895  92.588  -67.971  54.443  1
387896  92.647  -67.960  54.420  1
387897  92.705  -67.949  54.398  1
387898  92.764  -67.938  54.377  1
387899  92.821  -67.927  54.357  1
387900  92.880  -67.917  54.338  1
387901  92.938  -67.905  54.319  1
387902  92.985  -67.901  54.302  1
387903  93.020  -67.902  54.286  1
387904  93.055  -67.903  54.271  1
387905  93.090  -67.905  54.257  1
387906  93.132  -67.903  54.244  1
387907  93.185  -67.898  54.230  1
387908  93.238  -67.893  54.212  1
387909  93.292  -67.888  54.193  1
387910  93.344  -67.885  54.174  1
387911  93.396  -67.882  54.156  1
387912  93.447  -67.880  54.140  1
387913  93.499  -67.877  54.126  1
387914  93.551  -67.874  54.113  1
387915  93.603  -67.871  54.098  1
387916  93.655  -67.869  54.084  1
387917  93.707  -67.866  54.069  1
387918  93.758  -67.864  54.052  1
387919  93.804  -67.865  54.033  1
387920  93.850  -67.866  54.012  1
387921  93.896  -67.867  53.991  1
387922  93.942  -67.867  53.972  1
387923  93.988  -67.868  53.954  1
387924  94.034  -67.868  53.939  1
387925  94.079  -67.868  53.924  1
387926  94.125  -67.868  53.908  1
387927  94.171  -67.868  53.890  1
387928  94.215  -67.868  53.870  1
387929  94.252  -67.862  53.849  1
387930  94.288  -67.855  53.824  1
387931  94.324  -67.849  53.795  1
387932  94.360  -67.843  53.762  1
387933  94.397  -67.837  53.728  1
387934  94.433  -67.831  53.694  1
387935  94.470  -67.825  53.663  1
387936  94.506  -67.819  53.634  1
387937  94.542  -67.813  53.610  1
387938  94.578  -67.807  53.587  1
387939  94.615  -67.801  53.564  1
387940  94.651  -67.795  53.543  1
387941  94.684  -67.785  53.523  1
387942  94.713  -67.769  53.503  1
387943  94.742  -67.752  53.485  1
387944  94.770  -67.736  53.467  1
387945  94.799  -67.721  53.449  1
387946  94.827  -67.705  53.432  1
387947  94.856  -67.689  53.415  1
387948  94.882  -67.674  53.397  1
387949  94.907  -67.661  53.378  1
387950  94.932  -67.648  53.359  1
387951  94.957  -67.635  53.340  1
387952  94.983  -67.624  53.319  1
387953  95.021  -67.633  53.298  1
387954  95.059  -67.640  53.277  1
387955  95.100  -67.642  53.255  1
387956  95.140  -67.642  53.233  1
387957  95.181  -67.644  53.211  1
387958  95.222  -67.645  53.189  1
387959  95.262  -67.646  53.169  1
387960  95.303  -67.647  53.147  1
387961  95.344  -67.648  53.126  1
387962  95.385  -67.649  53.105  1
387963  95.425  -67.651  53.084  1
387964  95.466  -67.652  53.064  1
387965  95.508  -67.653  53.043  1
387966  95.548  -67.661  53.022  1
387967  95.589  -67.669  53.002  1
387968  95.630  -67.678  52.981  1
387969  95.671  -67.687  52.961  1
387970  95.711  -67.696  52.941  1
387971  95.752  -67.705  52.921  1
387972  95.793  -67.714  52.901  1
387973  95.834  -67.724  52.882  1
387974  95.875  -67.733  52.865  1
387975  95.915  -67.742  52.847  1
387976  95.952  -67.749  52.830  1
387977  95.979  -67.751  52.812  1
387978  96.006  -67.754  52.796  1
387979  96.034  -67.761  52.779  1
387980  96.068  -67.768  52.763  1
387981  96.101  -67.774  52.747  1
387982  96.134  -67.780  52.730  1
387983  96.168  -67.786  52.714  1
387984  96.201  -67.792  52.698  1
387985  96.236  -67.798  52.680  1
387986  96.271  -67.805  52.663  1
387987  96.306  -67.811  52.644  1
387988  96.341  -67.817  52.625  1
387989  96.377  -67.823  52.605  1
387990  96.411  -67.830  52.584  1
387991  96.447  -67.836  52.563  1
387992  96.482  -67.842  52.542  1
387993  96.517  -67.849  52.521  1
387994  96.551  -67.856  52.501  1
387995  96.586  -67.863  52.481  1
387996  96.620  -67.871  52.461  1
387997  96.655  -67.877  52.441  1
387998  96.689  -67.884  52.421  1
387999  96.718  -67.890  52.403  1
388000  96.746  -67.895  52.385  1
388001  96.774  -67.900  52.367  1
388002  96.802  -67.905  52.351  1
388003  96.833  -67.912  52.335  1
388004  96.866  -67.921  52.321  1
388005  96.899  -67.930  52.310  1
388006  96.932  -67.938  52.302  1
388007  96.965  -67.947  52.296  1
388008  96.999  -67.956  52.294  1
388009  97.032  -67.964  52.298  1
388010  97.065  -67.973  52.297  1
388011  97.098  -67.981  52.293  1
388012  97.131  -67.978  52.286  1
388013  97.172  -67.977  52.278  1
388014  97.218  -67.978  52.267  1
388015  97.259  -67.979  52.251  1
388016  97.290  -67.982  52.230  1
388017  97.322  -67.983  52.201  1
388018  97.356  -67.982  52.167  1
388019  97.389  -67.981  52.131  1
388020  97.423  -67.979  52.092  1
388021  97.456  -67.978  52.053  1
388022  97.490  -67.977  52.018  1
388023  97.523  -67.976  51.988  1
388024  97.557  -67.974  51.957  1
388025  97.591  -67.973  51.927  1
388026  97.625  -67.974  51.896  1
388027  97.659  -67.975  51.863  1
388028  97.695  -67.989  51.825  1
388029  97.730  -68.006  51.783  1
388030  97.764  -68.015  51.737  1
388031  97.799  -68.023  51.692  1
388032  97.832  -68.031  51.647  1
388033  97.867  -68.040  51.607  1
388034  97.900  -68.049  51.568  1
388035  97.935  -68.057  51.525  1
388036  97.967  -68.059  51.478  1
388037  97.999  -68.053  51.428  1
388038  98.030  -68.047  51.381  1
388039  98.062  -68.041  51.336  1
388040  98.093  -68.036  51.294  1
388041  98.125  -68.031  51.248  1
388042  98.158  -68.043  51.198  1
388043  98.191  -68.056  51.147  1
388044  98.225  -68.069  51.094  1
388045  98.258  -68.082  51.041  1
388046  98.291  -68.095  50.991  1
388047  98.325  -68.108  50.943  1
388048  98.358  -68.120  50.895  1
388049  98.392  -68.130  50.844  1
388050  98.426  -68.138  50.795  1
388051  98.460  -68.147  50.744  1
388052  98.494  -68.156  50.693  1
388053  98.527  -68.164  50.643  1
388054  98.561  -68.173  50.595  1
388055  98.596  -68.182  50.546  1
388056  98.632  -68.192  50.498  1
388057  98.667  -68.202  50.450  1
388058  98.703  -68.209  50.403  1
388059  98.744  -68.201  50.356  1
388060  98.785  -68.192  50.308  1
388061  98.827  -68.183  50.258  1
388062  98.868  -68.174  50.208  1
388063  98.909  -68.166  50.161  1
388064  98.945  -68.166  50.119  1
388065  98.980  -68.181  50.075  1
388066  99.014  -68.196  50.030  1
388067  99.049  -68.211  49.984  1
388068  99.083  -68.225  49.938  1
388069  99.118  -68.241  49.889  1
388070  99.152  -68.255  49.841  1
388071  99.187  -68.270  49.793  1
388072  99.230  -68.276  49.745  1
388073  99.273  -68.282  49.697  1
388074  99.309  -68.294  49.648  1
388075  99.349  -68.304  49.598  1
388076  99.384  -68.313  49.549  1
388077  99.419  -68.320  49.500  1
388078  99.453  -68.328  49.451  1
388079  99.487  -68.336  49.403  1
388080  99.521  -68.344  49.356  1
388081  99.556  -68.351  49.310  1
388082  99.590  -68.359  49.266  1
388083  99.636  -68.366  49.225  1
388084  99.684  -68.373  49.184  1
388085  99.731  -68.381  49.144  1
388086  99.763  -68.366  49.105  1
388087  99.791  -68.394  49.066  1
388088  99.820  -68.423  49.028  1
388089  99.849  -68.451  48.989  1
388090  99.876  -68.469  48.948  1
388091  99.916  -68.440  48.904  1
388092  99.959  -68.394  48.858  1
388093  100.002  -68.349  48.812  1
388094  100.035  -68.319  48.763  1
388095  100.067  -68.357  48.714  1
388096  100.099  -68.396  48.664  1
388097  100.131  -68.435  48.614  1
388098  100.163  -68.473  48.566  1
388099  100.195  -68.513  48.519  1
388100  100.227  -68.551  48.475  1
388101  100.258  -68.575  48.429  1
388102  100.287  -68.579  48.384  1
388103  100.317  -68.583  48.339  1
388104  100.356  -68.582  48.295  1
388105  100.396  -68.579  48.251  1
388106  100.436  -68.577  48.208  1
388545  90.219  -67.843  54.835  1
388546  90.253  -67.852  54.835  1
388547  90.288  -67.862  54.835  1
388548  90.321  -67.871  54.839  1
388549  90.353  -67.881  54.844  1
388550  90.384  -67.892  54.852  1
388551  90.415  -67.902  54.862  1
388552  90.446  -67.913  54.872  1
388553  90.477  -67.924  54.883  1
388554  90.508  -67.934  54.894  1
388555  90.539  -67.944  54.905  1
388556  90.595  -67.972  54.915  1
388557  90.664  -68.004  54.924  1
388558  90.730  -68.001  54.929  1
388559  90.797  -67.998  54.929  1
388560  90.864  -67.995  54.925  1
388561  90.931  -67.992  54.917  1
388562  90.991  -67.987  54.904  1
388563  91.041  -67.976  54.888  1
388564  91.091  -67.966  54.871  1
388565  91.141  -67.956  54.854  1
388566  91.191  -67.946  54.836  1
388567  91.241  -67.935  54.819  1
388568  91.291  -67.925  54.803  1
388569  91.341  -67.915  54.787  1
388570  91.391  -67.905  54.773  1
388571  91.441  -67.894  54.761  1
388572  91.491  -67.884  54.751  1
388573  91.541  -67.874  54.744  1
388574  91.591  -67.864  54.739  1
388575  91.641  -67.853  54.736  1
388576  91.686  -67.845  54.733  1
388577  91.728  -67.837  54.730  1
388578  91.769  -67.830  54.725  1
388579  91.810  -67.830  54.721  1
388580  91.850  -67.839  54.715  1
388581  91.891  -67.849  54.708  1
388582  91.931  -67.858  54.700  1
388583  91.971  -67.868  54.689  1
388584  92.012  -67.877  54.674  1
388585  92.053  -67.887  54.660  1
388586  92.093  -67.896  54.644  1
388587  92.133  -67.905  54.627  1
388588  92.174  -67.915  54.609  1
388589  92.214  -67.924  54.588  1
388590  92.265  -67.929  54.567  1
388591  92.318  -67.932  54.546  1
388592  92.372  -67.935  54.525  1
388593  92.426  -67.938  54.505  1
388594  92.480  -67.941  54.485  1
388595  92.537  -67.931  54.464  1
388596  92.596  -67.921  54.442  1
388597  92.654  -67.910  54.418  1
388598  92.713  -67.899  54.397  1
388599  92.771  -67.888  54.376  1
388600  92.829  -67.877  54.356  1
388601  92.887  -67.866  54.338  1
388602  92.945  -67.855  54.321  1
388603  92.988  -67.852  54.305  1
388604  93.023  -67.854  54.292  1
388605  93.058  -67.855  54.281  1
388606  93.092  -67.856  54.271  1
388607  93.127  -67.858  54.261  1
388608  93.179  -67.853  54.248  1
388609  93.231  -67.849  54.231  1
388610  93.285  -67.843  54.210  1
388611  93.338  -67.838  54.187  1
388612  93.391  -67.835  54.166  1
388613  93.442  -67.833  54.148  1
388614  93.494  -67.830  54.133  1
388615  93.546  -67.827  54.119  1
388616  93.598  -67.824  54.105  1
388617  93.650  -67.822  54.092  1
388618  93.697  -67.818  54.077  1
388619  93.743  -67.814  54.061  1
388620  93.789  -67.812  54.042  1
388621  93.836  -67.817  54.021  1
388622  93.882  -67.822  53.999  1
388623  93.928  -67.827  53.978  1
388624  93.975  -67.832  53.960  1
388625  94.021  -67.833  53.944  1
388626  94.067  -67.833  53.929  1
388627  94.113  -67.834  53.913  1
388628  94.150  -67.829  53.895  1
388629  94.187  -67.823  53.876  1
388630  94.223  -67.817  53.854  1
388631  94.259  -67.811  53.830  1
388632  94.295  -67.805  53.803  1
388633  94.332  -67.799  53.771  1
388634  94.368  -67.793  53.736  1
388635  94.404  -67.786  53.701  1
388636  94.441  -67.780  53.668  1
388637  94.477  -67.774  53.640  1
388638  94.513  -67.768  53.615  1
388639  94.550  -67.761  53.592  1
388640  94.586  -67.755  53.570  1
388641  94.623  -67.749  53.550  1
388642  94.660  -67.743  53.529  1
388643  94.696  -67.736  53.509  1
388644  94.723  -67.720  53.489  1
388645  94.751  -67.704  53.470  1
388646  94.779  -67.687  53.452  1
388647  94.808  -67.671  53.434  1
388648  94.837  -67.655  53.416  1
388649  94.865  -67.639  53.397  1
388650  94.894  -67.623  53.379  1
388651  94.922  -67.608  53.360  1
388652  94.948  -67.594  53.341  1
388653  94.984  -67.595  53.321  1
388654  95.024  -67.596  53.300  1
388655  95.065  -67.598  53.278  1
388656  95.106  -67.598  53.256  1
388657  95.146  -67.600  53.234  1
388658  95.187  -67.602  53.212  1
388659  95.228  -67.604  53.189  1
388660  95.268  -67.605  53.168  1
388661  95.308  -67.608  53.147  1
388662  95.349  -67.610  53.126  1
388663  95.389  -67.612  53.104  1
388664  95.429  -67.614  53.083  1
388665  95.470  -67.616  53.062  1
388666  95.512  -67.617  53.041  1
388667  95.552  -67.625  53.020  1
388668  95.593  -67.634  53.000  1
388669  95.634  -67.643  52.978  1
388670  95.675  -67.652  52.957  1
388671  95.715  -67.661  52.937  1
388672  95.756  -67.670  52.916  1
388673  95.797  -67.680  52.896  1
388674  95.838  -67.689  52.877  1
388675  95.879  -67.698  52.859  1
388676  95.919  -67.707  52.841  1
388677  95.957  -67.714  52.823  1
388678  95.984  -67.717  52.805  1
388679  96.011  -67.719  52.788  1
388680  96.037  -67.730  52.771  1
388681  96.071  -67.736  52.754  1
388682  96.104  -67.743  52.738  1
388683  96.137  -67.749  52.722  1
388684  96.171  -67.755  52.707  1
388685  96.204  -67.761  52.690  1
388686  96.238  -67.768  52.672  1
388687  96.271  -67.774  52.654  1
388688  96.305  -67.780  52.634  1
388689  96.338  -67.786  52.614  1
388690  96.372  -67.792  52.593  1
388691  96.405  -67.798  52.572  1
388692  96.439  -67.804  52.550  1
388693  96.474  -67.811  52.530  1
388694  96.509  -67.818  52.508  1
388695  96.543  -67.825  52.487  1
388696  96.578  -67.832  52.467  1
388697  96.612  -67.840  52.447  1
388698  96.647  -67.846  52.428  1
388699  96.682  -67.853  52.409  1
388700  96.715  -67.860  52.390  1
388701  96.743  -67.865  52.372  1
388702  96.771  -67.871  52.356  1
388703  96.802  -67.877  52.340  1
388704  96.835  -67.886  52.326  1
388705  96.868  -67.894  52.312  1
388706  96.901  -67.903  52.302  1
388707  96.934  -67.912  52.294  1
388708  96.967  -67.920  52.289  1
388709  97.001  -67.929  52.287  1
388710  97.034  -67.937  52.290  1
388711  97.067  -67.946  52.289  1
388712  97.100  -67.955  52.283  1
388713  97.134  -67.951  52.276  1
388714  97.180  -67.952  52.268  1
388715  97.226  -67.952  52.257  1
388716  97.265  -67.954  52.241  1
388717  97.297  -67.956  52.219  1
388718  97.331  -67.955  52.189  1
388719  97.364  -67.954  52.155  1
388720  97.398  -67.952  52.117  1
388721  97.432  -67.952  52.078  1
388722  97.465  -67.950  52.039  1
388723  97.499  -67.949  52.004  1
388724  97.532  -67.948  51.975  1
388725  97.566  -67.946  51.947  1
388726  97.599  -67.946  51.917  1
388727  97.633  -67.944  51.886  1
388728  97.667  -67.944  51.851  1
388729  97.701  -67.952  51.813  1
388730  97.735  -67.961  51.769  1
388731  97.769  -67.969  51.723  1
388732  97.803  -67.978  51.677  1
388733  97.837  -67.987  51.632  1
388734  97.871  -67.995  51.593  1
388735  97.905  -68.003  51.553  1
388736  97.939  -68.012  51.511  1
388737  97.973  -68.020  51.464  1
388738  98.005  -68.016  51.415  1
388739  98.036  -68.010  51.368  1
388740  98.067  -68.005  51.324  1
388741  98.099  -67.999  51.281  1
388742  98.131  -68.002  51.235  1
388743  98.164  -68.015  51.186  1
388744  98.198  -68.028  51.135  1
388745  98.231  -68.040  51.083  1
388746  98.265  -68.053  51.031  1
388747  98.298  -68.065  50.981  1
388748  98.332  -68.076  50.934  1
388749  98.366  -68.084  50.887  1
388750  98.400  -68.094  50.839  1
388751  98.433  -68.102  50.790  1
388752  98.467  -68.110  50.740  1
388753  98.501  -68.119  50.690  1
388754  98.535  -68.128  50.640  1
388755  98.569  -68.137  50.591  1
388756  98.604  -68.146  50.544  1
388757  98.640  -68.156  50.496  1
388758  98.675  -68.166  50.449  1
388759  98.711  -68.175  50.402  1
388760  98.749  -68.175  50.353  1
388761  98.790  -68.166  50.304  1
388762  98.832  -68.157  50.254  1
388763  98.873  -68.148  50.203  1
388764  98.914  -68.139  50.154  1
388765  98.956  -68.133  50.110  1
388766  98.993  -68.144  50.066  1
388767  99.028  -68.157  50.020  1
388768  99.064  -68.170  49.972  1
388769  99.099  -68.184  49.924  1
388770  99.135  -68.197  49.877  1
388771  99.170  -68.209  49.829  1
388772  99.206  -68.223  49.781  1
388773  99.241  -68.236  49.732  1
388774  99.277  -68.248  49.684  1
388775  99.308  -68.256  49.636  1
388776  99.340  -68.261  49.588  1
388777  99.374  -68.269  49.539  1
388778  99.409  -68.277  49.490  1
388779  99.443  -68.285  49.442  1
388780  99.477  -68.292  49.394  1
388781  99.511  -68.300  49.347  1
388782  99.546  -68.307  49.301  1
388783  99.580  -68.316  49.258  1
388784  99.626  -68.322  49.216  1
388785  99.673  -68.330  49.175  1
388786  99.713  -68.323  49.134  1
388787  99.759  -68.344  49.094  1
388788  99.800  -68.366  49.055  1
388789  99.829  -68.392  49.017  1
388790  99.857  -68.408  48.977  1
388791  99.885  -68.424  48.935  1
388792  99.924  -68.393  48.891  1
388793  99.968  -68.347  48.846  1
388794  100.011  -68.302  48.800  1
388795  100.037  -68.303  48.753  1
388796  100.069  -68.341  48.704  1
388797  100.101  -68.380  48.655  1
388798  100.133  -68.419  48.606  1
388799  100.165  -68.458  48.558  1
388800  100.198  -68.497  48.512  1
388801  100.229  -68.530  48.468  1
388802  100.258  -68.535  48.423  1
388803  100.287  -68.539  48.378  1
388804  100.326  -68.538  48.334  1
388805  100.366  -68.535  48.290  1
388806  100.405  -68.533  48.246  1
388807  100.445  -68.532  48.203  1
389245  90.164  -67.805  54.843  1
389246  90.199  -67.815  54.842  1
389247  90.233  -67.824  54.843  1
389248  90.268  -67.833  54.844  1
389249  90.303  -67.841  54.850  1
389250  90.337  -67.850  54.856  1
389251  90.372  -67.859  54.865  1
389252  90.403  -67.870  54.876  1
389253  90.434  -67.880  54.886  1
389254  90.465  -67.891  54.899  1
389255  90.496  -67.902  54.911  1
389256  90.531  -67.915  54.923  1
389257  90.595  -67.949  54.933  1
389258  90.662  -67.946  54.940  1
389259  90.728  -67.943  54.942  1
389260  90.795  -67.941  54.940  1
389261  90.862  -67.938  54.934  1
389262  90.929  -67.935  54.923  1
389263  90.996  -67.932  54.909  1
389264  91.047  -67.922  54.893  1
389265  91.097  -67.912  54.876  1
389266  91.147  -67.902  54.860  1
389267  91.197  -67.892  54.843  1
389268  91.247  -67.881  54.827  1
389269  91.297  -67.871  54.813  1
389270  91.347  -67.861  54.798  1
389271  91.397  -67.851  54.785  1
389272  91.447  -67.840  54.775  1
389273  91.497  -67.830  54.766  1
389274  91.547  -67.820  54.759  1
389275  91.597  -67.810  54.756  1
389276  91.643  -67.801  54.754  1
389277  91.684  -67.793  54.752  1
389278  91.725  -67.786  54.748  1
389279  91.767  -67.778  54.745  1
389280  91.807  -67.771  54.739  1
389281  91.848  -67.781  54.730  1
389282  91.888  -67.791  54.722  1
389283  91.929  -67.800  54.712  1
389284  91.969  -67.810  54.699  1
389285  92.010  -67.819  54.683  1
389286  92.050  -67.829  54.667  1
389287  92.090  -67.838  54.650  1
389288  92.131  -67.848  54.632  1
389289  92.171  -67.857  54.612  1
389290  92.223  -67.861  54.591  1
389291  92.277  -67.864  54.568  1
389292  92.331  -67.867  54.546  1
389293  92.384  -67.870  54.524  1
389294  92.438  -67.873  54.504  1
389295  92.492  -67.876  54.484  1
389296  92.546  -67.878  54.463  1
389297  92.603  -67.871  54.441  1
389298  92.662  -67.859  54.418  1
389299  92.720  -67.849  54.397  1
389300  92.778  -67.838  54.376  1
389301  92.837  -67.827  54.356  1
389302  92.895  -67.816  54.338  1
389303  92.953  -67.805  54.322  1
389304  92.991  -67.805  54.310  1
389305  93.026  -67.806  54.300  1
389306  93.061  -67.808  54.292  1
389307  93.095  -67.808  54.285  1
389308  93.130  -67.810  54.276  1
389309  93.171  -67.809  54.264  1
389310  93.225  -67.804  54.247  1
389311  93.278  -67.799  54.225  1
389312  93.331  -67.794  54.200  1
389313  93.384  -67.789  54.176  1
389314  93.437  -67.785  54.156  1
389315  93.489  -67.783  54.138  1
389316  93.541  -67.780  54.124  1
389317  93.589  -67.777  54.111  1
389318  93.635  -67.772  54.099  1
389319  93.681  -67.768  54.085  1
389320  93.727  -67.764  54.068  1
389321  93.773  -67.761  54.049  1
389322  93.820  -67.764  54.028  1
389323  93.866  -67.769  54.006  1
389324  93.913  -67.774  53.984  1
389325  93.960  -67.779  53.965  1
389326  94.006  -67.784  53.948  1
389327  94.053  -67.789  53.932  1
389328  94.092  -67.787  53.916  1
389329  94.130  -67.781  53.900  1
389330  94.167  -67.775  53.880  1
389331  94.203  -67.768  53.859  1
389332  94.240  -67.762  53.836  1
389333  94.277  -67.756  53.810  1
389334  94.314  -67.750  53.780  1
389335  94.351  -67.743  53.744  1
389336  94.388  -67.737  53.708  1
389337  94.424  -67.731  53.674  1
389338  94.461  -67.725  53.646  1
389339  94.498  -67.718  53.621  1
389340  94.535  -67.712  53.598  1
389341  94.572  -67.706  53.577  1
389342  94.609  -67.700  53.556  1
389343  94.650  -67.697  53.536  1
389344  94.690  -67.697  53.515  1
389345  94.723  -67.692  53.495  1
389346  94.751  -67.676  53.475  1
389347  94.779  -67.660  53.456  1
389348  94.807  -67.643  53.437  1
389349  94.834  -67.627  53.418  1
389350  94.862  -67.611  53.400  1
389351  94.890  -67.595  53.382  1
389352  94.917  -67.579  53.363  1
389353  94.947  -67.564  53.343  1
389354  94.987  -67.566  53.323  1
389355  95.027  -67.568  53.302  1
389356  95.068  -67.570  53.280  1
389357  95.108  -67.573  53.258  1
389358  95.149  -67.575  53.235  1
389359  95.189  -67.577  53.212  1
389360  95.230  -67.580  53.190  1
389361  95.270  -67.581  53.168  1
389362  95.311  -67.583  53.147  1
389363  95.351  -67.586  53.126  1
389364  95.392  -67.588  53.105  1
389365  95.429  -67.583  53.083  1
389366  95.469  -67.580  53.061  1
389367  95.517  -67.583  53.041  1
389368  95.557  -67.591  53.020  1
389369  95.597  -67.599  52.999  1
389370  95.638  -67.608  52.978  1
389371  95.679  -67.617  52.957  1
389372  95.720  -67.627  52.935  1
389373  95.760  -67.636  52.915  1
389374  95.801  -67.645  52.895  1
389375  95.842  -67.654  52.875  1
389376  95.883  -67.663  52.856  1
389377  95.923  -67.672  52.837  1
389378  95.962  -67.680  52.819  1
389379  95.989  -67.682  52.800  1
389380  96.016  -67.686  52.782  1
389381  96.040  -67.700  52.765  1
389382  96.074  -67.706  52.748  1
389383  96.107  -67.712  52.732  1
389384  96.141  -67.718  52.715  1
389385  96.174  -67.724  52.699  1
389386  96.207  -67.730  52.682  1
389387  96.241  -67.736  52.663  1
389388  96.274  -67.743  52.644  1
389389  96.308  -67.749  52.624  1
389390  96.341  -67.755  52.603  1
389391  96.375  -67.761  52.582  1
389392  96.408  -67.768  52.561  1
389393  96.440  -67.770  52.539  1
389394  96.473  -67.774  52.517  1
389395  96.506  -67.782  52.495  1
389396  96.539  -67.790  52.473  1
389397  96.572  -67.799  52.453  1
389398  96.605  -67.807  52.434  1
389399  96.639  -67.815  52.415  1
389400  96.674  -67.822  52.397  1
389401  96.709  -67.829  52.379  1
389402  96.740  -67.835  52.360  1
389403  96.770  -67.842  52.344  1
389404  96.804  -67.851  52.329  1
389405  96.837  -67.859  52.315  1
389406  96.870  -67.868  52.303  1
389407  96.903  -67.877  52.293  1
389408  96.937  -67.885  52.285  1
389409  96.970  -67.893  52.280  1
389410  97.003  -67.902  52.277  1
389411  97.036  -67.911  52.278  1
389412  97.069  -67.919  52.276  1
389413  97.102  -67.928  52.271  1
389414  97.142  -67.926  52.264  1
389415  97.187  -67.927  52.258  1
389416  97.234  -67.927  52.246  1
389417  97.273  -67.930  52.230  1
389418  97.306  -67.928  52.206  1
389419  97.339  -67.927  52.176  1
389420  97.373  -67.926  52.141  1
389421  97.407  -67.924  52.103  1
389422  97.441  -67.923  52.064  1
389423  97.475  -67.920  52.026  1
389424  97.509  -67.917  51.990  1
389425  97.543  -67.914  51.961  1
389426  97.578  -67.911  51.934  1
389427  97.612  -67.908  51.906  1
389428  97.646  -67.905  51.874  1
389429  97.675  -67.907  51.839  1
389430  97.711  -67.912  51.800  1
389431  97.741  -67.918  51.756  1
389432  97.773  -67.924  51.709  1
389433  97.807  -67.933  51.662  1
389434  97.841  -67.941  51.617  1
389435  97.875  -67.949  51.577  1
389436  97.909  -67.958  51.538  1
389437  97.943  -67.966  51.496  1
389438  97.977  -67.974  51.449  1
389439  98.011  -67.980  51.401  1
389440  98.042  -67.974  51.356  1
389441  98.073  -67.968  51.313  1
389442  98.105  -67.962  51.268  1
389443  98.138  -67.972  51.222  1
389444  98.171  -67.985  51.173  1
389445  98.205  -67.998  51.122  1
389446  98.238  -68.011  51.071  1
389447  98.272  -68.022  51.020  1
389448  98.305  -68.031  50.970  1
389449  98.339  -68.040  50.924  1
389450  98.373  -68.048  50.878  1
389451  98.407  -68.057  50.832  1
389452  98.441  -68.065  50.783  1
389453  98.475  -68.074  50.734  1
389454  98.509  -68.083  50.685  1
389455  98.543  -68.091  50.637  1
389456  98.576  -68.100  50.589  1
389457  98.612  -68.110  50.541  1
389458  98.647  -68.119  50.494  1
389459  98.683  -68.129  50.447  1
389460  98.718  -68.139  50.400  1
389461  98.754  -68.148  50.350  1
389462  98.795  -68.140  50.300  1
389463  98.837  -68.131  50.249  1
389464  98.878  -68.122  50.197  1
389465  98.919  -68.113  50.147  1
389466  98.961  -68.109  50.101  1
389467  99.000  -68.116  50.055  1
389468  99.036  -68.130  50.008  1
389469  99.071  -68.143  49.958  1
389470  99.107  -68.156  49.908  1
389471  99.142  -68.169  49.862  1
389472  99.178  -68.182  49.815  1
389473  99.214  -68.195  49.768  1
389474  99.249  -68.203  49.719  1
389475  99.282  -68.204  49.670  1
389476  99.313  -68.212  49.624  1
389477  99.344  -68.231  49.576  1
389478  99.373  -68.234  49.528  1
389479  99.403  -68.237  49.479  1
389480  99.432  -68.241  49.432  1
389481  99.467  -68.248  49.385  1
389482  99.501  -68.256  49.338  1
389483  99.535  -68.264  49.293  1
389484  99.569  -68.272  49.251  1
389485  99.615  -68.279  49.209  1
389486  99.658  -68.282  49.167  1
389487  99.703  -68.303  49.124  1
389488  99.752  -68.321  49.083  1
389489  99.806  -68.335  49.045  1
389490  99.837  -68.347  49.006  1
389491  99.864  -68.363  48.965  1
389492  99.893  -68.379  48.923  1
389493  99.933  -68.345  48.879  1
389494  99.976  -68.300  48.835  1
389495  100.012  -68.266  48.789  1
389496  100.039  -68.287  48.743  1
389497  100.071  -68.325  48.694  1
389498  100.104  -68.364  48.645  1
389499  100.136  -68.403  48.598  1
389500  100.168  -68.442  48.551  1
389501  100.200  -68.481  48.505  1
389502  100.229  -68.489  48.461  1
389503  100.259  -68.495  48.417  1
389504  100.296  -68.494  48.372  1
389505  100.335  -68.492  48.328  1
389506  100.375  -68.489  48.284  1
389507  100.415  -68.488  48.241  1
389946  90.144  -67.777  54.850  1
389947  90.179  -67.786  54.849  1
389948  90.214  -67.795  54.852  1
389949  90.248  -67.804  54.855  1
389950  90.283  -67.812  54.861  1
389951  90.317  -67.821  54.869  1
389952  90.352  -67.830  54.878  1
389953  90.386  -67.840  54.889  1
389954  90.421  -67.849  54.902  1
389955  90.453  -67.858  54.915  1
389956  90.484  -67.869  54.928  1
389957  90.525  -67.887  54.941  1
389958  90.593  -67.893  54.949  1
389959  90.660  -67.890  54.954  1
389960  90.726  -67.887  54.954  1
389961  90.793  -67.884  54.950  1
389962  90.860  -67.880  54.943  1
389963  90.927  -67.877  54.928  1
389964  90.994  -67.874  54.913  1
389965  91.053  -67.868  54.897  1
389966  91.103  -67.858  54.881  1
389967  91.153  -67.848  54.866  1
389968  91.203  -67.838  54.851  1
389969  91.253  -67.827  54.836  1
389970  91.303  -67.818  54.823  1
389971  91.353  -67.807  54.811  1
389972  91.403  -67.797  54.799  1
389973  91.453  -67.786  54.791  1
389974  91.503  -67.777  54.784  1
389975  91.553  -67.766  54.778  1
389976  91.599  -67.758  54.775  1
389977  91.640  -67.750  54.774  1
389978  91.681  -67.743  54.771  1
389979  91.722  -67.735  54.767  1
389980  91.764  -67.727  54.762  1
389981  91.805  -67.720  54.754  1
389982  91.846  -67.724  54.745  1
389983  91.886  -67.733  54.735  1
389984  91.926  -67.743  54.723  1
389985  91.967  -67.752  54.708  1
389986  92.007  -67.761  54.692  1
389987  92.048  -67.771  54.674  1
389988  92.088  -67.780  54.656  1
389989  92.129  -67.790  54.638  1
389990  92.181  -67.793  54.617  1
389991  92.235  -67.796  54.594  1
389992  92.289  -67.799  54.570  1
389993  92.343  -67.802  54.547  1
389994  92.397  -67.805  54.525  1
389995  92.451  -67.808  54.504  1
389996  92.504  -67.811  54.484  1
389997  92.558  -67.813  54.463  1
389998  92.612  -67.816  54.441  1
389999  92.669  -67.809  54.419  1
390000  92.727  -67.799  54.397  1
390001  92.786  -67.788  54.376  1
390002  92.844  -67.777  54.355  1
390003  92.902  -67.766  54.338  1
390004  92.959  -67.756  54.325  1
390005  92.994  -67.757  54.315  1
390006  93.028  -67.758  54.308  1
390007  93.063  -67.760  54.303  1
390008  93.098  -67.761  54.297  1
390009  93.133  -67.762  54.289  1
390010  93.168  -67.764  54.277  1
390011  93.218  -67.759  54.260  1
390012  93.271  -67.755  54.236  1
390013  93.325  -67.749  54.210  1
390014  93.378  -67.744  54.186  1
390015  93.431  -67.739  54.164  1
390016  93.481  -67.735  54.145  1
390017  93.528  -67.731  54.130  1
390018  93.574  -67.727  54.118  1
390019  93.620  -67.723  54.106  1
390020  93.666  -67.719  54.094  1
390021  93.712  -67.715  54.077  1
390022  93.758  -67.711  54.057  1
390023  93.804  -67.711  54.036  1
390024  93.851  -67.716  54.014  1
390025  93.898  -67.721  53.991  1
390026  93.944  -67.726  53.971  1
390027  93.991  -67.731  53.953  1
390028  94.037  -67.736  53.936  1
390029  94.078  -67.738  53.919  1
390030  94.115  -67.732  53.901  1
390031  94.152  -67.725  53.881  1
390032  94.189  -67.719  53.860  1
390033  94.225  -67.713  53.838  1
390034  94.263  -67.707  53.815  1
390035  94.299  -67.700  53.785  1
390036  94.336  -67.694  53.750  1
390037  94.373  -67.688  53.714  1
390038  94.410  -67.682  53.680  1
390039  94.447  -67.675  53.652  1
390040  94.484  -67.669  53.625  1
390041  94.521  -67.663  53.603  1
390042  94.557  -67.657  53.583  1
390043  94.597  -67.652  53.562  1
390044  94.647  -67.658  53.541  1
390045  94.682  -67.655  53.521  1
390046  94.717  -67.654  53.502  1
390047  94.751  -67.648  53.482  1
390048  94.779  -67.632  53.461  1
390049  94.807  -67.616  53.442  1
390050  94.834  -67.599  53.422  1
390051  94.862  -67.583  53.404  1
390052  94.890  -67.567  53.386  1
390053  94.917  -67.551  53.367  1
390054  94.949  -67.539  53.347  1
390055  94.989  -67.542  53.326  1
390056  95.030  -67.544  53.304  1
390057  95.070  -67.546  53.281  1
390058  95.111  -67.548  53.259  1
390059  95.151  -67.551  53.236  1
390060  95.192  -67.553  53.213  1
390061  95.232  -67.555  53.191  1
390062  95.272  -67.557  53.169  1
390063  95.313  -67.559  53.148  1
390064  95.351  -67.556  53.126  1
390065  95.389  -67.551  53.105  1
390066  95.426  -67.545  53.083  1
390067  95.473  -67.547  53.062  1
390068  95.520  -67.550  53.041  1
390069  95.563  -67.556  53.020  1
390070  95.603  -67.564  52.999  1
390071  95.642  -67.573  52.978  1
390072  95.683  -67.583  52.957  1
390073  95.724  -67.592  52.936  1
390074  95.764  -67.601  52.915  1
390075  95.805  -67.610  52.895  1
390076  95.846  -67.619  52.874  1
390077  95.887  -67.628  52.855  1
390078  95.927  -67.637  52.836  1
390079  95.966  -67.645  52.816  1
390080  95.994  -67.648  52.797  1
390081  96.020  -67.655  52.779  1
390082  96.044  -67.668  52.761  1
390083  96.077  -67.675  52.743  1
390084  96.110  -67.681  52.725  1
390085  96.144  -67.687  52.708  1
390086  96.177  -67.693  52.691  1
390087  96.210  -67.699  52.672  1
390088  96.244  -67.706  52.653  1
390089  96.277  -67.712  52.633  1
390090  96.311  -67.718  52.614  1
390091  96.344  -67.724  52.593  1
390092  96.377  -67.728  52.571  1
390093  96.409  -67.730  52.550  1
390094  96.441  -67.733  52.528  1
390095  96.474  -67.736  52.506  1
390096  96.507  -67.743  52.483  1
390097  96.540  -67.751  52.461  1
390098  96.573  -67.760  52.441  1
390099  96.606  -67.768  52.422  1
390100  96.640  -67.777  52.402  1
390101  96.672  -67.785  52.383  1
390102  96.705  -67.793  52.365  1
390103  96.739  -67.800  52.348  1
390104  96.772  -67.809  52.331  1
390105  96.805  -67.819  52.316  1
390106  96.838  -67.830  52.303  1
390107  96.872  -67.840  52.291  1
390108  96.905  -67.849  52.282  1
390109  96.939  -67.858  52.274  1
390110  96.972  -67.867  52.268  1
390111  97.005  -67.876  52.263  1
390112  97.038  -67.884  52.261  1
390113  97.071  -67.893  52.258  1
390114  97.104  -67.901  52.253  1
390115  97.149  -67.901  52.249  1
390116  97.195  -67.902  52.243  1
390117  97.241  -67.898  52.231  1
390118  97.283  -67.896  52.214  1
390119  97.317  -67.893  52.190  1
390120  97.352  -67.890  52.160  1
390121  97.386  -67.887  52.125  1
390122  97.420  -67.884  52.088  1
390123  97.454  -67.881  52.049  1
390124  97.489  -67.878  52.010  1
390125  97.523  -67.875  51.975  1
390126  97.557  -67.872  51.945  1
390127  97.591  -67.869  51.918  1
390128  97.625  -67.866  51.891  1
390129  97.654  -67.868  51.860  1
390130  97.682  -67.871  51.825  1
390131  97.725  -67.875  51.785  1
390132  97.755  -67.880  51.741  1
390133  97.786  -67.886  51.693  1
390134  97.816  -67.891  51.644  1
390135  97.847  -67.896  51.600  1
390136  97.879  -67.904  51.560  1
390137  97.914  -67.913  51.520  1
390138  97.947  -67.921  51.479  1
390139  97.982  -67.930  51.432  1
390140  98.016  -67.938  51.385  1
390141  98.048  -67.937  51.342  1
390142  98.079  -67.931  51.299  1
390143  98.111  -67.931  51.256  1
390144  98.145  -67.943  51.211  1
390145  98.178  -67.956  51.162  1
390146  98.211  -67.968  51.110  1
390147  98.245  -67.977  51.059  1
390148  98.279  -67.986  51.008  1
390149  98.313  -67.994  50.958  1
390150  98.347  -68.003  50.912  1
390151  98.381  -68.012  50.867  1
390152  98.415  -68.021  50.822  1
390153  98.448  -68.029  50.774  1
390154  98.482  -68.037  50.726  1
390155  98.516  -68.046  50.678  1
390156  98.550  -68.055  50.630  1
390157  98.584  -68.064  50.584  1
390158  98.620  -68.074  50.536  1
390159  98.655  -68.084  50.488  1
390160  98.691  -68.094  50.441  1
390161  98.726  -68.103  50.394  1
390162  98.762  -68.112  50.346  1
390163  98.800  -68.113  50.296  1
390164  98.842  -68.104  50.244  1
390165  98.883  -68.096  50.192  1
390166  98.924  -68.087  50.139  1
390167  98.967  -68.084  50.089  1
390168  99.008  -68.089  50.042  1
390169  99.044  -68.102  49.994  1
390170  99.079  -68.115  49.942  1
390171  99.115  -68.128  49.891  1
390172  99.150  -68.141  49.844  1
390173  99.186  -68.154  49.799  1
390174  99.220  -68.159  49.754  1
390175  99.254  -68.160  49.708  1
390176  99.287  -68.161  49.660  1
390177  99.320  -68.162  49.613  1
390178  99.356  -68.185  49.565  1
390179  99.380  -68.206  49.517  1
390180  99.410  -68.209  49.470  1
390181  99.439  -68.212  49.422  1
390182  99.468  -68.215  49.375  1
390183  99.497  -68.218  49.329  1
390184  99.526  -68.221  49.286  1
390185  99.559  -68.228  49.245  1
390186  99.604  -68.240  49.203  1
390187  99.659  -68.253  49.160  1
390188  99.713  -68.268  49.116  1
390189  99.768  -68.282  49.074  1
390190  99.812  -68.293  49.034  1
390191  99.845  -68.303  48.994  1
390192  99.872  -68.319  48.953  1
390193  99.900  -68.335  48.911  1
390194  99.941  -68.298  48.868  1
390195  99.985  -68.253  48.823  1
390196  100.010  -68.234  48.777  1
390197  100.042  -68.271  48.731  1
390198  100.074  -68.310  48.684  1
390199  100.106  -68.348  48.637  1
390200  100.138  -68.388  48.590  1
390201  100.170  -68.426  48.543  1
390202  100.200  -68.445  48.498  1
390203  100.229  -68.449  48.454  1
390204  100.265  -68.450  48.410  1
390205  100.305  -68.448  48.366  1
390206  100.344  -68.445  48.322  1
390207  100.384  -68.444  48.279  1
390208  100.424  -68.441  48.236  1
390646  90.095  -67.730  54.858  1
390647  90.129  -67.740  54.857  1
390648  90.163  -67.750  54.858  1
390649  90.197  -67.759  54.861  1
390650  90.232  -67.769  54.866  1
390651  90.266  -67.779  54.873  1
390652  90.300  -67.788  54.881  1
390653  90.334  -67.798  54.891  1
390654  90.369  -67.808  54.903  1
390655  90.403  -67.817  54.916  1
390656  90.437  -67.827  54.930  1
390657  90.471  -67.836  54.945  1
390658  90.524  -67.838  54.957  1
390659  90.591  -67.835  54.965  1
390660  90.658  -67.832  54.967  1
390661  90.724  -67.829  54.965  1
390662  90.791  -67.826  54.959  1
390663  90.858  -67.823  54.949  1
390664  90.925  -67.821  54.934  1
390665  90.992  -67.818  54.918  1
390666  91.058  -67.815  54.903  1
390667  91.109  -67.805  54.889  1
390668  91.159  -67.794  54.874  1
390669  91.209  -67.784  54.859  1
390670  91.259  -67.774  54.846  1
390671  91.309  -67.764  54.835  1
390672  91.359  -67.753  54.825  1
390673  91.409  -67.743  54.816  1
390674  91.459  -67.733  54.809  1
390675  91.509  -67.723  54.803  1
390676  91.555  -67.714  54.798  1
390677  91.596  -67.706  54.795  1
390678  91.637  -67.699  54.794  1
390679  91.678  -67.691  54.790  1
390680  91.720  -67.683  54.785  1
390681  91.761  -67.676  54.778  1
390682  91.802  -67.668  54.769  1
390683  91.843  -67.665  54.759  1
390684  91.883  -67.675  54.747  1
390685  91.924  -67.684  54.734  1
390686  91.964  -67.694  54.717  1
390687  92.005  -67.703  54.700  1
390688  92.046  -67.713  54.682  1
390689  92.086  -67.722  54.663  1
390690  92.140  -67.725  54.643  1
390691  92.194  -67.728  54.622  1
390692  92.247  -67.730  54.598  1
390693  92.301  -67.733  54.574  1
390694  92.355  -67.736  54.551  1
390695  92.409  -67.739  54.529  1
390696  92.463  -67.743  54.508  1
390697  92.517  -67.746  54.487  1
390698  92.571  -67.748  54.466  1
390699  92.625  -67.751  54.443  1
390700  92.678  -67.754  54.420  1
390701  92.735  -67.749  54.398  1
390702  92.793  -67.738  54.377  1
390703  92.851  -67.727  54.358  1
390704  92.910  -67.716  54.341  1
390705  92.962  -67.708  54.329  1
390706  92.997  -67.709  54.321  1
390707  93.031  -67.711  54.316  1
390708  93.066  -67.712  54.311  1
390709  93.101  -67.713  54.305  1
390710  93.136  -67.714  54.296  1
390711  93.172  -67.712  54.284  1
390712  93.221  -67.708  54.266  1
390713  93.275  -67.702  54.243  1
390714  93.329  -67.697  54.217  1
390715  93.382  -67.692  54.194  1
390716  93.436  -67.687  54.172  1
390717  93.476  -67.686  54.152  1
390718  93.512  -67.681  54.136  1
390719  93.558  -67.677  54.125  1
390720  93.605  -67.674  54.114  1
390721  93.650  -67.670  54.102  1
390722  93.697  -67.665  54.086  1
390723  93.743  -67.661  54.066  1
390724  93.789  -67.658  54.044  1
390725  93.835  -67.663  54.021  1
390726  93.882  -67.668  53.997  1
390727  93.928  -67.673  53.976  1
390728  93.975  -67.678  53.957  1
390729  94.021  -67.683  53.938  1
390730  94.063  -67.687  53.921  1
390731  94.101  -67.682  53.902  1
390732  94.137  -67.676  53.882  1
390733  94.175  -67.670  53.861  1
390734  94.211  -67.664  53.839  1
390735  94.248  -67.657  53.816  1
390736  94.285  -67.651  53.787  1
390737  94.322  -67.645  53.754  1
390738  94.359  -67.639  53.720  1
390739  94.396  -67.632  53.687  1
390740  94.432  -67.626  53.657  1
390741  94.469  -67.620  53.630  1
390742  94.506  -67.614  53.607  1
390743  94.544  -67.608  53.587  1
390744  94.594  -67.613  53.567  1
390745  94.639  -67.616  53.547  1
390746  94.675  -67.614  53.529  1
390747  94.710  -67.612  53.511  1
390748  94.746  -67.610  53.493  1
390749  94.779  -67.605  53.472  1
390750  94.807  -67.588  53.451  1
390751  94.834  -67.572  53.431  1
390752  94.862  -67.555  53.413  1
390753  94.890  -67.539  53.395  1
390754  94.917  -67.523  53.376  1
390755  94.951  -67.515  53.354  1
390756  94.992  -67.517  53.331  1
390757  95.032  -67.520  53.308  1
390758  95.072  -67.522  53.286  1
390759  95.113  -67.524  53.262  1
390760  95.154  -67.526  53.238  1
390761  95.194  -67.529  53.215  1
390762  95.235  -67.531  53.192  1
390763  95.273  -67.529  53.170  1
390764  95.311  -67.523  53.149  1
390765  95.349  -67.518  53.127  1
390766  95.386  -67.513  53.106  1
390767  95.429  -67.511  53.085  1
390768  95.476  -67.514  53.064  1
390769  95.523  -67.517  53.043  1
390770  95.569  -67.521  53.022  1
390771  95.608  -67.530  53.001  1
390772  95.648  -67.539  52.979  1
390773  95.687  -67.548  52.958  1
390774  95.728  -67.557  52.937  1
390775  95.768  -67.566  52.916  1
390776  95.809  -67.575  52.896  1
390777  95.850  -67.584  52.875  1
390778  95.891  -67.593  52.856  1
390779  95.932  -67.602  52.836  1
390780  95.971  -67.611  52.816  1
390781  95.999  -67.614  52.796  1
390782  96.025  -67.623  52.776  1
390783  96.049  -67.636  52.758  1
390784  96.080  -67.645  52.739  1
390785  96.113  -67.651  52.720  1
390786  96.147  -67.657  52.701  1
390787  96.180  -67.663  52.683  1
390788  96.214  -67.669  52.663  1
390789  96.247  -67.675  52.643  1
390790  96.281  -67.681  52.623  1
390791  96.313  -67.686  52.604  1
390792  96.345  -67.688  52.583  1
390793  96.377  -67.690  52.561  1
390794  96.409  -67.692  52.540  1
390795  96.442  -67.695  52.517  1
390796  96.475  -67.699  52.495  1
390797  96.508  -67.703  52.472  1
390798  96.541  -67.712  52.450  1
390799  96.574  -67.721  52.430  1
390800  96.607  -67.729  52.410  1
390801  96.641  -67.737  52.390  1
390802  96.673  -67.746  52.371  1
390803  96.707  -67.754  52.353  1
390804  96.740  -67.758  52.336  1
390805  96.773  -67.763  52.320  1
390806  96.806  -67.773  52.305  1
390807  96.840  -67.783  52.291  1
390808  96.873  -67.793  52.279  1
390809  96.906  -67.804  52.270  1
390810  96.940  -67.814  52.262  1
390811  96.973  -67.824  52.254  1
390812  97.006  -67.834  52.248  1
390813  97.039  -67.844  52.244  1
390814  97.073  -67.854  52.240  1
390815  97.111  -67.860  52.235  1
390816  97.157  -67.858  52.229  1
390817  97.203  -67.853  52.222  1
390818  97.249  -67.849  52.209  1
390819  97.296  -67.855  52.191  1
390820  97.331  -67.852  52.168  1
390821  97.365  -67.849  52.138  1
390822  97.399  -67.846  52.104  1
390823  97.434  -67.843  52.068  1
390824  97.468  -67.840  52.030  1
390825  97.502  -67.837  51.992  1
390826  97.536  -67.833  51.957  1
390827  97.570  -67.830  51.928  1
390828  97.604  -67.827  51.901  1
390829  97.634  -67.830  51.872  1
390830  97.662  -67.832  51.842  1
390831  97.690  -67.834  51.808  1
390832  97.737  -67.838  51.769  1
390833  97.770  -67.843  51.725  1
390834  97.800  -67.849  51.678  1
390835  97.830  -67.854  51.629  1
390836  97.861  -67.860  51.585  1
390837  97.891  -67.865  51.544  1
390838  97.922  -67.871  51.503  1
390839  97.952  -67.876  51.460  1
390840  97.986  -67.884  51.415  1
390841  98.020  -67.893  51.371  1
390842  98.054  -67.900  51.329  1
390843  98.085  -67.895  51.288  1
390844  98.118  -67.901  51.245  1
390845  98.151  -67.914  51.201  1
390846  98.185  -67.924  51.151  1
390847  98.219  -67.932  51.099  1
390848  98.253  -67.940  51.048  1
390849  98.287  -67.949  50.997  1
390850  98.320  -67.958  50.946  1
390851  98.354  -67.967  50.899  1
390852  98.388  -67.975  50.853  1
390853  98.422  -67.984  50.807  1
390854  98.456  -67.993  50.760  1
390855  98.490  -68.001  50.712  1
390856  98.524  -68.010  50.665  1
390857  98.558  -68.018  50.618  1
390858  98.592  -68.028  50.573  1
390859  98.628  -68.037  50.526  1
390860  98.663  -68.047  50.478  1
390861  98.699  -68.057  50.430  1
390862  98.734  -68.067  50.382  1
390863  98.770  -68.077  50.335  1
390864  98.805  -68.087  50.287  1
390865  98.847  -68.078  50.237  1
390866  98.887  -68.069  50.186  1
390867  98.929  -68.060  50.133  1
390868  98.972  -68.060  50.080  1
390869  99.015  -68.062  50.030  1
390870  99.051  -68.075  49.979  1
390871  99.087  -68.087  49.927  1
390872  99.122  -68.100  49.876  1
390873  99.158  -68.114  49.829  1
390874  99.192  -68.115  49.784  1
390875  99.225  -68.115  49.740  1
390876  99.259  -68.116  49.695  1
390877  99.292  -68.117  49.649  1
390878  99.326  -68.118  49.603  1
390879  99.353  -68.135  49.557  1
390880  99.403  -68.159  49.510  1
390881  99.417  -68.181  49.462  1
390882  99.446  -68.184  49.413  1
390883  99.475  -68.188  49.366  1
390884  99.504  -68.191  49.321  1
390885  99.533  -68.194  49.280  1
390886  99.570  -68.193  49.240  1
390887  99.621  -68.200  49.197  1
390888  99.675  -68.214  49.153  1
390889  99.730  -68.228  49.109  1
390890  99.784  -68.241  49.065  1
390891  99.819  -68.251  49.023  1
390892  99.851  -68.260  48.982  1
390893  99.880  -68.274  48.941  1
390894  99.908  -68.290  48.899  1
390895  99.950  -68.250  48.857  1
390896  99.989  -68.212  48.812  1
390897  100.012  -68.216  48.767  1
390898  100.044  -68.255  48.721  1
390899  100.076  -68.294  48.675  1
390900  100.108  -68.333  48.628  1
390901  100.140  -68.372  48.582  1
390902  100.171  -68.400  48.536  1
390903  100.201  -68.404  48.491  1
390904  100.235  -68.406  48.448  1
390905  100.274  -68.404  48.403  1
390906  100.314  -68.401  48.359  1
390907  100.354  -68.400  48.316  1
390908  100.393  -68.398  48.273  1
390909  100.433  -68.395  48.230  1
391347  90.087  -67.683  54.864  1
391348  90.121  -67.692  54.863  1
391349  90.155  -67.702  54.866  1
391350  90.189  -67.711  54.870  1
391351  90.224  -67.721  54.877  1
391352  90.258  -67.730  54.885  1
391353  90.292  -67.739  54.894  1
391354  90.326  -67.749  54.905  1
391355  90.361  -67.759  54.916  1
391356  90.395  -67.768  54.929  1
391357  90.429  -67.778  54.945  1
391358  90.470  -67.782  54.960  1
391359  90.530  -67.776  54.972  1
391360  90.591  -67.777  54.978  1
391361  90.656  -67.775  54.979  1
391362  90.722  -67.772  54.975  1
391363  90.789  -67.769  54.967  1
391364  90.856  -67.766  54.955  1
391365  90.923  -67.763  54.940  1
391366  90.990  -67.760  54.925  1
391367  91.056  -67.757  54.910  1
391368  91.115  -67.751  54.897  1
391369  91.165  -67.740  54.883  1
391370  91.215  -67.730  54.871  1
391371  91.265  -67.720  54.860  1
391372  91.315  -67.710  54.851  1
391373  91.365  -67.699  54.845  1
391374  91.415  -67.689  54.839  1
391375  91.465  -67.679  54.833  1
391376  91.511  -67.670  54.827  1
391377  91.552  -67.663  54.821  1
391378  91.593  -67.655  54.818  1
391379  91.635  -67.648  54.814  1
391380  91.676  -67.640  54.808  1
391381  91.717  -67.633  54.801  1
391382  91.758  -67.625  54.793  1
391383  91.799  -67.617  54.782  1
391384  91.841  -67.610  54.771  1
391385  91.881  -67.617  54.759  1
391386  91.922  -67.627  54.744  1
391387  91.962  -67.636  54.727  1
391388  92.003  -67.645  54.709  1
391389  92.044  -67.654  54.690  1
391390  92.098  -67.657  54.669  1
391391  92.152  -67.660  54.649  1
391392  92.206  -67.663  54.626  1
391393  92.260  -67.665  54.603  1
391394  92.314  -67.668  54.579  1
391395  92.368  -67.671  54.556  1
391396  92.422  -67.674  54.534  1
391397  92.475  -67.677  54.512  1
391398  92.529  -67.680  54.491  1
391399  92.583  -67.683  54.470  1
391400  92.637  -67.686  54.446  1
391401  92.691  -67.689  54.422  1
391402  92.744  -67.692  54.399  1
391403  92.800  -67.687  54.378  1
391404  92.859  -67.677  54.359  1
391405  92.917  -67.666  54.343  1
391406  92.965  -67.661  54.332  1
391407  93.000  -67.661  54.325  1
391408  93.035  -67.663  54.321  1
391409  93.069  -67.664  54.316  1
391410  93.105  -67.663  54.308  1
391411  93.141  -67.661  54.299  1
391412  93.177  -67.660  54.285  1
391413  93.226  -67.655  54.267  1
391414  93.280  -67.650  54.244  1
391415  93.334  -67.645  54.222  1
391416  93.387  -67.639  54.199  1
391417  93.439  -67.635  54.178  1
391418  93.476  -67.639  54.158  1
391419  93.507  -67.633  54.143  1
391420  93.543  -67.628  54.132  1
391421  93.589  -67.623  54.123  1
391422  93.635  -67.620  54.112  1
391423  93.681  -67.616  54.095  1
391424  93.727  -67.612  54.075  1
391425  93.773  -67.608  54.052  1
391426  93.820  -67.610  54.027  1
391427  93.866  -67.615  54.002  1
391428  93.913  -67.620  53.980  1
391429  93.960  -67.625  53.960  1
391430  94.005  -67.630  53.940  1
391431  94.047  -67.634  53.920  1
391432  94.086  -67.633  53.902  1
391433  94.123  -67.627  53.881  1
391434  94.160  -67.620  53.861  1
391435  94.197  -67.614  53.839  1
391436  94.234  -67.608  53.815  1
391437  94.270  -67.602  53.787  1
391438  94.308  -67.595  53.757  1
391439  94.344  -67.589  53.725  1
391440  94.381  -67.583  53.694  1
391441  94.418  -67.576  53.663  1
391442  94.455  -67.570  53.636  1
391443  94.492  -67.564  53.612  1
391444  94.541  -67.568  53.591  1
391445  94.591  -67.573  53.571  1
391446  94.632  -67.574  53.552  1
391447  94.668  -67.572  53.535  1
391448  94.703  -67.570  53.519  1
391449  94.738  -67.568  53.501  1
391450  94.773  -67.566  53.482  1
391451  94.807  -67.561  53.461  1
391452  94.834  -67.544  53.443  1
391453  94.862  -67.528  53.426  1
391454  94.890  -67.512  53.409  1
391455  94.918  -67.495  53.387  1
391456  94.954  -67.491  53.363  1
391457  94.994  -67.493  53.338  1
391458  95.035  -67.495  53.313  1
391459  95.075  -67.498  53.289  1
391460  95.115  -67.500  53.264  1
391461  95.156  -67.502  53.240  1
391462  95.195  -67.502  53.217  1
391463  95.233  -67.496  53.194  1
391464  95.271  -67.491  53.172  1
391465  95.308  -67.486  53.150  1
391466  95.346  -67.480  53.129  1
391467  95.385  -67.476  53.108  1
391468  95.432  -67.479  53.087  1
391469  95.479  -67.482  53.066  1
391470  95.527  -67.484  53.045  1
391471  95.574  -67.487  53.025  1
391472  95.614  -67.495  53.004  1
391473  95.654  -67.504  52.984  1
391474  95.693  -67.513  52.963  1
391475  95.733  -67.522  52.941  1
391476  95.772  -67.531  52.920  1
391477  95.813  -67.540  52.900  1
391478  95.854  -67.549  52.879  1
391479  95.895  -67.558  52.859  1
391480  95.936  -67.567  52.838  1
391481  95.976  -67.576  52.817  1
391482  96.004  -67.579  52.797  1
391483  96.029  -67.591  52.776  1
391484  96.053  -67.605  52.756  1
391485  96.083  -67.614  52.737  1
391486  96.116  -67.620  52.717  1
391487  96.150  -67.626  52.696  1
391488  96.183  -67.632  52.676  1
391489  96.217  -67.638  52.655  1
391490  96.250  -67.644  52.634  1
391491  96.282  -67.646  52.615  1
391492  96.314  -67.648  52.594  1
391493  96.346  -67.651  52.573  1
391494  96.378  -67.653  52.551  1
391495  96.410  -67.655  52.530  1
391496  96.443  -67.658  52.506  1
391497  96.476  -67.661  52.484  1
391498  96.509  -67.664  52.462  1
391499  96.542  -67.673  52.440  1
391500  96.575  -67.681  52.420  1
391501  96.608  -67.689  52.400  1
391502  96.642  -67.698  52.380  1
391503  96.674  -67.707  52.361  1
391504  96.708  -67.712  52.343  1
391505  96.741  -67.715  52.326  1
391506  96.774  -67.718  52.309  1
391507  96.808  -67.727  52.293  1
391508  96.841  -67.737  52.280  1
391509  96.874  -67.747  52.268  1
391510  96.907  -67.758  52.258  1
391511  96.941  -67.768  52.249  1
391512  96.974  -67.777  52.240  1
391513  97.007  -67.788  52.233  1
391514  97.044  -67.796  52.227  1
391515  97.083  -67.802  52.222  1
391516  97.122  -67.808  52.216  1
391517  97.164  -67.808  52.207  1
391518  97.211  -67.805  52.197  1
391519  97.256  -67.802  52.183  1
391520  97.304  -67.809  52.164  1
391521  97.345  -67.811  52.141  1
391522  97.379  -67.808  52.112  1
391523  97.413  -67.805  52.079  1
391524  97.447  -67.802  52.043  1
391525  97.481  -67.799  52.007  1
391526  97.515  -67.796  51.971  1
391527  97.549  -67.793  51.938  1
391528  97.584  -67.790  51.909  1
391529  97.613  -67.791  51.881  1
391530  97.642  -67.793  51.852  1
391531  97.670  -67.796  51.822  1
391532  97.699  -67.798  51.788  1
391533  97.743  -67.802  51.751  1
391534  97.785  -67.806  51.709  1
391535  97.815  -67.811  51.662  1
391536  97.845  -67.817  51.615  1
391537  97.875  -67.823  51.570  1
391538  97.906  -67.828  51.529  1
391539  97.936  -67.833  51.487  1
391540  97.966  -67.839  51.443  1
391541  97.997  -67.844  51.400  1
391542  98.027  -67.849  51.358  1
391543  98.058  -67.856  51.317  1
391544  98.091  -67.859  51.277  1
391545  98.125  -67.870  51.235  1
391546  98.159  -67.878  51.190  1
391547  98.193  -67.887  51.140  1
391548  98.226  -67.896  51.089  1
391549  98.261  -67.904  51.037  1
391550  98.294  -67.913  50.985  1
391551  98.328  -67.921  50.935  1
391552  98.362  -67.931  50.886  1
391553  98.396  -67.939  50.838  1
391554  98.430  -67.948  50.791  1
391555  98.463  -67.956  50.745  1
391556  98.497  -67.965  50.698  1
391557  98.531  -67.974  50.651  1
391558  98.565  -67.982  50.605  1
391559  98.600  -67.992  50.560  1
391560  98.636  -68.002  50.513  1
391561  98.671  -68.012  50.465  1
391562  98.707  -68.021  50.417  1
391563  98.742  -68.031  50.369  1
391564  98.778  -68.040  50.322  1
391565  98.813  -68.050  50.276  1
391566  98.851  -68.052  50.229  1
391567  98.892  -68.043  50.179  1
391568  98.934  -68.034  50.128  1
391569  98.977  -68.037  50.074  1
391570  99.020  -68.038  50.021  1
391571  99.059  -68.046  49.968  1
391572  99.094  -68.060  49.916  1
391573  99.130  -68.070  49.865  1
391574  99.163  -68.071  49.816  1
391575  99.197  -68.072  49.769  1
391576  99.230  -68.072  49.725  1
391577  99.264  -68.073  49.682  1
391578  99.297  -68.074  49.637  1
391579  99.331  -68.075  49.593  1
391580  99.360  -68.085  49.548  1
391581  99.392  -68.109  49.503  1
391582  99.449  -68.134  49.455  1
391583  99.453  -68.156  49.405  1
391584  99.482  -68.159  49.357  1
391585  99.511  -68.162  49.314  1
391586  99.546  -68.162  49.275  1
391587  99.589  -68.158  49.234  1
391588  99.637  -68.160  49.191  1
391589  99.692  -68.174  49.147  1
391590  99.746  -68.188  49.102  1
391591  99.792  -68.200  49.058  1
391592  99.825  -68.209  49.014  1
391593  99.857  -68.218  48.971  1
391594  99.888  -68.229  48.929  1
391595  99.916  -68.245  48.888  1
391596  99.959  -68.203  48.846  1
391597  99.987  -68.180  48.801  1
391598  100.014  -68.200  48.757  1
391599  100.046  -68.239  48.712  1
391600  100.078  -68.278  48.665  1
391601  100.111  -68.317  48.620  1
391602  100.142  -68.355  48.575  1
391603  100.171  -68.360  48.529  1
391604  100.204  -68.362  48.484  1
391605  100.244  -68.360  48.441  1
391606  100.284  -68.357  48.397  1
391607  100.323  -68.356  48.353  1
391608  100.363  -68.354  48.310  1
391609  100.403  -68.351  48.267  1
391610  100.442  -68.350  48.224  1
392047  90.044  -67.624  54.872  1
392048  90.079  -67.634  54.871  1
392049  90.113  -67.643  54.872  1
392050  90.147  -67.653  54.876  1
392051  90.181  -67.663  54.881  1
392052  90.216  -67.672  54.889  1
392053  90.250  -67.682  54.897  1
392054  90.284  -67.692  54.907  1
392055  90.318  -67.701  54.918  1
392056  90.353  -67.711  54.930  1
392057  90.387  -67.720  54.943  1
392058  90.425  -67.728  54.958  1
392059  90.478  -67.717  54.973  1
392060  90.538  -67.712  54.984  1
392061  90.599  -67.713  54.990  1
392062  90.660  -67.713  54.989  1
392063  90.722  -67.714  54.983  1
392064  90.787  -67.711  54.973  1
392065  90.854  -67.708  54.960  1
392066  90.921  -67.705  54.946  1
392067  90.988  -67.703  54.932  1
392068  91.054  -67.700  54.918  1
392069  91.121  -67.697  54.906  1
392070  91.171  -67.686  54.894  1
392071  91.221  -67.677  54.884  1
392072  91.271  -67.666  54.875  1
392073  91.321  -67.656  54.869  1
392074  91.371  -67.645  54.866  1
392075  91.421  -67.636  54.863  1
392076  91.467  -67.627  54.858  1
392077  91.508  -67.619  54.851  1
392078  91.549  -67.611  54.844  1
392079  91.591  -67.604  54.840  1
392080  91.632  -67.596  54.835  1
392081  91.673  -67.589  54.827  1
392082  91.714  -67.581  54.818  1
392083  91.755  -67.573  54.808  1
392084  91.797  -67.566  54.796  1
392085  91.838  -67.559  54.783  1
392086  91.879  -67.559  54.770  1
392087  91.919  -67.568  54.754  1
392088  91.960  -67.578  54.736  1
392089  92.003  -67.586  54.718  1
392090  92.057  -67.589  54.697  1
392091  92.111  -67.592  54.676  1
392092  92.165  -67.595  54.655  1
392093  92.218  -67.598  54.633  1
392094  92.272  -67.601  54.609  1
392095  92.326  -67.603  54.585  1
392096  92.380  -67.606  54.562  1
392097  92.434  -67.609  54.539  1
392098  92.488  -67.612  54.518  1
392099  92.542  -67.615  54.497  1
392100  92.595  -67.618  54.474  1
392101  92.649  -67.620  54.448  1
392102  92.703  -67.623  54.424  1
392103  92.757  -67.627  54.401  1
392104  92.810  -67.630  54.379  1
392105  92.866  -67.627  54.360  1
392106  92.925  -67.616  54.345  1
392107  92.968  -67.613  54.335  1
392108  93.002  -67.614  54.328  1
392109  93.038  -67.614  54.323  1
392110  93.074  -67.612  54.318  1
392111  93.110  -67.610  54.309  1
392112  93.146  -67.608  54.300  1
392113  93.182  -67.607  54.286  1
392114  93.231  -67.602  54.268  1
392115  93.285  -67.597  54.246  1
392116  93.339  -67.592  54.225  1
392117  93.392  -67.586  54.203  1
392118  93.439  -67.586  54.182  1
392119  93.476  -67.590  54.163  1
392120  93.508  -67.586  54.149  1
392121  93.539  -67.580  54.138  1
392122  93.573  -67.574  54.129  1
392123  93.620  -67.570  54.119  1
392124  93.666  -67.567  54.103  1
392125  93.712  -67.562  54.082  1
392126  93.758  -67.558  54.059  1
392127  93.804  -67.558  54.034  1
392128  93.851  -67.562  54.008  1
392129  93.897  -67.567  53.985  1
392130  93.944  -67.572  53.964  1
392131  93.989  -67.576  53.943  1
392132  94.031  -67.581  53.923  1
392133  94.072  -67.583  53.902  1
392134  94.109  -67.577  53.882  1
392135  94.145  -67.570  53.860  1
392136  94.182  -67.564  53.837  1
392137  94.219  -67.558  53.813  1
392138  94.256  -67.552  53.787  1
392139  94.293  -67.545  53.759  1
392140  94.330  -67.539  53.731  1
392141  94.366  -67.533  53.701  1
392142  94.403  -67.527  53.670  1
392143  94.440  -67.520  53.641  1
392144  94.488  -67.523  53.617  1
392145  94.538  -67.529  53.595  1
392146  94.588  -67.533  53.575  1
392147  94.625  -67.533  53.557  1
392148  94.660  -67.530  53.541  1
392149  94.695  -67.528  53.525  1
392150  94.731  -67.526  53.507  1
392151  94.766  -67.524  53.489  1
392152  94.801  -67.523  53.472  1
392153  94.834  -67.517  53.457  1
392154  94.862  -67.501  53.443  1
392155  94.890  -67.484  53.426  1
392156  94.918  -67.468  53.401  1
392157  94.956  -67.467  53.373  1
392158  94.996  -67.469  53.345  1
392159  95.037  -67.471  53.318  1
392160  95.077  -67.473  53.291  1
392161  95.118  -67.475  53.267  1
392162  95.155  -67.470  53.243  1
392163  95.193  -67.464  53.219  1
392164  95.231  -67.458  53.196  1
392165  95.268  -67.453  53.174  1
392166  95.306  -67.448  53.152  1
392167  95.343  -67.442  53.132  1
392168  95.388  -67.443  53.111  1
392169  95.436  -67.446  53.090  1
392170  95.483  -67.448  53.069  1
392171  95.530  -67.451  53.049  1
392172  95.578  -67.454  53.028  1
392173  95.620  -67.460  53.008  1
392174  95.660  -67.470  52.988  1
392175  95.699  -67.478  52.968  1
392176  95.739  -67.487  52.947  1
392177  95.778  -67.496  52.926  1
392178  95.817  -67.505  52.906  1
392179  95.858  -67.514  52.884  1
392180  95.899  -67.523  52.864  1
392181  95.940  -67.532  52.842  1
392182  95.980  -67.541  52.821  1
392183  96.009  -67.545  52.800  1
392184  96.033  -67.559  52.778  1
392185  96.057  -67.573  52.757  1
392186  96.086  -67.583  52.736  1
392187  96.119  -67.589  52.715  1
392188  96.153  -67.595  52.693  1
392189  96.186  -67.602  52.671  1
392190  96.219  -67.604  52.650  1
392191  96.251  -67.607  52.628  1
392192  96.283  -67.609  52.607  1
392193  96.315  -67.611  52.586  1
392194  96.347  -67.614  52.564  1
392195  96.379  -67.616  52.543  1
392196  96.411  -67.618  52.521  1
392197  96.444  -67.621  52.499  1
392198  96.477  -67.624  52.476  1
392199  96.510  -67.627  52.454  1
392200  96.543  -67.633  52.433  1
392201  96.576  -67.642  52.413  1
392202  96.609  -67.651  52.392  1
392203  96.643  -67.659  52.372  1
392204  96.675  -67.667  52.352  1
392205  96.709  -67.670  52.334  1
392206  96.742  -67.673  52.316  1
392207  96.776  -67.676  52.299  1
392208  96.809  -67.681  52.283  1
392209  96.842  -67.691  52.270  1
392210  96.875  -67.701  52.256  1
392211  96.908  -67.711  52.245  1
392212  96.942  -67.721  52.236  1
392213  96.976  -67.730  52.226  1
392214  97.015  -67.736  52.217  1
392215  97.054  -67.743  52.210  1
392216  97.093  -67.749  52.202  1
392217  97.133  -67.755  52.192  1
392218  97.172  -67.760  52.181  1
392219  97.218  -67.756  52.168  1
392220  97.264  -67.757  52.151  1
392221  97.311  -67.763  52.132  1
392222  97.358  -67.769  52.109  1
392223  97.392  -67.766  52.080  1
392224  97.426  -67.763  52.048  1
392225  97.460  -67.760  52.014  1
392226  97.495  -67.757  51.979  1
392227  97.529  -67.754  51.946  1
392228  97.563  -67.751  51.915  1
392229  97.593  -67.752  51.887  1
392230  97.621  -67.755  51.858  1
392231  97.650  -67.757  51.829  1
392232  97.678  -67.759  51.798  1
392233  97.707  -67.761  51.766  1
392234  97.750  -67.765  51.731  1
392235  97.799  -67.769  51.690  1
392236  97.829  -67.774  51.646  1
392237  97.860  -67.780  51.601  1
392238  97.890  -67.786  51.555  1
392239  97.920  -67.791  51.512  1
392240  97.950  -67.796  51.470  1
392241  97.981  -67.802  51.430  1
392242  98.011  -67.807  51.389  1
392243  98.041  -67.813  51.349  1
392244  98.072  -67.818  51.308  1
392245  98.099  -67.824  51.267  1
392246  98.133  -67.833  51.224  1
392247  98.166  -67.842  51.179  1
392248  98.200  -67.851  51.129  1
392249  98.234  -67.859  51.078  1
392250  98.268  -67.868  51.027  1
392251  98.302  -67.877  50.975  1
392252  98.336  -67.885  50.923  1
392253  98.369  -67.894  50.873  1
392254  98.404  -67.902  50.824  1
392255  98.437  -67.912  50.777  1
392256  98.471  -67.920  50.730  1
392257  98.505  -67.928  50.684  1
392258  98.539  -67.937  50.638  1
392259  98.573  -67.946  50.591  1
392260  98.608  -67.956  50.545  1
392261  98.644  -67.965  50.499  1
392262  98.679  -67.975  50.452  1
392263  98.715  -67.985  50.403  1
392264  98.750  -67.995  50.354  1
392265  98.786  -68.005  50.307  1
392266  98.821  -68.014  50.262  1
392267  98.857  -68.024  50.217  1
392268  98.898  -68.017  50.172  1
392269  98.939  -68.010  50.123  1
392270  98.982  -68.012  50.071  1
392271  99.025  -68.014  50.018  1
392272  99.067  -68.019  49.966  1
392273  99.101  -68.025  49.913  1
392274  99.135  -68.026  49.860  1
392275  99.168  -68.027  49.807  1
392276  99.202  -68.028  49.757  1
392277  99.235  -68.028  49.711  1
392278  99.269  -68.029  49.669  1
392279  99.302  -68.030  49.627  1
392280  99.336  -68.031  49.583  1
392281  99.367  -68.036  49.539  1
392282  99.394  -68.059  49.494  1
392283  99.438  -68.082  49.446  1
392284  99.496  -68.107  49.396  1
392285  99.489  -68.131  49.351  1
392286  99.522  -68.132  49.309  1
392287  99.566  -68.128  49.270  1
392288  99.609  -68.124  49.230  1
392289  99.653  -68.121  49.187  1
392290  99.708  -68.134  49.141  1
392291  99.762  -68.148  49.095  1
392292  99.798  -68.158  49.050  1
392293  99.831  -68.167  49.006  1
392294  99.863  -68.175  48.963  1
392295  99.896  -68.184  48.920  1
392296  99.924  -68.200  48.879  1
392297  99.966  -68.157  48.836  1
392298  99.985  -68.148  48.791  1
392299  100.016  -68.184  48.747  1
392300  100.049  -68.224  48.703  1
392301  100.081  -68.263  48.657  1
392302  100.113  -68.301  48.612  1
392303  100.143  -68.315  48.567  1
392304  100.174  -68.318  48.522  1
392305  100.214  -68.316  48.477  1
392306  100.253  -68.313  48.435  1
392307  100.293  -68.312  48.391  1
392308  100.332  -68.310  48.348  1
392309  100.372  -68.307  48.304  1
392310  100.412  -68.306  48.261  1
392311  100.451  -68.303  48.218  1
392748  90.036  -67.576  54.878  1
392749  90.071  -67.586  54.878  1
392750  90.105  -67.595  54.881  1
392751  90.140  -67.605  54.885  1
392752  90.174  -67.614  54.892  1
392753  90.208  -67.623  54.900  1
392754  90.242  -67.633  54.909  1
392755  90.276  -67.643  54.919  1
392756  90.311  -67.652  54.930  1
392757  90.345  -67.662  54.942  1
392758  90.381  -67.670  54.956  1
392759  90.429  -67.670  54.970  1
392760  90.486  -67.653  54.983  1
392761  90.546  -67.648  54.993  1
392762  90.607  -67.649  54.997  1
392763  90.668  -67.650  54.994  1
392764  90.730  -67.650  54.988  1
392765  90.791  -67.651  54.977  1
392766  90.852  -67.652  54.964  1
392767  90.919  -67.648  54.950  1
392768  90.986  -67.645  54.938  1
392769  91.052  -67.642  54.926  1
392770  91.119  -67.639  54.915  1
392771  91.177  -67.633  54.906  1
392772  91.227  -67.623  54.898  1
392773  91.277  -67.613  54.892  1
392774  91.327  -67.602  54.889  1
392775  91.377  -67.592  54.889  1
392776  91.423  -67.583  54.888  1
392777  91.464  -67.576  54.883  1
392778  91.505  -67.568  54.876  1
392779  91.546  -67.561  54.867  1
392780  91.588  -67.553  54.862  1
392781  91.629  -67.545  54.855  1
392782  91.670  -67.538  54.847  1
392783  91.712  -67.530  54.836  1
392784  91.753  -67.523  54.824  1
392785  91.794  -67.515  54.811  1
392786  91.835  -67.507  54.796  1
392787  91.876  -67.501  54.781  1
392788  91.917  -67.511  54.765  1
392789  91.961  -67.517  54.746  1
392790  92.015  -67.520  54.727  1
392791  92.069  -67.523  54.706  1
392792  92.123  -67.526  54.684  1
392793  92.177  -67.529  54.662  1
392794  92.231  -67.533  54.640  1
392795  92.285  -67.536  54.616  1
392796  92.339  -67.538  54.592  1
392797  92.392  -67.541  54.570  1
392798  92.446  -67.544  54.547  1
392799  92.500  -67.547  54.525  1
392800  92.554  -67.550  54.502  1
392801  92.607  -67.553  54.478  1
392802  92.661  -67.555  54.453  1
392803  92.715  -67.558  54.428  1
392804  92.769  -67.561  54.404  1
392805  92.823  -67.564  54.383  1
392806  92.877  -67.567  54.365  1
392807  92.932  -67.566  54.350  1
392808  92.971  -67.564  54.338  1
392809  93.007  -67.562  54.330  1
392810  93.043  -67.561  54.323  1
392811  93.079  -67.559  54.315  1
392812  93.115  -67.558  54.307  1
392813  93.151  -67.556  54.298  1
392814  93.187  -67.555  54.286  1
392815  93.236  -67.550  54.270  1
392816  93.290  -67.545  54.249  1
392817  93.344  -67.539  54.228  1
392818  93.397  -67.534  54.206  1
392819  93.438  -67.536  54.185  1
392820  93.476  -67.540  54.167  1
392821  93.509  -67.539  54.154  1
392822  93.540  -67.533  54.144  1
392823  93.570  -67.526  54.135  1
392824  93.604  -67.521  54.124  1
392825  93.650  -67.517  54.108  1
392826  93.697  -67.513  54.088  1
392827  93.743  -67.509  54.065  1
392828  93.789  -67.505  54.039  1
392829  93.835  -67.509  54.013  1
392830  93.882  -67.514  53.989  1
392831  93.928  -67.519  53.968  1
392832  93.973  -67.523  53.946  1
392833  94.014  -67.528  53.925  1
392834  94.056  -67.533  53.904  1
392835  94.094  -67.527  53.883  1
392836  94.131  -67.521  53.861  1
392837  94.168  -67.515  53.839  1
392838  94.205  -67.509  53.815  1
392839  94.242  -67.502  53.790  1
392840  94.278  -67.496  53.764  1
392841  94.315  -67.490  53.736  1
392842  94.352  -67.483  53.707  1
392843  94.389  -67.477  53.675  1
392844  94.435  -67.479  53.647  1
392845  94.485  -67.484  53.623  1
392846  94.535  -67.489  53.601  1
392847  94.582  -67.492  53.581  1
392848  94.617  -67.490  53.564  1
392849  94.652  -67.489  53.549  1
392850  94.688  -67.486  53.532  1
392851  94.723  -67.485  53.515  1
392852  94.758  -67.482  53.498  1
392853  94.794  -67.481  53.484  1
392854  94.829  -67.479  53.472  1
392855  94.862  -67.473  53.460  1
392856  94.890  -67.457  53.444  1
392857  94.918  -67.441  53.417  1
392858  94.958  -67.442  53.385  1
392859  94.999  -67.445  53.352  1
392860  95.039  -67.447  53.322  1
392861  95.077  -67.442  53.294  1
392862  95.115  -67.437  53.269  1
392863  95.153  -67.432  53.244  1
392864  95.190  -67.426  53.221  1
392865  95.228  -67.420  53.199  1
392866  95.265  -67.415  53.176  1
392867  95.303  -67.410  53.155  1
392868  95.344  -67.407  53.134  1
392869  95.392  -67.410  53.114  1
392870  95.439  -67.413  53.094  1
392871  95.486  -67.416  53.073  1
392872  95.533  -67.419  53.053  1
392873  95.581  -67.421  53.032  1
392874  95.626  -67.426  53.013  1
392875  95.665  -67.435  52.993  1
392876  95.705  -67.444  52.973  1
392877  95.744  -67.452  52.952  1
392878  95.784  -67.461  52.932  1
392879  95.823  -67.470  52.912  1
392880  95.863  -67.479  52.890  1
392881  95.903  -67.489  52.870  1
392882  95.944  -67.497  52.848  1
392883  95.984  -67.506  52.826  1
392884  96.013  -67.513  52.804  1
392885  96.037  -67.527  52.782  1
392886  96.061  -67.541  52.759  1
392887  96.089  -67.552  52.737  1
392888  96.122  -67.558  52.713  1
392889  96.155  -67.562  52.691  1
392890  96.187  -67.564  52.668  1
392891  96.220  -67.567  52.645  1
392892  96.251  -67.569  52.623  1
392893  96.284  -67.571  52.600  1
392894  96.316  -67.574  52.579  1
392895  96.347  -67.576  52.557  1
392896  96.380  -67.579  52.535  1
392897  96.412  -67.581  52.514  1
392898  96.445  -67.584  52.492  1
392899  96.478  -67.587  52.470  1
392900  96.511  -67.590  52.448  1
392901  96.544  -67.595  52.427  1
392902  96.577  -67.603  52.406  1
392903  96.610  -67.611  52.385  1
392904  96.644  -67.620  52.364  1
392905  96.677  -67.624  52.345  1
392906  96.710  -67.627  52.326  1
392907  96.743  -67.630  52.308  1
392908  96.777  -67.633  52.291  1
392909  96.810  -67.636  52.275  1
392910  96.843  -67.645  52.261  1
392911  96.876  -67.655  52.246  1
392912  96.909  -67.665  52.234  1
392913  96.948  -67.672  52.223  1
392914  96.986  -67.677  52.213  1
392915  97.026  -67.683  52.203  1
392916  97.065  -67.689  52.193  1
392917  97.104  -67.695  52.182  1
392918  97.143  -67.702  52.171  1
392919  97.182  -67.708  52.158  1
392920  97.225  -67.707  52.143  1
392921  97.272  -67.711  52.125  1
392922  97.319  -67.717  52.105  1
392923  97.366  -67.724  52.082  1
392924  97.405  -67.724  52.053  1
392925  97.440  -67.721  52.021  1
392926  97.474  -67.718  51.988  1
392927  97.508  -67.715  51.955  1
392928  97.542  -67.712  51.923  1
392929  97.573  -67.713  51.893  1
392930  97.601  -67.715  51.863  1
392931  97.630  -67.718  51.834  1
392932  97.658  -67.721  51.805  1
392933  97.687  -67.723  51.775  1
392934  97.715  -67.725  51.743  1
392935  97.756  -67.729  51.710  1
392936  97.806  -67.733  51.671  1
392937  97.844  -67.737  51.629  1
392938  97.874  -67.743  51.585  1
392939  97.904  -67.749  51.541  1
392940  97.935  -67.754  51.497  1
392941  97.965  -67.759  51.456  1
392942  97.995  -67.764  51.417  1
392943  98.025  -67.770  51.378  1
392944  98.056  -67.776  51.338  1
392945  98.082  -67.777  51.297  1
392946  98.108  -67.781  51.255  1
392947  98.143  -67.797  51.211  1
392948  98.176  -67.806  51.167  1
392949  98.209  -67.815  51.117  1
392950  98.242  -67.823  51.067  1
392951  98.276  -67.832  51.017  1
392952  98.309  -67.840  50.966  1
392953  98.343  -67.849  50.914  1
392954  98.377  -67.858  50.863  1
392955  98.411  -67.866  50.813  1
392956  98.445  -67.875  50.763  1
392957  98.479  -67.884  50.716  1
392958  98.512  -67.892  50.670  1
392959  98.547  -67.901  50.623  1
392960  98.581  -67.910  50.576  1
392961  98.616  -67.920  50.531  1
392962  98.652  -67.930  50.484  1
392963  98.688  -67.939  50.437  1
392964  98.723  -67.949  50.388  1
392965  98.759  -67.959  50.339  1
392966  98.794  -67.968  50.292  1
392967  98.830  -67.978  50.248  1
392968  98.865  -67.988  50.205  1
392969  98.903  -67.990  50.161  1
392970  98.944  -67.986  50.115  1
392971  98.988  -67.988  50.065  1
392972  99.032  -67.990  50.014  1
392973  99.081  -67.990  49.962  1
392974  99.113  -67.985  49.909  1
392975  99.140  -67.983  49.855  1
392976  99.173  -67.984  49.802  1
392977  99.207  -67.984  49.751  1
392978  99.240  -67.985  49.702  1
392979  99.274  -67.986  49.656  1
392980  99.307  -67.987  49.614  1
392981  99.341  -67.987  49.572  1
392982  99.374  -67.988  49.528  1
392983  99.401  -68.009  49.482  1
392984  99.427  -68.031  49.435  1
392985  99.484  -68.056  49.386  1
392986  99.534  -68.082  49.343  1
392987  99.548  -68.094  49.303  1
392988  99.585  -68.094  49.265  1
392989  99.629  -68.089  49.223  1
392990  99.672  -68.085  49.179  1
392991  99.724  -68.094  49.133  1
392992  99.771  -68.106  49.087  1
392993  99.804  -68.115  49.041  1
392994  99.837  -68.125  48.998  1
392995  99.869  -68.134  48.955  1
392996  99.902  -68.143  48.913  1
392997  99.932  -68.154  48.871  1
392998  99.964  -68.126  48.827  1
392999  99.987  -68.130  48.783  1
393000  100.019  -68.169  48.739  1
393001  100.051  -68.208  48.695  1
393002  100.083  -68.247  48.649  1
393003  100.114  -68.269  48.605  1
393004  100.143  -68.274  48.560  1
393005  100.183  -68.272  48.516  1
393006  100.223  -68.269  48.471  1
393007  100.262  -68.268  48.429  1
393008  100.302  -68.266  48.386  1
393009  100.342  -68.263  48.342  1
393010  100.381  -68.262  48.298  1
393011  100.421  -68.260  48.255  1
393012  100.461  -68.257  48.212  1
393449  90.029  -67.527  54.884  1
393450  90.063  -67.537  54.885  1
393451  90.097  -67.547  54.889  1
393452  90.131  -67.556  54.894  1
393453  90.166  -67.566  54.901  1
393454  90.200  -67.576  54.910  1
393455  90.234  -67.585  54.920  1
393456  90.268  -67.595  54.930  1
393457  90.303  -67.604  54.940  1
393458  90.337  -67.614  54.953  1
393459  90.384  -67.617  54.968  1
393460  90.437  -67.606  54.981  1
393461  90.494  -67.589  54.992  1
393462  90.554  -67.585  55.000  1
393463  90.615  -67.586  55.002  1
393464  90.676  -67.586  54.999  1
393465  90.738  -67.586  54.991  1
393466  90.799  -67.587  54.980  1
393467  90.860  -67.588  54.968  1
393468  90.921  -67.589  54.955  1
393469  90.983  -67.588  54.944  1
393470  91.050  -67.586  54.934  1
393471  91.117  -67.583  54.925  1
393472  91.183  -67.580  54.920  1
393473  91.233  -67.569  54.916  1
393474  91.283  -67.559  54.913  1
393475  91.333  -67.548  54.912  1
393476  91.379  -67.539  54.913  1
393477  91.420  -67.532  54.911  1
393478  91.461  -67.524  54.905  1
393479  91.503  -67.517  54.897  1
393480  91.544  -67.509  54.888  1
393481  91.585  -67.501  54.883  1
393482  91.627  -67.494  54.876  1
393483  91.668  -67.487  54.866  1
393484  91.709  -67.479  54.854  1
393485  91.750  -67.472  54.840  1
393486  91.791  -67.464  54.826  1
393487  91.832  -67.457  54.810  1
393488  91.874  -67.449  54.793  1
393489  91.920  -67.450  54.777  1
393490  91.974  -67.453  54.757  1
393491  92.028  -67.455  54.736  1
393492  92.082  -67.458  54.715  1
393493  92.135  -67.462  54.693  1
393494  92.188  -67.466  54.670  1
393495  92.241  -67.470  54.648  1
393496  92.295  -67.473  54.624  1
393497  92.348  -67.477  54.601  1
393498  92.401  -67.481  54.579  1
393499  92.454  -67.485  54.556  1
393500  92.508  -67.489  54.533  1
393501  92.561  -67.492  54.509  1
393502  92.614  -67.496  54.483  1
393503  92.667  -67.500  54.459  1
393504  92.721  -67.504  54.433  1
393505  92.774  -67.507  54.410  1
393506  92.827  -67.511  54.389  1
393507  92.880  -67.515  54.370  1
393508  92.937  -67.520  54.356  1
393509  92.976  -67.511  54.344  1
393510  93.012  -67.510  54.335  1
393511  93.048  -67.508  54.326  1
393512  93.084  -67.507  54.316  1
393513  93.120  -67.504  54.308  1
393514  93.156  -67.503  54.299  1
393515  93.192  -67.501  54.287  1
393516  93.241  -67.497  54.270  1
393517  93.295  -67.492  54.251  1
393518  93.349  -67.486  54.228  1
393519  93.401  -67.482  54.207  1
393520  93.438  -67.486  54.187  1
393521  93.475  -67.491  54.169  1
393522  93.510  -67.492  54.158  1
393523  93.541  -67.486  54.149  1
393524  93.571  -67.479  54.139  1
393525  93.602  -67.473  54.128  1
393526  93.635  -67.467  54.112  1
393527  93.681  -67.464  54.091  1
393528  93.727  -67.460  54.068  1
393529  93.773  -67.455  54.042  1
393530  93.820  -67.456  54.017  1
393531  93.866  -67.461  53.993  1
393532  93.913  -67.466  53.972  1
393533  93.957  -67.470  53.950  1
393534  93.998  -67.475  53.928  1
393535  94.040  -67.479  53.908  1
393536  94.079  -67.478  53.886  1
393537  94.117  -67.472  53.864  1
393538  94.153  -67.466  53.842  1
393539  94.190  -67.459  53.818  1
393540  94.227  -67.453  53.794  1
393541  94.264  -67.447  53.768  1
393542  94.301  -67.440  53.742  1
393543  94.338  -67.434  53.713  1
393544  94.382  -67.435  53.681  1
393545  94.432  -67.439  53.653  1
393546  94.482  -67.445  53.629  1
393547  94.532  -67.449  53.608  1
393548  94.574  -67.451  53.588  1
393549  94.610  -67.448  53.572  1
393550  94.645  -67.447  53.556  1
393551  94.680  -67.445  53.540  1
393552  94.715  -67.443  53.524  1
393553  94.751  -67.441  53.508  1
393554  94.786  -67.439  53.497  1
393555  94.822  -67.437  53.487  1
393556  94.857  -67.435  53.475  1
393557  94.890  -67.429  53.458  1
393558  94.920  -67.417  53.430  1
393559  94.961  -67.418  53.395  1
393560  94.999  -67.415  53.359  1
393561  95.037  -67.410  53.326  1
393562  95.074  -67.404  53.298  1
393563  95.112  -67.399  53.272  1
393564  95.149  -67.393  53.247  1
393565  95.187  -67.388  53.224  1
393566  95.225  -67.382  53.202  1
393567  95.262  -67.377  53.181  1
393568  95.301  -67.372  53.160  1
393569  95.348  -67.375  53.140  1
393570  95.395  -67.378  53.120  1
393571  95.442  -67.380  53.099  1
393572  95.489  -67.383  53.079  1
393573  95.537  -67.385  53.059  1
393574  95.584  -67.388  53.039  1
393575  95.631  -67.392  53.019  1
393576  95.671  -67.400  52.999  1
393577  95.710  -67.409  52.979  1
393578  95.750  -67.418  52.959  1
393579  95.790  -67.426  52.940  1
393580  95.829  -67.435  52.918  1
393581  95.869  -67.445  52.898  1
393582  95.908  -67.454  52.876  1
393583  95.948  -67.462  52.855  1
393584  95.988  -67.471  52.833  1
393585  96.017  -67.481  52.811  1
393586  96.042  -67.495  52.787  1
393587  96.066  -67.509  52.763  1
393588  96.092  -67.520  52.738  1
393589  96.124  -67.523  52.715  1
393590  96.156  -67.525  52.690  1
393591  96.188  -67.527  52.667  1
393592  96.220  -67.529  52.643  1
393593  96.252  -67.532  52.620  1
393594  96.284  -67.534  52.595  1
393595  96.316  -67.536  52.573  1
393596  96.348  -67.539  52.551  1
393597  96.381  -67.542  52.529  1
393598  96.413  -67.544  52.507  1
393599  96.446  -67.547  52.485  1
393600  96.479  -67.550  52.464  1
393601  96.512  -67.553  52.443  1
393602  96.545  -67.556  52.421  1
393603  96.578  -67.564  52.400  1
393604  96.611  -67.572  52.379  1
393605  96.645  -67.579  52.359  1
393606  96.678  -67.582  52.339  1
393607  96.711  -67.585  52.319  1
393608  96.744  -67.588  52.301  1
393609  96.778  -67.591  52.285  1
393610  96.811  -67.594  52.269  1
393611  96.844  -67.598  52.254  1
393612  96.880  -67.607  52.237  1
393613  96.919  -67.613  52.223  1
393614  96.958  -67.619  52.211  1
393615  96.997  -67.625  52.200  1
393616  97.036  -67.631  52.189  1
393617  97.075  -67.636  52.177  1
393618  97.114  -67.642  52.164  1
393619  97.153  -67.648  52.151  1
393620  97.192  -67.655  52.137  1
393621  97.233  -67.660  52.121  1
393622  97.280  -67.666  52.102  1
393623  97.327  -67.672  52.082  1
393624  97.374  -67.678  52.058  1
393625  97.419  -67.683  52.029  1
393626  97.453  -67.680  51.998  1
393627  97.488  -67.677  51.966  1
393628  97.522  -67.674  51.934  1
393629  97.552  -67.674  51.902  1
393630  97.581  -67.677  51.872  1
393631  97.609  -67.679  51.841  1
393632  97.638  -67.682  51.812  1
393633  97.666  -67.684  51.782  1
393634  97.695  -67.686  51.752  1
393635  97.724  -67.689  51.721  1
393636  97.762  -67.692  51.688  1
393637  97.812  -67.696  51.651  1
393638  97.858  -67.701  51.611  1
393639  97.888  -67.706  51.569  1
393640  97.919  -67.711  51.526  1
393641  97.949  -67.717  51.482  1
393642  97.979  -67.722  51.442  1
393643  98.010  -67.727  51.403  1
393644  98.040  -67.733  51.365  1
393645  98.068  -67.736  51.324  1
393646  98.089  -67.734  51.283  1
393647  98.116  -67.739  51.241  1
393648  98.152  -67.758  51.198  1
393649  98.186  -67.770  51.153  1
393650  98.219  -67.779  51.105  1
393651  98.252  -67.787  51.056  1
393652  98.286  -67.796  51.007  1
393653  98.319  -67.804  50.955  1
393654  98.352  -67.813  50.904  1
393655  98.385  -67.821  50.853  1
393656  98.418  -67.830  50.801  1
393657  98.452  -67.839  50.750  1
393658  98.486  -67.847  50.703  1
393659  98.520  -67.855  50.657  1
393660  98.554  -67.865  50.610  1
393661  98.589  -67.874  50.562  1
393662  98.624  -67.884  50.516  1
393663  98.660  -67.893  50.468  1
393664  98.695  -67.903  50.421  1
393665  98.731  -67.913  50.372  1
393666  98.766  -67.923  50.324  1
393667  98.802  -67.932  50.277  1
393668  98.837  -67.942  50.234  1
393669  98.873  -67.952  50.192  1
393670  98.909  -67.962  50.149  1
393671  98.950  -67.962  50.105  1
393672  99.000  -67.962  50.056  1
393673  99.049  -67.961  50.006  1
393674  99.098  -67.961  49.955  1
393675  99.148  -67.961  49.903  1
393676  99.183  -67.957  49.849  1
393677  99.196  -67.948  49.797  1
393678  99.212  -67.940  49.745  1
393679  99.245  -67.941  49.695  1
393680  99.279  -67.942  49.645  1
393681  99.312  -67.943  49.603  1
393682  99.346  -67.943  49.560  1
393683  99.379  -67.944  49.516  1
393684  99.408  -67.959  49.470  1
393685  99.434  -67.982  49.423  1
393686  99.473  -68.006  49.377  1
393687  99.545  -68.030  49.335  1
393688  99.586  -68.037  49.296  1
393689  99.626  -68.043  49.258  1
393690  99.653  -68.053  49.215  1
393691  99.692  -68.050  49.169  1
393692  99.740  -68.055  49.123  1
393693  99.777  -68.065  49.078  1
393694  99.810  -68.074  49.032  1
393695  99.843  -68.083  48.989  1
393696  99.875  -68.091  48.947  1
393697  99.908  -68.100  48.905  1
393698  99.941  -68.106  48.863  1
393699  99.962  -68.094  48.819  1
393700  99.989  -68.114  48.776  1
393701  100.021  -68.153  48.732  1
393702  100.053  -68.192  48.688  1
393703  100.085  -68.225  48.643  1
393704  100.114  -68.229  48.599  1
393705  100.153  -68.228  48.554  1
393706  100.192  -68.226  48.510  1
393707  100.232  -68.224  48.466  1
393708  100.272  -68.222  48.423  1
393709  100.311  -68.219  48.380  1
393710  100.351  -68.218  48.337  1
393711  100.391  -68.216  48.293  1
393712  100.430  -68.213  48.250  1
393713  100.470  -68.212  48.207  1
394150  90.021  -67.479  54.889  1
394151  90.055  -67.489  54.891  1
394152  90.089  -67.498  54.896  1
394153  90.123  -67.507  54.903  1
394154  90.158  -67.517  54.910  1
394155  90.192  -67.527  54.920  1
394156  90.226  -67.536  54.930  1
394157  90.260  -67.546  54.940  1
394158  90.295  -67.556  54.950  1
394159  90.340  -67.560  54.964  1
394160  90.388  -67.559  54.978  1
394161  90.445  -67.542  54.991  1
394162  90.502  -67.524  55.000  1
394163  90.562  -67.521  55.007  1
394164  90.623  -67.522  55.006  1
394165  90.684  -67.523  55.002  1
394166  90.746  -67.523  54.994  1
394167  90.807  -67.523  54.983  1
394168  90.868  -67.524  54.971  1
394169  90.929  -67.525  54.960  1
394170  90.991  -67.525  54.950  1
394171  91.051  -67.526  54.942  1
394172  91.115  -67.525  54.937  1
394173  91.182  -67.522  54.935  1
394174  91.239  -67.515  54.935  1
394175  91.289  -67.505  54.935  1
394176  91.335  -67.496  54.936  1
394177  91.376  -67.489  54.936  1
394178  91.418  -67.481  54.931  1
394179  91.459  -67.473  54.924  1
394180  91.500  -67.466  54.915  1
394181  91.541  -67.458  54.907  1
394182  91.582  -67.451  54.901  1
394183  91.624  -67.443  54.894  1
394184  91.665  -67.435  54.884  1
394185  91.707  -67.429  54.871  1
394186  91.748  -67.422  54.856  1
394187  91.790  -67.415  54.841  1
394188  91.831  -67.407  54.824  1
394189  91.873  -67.401  54.806  1
394190  91.920  -67.404  54.788  1
394191  91.972  -67.407  54.768  1
394192  92.026  -67.411  54.748  1
394193  92.079  -67.415  54.727  1
394194  92.133  -67.419  54.705  1
394195  92.186  -67.423  54.681  1
394196  92.239  -67.426  54.657  1
394197  92.292  -67.430  54.634  1
394198  92.345  -67.434  54.611  1
394199  92.399  -67.438  54.588  1
394200  92.452  -67.442  54.565  1
394201  92.505  -67.445  54.541  1
394202  92.558  -67.449  54.516  1
394203  92.612  -67.453  54.490  1
394204  92.665  -67.457  54.464  1
394205  92.718  -67.460  54.440  1
394206  92.771  -67.464  54.417  1
394207  92.825  -67.468  54.396  1
394208  92.883  -67.475  54.377  1
394209  92.939  -67.476  54.363  1
394210  92.981  -67.459  54.352  1
394211  93.017  -67.457  54.342  1
394212  93.053  -67.455  54.332  1
394213  93.089  -67.454  54.321  1
394214  93.125  -67.452  54.310  1
394215  93.161  -67.451  54.300  1
394216  93.197  -67.449  54.286  1
394217  93.247  -67.445  54.269  1
394218  93.300  -67.439  54.249  1
394219  93.354  -67.434  54.227  1
394220  93.401  -67.432  54.205  1
394221  93.437  -67.437  54.187  1
394222  93.475  -67.442  54.172  1
394223  93.511  -67.445  54.161  1
394224  93.542  -67.439  54.152  1
394225  93.572  -67.432  54.141  1
394226  93.603  -67.426  54.129  1
394227  93.633  -67.420  54.113  1
394228  93.665  -67.413  54.093  1
394229  93.712  -67.410  54.069  1
394230  93.758  -67.406  54.045  1
394231  93.804  -67.403  54.021  1
394232  93.851  -67.408  53.998  1
394233  93.897  -67.413  53.975  1
394234  93.940  -67.417  53.954  1
394235  93.982  -67.422  53.933  1
394236  94.024  -67.426  53.910  1
394237  94.065  -67.429  53.889  1
394238  94.102  -67.422  53.866  1
394239  94.139  -67.416  53.844  1
394240  94.176  -67.410  53.821  1
394241  94.212  -67.404  53.797  1
394242  94.250  -67.397  53.773  1
394243  94.286  -67.391  53.747  1
394244  94.329  -67.390  53.720  1
394245  94.379  -67.395  53.688  1
394246  94.429  -67.400  53.659  1
394247  94.479  -67.404  53.635  1
394248  94.530  -67.410  53.614  1
394249  94.567  -67.409  53.596  1
394250  94.602  -67.407  53.580  1
394251  94.637  -67.405  53.564  1
394252  94.673  -67.403  53.549  1
394253  94.708  -67.401  53.534  1
394254  94.744  -67.399  53.521  1
394255  94.779  -67.397  53.511  1
394256  94.814  -67.395  53.500  1
394257  94.849  -67.393  53.487  1
394258  94.885  -67.392  53.468  1
394259  94.921  -67.388  53.439  1
394260  94.959  -67.382  53.402  1
394261  94.996  -67.377  53.364  1
394262  95.034  -67.372  53.329  1
394263  95.071  -67.366  53.301  1
394264  95.109  -67.361  53.276  1
394265  95.147  -67.355  53.251  1
394266  95.184  -67.350  53.227  1
394267  95.222  -67.344  53.207  1
394268  95.260  -67.339  53.186  1
394269  95.304  -67.339  53.166  1
394270  95.351  -67.342  53.146  1
394271  95.398  -67.344  53.126  1
394272  95.446  -67.348  53.106  1
394273  95.493  -67.351  53.085  1
394274  95.540  -67.353  53.066  1
394275  95.587  -67.356  53.046  1
394276  95.634  -67.359  53.027  1
394277  95.677  -67.365  53.007  1
394278  95.716  -67.374  52.987  1
394279  95.756  -67.383  52.967  1
394280  95.796  -67.392  52.948  1
394281  95.835  -67.401  52.926  1
394282  95.875  -67.410  52.906  1
394283  95.914  -67.419  52.884  1
394284  95.953  -67.428  52.862  1
394285  95.993  -67.436  52.840  1
394286  96.022  -67.446  52.817  1
394287  96.047  -67.457  52.792  1
394288  96.072  -67.468  52.767  1
394289  96.097  -67.479  52.743  1
394290  96.124  -67.486  52.718  1
394291  96.157  -67.488  52.693  1
394292  96.189  -67.490  52.668  1
394293  96.221  -67.492  52.643  1
394294  96.253  -67.495  52.618  1
394295  96.285  -67.497  52.593  1
394296  96.317  -67.499  52.570  1
394297  96.349  -67.501  52.547  1
394298  96.382  -67.504  52.525  1
394299  96.414  -67.507  52.503  1
394300  96.448  -67.510  52.481  1
394301  96.480  -67.513  52.460  1
394302  96.513  -67.516  52.438  1
394303  96.546  -67.519  52.417  1
394304  96.579  -67.524  52.396  1
394305  96.612  -67.533  52.375  1
394306  96.646  -67.536  52.355  1
394307  96.679  -67.539  52.335  1
394308  96.712  -67.542  52.315  1
394309  96.745  -67.545  52.297  1
394310  96.779  -67.548  52.281  1
394311  96.812  -67.553  52.265  1
394312  96.847  -67.556  52.248  1
394313  96.886  -67.559  52.231  1
394314  96.925  -67.566  52.216  1
394315  96.964  -67.572  52.201  1
394316  97.003  -67.578  52.188  1
394317  97.042  -67.584  52.175  1
394318  97.081  -67.590  52.162  1
394319  97.120  -67.596  52.148  1
394320  97.159  -67.602  52.134  1
394321  97.197  -67.608  52.119  1
394322  97.239  -67.614  52.103  1
394323  97.287  -67.620  52.083  1
394324  97.334  -67.627  52.063  1
394325  97.381  -67.633  52.040  1
394326  97.429  -67.639  52.012  1
394327  97.467  -67.639  51.984  1
394328  97.501  -67.636  51.952  1
394329  97.532  -67.636  51.919  1
394330  97.561  -67.638  51.886  1
394331  97.589  -67.640  51.854  1
394332  97.617  -67.642  51.823  1
394333  97.646  -67.645  51.793  1
394334  97.675  -67.648  51.762  1
394335  97.703  -67.650  51.732  1
394336  97.732  -67.652  51.701  1
394337  97.769  -67.655  51.668  1
394338  97.819  -67.660  51.632  1
394339  97.869  -67.664  51.593  1
394340  97.902  -67.669  51.552  1
394341  97.933  -67.674  51.509  1
394342  97.963  -67.680  51.465  1
394343  97.994  -67.685  51.425  1
394344  98.024  -67.690  51.387  1
394345  98.053  -67.695  51.348  1
394346  98.075  -67.692  51.307  1
394347  98.097  -67.691  51.267  1
394348  98.125  -67.696  51.225  1
394349  98.160  -67.716  51.182  1
394350  98.196  -67.734  51.138  1
394351  98.229  -67.743  51.090  1
394352  98.263  -67.751  51.042  1
394353  98.295  -67.760  50.993  1
394354  98.329  -67.768  50.943  1
394355  98.362  -67.777  50.893  1
394356  98.395  -67.785  50.841  1
394357  98.428  -67.794  50.789  1
394358  98.461  -67.802  50.738  1
394359  98.495  -67.811  50.691  1
394360  98.528  -67.820  50.645  1
394361  98.561  -67.828  50.599  1
394362  98.597  -67.838  50.551  1
394363  98.632  -67.847  50.502  1
394364  98.667  -67.857  50.452  1
394365  98.702  -67.865  50.403  1
394366  98.737  -67.874  50.356  1
394367  98.772  -67.883  50.309  1
394368  98.806  -67.891  50.262  1
394369  98.841  -67.900  50.219  1
394370  98.876  -67.909  50.177  1
394371  98.915  -67.921  50.135  1
394372  98.966  -67.928  50.090  1
394373  99.016  -67.933  50.041  1
394374  99.066  -67.933  49.993  1
394375  99.115  -67.932  49.944  1
394376  99.164  -67.932  49.893  1
394377  99.214  -67.931  49.842  1
394378  99.253  -67.929  49.789  1
394379  99.267  -67.921  49.739  1
394380  99.280  -67.912  49.689  1
394381  99.294  -67.903  49.639  1
394382  99.317  -67.899  49.593  1
394383  99.351  -67.900  49.549  1
394384  99.384  -67.901  49.504  1
394385  99.415  -67.909  49.459  1
394386  99.441  -67.932  49.413  1
394387  99.481  -67.955  49.369  1
394388  99.547  -67.979  49.327  1
394389  99.593  -67.988  49.288  1
394390  99.633  -67.994  49.248  1
394391  99.673  -68.000  49.204  1
394392  99.712  -68.006  49.159  1
394393  99.748  -68.015  49.114  1
394394  99.779  -68.025  49.069  1
394395  99.810  -68.035  49.024  1
394396  99.842  -68.045  48.981  1
394397  99.873  -68.055  48.938  1
394398  99.905  -68.065  48.896  1
394399  99.941  -68.072  48.854  1
394400  99.960  -68.063  48.811  1
394401  99.991  -68.099  48.768  1
394402  100.023  -68.137  48.725  1
394403  100.056  -68.176  48.681  1
394404  100.085  -68.184  48.636  1
394405  100.122  -68.184  48.592  1
394406  100.162  -68.182  48.548  1
394407  100.202  -68.180  48.503  1
394408  100.241  -68.178  48.460  1
394409  100.281  -68.175  48.416  1
394410  100.320  -68.174  48.374  1
394411  100.360  -68.172  48.331  1
394412  100.400  -68.169  48.288  1
394413  100.439  -68.168  48.244  1
394414  100.479  -68.166  48.201  1
394851  90.013  -67.431  54.894  1
394852  90.047  -67.440  54.896  1
394853  90.081  -67.450  54.902  1
394854  90.115  -67.460  54.910  1
394855  90.150  -67.469  54.919  1
394856  90.184  -67.479  54.928  1
394857  90.218  -67.488  54.938  1
394858  90.252  -67.498  54.948  1
394859  90.296  -67.503  54.959  1
394860  90.342  -67.507  54.972  1
394861  90.396  -67.495  54.987  1
394862  90.453  -67.477  54.998  1
394863  90.510  -67.460  55.005  1
394864  90.570  -67.458  55.011  1
394865  90.632  -67.458  55.009  1
394866  90.692  -67.459  55.004  1
394867  90.754  -67.460  54.996  1
394868  90.815  -67.460  54.985  1
394869  90.876  -67.460  54.975  1
394870  90.937  -67.461  54.965  1
394871  90.999  -67.461  54.958  1
394872  91.060  -67.462  54.954  1
394873  91.121  -67.463  54.952  1
394874  91.182  -67.464  54.954  1
394875  91.245  -67.461  54.956  1
394876  91.291  -67.452  54.958  1
394877  91.332  -67.445  54.960  1
394878  91.374  -67.438  54.957  1
394879  91.416  -67.430  54.950  1
394880  91.457  -67.423  54.942  1
394881  91.499  -67.417  54.932  1
394882  91.540  -67.410  54.923  1
394883  91.582  -67.403  54.918  1
394884  91.624  -67.395  54.910  1
394885  91.665  -67.388  54.900  1
394886  91.707  -67.382  54.887  1
394887  91.749  -67.375  54.872  1
394888  91.790  -67.367  54.855  1
394889  91.832  -67.360  54.837  1
394890  91.875  -67.357  54.818  1
394891  91.919  -67.360  54.800  1
394892  91.970  -67.364  54.780  1
394893  92.023  -67.368  54.760  1
394894  92.077  -67.372  54.739  1
394895  92.130  -67.376  54.717  1
394896  92.183  -67.379  54.692  1
394897  92.236  -67.383  54.668  1
394898  92.290  -67.387  54.644  1
394899  92.343  -67.391  54.620  1
394900  92.396  -67.395  54.597  1
394901  92.449  -67.398  54.573  1
394902  92.502  -67.402  54.549  1
394903  92.556  -67.406  54.524  1
394904  92.609  -67.410  54.500  1
394905  92.662  -67.413  54.475  1
394906  92.715  -67.417  54.450  1
394907  92.769  -67.421  54.426  1
394908  92.827  -67.428  54.404  1
394909  92.890  -67.439  54.386  1
394910  92.941  -67.433  54.373  1
394911  92.982  -67.416  54.363  1
394912  93.021  -67.404  54.353  1
394913  93.058  -67.403  54.342  1
394914  93.093  -67.401  54.330  1
394915  93.130  -67.399  54.317  1
394916  93.165  -67.398  54.302  1
394917  93.202  -67.396  54.286  1
394918  93.252  -67.392  54.266  1
394919  93.305  -67.386  54.245  1
394920  93.359  -67.381  54.223  1
394921  93.400  -67.383  54.203  1
394922  93.437  -67.388  54.186  1
394923  93.474  -67.392  54.173  1
394924  93.511  -67.396  54.163  1
394925  93.543  -67.392  54.153  1
394926  93.573  -67.385  54.142  1
394927  93.604  -67.379  54.129  1
394928  93.634  -67.373  54.113  1
394929  93.664  -67.366  54.093  1
394930  93.696  -67.360  54.071  1
394931  93.743  -67.357  54.047  1
394932  93.789  -67.352  54.023  1
394933  93.835  -67.355  54.001  1
394934  93.882  -67.360  53.979  1
394935  93.924  -67.364  53.958  1
394936  93.966  -67.369  53.937  1
394937  94.008  -67.373  53.915  1
394938  94.050  -67.377  53.893  1
394939  94.087  -67.373  53.871  1
394940  94.124  -67.366  53.849  1
394941  94.161  -67.360  53.827  1
394942  94.198  -67.354  53.803  1
394943  94.235  -67.348  53.779  1
394944  94.276  -67.345  53.753  1
394945  94.326  -67.350  53.726  1
394946  94.377  -67.355  53.696  1
394947  94.426  -67.360  53.668  1
394948  94.477  -67.365  53.644  1
394949  94.524  -67.369  53.622  1
394950  94.559  -67.367  53.602  1
394951  94.595  -67.365  53.586  1
394952  94.630  -67.363  53.571  1
394953  94.666  -67.361  53.557  1
394954  94.701  -67.359  53.545  1
394955  94.736  -67.357  53.533  1
394956  94.771  -67.355  53.521  1
394957  94.807  -67.354  53.507  1
394958  94.842  -67.351  53.491  1
394959  94.882  -67.351  53.470  1
394960  94.928  -67.354  53.440  1
394961  94.956  -67.344  53.403  1
394962  94.993  -67.339  53.366  1
394963  95.031  -67.334  53.331  1
394964  95.069  -67.329  53.303  1
394965  95.107  -67.323  53.278  1
394966  95.144  -67.317  53.254  1
394967  95.182  -67.312  53.231  1
394968  95.219  -67.307  53.211  1
394969  95.260  -67.304  53.190  1
394970  95.307  -67.307  53.171  1
394971  95.354  -67.309  53.152  1
394972  95.402  -67.312  53.132  1
394973  95.449  -67.315  53.113  1
394974  95.496  -67.317  53.092  1
394975  95.543  -67.320  53.073  1
394976  95.591  -67.323  53.054  1
394977  95.638  -67.326  53.034  1
394978  95.683  -67.330  53.015  1
394979  95.723  -67.339  52.995  1
394980  95.762  -67.348  52.975  1
394981  95.801  -67.357  52.956  1
394982  95.841  -67.366  52.935  1
394983  95.880  -67.375  52.915  1
394984  95.920  -67.384  52.893  1
394985  95.957  -67.394  52.870  1
394986  95.994  -67.404  52.847  1
394987  96.028  -67.404  52.823  1
394988  96.052  -67.414  52.798  1
394989  96.077  -67.426  52.773  1
394990  96.102  -67.436  52.748  1
394991  96.129  -67.444  52.721  1
394992  96.158  -67.450  52.696  1
394993  96.189  -67.453  52.670  1
394994  96.222  -67.455  52.643  1
394995  96.254  -67.457  52.617  1
394996  96.286  -67.460  52.593  1
394997  96.318  -67.462  52.568  1
394998  96.350  -67.464  52.545  1
394999  96.383  -67.467  52.522  1
395000  96.415  -67.470  52.500  1
395001  96.449  -67.473  52.478  1
395002  96.481  -67.476  52.456  1
395003  96.514  -67.479  52.435  1
395004  96.547  -67.482  52.413  1
395005  96.580  -67.486  52.393  1
395006  96.613  -67.491  52.372  1
395007  96.647  -67.494  52.352  1
395008  96.680  -67.498  52.332  1
395009  96.714  -67.502  52.312  1
395010  96.747  -67.506  52.294  1
395011  96.781  -67.510  52.278  1
395012  96.814  -67.514  52.261  1
395013  96.850  -67.517  52.245  1
395014  96.890  -67.517  52.227  1
395015  96.930  -67.521  52.210  1
395016  96.969  -67.527  52.193  1
395017  97.008  -67.533  52.178  1
395018  97.046  -67.539  52.164  1
395019  97.085  -67.545  52.149  1
395020  97.124  -67.551  52.134  1
395021  97.163  -67.558  52.118  1
395022  97.202  -67.564  52.102  1
395023  97.245  -67.570  52.086  1
395024  97.293  -67.576  52.068  1
395025  97.341  -67.581  52.048  1
395026  97.388  -67.587  52.025  1
395027  97.436  -67.593  51.999  1
395028  97.480  -67.597  51.971  1
395029  97.512  -67.597  51.940  1
395030  97.540  -67.599  51.907  1
395031  97.569  -67.602  51.873  1
395032  97.597  -67.604  51.839  1
395033  97.626  -67.606  51.806  1
395034  97.654  -67.609  51.774  1
395035  97.683  -67.611  51.743  1
395036  97.712  -67.614  51.711  1
395037  97.740  -67.616  51.680  1
395038  97.775  -67.619  51.646  1
395039  97.825  -67.623  51.610  1
395040  97.875  -67.627  51.572  1
395041  97.917  -67.632  51.532  1
395042  97.947  -67.637  51.491  1
395043  97.978  -67.642  51.449  1
395044  98.008  -67.648  51.409  1
395045  98.038  -67.654  51.371  1
395046  98.061  -67.652  51.329  1
395047  98.083  -67.650  51.288  1
395048  98.105  -67.648  51.247  1
395049  98.133  -67.655  51.207  1
395050  98.169  -67.674  51.165  1
395051  98.205  -67.692  51.121  1
395052  98.239  -67.707  51.075  1
395053  98.272  -67.715  51.028  1
395054  98.305  -67.724  50.980  1
395055  98.339  -67.732  50.931  1
395056  98.372  -67.741  50.880  1
395057  98.405  -67.749  50.829  1
395058  98.438  -67.758  50.778  1
395059  98.472  -67.767  50.727  1
395060  98.505  -67.775  50.679  1
395061  98.537  -67.783  50.632  1
395062  98.558  -67.786  50.586  1
395063  98.596  -67.792  50.539  1
395064  98.632  -67.799  50.491  1
395065  98.667  -67.808  50.442  1
395066  98.702  -67.816  50.394  1
395067  98.736  -67.825  50.346  1
395068  98.771  -67.833  50.300  1
395069  98.806  -67.842  50.254  1
395070  98.841  -67.851  50.208  1
395071  98.878  -67.870  50.164  1
395072  98.929  -67.877  50.119  1
395073  98.980  -67.884  50.075  1
395074  99.031  -67.892  50.026  1
395075  99.082  -67.899  49.977  1
395076  99.132  -67.904  49.929  1
395077  99.182  -67.903  49.880  1
395078  99.231  -67.903  49.831  1
395079  99.280  -67.902  49.781  1
395080  99.324  -67.901  49.731  1
395081  99.337  -67.893  49.681  1
395082  99.351  -67.884  49.632  1
395083  99.364  -67.875  49.584  1
395084  99.377  -67.867  49.538  1
395085  99.391  -67.858  49.494  1
395086  99.422  -67.860  49.450  1
395087  99.460  -67.883  49.404  1
395088  99.502  -67.905  49.361  1
395089  99.550  -67.927  49.319  1
395090  99.600  -67.940  49.278  1
395091  99.640  -67.946  49.236  1
395092  99.688  -67.944  49.192  1
395093  99.713  -67.964  49.147  1
395094  99.738  -67.983  49.104  1
395095  99.768  -67.996  49.060  1
395096  99.799  -68.006  49.016  1
395097  99.831  -68.015  48.973  1
395098  99.862  -68.025  48.930  1
395099  99.905  -68.037  48.888  1
395100  99.939  -68.040  48.846  1
395101  99.962  -68.044  48.804  1
395102  99.994  -68.083  48.761  1
395103  100.026  -68.122  48.719  1
395104  100.056  -68.140  48.676  1
395105  100.092  -68.140  48.630  1
395106  100.131  -68.138  48.586  1
395107  100.171  -68.136  48.541  1
395108  100.211  -68.134  48.497  1
395109  100.250  -68.131  48.453  1
395110  100.290  -68.130  48.410  1
395111  100.330  -68.128  48.368  1
395112  100.369  -68.125  48.325  1
395113  100.409  -68.124  48.283  1
395114  100.449  -68.122  48.239  1
395115  100.488  -68.119  48.196  1
395552  90.005  -67.382  54.898  1
395553  90.039  -67.392  54.902  1
395554  90.074  -67.401  54.908  1
395555  90.108  -67.411  54.916  1
395556  90.142  -67.420  54.926  1
395557  90.176  -67.430  54.935  1
395558  90.211  -67.440  54.945  1
395559  90.252  -67.446  54.956  1
395560  90.298  -67.450  54.966  1
395561  90.347  -67.448  54.980  1
395562  90.404  -67.430  54.993  1
395563  90.461  -67.413  55.004  1
395564  90.517  -67.395  55.010  1
395565  90.578  -67.395  55.015  1
395566  90.640  -67.395  55.011  1
395567  90.700  -67.395  55.005  1
395568  90.762  -67.396  54.998  1
395569  90.823  -67.396  54.988  1
395570  90.884  -67.397  54.980  1
395571  90.945  -67.398  54.973  1
395572  91.007  -67.398  54.968  1
395573  91.068  -67.398  54.967  1
395574  91.129  -67.399  54.969  1
395575  91.190  -67.400  54.974  1
395576  91.248  -67.407  54.979  1
395577  91.291  -67.404  54.983  1
395578  91.332  -67.398  54.983  1
395579  91.374  -67.390  54.979  1
395580  91.416  -67.383  54.971  1
395581  91.457  -67.376  54.960  1
395582  91.499  -67.370  54.949  1
395583  91.540  -67.362  54.939  1
395584  91.582  -67.355  54.932  1
395585  91.624  -67.348  54.924  1
395586  91.666  -67.341  54.914  1
395587  91.707  -67.335  54.901  1
395588  91.749  -67.327  54.885  1
395589  91.791  -67.320  54.868  1
395590  91.832  -67.313  54.850  1
395591  91.876  -67.314  54.831  1
395592  91.921  -67.318  54.812  1
395593  91.967  -67.321  54.792  1
395594  92.021  -67.325  54.772  1
395595  92.074  -67.329  54.751  1
395596  92.127  -67.332  54.729  1
395597  92.180  -67.336  54.704  1
395598  92.234  -67.340  54.680  1
395599  92.287  -67.344  54.655  1
395600  92.340  -67.348  54.630  1
395601  92.393  -67.351  54.606  1
395602  92.447  -67.355  54.583  1
395603  92.500  -67.359  54.558  1
395604  92.553  -67.363  54.533  1
395605  92.606  -67.366  54.510  1
395606  92.659  -67.370  54.485  1
395607  92.713  -67.374  54.461  1
395608  92.771  -67.381  54.437  1
395609  92.834  -67.392  54.416  1
395610  92.897  -67.402  54.398  1
395611  92.942  -67.390  54.385  1
395612  92.984  -67.373  54.375  1
395613  93.025  -67.355  54.366  1
395614  93.063  -67.350  54.356  1
395615  93.098  -67.348  54.344  1
395616  93.135  -67.347  54.330  1
395617  93.170  -67.345  54.313  1
395618  93.207  -67.344  54.293  1
395619  93.257  -67.339  54.270  1
395620  93.310  -67.334  54.246  1
395621  93.363  -67.329  54.223  1
395622  93.400  -67.333  54.203  1
395623  93.437  -67.338  54.186  1
395624  93.474  -67.342  54.175  1
395625  93.511  -67.347  54.164  1
395626  93.544  -67.345  54.153  1
395627  93.574  -67.338  54.141  1
395628  93.605  -67.332  54.127  1
395629  93.635  -67.326  54.111  1
395630  93.665  -67.319  54.093  1
395631  93.696  -67.313  54.072  1
395632  93.727  -67.307  54.048  1
395633  93.773  -67.303  54.024  1
395634  93.820  -67.302  54.003  1
395635  93.866  -67.307  53.983  1
395636  93.908  -67.311  53.963  1
395637  93.949  -67.316  53.942  1
395638  93.992  -67.320  53.920  1
395639  94.034  -67.324  53.899  1
395640  94.073  -67.323  53.878  1
395641  94.110  -67.317  53.857  1
395642  94.147  -67.310  53.835  1
395643  94.184  -67.304  53.812  1
395644  94.223  -67.301  53.787  1
395645  94.273  -67.306  53.760  1
395646  94.324  -67.310  53.733  1
395647  94.373  -67.316  53.704  1
395648  94.423  -67.320  53.678  1
395649  94.474  -67.326  53.654  1
395650  94.517  -67.327  53.631  1
395651  94.552  -67.326  53.610  1
395652  94.587  -67.323  53.593  1
395653  94.623  -67.321  53.578  1
395654  94.658  -67.319  53.565  1
395655  94.693  -67.317  53.552  1
395656  94.729  -67.316  53.540  1
395657  94.764  -67.313  53.525  1
395658  94.802  -67.312  53.509  1
395659  94.841  -67.312  53.489  1
395660  94.882  -67.311  53.465  1
395661  94.936  -67.319  53.434  1
395662  94.963  -67.310  53.399  1
395663  94.991  -67.301  53.365  1
395664  95.029  -67.296  53.332  1
395665  95.066  -67.290  53.305  1
395666  95.104  -67.285  53.280  1
395667  95.141  -67.279  53.258  1
395668  95.179  -67.274  53.236  1
395669  95.216  -67.269  53.216  1
395670  95.263  -67.271  53.197  1
395671  95.311  -67.274  53.178  1
395672  95.358  -67.276  53.159  1
395673  95.405  -67.279  53.140  1
395674  95.452  -67.282  53.122  1
395675  95.499  -67.285  53.102  1
395676  95.547  -67.288  53.083  1
395677  95.594  -67.290  53.064  1
395678  95.641  -67.293  53.045  1
395679  95.688  -67.296  53.025  1
395680  95.728  -67.304  53.005  1
395681  95.768  -67.313  52.986  1
395682  95.807  -67.323  52.966  1
395683  95.846  -67.332  52.945  1
395684  95.885  -67.341  52.925  1
395685  95.921  -67.351  52.902  1
395686  95.959  -67.361  52.879  1
395687  95.995  -67.370  52.855  1
395688  96.030  -67.366  52.831  1
395689  96.058  -67.372  52.805  1
395690  96.083  -67.382  52.779  1
395691  96.108  -67.393  52.754  1
395692  96.135  -67.401  52.726  1
395693  96.162  -67.408  52.700  1
395694  96.190  -67.415  52.673  1
395695  96.223  -67.417  52.645  1
395696  96.254  -67.420  52.618  1
395697  96.287  -67.423  52.593  1
395698  96.319  -67.425  52.568  1
395699  96.351  -67.427  52.543  1
395700  96.384  -67.430  52.520  1
395701  96.417  -67.433  52.497  1
395702  96.450  -67.435  52.475  1
395703  96.482  -67.439  52.453  1
395704  96.516  -67.442  52.432  1
395705  96.548  -67.445  52.410  1
395706  96.581  -67.448  52.390  1
395707  96.615  -67.451  52.370  1
395708  96.649  -67.455  52.350  1
395709  96.682  -67.459  52.330  1
395710  96.716  -67.463  52.310  1
395711  96.749  -67.467  52.292  1
395712  96.783  -67.471  52.275  1
395713  96.816  -67.475  52.260  1
395714  96.854  -67.477  52.244  1
395715  96.894  -67.476  52.225  1
395716  96.934  -67.476  52.205  1
395717  96.973  -67.482  52.187  1
395718  97.012  -67.489  52.170  1
395719  97.051  -67.495  52.154  1
395720  97.090  -67.501  52.138  1
395721  97.129  -67.507  52.122  1
395722  97.168  -67.513  52.105  1
395723  97.207  -67.519  52.088  1
395724  97.251  -67.525  52.070  1
395725  97.299  -67.531  52.053  1
395726  97.347  -67.536  52.035  1
395727  97.394  -67.542  52.012  1
395728  97.442  -67.548  51.987  1
395729  97.488  -67.555  51.959  1
395730  97.519  -67.560  51.929  1
395731  97.548  -67.563  51.896  1
395732  97.577  -67.565  51.861  1
395733  97.605  -67.567  51.827  1
395734  97.634  -67.570  51.792  1
395735  97.663  -67.573  51.758  1
395736  97.691  -67.575  51.726  1
395737  97.720  -67.577  51.694  1
395738  97.748  -67.580  51.661  1
395739  97.781  -67.583  51.628  1
395740  97.831  -67.586  51.591  1
395741  97.881  -67.591  51.552  1
395742  97.932  -67.595  51.514  1
395743  97.962  -67.600  51.474  1
395744  97.992  -67.605  51.432  1
395745  98.022  -67.611  51.393  1
395746  98.046  -67.611  51.354  1
395747  98.069  -67.608  51.311  1
395748  98.091  -67.607  51.269  1
395749  98.113  -67.605  51.228  1
395750  98.141  -67.612  51.187  1
395751  98.177  -67.631  51.147  1
395752  98.213  -67.651  51.104  1
395753  98.249  -67.670  51.059  1
395754  98.282  -67.679  51.013  1
395755  98.315  -67.688  50.966  1
395756  98.349  -67.696  50.918  1
395757  98.382  -67.705  50.866  1
395758  98.415  -67.714  50.816  1
395759  98.448  -67.722  50.766  1
395760  98.481  -67.730  50.716  1
395761  98.510  -67.737  50.667  1
395762  98.530  -67.740  50.619  1
395763  98.553  -67.743  50.574  1
395764  98.590  -67.749  50.528  1
395765  98.628  -67.754  50.481  1
395766  98.665  -67.759  50.434  1
395767  98.701  -67.767  50.388  1
395768  98.736  -67.776  50.341  1
395769  98.771  -67.784  50.294  1
395770  98.805  -67.793  50.249  1
395771  98.841  -67.818  50.201  1
395772  98.891  -67.826  50.153  1
395773  98.943  -67.833  50.107  1
395774  98.994  -67.840  50.061  1
395775  99.045  -67.848  50.011  1
395776  99.095  -67.855  49.963  1
395777  99.146  -67.862  49.915  1
395778  99.198  -67.870  49.866  1
395779  99.248  -67.874  49.819  1
395780  99.297  -67.874  49.772  1
395781  99.347  -67.874  49.723  1
395782  99.394  -67.873  49.673  1
395783  99.408  -67.865  49.625  1
395784  99.421  -67.856  49.576  1
395785  99.434  -67.847  49.531  1
395786  99.448  -67.839  49.487  1
395787  99.465  -67.833  49.443  1
395788  99.503  -67.840  49.398  1
395789  99.542  -67.847  49.355  1
395790  99.572  -67.871  49.312  1
395791  99.630  -67.871  49.269  1
395792  99.655  -67.891  49.225  1
395793  99.680  -67.910  49.181  1
395794  99.705  -67.930  49.137  1
395795  99.730  -67.949  49.093  1
395796  99.757  -67.966  49.051  1
395797  99.788  -67.976  49.007  1
395798  99.821  -67.986  48.964  1
395799  99.864  -67.997  48.922  1
395800  99.907  -68.009  48.880  1
395801  99.937  -68.009  48.838  1
395802  99.964  -68.028  48.796  1
395803  99.996  -68.067  48.753  1
395804  100.027  -68.095  48.712  1
395805  100.061  -68.096  48.670  1
395806  100.101  -68.094  48.624  1
395807  100.141  -68.092  48.579  1
395808  100.180  -68.090  48.534  1
395809  100.220  -68.087  48.490  1
395810  100.260  -68.086  48.447  1
395811  100.299  -68.084  48.405  1
395812  100.339  -68.081  48.362  1
395813  100.379  -68.080  48.320  1
395814  100.418  -68.078  48.277  1
395815  100.458  -68.075  48.234  1
395816  100.497  -68.074  48.192  1
396253  89.997  -67.334  54.901  1
396254  90.031  -67.344  54.906  1
396255  90.065  -67.353  54.912  1
396256  90.100  -67.363  54.920  1
396257  90.134  -67.372  54.931  1
396258  90.168  -67.382  54.941  1
396259  90.208  -67.388  54.951  1
396260  90.254  -67.392  54.961  1
396261  90.301  -67.397  54.972  1
396262  90.355  -67.383  54.986  1
396263  90.412  -67.366  54.999  1
396264  90.468  -67.348  55.008  1
396265  90.525  -67.331  55.014  1
396266  90.586  -67.331  55.017  1
396267  90.648  -67.332  55.013  1
396268  90.709  -67.332  55.007  1
396269  90.770  -67.332  55.001  1
396270  90.831  -67.333  54.992  1
396271  90.892  -67.333  54.987  1
396272  90.953  -67.334  54.982  1
396273  91.015  -67.335  54.980  1
396274  91.076  -67.335  54.982  1
396275  91.135  -67.341  54.988  1
396276  91.194  -67.348  54.996  1
396277  91.248  -67.355  55.002  1
396278  91.291  -67.357  55.006  1
396279  91.332  -67.350  55.004  1
396280  91.374  -67.343  54.999  1
396281  91.416  -67.336  54.989  1
396282  91.457  -67.329  54.977  1
396283  91.499  -67.322  54.964  1
396284  91.541  -67.315  54.955  1
396285  91.583  -67.308  54.946  1
396286  91.624  -67.301  54.937  1
396287  91.666  -67.294  54.928  1
396288  91.708  -67.287  54.915  1
396289  91.749  -67.280  54.900  1
396290  91.791  -67.273  54.882  1
396291  91.833  -67.268  54.864  1
396292  91.878  -67.271  54.845  1
396293  91.922  -67.275  54.826  1
396294  91.967  -67.279  54.804  1
396295  92.018  -67.282  54.784  1
396296  92.071  -67.286  54.763  1
396297  92.125  -67.289  54.741  1
396298  92.178  -67.293  54.716  1
396299  92.231  -67.297  54.691  1
396300  92.284  -67.301  54.665  1
396301  92.338  -67.304  54.640  1
396302  92.391  -67.308  54.617  1
396303  92.444  -67.312  54.593  1
396304  92.497  -67.316  54.568  1
396305  92.551  -67.319  54.543  1
396306  92.604  -67.323  54.521  1
396307  92.657  -67.327  54.496  1
396308  92.715  -67.334  54.473  1
396309  92.778  -67.344  54.451  1
396310  92.841  -67.355  54.430  1
396311  92.903  -67.363  54.413  1
396312  92.944  -67.346  54.399  1
396313  92.986  -67.329  54.389  1
396314  93.027  -67.311  54.380  1
396315  93.067  -67.297  54.372  1
396316  93.103  -67.296  54.360  1
396317  93.139  -67.294  54.344  1
396318  93.176  -67.292  54.325  1
396319  93.211  -67.291  54.301  1
396320  93.262  -67.286  54.275  1
396321  93.315  -67.281  54.248  1
396322  93.362  -67.279  54.224  1
396323  93.399  -67.284  54.204  1
396324  93.436  -67.288  54.187  1
396325  93.473  -67.293  54.174  1
396326  93.510  -67.297  54.162  1
396327  93.545  -67.298  54.151  1
396328  93.575  -67.291  54.138  1
396329  93.606  -67.285  54.125  1
396330  93.636  -67.279  54.109  1
396331  93.667  -67.272  54.092  1
396332  93.697  -67.266  54.072  1
396333  93.727  -67.260  54.048  1
396334  93.758  -67.254  54.025  1
396335  93.804  -67.250  54.006  1
396336  93.850  -67.254  53.987  1
396337  93.892  -67.258  53.968  1
396338  93.933  -67.263  53.949  1
396339  93.976  -67.267  53.928  1
396340  94.017  -67.271  53.907  1
396341  94.059  -67.274  53.886  1
396342  94.096  -67.267  53.866  1
396343  94.132  -67.261  53.845  1
396344  94.171  -67.256  53.821  1
396345  94.220  -67.261  53.796  1
396346  94.271  -67.266  53.769  1
396347  94.321  -67.271  53.742  1
396348  94.370  -67.276  53.715  1
396349  94.421  -67.281  53.689  1
396350  94.471  -67.286  53.664  1
396351  94.509  -67.285  53.641  1
396352  94.545  -67.284  53.619  1
396353  94.580  -67.282  53.601  1
396354  94.615  -67.279  53.585  1
396355  94.650  -67.278  53.571  1
396356  94.686  -67.276  53.558  1
396357  94.721  -67.274  53.543  1
396358  94.761  -67.273  53.525  1
396359  94.801  -67.272  53.506  1
396360  94.841  -67.272  53.483  1
396361  94.883  -67.273  53.457  1
396362  94.939  -67.282  53.426  1
396363  94.975  -67.279  53.394  1
396364  94.996  -67.266  53.362  1
396365  95.026  -67.258  53.333  1
396366  95.063  -67.252  53.306  1
396367  95.101  -67.247  53.284  1
396368  95.138  -67.241  53.262  1
396369  95.176  -67.236  53.242  1
396370  95.219  -67.235  53.223  1
396371  95.267  -67.238  53.204  1
396372  95.314  -67.241  53.186  1
396373  95.361  -67.244  53.167  1
396374  95.408  -67.247  53.149  1
396375  95.456  -67.249  53.132  1
396376  95.503  -67.252  53.113  1
396377  95.550  -67.255  53.094  1
396378  95.597  -67.257  53.075  1
396379  95.644  -67.260  53.056  1
396380  95.692  -67.263  53.036  1
396381  95.734  -67.269  53.017  1
396382  95.773  -67.279  52.997  1
396383  95.812  -67.288  52.976  1
396384  95.849  -67.298  52.957  1
396385  95.886  -67.309  52.935  1
396386  95.923  -67.319  52.913  1
396387  95.960  -67.329  52.889  1
396388  95.996  -67.335  52.866  1
396389  96.031  -67.331  52.841  1
396390  96.063  -67.329  52.815  1
396391  96.088  -67.340  52.788  1
396392  96.113  -67.351  52.761  1
396393  96.141  -67.358  52.734  1
396394  96.168  -67.366  52.707  1
396395  96.195  -67.373  52.678  1
396396  96.223  -67.380  52.650  1
396397  96.255  -67.382  52.622  1
396398  96.288  -67.385  52.595  1
396399  96.319  -67.387  52.569  1
396400  96.352  -67.390  52.544  1
396401  96.385  -67.393  52.520  1
396402  96.418  -67.396  52.497  1
396403  96.451  -67.398  52.474  1
396404  96.483  -67.401  52.452  1
396405  96.516  -67.405  52.430  1
396406  96.549  -67.409  52.409  1
396407  96.583  -67.411  52.390  1
396408  96.617  -67.412  52.370  1
396409  96.651  -67.416  52.350  1
396410  96.684  -67.420  52.330  1
396411  96.718  -67.424  52.312  1
396412  96.751  -67.428  52.293  1
396413  96.785  -67.432  52.277  1
396414  96.818  -67.436  52.260  1
396415  96.857  -67.437  52.243  1
396416  96.897  -67.437  52.225  1
396417  96.938  -67.437  52.205  1
396418  96.977  -67.438  52.186  1
396419  97.017  -67.444  52.168  1
396420  97.055  -67.450  52.150  1
396421  97.094  -67.456  52.134  1
396422  97.133  -67.462  52.115  1
396423  97.172  -67.468  52.097  1
396424  97.211  -67.475  52.078  1
396425  97.256  -67.480  52.059  1
396426  97.304  -67.486  52.040  1
396427  97.352  -67.492  52.021  1
396428  97.400  -67.498  52.000  1
396429  97.447  -67.504  51.975  1
396430  97.488  -67.511  51.947  1
396431  97.518  -67.517  51.917  1
396432  97.550  -67.522  51.885  1
396433  97.583  -67.527  51.851  1
396434  97.614  -67.531  51.819  1
396435  97.642  -67.534  51.784  1
396436  97.671  -67.536  51.750  1
396437  97.699  -67.539  51.717  1
396438  97.728  -67.541  51.684  1
396439  97.756  -67.543  51.652  1
396440  97.788  -67.546  51.616  1
396441  97.838  -67.550  51.578  1
396442  97.888  -67.554  51.538  1
396443  97.938  -67.558  51.498  1
396444  97.976  -67.563  51.458  1
396445  98.007  -67.568  51.417  1
396446  98.032  -67.570  51.377  1
396447  98.054  -67.567  51.338  1
396448  98.076  -67.565  51.295  1
396449  98.098  -67.564  51.253  1
396450  98.121  -67.561  51.211  1
396451  98.150  -67.570  51.169  1
396452  98.185  -67.589  51.128  1
396453  98.221  -67.608  51.088  1
396454  98.257  -67.627  51.043  1
396455  98.292  -67.643  50.997  1
396456  98.325  -67.652  50.950  1
396457  98.358  -67.661  50.902  1
396458  98.391  -67.669  50.851  1
396459  98.425  -67.677  50.801  1
396460  98.458  -67.686  50.751  1
396461  98.482  -67.690  50.703  1
396462  98.502  -67.693  50.656  1
396463  98.522  -67.696  50.609  1
396464  98.547  -67.700  50.563  1
396465  98.584  -67.705  50.519  1
396466  98.622  -67.711  50.475  1
396467  98.660  -67.716  50.431  1
396468  98.697  -67.721  50.386  1
396469  98.735  -67.727  50.340  1
396470  98.770  -67.735  50.294  1
396471  98.803  -67.767  50.248  1
396472  98.855  -67.774  50.198  1
396473  98.906  -67.782  50.148  1
396474  98.956  -67.789  50.098  1
396475  99.007  -67.796  50.049  1
396476  99.058  -67.804  49.999  1
396477  99.109  -67.811  49.951  1
396478  99.160  -67.818  49.903  1
396479  99.211  -67.826  49.855  1
396480  99.262  -67.833  49.809  1
396481  99.313  -67.840  49.761  1
396482  99.364  -67.846  49.713  1
396483  99.413  -67.845  49.664  1
396484  99.462  -67.845  49.616  1
396485  99.478  -67.837  49.572  1
396486  99.491  -67.828  49.528  1
396487  99.505  -67.819  49.485  1
396488  99.528  -67.817  49.443  1
396489  99.567  -67.824  49.399  1
396490  99.605  -67.831  49.352  1
396491  99.635  -67.837  49.306  1
396492  99.657  -67.840  49.261  1
396493  99.672  -67.858  49.218  1
396494  99.687  -67.877  49.173  1
396495  99.701  -67.896  49.129  1
396496  99.722  -67.915  49.085  1
396497  99.747  -67.934  49.042  1
396498  99.780  -67.946  48.998  1
396499  99.823  -67.958  48.955  1
396500  99.866  -67.969  48.913  1
396501  99.909  -67.981  48.871  1
396502  99.935  -67.978  48.829  1
396503  99.966  -68.012  48.787  1
396504  99.998  -68.050  48.745  1
396505  100.031  -68.052  48.703  1
396506  100.071  -68.050  48.661  1
396507  100.110  -68.048  48.616  1
396508  100.150  -68.046  48.572  1
396509  100.190  -68.044  48.527  1
396510  100.229  -68.042  48.483  1
396511  100.269  -68.040  48.440  1
396512  100.308  -68.037  48.399  1
396513  100.348  -68.036  48.356  1
396514  100.388  -68.034  48.314  1
396515  100.427  -68.031  48.271  1
396516  100.467  -68.030  48.228  1
396517  100.506  -68.028  48.186  1
396954  89.989  -67.285  54.905  1
396955  90.023  -67.295  54.910  1
396956  90.057  -67.304  54.916  1
396957  90.092  -67.314  54.924  1
396958  90.126  -67.324  54.935  1
396959  90.164  -67.332  54.945  1
396960  90.211  -67.335  54.955  1
396961  90.257  -67.339  54.965  1
396962  90.306  -67.336  54.976  1
396963  90.363  -67.319  54.989  1
396964  90.419  -67.301  55.002  1
396965  90.476  -67.284  55.012  1
396966  90.533  -67.266  55.018  1
396967  90.594  -67.267  55.019  1
396968  90.656  -67.268  55.016  1
396969  90.717  -67.268  55.011  1
396970  90.778  -67.269  55.007  1
396971  90.839  -67.269  55.000  1
396972  90.900  -67.269  54.995  1
396973  90.961  -67.270  54.993  1
396974  91.021  -67.275  54.995  1
396975  91.080  -67.282  55.000  1
396976  91.139  -67.288  55.009  1
396977  91.198  -67.296  55.017  1
396978  91.248  -67.304  55.024  1
396979  91.291  -67.310  55.027  1
396980  91.333  -67.303  55.024  1
396981  91.375  -67.296  55.017  1
396982  91.416  -67.288  55.006  1
396983  91.458  -67.282  54.993  1
396984  91.500  -67.275  54.980  1
396985  91.541  -67.268  54.971  1
396986  91.583  -67.261  54.961  1
396987  91.625  -67.254  54.952  1
396988  91.666  -67.247  54.942  1
396989  91.708  -67.240  54.930  1
396990  91.749  -67.233  54.915  1
396991  91.791  -67.225  54.897  1
396992  91.835  -67.225  54.878  1
396993  91.879  -67.229  54.858  1
396994  91.924  -67.232  54.839  1
396995  91.968  -67.235  54.817  1
396996  92.015  -67.239  54.795  1
396997  92.069  -67.243  54.774  1
396998  92.122  -67.247  54.751  1
396999  92.175  -67.251  54.727  1
397000  92.228  -67.254  54.702  1
397001  92.282  -67.258  54.677  1
397002  92.335  -67.262  54.652  1
397003  92.388  -67.266  54.629  1
397004  92.441  -67.269  54.605  1
397005  92.495  -67.273  54.580  1
397006  92.548  -67.276  54.556  1
397007  92.601  -67.280  54.534  1
397008  92.658  -67.287  54.510  1
397009  92.722  -67.297  54.488  1
397010  92.785  -67.308  54.468  1
397011  92.848  -67.319  54.449  1
397012  92.905  -67.320  54.430  1
397013  92.946  -67.303  54.417  1
397014  92.988  -67.285  54.407  1
397015  93.029  -67.268  54.399  1
397016  93.070  -67.251  54.392  1
397017  93.109  -67.243  54.378  1
397018  93.144  -67.241  54.361  1
397019  93.181  -67.240  54.339  1
397020  93.216  -67.238  54.311  1
397021  93.267  -67.233  54.280  1
397022  93.321  -67.228  54.252  1
397023  93.362  -67.230  54.227  1
397024  93.399  -67.235  54.205  1
397025  93.436  -67.239  54.188  1
397026  93.473  -67.243  54.174  1
397027  93.510  -67.247  54.160  1
397028  93.546  -67.251  54.148  1
397029  93.577  -67.245  54.135  1
397030  93.607  -67.238  54.122  1
397031  93.637  -67.232  54.107  1
397032  93.668  -67.225  54.090  1
397033  93.698  -67.219  54.071  1
397034  93.729  -67.213  54.048  1
397035  93.759  -67.207  54.027  1
397036  93.789  -67.200  54.009  1
397037  93.834  -67.201  53.992  1
397038  93.875  -67.205  53.974  1
397039  93.917  -67.210  53.955  1
397040  93.959  -67.214  53.936  1
397041  94.001  -67.218  53.916  1
397042  94.043  -67.222  53.897  1
397043  94.081  -67.218  53.877  1
397044  94.118  -67.212  53.856  1
397045  94.168  -67.216  53.832  1
397046  94.217  -67.222  53.806  1
397047  94.268  -67.226  53.780  1
397048  94.318  -67.232  53.753  1
397049  94.368  -67.236  53.728  1
397050  94.418  -67.241  53.702  1
397051  94.466  -67.246  53.677  1
397052  94.502  -67.244  53.653  1
397053  94.537  -67.241  53.629  1
397054  94.572  -67.240  53.609  1
397055  94.608  -67.238  53.592  1
397056  94.643  -67.236  53.577  1
397057  94.680  -67.235  53.561  1
397058  94.720  -67.234  53.543  1
397059  94.761  -67.234  53.522  1
397060  94.801  -67.233  53.499  1
397061  94.841  -67.233  53.475  1
397062  94.886  -67.236  53.447  1
397063  94.943  -67.245  53.417  1
397064  94.987  -67.247  53.388  1
397065  95.009  -67.235  53.360  1
397066  95.031  -67.223  53.334  1
397067  95.060  -67.214  53.309  1
397068  95.098  -67.209  53.288  1
397069  95.136  -67.204  53.268  1
397070  95.176  -67.200  53.249  1
397071  95.223  -67.203  53.231  1
397072  95.270  -67.206  53.212  1
397073  95.317  -67.208  53.194  1
397074  95.365  -67.211  53.177  1
397075  95.412  -67.213  53.160  1
397076  95.459  -67.216  53.142  1
397077  95.507  -67.219  53.124  1
397078  95.553  -67.222  53.106  1
397079  95.601  -67.225  53.087  1
397080  95.648  -67.228  53.068  1
397081  95.695  -67.230  53.048  1
397082  95.740  -67.235  53.029  1
397083  95.776  -67.245  53.009  1
397084  95.813  -67.256  52.988  1
397085  95.850  -67.266  52.969  1
397086  95.887  -67.276  52.946  1
397087  95.924  -67.287  52.924  1
397088  95.961  -67.297  52.901  1
397089  95.997  -67.300  52.878  1
397090  96.032  -67.295  52.852  1
397091  96.066  -67.291  52.825  1
397092  96.094  -67.297  52.798  1
397093  96.119  -67.308  52.771  1
397094  96.146  -67.316  52.743  1
397095  96.173  -67.323  52.714  1
397096  96.200  -67.331  52.685  1
397097  96.228  -67.338  52.656  1
397098  96.256  -67.345  52.627  1
397099  96.288  -67.348  52.599  1
397100  96.320  -67.350  52.573  1
397101  96.353  -67.353  52.546  1
397102  96.386  -67.356  52.521  1
397103  96.419  -67.359  52.498  1
397104  96.452  -67.363  52.475  1
397105  96.484  -67.366  52.452  1
397106  96.517  -67.370  52.430  1
397107  96.550  -67.374  52.409  1
397108  96.584  -67.375  52.389  1
397109  96.619  -67.374  52.370  1
397110  96.653  -67.377  52.351  1
397111  96.686  -67.381  52.331  1
397112  96.720  -67.385  52.313  1
397113  96.753  -67.389  52.295  1
397114  96.787  -67.394  52.279  1
397115  96.820  -67.398  52.263  1
397116  96.860  -67.398  52.245  1
397117  96.900  -67.398  52.226  1
397118  96.941  -67.397  52.207  1
397119  96.981  -67.397  52.188  1
397120  97.021  -67.399  52.169  1
397121  97.060  -67.405  52.151  1
397122  97.099  -67.411  52.133  1
397123  97.138  -67.417  52.114  1
397124  97.177  -67.423  52.094  1
397125  97.216  -67.430  52.075  1
397126  97.262  -67.435  52.054  1
397127  97.310  -67.442  52.033  1
397128  97.358  -67.447  52.012  1
397129  97.406  -67.453  51.989  1
397130  97.449  -67.460  51.964  1
397131  97.488  -67.467  51.936  1
397132  97.516  -67.474  51.907  1
397133  97.549  -67.479  51.876  1
397134  97.581  -67.485  51.845  1
397135  97.614  -67.489  51.814  1
397136  97.646  -67.495  51.781  1
397137  97.678  -67.499  51.747  1
397138  97.708  -67.502  51.714  1
397139  97.736  -67.504  51.681  1
397140  97.764  -67.507  51.649  1
397141  97.794  -67.510  51.614  1
397142  97.844  -67.514  51.576  1
397143  97.894  -67.517  51.536  1
397144  97.944  -67.522  51.495  1
397145  97.991  -67.526  51.455  1
397146  98.018  -67.529  51.414  1
397147  98.040  -67.526  51.374  1
397148  98.062  -67.524  51.334  1
397149  98.084  -67.522  51.292  1
397150  98.106  -67.520  51.250  1
397151  98.129  -67.518  51.206  1
397152  98.158  -67.527  51.162  1
397153  98.194  -67.547  51.117  1
397154  98.230  -67.566  51.075  1
397155  98.266  -67.585  51.029  1
397156  98.301  -67.605  50.983  1
397157  98.335  -67.616  50.935  1
397158  98.368  -67.624  50.887  1
397159  98.402  -67.633  50.839  1
397160  98.434  -67.641  50.793  1
397161  98.454  -67.644  50.747  1
397162  98.474  -67.647  50.702  1
397163  98.494  -67.650  50.656  1
397164  98.514  -67.653  50.609  1
397165  98.541  -67.657  50.563  1
397166  98.579  -67.662  50.519  1
397167  98.617  -67.667  50.475  1
397168  98.654  -67.673  50.431  1
397169  98.692  -67.678  50.386  1
397170  98.732  -67.686  50.340  1
397171  98.766  -67.712  50.293  1
397172  98.812  -67.723  50.246  1
397173  98.865  -67.730  50.196  1
397174  98.917  -67.737  50.146  1
397175  98.969  -67.745  50.096  1
397176  99.021  -67.752  50.047  1
397177  99.072  -67.760  49.997  1
397178  99.123  -67.767  49.948  1
397179  99.174  -67.774  49.899  1
397180  99.225  -67.782  49.849  1
397181  99.276  -67.789  49.801  1
397182  99.327  -67.796  49.754  1
397183  99.378  -67.804  49.707  1
397184  99.429  -67.811  49.660  1
397185  99.479  -67.816  49.615  1
397186  99.528  -67.816  49.571  1
397187  99.548  -67.808  49.527  1
397188  99.562  -67.800  49.484  1
397189  99.591  -67.802  49.441  1
397190  99.630  -67.809  49.396  1
397191  99.654  -67.812  49.348  1
397192  99.676  -67.815  49.301  1
397193  99.698  -67.818  49.256  1
397194  99.717  -67.827  49.212  1
397195  99.732  -67.846  49.166  1
397196  99.747  -67.865  49.122  1
397197  99.761  -67.884  49.077  1
397198  99.772  -67.902  49.033  1
397199  99.782  -67.918  48.989  1
397200  99.825  -67.930  48.946  1
397201  99.868  -67.941  48.904  1
397202  99.911  -67.952  48.862  1
397203  99.936  -67.958  48.820  1
397204  99.969  -67.996  48.778  1
397205  100.001  -68.008  48.736  1
397206  100.040  -68.006  48.694  1
397207  100.080  -68.004  48.651  1
397208  100.119  -68.002  48.607  1
397209  100.159  -68.000  48.563  1
397210  100.199  -67.998  48.520  1
397211  100.238  -67.996  48.476  1
397212  100.278  -67.993  48.433  1
397213  100.318  -67.992  48.392  1
397214  100.357  -67.990  48.349  1
397215  100.397  -67.987  48.307  1
397216  100.436  -67.986  48.265  1
397217  100.476  -67.984  48.222  1
397218  100.516  -67.981  48.179  1
397655  89.981  -67.237  54.908  1
397656  90.016  -67.247  54.913  1
397657  90.050  -67.256  54.920  1
397658  90.084  -67.266  54.929  1
397659  90.120  -67.274  54.939  1
397660  90.167  -67.279  54.948  1
397661  90.213  -67.282  54.958  1
397662  90.259  -67.286  54.968  1
397663  90.314  -67.272  54.979  1
397664  90.371  -67.254  54.991  1
397665  90.428  -67.237  55.003  1
397666  90.484  -67.219  55.014  1
397667  90.541  -67.203  55.021  1
397668  90.602  -67.204  55.022  1
397669  90.664  -67.204  55.020  1
397670  90.725  -67.204  55.017  1
397671  90.786  -67.205  55.013  1
397672  90.847  -67.206  55.008  1
397673  90.907  -67.209  55.005  1
397674  90.966  -67.216  55.006  1
397675  91.025  -67.223  55.011  1
397676  91.084  -67.230  55.020  1
397677  91.143  -67.237  55.031  1
397678  91.202  -67.244  55.038  1
397679  91.247  -67.251  55.042  1
397680  91.291  -67.260  55.043  1
397681  91.333  -67.256  55.039  1
397682  91.375  -67.248  55.030  1
397683  91.417  -67.241  55.019  1
397684  91.458  -67.235  55.008  1
397685  91.500  -67.228  54.997  1
397686  91.541  -67.220  54.987  1
397687  91.583  -67.213  54.977  1
397688  91.625  -67.207  54.967  1
397689  91.666  -67.200  54.956  1
397690  91.708  -67.193  54.944  1
397691  91.750  -67.185  54.929  1
397692  91.792  -67.178  54.911  1
397693  91.836  -67.182  54.892  1
397694  91.881  -67.185  54.872  1
397695  91.925  -67.189  54.851  1
397696  91.970  -67.192  54.828  1
397697  92.014  -67.196  54.806  1
397698  92.066  -67.200  54.784  1
397699  92.120  -67.204  54.761  1
397700  92.172  -67.207  54.737  1
397701  92.226  -67.211  54.713  1
397702  92.279  -67.215  54.689  1
397703  92.333  -67.219  54.664  1
397704  92.385  -67.222  54.641  1
397705  92.439  -67.226  54.617  1
397706  92.492  -67.230  54.593  1
397707  92.545  -67.234  54.571  1
397708  92.602  -67.240  54.550  1
397709  92.665  -67.251  54.527  1
397710  92.729  -67.261  54.507  1
397711  92.792  -67.272  54.487  1
397712  92.855  -67.282  54.468  1
397713  92.906  -67.276  54.449  1
397714  92.948  -67.260  54.434  1
397715  92.989  -67.242  54.423  1
397716  93.030  -67.225  54.416  1
397717  93.072  -67.207  54.409  1
397718  93.114  -67.191  54.395  1
397719  93.149  -67.188  54.376  1
397720  93.185  -67.187  54.351  1
397721  93.221  -67.185  54.322  1
397722  93.272  -67.181  54.289  1
397723  93.324  -67.176  54.259  1
397724  93.361  -67.181  54.233  1
397725  93.398  -67.185  54.211  1
397726  93.435  -67.189  54.191  1
397727  93.472  -67.194  54.175  1
397728  93.509  -67.198  54.160  1
397729  93.546  -67.203  54.146  1
397730  93.578  -67.198  54.132  1
397731  93.608  -67.191  54.118  1
397732  93.639  -67.185  54.103  1
397733  93.669  -67.178  54.087  1
397734  93.699  -67.172  54.069  1
397735  93.730  -67.166  54.048  1
397736  93.760  -67.160  54.030  1
397737  93.791  -67.153  54.013  1
397738  93.826  -67.153  53.997  1
397739  93.864  -67.155  53.979  1
397740  93.903  -67.157  53.961  1
397741  93.943  -67.160  53.943  1
397742  93.985  -67.165  53.926  1
397743  94.027  -67.169  53.909  1
397744  94.066  -67.169  53.890  1
397745  94.115  -67.172  53.868  1
397746  94.165  -67.177  53.843  1
397747  94.215  -67.182  53.818  1
397748  94.265  -67.187  53.792  1
397749  94.315  -67.191  53.766  1
397750  94.365  -67.197  53.742  1
397751  94.415  -67.202  53.717  1
397752  94.459  -67.204  53.692  1
397753  94.494  -67.202  53.667  1
397754  94.530  -67.200  53.642  1
397755  94.565  -67.198  53.620  1
397756  94.600  -67.196  53.600  1
397757  94.640  -67.195  53.583  1
397758  94.680  -67.195  53.565  1
397759  94.720  -67.194  53.544  1
397760  94.760  -67.194  53.520  1
397761  94.800  -67.194  53.495  1
397762  94.840  -67.194  53.470  1
397763  94.890  -67.199  53.443  1
397764  94.947  -67.208  53.415  1
397765  94.999  -67.215  53.387  1
397766  95.021  -67.203  53.362  1
397767  95.043  -67.191  53.338  1
397768  95.064  -67.179  53.315  1
397769  95.096  -67.171  53.295  1
397770  95.133  -67.166  53.276  1
397771  95.179  -67.167  53.258  1
397772  95.227  -67.170  53.240  1
397773  95.273  -67.172  53.223  1
397774  95.321  -67.175  53.206  1
397775  95.368  -67.178  53.189  1
397776  95.415  -67.181  53.172  1
397777  95.462  -67.184  53.155  1
397778  95.509  -67.185  53.138  1
397779  95.555  -67.188  53.120  1
397780  95.601  -67.190  53.101  1
397781  95.648  -67.192  53.083  1
397782  95.694  -67.194  53.063  1
397783  95.738  -67.204  53.043  1
397784  95.777  -67.213  53.023  1
397785  95.815  -67.223  53.002  1
397786  95.851  -67.234  52.981  1
397787  95.888  -67.244  52.959  1
397788  95.925  -67.254  52.938  1
397789  95.962  -67.264  52.915  1
397790  95.997  -67.265  52.890  1
397791  96.032  -67.260  52.864  1
397792  96.067  -67.256  52.837  1
397793  96.099  -67.255  52.809  1
397794  96.124  -67.266  52.781  1
397795  96.152  -67.273  52.752  1
397796  96.179  -67.281  52.724  1
397797  96.206  -67.288  52.694  1
397798  96.234  -67.296  52.664  1
397799  96.261  -67.304  52.634  1
397800  96.289  -67.310  52.605  1
397801  96.321  -67.313  52.577  1
397802  96.354  -67.316  52.550  1
397803  96.387  -67.320  52.525  1
397804  96.419  -67.324  52.500  1
397805  96.452  -67.328  52.477  1
397806  96.485  -67.332  52.454  1
397807  96.518  -67.335  52.431  1
397808  96.551  -67.338  52.410  1
397809  96.586  -67.338  52.390  1
397810  96.620  -67.338  52.371  1
397811  96.655  -67.338  52.352  1
397812  96.688  -67.342  52.333  1
397813  96.722  -67.347  52.314  1
397814  96.755  -67.351  52.298  1
397815  96.789  -67.354  52.282  1
397816  96.823  -67.358  52.266  1
397817  96.863  -67.358  52.248  1
397818  96.903  -67.357  52.229  1
397819  96.944  -67.357  52.210  1
397820  96.984  -67.357  52.191  1
397821  97.025  -67.357  52.172  1
397822  97.065  -67.360  52.154  1
397823  97.103  -67.366  52.135  1
397824  97.142  -67.373  52.115  1
397825  97.181  -67.379  52.094  1
397826  97.221  -67.385  52.074  1
397827  97.268  -67.391  52.052  1
397828  97.316  -67.397  52.030  1
397829  97.364  -67.402  52.006  1
397830  97.408  -67.409  51.981  1
397831  97.451  -67.417  51.956  1
397832  97.488  -67.423  51.928  1
397833  97.516  -67.431  51.899  1
397834  97.547  -67.437  51.870  1
397835  97.580  -67.442  51.842  1
397836  97.612  -67.447  51.812  1
397837  97.645  -67.452  51.779  1
397838  97.677  -67.457  51.745  1
397839  97.710  -67.462  51.712  1
397840  97.742  -67.467  51.680  1
397841  97.773  -67.471  51.648  1
397842  97.801  -67.473  51.614  1
397843  97.850  -67.477  51.576  1
397844  97.900  -67.481  51.536  1
397845  97.951  -67.484  51.495  1
397846  97.999  -67.487  51.455  1
397847  98.024  -67.494  51.415  1
397848  98.046  -67.491  51.374  1
397849  98.068  -67.488  51.333  1
397850  98.091  -67.485  51.291  1
397851  98.113  -67.482  51.248  1
397852  98.135  -67.479  51.203  1
397853  98.166  -67.486  51.157  1
397854  98.202  -67.504  51.110  1
397855  98.238  -67.523  51.064  1
397856  98.274  -67.543  51.018  1
397857  98.310  -67.562  50.971  1
397858  98.345  -67.580  50.923  1
397859  98.378  -67.589  50.877  1
397860  98.406  -67.595  50.831  1
397861  98.426  -67.598  50.789  1
397862  98.446  -67.601  50.747  1
397863  98.466  -67.604  50.703  1
397864  98.486  -67.606  50.659  1
397865  98.506  -67.609  50.613  1
397866  98.535  -67.614  50.568  1
397867  98.573  -67.619  50.522  1
397868  98.611  -67.624  50.477  1
397869  98.650  -67.630  50.433  1
397870  98.692  -67.639  50.387  1
397871  98.734  -67.648  50.340  1
397872  98.768  -67.677  50.293  1
397873  98.816  -67.679  50.244  1
397874  98.868  -67.686  50.194  1
397875  98.921  -67.693  50.144  1
397876  98.973  -67.700  50.094  1
397877  99.025  -67.708  50.045  1
397878  99.077  -67.715  49.996  1
397879  99.130  -67.723  49.946  1
397880  99.182  -67.730  49.897  1
397881  99.234  -67.737  49.847  1
397882  99.286  -67.745  49.797  1
397883  99.339  -67.752  49.750  1
397884  99.391  -67.759  49.703  1
397885  99.442  -67.767  49.658  1
397886  99.493  -67.774  49.613  1
397887  99.545  -67.782  49.569  1
397888  99.595  -67.787  49.525  1
397889  99.619  -67.780  49.481  1
397890  99.650  -67.786  49.437  1
397891  99.673  -67.788  49.391  1
397892  99.695  -67.791  49.344  1
397893  99.717  -67.793  49.297  1
397894  99.739  -67.796  49.251  1
397895  99.761  -67.799  49.206  1
397896  99.777  -67.816  49.160  1
397897  99.788  -67.834  49.115  1
397898  99.797  -67.852  49.071  1
397899  99.806  -67.869  49.026  1
397900  99.809  -67.887  48.982  1
397901  99.827  -67.902  48.939  1
397902  99.870  -67.913  48.896  1
397903  99.912  -67.924  48.854  1
397904  99.939  -67.942  48.812  1
397905  99.970  -67.964  48.769  1
397906  100.010  -67.962  48.727  1
397907  100.049  -67.960  48.684  1
397908  100.089  -67.958  48.641  1
397909  100.129  -67.956  48.598  1
397910  100.168  -67.954  48.555  1
397911  100.208  -67.952  48.512  1
397912  100.248  -67.949  48.469  1
397913  100.287  -67.948  48.425  1
397914  100.327  -67.946  48.383  1
397915  100.366  -67.943  48.342  1
397916  100.406  -67.942  48.300  1
397917  100.445  -67.940  48.258  1
397918  100.485  -67.937  48.216  1
398356  89.973  -67.188  54.910  1
398357  90.008  -67.198  54.915  1
398358  90.042  -67.208  54.923  1
398359  90.077  -67.217  54.931  1
398360  90.123  -67.221  54.942  1
398361  90.169  -67.225  54.951  1
398362  90.215  -67.229  54.960  1
398363  90.265  -67.225  54.970  1
398364  90.322  -67.207  54.980  1
398365  90.379  -67.190  54.992  1
398366  90.435  -67.172  55.004  1
398367  90.492  -67.155  55.015  1
398368  90.549  -67.139  55.023  1
398369  90.610  -67.140  55.024  1
398370  90.672  -67.141  55.024  1
398371  90.733  -67.141  55.023  1
398372  90.794  -67.143  55.020  1
398373  90.853  -67.150  55.016  1
398374  90.911  -67.157  55.016  1
398375  90.970  -67.164  55.020  1
398376  91.029  -67.171  55.029  1
398377  91.088  -67.178  55.041  1
398378  91.147  -67.185  55.051  1
398379  91.204  -67.192  55.057  1
398380  91.247  -67.200  55.059  1
398381  91.291  -67.208  55.058  1
398382  91.333  -67.208  55.052  1
398383  91.375  -67.201  55.043  1
398384  91.417  -67.194  55.033  1
398385  91.458  -67.188  55.023  1
398386  91.500  -67.180  55.013  1
398387  91.542  -67.173  55.003  1
398388  91.583  -67.166  54.993  1
398389  91.625  -67.160  54.983  1
398390  91.667  -67.152  54.972  1
398391  91.709  -67.145  54.959  1
398392  91.750  -67.138  54.942  1
398393  91.793  -67.135  54.924  1
398394  91.838  -67.139  54.905  1
398395  91.882  -67.142  54.886  1
398396  91.927  -67.146  54.864  1
398397  91.971  -67.150  54.841  1
398398  92.016  -67.153  54.818  1
398399  92.064  -67.157  54.795  1
398400  92.117  -67.160  54.771  1
398401  92.170  -67.164  54.749  1
398402  92.223  -67.168  54.725  1
398403  92.277  -67.172  54.702  1
398404  92.330  -67.175  54.678  1
398405  92.383  -67.179  54.654  1
398406  92.436  -67.183  54.631  1
398407  92.490  -67.187  54.608  1
398408  92.546  -67.193  54.586  1
398409  92.609  -67.204  54.567  1
398410  92.673  -67.214  54.547  1
398411  92.736  -67.225  54.527  1
398412  92.799  -67.235  54.507  1
398413  92.863  -67.245  54.487  1
398414  92.908  -67.233  54.468  1
398415  92.949  -67.216  54.451  1
398416  92.991  -67.198  54.439  1
398417  93.032  -67.181  54.430  1
398418  93.074  -67.163  54.424  1
398419  93.115  -67.147  54.409  1
398420  93.154  -67.136  54.389  1
398421  93.190  -67.135  54.364  1
398422  93.226  -67.132  54.334  1
398423  93.277  -67.128  54.302  1
398424  93.324  -67.126  54.271  1
398425  93.361  -67.131  54.244  1
398426  93.398  -67.135  54.220  1
398427  93.435  -67.140  54.198  1
398428  93.472  -67.144  54.180  1
398429  93.509  -67.149  54.162  1
398430  93.546  -67.153  54.145  1
398431  93.579  -67.151  54.130  1
398432  93.609  -67.144  54.116  1
398433  93.640  -67.138  54.101  1
398434  93.670  -67.131  54.084  1
398435  93.701  -67.125  54.067  1
398436  93.731  -67.119  54.048  1
398437  93.761  -67.113  54.032  1
398438  93.795  -67.112  54.016  1
398439  93.829  -67.111  54.000  1
398440  93.867  -67.113  53.985  1
398441  93.906  -67.116  53.969  1
398442  93.945  -67.119  53.954  1
398443  93.984  -67.121  53.939  1
398444  94.023  -67.123  53.922  1
398445  94.065  -67.127  53.903  1
398446  94.112  -67.132  53.880  1
398447  94.162  -67.137  53.856  1
398448  94.212  -67.142  53.831  1
398449  94.262  -67.147  53.806  1
398450  94.312  -67.152  53.782  1
398451  94.362  -67.157  53.758  1
398452  94.412  -67.162  53.733  1
398453  94.452  -67.162  53.708  1
398454  94.487  -67.160  53.683  1
398455  94.522  -67.158  53.657  1
398456  94.559  -67.157  53.632  1
398457  94.600  -67.157  53.610  1
398458  94.639  -67.156  53.590  1
398459  94.680  -67.156  53.570  1
398460  94.719  -67.155  53.546  1
398461  94.760  -67.155  53.520  1
398462  94.800  -67.154  53.494  1
398463  94.840  -67.154  53.468  1
398464  94.894  -67.162  53.442  1
398465  94.951  -67.171  53.416  1
398466  95.007  -67.181  53.390  1
398467  95.033  -67.171  53.365  1
398468  95.055  -67.160  53.342  1
398469  95.077  -67.147  53.321  1
398470  95.099  -67.135  53.302  1
398471  95.135  -67.131  53.285  1
398472  95.182  -67.134  53.267  1
398473  95.228  -67.136  53.249  1
398474  95.274  -67.138  53.234  1
398475  95.321  -67.140  53.218  1
398476  95.367  -67.142  53.202  1
398477  95.413  -67.144  53.185  1
398478  95.460  -67.146  53.169  1
398479  95.507  -67.148  53.153  1
398480  95.553  -67.150  53.135  1
398481  95.599  -67.152  53.117  1
398482  95.645  -67.154  53.098  1
398483  95.690  -67.163  53.079  1
398484  95.734  -67.172  53.059  1
398485  95.777  -67.181  53.039  1
398486  95.816  -67.191  53.018  1
398487  95.852  -67.201  52.996  1
398488  95.889  -67.212  52.973  1
398489  95.926  -67.222  52.952  1
398490  95.963  -67.232  52.929  1
398491  95.999  -67.229  52.904  1
398492  96.033  -67.225  52.878  1
398493  96.068  -67.220  52.850  1
398494  96.103  -67.216  52.822  1
398495  96.130  -67.223  52.793  1
398496  96.157  -67.231  52.764  1
398497  96.184  -67.238  52.734  1
398498  96.212  -67.246  52.704  1
398499  96.239  -67.254  52.674  1
398500  96.266  -67.261  52.643  1
398501  96.294  -67.269  52.614  1
398502  96.322  -67.277  52.585  1
398503  96.355  -67.281  52.558  1
398504  96.388  -67.285  52.531  1
398505  96.420  -67.289  52.506  1
398506  96.453  -67.293  52.481  1
398507  96.486  -67.297  52.458  1
398508  96.519  -67.301  52.436  1
398509  96.552  -67.302  52.416  1
398510  96.587  -67.301  52.395  1
398511  96.621  -67.301  52.376  1
398512  96.656  -67.301  52.357  1
398513  96.690  -67.304  52.338  1
398514  96.724  -67.307  52.320  1
398515  96.757  -67.312  52.303  1
398516  96.791  -67.316  52.287  1
398517  96.826  -67.319  52.270  1
398518  96.867  -67.319  52.252  1
398519  96.907  -67.318  52.233  1
398520  96.947  -67.318  52.215  1
398521  96.987  -67.317  52.195  1
398522  97.028  -67.317  52.176  1
398523  97.069  -67.317  52.159  1
398524  97.108  -67.322  52.139  1
398525  97.147  -67.329  52.118  1
398526  97.185  -67.335  52.096  1
398527  97.226  -67.341  52.074  1
398528  97.274  -67.346  52.053  1
398529  97.322  -67.352  52.031  1
398530  97.367  -67.358  52.007  1
398531  97.409  -67.366  51.982  1
398532  97.453  -67.373  51.955  1
398533  97.488  -67.380  51.927  1
398534  97.516  -67.387  51.897  1
398535  97.546  -67.394  51.868  1
398536  97.578  -67.399  51.840  1
398537  97.611  -67.404  51.811  1
398538  97.643  -67.409  51.778  1
398539  97.676  -67.414  51.744  1
398540  97.708  -67.419  51.711  1
398541  97.740  -67.424  51.679  1
398542  97.773  -67.429  51.647  1
398543  97.808  -67.433  51.614  1
398544  97.859  -67.434  51.577  1
398545  97.910  -67.435  51.538  1
398546  97.961  -67.437  51.498  1
398547  97.993  -67.445  51.458  1
398548  98.019  -67.455  51.417  1
398549  98.045  -67.465  51.376  1
398550  98.070  -67.471  51.335  1
398551  98.092  -67.468  51.291  1
398552  98.114  -67.465  51.247  1
398553  98.137  -67.462  51.202  1
398554  98.159  -67.459  51.155  1
398555  98.195  -67.473  51.106  1
398556  98.234  -67.489  51.057  1
398557  98.273  -67.507  51.009  1
398558  98.312  -67.524  50.962  1
398559  98.351  -67.541  50.917  1
398560  98.378  -67.548  50.873  1
398561  98.398  -67.551  50.829  1
398562  98.418  -67.554  50.788  1
398563  98.438  -67.557  50.749  1
398564  98.458  -67.560  50.708  1
398565  98.479  -67.563  50.665  1
398566  98.499  -67.566  50.622  1
398567  98.530  -67.570  50.576  1
398568  98.568  -67.576  50.528  1
398569  98.609  -67.585  50.481  1
398570  98.652  -67.594  50.434  1
398571  98.694  -67.602  50.388  1
398572  98.736  -67.612  50.341  1
398573  98.773  -67.636  50.292  1
398574  98.822  -67.637  50.241  1
398575  98.872  -67.641  50.192  1
398576  98.925  -67.648  50.141  1
398577  98.977  -67.656  50.091  1
398578  99.029  -67.663  50.043  1
398579  99.081  -67.670  49.995  1
398580  99.134  -67.678  49.946  1
398581  99.186  -67.686  49.898  1
398582  99.238  -67.692  49.849  1
398583  99.290  -67.700  49.799  1
398584  99.343  -67.708  49.750  1
398585  99.395  -67.715  49.703  1
398586  99.447  -67.722  49.656  1
398587  99.499  -67.730  49.610  1
398588  99.552  -67.737  49.566  1
398589  99.604  -67.745  49.521  1
398590  99.639  -67.755  49.475  1
398591  99.663  -67.758  49.430  1
398592  99.684  -67.765  49.385  1
398593  99.705  -67.772  49.337  1
398594  99.726  -67.778  49.291  1
398595  99.748  -67.785  49.245  1
398596  99.769  -67.790  49.200  1
398597  99.807  -67.802  49.156  1
398598  99.824  -67.801  49.110  1
398599  99.833  -67.819  49.065  1
398600  99.842  -67.837  49.022  1
398601  99.848  -67.854  48.978  1
398602  99.839  -67.872  48.934  1
398603  99.872  -67.885  48.891  1
398604  99.910  -67.892  48.847  1
398605  99.940  -67.920  48.804  1
398606  99.979  -67.918  48.761  1
398607  100.019  -67.916  48.717  1
398608  100.059  -67.914  48.674  1
398609  100.098  -67.912  48.631  1
398610  100.138  -67.910  48.589  1
398611  100.177  -67.908  48.546  1
398612  100.217  -67.905  48.503  1
398613  100.257  -67.904  48.461  1
398614  100.296  -67.902  48.418  1
398615  100.336  -67.899  48.375  1
398616  100.375  -67.898  48.334  1
398617  100.415  -67.896  48.293  1
398618  100.455  -67.893  48.251  1
398619  100.497  -67.892  48.209  1
399057  89.965  -67.140  54.912  1
399058  90.000  -67.150  54.917  1
399059  90.034  -67.160  54.924  1
399060  90.079  -67.164  54.932  1
399061  90.125  -67.168  54.942  1
399062  90.171  -67.172  54.951  1
399063  90.218  -67.175  54.961  1
399064  90.273  -67.160  54.970  1
399065  90.330  -67.143  54.980  1
399066  90.386  -67.125  54.992  1
399067  90.443  -67.108  55.003  1
399068  90.500  -67.091  55.014  1
399069  90.557  -67.076  55.023  1
399070  90.618  -67.076  55.025  1
399071  90.679  -67.078  55.027  1
399072  90.738  -67.084  55.027  1
399073  90.798  -67.091  55.026  1
399074  90.857  -67.098  55.025  1
399075  90.916  -67.105  55.027  1
399076  90.974  -67.112  55.034  1
399077  91.033  -67.119  55.046  1
399078  91.092  -67.126  55.060  1
399079  91.151  -67.133  55.069  1
399080  91.203  -67.140  55.074  1
399081  91.247  -67.148  55.074  1
399082  91.291  -67.157  55.071  1
399083  91.333  -67.161  55.064  1
399084  91.375  -67.154  55.056  1
399085  91.417  -67.147  55.047  1
399086  91.459  -67.140  55.038  1
399087  91.500  -67.133  55.028  1
399088  91.542  -67.126  55.018  1
399089  91.584  -67.119  55.009  1
399090  91.626  -67.112  54.999  1
399091  91.667  -67.105  54.987  1
399092  91.709  -67.098  54.972  1
399093  91.750  -67.091  54.955  1
399094  91.794  -67.092  54.937  1
399095  91.839  -67.096  54.918  1
399096  91.883  -67.100  54.899  1
399097  91.928  -67.103  54.876  1
399098  91.973  -67.106  54.854  1
399099  92.017  -67.110  54.831  1
399100  92.062  -67.113  54.807  1
399101  92.114  -67.117  54.784  1
399102  92.167  -67.121  54.761  1
399103  92.221  -67.125  54.739  1
399104  92.274  -67.128  54.716  1
399105  92.327  -67.132  54.693  1
399106  92.380  -67.136  54.669  1
399107  92.434  -67.140  54.648  1
399108  92.490  -67.146  54.627  1
399109  92.554  -67.157  54.607  1
399110  92.617  -67.167  54.592  1
399111  92.680  -67.178  54.572  1
399112  92.743  -67.188  54.550  1
399113  92.806  -67.198  54.528  1
399114  92.868  -67.207  54.509  1
399115  92.910  -67.190  54.489  1
399116  92.951  -67.172  54.470  1
399117  92.993  -67.155  54.455  1
399118  93.034  -67.138  54.443  1
399119  93.075  -67.120  54.434  1
399120  93.117  -67.103  54.420  1
399121  93.158  -67.085  54.401  1
399122  93.195  -67.081  54.377  1
399123  93.231  -67.080  54.350  1
399124  93.282  -67.075  54.318  1
399125  93.324  -67.077  54.286  1
399126  93.360  -67.081  54.257  1
399127  93.398  -67.086  54.232  1
399128  93.434  -67.091  54.208  1
399129  93.472  -67.095  54.186  1
399130  93.508  -67.099  54.165  1
399131  93.546  -67.103  54.146  1
399132  93.580  -67.104  54.129  1
399133  93.611  -67.097  54.114  1
399134  93.641  -67.091  54.098  1
399135  93.671  -67.084  54.082  1
399136  93.702  -67.078  54.065  1
399137  93.732  -67.072  54.049  1
399138  93.766  -67.071  54.035  1
399139  93.799  -67.071  54.020  1
399140  93.834  -67.071  54.005  1
399141  93.870  -67.072  53.991  1
399142  93.909  -67.075  53.979  1
399143  93.948  -67.077  53.965  1
399144  93.987  -67.079  53.951  1
399145  94.026  -67.081  53.934  1
399146  94.071  -67.087  53.914  1
399147  94.117  -67.092  53.892  1
399148  94.162  -67.097  53.870  1
399149  94.209  -67.103  53.847  1
399150  94.259  -67.107  53.823  1
399151  94.309  -67.113  53.799  1
399152  94.359  -67.118  53.776  1
399153  94.409  -67.122  53.751  1
399154  94.444  -67.120  53.725  1
399155  94.479  -67.119  53.700  1
399156  94.519  -67.118  53.674  1
399157  94.559  -67.117  53.648  1
399158  94.599  -67.117  53.623  1
399159  94.639  -67.116  53.598  1
399160  94.679  -67.116  53.575  1
399161  94.719  -67.116  53.552  1
399162  94.759  -67.116  53.527  1
399163  94.800  -67.115  53.502  1
399164  94.840  -67.115  53.475  1
399165  94.897  -67.125  53.448  1
399166  94.954  -67.134  53.421  1
399167  95.008  -67.143  53.395  1
399168  95.033  -67.133  53.369  1
399169  95.053  -67.120  53.346  1
399170  95.073  -67.107  53.327  1
399171  95.094  -67.094  53.310  1
399172  95.129  -67.094  53.292  1
399173  95.179  -67.096  53.276  1
399174  95.226  -67.098  53.259  1
399175  95.272  -67.100  53.244  1
399176  95.318  -67.103  53.230  1
399177  95.365  -67.104  53.215  1
399178  95.411  -67.106  53.199  1
399179  95.458  -67.109  53.184  1
399180  95.504  -67.111  53.168  1
399181  95.550  -67.113  53.151  1
399182  95.597  -67.115  53.133  1
399183  95.641  -67.122  53.115  1
399184  95.685  -67.131  53.096  1
399185  95.729  -67.141  53.076  1
399186  95.773  -67.150  53.055  1
399187  95.817  -67.159  53.033  1
399188  95.854  -67.169  53.011  1
399189  95.891  -67.179  52.988  1
399190  95.927  -67.190  52.966  1
399191  95.964  -67.199  52.944  1
399192  95.999  -67.194  52.919  1
399193  96.034  -67.190  52.892  1
399194  96.068  -67.185  52.865  1
399195  96.104  -67.181  52.837  1
399196  96.135  -67.181  52.807  1
399197  96.163  -67.188  52.778  1
399198  96.190  -67.196  52.746  1
399199  96.217  -67.204  52.716  1
399200  96.244  -67.213  52.686  1
399201  96.271  -67.222  52.654  1
399202  96.298  -67.232  52.624  1
399203  96.325  -67.240  52.595  1
399204  96.356  -67.246  52.566  1
399205  96.388  -67.250  52.538  1
399206  96.421  -67.254  52.513  1
399207  96.454  -67.258  52.487  1
399208  96.486  -67.262  52.464  1
399209  96.519  -67.266  52.443  1
399210  96.554  -67.265  52.423  1
399211  96.589  -67.265  52.402  1
399212  96.623  -67.264  52.383  1
399213  96.658  -67.264  52.364  1
399214  96.692  -67.265  52.345  1
399215  96.726  -67.269  52.327  1
399216  96.759  -67.273  52.310  1
399217  96.793  -67.277  52.293  1
399218  96.829  -67.279  52.276  1
399219  96.870  -67.279  52.258  1
399220  96.910  -67.279  52.239  1
399221  96.951  -67.278  52.220  1
399222  96.991  -67.278  52.202  1
399223  97.031  -67.278  52.183  1
399224  97.072  -67.277  52.165  1
399225  97.112  -67.277  52.146  1
399226  97.151  -67.284  52.125  1
399227  97.190  -67.290  52.104  1
399228  97.232  -67.296  52.082  1
399229  97.280  -67.301  52.059  1
399230  97.325  -67.308  52.036  1
399231  97.369  -67.315  52.012  1
399232  97.412  -67.322  51.987  1
399233  97.454  -67.329  51.960  1
399234  97.488  -67.336  51.930  1
399235  97.516  -67.344  51.901  1
399236  97.545  -67.351  51.871  1
399237  97.577  -67.357  51.842  1
399238  97.609  -67.361  51.811  1
399239  97.642  -67.366  51.779  1
399240  97.674  -67.371  51.746  1
399241  97.707  -67.376  51.712  1
399242  97.739  -67.382  51.679  1
399243  97.772  -67.386  51.648  1
399244  97.818  -67.385  51.614  1
399245  97.869  -67.387  51.578  1
399246  97.920  -67.388  51.539  1
399247  97.961  -67.394  51.499  1
399248  97.987  -67.404  51.460  1
399249  98.013  -67.413  51.418  1
399250  98.039  -67.423  51.377  1
399251  98.065  -67.433  51.335  1
399252  98.091  -67.444  51.291  1
399253  98.116  -67.448  51.245  1
399254  98.138  -67.445  51.199  1
399255  98.161  -67.442  51.152  1
399256  98.185  -67.442  51.104  1
399257  98.224  -67.459  51.056  1
399258  98.263  -67.476  51.008  1
399259  98.302  -67.494  50.961  1
399260  98.334  -67.504  50.915  1
399261  98.356  -67.507  50.870  1
399262  98.379  -67.510  50.829  1
399263  98.401  -67.512  50.790  1
399264  98.424  -67.514  50.752  1
399265  98.446  -67.517  50.711  1
399266  98.468  -67.520  50.669  1
399267  98.491  -67.523  50.625  1
399268  98.527  -67.529  50.579  1
399269  98.570  -67.539  50.532  1
399270  98.612  -67.548  50.484  1
399271  98.654  -67.557  50.437  1
399272  98.697  -67.566  50.388  1
399273  98.734  -67.583  50.340  1
399274  98.779  -67.594  50.290  1
399275  98.828  -67.595  50.240  1
399276  98.876  -67.596  50.190  1
399277  98.929  -67.604  50.140  1
399278  98.981  -67.611  50.091  1
399279  99.033  -67.619  50.041  1
399280  99.085  -67.626  49.993  1
399281  99.138  -67.633  49.944  1
399282  99.190  -67.641  49.896  1
399283  99.242  -67.648  49.847  1
399284  99.294  -67.655  49.797  1
399285  99.347  -67.663  49.748  1
399286  99.399  -67.670  49.700  1
399287  99.451  -67.678  49.652  1
399288  99.503  -67.685  49.605  1
399289  99.556  -67.692  49.559  1
399290  99.608  -67.700  49.513  1
399291  99.612  -67.716  49.467  1
399292  99.637  -67.714  49.421  1
399293  99.658  -67.721  49.375  1
399294  99.680  -67.727  49.329  1
399295  99.701  -67.734  49.283  1
399296  99.722  -67.740  49.237  1
399297  99.759  -67.780  49.194  1
399298  99.796  -67.819  49.150  1
399299  99.832  -67.837  49.105  1
399300  99.851  -67.827  49.061  1
399301  99.870  -67.819  49.017  1
399302  99.886  -67.821  48.973  1
399303  99.877  -67.840  48.930  1
399304  99.874  -67.856  48.885  1
399305  99.911  -67.871  48.841  1
399306  99.949  -67.874  48.796  1
399307  99.989  -67.872  48.752  1
399308  100.028  -67.870  48.707  1
399309  100.068  -67.868  48.664  1
399310  100.107  -67.866  48.621  1
399311  100.147  -67.864  48.579  1
399312  100.187  -67.862  48.536  1
399313  100.226  -67.860  48.494  1
399314  100.266  -67.858  48.452  1
399315  100.305  -67.855  48.409  1
399316  100.345  -67.854  48.367  1
399317  100.385  -67.852  48.326  1
399318  100.424  -67.849  48.285  1
399319  100.464  -67.848  48.243  1
399757  89.923  -67.082  54.909  1
399758  89.958  -67.092  54.912  1
399759  89.992  -67.101  54.917  1
399760  90.035  -67.106  54.923  1
399761  90.081  -67.110  54.932  1
399762  90.127  -67.115  54.941  1
399763  90.174  -67.119  54.951  1
399764  90.224  -67.113  54.960  1
399765  90.281  -67.096  54.969  1
399766  90.337  -67.078  54.980  1
399767  90.394  -67.061  54.990  1
399768  90.451  -67.044  55.002  1
399769  90.508  -67.025  55.013  1
399770  90.566  -67.012  55.021  1
399771  90.624  -67.019  55.026  1
399772  90.683  -67.025  55.029  1
399773  90.742  -67.032  55.031  1
399774  90.801  -67.039  55.031  1
399775  90.860  -67.046  55.033  1
399776  90.920  -67.053  55.038  1
399777  90.978  -67.060  55.048  1
399778  91.037  -67.067  55.063  1
399779  91.096  -67.074  55.075  1
399780  91.155  -67.081  55.083  1
399781  91.203  -67.088  55.086  1
399782  91.246  -67.097  55.085  1
399783  91.290  -67.105  55.081  1
399784  91.334  -67.113  55.074  1
399785  91.376  -67.106  55.068  1
399786  91.418  -67.100  55.060  1
399787  91.459  -67.093  55.051  1
399788  91.501  -67.086  55.041  1
399789  91.542  -67.078  55.031  1
399790  91.584  -67.072  55.022  1
399791  91.626  -67.065  55.012  1
399792  91.667  -67.058  55.000  1
399793  91.709  -67.051  54.984  1
399794  91.751  -67.046  54.967  1
399795  91.796  -67.050  54.949  1
399796  91.841  -67.053  54.931  1
399797  91.885  -67.056  54.911  1
399798  91.930  -67.059  54.889  1
399799  91.975  -67.063  54.867  1
399800  92.019  -67.067  54.844  1
399801  92.064  -67.070  54.820  1
399802  92.111  -67.074  54.797  1
399803  92.165  -67.078  54.775  1
399804  92.218  -67.081  54.753  1
399805  92.271  -67.085  54.731  1
399806  92.324  -67.089  54.709  1
399807  92.378  -67.093  54.686  1
399808  92.434  -67.099  54.665  1
399809  92.497  -67.109  54.646  1
399810  92.561  -67.120  54.629  1
399811  92.624  -67.131  54.616  1
399812  92.687  -67.141  54.598  1
399813  92.751  -67.151  54.577  1
399814  92.813  -67.162  54.555  1
399815  92.870  -67.163  54.533  1
399816  92.912  -67.146  54.511  1
399817  92.953  -67.128  54.491  1
399818  92.994  -67.112  54.473  1
399819  93.036  -67.094  54.456  1
399820  93.077  -67.077  54.446  1
399821  93.119  -67.059  54.431  1
399822  93.160  -67.042  54.412  1
399823  93.200  -67.029  54.388  1
399824  93.236  -67.027  54.360  1
399825  93.286  -67.023  54.329  1
399826  93.323  -67.028  54.300  1
399827  93.360  -67.032  54.272  1
399828  93.397  -67.037  54.245  1
399829  93.434  -67.041  54.218  1
399830  93.471  -67.045  54.195  1
399831  93.508  -67.050  54.172  1
399832  93.545  -67.054  54.150  1
399833  93.581  -67.057  54.130  1
399834  93.612  -67.050  54.114  1
399835  93.642  -67.044  54.097  1
399836  93.673  -67.037  54.080  1
399837  93.703  -67.031  54.066  1
399838  93.736  -67.031  54.052  1
399839  93.770  -67.030  54.038  1
399840  93.804  -67.030  54.024  1
399841  93.838  -67.030  54.012  1
399842  93.874  -67.031  54.000  1
399843  93.913  -67.033  53.989  1
399844  93.952  -67.035  53.977  1
399845  93.990  -67.037  53.963  1
399846  94.032  -67.041  53.946  1
399847  94.077  -67.047  53.925  1
399848  94.123  -67.052  53.905  1
399849  94.169  -67.057  53.884  1
399850  94.214  -67.062  53.863  1
399851  94.260  -67.068  53.840  1
399852  94.306  -67.073  53.817  1
399853  94.356  -67.078  53.795  1
399854  94.401  -67.081  53.769  1
399855  94.438  -67.079  53.743  1
399856  94.479  -67.078  53.717  1
399857  94.519  -67.078  53.691  1
399858  94.559  -67.078  53.664  1
399859  94.599  -67.078  53.637  1
399860  94.639  -67.077  53.610  1
399861  94.679  -67.077  53.585  1
399862  94.719  -67.076  53.561  1
399863  94.759  -67.076  53.536  1
399864  94.799  -67.075  53.511  1
399865  94.844  -67.078  53.484  1
399866  94.901  -67.088  53.456  1
399867  94.953  -67.095  53.427  1
399868  95.005  -67.103  53.400  1
399869  95.026  -67.091  53.374  1
399870  95.046  -67.078  53.351  1
399871  95.066  -67.065  53.333  1
399872  95.092  -67.058  53.317  1
399873  95.123  -67.056  53.300  1
399874  95.171  -67.058  53.285  1
399875  95.222  -67.061  53.270  1
399876  95.270  -67.063  53.256  1
399877  95.316  -67.065  53.242  1
399878  95.362  -67.067  53.229  1
399879  95.409  -67.069  53.215  1
399880  95.455  -67.072  53.200  1
399881  95.502  -67.073  53.184  1
399882  95.548  -67.075  53.166  1
399883  95.593  -67.082  53.149  1
399884  95.637  -67.091  53.131  1
399885  95.681  -67.100  53.111  1
399886  95.725  -67.109  53.091  1
399887  95.768  -67.119  53.070  1
399888  95.813  -67.128  53.048  1
399889  95.855  -67.137  53.025  1
399890  95.892  -67.147  53.003  1
399891  95.928  -67.157  52.982  1
399892  95.965  -67.164  52.959  1
399893  96.000  -67.160  52.935  1
399894  96.035  -67.155  52.909  1
399895  96.070  -67.150  52.881  1
399896  96.104  -67.145  52.852  1
399897  96.138  -67.142  52.822  1
399898  96.168  -67.148  52.792  1
399899  96.195  -67.157  52.760  1
399900  96.222  -67.166  52.729  1
399901  96.249  -67.175  52.698  1
399902  96.276  -67.184  52.666  1
399903  96.303  -67.193  52.635  1
399904  96.330  -67.202  52.605  1
399905  96.357  -67.210  52.575  1
399906  96.389  -67.215  52.547  1
399907  96.422  -67.219  52.522  1
399908  96.455  -67.222  52.496  1
399909  96.487  -67.226  52.472  1
399910  96.521  -67.229  52.451  1
399911  96.555  -67.229  52.430  1
399912  96.590  -67.229  52.410  1
399913  96.624  -67.228  52.391  1
399914  96.659  -67.227  52.372  1
399915  96.694  -67.227  52.353  1
399916  96.728  -67.230  52.334  1
399917  96.761  -67.234  52.316  1
399918  96.795  -67.238  52.299  1
399919  96.832  -67.239  52.281  1
399920  96.873  -67.239  52.263  1
399921  96.913  -67.239  52.245  1
399922  96.954  -67.238  52.227  1
399923  96.994  -67.238  52.209  1
399924  97.035  -67.238  52.191  1
399925  97.075  -67.238  52.172  1
399926  97.115  -67.238  52.154  1
399927  97.156  -67.239  52.134  1
399928  97.194  -67.245  52.114  1
399929  97.238  -67.251  52.093  1
399930  97.285  -67.257  52.068  1
399931  97.327  -67.264  52.044  1
399932  97.370  -67.272  52.020  1
399933  97.414  -67.279  51.995  1
399934  97.456  -67.285  51.966  1
399935  97.488  -67.293  51.936  1
399936  97.516  -67.301  51.906  1
399937  97.545  -67.307  51.875  1
399938  97.575  -67.313  51.845  1
399939  97.608  -67.319  51.813  1
399940  97.640  -67.324  51.781  1
399941  97.673  -67.329  51.747  1
399942  97.705  -67.334  51.714  1
399943  97.738  -67.338  51.681  1
399944  97.778  -67.340  51.649  1
399945  97.828  -67.338  51.615  1
399946  97.879  -67.340  51.579  1
399947  97.929  -67.341  51.540  1
399948  97.955  -67.352  51.501  1
399949  97.981  -67.362  51.461  1
399950  98.007  -67.372  51.420  1
399951  98.033  -67.382  51.378  1
399952  98.060  -67.392  51.335  1
399953  98.086  -67.402  51.290  1
399954  98.112  -67.412  51.244  1
399955  98.138  -67.422  51.197  1
399956  98.162  -67.426  51.150  1
399957  98.184  -67.423  51.103  1
399958  98.214  -67.429  51.056  1
399959  98.253  -67.446  51.009  1
399960  98.290  -67.461  50.961  1
399961  98.312  -67.464  50.914  1
399962  98.335  -67.466  50.867  1
399963  98.357  -67.469  50.827  1
399964  98.379  -67.471  50.789  1
399965  98.405  -67.474  50.751  1
399966  98.437  -67.477  50.710  1
399967  98.469  -67.480  50.669  1
399968  98.499  -67.486  50.625  1
399969  98.530  -67.492  50.580  1
399970  98.572  -67.501  50.533  1
399971  98.615  -67.511  50.484  1
399972  98.656  -67.520  50.437  1
399973  98.699  -67.529  50.388  1
399974  98.735  -67.551  50.338  1
399975  98.784  -67.552  50.288  1
399976  98.833  -67.553  50.238  1
399977  98.882  -67.555  50.188  1
399978  98.932  -67.559  50.138  1
399979  98.985  -67.567  50.089  1
399980  99.037  -67.574  50.039  1
399981  99.089  -67.582  49.989  1
399982  99.141  -67.589  49.941  1
399983  99.194  -67.596  49.892  1
399984  99.246  -67.604  49.842  1
399985  99.298  -67.611  49.793  1
399986  99.350  -67.618  49.744  1
399987  99.403  -67.626  49.696  1
399988  99.455  -67.633  49.647  1
399989  99.507  -67.641  49.598  1
399990  99.559  -67.648  49.551  1
399991  99.584  -67.661  49.504  1
399992  99.584  -67.677  49.458  1
399993  99.588  -67.691  49.411  1
399994  99.633  -67.676  49.365  1
399995  99.654  -67.683  49.320  1
399996  99.683  -67.705  49.274  1
399997  99.720  -67.745  49.230  1
399998  99.757  -67.784  49.187  1
399999  99.793  -67.824  49.143  1
400000  99.831  -67.863  49.099  1
400001  99.853  -67.871  49.055  1
400002  99.862  -67.865  49.011  1
400003  99.871  -67.857  48.967  1
400004  99.881  -67.846  48.924  1
400005  99.891  -67.834  48.879  1
400006  99.918  -67.830  48.834  1
400007  99.958  -67.828  48.788  1
400008  99.998  -67.826  48.743  1
400009  100.037  -67.824  48.697  1
400010  100.077  -67.822  48.654  1
400011  100.117  -67.820  48.611  1
400012  100.156  -67.818  48.569  1
400013  100.196  -67.816  48.527  1
400014  100.235  -67.814  48.485  1
400015  100.275  -67.811  48.443  1
400016  100.315  -67.810  48.401  1
400017  100.354  -67.808  48.359  1
400018  100.394  -67.805  48.318  1
400019  100.433  -67.804  48.277  1
400020  100.477  -67.802  48.236  1
400458  89.915  -67.034  54.908  1
400459  89.950  -67.044  54.912  1
400460  89.991  -67.050  54.916  1
400461  90.037  -67.053  54.922  1
400462  90.084  -67.057  54.931  1
400463  90.129  -67.061  54.940  1
400464  90.176  -67.066  54.948  1
400465  90.232  -67.049  54.957  1
400466  90.289  -67.031  54.967  1
400467  90.345  -67.014  54.977  1
400468  90.402  -66.997  54.987  1
400469  90.459  -66.979  54.998  1
400470  90.516  -66.961  55.010  1
400471  90.571  -66.961  55.019  1
400472  90.628  -66.966  55.027  1
400473  90.687  -66.973  55.032  1
400474  90.746  -66.981  55.035  1
400475  90.805  -66.987  55.036  1
400476  90.864  -66.994  55.040  1
400477  90.923  -67.001  55.049  1
400478  90.982  -67.008  55.062  1
400479  91.041  -67.015  55.078  1
400480  91.100  -67.022  55.090  1
400481  91.159  -67.028  55.096  1
400482  91.203  -67.037  55.098  1
400483  91.246  -67.045  55.097  1
400484  91.290  -67.053  55.093  1
400485  91.333  -67.061  55.086  1
400486  91.376  -67.059  55.080  1
400487  91.418  -67.053  55.073  1
400488  91.459  -67.046  55.065  1
400489  91.501  -67.038  55.054  1
400490  91.542  -67.031  55.045  1
400491  91.584  -67.025  55.036  1
400492  91.626  -67.018  55.026  1
400493  91.668  -67.011  55.013  1
400494  91.709  -67.003  54.997  1
400495  91.752  -67.003  54.980  1
400496  91.797  -67.006  54.962  1
400497  91.842  -67.009  54.943  1
400498  91.886  -67.013  54.922  1
400499  91.931  -67.017  54.901  1
400500  91.976  -67.020  54.879  1
400501  92.020  -67.024  54.856  1
400502  92.065  -67.028  54.832  1
400503  92.110  -67.031  54.810  1
400504  92.162  -67.034  54.788  1
400505  92.215  -67.038  54.767  1
400506  92.269  -67.042  54.747  1
400507  92.322  -67.046  54.725  1
400508  92.378  -67.052  54.703  1
400509  92.441  -67.062  54.683  1
400510  92.505  -67.073  54.666  1
400511  92.568  -67.083  54.652  1
400512  92.631  -67.094  54.640  1
400513  92.694  -67.104  54.625  1
400514  92.758  -67.115  54.607  1
400515  92.821  -67.125  54.584  1
400516  92.872  -67.120  54.560  1
400517  92.913  -67.103  54.537  1
400518  92.954  -67.085  54.515  1
400519  92.996  -67.068  54.494  1
400520  93.038  -67.050  54.474  1
400521  93.079  -67.033  54.460  1
400522  93.121  -67.016  54.442  1
400523  93.162  -66.999  54.422  1
400524  93.203  -66.981  54.398  1
400525  93.241  -66.975  54.370  1
400526  93.285  -66.974  54.340  1
400527  93.323  -66.978  54.313  1
400528  93.359  -66.982  54.286  1
400529  93.397  -66.987  54.259  1
400530  93.433  -66.991  54.230  1
400531  93.471  -66.996  54.204  1
400532  93.507  -67.000  54.178  1
400533  93.545  -67.005  54.155  1
400534  93.581  -67.009  54.133  1
400535  93.613  -67.003  54.116  1
400536  93.643  -66.997  54.100  1
400537  93.674  -66.990  54.085  1
400538  93.707  -66.990  54.071  1
400539  93.741  -66.990  54.057  1
400540  93.775  -66.990  54.044  1
400541  93.809  -66.990  54.033  1
400542  93.843  -66.989  54.023  1
400543  93.877  -66.989  54.013  1
400544  93.916  -66.991  54.002  1
400545  93.955  -66.994  53.989  1
400546  93.993  -66.996  53.974  1
400547  94.038  -67.001  53.956  1
400548  94.083  -67.006  53.936  1
400549  94.129  -67.012  53.918  1
400550  94.175  -67.017  53.898  1
400551  94.220  -67.022  53.878  1
400552  94.266  -67.028  53.856  1
400553  94.312  -67.033  53.835  1
400554  94.357  -67.038  53.813  1
400555  94.392  -67.039  53.788  1
400556  94.432  -67.039  53.762  1
400557  94.474  -67.039  53.735  1
400558  94.514  -67.038  53.708  1
400559  94.556  -67.038  53.680  1
400560  94.597  -67.038  53.653  1
400561  94.638  -67.037  53.625  1
400562  94.679  -67.037  53.598  1
400563  94.718  -67.037  53.573  1
400564  94.759  -67.037  53.547  1
400565  94.799  -67.036  53.521  1
400566  94.846  -67.041  53.493  1
400567  94.898  -67.048  53.463  1
400568  94.950  -67.056  53.433  1
400569  94.998  -67.061  53.405  1
400570  95.019  -67.048  53.380  1
400571  95.039  -67.035  53.357  1
400572  95.059  -67.023  53.341  1
400573  95.090  -67.021  53.324  1
400574  95.121  -67.019  53.309  1
400575  95.162  -67.020  53.295  1
400576  95.212  -67.022  53.282  1
400577  95.263  -67.025  53.268  1
400578  95.314  -67.028  53.256  1
400579  95.360  -67.030  53.244  1
400580  95.407  -67.032  53.232  1
400581  95.453  -67.034  53.217  1
400582  95.499  -67.036  53.200  1
400583  95.545  -67.042  53.183  1
400584  95.589  -67.051  53.165  1
400585  95.632  -67.059  53.147  1
400586  95.676  -67.069  53.126  1
400587  95.720  -67.078  53.106  1
400588  95.764  -67.087  53.085  1
400589  95.808  -67.096  53.063  1
400590  95.852  -67.105  53.040  1
400591  95.893  -67.115  53.018  1
400592  95.930  -67.125  52.997  1
400593  95.966  -67.128  52.974  1
400594  96.001  -67.124  52.951  1
400595  96.035  -67.119  52.924  1
400596  96.070  -67.116  52.896  1
400597  96.102  -67.114  52.867  1
400598  96.134  -67.113  52.838  1
400599  96.165  -67.115  52.808  1
400600  96.195  -67.122  52.776  1
400601  96.226  -67.128  52.745  1
400602  96.253  -67.136  52.714  1
400603  96.281  -67.145  52.681  1
400604  96.308  -67.154  52.649  1
400605  96.335  -67.163  52.618  1
400606  96.362  -67.172  52.588  1
400607  96.390  -67.180  52.559  1
400608  96.422  -67.184  52.532  1
400609  96.455  -67.188  52.506  1
400610  96.488  -67.191  52.482  1
400611  96.522  -67.192  52.460  1
400612  96.557  -67.192  52.440  1
400613  96.591  -67.191  52.421  1
400614  96.626  -67.191  52.402  1
400615  96.661  -67.191  52.383  1
400616  96.695  -67.191  52.363  1
400617  96.729  -67.191  52.343  1
400618  96.763  -67.195  52.325  1
400619  96.797  -67.199  52.306  1
400620  96.836  -67.200  52.288  1
400621  96.876  -67.200  52.270  1
400622  96.916  -67.199  52.251  1
400623  96.957  -67.199  52.234  1
400624  96.998  -67.198  52.217  1
400625  97.038  -67.198  52.199  1
400626  97.079  -67.198  52.180  1
400627  97.119  -67.197  52.163  1
400628  97.159  -67.197  52.145  1
400629  97.199  -67.200  52.126  1
400630  97.243  -67.207  52.106  1
400631  97.286  -67.213  52.081  1
400632  97.329  -67.221  52.056  1
400633  97.372  -67.228  52.031  1
400634  97.415  -67.235  52.004  1
400635  97.458  -67.242  51.974  1
400636  97.488  -67.250  51.943  1
400637  97.516  -67.257  51.911  1
400638  97.545  -67.264  51.880  1
400639  97.574  -67.271  51.849  1
400640  97.606  -67.276  51.817  1
400641  97.639  -67.281  51.783  1
400642  97.671  -67.286  51.749  1
400643  97.704  -67.291  51.716  1
400644  97.737  -67.295  51.685  1
400645  97.788  -67.291  51.652  1
400646  97.839  -67.291  51.618  1
400647  97.890  -67.293  51.581  1
400648  97.923  -67.300  51.543  1
400649  97.949  -67.310  51.502  1
400650  97.975  -67.320  51.462  1
400651  98.002  -67.330  51.420  1
400652  98.028  -67.340  51.378  1
400653  98.054  -67.350  51.335  1
400654  98.080  -67.360  51.288  1
400655  98.106  -67.370  51.243  1
400656  98.132  -67.380  51.197  1
400657  98.158  -67.390  51.151  1
400658  98.184  -67.400  51.104  1
400659  98.208  -67.404  51.059  1
400660  98.243  -67.416  51.012  1
400661  98.268  -67.420  50.963  1
400662  98.290  -67.423  50.913  1
400663  98.322  -67.426  50.866  1
400664  98.355  -67.429  50.822  1
400665  98.387  -67.432  50.783  1
400666  98.419  -67.435  50.745  1
400667  98.451  -67.439  50.705  1
400668  98.482  -67.443  50.664  1
400669  98.509  -67.450  50.622  1
400670  98.536  -67.456  50.577  1
400671  98.574  -67.464  50.531  1
400672  98.617  -67.473  50.483  1
400673  98.659  -67.482  50.435  1
400674  98.701  -67.492  50.386  1
400675  98.741  -67.509  50.335  1
400676  98.790  -67.510  50.284  1
400677  98.839  -67.511  50.235  1
400678  98.887  -67.513  50.185  1
400679  98.936  -67.515  50.136  1
400680  98.989  -67.522  50.086  1
400681  99.041  -67.529  50.036  1
400682  99.093  -67.537  49.985  1
400683  99.145  -67.545  49.935  1
400684  99.198  -67.551  49.885  1
400685  99.250  -67.559  49.836  1
400686  99.302  -67.567  49.787  1
400687  99.354  -67.574  49.739  1
400688  99.407  -67.581  49.690  1
400689  99.459  -67.589  49.641  1
400690  99.511  -67.596  49.591  1
400691  99.556  -67.605  49.542  1
400692  99.556  -67.622  49.496  1
400693  99.556  -67.639  49.449  1
400694  99.557  -67.655  49.403  1
400695  99.596  -67.649  49.357  1
400696  99.644  -67.658  49.312  1
400697  99.681  -67.692  49.266  1
400698  99.718  -67.727  49.222  1
400699  99.756  -67.762  49.179  1
400700  99.793  -67.796  49.135  1
400701  99.835  -67.829  49.092  1
400702  99.845  -67.818  49.048  1
400703  99.855  -67.807  49.004  1
400704  99.864  -67.796  48.959  1
400705  99.874  -67.784  48.915  1
400706  99.894  -67.783  48.870  1
400707  99.928  -67.784  48.825  1
400708  99.967  -67.782  48.779  1
400709  100.007  -67.780  48.732  1
400710  100.047  -67.778  48.687  1
400711  100.086  -67.776  48.644  1
400712  100.126  -67.774  48.602  1
400713  100.165  -67.772  48.560  1
400714  100.205  -67.770  48.518  1
400715  100.245  -67.768  48.476  1
400716  100.284  -67.766  48.434  1
400717  100.324  -67.764  48.392  1
400718  100.363  -67.761  48.352  1
400719  100.403  -67.760  48.310  1
400720  100.443  -67.758  48.269  1
401159  89.907  -66.985  54.908  1
401160  89.947  -66.992  54.911  1
401161  89.993  -66.997  54.916  1
401162  90.040  -67.000  54.921  1
401163  90.086  -67.004  54.929  1
401164  90.132  -67.008  54.937  1
401165  90.183  -67.002  54.946  1
401166  90.240  -66.984  54.954  1
401167  90.297  -66.967  54.963  1
401168  90.353  -66.950  54.973  1
401169  90.410  -66.932  54.983  1
401170  90.466  -66.914  54.994  1
401171  90.523  -66.907  55.005  1
401172  90.578  -66.912  55.015  1
401173  90.634  -66.915  55.024  1
401174  90.691  -66.921  55.031  1
401175  90.750  -66.928  55.036  1
401176  90.809  -66.935  55.039  1
401177  90.868  -66.942  55.046  1
401178  90.927  -66.949  55.058  1
401179  90.986  -66.956  55.074  1
401180  91.045  -66.963  55.090  1
401181  91.104  -66.970  55.101  1
401182  91.159  -66.977  55.107  1
401183  91.203  -66.985  55.109  1
401184  91.246  -66.994  55.108  1
401185  91.290  -67.001  55.106  1
401186  91.333  -67.009  55.099  1
401187  91.376  -67.012  55.093  1
401188  91.418  -67.006  55.086  1
401189  91.459  -66.998  55.077  1
401190  91.501  -66.991  55.068  1
401191  91.543  -66.984  55.059  1
401192  91.585  -66.978  55.049  1
401193  91.626  -66.970  55.039  1
401194  91.668  -66.963  55.026  1
401195  91.710  -66.956  55.009  1
401196  91.754  -66.959  54.993  1
401197  91.799  -66.963  54.975  1
401198  91.844  -66.967  54.954  1
401199  91.888  -66.970  54.932  1
401200  91.933  -66.974  54.911  1
401201  91.978  -66.978  54.889  1
401202  92.022  -66.981  54.867  1
401203  92.067  -66.984  54.844  1
401204  92.111  -66.988  54.822  1
401205  92.159  -66.992  54.801  1
401206  92.213  -66.996  54.782  1
401207  92.266  -67.000  54.762  1
401208  92.322  -67.005  54.741  1
401209  92.385  -67.015  54.720  1
401210  92.448  -67.026  54.703  1
401211  92.512  -67.036  54.688  1
401212  92.575  -67.047  54.678  1
401213  92.638  -67.057  54.668  1
401214  92.702  -67.068  54.654  1
401215  92.765  -67.078  54.637  1
401216  92.828  -67.089  54.617  1
401217  92.873  -67.077  54.593  1
401218  92.915  -67.059  54.567  1
401219  92.956  -67.042  54.544  1
401220  92.998  -67.025  54.520  1
401221  93.039  -67.007  54.496  1
401222  93.081  -66.990  54.474  1
401223  93.122  -66.972  54.454  1
401224  93.163  -66.955  54.432  1
401225  93.205  -66.937  54.407  1
401226  93.246  -66.921  54.380  1
401227  93.285  -66.924  54.353  1
401228  93.322  -66.928  54.326  1
401229  93.359  -66.933  54.299  1
401230  93.396  -66.937  54.272  1
401231  93.433  -66.942  54.242  1
401232  93.470  -66.946  54.213  1
401233  93.507  -66.950  54.186  1
401234  93.544  -66.955  54.161  1
401235  93.581  -66.959  54.139  1
401236  93.614  -66.956  54.121  1
401237  93.644  -66.950  54.106  1
401238  93.678  -66.950  54.092  1
401239  93.712  -66.949  54.078  1
401240  93.746  -66.949  54.065  1
401241  93.780  -66.949  54.054  1
401242  93.814  -66.949  54.045  1
401243  93.848  -66.949  54.036  1
401244  93.882  -66.948  54.027  1
401245  93.919  -66.950  54.016  1
401246  93.958  -66.953  54.003  1
401247  93.999  -66.956  53.986  1
401248  94.044  -66.961  53.968  1
401249  94.090  -66.966  53.950  1
401250  94.135  -66.972  53.932  1
401251  94.181  -66.977  53.914  1
401252  94.226  -66.982  53.895  1
401253  94.271  -66.987  53.875  1
401254  94.314  -66.992  53.853  1
401255  94.356  -66.997  53.830  1
401256  94.394  -67.000  53.806  1
401257  94.415  -66.997  53.780  1
401258  94.439  -66.994  53.752  1
401259  94.480  -66.994  53.725  1
401260  94.521  -66.994  53.697  1
401261  94.562  -66.993  53.668  1
401262  94.603  -66.993  53.640  1
401263  94.644  -66.993  53.613  1
401264  94.687  -66.993  53.586  1
401265  94.739  -66.995  53.560  1
401266  94.791  -66.997  53.532  1
401267  94.843  -67.001  53.501  1
401268  94.895  -67.009  53.469  1
401269  94.948  -67.017  53.437  1
401270  94.991  -67.019  53.410  1
401271  95.011  -67.006  53.386  1
401272  95.031  -66.994  53.366  1
401273  95.057  -66.986  53.350  1
401274  95.089  -66.984  53.334  1
401275  95.120  -66.983  53.319  1
401276  95.154  -66.982  53.305  1
401277  95.204  -66.984  53.294  1
401278  95.254  -66.987  53.282  1
401279  95.305  -66.990  53.270  1
401280  95.355  -66.992  53.260  1
401281  95.404  -66.994  53.249  1
401282  95.451  -66.997  53.235  1
401283  95.496  -67.001  53.218  1
401284  95.540  -67.010  53.199  1
401285  95.584  -67.019  53.181  1
401286  95.628  -67.028  53.161  1
401287  95.672  -67.037  53.141  1
401288  95.716  -67.047  53.121  1
401289  95.760  -67.056  53.100  1
401290  95.804  -67.065  53.078  1
401291  95.847  -67.074  53.054  1
401292  95.891  -67.083  53.033  1
401293  95.931  -67.093  53.011  1
401294  95.967  -67.094  52.989  1
401295  96.002  -67.089  52.966  1
401296  96.033  -67.088  52.939  1
401297  96.065  -67.086  52.911  1
401298  96.098  -67.084  52.883  1
401299  96.129  -67.083  52.854  1
401300  96.161  -67.083  52.824  1
401301  96.192  -67.089  52.793  1
401302  96.223  -67.096  52.762  1
401303  96.253  -67.102  52.730  1
401304  96.284  -67.108  52.696  1
401305  96.312  -67.116  52.664  1
401306  96.339  -67.125  52.633  1
401307  96.367  -67.134  52.602  1
401308  96.393  -67.143  52.573  1
401309  96.424  -67.149  52.545  1
401310  96.456  -67.153  52.518  1
401311  96.489  -67.157  52.493  1
401312  96.524  -67.156  52.470  1
401313  96.558  -67.155  52.450  1
401314  96.593  -67.155  52.432  1
401315  96.627  -67.154  52.414  1
401316  96.662  -67.154  52.395  1
401317  96.696  -67.153  52.375  1
401318  96.731  -67.153  52.354  1
401319  96.765  -67.157  52.335  1
401320  96.799  -67.160  52.316  1
401321  96.839  -67.160  52.297  1
401322  96.880  -67.160  52.279  1
401323  96.920  -67.160  52.259  1
401324  96.960  -67.160  52.242  1
401325  97.001  -67.159  52.225  1
401326  97.041  -67.159  52.207  1
401327  97.082  -67.158  52.190  1
401328  97.122  -67.158  52.173  1
401329  97.163  -67.158  52.156  1
401330  97.203  -67.157  52.138  1
401331  97.245  -67.163  52.118  1
401332  97.288  -67.170  52.094  1
401333  97.331  -67.177  52.069  1
401334  97.374  -67.185  52.043  1
401335  97.417  -67.191  52.015  1
401336  97.459  -67.198  51.984  1
401337  97.488  -67.206  51.952  1
401338  97.516  -67.213  51.919  1
401339  97.545  -67.220  51.886  1
401340  97.574  -67.228  51.854  1
401341  97.605  -67.233  51.821  1
401342  97.637  -67.238  51.787  1
401343  97.670  -67.243  51.753  1
401344  97.702  -67.248  51.720  1
401345  97.747  -67.247  51.687  1
401346  97.798  -67.243  51.654  1
401347  97.849  -67.244  51.620  1
401348  97.891  -67.248  51.584  1
401349  97.918  -67.258  51.545  1
401350  97.944  -67.269  51.505  1
401351  97.969  -67.279  51.463  1
401352  97.996  -67.288  51.420  1
401353  98.022  -67.298  51.377  1
401354  98.048  -67.308  51.333  1
401355  98.074  -67.319  51.287  1
401356  98.100  -67.329  51.241  1
401357  98.126  -67.338  51.196  1
401358  98.152  -67.348  51.149  1
401359  98.178  -67.358  51.102  1
401360  98.208  -67.369  51.057  1
401361  98.240  -67.377  51.009  1
401362  98.273  -67.381  50.960  1
401363  98.305  -67.384  50.911  1
401364  98.337  -67.387  50.864  1
401365  98.369  -67.390  50.819  1
401366  98.402  -67.394  50.777  1
401367  98.434  -67.397  50.736  1
401368  98.465  -67.401  50.695  1
401369  98.492  -67.407  50.654  1
401370  98.519  -67.413  50.613  1
401371  98.547  -67.420  50.570  1
401372  98.577  -67.428  50.526  1
401373  98.619  -67.436  50.481  1
401374  98.661  -67.445  50.432  1
401375  98.703  -67.455  50.383  1
401376  98.746  -67.467  50.333  1
401377  98.795  -67.468  50.282  1
401378  98.844  -67.470  50.233  1
401379  98.892  -67.471  50.182  1
401380  98.941  -67.472  50.133  1
401381  98.993  -67.478  50.083  1
401382  99.045  -67.485  50.033  1
401383  99.097  -67.492  49.980  1
401384  99.149  -67.500  49.929  1
401385  99.202  -67.508  49.879  1
401386  99.254  -67.514  49.829  1
401387  99.306  -67.522  49.779  1
401388  99.358  -67.529  49.730  1
401389  99.411  -67.537  49.681  1
401390  99.463  -67.544  49.631  1
401391  99.515  -67.551  49.583  1
401392  99.528  -67.566  49.534  1
401393  99.528  -67.583  49.487  1
401394  99.528  -67.600  49.441  1
401395  99.556  -67.617  49.395  1
401396  99.594  -67.632  49.348  1
401397  99.642  -67.626  49.303  1
401398  99.681  -67.655  49.258  1
401399  99.718  -67.689  49.213  1
401400  99.756  -67.724  49.170  1
401401  99.793  -67.759  49.126  1
401402  99.828  -67.768  49.082  1
401403  99.838  -67.757  49.038  1
401404  99.848  -67.746  48.993  1
401405  99.861  -67.733  48.948  1
401406  99.885  -67.731  48.904  1
401407  99.899  -67.739  48.858  1
401408  99.937  -67.738  48.813  1
401409  99.977  -67.736  48.767  1
401410  100.016  -67.734  48.721  1
401411  100.056  -67.732  48.676  1
401412  100.095  -67.730  48.633  1
401413  100.135  -67.728  48.591  1
401414  100.174  -67.726  48.549  1
401415  100.214  -67.724  48.508  1
401416  100.254  -67.722  48.466  1
401417  100.293  -67.720  48.424  1
401418  100.333  -67.717  48.382  1
401419  100.372  -67.716  48.343  1
401420  100.412  -67.714  48.302  1
401421  100.458  -67.711  48.261  1
401860  89.903  -66.935  54.907  1
401861  89.950  -66.939  54.910  1
401862  89.996  -66.943  54.915  1
401863  90.042  -66.947  54.919  1
401864  90.088  -66.951  54.927  1
401865  90.134  -66.955  54.935  1
401866  90.191  -66.937  54.943  1
401867  90.247  -66.920  54.951  1
401868  90.304  -66.903  54.960  1
401869  90.361  -66.885  54.969  1
401870  90.417  -66.868  54.979  1
401871  90.474  -66.853  54.989  1
401872  90.530  -66.858  54.999  1
401873  90.586  -66.862  55.009  1
401874  90.641  -66.866  55.019  1
401875  90.696  -66.871  55.027  1
401876  90.754  -66.876  55.034  1
401877  90.813  -66.884  55.040  1
401878  90.872  -66.890  55.049  1
401879  90.931  -66.897  55.065  1
401880  90.990  -66.904  55.082  1
401881  91.049  -66.911  55.098  1
401882  91.108  -66.918  55.109  1
401883  91.158  -66.925  55.116  1
401884  91.202  -66.934  55.119  1
401885  91.246  -66.941  55.119  1
401886  91.289  -66.950  55.117  1
401887  91.333  -66.958  55.111  1
401888  91.376  -66.965  55.105  1
401889  91.418  -66.958  55.098  1
401890  91.460  -66.951  55.091  1
401891  91.502  -66.944  55.082  1
401892  91.543  -66.937  55.071  1
401893  91.585  -66.930  55.061  1
401894  91.627  -66.923  55.051  1
401895  91.668  -66.916  55.038  1
401896  91.711  -66.913  55.022  1
401897  91.755  -66.917  55.005  1
401898  91.800  -66.920  54.986  1
401899  91.845  -66.924  54.964  1
401900  91.889  -66.928  54.941  1
401901  91.934  -66.931  54.920  1
401902  91.979  -66.934  54.898  1
401903  92.023  -66.938  54.877  1
401904  92.068  -66.941  54.856  1
401905  92.112  -66.945  54.834  1
401906  92.157  -66.949  54.815  1
401907  92.210  -66.953  54.796  1
401908  92.266  -66.958  54.778  1
401909  92.329  -66.968  54.756  1
401910  92.392  -66.979  54.737  1
401911  92.455  -66.989  54.722  1
401912  92.519  -67.000  54.711  1
401913  92.582  -67.010  54.703  1
401914  92.645  -67.021  54.695  1
401915  92.709  -67.031  54.684  1
401916  92.772  -67.042  54.669  1
401917  92.834  -67.050  54.651  1
401918  92.875  -67.033  54.627  1
401919  92.917  -67.015  54.602  1
401920  92.958  -66.998  54.578  1
401921  93.000  -66.981  54.553  1
401922  93.041  -66.964  54.526  1
401923  93.082  -66.946  54.499  1
401924  93.124  -66.929  54.472  1
401925  93.165  -66.912  54.446  1
401926  93.207  -66.894  54.420  1
401927  93.246  -66.879  54.393  1
401928  93.283  -66.877  54.365  1
401929  93.320  -66.881  54.337  1
401930  93.357  -66.884  54.310  1
401931  93.395  -66.888  54.282  1
401932  93.432  -66.893  54.253  1
401933  93.470  -66.896  54.225  1
401934  93.506  -66.901  54.198  1
401935  93.544  -66.906  54.173  1
401936  93.580  -66.910  54.151  1
401937  93.615  -66.909  54.135  1
401938  93.648  -66.909  54.119  1
401939  93.683  -66.909  54.103  1
401940  93.716  -66.909  54.088  1
401941  93.751  -66.909  54.075  1
401942  93.784  -66.908  54.066  1
401943  93.819  -66.908  54.058  1
401944  93.852  -66.908  54.050  1
401945  93.887  -66.908  54.042  1
401946  93.922  -66.909  54.031  1
401947  93.961  -66.911  54.017  1
401948  94.005  -66.915  54.000  1
401949  94.051  -66.921  53.982  1
401950  94.096  -66.926  53.964  1
401951  94.142  -66.931  53.947  1
401952  94.185  -66.936  53.931  1
401953  94.228  -66.941  53.913  1
401954  94.271  -66.946  53.893  1
401955  94.314  -66.950  53.872  1
401956  94.356  -66.956  53.849  1
401957  94.399  -66.960  53.824  1
401958  94.420  -66.957  53.798  1
401959  94.441  -66.954  53.769  1
401960  94.463  -66.951  53.741  1
401961  94.487  -66.948  53.713  1
401962  94.529  -66.948  53.684  1
401963  94.580  -66.950  53.655  1
401964  94.632  -66.953  53.627  1
401965  94.684  -66.955  53.599  1
401966  94.736  -66.957  53.570  1
401967  94.788  -66.959  53.540  1
401968  94.840  -66.962  53.507  1
401969  94.892  -66.969  53.474  1
401970  94.945  -66.978  53.444  1
401971  94.984  -66.977  53.418  1
401972  95.004  -66.964  53.395  1
401973  95.024  -66.951  53.376  1
401974  95.055  -66.950  53.360  1
401975  95.087  -66.948  53.345  1
401976  95.118  -66.946  53.330  1
401977  95.149  -66.945  53.316  1
401978  95.195  -66.946  53.307  1
401979  95.246  -66.949  53.296  1
401980  95.296  -66.951  53.286  1
401981  95.346  -66.954  53.276  1
401982  95.397  -66.956  53.266  1
401983  95.448  -66.963  53.252  1
401984  95.491  -66.969  53.234  1
401985  95.535  -66.978  53.214  1
401986  95.579  -66.987  53.194  1
401987  95.623  -66.997  53.174  1
401988  95.667  -67.006  53.154  1
401989  95.711  -67.015  53.134  1
401990  95.755  -67.024  53.113  1
401991  95.799  -67.033  53.091  1
401992  95.843  -67.042  53.068  1
401993  95.887  -67.051  53.046  1
401994  95.931  -67.060  53.025  1
401995  95.965  -67.061  53.003  1
401996  95.997  -67.059  52.980  1
401997  96.029  -67.058  52.953  1
401998  96.061  -67.056  52.925  1
401999  96.093  -67.055  52.898  1
402000  96.125  -67.053  52.870  1
402001  96.157  -67.053  52.840  1
402002  96.188  -67.057  52.810  1
402003  96.219  -67.063  52.779  1
402004  96.249  -67.070  52.746  1
402005  96.279  -67.076  52.712  1
402006  96.310  -67.082  52.680  1
402007  96.340  -67.089  52.648  1
402008  96.371  -67.095  52.617  1
402009  96.398  -67.104  52.587  1
402010  96.425  -67.113  52.559  1
402011  96.457  -67.118  52.532  1
402012  96.490  -67.119  52.506  1
402013  96.525  -67.119  52.483  1
402014  96.559  -67.119  52.461  1
402015  96.594  -67.119  52.444  1
402016  96.629  -67.118  52.426  1
402017  96.663  -67.118  52.407  1
402018  96.698  -67.117  52.388  1
402019  96.733  -67.116  52.366  1
402020  96.767  -67.118  52.346  1
402021  96.802  -67.121  52.326  1
402022  96.842  -67.120  52.307  1
402023  96.883  -67.120  52.288  1
402024  96.923  -67.120  52.268  1
402025  96.964  -67.119  52.251  1
402026  97.004  -67.119  52.233  1
402027  97.044  -67.119  52.215  1
402028  97.083  -67.119  52.199  1
402029  97.122  -67.119  52.182  1
402030  97.162  -67.119  52.165  1
402031  97.204  -67.120  52.148  1
402032  97.246  -67.123  52.128  1
402033  97.290  -67.126  52.106  1
402034  97.333  -67.134  52.081  1
402035  97.376  -67.141  52.055  1
402036  97.419  -67.148  52.026  1
402037  97.459  -67.155  51.994  1
402038  97.488  -67.163  51.962  1
402039  97.516  -67.169  51.927  1
402040  97.545  -67.177  51.893  1
402041  97.574  -67.184  51.860  1
402042  97.603  -67.191  51.826  1
402043  97.636  -67.196  51.791  1
402044  97.668  -67.200  51.757  1
402045  97.707  -67.203  51.723  1
402046  97.757  -67.197  51.689  1
402047  97.808  -67.195  51.655  1
402048  97.860  -67.197  51.621  1
402049  97.885  -67.207  51.584  1
402050  97.912  -67.216  51.546  1
402051  97.938  -67.227  51.505  1
402052  97.964  -67.237  51.462  1
402053  97.990  -67.247  51.419  1
402054  98.016  -67.257  51.376  1
402055  98.042  -67.266  51.330  1
402056  98.068  -67.277  51.285  1
402057  98.094  -67.287  51.239  1
402058  98.125  -67.297  51.193  1
402059  98.157  -67.307  51.146  1
402060  98.190  -67.318  51.099  1
402061  98.222  -67.329  51.053  1
402062  98.255  -67.339  51.004  1
402063  98.287  -67.342  50.955  1
402064  98.319  -67.345  50.907  1
402065  98.352  -67.348  50.861  1
402066  98.384  -67.351  50.816  1
402067  98.416  -67.355  50.772  1
402068  98.448  -67.358  50.730  1
402069  98.476  -67.365  50.688  1
402070  98.503  -67.372  50.646  1
402071  98.530  -67.378  50.605  1
402072  98.557  -67.385  50.564  1
402073  98.584  -67.392  50.522  1
402074  98.621  -67.400  50.479  1
402075  98.663  -67.408  50.430  1
402076  98.703  -67.424  50.381  1
402077  98.751  -67.426  50.331  1
402078  98.800  -67.426  50.280  1
402079  98.849  -67.428  50.231  1
402080  98.898  -67.429  50.180  1
402081  98.947  -67.430  50.130  1
402082  98.997  -67.433  50.080  1
402083  99.049  -67.440  50.028  1
402084  99.101  -67.448  49.976  1
402085  99.153  -67.455  49.924  1
402086  99.206  -67.463  49.873  1
402087  99.258  -67.470  49.822  1
402088  99.310  -67.477  49.771  1
402089  99.362  -67.485  49.721  1
402090  99.415  -67.492  49.672  1
402091  99.467  -67.500  49.622  1
402092  99.500  -67.511  49.574  1
402093  99.500  -67.527  49.526  1
402094  99.500  -67.544  49.478  1
402095  99.524  -67.561  49.432  1
402096  99.568  -67.579  49.386  1
402097  99.614  -67.589  49.339  1
402098  99.632  -67.617  49.294  1
402099  99.681  -67.617  49.248  1
402100  99.718  -67.652  49.204  1
402101  99.755  -67.687  49.160  1
402102  99.808  -67.717  49.116  1
402103  99.821  -67.707  49.071  1
402104  99.831  -67.695  49.026  1
402105  99.851  -67.683  48.981  1
402106  99.877  -67.679  48.936  1
402107  99.885  -67.687  48.891  1
402108  99.906  -67.694  48.846  1
402109  99.946  -67.692  48.800  1
402110  99.986  -67.690  48.754  1
402111  100.025  -67.688  48.709  1
402112  100.065  -67.686  48.665  1
402113  100.105  -67.684  48.622  1
402114  100.144  -67.682  48.580  1
402115  100.184  -67.680  48.539  1
402116  100.223  -67.678  48.497  1
402117  100.263  -67.676  48.456  1
402118  100.302  -67.674  48.414  1
402119  100.342  -67.672  48.373  1
402120  100.382  -67.670  48.333  1
402121  100.424  -67.667  48.293  1
402561  89.906  -66.882  54.906  1
402562  89.952  -66.886  54.909  1
402563  89.998  -66.890  54.913  1
402564  90.044  -66.893  54.918  1
402565  90.090  -66.897  54.925  1
402566  90.142  -66.890  54.932  1
402567  90.198  -66.873  54.940  1
402568  90.255  -66.856  54.949  1
402569  90.312  -66.838  54.957  1
402570  90.369  -66.821  54.965  1
402571  90.426  -66.802  54.974  1
402572  90.481  -66.804  54.983  1
402573  90.537  -66.808  54.992  1
402574  90.593  -66.812  55.001  1
402575  90.648  -66.817  55.011  1
402576  90.704  -66.821  55.021  1
402577  90.759  -66.825  55.030  1
402578  90.817  -66.831  55.039  1
402579  90.876  -66.838  55.052  1
402580  90.935  -66.845  55.070  1
402581  90.994  -66.852  55.089  1
402582  91.053  -66.859  55.103  1
402583  91.112  -66.866  55.115  1
402584  91.158  -66.874  55.123  1
402585  91.202  -66.882  55.128  1
402586  91.245  -66.890  55.130  1
402587  91.289  -66.898  55.128  1
402588  91.332  -66.906  55.123  1
402589  91.376  -66.914  55.117  1
402590  91.419  -66.911  55.110  1
402591  91.460  -66.904  55.103  1
402592  91.502  -66.896  55.094  1
402593  91.543  -66.890  55.082  1
402594  91.585  -66.883  55.070  1
402595  91.627  -66.876  55.059  1
402596  91.668  -66.869  55.048  1
402597  91.713  -66.870  55.031  1
402598  91.757  -66.874  55.014  1
402599  91.802  -66.878  54.994  1
402600  91.847  -66.881  54.972  1
402601  91.891  -66.884  54.950  1
402602  91.936  -66.888  54.929  1
402603  91.981  -66.891  54.908  1
402604  92.025  -66.895  54.887  1
402605  92.070  -66.899  54.867  1
402606  92.114  -66.902  54.847  1
402607  92.159  -66.906  54.829  1
402608  92.210  -66.911  54.811  1
402609  92.273  -66.921  54.792  1
402610  92.336  -66.932  54.770  1
402611  92.400  -66.942  54.754  1
402612  92.463  -66.953  54.742  1
402613  92.526  -66.963  54.734  1
402614  92.589  -66.974  54.728  1
402615  92.653  -66.984  54.722  1
402616  92.716  -66.995  54.714  1
402617  92.779  -67.006  54.702  1
402618  92.836  -67.007  54.684  1
402619  92.877  -66.990  54.662  1
402620  92.918  -66.972  54.638  1
402621  92.960  -66.955  54.614  1
402622  93.001  -66.937  54.588  1
402623  93.043  -66.920  54.559  1
402624  93.084  -66.903  54.528  1
402625  93.126  -66.885  54.496  1
402626  93.166  -66.868  54.466  1
402627  93.205  -66.855  54.437  1
402628  93.242  -66.840  54.408  1
402629  93.278  -66.831  54.379  1
402630  93.315  -66.834  54.350  1
402631  93.353  -66.839  54.321  1
402632  93.391  -66.843  54.293  1
402633  93.428  -66.846  54.265  1
402634  93.466  -66.851  54.239  1
402635  93.503  -66.855  54.213  1
402636  93.540  -66.859  54.190  1
402637  93.578  -66.862  54.168  1
402638  93.616  -66.868  54.151  1
402639  93.652  -66.869  54.133  1
402640  93.687  -66.868  54.116  1
402641  93.721  -66.868  54.101  1
402642  93.755  -66.868  54.089  1
402643  93.789  -66.868  54.080  1
402644  93.823  -66.867  54.073  1
402645  93.857  -66.867  54.066  1
402646  93.891  -66.867  54.058  1
402647  93.925  -66.867  54.047  1
402648  93.966  -66.870  54.032  1
402649  94.011  -66.875  54.015  1
402650  94.057  -66.881  53.997  1
402651  94.099  -66.885  53.979  1
402652  94.142  -66.890  53.963  1
402653  94.185  -66.895  53.948  1
402654  94.227  -66.900  53.931  1
402655  94.270  -66.905  53.912  1
402656  94.313  -66.909  53.892  1
402657  94.356  -66.914  53.868  1
402658  94.399  -66.919  53.843  1
402659  94.426  -66.918  53.816  1
402660  94.447  -66.915  53.787  1
402661  94.469  -66.912  53.758  1
402662  94.490  -66.909  53.729  1
402663  94.530  -66.910  53.700  1
402664  94.578  -66.912  53.670  1
402665  94.630  -66.915  53.641  1
402666  94.682  -66.917  53.611  1
402667  94.734  -66.919  53.580  1
402668  94.785  -66.921  53.547  1
402669  94.837  -66.924  53.514  1
402670  94.890  -66.930  53.481  1
402671  94.942  -66.938  53.452  1
402672  94.977  -66.934  53.426  1
402673  94.996  -66.921  53.404  1
402674  95.023  -66.915  53.386  1
402675  95.054  -66.913  53.371  1
402676  95.085  -66.912  53.356  1
402677  95.116  -66.909  53.342  1
402678  95.147  -66.908  53.329  1
402679  95.186  -66.908  53.321  1
402680  95.237  -66.911  53.312  1
402681  95.287  -66.913  53.303  1
402682  95.338  -66.915  53.294  1
402683  95.388  -66.918  53.284  1
402684  95.447  -66.947  53.268  1
402685  95.487  -66.943  53.248  1
402686  95.528  -66.941  53.228  1
402687  95.571  -66.950  53.207  1
402688  95.616  -66.960  53.187  1
402689  95.660  -66.969  53.167  1
402690  95.703  -66.978  53.147  1
402691  95.748  -66.987  53.126  1
402692  95.792  -66.997  53.105  1
402693  95.835  -67.006  53.082  1
402694  95.880  -67.015  53.061  1
402695  95.922  -67.024  53.039  1
402696  95.959  -67.028  53.017  1
402697  95.993  -67.030  52.994  1
402698  96.025  -67.028  52.967  1
402699  96.057  -67.027  52.940  1
402700  96.089  -67.026  52.913  1
402701  96.121  -67.025  52.886  1
402702  96.153  -67.023  52.857  1
402703  96.184  -67.025  52.827  1
402704  96.215  -67.031  52.796  1
402705  96.245  -67.037  52.764  1
402706  96.276  -67.044  52.731  1
402707  96.306  -67.050  52.698  1
402708  96.337  -67.056  52.666  1
402709  96.367  -67.063  52.634  1
402710  96.398  -67.069  52.604  1
402711  96.429  -67.075  52.576  1
402712  96.458  -67.083  52.548  1
402713  96.492  -67.083  52.521  1
402714  96.527  -67.082  52.496  1
402715  96.561  -67.082  52.474  1
402716  96.596  -67.081  52.455  1
402717  96.630  -67.081  52.437  1
402718  96.665  -67.081  52.418  1
402719  96.699  -67.081  52.399  1
402720  96.734  -67.080  52.379  1
402721  96.768  -67.080  52.360  1
402722  96.805  -67.081  52.341  1
402723  96.846  -67.081  52.321  1
402724  96.886  -67.081  52.300  1
402725  96.925  -67.080  52.279  1
402726  96.964  -67.080  52.260  1
402727  97.003  -67.080  52.241  1
402728  97.042  -67.080  52.223  1
402729  97.082  -67.080  52.205  1
402730  97.121  -67.080  52.189  1
402731  97.162  -67.081  52.171  1
402732  97.205  -67.083  52.154  1
402733  97.247  -67.086  52.136  1
402734  97.291  -67.089  52.115  1
402735  97.334  -67.092  52.092  1
402736  97.378  -67.097  52.066  1
402737  97.421  -67.104  52.037  1
402738  97.458  -67.112  52.004  1
402739  97.487  -67.119  51.972  1
402740  97.516  -67.126  51.937  1
402741  97.544  -67.133  51.902  1
402742  97.573  -67.141  51.867  1
402743  97.602  -67.147  51.832  1
402744  97.635  -67.153  51.797  1
402745  97.667  -67.158  51.761  1
402746  97.717  -67.153  51.725  1
402747  97.768  -67.149  51.690  1
402748  97.819  -67.148  51.655  1
402749  97.854  -67.155  51.620  1
402750  97.880  -67.165  51.583  1
402751  97.906  -67.175  51.544  1
402752  97.932  -67.185  51.502  1
402753  97.958  -67.195  51.461  1
402754  97.984  -67.205  51.419  1
402755  98.010  -67.215  51.375  1
402756  98.042  -67.225  51.329  1
402757  98.074  -67.236  51.282  1
402758  98.107  -67.247  51.236  1
402759  98.139  -67.257  51.189  1
402760  98.172  -67.267  51.141  1
402761  98.204  -67.278  51.093  1
402762  98.237  -67.288  51.046  1
402763  98.270  -67.299  50.997  1
402764  98.302  -67.304  50.949  1
402765  98.334  -67.307  50.902  1
402766  98.366  -67.310  50.857  1
402767  98.398  -67.313  50.813  1
402768  98.431  -67.316  50.770  1
402769  98.459  -67.323  50.728  1
402770  98.486  -67.329  50.684  1
402771  98.513  -67.335  50.641  1
402772  98.540  -67.342  50.599  1
402773  98.567  -67.349  50.559  1
402774  98.594  -67.356  50.518  1
402775  98.624  -67.363  50.476  1
402776  98.666  -67.372  50.427  1
402777  98.708  -67.382  50.379  1
402778  98.757  -67.383  50.330  1
402779  98.806  -67.385  50.280  1
402780  98.855  -67.386  50.230  1
402781  98.904  -67.387  50.178  1
402782  98.952  -67.388  50.127  1
402783  99.001  -67.390  50.076  1
402784  99.053  -67.396  50.023  1
402785  99.105  -67.403  49.971  1
402786  99.157  -67.410  49.920  1
402787  99.209  -67.418  49.867  1
402788  99.262  -67.426  49.814  1
402789  99.314  -67.433  49.763  1
402790  99.366  -67.440  49.713  1
402791  99.418  -67.448  49.663  1
402792  99.471  -67.455  49.613  1
402793  99.472  -67.472  49.565  1
402794  99.473  -67.489  49.516  1
402795  99.492  -67.505  49.470  1
402796  99.536  -67.523  49.423  1
402797  99.579  -67.540  49.376  1
402798  99.624  -67.555  49.330  1
402799  99.663  -67.561  49.285  1
402800  99.675  -67.595  49.239  1
402801  99.718  -67.614  49.194  1
402802  99.755  -67.649  49.149  1
402803  99.804  -67.657  49.104  1
402804  99.814  -67.645  49.058  1
402805  99.841  -67.632  49.013  1
402806  99.869  -67.627  48.968  1
402807  99.877  -67.635  48.923  1
402808  99.890  -67.643  48.877  1
402809  99.916  -67.648  48.833  1
402810  99.955  -67.646  48.787  1
402811  99.995  -67.644  48.741  1
402812  100.034  -67.642  48.697  1
402813  100.074  -67.640  48.654  1
402814  100.114  -67.638  48.611  1
402815  100.153  -67.636  48.570  1
402816  100.193  -67.634  48.529  1
402817  100.232  -67.632  48.487  1
402818  100.272  -67.630  48.447  1
402819  100.312  -67.628  48.405  1
402820  100.351  -67.626  48.363  1
402821  100.391  -67.623  48.324  1
402822  100.438  -67.622  48.283  1
403262  89.908  -66.829  54.907  1
403263  89.954  -66.833  54.908  1
403264  90.001  -66.837  54.911  1
403265  90.046  -66.840  54.915  1
403266  90.093  -66.843  54.922  1
403267  90.150  -66.826  54.929  1
403268  90.206  -66.809  54.937  1
403269  90.263  -66.791  54.945  1
403270  90.320  -66.774  54.952  1
403271  90.377  -66.756  54.960  1
403272  90.433  -66.750  54.968  1
403273  90.488  -66.754  54.977  1
403274  90.544  -66.758  54.986  1
403275  90.600  -66.763  54.996  1
403276  90.655  -66.767  55.005  1
403277  90.711  -66.771  55.015  1
403278  90.766  -66.775  55.025  1
403279  90.822  -66.780  55.036  1
403280  90.880  -66.786  55.052  1
403281  90.939  -66.793  55.072  1
403282  90.998  -66.800  55.092  1
403283  91.057  -66.807  55.108  1
403284  91.114  -66.814  55.118  1
403285  91.158  -66.822  55.128  1
403286  91.202  -66.830  55.136  1
403287  91.245  -66.838  55.141  1
403288  91.289  -66.846  55.140  1
403289  91.332  -66.854  55.135  1
403290  91.376  -66.862  55.129  1
403291  91.419  -66.864  55.122  1
403292  91.460  -66.856  55.114  1
403293  91.502  -66.849  55.104  1
403294  91.544  -66.843  55.092  1
403295  91.585  -66.836  55.079  1
403296  91.627  -66.828  55.067  1
403297  91.669  -66.824  55.056  1
403298  91.714  -66.827  55.039  1
403299  91.758  -66.831  55.020  1
403300  91.803  -66.834  55.000  1
403301  91.848  -66.838  54.979  1
403302  91.892  -66.841  54.958  1
403303  91.937  -66.845  54.937  1
403304  91.982  -66.849  54.917  1
403305  92.026  -66.852  54.897  1
403306  92.071  -66.856  54.878  1
403307  92.116  -66.859  54.859  1
403308  92.162  -66.865  54.841  1
403309  92.220  -66.874  54.823  1
403310  92.280  -66.885  54.805  1
403311  92.344  -66.895  54.785  1
403312  92.407  -66.906  54.769  1
403313  92.470  -66.916  54.758  1
403314  92.533  -66.927  54.752  1
403315  92.596  -66.937  54.751  1
403316  92.660  -66.948  54.749  1
403317  92.723  -66.959  54.743  1
403318  92.786  -66.968  54.733  1
403319  92.837  -66.963  54.718  1
403320  92.879  -66.946  54.696  1
403321  92.920  -66.929  54.674  1
403322  92.961  -66.912  54.650  1
403323  93.003  -66.894  54.624  1
403324  93.045  -66.877  54.594  1
403325  93.086  -66.859  54.560  1
403326  93.125  -66.844  54.525  1
403327  93.163  -66.830  54.490  1
403328  93.202  -66.815  54.457  1
403329  93.239  -66.802  54.425  1
403330  93.276  -66.791  54.394  1
403331  93.311  -66.789  54.363  1
403332  93.349  -66.793  54.335  1
403333  93.386  -66.797  54.308  1
403334  93.424  -66.801  54.281  1
403335  93.461  -66.805  54.256  1
403336  93.498  -66.809  54.232  1
403337  93.536  -66.813  54.208  1
403338  93.573  -66.817  54.186  1
403339  93.612  -66.823  54.166  1
403340  93.651  -66.831  54.147  1
403341  93.687  -66.832  54.129  1
403342  93.721  -66.831  54.115  1
403343  93.756  -66.830  54.104  1
403344  93.791  -66.829  54.095  1
403345  93.826  -66.828  54.088  1
403346  93.861  -66.827  54.082  1
403347  93.896  -66.827  54.073  1
403348  93.930  -66.826  54.063  1
403349  93.971  -66.829  54.048  1
403350  94.013  -66.834  54.031  1
403351  94.056  -66.839  54.014  1
403352  94.099  -66.844  53.995  1
403353  94.142  -66.849  53.979  1
403354  94.184  -66.853  53.964  1
403355  94.227  -66.859  53.949  1
403356  94.270  -66.863  53.932  1
403357  94.313  -66.868  53.912  1
403358  94.355  -66.873  53.889  1
403359  94.398  -66.878  53.863  1
403360  94.431  -66.879  53.834  1
403361  94.453  -66.876  53.804  1
403362  94.474  -66.873  53.773  1
403363  94.502  -66.871  53.743  1
403364  94.542  -66.873  53.714  1
403365  94.582  -66.874  53.684  1
403366  94.627  -66.877  53.654  1
403367  94.679  -66.879  53.623  1
403368  94.731  -66.881  53.590  1
403369  94.783  -66.884  53.555  1
403370  94.835  -66.886  53.521  1
403371  94.887  -66.890  53.489  1
403372  94.939  -66.899  53.460  1
403373  94.969  -66.892  53.435  1
403374  94.989  -66.879  53.414  1
403375  95.021  -66.878  53.396  1
403376  95.052  -66.876  53.381  1
403377  95.083  -66.874  53.367  1
403378  95.115  -66.873  53.354  1
403379  95.146  -66.871  53.344  1
403380  95.178  -66.870  53.336  1
403381  95.228  -66.873  53.329  1
403382  95.278  -66.875  53.322  1
403383  95.329  -66.878  53.313  1
403384  95.383  -66.892  53.301  1
403385  95.445  -66.932  53.283  1
403386  95.485  -66.928  53.262  1
403387  95.526  -66.924  53.240  1
403388  95.566  -66.920  53.220  1
403389  95.608  -66.923  53.199  1
403390  95.652  -66.932  53.179  1
403391  95.696  -66.941  53.160  1
403392  95.740  -66.950  53.141  1
403393  95.784  -66.959  53.120  1
403394  95.828  -66.969  53.098  1
403395  95.872  -66.978  53.077  1
403396  95.913  -66.986  53.055  1
403397  95.950  -66.992  53.032  1
403398  95.985  -66.996  53.008  1
403399  96.021  -67.000  52.983  1
403400  96.052  -66.998  52.956  1
403401  96.085  -66.997  52.929  1
403402  96.117  -66.995  52.902  1
403403  96.149  -66.994  52.873  1
403404  96.181  -66.993  52.844  1
403405  96.211  -66.999  52.814  1
403406  96.242  -67.006  52.782  1
403407  96.272  -67.012  52.750  1
403408  96.303  -67.019  52.717  1
403409  96.333  -67.025  52.684  1
403410  96.364  -67.031  52.653  1
403411  96.394  -67.037  52.622  1
403412  96.425  -67.044  52.593  1
403413  96.457  -67.045  52.565  1
403414  96.487  -67.044  52.537  1
403415  96.522  -67.043  52.511  1
403416  96.557  -67.043  52.488  1
403417  96.592  -67.042  52.468  1
403418  96.626  -67.042  52.449  1
403419  96.661  -67.042  52.430  1
403420  96.696  -67.041  52.411  1
403421  96.731  -67.041  52.392  1
403422  96.766  -67.041  52.374  1
403423  96.806  -67.041  52.355  1
403424  96.845  -67.041  52.335  1
403425  96.884  -67.041  52.313  1
403426  96.923  -67.041  52.291  1
403427  96.962  -67.041  52.271  1
403428  97.002  -67.041  52.252  1
403429  97.041  -67.041  52.233  1
403430  97.080  -67.041  52.214  1
403431  97.120  -67.041  52.197  1
403432  97.163  -67.044  52.179  1
403433  97.206  -67.047  52.162  1
403434  97.248  -67.049  52.145  1
403435  97.292  -67.052  52.125  1
403436  97.335  -67.055  52.103  1
403437  97.379  -67.058  52.077  1
403438  97.423  -67.061  52.047  1
403439  97.458  -67.068  52.015  1
403440  97.487  -67.075  51.981  1
403441  97.516  -67.082  51.945  1
403442  97.544  -67.090  51.909  1
403443  97.573  -67.097  51.874  1
403444  97.602  -67.104  51.839  1
403445  97.633  -67.110  51.802  1
403446  97.676  -67.109  51.766  1
403447  97.727  -67.105  51.730  1
403448  97.778  -67.100  51.693  1
403449  97.822  -67.103  51.656  1
403450  97.848  -67.113  51.619  1
403451  97.874  -67.123  51.580  1
403452  97.900  -67.134  51.540  1
403453  97.926  -67.144  51.497  1
403454  97.959  -67.154  51.455  1
403455  97.991  -67.164  51.413  1
403456  98.024  -67.175  51.369  1
403457  98.056  -67.185  51.324  1
403458  98.089  -67.196  51.277  1
403459  98.122  -67.207  51.230  1
403460  98.154  -67.217  51.183  1
403461  98.186  -67.228  51.136  1
403462  98.219  -67.238  51.087  1
403463  98.251  -67.248  51.039  1
403464  98.284  -67.259  50.991  1
403465  98.316  -67.265  50.945  1
403466  98.349  -67.268  50.900  1
403467  98.381  -67.271  50.857  1
403468  98.413  -67.275  50.814  1
403469  98.442  -67.280  50.772  1
403470  98.469  -67.287  50.730  1
403471  98.496  -67.293  50.686  1
403472  98.523  -67.300  50.643  1
403473  98.551  -67.307  50.600  1
403474  98.578  -67.313  50.557  1
403475  98.605  -67.319  50.516  1
403476  98.632  -67.326  50.473  1
403477  98.668  -67.335  50.427  1
403478  98.714  -67.341  50.380  1
403479  98.763  -67.341  50.331  1
403480  98.811  -67.343  50.281  1
403481  98.860  -67.344  50.230  1
403482  98.909  -67.345  50.178  1
403483  98.958  -67.347  50.126  1
403484  99.007  -67.348  50.073  1
403485  99.057  -67.351  50.020  1
403486  99.109  -67.359  49.968  1
403487  99.161  -67.366  49.915  1
403488  99.213  -67.373  49.861  1
403489  99.266  -67.381  49.808  1
403490  99.318  -67.388  49.756  1
403491  99.370  -67.396  49.705  1
403492  99.422  -67.403  49.655  1
403493  99.444  -67.416  49.606  1
403494  99.444  -67.433  49.557  1
403495  99.461  -67.450  49.509  1
403496  99.504  -67.467  49.462  1
403497  99.548  -67.485  49.415  1
403498  99.591  -67.501  49.368  1
403499  99.635  -67.519  49.323  1
403500  99.686  -67.514  49.276  1
403501  99.701  -67.545  49.230  1
403502  99.717  -67.577  49.183  1
403503  99.780  -67.604  49.138  1
403504  99.797  -67.595  49.092  1
403505  99.831  -67.581  49.046  1
403506  99.861  -67.574  49.000  1
403507  99.869  -67.583  48.955  1
403508  99.877  -67.591  48.909  1
403509  99.895  -67.599  48.864  1
403510  99.925  -67.602  48.819  1
403511  99.965  -67.600  48.774  1
403512  100.004  -67.598  48.729  1
403513  100.044  -67.596  48.686  1
403514  100.083  -67.594  48.643  1
403515  100.123  -67.592  48.600  1
403516  100.162  -67.590  48.559  1
403517  100.202  -67.588  48.518  1
403518  100.242  -67.586  48.477  1
403519  100.281  -67.584  48.436  1
403520  100.321  -67.582  48.394  1
403521  100.360  -67.580  48.354  1
403522  100.405  -67.578  48.314  1
403964  89.957  -66.779  54.908  1
403965  90.003  -66.784  54.910  1
403966  90.049  -66.787  54.913  1
403967  90.101  -66.779  54.919  1
403968  90.158  -66.762  54.926  1
403969  90.214  -66.744  54.933  1
403970  90.271  -66.727  54.941  1
403971  90.328  -66.709  54.948  1
403972  90.384  -66.696  54.955  1
403973  90.440  -66.700  54.963  1
403974  90.496  -66.705  54.972  1
403975  90.551  -66.708  54.981  1
403976  90.607  -66.713  54.991  1
403977  90.662  -66.718  55.000  1
403978  90.718  -66.721  55.009  1
403979  90.773  -66.726  55.020  1
403980  90.829  -66.730  55.032  1
403981  90.885  -66.734  55.049  1
403982  90.943  -66.741  55.069  1
403983  91.002  -66.748  55.091  1
403984  91.061  -66.755  55.108  1
403985  91.114  -66.762  55.120  1
403986  91.158  -66.771  55.131  1
403987  91.201  -66.778  55.140  1
403988  91.245  -66.787  55.148  1
403989  91.289  -66.795  55.149  1
403990  91.332  -66.802  55.147  1
403991  91.376  -66.811  55.141  1
403992  91.419  -66.816  55.134  1
403993  91.461  -66.809  55.125  1
403994  91.502  -66.802  55.113  1
403995  91.544  -66.796  55.100  1
403996  91.586  -66.788  55.087  1
403997  91.628  -66.781  55.074  1
403998  91.671  -66.780  55.061  1
403999  91.716  -66.784  55.044  1
404000  91.760  -66.788  55.026  1
404001  91.805  -66.791  55.006  1
404002  91.850  -66.795  54.985  1
404003  91.894  -66.799  54.965  1
404004  91.939  -66.802  54.945  1
404005  91.983  -66.805  54.926  1
404006  92.028  -66.809  54.907  1
404007  92.073  -66.813  54.888  1
404008  92.117  -66.819  54.871  1
404009  92.175  -66.829  54.853  1
404010  92.233  -66.839  54.835  1
404011  92.292  -66.849  54.818  1
404012  92.351  -66.859  54.800  1
404013  92.414  -66.869  54.785  1
404014  92.477  -66.880  54.774  1
404015  92.541  -66.890  54.769  1
404016  92.603  -66.901  54.770  1
404017  92.667  -66.911  54.771  1
404018  92.730  -66.921  54.768  1
404019  92.793  -66.932  54.760  1
404020  92.839  -66.920  54.747  1
404021  92.880  -66.903  54.728  1
404022  92.922  -66.885  54.706  1
404023  92.964  -66.868  54.681  1
404024  93.005  -66.851  54.654  1
404025  93.046  -66.834  54.622  1
404026  93.084  -66.819  54.588  1
404027  93.122  -66.805  54.553  1
404028  93.160  -66.791  54.517  1
404029  93.198  -66.777  54.482  1
404030  93.236  -66.763  54.448  1
404031  93.274  -66.750  54.415  1
404032  93.308  -66.746  54.384  1
404033  93.344  -66.747  54.357  1
404034  93.382  -66.751  54.332  1
404035  93.419  -66.755  54.306  1
404036  93.457  -66.759  54.281  1
404037  93.494  -66.763  54.254  1
404038  93.532  -66.767  54.228  1
404039  93.569  -66.771  54.203  1
404040  93.608  -66.777  54.180  1
404041  93.647  -66.786  54.159  1
404042  93.687  -66.795  54.142  1
404043  93.722  -66.794  54.129  1
404044  93.757  -66.793  54.119  1
404045  93.791  -66.793  54.111  1
404046  93.826  -66.792  54.105  1
404047  93.861  -66.791  54.098  1
404048  93.896  -66.790  54.089  1
404049  93.932  -66.784  54.078  1
404050  93.972  -66.789  54.064  1
404051  94.014  -66.793  54.047  1
404052  94.056  -66.798  54.029  1
404053  94.099  -66.802  54.011  1
404054  94.141  -66.808  53.995  1
404055  94.184  -66.812  53.981  1
404056  94.227  -66.817  53.966  1
404057  94.269  -66.822  53.951  1
404058  94.312  -66.827  53.931  1
404059  94.355  -66.832  53.908  1
404060  94.398  -66.837  53.882  1
404061  94.436  -66.840  53.853  1
404062  94.458  -66.837  53.822  1
404063  94.479  -66.834  53.789  1
404064  94.515  -66.834  53.758  1
404065  94.555  -66.836  53.728  1
404066  94.595  -66.837  53.698  1
404067  94.635  -66.840  53.667  1
404068  94.676  -66.841  53.635  1
404069  94.728  -66.843  53.600  1
404070  94.780  -66.846  53.564  1
404071  94.832  -66.848  53.530  1
404072  94.884  -66.852  53.498  1
404073  94.936  -66.859  53.469  1
404074  94.962  -66.850  53.445  1
404075  94.988  -66.843  53.424  1
404076  95.019  -66.841  53.407  1
404077  95.050  -66.840  53.392  1
404078  95.082  -66.838  53.380  1
404079  95.113  -66.837  53.369  1
404080  95.144  -66.835  53.359  1
404081  95.175  -66.834  53.352  1
404082  95.219  -66.834  53.346  1
404083  95.270  -66.837  53.339  1
404084  95.320  -66.840  53.329  1
404085  95.383  -66.878  53.315  1
404086  95.443  -66.914  53.294  1
404087  95.484  -66.912  53.272  1
404088  95.524  -66.909  53.251  1
404089  95.564  -66.905  53.231  1
404090  95.605  -66.901  53.212  1
404091  95.645  -66.896  53.193  1
404092  95.689  -66.905  53.175  1
404093  95.733  -66.914  53.157  1
404094  95.776  -66.923  53.138  1
404095  95.821  -66.932  53.118  1
404096  95.865  -66.941  53.096  1
404097  95.903  -66.948  53.073  1
404098  95.940  -66.954  53.049  1
404099  95.976  -66.959  53.025  1
404100  96.012  -66.963  52.999  1
404101  96.047  -66.967  52.973  1
404102  96.081  -66.967  52.945  1
404103  96.112  -66.965  52.918  1
404104  96.145  -66.964  52.890  1
404105  96.176  -66.962  52.863  1
404106  96.207  -66.967  52.833  1
404107  96.238  -66.973  52.802  1
404108  96.268  -66.980  52.769  1
404109  96.299  -66.986  52.736  1
404110  96.329  -66.993  52.703  1
404111  96.360  -66.999  52.672  1
404112  96.391  -67.004  52.641  1
404113  96.426  -67.006  52.612  1
404114  96.456  -67.006  52.583  1
404115  96.485  -67.004  52.555  1
404116  96.514  -67.002  52.527  1
404117  96.549  -67.002  52.503  1
404118  96.584  -67.002  52.482  1
404119  96.619  -67.001  52.462  1
404120  96.654  -67.001  52.443  1
404121  96.689  -67.001  52.423  1
404122  96.724  -67.000  52.406  1
404123  96.762  -67.001  52.388  1
404124  96.804  -67.003  52.369  1
404125  96.843  -67.003  52.349  1
404126  96.882  -67.003  52.327  1
404127  96.922  -67.002  52.305  1
404128  96.961  -67.002  52.283  1
404129  97.000  -67.002  52.263  1
404130  97.039  -67.002  52.243  1
404131  97.079  -67.002  52.223  1
404132  97.121  -67.004  52.206  1
404133  97.164  -67.007  52.188  1
404134  97.207  -67.009  52.171  1
404135  97.249  -67.012  52.156  1
404136  97.293  -67.015  52.137  1
404137  97.336  -67.018  52.115  1
404138  97.380  -67.021  52.088  1
404139  97.426  -67.019  52.058  1
404140  97.467  -67.023  52.025  1
404141  97.495  -67.031  51.990  1
404142  97.522  -67.038  51.953  1
404143  97.549  -67.046  51.916  1
404144  97.577  -67.053  51.881  1
404145  97.604  -67.060  51.845  1
404146  97.637  -67.065  51.808  1
404147  97.687  -67.060  51.771  1
404148  97.738  -67.056  51.734  1
404149  97.789  -67.053  51.696  1
404150  97.816  -67.062  51.657  1
404151  97.843  -67.072  51.618  1
404152  97.876  -67.082  51.578  1
404153  97.908  -67.093  51.536  1
404154  97.941  -67.103  51.493  1
404155  97.973  -67.114  51.450  1
404156  98.006  -67.125  51.406  1
404157  98.038  -67.135  51.363  1
404158  98.071  -67.145  51.318  1
404159  98.103  -67.156  51.271  1
404160  98.136  -67.166  51.224  1
404161  98.168  -67.177  51.177  1
404162  98.201  -67.188  51.130  1
404163  98.233  -67.198  51.082  1
404164  98.266  -67.208  51.034  1
404165  98.298  -67.219  50.988  1
404166  98.331  -67.226  50.944  1
404167  98.363  -67.229  50.901  1
404168  98.395  -67.233  50.859  1
404169  98.425  -67.238  50.817  1
404170  98.452  -67.244  50.775  1
404171  98.480  -67.251  50.732  1
404172  98.507  -67.257  50.689  1
404173  98.534  -67.264  50.645  1
404174  98.561  -67.271  50.600  1
404175  98.588  -67.278  50.557  1
404176  98.616  -67.284  50.515  1
404177  98.643  -67.291  50.472  1
404178  98.670  -67.297  50.427  1
404179  98.719  -67.299  50.380  1
404180  98.768  -67.300  50.332  1
404181  98.817  -67.301  50.281  1
404182  98.866  -67.303  50.229  1
404183  98.915  -67.304  50.177  1
404184  98.963  -67.305  50.124  1
404185  99.012  -67.306  50.070  1
404186  99.061  -67.307  50.017  1
404187  99.113  -67.314  49.964  1
404188  99.165  -67.322  49.909  1
404189  99.217  -67.329  49.855  1
404190  99.270  -67.336  49.802  1
404191  99.322  -67.344  49.750  1
404192  99.374  -67.351  49.698  1
404193  99.416  -67.360  49.648  1
404194  99.416  -67.377  49.599  1
404195  99.429  -67.395  49.550  1
404196  99.472  -67.411  49.501  1
404197  99.516  -67.429  49.453  1
404198  99.559  -67.446  49.407  1
404199  99.603  -67.464  49.361  1
404200  99.646  -67.481  49.315  1
404201  99.696  -67.480  49.268  1
404202  99.732  -67.489  49.220  1
404203  99.739  -67.529  49.173  1
404204  99.780  -67.545  49.127  1
404205  99.821  -67.529  49.081  1
404206  99.853  -67.522  49.034  1
404207  99.861  -67.530  48.988  1
404208  99.869  -67.539  48.942  1
404209  99.880  -67.547  48.897  1
404210  99.901  -67.555  48.851  1
404211  99.934  -67.556  48.806  1
404212  99.974  -67.555  48.762  1
404213  100.013  -67.552  48.717  1
404214  100.053  -67.550  48.674  1
404215  100.092  -67.548  48.631  1
404216  100.132  -67.546  48.589  1
404217  100.171  -67.544  48.548  1
404218  100.211  -67.542  48.507  1
404219  100.251  -67.540  48.467  1
404220  100.290  -67.538  48.426  1
404221  100.330  -67.536  48.384  1
404222  100.371  -67.534  48.344  1
404223  100.419  -67.532  48.305  1
404666  90.005  -66.730  54.909  1
404667  90.052  -66.732  54.912  1
404668  90.109  -66.715  54.918  1
404669  90.165  -66.697  54.924  1
404670  90.222  -66.680  54.930  1
404671  90.279  -66.662  54.937  1
404672  90.335  -66.644  54.945  1
404673  90.391  -66.646  54.952  1
404674  90.447  -66.651  54.959  1
404675  90.503  -66.655  54.967  1
404676  90.558  -66.659  54.976  1
404677  90.614  -66.664  54.985  1
404678  90.669  -66.668  54.994  1
404679  90.725  -66.672  55.003  1
404680  90.781  -66.677  55.014  1
404681  90.836  -66.680  55.028  1
404682  90.892  -66.685  55.043  1
404683  90.947  -66.690  55.063  1
404684  91.006  -66.696  55.086  1
404685  91.065  -66.703  55.105  1
404686  91.113  -66.711  55.119  1
404687  91.157  -66.718  55.131  1
404688  91.201  -66.727  55.141  1
404689  91.244  -66.735  55.152  1
404690  91.288  -66.743  55.155  1
404691  91.332  -66.751  55.155  1
404692  91.375  -66.759  55.151  1
404693  91.419  -66.767  55.143  1
404694  91.461  -66.762  55.133  1
404695  91.503  -66.755  55.119  1
404696  91.544  -66.748  55.106  1
404697  91.586  -66.741  55.093  1
404698  91.628  -66.734  55.078  1
404699  91.672  -66.738  55.064  1
404700  91.717  -66.741  55.047  1
404701  91.761  -66.745  55.028  1
404702  91.806  -66.749  55.009  1
404703  91.851  -66.752  54.990  1
404704  91.895  -66.755  54.971  1
404705  91.940  -66.759  54.953  1
404706  91.985  -66.762  54.935  1
404707  92.029  -66.768  54.917  1
404708  92.074  -66.774  54.899  1
404709  92.130  -66.783  54.882  1
404710  92.189  -66.793  54.865  1
404711  92.247  -66.803  54.847  1
404712  92.305  -66.813  54.832  1
404713  92.364  -66.823  54.815  1
404714  92.422  -66.833  54.801  1
404715  92.484  -66.843  54.791  1
404716  92.548  -66.854  54.785  1
404717  92.611  -66.864  54.786  1
404718  92.674  -66.874  54.790  1
404719  92.737  -66.885  54.789  1
404720  92.799  -66.894  54.783  1
404721  92.841  -66.877  54.772  1
404722  92.882  -66.859  54.755  1
404723  92.924  -66.842  54.732  1
404724  92.965  -66.824  54.706  1
404725  93.005  -66.809  54.678  1
404726  93.043  -66.795  54.646  1
404727  93.081  -66.780  54.612  1
404728  93.119  -66.766  54.577  1
404729  93.157  -66.752  54.541  1
404730  93.195  -66.738  54.505  1
404731  93.233  -66.724  54.471  1
404732  93.271  -66.710  54.437  1
404733  93.305  -66.705  54.406  1
404734  93.340  -66.701  54.378  1
404735  93.377  -66.705  54.353  1
404736  93.415  -66.709  54.328  1
404737  93.452  -66.713  54.301  1
404738  93.490  -66.718  54.273  1
404739  93.527  -66.721  54.245  1
404740  93.565  -66.725  54.219  1
404741  93.603  -66.731  54.195  1
404742  93.643  -66.740  54.175  1
404743  93.683  -66.749  54.159  1
404744  93.722  -66.758  54.146  1
404745  93.757  -66.757  54.136  1
404746  93.792  -66.756  54.128  1
404747  93.827  -66.755  54.121  1
404748  93.862  -66.751  54.114  1
404749  93.898  -66.746  54.105  1
404750  93.935  -66.743  54.093  1
404751  93.975  -66.748  54.079  1
404752  94.016  -66.752  54.062  1
404753  94.058  -66.757  54.044  1
404754  94.100  -66.762  54.026  1
404755  94.141  -66.766  54.010  1
404756  94.184  -66.771  53.996  1
404757  94.226  -66.776  53.982  1
404758  94.269  -66.780  53.966  1
404759  94.312  -66.786  53.948  1
404760  94.354  -66.790  53.926  1
404761  94.397  -66.796  53.901  1
404762  94.440  -66.800  53.872  1
404763  94.463  -66.798  53.840  1
404764  94.487  -66.796  53.806  1
404765  94.528  -66.797  53.773  1
404766  94.567  -66.799  53.742  1
404767  94.608  -66.800  53.712  1
404768  94.647  -66.802  53.680  1
404769  94.688  -66.804  53.647  1
404770  94.728  -66.805  53.611  1
404771  94.777  -66.808  53.574  1
404772  94.829  -66.810  53.539  1
404773  94.881  -66.812  53.507  1
404774  94.933  -66.820  53.479  1
404775  94.955  -66.808  53.456  1
404776  94.986  -66.806  53.436  1
404777  95.017  -66.805  53.419  1
404778  95.048  -66.803  53.405  1
404779  95.080  -66.802  53.394  1
404780  95.111  -66.800  53.384  1
404781  95.142  -66.798  53.376  1
404782  95.174  -66.796  53.369  1
404783  95.211  -66.796  53.363  1
404784  95.261  -66.799  53.355  1
404785  95.316  -66.815  53.343  1
404786  95.377  -66.853  53.325  1
404787  95.425  -66.866  53.303  1
404788  95.472  -66.878  53.280  1
404789  95.516  -66.881  53.260  1
404790  95.560  -66.884  53.241  1
404791  95.603  -66.885  53.223  1
404792  95.643  -66.881  53.206  1
404793  95.684  -66.878  53.189  1
404794  95.725  -66.878  53.172  1
404795  95.769  -66.887  53.156  1
404796  95.813  -66.896  53.137  1
404797  95.857  -66.905  53.116  1
404798  95.893  -66.911  53.093  1
404799  95.930  -66.917  53.069  1
404800  95.966  -66.923  53.044  1
404801  96.003  -66.927  53.018  1
404802  96.038  -66.931  52.992  1
404803  96.074  -66.934  52.964  1
404804  96.108  -66.936  52.937  1
404805  96.140  -66.935  52.910  1
404806  96.172  -66.934  52.883  1
404807  96.203  -66.935  52.853  1
404808  96.234  -66.941  52.822  1
404809  96.264  -66.947  52.790  1
404810  96.295  -66.954  52.757  1
404811  96.326  -66.960  52.724  1
404812  96.358  -66.965  52.693  1
404813  96.393  -66.967  52.662  1
404814  96.427  -66.968  52.632  1
404815  96.455  -66.966  52.602  1
404816  96.484  -66.965  52.573  1
404817  96.513  -66.962  52.546  1
404818  96.542  -66.961  52.520  1
404819  96.577  -66.961  52.498  1
404820  96.612  -66.960  52.478  1
404821  96.647  -66.960  52.457  1
404822  96.681  -66.960  52.436  1
404823  96.719  -66.960  52.420  1
404824  96.760  -66.962  52.402  1
404825  96.801  -66.963  52.383  1
404826  96.841  -66.963  52.364  1
404827  96.881  -66.963  52.342  1
404828  96.920  -66.963  52.317  1
404829  96.959  -66.963  52.295  1
404830  96.998  -66.962  52.274  1
404831  97.037  -66.962  52.254  1
404832  97.080  -66.965  52.234  1
404833  97.122  -66.968  52.216  1
404834  97.165  -66.970  52.199  1
404835  97.208  -66.972  52.184  1
404836  97.250  -66.975  52.169  1
404837  97.294  -66.978  52.151  1
404838  97.337  -66.981  52.128  1
404839  97.384  -66.977  52.100  1
404840  97.433  -66.971  52.067  1
404841  97.480  -66.978  52.033  1
404842  97.508  -66.986  51.998  1
404843  97.535  -66.994  51.962  1
404844  97.563  -67.000  51.925  1
404845  97.590  -67.008  51.888  1
404846  97.621  -67.013  51.852  1
404847  97.666  -67.010  51.814  1
404848  97.712  -67.007  51.776  1
404849  97.757  -67.004  51.738  1
404850  97.792  -67.012  51.699  1
404851  97.824  -67.022  51.659  1
404852  97.858  -67.031  51.618  1
404853  97.890  -67.042  51.576  1
404854  97.923  -67.053  51.533  1
404855  97.955  -67.063  51.489  1
404856  97.988  -67.074  51.444  1
404857  98.020  -67.084  51.400  1
404858  98.053  -67.095  51.356  1
404859  98.085  -67.105  51.311  1
404860  98.118  -67.116  51.263  1
404861  98.150  -67.126  51.217  1
404862  98.183  -67.137  51.169  1
404863  98.215  -67.147  51.122  1
404864  98.248  -67.158  51.076  1
404865  98.281  -67.169  51.031  1
404866  98.313  -67.178  50.989  1
404867  98.346  -67.188  50.947  1
404868  98.378  -67.191  50.905  1
404869  98.409  -67.195  50.863  1
404870  98.436  -67.202  50.822  1
404871  98.463  -67.209  50.780  1
404872  98.490  -67.215  50.736  1
404873  98.517  -67.222  50.691  1
404874  98.545  -67.229  50.648  1
404875  98.571  -67.235  50.602  1
404876  98.597  -67.237  50.558  1
404877  98.624  -67.238  50.515  1
404878  98.650  -67.241  50.472  1
404879  98.678  -67.256  50.427  1
404880  98.726  -67.257  50.380  1
404881  98.774  -67.258  50.331  1
404882  98.822  -67.260  50.280  1
404883  98.871  -67.260  50.227  1
404884  98.920  -67.262  50.174  1
404885  98.969  -67.263  50.121  1
404886  99.017  -67.264  50.067  1
404887  99.066  -67.266  50.012  1
404888  99.117  -67.269  49.958  1
404889  99.169  -67.277  49.904  1
404890  99.221  -67.285  49.850  1
404891  99.274  -67.291  49.797  1
404892  99.326  -67.299  49.744  1
404893  99.378  -67.307  49.692  1
404894  99.388  -67.322  49.641  1
404895  99.397  -67.338  49.592  1
404896  99.440  -67.356  49.543  1
404897  99.484  -67.373  49.493  1
404898  99.527  -67.391  49.445  1
404899  99.571  -67.407  49.399  1
404900  99.615  -67.425  49.352  1
404901  99.658  -67.442  49.306  1
404902  99.706  -67.446  49.259  1
404903  99.758  -67.440  49.211  1
404904  99.770  -67.474  49.163  1
404905  99.811  -67.479  49.116  1
404906  99.845  -67.469  49.070  1
404907  99.853  -67.478  49.023  1
404908  99.861  -67.486  48.976  1
404909  99.869  -67.495  48.930  1
404910  99.886  -67.503  48.884  1
404911  99.907  -67.511  48.839  1
404912  99.943  -67.511  48.793  1
404913  99.983  -67.508  48.749  1
404914  100.022  -67.506  48.705  1
404915  100.062  -67.504  48.663  1
404916  100.102  -67.502  48.620  1
404917  100.141  -67.500  48.579  1
404918  100.181  -67.498  48.539  1
404919  100.220  -67.496  48.497  1
404920  100.260  -67.494  48.457  1
404921  100.299  -67.492  48.416  1
404922  100.339  -67.490  48.375  1
404923  100.385  -67.488  48.334  1
405368  90.060  -66.668  54.911  1
405369  90.116  -66.650  54.916  1
405370  90.173  -66.633  54.922  1
405371  90.230  -66.615  54.927  1
405372  90.287  -66.598  54.934  1
405373  90.343  -66.592  54.941  1
405374  90.398  -66.597  54.947  1
405375  90.454  -66.601  54.954  1
405376  90.510  -66.605  54.962  1
405377  90.565  -66.610  54.971  1
405378  90.621  -66.614  54.980  1
405379  90.676  -66.618  54.989  1
405380  90.732  -66.623  54.999  1
405381  90.788  -66.627  55.009  1
405382  90.843  -66.631  55.022  1
405383  90.899  -66.636  55.037  1
405384  90.954  -66.639  55.055  1
405385  91.010  -66.644  55.076  1
405386  91.069  -66.651  55.097  1
405387  91.113  -66.659  55.113  1
405388  91.157  -66.667  55.127  1
405389  91.201  -66.675  55.139  1
405390  91.244  -66.683  55.152  1
405391  91.288  -66.691  55.158  1
405392  91.331  -66.699  55.160  1
405393  91.375  -66.707  55.158  1
405394  91.419  -66.715  55.151  1
405395  91.461  -66.715  55.139  1
405396  91.503  -66.708  55.125  1
405397  91.544  -66.701  55.111  1
405398  91.586  -66.694  55.097  1
405399  91.629  -66.691  55.081  1
405400  91.674  -66.695  55.066  1
405401  91.718  -66.699  55.049  1
405402  91.763  -66.702  55.030  1
405403  91.808  -66.705  55.012  1
405404  91.852  -66.709  54.994  1
405405  91.897  -66.712  54.976  1
405406  91.942  -66.717  54.960  1
405407  91.986  -66.723  54.944  1
405408  92.030  -66.728  54.927  1
405409  92.085  -66.737  54.911  1
405410  92.143  -66.747  54.895  1
405411  92.202  -66.757  54.878  1
405412  92.260  -66.767  54.863  1
405413  92.318  -66.777  54.848  1
405414  92.377  -66.787  54.832  1
405415  92.435  -66.797  54.819  1
405416  92.494  -66.807  54.808  1
405417  92.555  -66.817  54.801  1
405418  92.618  -66.827  54.799  1
405419  92.682  -66.838  54.801  1
405420  92.744  -66.849  54.802  1
405421  92.801  -66.850  54.797  1
405422  92.843  -66.833  54.786  1
405423  92.884  -66.816  54.770  1
405424  92.925  -66.799  54.747  1
405425  92.964  -66.784  54.722  1
405426  93.002  -66.770  54.695  1
405427  93.040  -66.755  54.664  1
405428  93.078  -66.742  54.632  1
405429  93.116  -66.727  54.597  1
405430  93.154  -66.713  54.561  1
405431  93.192  -66.699  54.526  1
405432  93.230  -66.685  54.493  1
405433  93.268  -66.671  54.459  1
405434  93.303  -66.664  54.428  1
405435  93.337  -66.659  54.399  1
405436  93.373  -66.659  54.373  1
405437  93.411  -66.663  54.348  1
405438  93.448  -66.668  54.320  1
405439  93.485  -66.671  54.291  1
405440  93.523  -66.675  54.262  1
405441  93.560  -66.680  54.235  1
405442  93.599  -66.686  54.211  1
405443  93.638  -66.694  54.192  1
405444  93.678  -66.703  54.177  1
405445  93.718  -66.712  54.165  1
405446  93.758  -66.721  54.155  1
405447  93.793  -66.718  54.146  1
405448  93.828  -66.712  54.138  1
405449  93.864  -66.708  54.130  1
405450  93.900  -66.702  54.119  1
405451  93.938  -66.703  54.107  1
405452  93.979  -66.708  54.092  1
405453  94.019  -66.711  54.076  1
405454  94.060  -66.717  54.058  1
405455  94.102  -66.721  54.040  1
405456  94.144  -66.726  54.025  1
405457  94.186  -66.730  54.010  1
405458  94.227  -66.735  53.996  1
405459  94.269  -66.740  53.980  1
405460  94.312  -66.744  53.962  1
405461  94.354  -66.749  53.940  1
405462  94.397  -66.754  53.915  1
405463  94.439  -66.759  53.887  1
405464  94.469  -66.758  53.856  1
405465  94.500  -66.758  53.822  1
405466  94.540  -66.760  53.788  1
405467  94.580  -66.762  53.756  1
405468  94.620  -66.763  53.725  1
405469  94.660  -66.765  53.693  1
405470  94.700  -66.767  53.659  1
405471  94.740  -66.768  53.622  1
405472  94.780  -66.770  53.585  1
405473  94.827  -66.772  53.549  1
405474  94.879  -66.774  53.519  1
405475  94.927  -66.778  53.491  1
405476  94.953  -66.771  53.468  1
405477  94.984  -66.770  53.448  1
405478  95.016  -66.768  53.431  1
405479  95.047  -66.766  53.419  1
405480  95.078  -66.765  53.408  1
405481  95.109  -66.763  53.399  1
405482  95.140  -66.762  53.393  1
405483  95.172  -66.760  53.387  1
405484  95.203  -66.758  53.381  1
405485  95.252  -66.761  53.370  1
405486  95.311  -66.792  53.353  1
405487  95.359  -66.805  53.332  1
405488  95.407  -66.818  53.309  1
405489  95.456  -66.832  53.288  1
405490  95.502  -66.842  53.269  1
405491  95.546  -66.845  53.251  1
405492  95.590  -66.848  53.234  1
405493  95.634  -66.851  53.218  1
405494  95.678  -66.854  53.202  1
405495  95.722  -66.857  53.187  1
405496  95.763  -66.854  53.172  1
405497  95.806  -66.859  53.155  1
405498  95.847  -66.867  53.136  1
405499  95.884  -66.873  53.114  1
405500  95.920  -66.879  53.089  1
405501  95.957  -66.885  53.065  1
405502  95.993  -66.890  53.038  1
405503  96.029  -66.894  53.011  1
405504  96.064  -66.898  52.983  1
405505  96.100  -66.902  52.956  1
405506  96.136  -66.906  52.930  1
405507  96.168  -66.904  52.903  1
405508  96.200  -66.903  52.874  1
405509  96.230  -66.909  52.844  1
405510  96.261  -66.915  52.811  1
405511  96.292  -66.921  52.778  1
405512  96.325  -66.925  52.745  1
405513  96.360  -66.928  52.714  1
405514  96.395  -66.930  52.683  1
405515  96.426  -66.929  52.652  1
405516  96.454  -66.927  52.622  1
405517  96.483  -66.925  52.593  1
405518  96.512  -66.924  52.565  1
405519  96.541  -66.921  52.540  1
405520  96.570  -66.920  52.517  1
405521  96.604  -66.919  52.495  1
405522  96.639  -66.919  52.473  1
405523  96.675  -66.919  52.451  1
405524  96.716  -66.921  52.433  1
405525  96.757  -66.921  52.416  1
405526  96.799  -66.923  52.398  1
405527  96.839  -66.925  52.378  1
405528  96.879  -66.924  52.357  1
405529  96.918  -66.924  52.331  1
405530  96.957  -66.924  52.308  1
405531  96.996  -66.924  52.286  1
405532  97.038  -66.926  52.265  1
405533  97.081  -66.928  52.244  1
405534  97.124  -66.931  52.227  1
405535  97.166  -66.933  52.211  1
405536  97.209  -66.935  52.195  1
405537  97.252  -66.937  52.180  1
405538  97.295  -66.940  52.163  1
405539  97.342  -66.935  52.138  1
405540  97.392  -66.924  52.110  1
405541  97.441  -66.925  52.078  1
405542  97.490  -66.934  52.043  1
405543  97.521  -66.941  52.006  1
405544  97.549  -66.948  51.970  1
405545  97.576  -66.956  51.933  1
405546  97.605  -66.962  51.895  1
405547  97.651  -66.959  51.857  1
405548  97.696  -66.956  51.819  1
405549  97.734  -66.961  51.780  1
405550  97.768  -66.971  51.740  1
405551  97.802  -66.981  51.700  1
405552  97.835  -66.990  51.660  1
405553  97.868  -67.000  51.618  1
405554  97.901  -67.009  51.575  1
405555  97.934  -67.019  51.531  1
405556  97.967  -67.028  51.486  1
405557  98.000  -67.038  51.441  1
405558  98.033  -67.047  51.396  1
405559  98.066  -67.057  51.351  1
405560  98.099  -67.066  51.305  1
405561  98.132  -67.075  51.257  1
405562  98.165  -67.086  51.211  1
405563  98.198  -67.097  51.165  1
405564  98.230  -67.107  51.119  1
405565  98.263  -67.118  51.074  1
405566  98.295  -67.128  51.032  1
405567  98.327  -67.139  50.992  1
405568  98.360  -67.149  50.951  1
405569  98.392  -67.153  50.911  1
405570  98.419  -67.160  50.868  1
405571  98.446  -67.166  50.827  1
405572  98.473  -67.172  50.784  1
405573  98.499  -67.174  50.740  1
405574  98.525  -67.175  50.695  1
405575  98.552  -67.178  50.650  1
405576  98.578  -67.179  50.604  1
405577  98.604  -67.181  50.560  1
405578  98.630  -67.183  50.516  1
405579  98.655  -67.192  50.471  1
405580  98.687  -67.214  50.426  1
405581  98.734  -67.216  50.377  1
405582  98.781  -67.216  50.327  1
405583  98.829  -67.218  50.276  1
405584  98.876  -67.219  50.222  1
405585  98.925  -67.220  50.170  1
405586  98.974  -67.222  50.116  1
405587  99.023  -67.222  50.062  1
405588  99.072  -67.224  50.007  1
405589  99.121  -67.225  49.953  1
405590  99.173  -67.232  49.899  1
405591  99.225  -67.240  49.845  1
405592  99.277  -67.247  49.792  1
405593  99.330  -67.254  49.739  1
405594  99.360  -67.266  49.686  1
405595  99.365  -67.283  49.635  1
405596  99.409  -67.301  49.585  1
405597  99.452  -67.317  49.534  1
405598  99.496  -67.335  49.486  1
405599  99.540  -67.352  49.437  1
405600  99.583  -67.370  49.390  1
405601  99.627  -67.386  49.344  1
405602  99.670  -67.404  49.297  1
405603  99.717  -67.412  49.249  1
405604  99.768  -67.406  49.201  1
405605  99.802  -67.418  49.153  1
405606  99.837  -67.417  49.106  1
405607  99.845  -67.426  49.058  1
405608  99.853  -67.434  49.011  1
405609  99.861  -67.442  48.964  1
405610  99.871  -67.451  48.917  1
405611  99.892  -67.459  48.871  1
405612  99.913  -67.467  48.826  1
405613  99.952  -67.464  48.781  1
405614  99.992  -67.462  48.738  1
405615  100.031  -67.460  48.695  1
405616  100.071  -67.458  48.652  1
405617  100.111  -67.456  48.610  1
405618  100.150  -67.454  48.569  1
405619  100.190  -67.452  48.528  1
405620  100.229  -67.450  48.487  1
405621  100.269  -67.448  48.446  1
405622  100.309  -67.446  48.406  1
405623  100.351  -67.444  48.365  1
405624  100.400  -67.442  48.324  1
406070  90.124  -66.586  54.915  1
406071  90.181  -66.568  54.920  1
406072  90.238  -66.551  54.925  1
406073  90.294  -66.539  54.931  1
406074  90.350  -66.543  54.937  1
406075  90.405  -66.547  54.944  1
406076  90.461  -66.552  54.951  1
406077  90.517  -66.556  54.959  1
406078  90.572  -66.560  54.967  1
406079  90.628  -66.564  54.975  1
406080  90.683  -66.569  54.984  1
406081  90.739  -66.573  54.994  1
406082  90.795  -66.577  55.004  1
406083  90.850  -66.582  55.016  1
406084  90.906  -66.586  55.030  1
406085  90.961  -66.590  55.046  1
406086  91.017  -66.595  55.064  1
406087  91.070  -66.599  55.084  1
406088  91.113  -66.607  55.101  1
406089  91.157  -66.615  55.116  1
406090  91.200  -66.624  55.130  1
406091  91.244  -66.631  55.144  1
406092  91.288  -66.639  55.153  1
406093  91.331  -66.648  55.157  1
406094  91.375  -66.655  55.157  1
406095  91.419  -66.664  55.152  1
406096  91.461  -66.668  55.142  1
406097  91.503  -66.661  55.128  1
406098  91.545  -66.654  55.113  1
406099  91.587  -66.646  55.098  1
406100  91.631  -66.649  55.082  1
406101  91.675  -66.652  55.067  1
406102  91.720  -66.655  55.050  1
406103  91.765  -66.659  55.032  1
406104  91.809  -66.662  55.014  1
406105  91.854  -66.666  54.997  1
406106  91.898  -66.672  54.981  1
406107  91.943  -66.677  54.967  1
406108  91.988  -66.683  54.953  1
406109  92.040  -66.691  54.938  1
406110  92.098  -66.702  54.923  1
406111  92.157  -66.711  54.908  1
406112  92.215  -66.721  54.893  1
406113  92.274  -66.731  54.879  1
406114  92.332  -66.741  54.866  1
406115  92.390  -66.751  54.851  1
406116  92.448  -66.761  54.838  1
406117  92.507  -66.771  54.827  1
406118  92.565  -66.781  54.819  1
406119  92.625  -66.791  54.814  1
406120  92.689  -66.802  54.812  1
406121  92.752  -66.812  54.810  1
406122  92.803  -66.807  54.804  1
406123  92.844  -66.790  54.793  1
406124  92.884  -66.774  54.776  1
406125  92.922  -66.759  54.755  1
406126  92.960  -66.746  54.731  1
406127  92.999  -66.731  54.705  1
406128  93.037  -66.717  54.676  1
406129  93.075  -66.703  54.646  1
406130  93.113  -66.689  54.614  1
406131  93.151  -66.674  54.581  1
406132  93.189  -66.661  54.547  1
406133  93.227  -66.646  54.515  1
406134  93.265  -66.632  54.482  1
406135  93.300  -66.624  54.452  1
406136  93.335  -66.619  54.423  1
406137  93.369  -66.614  54.395  1
406138  93.406  -66.617  54.367  1
406139  93.443  -66.621  54.338  1
406140  93.481  -66.626  54.310  1
406141  93.518  -66.630  54.281  1
406142  93.556  -66.633  54.253  1
406143  93.594  -66.640  54.229  1
406144  93.634  -66.649  54.210  1
406145  93.674  -66.658  54.196  1
406146  93.714  -66.666  54.185  1
406147  93.754  -66.674  54.174  1
406148  93.794  -66.674  54.165  1
406149  93.830  -66.669  54.156  1
406150  93.866  -66.664  54.146  1
406151  93.902  -66.658  54.134  1
406152  93.941  -66.662  54.121  1
406153  93.982  -66.667  54.106  1
406154  94.022  -66.671  54.089  1
406155  94.063  -66.676  54.072  1
406156  94.105  -66.680  54.055  1
406157  94.146  -66.685  54.040  1
406158  94.188  -66.690  54.025  1
406159  94.229  -66.694  54.010  1
406160  94.271  -66.699  53.995  1
406161  94.313  -66.704  53.975  1
406162  94.355  -66.708  53.953  1
406163  94.397  -66.713  53.928  1
406164  94.439  -66.718  53.900  1
406165  94.474  -66.720  53.870  1
406166  94.512  -66.721  53.837  1
406167  94.553  -66.723  53.802  1
406168  94.593  -66.724  53.768  1
406169  94.633  -66.726  53.737  1
406170  94.673  -66.727  53.704  1
406171  94.713  -66.729  53.669  1
406172  94.753  -66.731  53.633  1
406173  94.793  -66.733  53.596  1
406174  94.833  -66.734  53.561  1
406175  94.876  -66.736  53.531  1
406176  94.920  -66.736  53.504  1
406177  94.951  -66.734  53.482  1
406178  94.982  -66.733  53.463  1
406179  95.014  -66.731  53.448  1
406180  95.045  -66.730  53.436  1
406181  95.076  -66.728  53.425  1
406182  95.108  -66.727  53.417  1
406183  95.139  -66.725  53.410  1
406184  95.170  -66.724  53.404  1
406185  95.201  -66.722  53.394  1
406186  95.245  -66.730  53.379  1
406187  95.293  -66.744  53.360  1
406188  95.341  -66.758  53.336  1
406189  95.390  -66.771  53.313  1
406190  95.438  -66.784  53.294  1
406191  95.486  -66.798  53.276  1
406192  95.532  -66.805  53.260  1
406193  95.576  -66.809  53.244  1
406194  95.620  -66.812  53.230  1
406195  95.664  -66.815  53.215  1
406196  95.708  -66.818  53.201  1
406197  95.752  -66.821  53.187  1
406198  95.796  -66.824  53.171  1
406199  95.837  -66.830  53.154  1
406200  95.874  -66.836  53.134  1
406201  95.910  -66.842  53.111  1
406202  95.947  -66.848  53.088  1
406203  95.983  -66.853  53.060  1
406204  96.019  -66.858  53.032  1
406205  96.055  -66.862  53.003  1
406206  96.091  -66.865  52.974  1
406207  96.127  -66.869  52.949  1
406208  96.163  -66.873  52.923  1
406209  96.195  -66.873  52.896  1
406210  96.227  -66.877  52.866  1
406211  96.257  -66.884  52.832  1
406212  96.292  -66.886  52.800  1
406213  96.327  -66.888  52.767  1
406214  96.362  -66.890  52.735  1
406215  96.397  -66.891  52.703  1
406216  96.426  -66.890  52.673  1
406217  96.454  -66.888  52.642  1
406218  96.482  -66.886  52.612  1
406219  96.511  -66.884  52.584  1
406220  96.540  -66.882  52.560  1
406221  96.569  -66.881  52.536  1
406222  96.598  -66.879  52.514  1
406223  96.631  -66.878  52.491  1
406224  96.672  -66.880  52.468  1
406225  96.714  -66.881  52.448  1
406226  96.755  -66.882  52.429  1
406227  96.796  -66.884  52.411  1
406228  96.837  -66.885  52.392  1
406229  96.877  -66.885  52.372  1
406230  96.916  -66.885  52.345  1
406231  96.955  -66.885  52.321  1
406232  96.997  -66.887  52.298  1
406233  97.039  -66.889  52.276  1
406234  97.082  -66.891  52.256  1
406235  97.125  -66.893  52.238  1
406236  97.167  -66.896  52.222  1
406237  97.210  -66.898  52.206  1
406238  97.253  -66.900  52.191  1
406239  97.300  -66.893  52.173  1
406240  97.350  -66.882  52.148  1
406241  97.400  -66.872  52.120  1
406242  97.449  -66.881  52.088  1
406243  97.498  -66.888  52.053  1
406244  97.535  -66.896  52.016  1
406245  97.563  -66.903  51.979  1
406246  97.590  -66.911  51.941  1
406247  97.635  -66.908  51.902  1
406248  97.677  -66.909  51.863  1
406249  97.711  -66.918  51.823  1
406250  97.744  -66.929  51.782  1
406251  97.778  -66.939  51.741  1
406252  97.812  -66.950  51.700  1
406253  97.845  -66.959  51.659  1
406254  97.878  -66.968  51.617  1
406255  97.911  -66.978  51.574  1
406256  97.944  -66.987  51.529  1
406257  97.978  -66.997  51.484  1
406258  98.010  -67.006  51.439  1
406259  98.043  -67.016  51.393  1
406260  98.077  -67.025  51.347  1
406261  98.109  -67.034  51.300  1
406262  98.143  -67.044  51.253  1
406263  98.175  -67.053  51.207  1
406264  98.209  -67.063  51.161  1
406265  98.242  -67.072  51.116  1
406266  98.275  -67.082  51.072  1
406267  98.308  -67.091  51.033  1
406268  98.341  -67.101  50.995  1
406269  98.373  -67.110  50.956  1
406270  98.401  -67.111  50.916  1
406271  98.427  -67.113  50.874  1
406272  98.453  -67.114  50.832  1
406273  98.480  -67.116  50.789  1
406274  98.506  -67.118  50.744  1
406275  98.532  -67.120  50.699  1
406276  98.558  -67.122  50.653  1
406277  98.584  -67.123  50.607  1
406278  98.610  -67.125  50.561  1
406279  98.637  -67.127  50.516  1
406280  98.659  -67.157  50.470  1
406281  98.695  -67.173  50.423  1
406282  98.742  -67.174  50.373  1
406283  98.790  -67.175  50.322  1
406284  98.837  -67.176  50.271  1
406285  98.884  -67.177  50.218  1
406286  98.931  -67.178  50.165  1
406287  98.980  -67.179  50.111  1
406288  99.028  -67.181  50.056  1
406289  99.077  -67.182  50.001  1
406290  99.126  -67.183  49.947  1
406291  99.177  -67.188  49.893  1
406292  99.229  -67.195  49.839  1
406293  99.281  -67.203  49.786  1
406294  99.332  -67.210  49.733  1
406295  99.334  -67.227  49.681  1
406296  99.377  -67.244  49.630  1
406297  99.421  -67.262  49.579  1
406298  99.464  -67.279  49.529  1
406299  99.508  -67.296  49.479  1
406300  99.551  -67.313  49.431  1
406301  99.595  -67.331  49.383  1
406302  99.638  -67.348  49.335  1
406303  99.682  -67.366  49.287  1
406304  99.727  -67.378  49.239  1
406305  99.779  -67.372  49.191  1
406306  99.828  -67.365  49.143  1
406307  99.837  -67.373  49.095  1
406308  99.845  -67.382  49.047  1
406309  99.853  -67.390  49.000  1
406310  99.861  -67.399  48.952  1
406311  99.877  -67.407  48.905  1
406312  99.897  -67.415  48.859  1
406313  99.922  -67.420  48.814  1
406314  99.962  -67.418  48.770  1
406315  100.001  -67.417  48.727  1
406316  100.041  -67.414  48.684  1
406317  100.080  -67.412  48.641  1
406318  100.120  -67.410  48.599  1
406319  100.159  -67.408  48.558  1
406320  100.199  -67.406  48.517  1
406321  100.239  -67.404  48.476  1
406322  100.278  -67.402  48.436  1
406323  100.318  -67.400  48.396  1
406324  100.366  -67.398  48.355  1
406772  90.189  -66.504  54.918  1
406773  90.246  -66.486  54.923  1
406774  90.301  -66.489  54.930  1
406775  90.357  -66.493  54.936  1
406776  90.412  -66.498  54.942  1
406777  90.468  -66.502  54.949  1
406778  90.524  -66.506  54.955  1
406779  90.579  -66.511  54.964  1
406780  90.635  -66.515  54.972  1
406781  90.690  -66.519  54.980  1
406782  90.746  -66.523  54.989  1
406783  90.802  -66.528  54.999  1
406784  90.858  -66.532  55.010  1
406785  90.913  -66.536  55.023  1
406786  90.968  -66.541  55.037  1
406787  91.021  -66.548  55.052  1
406788  91.069  -66.557  55.071  1
406789  91.115  -66.564  55.088  1
406790  91.157  -66.564  55.103  1
406791  91.200  -66.572  55.118  1
406792  91.244  -66.580  55.131  1
406793  91.287  -66.588  55.141  1
406794  91.331  -66.596  55.147  1
406795  91.375  -66.604  55.149  1
406796  91.418  -66.612  55.147  1
406797  91.462  -66.620  55.138  1
406798  91.504  -66.614  55.126  1
406799  91.545  -66.606  55.113  1
406800  91.587  -66.602  55.098  1
406801  91.632  -66.605  55.084  1
406802  91.677  -66.609  55.068  1
406803  91.721  -66.612  55.051  1
406804  91.766  -66.616  55.034  1
406805  91.811  -66.621  55.018  1
406806  91.855  -66.627  55.002  1
406807  91.899  -66.632  54.987  1
406808  91.944  -66.638  54.975  1
406809  91.995  -66.646  54.962  1
406810  92.054  -66.655  54.950  1
406811  92.112  -66.665  54.936  1
406812  92.170  -66.675  54.922  1
406813  92.228  -66.686  54.909  1
406814  92.287  -66.696  54.897  1
406815  92.345  -66.705  54.886  1
406816  92.404  -66.715  54.872  1
406817  92.462  -66.725  54.859  1
406818  92.520  -66.735  54.847  1
406819  92.579  -66.745  54.838  1
406820  92.637  -66.755  54.831  1
406821  92.696  -66.765  54.825  1
406822  92.759  -66.776  54.819  1
406823  92.804  -66.764  54.811  1
406824  92.843  -66.749  54.799  1
406825  92.881  -66.735  54.782  1
406826  92.919  -66.721  54.763  1
406827  92.957  -66.706  54.740  1
406828  92.995  -66.693  54.716  1
406829  93.034  -66.678  54.689  1
406830  93.072  -66.664  54.662  1
406831  93.110  -66.650  54.634  1
406832  93.148  -66.636  54.604  1
406833  93.186  -66.621  54.573  1
406834  93.224  -66.608  54.541  1
406835  93.262  -66.593  54.509  1
406836  93.298  -66.583  54.478  1
406837  93.332  -66.579  54.447  1
406838  93.366  -66.574  54.417  1
406839  93.402  -66.572  54.387  1
406840  93.439  -66.576  54.357  1
406841  93.477  -66.580  54.327  1
406842  93.514  -66.583  54.297  1
406843  93.552  -66.588  54.270  1
406844  93.590  -66.594  54.248  1
406845  93.630  -66.603  54.231  1
406846  93.670  -66.611  54.217  1
406847  93.709  -66.621  54.208  1
406848  93.751  -66.625  54.197  1
406849  93.794  -66.627  54.187  1
406850  93.832  -66.625  54.177  1
406851  93.867  -66.620  54.166  1
406852  93.905  -66.617  54.153  1
406853  93.945  -66.622  54.139  1
406854  93.985  -66.627  54.124  1
406855  94.026  -66.631  54.106  1
406856  94.066  -66.635  54.088  1
406857  94.107  -66.639  54.071  1
406858  94.148  -66.645  54.056  1
406859  94.190  -66.649  54.041  1
406860  94.232  -66.654  54.026  1
406861  94.274  -66.658  54.010  1
406862  94.316  -66.663  53.989  1
406863  94.357  -66.668  53.965  1
406864  94.399  -66.672  53.940  1
406865  94.440  -66.677  53.913  1
406866  94.480  -66.680  53.883  1
406867  94.521  -66.682  53.850  1
406868  94.560  -66.683  53.815  1
406869  94.601  -66.685  53.780  1
406870  94.640  -66.687  53.747  1
406871  94.681  -66.689  53.714  1
406872  94.720  -66.690  53.679  1
406873  94.761  -66.692  53.643  1
406874  94.801  -66.693  53.607  1
406875  94.841  -66.696  53.574  1
406876  94.881  -66.697  53.545  1
406877  94.920  -66.703  53.519  1
406878  94.953  -66.705  53.497  1
406879  94.985  -66.704  53.480  1
406880  95.017  -66.703  53.466  1
406881  95.048  -66.702  53.454  1
406882  95.080  -66.702  53.444  1
406883  95.112  -66.701  53.436  1
406884  95.143  -66.700  53.428  1
406885  95.175  -66.700  53.418  1
406886  95.207  -66.699  53.404  1
406887  95.229  -66.694  53.386  1
406888  95.276  -66.699  53.365  1
406889  95.324  -66.709  53.340  1
406890  95.372  -66.723  53.318  1
406891  95.420  -66.737  53.299  1
406892  95.469  -66.750  53.283  1
406893  95.517  -66.764  53.269  1
406894  95.562  -66.769  53.255  1
406895  95.606  -66.772  53.242  1
406896  95.650  -66.775  53.228  1
406897  95.694  -66.778  53.214  1
406898  95.738  -66.782  53.201  1
406899  95.783  -66.787  53.186  1
406900  95.827  -66.794  53.169  1
406901  95.864  -66.799  53.151  1
406902  95.901  -66.804  53.130  1
406903  95.937  -66.810  53.107  1
406904  95.974  -66.816  53.081  1
406905  96.010  -66.821  53.053  1
406906  96.046  -66.824  53.025  1
406907  96.082  -66.829  52.996  1
406908  96.117  -66.833  52.969  1
406909  96.153  -66.837  52.944  1
406910  96.189  -66.840  52.917  1
406911  96.224  -66.844  52.887  1
406912  96.258  -66.845  52.854  1
406913  96.293  -66.846  52.821  1
406914  96.327  -66.846  52.788  1
406915  96.362  -66.847  52.756  1
406916  96.398  -66.849  52.725  1
406917  96.430  -66.850  52.694  1
406918  96.458  -66.849  52.662  1
406919  96.486  -66.847  52.632  1
406920  96.515  -66.845  52.606  1
406921  96.543  -66.843  52.580  1
406922  96.572  -66.841  52.557  1
406923  96.600  -66.840  52.535  1
406924  96.630  -66.837  52.512  1
406925  96.670  -66.840  52.486  1
406926  96.711  -66.841  52.463  1
406927  96.752  -66.843  52.442  1
406928  96.794  -66.844  52.423  1
406929  96.835  -66.845  52.405  1
406930  96.875  -66.846  52.384  1
406931  96.914  -66.846  52.358  1
406932  96.955  -66.847  52.333  1
406933  96.998  -66.849  52.310  1
406934  97.041  -66.852  52.290  1
406935  97.083  -66.854  52.269  1
406936  97.127  -66.853  52.251  1
406937  97.173  -66.849  52.233  1
406938  97.219  -66.846  52.217  1
406939  97.264  -66.841  52.201  1
406940  97.310  -66.837  52.182  1
406941  97.358  -66.828  52.158  1
406942  97.407  -66.827  52.130  1
406943  97.456  -66.835  52.098  1
406944  97.505  -66.843  52.063  1
406945  97.548  -66.851  52.027  1
406946  97.576  -66.859  51.990  1
406947  97.619  -66.856  51.950  1
406948  97.653  -66.866  51.908  1
406949  97.687  -66.877  51.869  1
406950  97.721  -66.887  51.827  1
406951  97.754  -66.897  51.785  1
406952  97.788  -66.907  51.742  1
406953  97.822  -66.918  51.699  1
406954  97.856  -66.928  51.657  1
406955  97.888  -66.937  51.616  1
406956  97.922  -66.946  51.573  1
406957  97.954  -66.956  51.528  1
406958  97.988  -66.965  51.483  1
406959  98.021  -66.975  51.437  1
406960  98.054  -66.984  51.391  1
406961  98.087  -66.994  51.344  1
406962  98.120  -67.003  51.297  1
406963  98.153  -67.012  51.250  1
406964  98.186  -67.022  51.204  1
406965  98.219  -67.031  51.158  1
406966  98.252  -67.041  51.113  1
406967  98.285  -67.050  51.072  1
406968  98.314  -67.059  51.035  1
406969  98.340  -67.066  50.998  1
406970  98.365  -67.071  50.960  1
406971  98.390  -67.069  50.921  1
406972  98.421  -67.067  50.879  1
406973  98.451  -67.066  50.837  1
406974  98.482  -67.064  50.793  1
406975  98.512  -67.062  50.748  1
406976  98.538  -67.064  50.702  1
406977  98.565  -67.066  50.656  1
406978  98.591  -67.068  50.609  1
406979  98.617  -67.069  50.562  1
406980  98.641  -67.087  50.515  1
406981  98.663  -67.121  50.469  1
406982  98.704  -67.131  50.419  1
406983  98.750  -67.132  50.368  1
406984  98.798  -67.134  50.317  1
406985  98.845  -67.135  50.265  1
406986  98.892  -67.136  50.213  1
406987  98.939  -67.137  50.159  1
406988  98.987  -67.138  50.105  1
406989  99.034  -67.139  50.051  1
406990  99.083  -67.141  49.996  1
406991  99.132  -67.141  49.940  1
406992  99.181  -67.144  49.886  1
406993  99.233  -67.150  49.834  1
406994  99.285  -67.158  49.781  1
406995  99.304  -67.172  49.729  1
406996  99.345  -67.189  49.677  1
406997  99.389  -67.206  49.625  1
406998  99.432  -67.223  49.574  1
406999  99.476  -67.241  49.525  1
407000  99.519  -67.258  49.475  1
407001  99.563  -67.276  49.426  1
407002  99.607  -67.292  49.377  1
407003  99.650  -67.310  49.327  1
407004  99.694  -67.327  49.278  1
407005  99.737  -67.344  49.229  1
407006  99.789  -67.338  49.179  1
407007  99.826  -67.325  49.132  1
407008  99.837  -67.329  49.085  1
407009  99.845  -67.338  49.037  1
407010  99.853  -67.346  48.989  1
407011  99.862  -67.355  48.941  1
407012  99.883  -67.363  48.893  1
407013  99.903  -67.370  48.847  1
407014  99.931  -67.374  48.804  1
407015  99.971  -67.373  48.760  1
407016  100.010  -67.370  48.716  1
407017  100.050  -67.368  48.674  1
407018  100.089  -67.366  48.630  1
407019  100.129  -67.364  48.589  1
407020  100.168  -67.362  48.548  1
407021  100.208  -67.360  48.507  1
407022  100.248  -67.358  48.467  1
407023  100.287  -67.356  48.425  1
407024  100.332  -67.354  48.386  1
407474  90.253  -66.436  54.923  1
407475  90.308  -66.439  54.930  1
407476  90.364  -66.444  54.936  1
407477  90.419  -66.448  54.942  1
407478  90.475  -66.452  54.948  1
407479  90.531  -66.457  54.955  1
407480  90.586  -66.461  54.962  1
407481  90.642  -66.465  54.970  1
407482  90.697  -66.470  54.978  1
407483  90.753  -66.474  54.986  1
407484  90.809  -66.478  54.994  1
407485  90.865  -66.483  55.005  1
407486  90.920  -66.487  55.016  1
407487  90.971  -66.495  55.028  1
407488  91.020  -66.504  55.041  1
407489  91.068  -66.514  55.057  1
407490  91.117  -66.523  55.073  1
407491  91.161  -66.527  55.088  1
407492  91.203  -66.528  55.102  1
407493  91.244  -66.530  55.115  1
407494  91.287  -66.536  55.125  1
407495  91.330  -66.544  55.133  1
407496  91.374  -66.552  55.137  1
407497  91.418  -66.561  55.137  1
407498  91.461  -66.568  55.130  1
407499  91.504  -66.566  55.121  1
407500  91.545  -66.559  55.110  1
407501  91.589  -66.559  55.096  1
407502  91.634  -66.562  55.083  1
407503  91.678  -66.566  55.068  1
407504  91.723  -66.570  55.052  1
407505  91.768  -66.576  55.036  1
407506  91.812  -66.581  55.021  1
407507  91.857  -66.587  55.007  1
407508  91.901  -66.592  54.994  1
407509  91.950  -66.600  54.983  1
407510  92.008  -66.610  54.972  1
407511  92.067  -66.620  54.960  1
407512  92.125  -66.630  54.948  1
407513  92.183  -66.639  54.935  1
407514  92.242  -66.649  54.924  1
407515  92.300  -66.659  54.915  1
407516  92.359  -66.670  54.907  1
407517  92.417  -66.680  54.894  1
407518  92.476  -66.690  54.881  1
407519  92.533  -66.699  54.868  1
407520  92.592  -66.709  54.859  1
407521  92.650  -66.719  54.854  1
407522  92.709  -66.730  54.847  1
407523  92.763  -66.737  54.837  1
407524  92.802  -66.724  54.823  1
407525  92.840  -66.710  54.809  1
407526  92.878  -66.696  54.793  1
407527  92.916  -66.682  54.774  1
407528  92.954  -66.668  54.753  1
407529  92.992  -66.653  54.730  1
407530  93.030  -66.639  54.704  1
407531  93.069  -66.625  54.681  1
407532  93.107  -66.611  54.657  1
407533  93.145  -66.597  54.632  1
407534  93.183  -66.583  54.603  1
407535  93.221  -66.568  54.570  1
407536  93.259  -66.555  54.537  1
407537  93.296  -66.543  54.504  1
407538  93.330  -66.538  54.471  1
407539  93.364  -66.533  54.439  1
407540  93.398  -66.528  54.407  1
407541  93.435  -66.530  54.375  1
407542  93.472  -66.534  54.344  1
407543  93.510  -66.538  54.314  1
407544  93.547  -66.542  54.289  1
407545  93.586  -66.549  54.269  1
407546  93.626  -66.558  54.253  1
407547  93.665  -66.566  54.240  1
407548  93.706  -66.574  54.231  1
407549  93.748  -66.577  54.221  1
407550  93.791  -66.579  54.211  1
407551  93.834  -66.581  54.201  1
407552  93.869  -66.577  54.189  1
407553  93.908  -66.577  54.174  1
407554  93.948  -66.581  54.159  1
407555  93.988  -66.586  54.142  1
407556  94.029  -66.590  54.123  1
407557  94.069  -66.595  54.104  1
407558  94.109  -66.599  54.087  1
407559  94.151  -66.604  54.072  1
407560  94.193  -66.608  54.057  1
407561  94.235  -66.613  54.041  1
407562  94.276  -66.617  54.023  1
407563  94.318  -66.622  54.002  1
407564  94.359  -66.627  53.977  1
407565  94.401  -66.632  53.950  1
407566  94.438  -66.635  53.921  1
407567  94.470  -66.636  53.891  1
407568  94.518  -66.639  53.857  1
407569  94.558  -66.641  53.824  1
407570  94.598  -66.643  53.791  1
407571  94.638  -66.645  53.758  1
407572  94.678  -66.646  53.724  1
407573  94.718  -66.648  53.690  1
407574  94.758  -66.649  53.655  1
407575  94.798  -66.651  53.621  1
407576  94.838  -66.653  53.590  1
407577  94.878  -66.655  53.562  1
407578  94.917  -66.667  53.538  1
407579  94.954  -66.675  53.517  1
407580  94.991  -66.683  53.499  1
407581  95.024  -66.685  53.486  1
407582  95.056  -66.684  53.474  1
407583  95.088  -66.683  53.464  1
407584  95.119  -66.683  53.456  1
407585  95.151  -66.682  53.446  1
407586  95.183  -66.681  53.431  1
407587  95.211  -66.679  53.413  1
407588  95.232  -66.673  53.392  1
407589  95.260  -66.671  53.367  1
407590  95.308  -66.676  53.344  1
407591  95.355  -66.681  53.324  1
407592  95.403  -66.689  53.305  1
407593  95.451  -66.702  53.290  1
407594  95.499  -66.716  53.279  1
407595  95.548  -66.730  53.266  1
407596  95.592  -66.733  53.254  1
407597  95.636  -66.736  53.241  1
407598  95.680  -66.740  53.228  1
407599  95.725  -66.744  53.214  1
407600  95.771  -66.751  53.199  1
407601  95.817  -66.758  53.183  1
407602  95.854  -66.763  53.166  1
407603  95.891  -66.768  53.147  1
407604  95.927  -66.773  53.124  1
407605  95.964  -66.778  53.100  1
407606  96.001  -66.784  53.074  1
407607  96.036  -66.788  53.046  1
407608  96.072  -66.792  53.018  1
407609  96.108  -66.796  52.990  1
407610  96.146  -66.799  52.964  1
407611  96.184  -66.801  52.937  1
407612  96.224  -66.802  52.908  1
407613  96.259  -66.802  52.875  1
407614  96.293  -66.803  52.842  1
407615  96.328  -66.804  52.809  1
407616  96.363  -66.805  52.778  1
407617  96.399  -66.808  52.747  1
407618  96.435  -66.811  52.715  1
407619  96.463  -66.809  52.682  1
407620  96.491  -66.808  52.652  1
407621  96.520  -66.805  52.626  1
407622  96.548  -66.804  52.600  1
407623  96.576  -66.802  52.578  1
407624  96.604  -66.797  52.555  1
407625  96.635  -66.793  52.531  1
407626  96.674  -66.796  52.505  1
407627  96.713  -66.798  52.479  1
407628  96.752  -66.801  52.455  1
407629  96.792  -66.804  52.434  1
407630  96.832  -66.805  52.414  1
407631  96.873  -66.807  52.394  1
407632  96.914  -66.808  52.369  1
407633  96.957  -66.810  52.345  1
407634  97.002  -66.806  52.322  1
407635  97.047  -66.802  52.301  1
407636  97.093  -66.799  52.282  1
407637  97.139  -66.794  52.263  1
407638  97.184  -66.790  52.245  1
407639  97.230  -66.787  52.227  1
407640  97.276  -66.782  52.210  1
407641  97.321  -66.778  52.190  1
407642  97.367  -66.774  52.167  1
407643  97.415  -66.782  52.138  1
407644  97.464  -66.790  52.106  1
407645  97.513  -66.798  52.071  1
407646  97.562  -66.806  52.035  1
407647  97.596  -66.814  51.996  1
407648  97.630  -66.824  51.955  1
407649  97.663  -66.834  51.913  1
407650  97.697  -66.845  51.873  1
407651  97.731  -66.855  51.829  1
407652  97.764  -66.865  51.785  1
407653  97.798  -66.875  51.741  1
407654  97.832  -66.886  51.696  1
407655  97.866  -66.896  51.654  1
407656  97.899  -66.906  51.612  1
407657  97.932  -66.915  51.569  1
407658  97.965  -66.925  51.525  1
407659  97.998  -66.934  51.480  1
407660  98.031  -66.943  51.434  1
407661  98.064  -66.953  51.387  1
407662  98.097  -66.962  51.341  1
407663  98.130  -66.972  51.295  1
407664  98.163  -66.981  51.249  1
407665  98.196  -66.990  51.203  1
407666  98.229  -67.000  51.158  1
407667  98.256  -67.008  51.114  1
407668  98.282  -67.015  51.072  1
407669  98.307  -67.022  51.034  1
407670  98.333  -67.028  50.997  1
407671  98.357  -67.031  50.961  1
407672  98.379  -67.028  50.923  1
407673  98.410  -67.026  50.882  1
407674  98.440  -67.025  50.839  1
407675  98.470  -67.023  50.795  1
407676  98.500  -67.022  50.751  1
407677  98.530  -67.020  50.705  1
407678  98.561  -67.019  50.658  1
407679  98.591  -67.017  50.611  1
407680  98.623  -67.017  50.563  1
407681  98.645  -67.051  50.514  1
407682  98.667  -67.085  50.465  1
407683  98.712  -67.090  50.415  1
407684  98.759  -67.091  50.364  1
407685  98.806  -67.092  50.312  1
407686  98.853  -67.094  50.260  1
407687  98.901  -67.094  50.206  1
407688  98.948  -67.095  50.153  1
407689  98.995  -67.097  50.099  1
407690  99.042  -67.097  50.044  1
407691  99.089  -67.099  49.990  1
407692  99.137  -67.100  49.936  1
407693  99.186  -67.101  49.882  1
407694  99.237  -67.106  49.828  1
407695  99.276  -67.116  49.776  1
407696  99.313  -67.133  49.724  1
407697  99.357  -67.150  49.673  1
407698  99.401  -67.168  49.621  1
407699  99.444  -67.185  49.571  1
407700  99.488  -67.202  49.520  1
407701  99.532  -67.219  49.469  1
407702  99.575  -67.237  49.419  1
407703  99.619  -67.254  49.369  1
407704  99.662  -67.272  49.318  1
407705  99.706  -67.288  49.268  1
407706  99.749  -67.306  49.220  1
407707  99.798  -67.304  49.170  1
407708  99.824  -67.285  49.122  1
407709  99.837  -67.285  49.075  1
407710  99.845  -67.294  49.027  1
407711  99.853  -67.303  48.978  1
407712  99.868  -67.310  48.931  1
407713  99.888  -67.319  48.884  1
407714  99.908  -67.326  48.837  1
407715  99.940  -67.329  48.794  1
407716  99.980  -67.326  48.750  1
407717  100.019  -67.324  48.707  1
407718  100.059  -67.323  48.664  1
407719  100.099  -67.320  48.621  1
407720  100.138  -67.318  48.579  1
407721  100.177  -67.316  48.538  1
407722  100.217  -67.314  48.497  1
407723  100.257  -67.312  48.457  1
407724  100.298  -67.310  48.417  1
407725  100.347  -67.308  48.378  1
408177  90.371  -66.395  54.936  1
408178  90.427  -66.398  54.942  1
408179  90.482  -66.403  54.948  1
408180  90.538  -66.407  54.955  1
408181  90.593  -66.411  54.962  1
408182  90.649  -66.416  54.969  1
408183  90.705  -66.420  54.976  1
408184  90.760  -66.424  54.983  1
408185  90.816  -66.429  54.991  1
408186  90.872  -66.433  55.000  1
408187  90.922  -66.442  55.010  1
408188  90.970  -66.451  55.021  1
408189  91.019  -66.461  55.031  1
408190  91.067  -66.470  55.044  1
408191  91.116  -66.480  55.057  1
408192  91.164  -66.489  55.071  1
408193  91.207  -66.492  55.085  1
408194  91.248  -66.492  55.096  1
408195  91.289  -66.493  55.107  1
408196  91.331  -66.494  55.115  1
408197  91.374  -66.501  55.121  1
408198  91.418  -66.508  55.122  1
408199  91.461  -66.517  55.119  1
408200  91.504  -66.519  55.113  1
408201  91.546  -66.512  55.104  1
408202  91.590  -66.516  55.093  1
408203  91.635  -66.520  55.081  1
408204  91.679  -66.524  55.067  1
408205  91.724  -66.530  55.051  1
408206  91.769  -66.536  55.036  1
408207  91.813  -66.542  55.023  1
408208  91.858  -66.547  55.011  1
408209  91.905  -66.554  55.001  1
408210  91.963  -66.564  54.992  1
408211  92.022  -66.574  54.982  1
408212  92.080  -66.584  54.971  1
408213  92.139  -66.594  54.959  1
408214  92.197  -66.604  54.949  1
408215  92.255  -66.614  54.940  1
408216  92.313  -66.624  54.932  1
408217  92.372  -66.633  54.926  1
408218  92.430  -66.643  54.914  1
408219  92.489  -66.654  54.901  1
408220  92.546  -66.664  54.889  1
408221  92.601  -66.677  54.881  1
408222  92.654  -66.684  54.877  1
408223  92.704  -66.687  54.872  1
408224  92.751  -66.690  54.861  1
408225  92.795  -66.682  54.846  1
408226  92.837  -66.671  54.829  1
408227  92.875  -66.657  54.812  1
408228  92.913  -66.643  54.792  1
408229  92.951  -66.629  54.771  1
408230  92.989  -66.614  54.748  1
408231  93.027  -66.601  54.724  1
408232  93.065  -66.586  54.704  1
408233  93.103  -66.572  54.683  1
408234  93.142  -66.558  54.661  1
408235  93.180  -66.544  54.632  1
408236  93.218  -66.530  54.599  1
408237  93.256  -66.516  54.564  1
408238  93.293  -66.503  54.528  1
408239  93.328  -66.498  54.493  1
408240  93.362  -66.492  54.459  1
408241  93.396  -66.487  54.425  1
408242  93.430  -66.484  54.392  1
408243  93.468  -66.488  54.362  1
408244  93.505  -66.492  54.331  1
408245  93.543  -66.496  54.310  1
408246  93.581  -66.503  54.292  1
408247  93.621  -66.511  54.277  1
408248  93.661  -66.520  54.264  1
408249  93.703  -66.525  54.255  1
408250  93.746  -66.527  54.246  1
408251  93.788  -66.530  54.236  1
408252  93.831  -66.533  54.225  1
408253  93.871  -66.533  54.213  1
408254  93.911  -66.536  54.197  1
408255  93.952  -66.541  54.180  1
408256  93.992  -66.545  54.161  1
408257  94.032  -66.550  54.140  1
408258  94.072  -66.554  54.121  1
408259  94.113  -66.558  54.103  1
408260  94.153  -66.563  54.088  1
408261  94.195  -66.567  54.072  1
408262  94.237  -66.573  54.055  1
408263  94.279  -66.577  54.036  1
408264  94.320  -66.582  54.013  1
408265  94.362  -66.586  53.987  1
408266  94.400  -66.589  53.959  1
408267  94.430  -66.591  53.928  1
408268  94.461  -66.592  53.897  1
408269  94.511  -66.596  53.864  1
408270  94.555  -66.599  53.833  1
408271  94.595  -66.600  53.803  1
408272  94.635  -66.602  53.773  1
408273  94.675  -66.604  53.739  1
408274  94.715  -66.605  53.705  1
408275  94.755  -66.607  53.671  1
408276  94.795  -66.608  53.637  1
408277  94.835  -66.610  53.607  1
408278  94.876  -66.619  53.581  1
408279  94.915  -66.630  53.558  1
408280  94.952  -66.639  53.538  1
408281  94.988  -66.647  53.522  1
408282  95.025  -66.655  53.508  1
408283  95.062  -66.664  53.497  1
408284  95.095  -66.665  53.487  1
408285  95.127  -66.664  53.476  1
408286  95.159  -66.664  53.462  1
408287  95.190  -66.663  53.444  1
408288  95.213  -66.658  53.422  1
408289  95.234  -66.652  53.398  1
408290  95.255  -66.646  53.372  1
408291  95.293  -66.647  53.350  1
408292  95.340  -66.653  53.330  1
408293  95.387  -66.658  53.313  1
408294  95.435  -66.664  53.299  1
408295  95.482  -66.669  53.288  1
408296  95.530  -66.682  53.277  1
408297  95.578  -66.694  53.267  1
408298  95.622  -66.697  53.255  1
408299  95.667  -66.701  53.241  1
408300  95.712  -66.708  53.226  1
408301  95.758  -66.715  53.210  1
408302  95.804  -66.722  53.195  1
408303  95.844  -66.727  53.178  1
408304  95.881  -66.733  53.161  1
408305  95.917  -66.737  53.140  1
408306  95.954  -66.743  53.118  1
408307  95.991  -66.747  53.093  1
408308  96.029  -66.750  53.066  1
408309  96.067  -66.752  53.039  1
408310  96.105  -66.755  53.011  1
408311  96.143  -66.757  52.985  1
408312  96.181  -66.759  52.957  1
408313  96.222  -66.760  52.927  1
408314  96.259  -66.760  52.894  1
408315  96.294  -66.761  52.862  1
408316  96.328  -66.762  52.830  1
408317  96.364  -66.763  52.799  1
408318  96.400  -66.767  52.770  1
408319  96.436  -66.770  52.736  1
408320  96.468  -66.771  52.702  1
408321  96.496  -66.768  52.672  1
408322  96.524  -66.767  52.645  1
408323  96.553  -66.765  52.620  1
408324  96.581  -66.761  52.599  1
408325  96.609  -66.754  52.575  1
408326  96.639  -66.749  52.550  1
408327  96.678  -66.752  52.524  1
408328  96.718  -66.754  52.495  1
408329  96.757  -66.757  52.468  1
408330  96.796  -66.759  52.444  1
408331  96.835  -66.762  52.423  1
408332  96.876  -66.762  52.404  1
408333  96.920  -66.758  52.380  1
408334  96.965  -66.755  52.356  1
408335  97.011  -66.752  52.333  1
408336  97.056  -66.748  52.312  1
408337  97.102  -66.744  52.293  1
408338  97.147  -66.740  52.275  1
408339  97.192  -66.737  52.257  1
408340  97.238  -66.733  52.238  1
408341  97.283  -66.729  52.220  1
408342  97.327  -66.730  52.198  1
408343  97.369  -66.738  52.173  1
408344  97.413  -66.744  52.144  1
408345  97.462  -66.752  52.110  1
408346  97.511  -66.759  52.075  1
408347  97.561  -66.767  52.038  1
408348  97.599  -66.779  51.999  1
408349  97.638  -66.791  51.958  1
408350  97.673  -66.802  51.917  1
408351  97.707  -66.813  51.875  1
408352  97.741  -66.823  51.831  1
408353  97.775  -66.834  51.786  1
408354  97.808  -66.843  51.741  1
408355  97.842  -66.854  51.695  1
408356  97.875  -66.864  51.652  1
408357  97.909  -66.874  51.608  1
408358  97.942  -66.884  51.565  1
408359  97.975  -66.893  51.521  1
408360  98.008  -66.903  51.477  1
408361  98.041  -66.912  51.432  1
408362  98.074  -66.921  51.386  1
408363  98.107  -66.931  51.340  1
408364  98.140  -66.940  51.294  1
408365  98.172  -66.950  51.248  1
408366  98.198  -66.956  51.203  1
408367  98.223  -66.963  51.158  1
408368  98.248  -66.970  51.114  1
408369  98.274  -66.978  51.072  1
408370  98.300  -66.984  51.034  1
408371  98.325  -66.991  50.997  1
408372  98.349  -66.990  50.961  1
408373  98.371  -66.987  50.924  1
408374  98.397  -66.985  50.885  1
408375  98.428  -66.984  50.842  1
408376  98.458  -66.982  50.798  1
408377  98.489  -66.981  50.753  1
408378  98.519  -66.979  50.707  1
408379  98.553  -66.981  50.659  1
408380  98.588  -66.985  50.612  1
408381  98.623  -66.990  50.563  1
408382  98.649  -67.015  50.513  1
408383  98.673  -67.047  50.462  1
408384  98.720  -67.048  50.411  1
408385  98.767  -67.050  50.359  1
408386  98.814  -67.050  50.307  1
408387  98.862  -67.052  50.254  1
408388  98.909  -67.053  50.201  1
408389  98.956  -67.054  50.147  1
408390  99.003  -67.055  50.093  1
408391  99.051  -67.056  50.039  1
408392  99.098  -67.057  49.985  1
408393  99.145  -67.058  49.931  1
408394  99.192  -67.059  49.877  1
408395  99.241  -67.062  49.824  1
408396  99.282  -67.078  49.772  1
408397  99.325  -67.095  49.720  1
408398  99.369  -67.112  49.669  1
408399  99.412  -67.129  49.618  1
408400  99.456  -67.147  49.567  1
408401  99.500  -67.164  49.516  1
408402  99.543  -67.182  49.464  1
408403  99.587  -67.198  49.413  1
408404  99.630  -67.216  49.362  1
408405  99.674  -67.233  49.310  1
408406  99.717  -67.251  49.260  1
408407  99.761  -67.267  49.211  1
408408  99.796  -67.263  49.161  1
408409  99.821  -67.245  49.112  1
408410  99.837  -67.241  49.065  1
408411  99.845  -67.251  49.017  1
408412  99.853  -67.259  48.969  1
408413  99.873  -67.266  48.921  1
408414  99.894  -67.275  48.874  1
408415  99.914  -67.282  48.828  1
408416  99.949  -67.282  48.785  1
408417  99.989  -67.280  48.740  1
408418  100.028  -67.279  48.698  1
408419  100.068  -67.276  48.655  1
408420  100.108  -67.274  48.612  1
408421  100.147  -67.272  48.570  1
408422  100.187  -67.270  48.529  1
408423  100.226  -67.268  48.488  1
408424  100.266  -67.266  48.448  1
408425  100.313  -67.264  48.409  1
408879  90.434  -66.349  54.942  1
408880  90.489  -66.354  54.948  1
408881  90.545  -66.357  54.954  1
408882  90.600  -66.362  54.961  1
408883  90.656  -66.367  54.968  1
408884  90.712  -66.370  54.974  1
408885  90.767  -66.375  54.980  1
408886  90.823  -66.379  54.988  1
408887  90.872  -66.389  54.996  1
408888  90.921  -66.398  55.005  1
408889  90.969  -66.407  55.014  1
408890  91.018  -66.417  55.022  1
408891  91.067  -66.426  55.033  1
408892  91.115  -66.436  55.044  1
408893  91.163  -66.446  55.056  1
408894  91.211  -66.454  55.069  1
408895  91.252  -66.455  55.079  1
408896  91.294  -66.456  55.090  1
408897  91.335  -66.457  55.099  1
408898  91.376  -66.458  55.106  1
408899  91.418  -66.459  55.109  1
408900  91.461  -66.465  55.108  1
408901  91.504  -66.472  55.103  1
408902  91.547  -66.470  55.096  1
408903  91.592  -66.473  55.087  1
408904  91.637  -66.480  55.076  1
408905  91.681  -66.485  55.064  1
408906  91.726  -66.491  55.051  1
408907  91.770  -66.496  55.039  1
408908  91.814  -66.502  55.029  1
408909  91.860  -66.508  55.020  1
408910  91.918  -66.518  55.011  1
408911  91.977  -66.528  55.002  1
408912  92.035  -66.538  54.993  1
408913  92.093  -66.548  54.982  1
408914  92.152  -66.558  54.972  1
408915  92.210  -66.568  54.963  1
408916  92.269  -66.578  54.955  1
408917  92.326  -66.589  54.949  1
408918  92.381  -66.602  54.943  1
408919  92.437  -66.614  54.932  1
408920  92.492  -66.627  54.919  1
408921  92.545  -66.633  54.909  1
408922  92.596  -66.633  54.903  1
408923  92.646  -66.636  54.901  1
408924  92.694  -66.646  54.897  1
408925  92.740  -66.643  54.888  1
408926  92.783  -66.635  54.873  1
408927  92.827  -66.626  54.854  1
408928  92.871  -66.617  54.833  1
408929  92.910  -66.604  54.812  1
408930  92.948  -66.590  54.789  1
408931  92.986  -66.576  54.767  1
408932  93.024  -66.561  54.744  1
408933  93.062  -66.548  54.726  1
408934  93.100  -66.533  54.707  1
408935  93.138  -66.519  54.686  1
408936  93.177  -66.505  54.657  1
408937  93.215  -66.491  54.625  1
408938  93.253  -66.476  54.588  1
408939  93.291  -66.463  54.549  1
408940  93.325  -66.457  54.513  1
408941  93.359  -66.452  54.478  1
408942  93.394  -66.447  54.443  1
408943  93.427  -66.442  54.411  1
408944  93.464  -66.442  54.382  1
408945  93.501  -66.446  54.354  1
408946  93.539  -66.450  54.333  1
408947  93.577  -66.457  54.316  1
408948  93.617  -66.466  54.303  1
408949  93.657  -66.473  54.291  1
408950  93.700  -66.476  54.281  1
408951  93.743  -66.479  54.270  1
408952  93.785  -66.481  54.260  1
408953  93.828  -66.484  54.248  1
408954  93.872  -66.490  54.236  1
408955  93.914  -66.495  54.220  1
408956  93.955  -66.500  54.201  1
408957  93.995  -66.505  54.180  1
408958  94.035  -66.509  54.158  1
408959  94.075  -66.514  54.139  1
408960  94.116  -66.518  54.120  1
408961  94.156  -66.523  54.103  1
408962  94.198  -66.527  54.086  1
408963  94.240  -66.532  54.068  1
408964  94.281  -66.536  54.046  1
408965  94.323  -66.541  54.023  1
408966  94.361  -66.545  53.995  1
408967  94.391  -66.546  53.965  1
408968  94.422  -66.548  53.934  1
408969  94.452  -66.549  53.903  1
408970  94.501  -66.552  53.871  1
408971  94.552  -66.556  53.842  1
408972  94.592  -66.558  53.816  1
408973  94.632  -66.559  53.788  1
408974  94.672  -66.561  53.754  1
408975  94.712  -66.563  53.721  1
408976  94.752  -66.564  53.687  1
408977  94.792  -66.566  53.655  1
408978  94.832  -66.568  53.626  1
408979  94.875  -66.583  53.601  1
408980  94.912  -66.593  53.580  1
408981  94.949  -66.602  53.561  1
408982  94.986  -66.611  53.545  1
408983  95.023  -66.619  53.531  1
408984  95.059  -66.627  53.519  1
408985  95.096  -66.636  53.507  1
408986  95.133  -66.644  53.494  1
408987  95.166  -66.646  53.476  1
408988  95.195  -66.644  53.455  1
408989  95.216  -66.638  53.430  1
408990  95.237  -66.632  53.404  1
408991  95.257  -66.626  53.378  1
408992  95.278  -66.620  53.356  1
408993  95.324  -66.624  53.337  1
408994  95.372  -66.630  53.321  1
408995  95.419  -66.635  53.308  1
408996  95.467  -66.640  53.298  1
408997  95.514  -66.646  53.288  1
408998  95.561  -66.652  53.279  1
408999  95.608  -66.658  53.268  1
409000  95.654  -66.665  53.254  1
409001  95.700  -66.672  53.239  1
409002  95.746  -66.679  53.223  1
409003  95.792  -66.686  53.206  1
409004  95.834  -66.693  53.189  1
409005  95.871  -66.697  53.171  1
409006  95.908  -66.702  53.151  1
409007  95.944  -66.707  53.130  1
409008  95.984  -66.709  53.108  1
409009  96.026  -66.709  53.084  1
409010  96.064  -66.711  53.059  1
409011  96.102  -66.714  53.032  1
409012  96.141  -66.716  53.005  1
409013  96.179  -66.718  52.978  1
409014  96.220  -66.718  52.948  1
409015  96.259  -66.718  52.914  1
409016  96.294  -66.718  52.881  1
409017  96.329  -66.719  52.849  1
409018  96.365  -66.722  52.818  1
409019  96.400  -66.725  52.788  1
409020  96.437  -66.728  52.755  1
409021  96.473  -66.731  52.722  1
409022  96.501  -66.729  52.692  1
409023  96.529  -66.727  52.665  1
409024  96.557  -66.724  52.640  1
409025  96.586  -66.717  52.618  1
409026  96.614  -66.710  52.595  1
409027  96.644  -66.705  52.569  1
409028  96.683  -66.707  52.542  1
409029  96.722  -66.710  52.511  1
409030  96.761  -66.713  52.482  1
409031  96.801  -66.715  52.455  1
409032  96.842  -66.712  52.430  1
409033  96.883  -66.710  52.411  1
409034  96.928  -66.706  52.388  1
409035  96.973  -66.702  52.365  1
409036  97.018  -66.699  52.343  1
409037  97.064  -66.696  52.323  1
409038  97.109  -66.692  52.304  1
409039  97.154  -66.688  52.286  1
409040  97.199  -66.684  52.268  1
409041  97.245  -66.680  52.249  1
409042  97.288  -66.685  52.228  1
409043  97.330  -66.696  52.204  1
409044  97.371  -66.702  52.177  1
409045  97.411  -66.707  52.146  1
409046  97.459  -66.715  52.111  1
409047  97.508  -66.722  52.073  1
409048  97.558  -66.730  52.036  1
409049  97.596  -66.742  51.998  1
409050  97.634  -66.754  51.958  1
409051  97.672  -66.766  51.917  1
409052  97.711  -66.778  51.874  1
409053  97.749  -66.790  51.831  1
409054  97.785  -66.802  51.786  1
409055  97.818  -66.812  51.740  1
409056  97.852  -66.822  51.695  1
409057  97.885  -66.832  51.649  1
409058  97.919  -66.843  51.604  1
409059  97.952  -66.853  51.560  1
409060  97.986  -66.862  51.517  1
409061  98.018  -66.871  51.474  1
409062  98.052  -66.881  51.431  1
409063  98.085  -66.890  51.386  1
409064  98.113  -66.898  51.340  1
409065  98.139  -66.905  51.294  1
409066  98.164  -66.912  51.249  1
409067  98.190  -66.919  51.203  1
409068  98.216  -66.926  51.157  1
409069  98.241  -66.933  51.114  1
409070  98.267  -66.940  51.071  1
409071  98.292  -66.947  51.034  1
409072  98.317  -66.953  50.998  1
409073  98.340  -66.950  50.962  1
409074  98.363  -66.947  50.925  1
409075  98.386  -66.944  50.887  1
409076  98.417  -66.943  50.845  1
409077  98.447  -66.941  50.800  1
409078  98.482  -66.946  50.754  1
409079  98.518  -66.950  50.707  1
409080  98.553  -66.954  50.659  1
409081  98.588  -66.958  50.611  1
409082  98.624  -66.962  50.562  1
409083  98.653  -66.980  50.511  1
409084  98.681  -67.006  50.460  1
409085  98.728  -67.007  50.407  1
409086  98.776  -67.008  50.354  1
409087  98.823  -67.009  50.302  1
409088  98.870  -67.010  50.249  1
409089  98.917  -67.011  50.196  1
409090  98.964  -67.012  50.142  1
409091  99.012  -67.013  50.089  1
409092  99.059  -67.015  50.034  1
409093  99.106  -67.015  49.980  1
409094  99.153  -67.018  49.926  1
409095  99.199  -67.019  49.873  1
409096  99.244  -67.025  49.820  1
409097  99.277  -67.030  49.768  1
409098  99.313  -67.040  49.716  1
409099  99.356  -67.057  49.666  1
409100  99.400  -67.074  49.614  1
409101  99.443  -67.091  49.563  1
409102  99.486  -67.108  49.511  1
409103  99.529  -67.125  49.459  1
409104  99.573  -67.143  49.407  1
409105  99.617  -67.160  49.355  1
409106  99.660  -67.177  49.304  1
409107  99.703  -67.194  49.252  1
409108  99.747  -67.211  49.202  1
409109  99.794  -67.223  49.153  1
409110  99.819  -67.205  49.104  1
409111  99.837  -67.198  49.055  1
409112  99.845  -67.207  49.007  1
409113  99.858  -67.215  48.959  1
409114  99.879  -67.222  48.912  1
409115  99.899  -67.230  48.865  1
409116  99.920  -67.238  48.820  1
409117  99.959  -67.236  48.776  1
409118  99.998  -67.235  48.732  1
409119  100.037  -67.232  48.689  1
409120  100.077  -67.230  48.646  1
409121  100.117  -67.229  48.603  1
409122  100.156  -67.226  48.562  1
409123  100.196  -67.224  48.521  1
409124  100.235  -67.222  48.481  1
409125  100.279  -67.220  48.440  1
409126  100.327  -67.218  48.401  1
409582  90.552  -66.308  54.955  1
409583  90.608  -66.313  54.961  1
409584  90.663  -66.317  54.967  1
409585  90.719  -66.321  54.973  1
409586  90.774  -66.326  54.979  1
409587  90.822  -66.335  54.986  1
409588  90.871  -66.345  54.993  1
409589  90.920  -66.354  55.000  1
409590  90.968  -66.364  55.008  1
409591  91.017  -66.373  55.014  1
409592  91.066  -66.383  55.023  1
409593  91.114  -66.393  55.033  1
409594  91.162  -66.402  55.043  1
409595  91.211  -66.412  55.055  1
409596  91.257  -66.418  55.065  1
409597  91.298  -66.419  55.074  1
409598  91.340  -66.420  55.084  1
409599  91.381  -66.421  55.092  1
409600  91.422  -66.422  55.097  1
409601  91.463  -66.423  55.097  1
409602  91.505  -66.423  55.094  1
409603  91.548  -66.428  55.089  1
409604  91.593  -66.434  55.081  1
409605  91.638  -66.440  55.072  1
409606  91.682  -66.445  55.062  1
409607  91.727  -66.451  55.052  1
409608  91.772  -66.457  55.043  1
409609  91.816  -66.463  55.036  1
409610  91.873  -66.472  55.029  1
409611  91.932  -66.483  55.021  1
409612  91.990  -66.492  55.012  1
409613  92.049  -66.502  55.004  1
409614  92.107  -66.512  54.994  1
409615  92.162  -66.525  54.984  1
409616  92.217  -66.538  54.976  1
409617  92.273  -66.550  54.969  1
409618  92.328  -66.563  54.963  1
409619  92.383  -66.576  54.957  1
409620  92.436  -66.581  54.947  1
409621  92.487  -66.581  54.936  1
409622  92.537  -66.580  54.927  1
409623  92.587  -66.584  54.922  1
409624  92.636  -66.594  54.923  1
409625  92.684  -66.604  54.920  1
409626  92.728  -66.597  54.913  1
409627  92.772  -66.588  54.901  1
409628  92.816  -66.580  54.880  1
409629  92.860  -66.570  54.857  1
409630  92.904  -66.562  54.832  1
409631  92.945  -66.551  54.807  1
409632  92.983  -66.537  54.784  1
409633  93.021  -66.523  54.763  1
409634  93.059  -66.508  54.747  1
409635  93.097  -66.495  54.729  1
409636  93.135  -66.480  54.708  1
409637  93.174  -66.466  54.679  1
409638  93.211  -66.452  54.647  1
409639  93.250  -66.438  54.608  1
409640  93.288  -66.423  54.569  1
409641  93.323  -66.417  54.531  1
409642  93.357  -66.411  54.496  1
409643  93.391  -66.407  54.462  1
409644  93.425  -66.401  54.431  1
409645  93.459  -66.396  54.402  1
409646  93.497  -66.401  54.376  1
409647  93.534  -66.404  54.356  1
409648  93.573  -66.411  54.341  1
409649  93.613  -66.420  54.328  1
409650  93.654  -66.424  54.316  1
409651  93.697  -66.427  54.306  1
409652  93.740  -66.429  54.294  1
409653  93.783  -66.433  54.281  1
409654  93.828  -66.441  54.269  1
409655  93.872  -66.448  54.255  1
409656  93.915  -66.455  54.239  1
409657  93.956  -66.460  54.221  1
409658  93.997  -66.464  54.200  1
409659  94.039  -66.469  54.177  1
409660  94.079  -66.473  54.156  1
409661  94.119  -66.477  54.136  1
409662  94.159  -66.482  54.118  1
409663  94.200  -66.486  54.100  1
409664  94.242  -66.491  54.080  1
409665  94.283  -66.495  54.054  1
409666  94.322  -66.499  54.027  1
409667  94.352  -66.501  53.999  1
409668  94.383  -66.502  53.969  1
409669  94.413  -66.504  53.938  1
409670  94.444  -66.505  53.907  1
409671  94.491  -66.508  53.879  1
409672  94.543  -66.512  53.852  1
409673  94.589  -66.515  53.826  1
409674  94.629  -66.517  53.799  1
409675  94.669  -66.518  53.768  1
409676  94.709  -66.520  53.736  1
409677  94.749  -66.522  53.704  1
409678  94.789  -66.523  53.673  1
409679  94.831  -66.533  53.646  1
409680  94.873  -66.548  53.624  1
409681  94.910  -66.557  53.604  1
409682  94.947  -66.565  53.586  1
409683  94.983  -66.574  53.570  1
409684  95.020  -66.582  53.554  1
409685  95.057  -66.591  53.539  1
409686  95.094  -66.599  53.524  1
409687  95.130  -66.608  53.508  1
409688  95.166  -66.615  53.488  1
409689  95.194  -66.618  53.464  1
409690  95.218  -66.617  53.437  1
409691  95.239  -66.611  53.410  1
409692  95.260  -66.605  53.384  1
409693  95.280  -66.599  53.363  1
409694  95.309  -66.596  53.345  1
409695  95.356  -66.602  53.330  1
409696  95.404  -66.607  53.317  1
409697  95.451  -66.612  53.308  1
409698  95.498  -66.617  53.299  1
409699  95.554  -66.617  53.290  1
409700  95.600  -66.622  53.280  1
409701  95.642  -66.630  53.268  1
409702  95.688  -66.636  53.254  1
409703  95.734  -66.643  53.236  1
409704  95.779  -66.650  53.218  1
409705  95.824  -66.657  53.201  1
409706  95.861  -66.661  53.182  1
409707  95.898  -66.667  53.163  1
409708  95.937  -66.669  53.143  1
409709  95.979  -66.669  53.122  1
409710  96.021  -66.670  53.100  1
409711  96.061  -66.671  53.077  1
409712  96.100  -66.673  53.052  1
409713  96.137  -66.675  53.026  1
409714  96.176  -66.677  52.998  1
409715  96.218  -66.676  52.968  1
409716  96.259  -66.675  52.934  1
409717  96.295  -66.676  52.902  1
409718  96.329  -66.677  52.869  1
409719  96.366  -66.680  52.836  1
409720  96.401  -66.683  52.803  1
409721  96.438  -66.686  52.771  1
409722  96.474  -66.690  52.740  1
409723  96.506  -66.690  52.711  1
409724  96.534  -66.686  52.684  1
409725  96.562  -66.680  52.659  1
409726  96.591  -66.673  52.636  1
409727  96.619  -66.666  52.613  1
409728  96.648  -66.661  52.587  1
409729  96.687  -66.663  52.557  1
409730  96.727  -66.666  52.525  1
409731  96.767  -66.665  52.494  1
409732  96.808  -66.662  52.465  1
409733  96.850  -66.660  52.439  1
409734  96.891  -66.657  52.419  1
409735  96.935  -66.654  52.396  1
409736  96.980  -66.650  52.374  1
409737  97.026  -66.646  52.353  1
409738  97.071  -66.643  52.333  1
409739  97.116  -66.639  52.314  1
409740  97.162  -66.636  52.296  1
409741  97.207  -66.632  52.276  1
409742  97.249  -66.640  52.255  1
409743  97.291  -66.651  52.233  1
409744  97.332  -66.661  52.206  1
409745  97.373  -66.667  52.176  1
409746  97.413  -66.671  52.143  1
409747  97.456  -66.677  52.107  1
409748  97.505  -66.684  52.068  1
409749  97.554  -66.693  52.029  1
409750  97.592  -66.705  51.990  1
409751  97.631  -66.717  51.950  1
409752  97.669  -66.729  51.909  1
409753  97.707  -66.741  51.868  1
409754  97.745  -66.753  51.824  1
409755  97.784  -66.765  51.780  1
409756  97.822  -66.777  51.735  1
409757  97.860  -66.790  51.690  1
409758  97.895  -66.800  51.645  1
409759  97.929  -66.811  51.600  1
409760  97.962  -66.821  51.555  1
409761  97.996  -66.830  51.510  1
409762  98.029  -66.840  51.467  1
409763  98.055  -66.846  51.424  1
409764  98.080  -66.854  51.379  1
409765  98.106  -66.861  51.335  1
409766  98.131  -66.868  51.291  1
409767  98.157  -66.874  51.246  1
409768  98.182  -66.882  51.202  1
409769  98.208  -66.889  51.158  1
409770  98.233  -66.896  51.116  1
409771  98.259  -66.903  51.074  1
409772  98.285  -66.910  51.034  1
409773  98.309  -66.913  50.997  1
409774  98.332  -66.910  50.960  1
409775  98.354  -66.907  50.923  1
409776  98.378  -66.904  50.886  1
409777  98.413  -66.909  50.845  1
409778  98.447  -66.914  50.801  1
409779  98.483  -66.918  50.755  1
409780  98.518  -66.922  50.708  1
409781  98.553  -66.926  50.660  1
409782  98.589  -66.931  50.610  1
409783  98.624  -66.934  50.560  1
409784  98.657  -66.944  50.509  1
409785  98.690  -66.965  50.456  1
409786  98.737  -66.965  50.404  1
409787  98.784  -66.966  50.350  1
409788  98.831  -66.968  50.297  1
409789  98.878  -66.968  50.243  1
409790  98.926  -66.970  50.189  1
409791  98.973  -66.972  50.136  1
409792  99.019  -66.973  50.082  1
409793  99.065  -66.975  50.028  1
409794  99.111  -66.978  49.974  1
409795  99.157  -66.980  49.921  1
409796  99.203  -66.981  49.868  1
409797  99.248  -66.990  49.815  1
409798  99.291  -67.003  49.763  1
409799  99.320  -67.006  49.710  1
409800  99.341  -67.002  49.659  1
409801  99.378  -67.012  49.608  1
409802  99.421  -67.030  49.556  1
409803  99.465  -67.047  49.504  1
409804  99.508  -67.064  49.451  1
409805  99.551  -67.081  49.400  1
409806  99.594  -67.098  49.347  1
409807  99.638  -67.116  49.295  1
409808  99.682  -67.132  49.244  1
409809  99.725  -67.150  49.194  1
409810  99.777  -67.165  49.144  1
409811  99.817  -67.165  49.095  1
409812  99.837  -67.154  49.046  1
409813  99.845  -67.163  48.998  1
409814  99.864  -67.170  48.951  1
409815  99.885  -67.178  48.904  1
409816  99.905  -67.186  48.858  1
409817  99.928  -67.192  48.812  1
409818  99.968  -67.191  48.768  1
409819  100.007  -67.188  48.725  1
409820  100.047  -67.186  48.682  1
409821  100.086  -67.185  48.639  1
409822  100.126  -67.182  48.596  1
409823  100.165  -67.180  48.554  1
409824  100.205  -67.178  48.513  1
409825  100.245  -67.176  48.473  1
409826  100.293  -67.174  48.433  1
409827  100.342  -67.172  48.393  1
410284  90.615  -66.263  54.961  1
410285  90.670  -66.267  54.966  1
410286  90.724  -66.273  54.972  1
410287  90.773  -66.282  54.978  1
410288  90.821  -66.292  54.983  1
410289  90.870  -66.301  54.990  1
410290  90.919  -66.311  54.996  1
410291  90.967  -66.320  55.003  1
410292  91.016  -66.330  55.010  1
410293  91.065  -66.340  55.017  1
410294  91.113  -66.349  55.026  1
410295  91.162  -66.359  55.036  1
410296  91.210  -66.369  55.048  1
410297  91.258  -66.378  55.058  1
410298  91.302  -66.381  55.066  1
410299  91.343  -66.382  55.073  1
410300  91.383  -66.382  55.081  1
410301  91.424  -66.382  55.086  1
410302  91.465  -66.383  55.088  1
410303  91.506  -66.383  55.086  1
410304  91.551  -66.397  55.083  1
410305  91.595  -66.401  55.076  1
410306  91.639  -66.402  55.067  1
410307  91.683  -66.406  55.059  1
410308  91.728  -66.411  55.053  1
410309  91.773  -66.417  55.048  1
410310  91.828  -66.426  55.044  1
410311  91.887  -66.436  55.038  1
410312  91.943  -66.448  55.031  1
410313  91.998  -66.461  55.023  1
410314  92.054  -66.474  55.016  1
410315  92.108  -66.486  55.007  1
410316  92.164  -66.499  54.998  1
410317  92.219  -66.512  54.990  1
410318  92.275  -66.525  54.983  1
410319  92.327  -66.530  54.976  1
410320  92.378  -66.530  54.970  1
410321  92.429  -66.529  54.961  1
410322  92.479  -66.529  54.951  1
410323  92.529  -66.533  54.943  1
410324  92.577  -66.542  54.940  1
410325  92.626  -66.552  54.941  1
410326  92.673  -66.559  54.940  1
410327  92.717  -66.550  54.934  1
410328  92.761  -66.542  54.922  1
410329  92.804  -66.533  54.901  1
410330  92.848  -66.524  54.877  1
410331  92.892  -66.515  54.851  1
410332  92.936  -66.507  54.825  1
410333  92.980  -66.498  54.799  1
410334  93.018  -66.484  54.780  1
410335  93.056  -66.470  54.763  1
410336  93.094  -66.456  54.746  1
410337  93.132  -66.442  54.723  1
410338  93.170  -66.427  54.695  1
410339  93.208  -66.414  54.660  1
410340  93.247  -66.399  54.622  1
410341  93.284  -66.385  54.583  1
410342  93.320  -66.376  54.548  1
410343  93.354  -66.371  54.513  1
410344  93.389  -66.366  54.480  1
410345  93.423  -66.361  54.450  1
410346  93.457  -66.356  54.423  1
410347  93.492  -66.354  54.397  1
410348  93.530  -66.358  54.380  1
410349  93.569  -66.366  54.366  1
410350  93.609  -66.373  54.353  1
410351  93.652  -66.376  54.341  1
410352  93.694  -66.378  54.330  1
410353  93.739  -66.384  54.316  1
410354  93.783  -66.392  54.302  1
410355  93.827  -66.399  54.288  1
410356  93.872  -66.407  54.272  1
410357  93.916  -66.414  54.256  1
410358  93.958  -66.419  54.238  1
410359  93.998  -66.423  54.218  1
410360  94.040  -66.428  54.195  1
410361  94.081  -66.433  54.172  1
410362  94.122  -66.437  54.152  1
410363  94.163  -66.442  54.133  1
410364  94.203  -66.446  54.114  1
410365  94.244  -66.451  54.092  1
410366  94.283  -66.454  54.064  1
410367  94.314  -66.456  54.035  1
410368  94.344  -66.458  54.005  1
410369  94.374  -66.459  53.975  1
410370  94.405  -66.461  53.944  1
410371  94.436  -66.461  53.914  1
410372  94.481  -66.464  53.887  1
410373  94.533  -66.468  53.861  1
410374  94.584  -66.472  53.835  1
410375  94.626  -66.474  53.809  1
410376  94.667  -66.476  53.779  1
410377  94.706  -66.477  53.750  1
410378  94.747  -66.479  53.721  1
410379  94.786  -66.483  53.693  1
410380  94.829  -66.498  53.670  1
410381  94.871  -66.512  53.650  1
410382  94.907  -66.520  53.631  1
410383  94.944  -66.529  53.613  1
410384  94.981  -66.537  53.596  1
410385  95.018  -66.545  53.578  1
410386  95.054  -66.554  53.560  1
410387  95.090  -66.562  53.540  1
410388  95.120  -66.569  53.518  1
410389  95.151  -66.576  53.495  1
410390  95.178  -66.577  53.469  1
410391  95.204  -66.577  53.442  1
410392  95.231  -66.578  53.415  1
410393  95.258  -66.579  53.391  1
410394  95.283  -66.578  53.371  1
410395  95.304  -66.572  53.354  1
410396  95.341  -66.573  53.340  1
410397  95.388  -66.578  53.329  1
410398  95.443  -66.579  53.318  1
410399  95.500  -66.577  53.309  1
410400  95.556  -66.577  53.301  1
410401  95.596  -66.585  53.293  1
410402  95.633  -66.595  53.283  1
410403  95.677  -66.601  53.267  1
410404  95.722  -66.607  53.249  1
410405  95.767  -66.614  53.232  1
410406  95.813  -66.621  53.215  1
410407  95.851  -66.626  53.196  1
410408  95.890  -66.630  53.175  1
410409  95.932  -66.630  53.155  1
410410  95.973  -66.630  53.135  1
410411  96.015  -66.630  53.115  1
410412  96.057  -66.630  53.094  1
410413  96.097  -66.631  53.071  1
410414  96.135  -66.633  53.046  1
410415  96.174  -66.635  53.019  1
410416  96.215  -66.634  52.988  1
410417  96.256  -66.633  52.955  1
410418  96.295  -66.633  52.923  1
410419  96.330  -66.636  52.888  1
410420  96.367  -66.639  52.853  1
410421  96.402  -66.642  52.816  1
410422  96.439  -66.645  52.786  1
410423  96.475  -66.648  52.757  1
410424  96.510  -66.648  52.730  1
410425  96.538  -66.642  52.703  1
410426  96.567  -66.636  52.676  1
410427  96.596  -66.629  52.652  1
410428  96.624  -66.623  52.629  1
410429  96.653  -66.616  52.603  1
410430  96.692  -66.618  52.572  1
410431  96.734  -66.615  52.538  1
410432  96.775  -66.612  52.506  1
410433  96.816  -66.610  52.475  1
410434  96.858  -66.607  52.449  1
410435  96.899  -66.605  52.427  1
410436  96.942  -66.602  52.403  1
410437  96.987  -66.598  52.381  1
410438  97.033  -66.594  52.360  1
410439  97.078  -66.590  52.341  1
410440  97.123  -66.586  52.322  1
410441  97.168  -66.585  52.304  1
410442  97.210  -66.596  52.284  1
410443  97.251  -66.606  52.261  1
410444  97.293  -66.617  52.236  1
410445  97.334  -66.627  52.207  1
410446  97.375  -66.631  52.174  1
410447  97.415  -66.636  52.140  1
410448  97.455  -66.640  52.102  1
410449  97.502  -66.647  52.063  1
410450  97.550  -66.655  52.022  1
410451  97.589  -66.667  51.982  1
410452  97.627  -66.679  51.942  1
410453  97.665  -66.691  51.901  1
410454  97.704  -66.703  51.861  1
410455  97.742  -66.715  51.817  1
410456  97.780  -66.727  51.774  1
410457  97.818  -66.740  51.729  1
410458  97.857  -66.752  51.684  1
410459  97.895  -66.765  51.640  1
410460  97.933  -66.777  51.596  1
410461  97.971  -66.788  51.551  1
410462  97.996  -66.796  51.506  1
410463  98.021  -66.802  51.461  1
410464  98.047  -66.809  51.418  1
410465  98.073  -66.816  51.375  1
410466  98.098  -66.824  51.332  1
410467  98.124  -66.831  51.291  1
410468  98.149  -66.837  51.248  1
410469  98.175  -66.844  51.206  1
410470  98.201  -66.852  51.163  1
410471  98.226  -66.859  51.121  1
410472  98.251  -66.865  51.078  1
410473  98.277  -66.872  51.036  1
410474  98.301  -66.872  50.996  1
410475  98.323  -66.869  50.957  1
410476  98.349  -66.866  50.920  1
410477  98.383  -66.862  50.883  1
410478  98.421  -66.864  50.842  1
410479  98.456  -66.871  50.799  1
410480  98.489  -66.880  50.755  1
410481  98.521  -66.889  50.708  1
410482  98.555  -66.897  50.660  1
410483  98.589  -66.903  50.610  1
410484  98.624  -66.907  50.559  1
410485  98.660  -66.911  50.507  1
410486  98.698  -66.923  50.455  1
410487  98.745  -66.924  50.402  1
410488  98.792  -66.925  50.348  1
410489  98.839  -66.928  50.294  1
410490  98.885  -66.929  50.239  1
410491  98.931  -66.931  50.184  1
410492  98.978  -66.934  50.131  1
410493  99.023  -66.935  50.077  1
410494  99.070  -66.937  50.024  1
410495  99.116  -66.940  49.970  1
410496  99.162  -66.942  49.917  1
410497  99.208  -66.944  49.863  1
410498  99.251  -66.955  49.810  1
410499  99.294  -66.968  49.757  1
410500  99.338  -66.981  49.704  1
410501  99.363  -66.981  49.653  1
410502  99.384  -66.978  49.601  1
410503  99.405  -66.974  49.549  1
410504  99.443  -66.985  49.497  1
410505  99.486  -67.003  49.443  1
410506  99.529  -67.019  49.392  1
410507  99.573  -67.037  49.340  1
410508  99.616  -67.053  49.287  1
410509  99.659  -67.071  49.236  1
410510  99.705  -67.088  49.186  1
410511  99.757  -67.103  49.136  1
410512  99.809  -67.118  49.086  1
410513  99.837  -67.110  49.038  1
410514  99.849  -67.119  48.990  1
410515  99.869  -67.126  48.943  1
410516  99.890  -67.134  48.897  1
410517  99.910  -67.142  48.851  1
410518  99.937  -67.147  48.805  1
410519  99.977  -67.144  48.762  1
410520  100.016  -67.142  48.718  1
410521  100.056  -67.141  48.675  1
410522  100.096  -67.138  48.632  1
410523  100.135  -67.136  48.589  1
410524  100.175  -67.135  48.547  1
410525  100.214  -67.132  48.506  1
410526  100.260  -67.130  48.466  1
410527  100.308  -67.128  48.426  1
410528  100.356  -67.126  48.386  1
410986  90.675  -66.219  54.965  1
410987  90.723  -66.229  54.971  1
410988  90.772  -66.238  54.976  1
410989  90.820  -66.248  54.981  1
410990  90.869  -66.258  54.987  1
410991  90.918  -66.267  54.993  1
410992  90.966  -66.277  54.999  1
410993  91.015  -66.287  55.005  1
410994  91.064  -66.296  55.012  1
410995  91.112  -66.306  55.020  1
410996  91.161  -66.316  55.029  1
410997  91.209  -66.323  55.041  1
410998  91.257  -66.330  55.051  1
410999  91.303  -66.342  55.059  1
411000  91.344  -66.342  55.066  1
411001  91.384  -66.342  55.072  1
411002  91.425  -66.342  55.077  1
411003  91.466  -66.343  55.079  1
411004  91.507  -66.344  55.079  1
411005  91.553  -66.358  55.076  1
411006  91.598  -66.373  55.071  1
411007  91.642  -66.378  55.064  1
411008  91.686  -66.379  55.059  1
411009  91.730  -66.379  55.056  1
411010  91.779  -66.385  55.053  1
411011  91.834  -66.398  55.050  1
411012  91.889  -66.411  55.046  1
411013  91.944  -66.423  55.041  1
411014  92.000  -66.436  55.035  1
411015  92.055  -66.448  55.029  1
411016  92.110  -66.461  55.021  1
411017  92.166  -66.474  55.013  1
411018  92.218  -66.478  55.005  1
411019  92.269  -66.477  54.997  1
411020  92.319  -66.477  54.988  1
411021  92.370  -66.476  54.981  1
411022  92.421  -66.476  54.973  1
411023  92.471  -66.482  54.965  1
411024  92.519  -66.492  54.958  1
411025  92.567  -66.501  54.956  1
411026  92.616  -66.511  54.957  1
411027  92.662  -66.512  54.957  1
411028  92.706  -66.503  54.951  1
411029  92.749  -66.495  54.939  1
411030  92.793  -66.486  54.918  1
411031  92.837  -66.477  54.894  1
411032  92.880  -66.468  54.867  1
411033  92.924  -66.460  54.840  1
411034  92.968  -66.451  54.815  1
411035  93.012  -66.442  54.796  1
411036  93.053  -66.431  54.780  1
411037  93.091  -66.417  54.762  1
411038  93.129  -66.403  54.739  1
411039  93.167  -66.389  54.708  1
411040  93.205  -66.374  54.671  1
411041  93.243  -66.361  54.633  1
411042  93.281  -66.346  54.595  1
411043  93.318  -66.335  54.559  1
411044  93.352  -66.331  54.527  1
411045  93.386  -66.326  54.496  1
411046  93.420  -66.320  54.468  1
411047  93.454  -66.316  54.443  1
411048  93.488  -66.310  54.420  1
411049  93.525  -66.313  54.403  1
411050  93.564  -66.320  54.388  1
411051  93.607  -66.324  54.375  1
411052  93.649  -66.327  54.363  1
411053  93.694  -66.335  54.351  1
411054  93.738  -66.342  54.338  1
411055  93.783  -66.350  54.323  1
411056  93.827  -66.357  54.308  1
411057  93.871  -66.365  54.292  1
411058  93.916  -66.372  54.274  1
411059  93.959  -66.378  54.253  1
411060  94.000  -66.382  54.231  1
411061  94.041  -66.387  54.209  1
411062  94.082  -66.392  54.186  1
411063  94.123  -66.396  54.167  1
411064  94.164  -66.401  54.147  1
411065  94.205  -66.405  54.127  1
411066  94.245  -66.410  54.105  1
411067  94.275  -66.411  54.077  1
411068  94.305  -66.412  54.046  1
411069  94.336  -66.414  54.015  1
411070  94.366  -66.415  53.983  1
411071  94.397  -66.417  53.952  1
411072  94.427  -66.418  53.923  1
411073  94.471  -66.421  53.896  1
411074  94.523  -66.424  53.871  1
411075  94.574  -66.428  53.845  1
411076  94.623  -66.432  53.819  1
411077  94.664  -66.433  53.791  1
411078  94.703  -66.435  53.764  1
411079  94.744  -66.436  53.739  1
411080  94.785  -66.447  53.716  1
411081  94.827  -66.462  53.697  1
411082  94.868  -66.476  53.678  1
411083  94.905  -66.484  53.659  1
411084  94.942  -66.492  53.641  1
411085  94.978  -66.501  53.621  1
411086  95.014  -66.509  53.601  1
411087  95.044  -66.515  53.579  1
411088  95.075  -66.522  53.555  1
411089  95.106  -66.529  53.529  1
411090  95.135  -66.533  53.503  1
411091  95.162  -66.534  53.475  1
411092  95.188  -66.535  53.448  1
411093  95.215  -66.536  53.422  1
411094  95.242  -66.537  53.399  1
411095  95.268  -66.538  53.380  1
411096  95.295  -66.539  53.364  1
411097  95.333  -66.540  53.351  1
411098  95.389  -66.539  53.341  1
411099  95.445  -66.538  53.330  1
411100  95.502  -66.537  53.322  1
411101  95.558  -66.536  53.314  1
411102  95.592  -66.548  53.305  1
411103  95.624  -66.560  53.295  1
411104  95.668  -66.567  53.279  1
411105  95.712  -66.573  53.261  1
411106  95.756  -66.579  53.244  1
411107  95.801  -66.585  53.227  1
411108  95.842  -66.589  53.209  1
411109  95.884  -66.589  53.188  1
411110  95.926  -66.589  53.168  1
411111  95.968  -66.590  53.148  1
411112  96.010  -66.590  53.128  1
411113  96.051  -66.590  53.108  1
411114  96.093  -66.590  53.087  1
411115  96.132  -66.592  53.063  1
411116  96.172  -66.593  53.036  1
411117  96.213  -66.592  53.006  1
411118  96.254  -66.592  52.973  1
411119  96.295  -66.591  52.939  1
411120  96.332  -66.592  52.904  1
411121  96.369  -66.595  52.869  1
411122  96.405  -66.597  52.832  1
411123  96.442  -66.599  52.801  1
411124  96.478  -66.601  52.773  1
411125  96.510  -66.597  52.746  1
411126  96.538  -66.591  52.718  1
411127  96.568  -66.586  52.693  1
411128  96.597  -66.580  52.668  1
411129  96.625  -66.574  52.644  1
411130  96.658  -66.571  52.618  1
411131  96.700  -66.566  52.585  1
411132  96.741  -66.563  52.552  1
411133  96.783  -66.560  52.518  1
411134  96.824  -66.558  52.486  1
411135  96.866  -66.555  52.458  1
411136  96.907  -66.552  52.434  1
411137  96.949  -66.549  52.411  1
411138  96.995  -66.545  52.388  1
411139  97.040  -66.542  52.366  1
411140  97.086  -66.538  52.346  1
411141  97.129  -66.541  52.328  1
411142  97.171  -66.552  52.311  1
411143  97.213  -66.561  52.291  1
411144  97.254  -66.572  52.266  1
411145  97.296  -66.583  52.237  1
411146  97.336  -66.591  52.205  1
411147  97.377  -66.596  52.171  1
411148  97.417  -66.600  52.135  1
411149  97.457  -66.605  52.097  1
411150  97.499  -66.609  52.058  1
411151  97.547  -66.617  52.016  1
411152  97.586  -66.630  51.975  1
411153  97.624  -66.642  51.933  1
411154  97.662  -66.654  51.892  1
411155  97.700  -66.666  51.852  1
411156  97.738  -66.678  51.810  1
411157  97.777  -66.690  51.767  1
411158  97.815  -66.703  51.723  1
411159  97.854  -66.716  51.678  1
411160  97.893  -66.729  51.634  1
411161  97.932  -66.741  51.591  1
411162  97.968  -66.748  51.547  1
411163  97.997  -66.754  51.503  1
411164  98.020  -66.762  51.457  1
411165  98.042  -66.771  51.414  1
411166  98.065  -66.779  51.372  1
411167  98.091  -66.786  51.332  1
411168  98.116  -66.793  51.293  1
411169  98.142  -66.800  51.253  1
411170  98.167  -66.807  51.213  1
411171  98.193  -66.814  51.171  1
411172  98.219  -66.821  51.128  1
411173  98.244  -66.828  51.084  1
411174  98.270  -66.835  51.038  1
411175  98.292  -66.832  50.995  1
411176  98.319  -66.829  50.954  1
411177  98.353  -66.825  50.914  1
411178  98.388  -66.821  50.877  1
411179  98.426  -66.823  50.837  1
411180  98.465  -66.826  50.796  1
411181  98.499  -66.834  50.753  1
411182  98.532  -66.843  50.707  1
411183  98.565  -66.851  50.659  1
411184  98.598  -66.860  50.609  1
411185  98.631  -66.868  50.558  1
411186  98.663  -66.877  50.506  1
411187  98.705  -66.883  50.455  1
411188  98.751  -66.885  50.402  1
411189  98.797  -66.887  50.347  1
411190  98.844  -66.890  50.292  1
411191  98.890  -66.891  50.236  1
411192  98.936  -66.893  50.181  1
411193  98.982  -66.896  50.127  1
411194  99.028  -66.897  50.074  1
411195  99.075  -66.900  50.021  1
411196  99.121  -66.902  49.967  1
411197  99.166  -66.904  49.913  1
411198  99.212  -66.906  49.859  1
411199  99.255  -66.920  49.805  1
411200  99.298  -66.934  49.752  1
411201  99.341  -66.946  49.698  1
411202  99.384  -66.960  49.646  1
411203  99.407  -66.957  49.594  1
411204  99.427  -66.953  49.542  1
411205  99.448  -66.950  49.490  1
411206  99.469  -66.945  49.436  1
411207  99.508  -66.958  49.384  1
411208  99.551  -66.975  49.333  1
411209  99.594  -66.992  49.281  1
411210  99.638  -67.009  49.229  1
411211  99.686  -67.025  49.179  1
411212  99.737  -67.041  49.129  1
411213  99.789  -67.056  49.079  1
411214  99.837  -67.066  49.031  1
411215  99.855  -67.075  48.984  1
411216  99.875  -67.082  48.937  1
411217  99.896  -67.090  48.891  1
411218  99.916  -67.098  48.844  1
411219  99.946  -67.100  48.798  1
411220  99.986  -67.098  48.755  1
411221  100.025  -67.097  48.712  1
411222  100.065  -67.094  48.668  1
411223  100.105  -67.092  48.624  1
411224  100.144  -67.091  48.582  1
411225  100.184  -67.088  48.541  1
411226  100.226  -67.086  48.500  1
411227  100.274  -67.084  48.459  1
411228  100.322  -67.082  48.419  1
411229  100.370  -67.080  48.378  1
411687  90.674  -66.176  54.965  1
411688  90.723  -66.185  54.970  1
411689  90.771  -66.195  54.975  1
411690  90.819  -66.205  54.980  1
411691  90.868  -66.214  54.985  1
411692  90.917  -66.224  54.991  1
411693  90.965  -66.234  54.997  1
411694  91.014  -66.243  55.002  1
411695  91.063  -66.253  55.007  1
411696  91.111  -66.262  55.014  1
411697  91.159  -66.268  55.023  1
411698  91.208  -66.274  55.034  1
411699  91.255  -66.283  55.045  1
411700  91.301  -66.295  55.054  1
411701  91.345  -66.301  55.062  1
411702  91.385  -66.302  55.066  1
411703  91.426  -66.303  55.070  1
411704  91.467  -66.303  55.073  1
411705  91.508  -66.305  55.074  1
411706  91.554  -66.320  55.072  1
411707  91.599  -66.335  55.067  1
411708  91.645  -66.349  55.063  1
411709  91.689  -66.354  55.061  1
411710  91.733  -66.355  55.059  1
411711  91.781  -66.360  55.057  1
411712  91.836  -66.372  55.055  1
411713  91.891  -66.385  55.053  1
411714  91.946  -66.398  55.050  1
411715  92.002  -66.411  55.047  1
411716  92.057  -66.423  55.042  1
411717  92.109  -66.426  55.035  1
411718  92.160  -66.426  55.028  1
411719  92.210  -66.426  55.020  1
411720  92.261  -66.425  55.011  1
411721  92.312  -66.425  55.002  1
411722  92.363  -66.424  54.994  1
411723  92.412  -66.430  54.986  1
411724  92.460  -66.440  54.978  1
411725  92.509  -66.450  54.972  1
411726  92.557  -66.460  54.972  1
411727  92.605  -66.469  54.972  1
411728  92.650  -66.465  54.970  1
411729  92.694  -66.457  54.964  1
411730  92.738  -66.448  54.950  1
411731  92.782  -66.439  54.929  1
411732  92.826  -66.430  54.904  1
411733  92.869  -66.422  54.878  1
411734  92.913  -66.413  54.852  1
411735  92.957  -66.404  54.830  1
411736  93.001  -66.395  54.812  1
411737  93.044  -66.387  54.795  1
411738  93.088  -66.378  54.777  1
411739  93.126  -66.364  54.754  1
411740  93.164  -66.350  54.720  1
411741  93.202  -66.335  54.683  1
411742  93.240  -66.321  54.644  1
411743  93.278  -66.307  54.606  1
411744  93.315  -66.295  54.571  1
411745  93.350  -66.290  54.540  1
411746  93.383  -66.285  54.512  1
411747  93.418  -66.280  54.486  1
411748  93.452  -66.275  54.463  1
411749  93.486  -66.270  54.441  1
411750  93.521  -66.267  54.425  1
411751  93.561  -66.273  54.411  1
411752  93.605  -66.278  54.398  1
411753  93.649  -66.285  54.385  1
411754  93.694  -66.293  54.373  1
411755  93.738  -66.301  54.358  1
411756  93.782  -66.307  54.343  1
411757  93.827  -66.315  54.328  1
411758  93.871  -66.323  54.311  1
411759  93.916  -66.330  54.291  1
411760  93.960  -66.338  54.269  1
411761  94.001  -66.342  54.246  1
411762  94.042  -66.347  54.222  1
411763  94.083  -66.351  54.200  1
411764  94.124  -66.356  54.179  1
411765  94.166  -66.361  54.160  1
411766  94.206  -66.365  54.139  1
411767  94.246  -66.370  54.116  1
411768  94.285  -66.376  54.088  1
411769  94.312  -66.376  54.057  1
411770  94.339  -66.376  54.026  1
411771  94.367  -66.376  53.995  1
411772  94.394  -66.376  53.964  1
411773  94.421  -66.376  53.936  1
411774  94.461  -66.377  53.909  1
411775  94.512  -66.381  53.883  1
411776  94.564  -66.384  53.858  1
411777  94.615  -66.388  53.832  1
411778  94.661  -66.391  53.806  1
411779  94.701  -66.392  53.782  1
411780  94.741  -66.396  53.761  1
411781  94.783  -66.411  53.744  1
411782  94.825  -66.426  53.726  1
411783  94.865  -66.439  53.707  1
411784  94.902  -66.448  53.688  1
411785  94.937  -66.455  53.668  1
411786  94.968  -66.462  53.646  1
411787  94.999  -66.469  53.622  1
411788  95.030  -66.476  53.597  1
411789  95.060  -66.482  53.570  1
411790  95.091  -66.489  53.542  1
411791  95.119  -66.492  53.512  1
411792  95.146  -66.492  53.484  1
411793  95.173  -66.493  53.456  1
411794  95.199  -66.494  53.430  1
411795  95.226  -66.495  53.408  1
411796  95.261  -66.499  53.390  1
411797  95.296  -66.503  53.375  1
411798  95.339  -66.503  53.363  1
411799  95.391  -66.498  53.353  1
411800  95.447  -66.497  53.343  1
411801  95.504  -66.496  53.335  1
411802  95.557  -66.497  53.326  1
411803  95.589  -66.510  53.317  1
411804  95.620  -66.523  53.306  1
411805  95.659  -66.532  53.291  1
411806  95.703  -66.538  53.273  1
411807  95.748  -66.544  53.255  1
411808  95.795  -66.548  53.237  1
411809  95.839  -66.551  53.220  1
411810  95.881  -66.551  53.200  1
411811  95.922  -66.551  53.180  1
411812  95.963  -66.551  53.160  1
411813  96.005  -66.551  53.140  1
411814  96.046  -66.551  53.121  1
411815  96.088  -66.551  53.100  1
411816  96.129  -66.552  53.076  1
411817  96.170  -66.552  53.049  1
411818  96.212  -66.550  53.020  1
411819  96.254  -66.548  52.986  1
411820  96.297  -66.545  52.951  1
411821  96.335  -66.545  52.916  1
411822  96.372  -66.548  52.881  1
411823  96.409  -66.549  52.846  1
411824  96.446  -66.552  52.815  1
411825  96.480  -66.552  52.787  1
411826  96.509  -66.546  52.760  1
411827  96.538  -66.540  52.734  1
411828  96.568  -66.535  52.710  1
411829  96.597  -66.530  52.685  1
411830  96.630  -66.527  52.661  1
411831  96.664  -66.524  52.634  1
411832  96.703  -66.520  52.602  1
411833  96.747  -66.514  52.568  1
411834  96.790  -66.508  52.533  1
411835  96.832  -66.505  52.498  1
411836  96.873  -66.502  52.467  1
411837  96.915  -66.499  52.439  1
411838  96.957  -66.496  52.415  1
411839  97.002  -66.492  52.392  1
411840  97.047  -66.489  52.370  1
411841  97.090  -66.496  52.351  1
411842  97.132  -66.507  52.332  1
411843  97.173  -66.517  52.314  1
411844  97.215  -66.528  52.293  1
411845  97.256  -66.538  52.268  1
411846  97.298  -66.549  52.239  1
411847  97.338  -66.555  52.206  1
411848  97.379  -66.560  52.170  1
411849  97.419  -66.564  52.133  1
411850  97.459  -66.568  52.095  1
411851  97.500  -66.573  52.054  1
411852  97.544  -66.580  52.013  1
411853  97.582  -66.592  51.970  1
411854  97.620  -66.605  51.927  1
411855  97.659  -66.617  51.885  1
411856  97.698  -66.630  51.844  1
411857  97.737  -66.643  51.802  1
411858  97.776  -66.656  51.760  1
411859  97.815  -66.669  51.718  1
411860  97.854  -66.682  51.675  1
411861  97.892  -66.694  51.632  1
411862  97.931  -66.702  51.591  1
411863  97.965  -66.708  51.548  1
411864  97.998  -66.712  51.504  1
411865  98.023  -66.720  51.460  1
411866  98.045  -66.728  51.417  1
411867  98.068  -66.737  51.376  1
411868  98.091  -66.745  51.338  1
411869  98.113  -66.754  51.301  1
411870  98.136  -66.762  51.261  1
411871  98.160  -66.770  51.220  1
411872  98.185  -66.777  51.178  1
411873  98.211  -66.784  51.135  1
411874  98.237  -66.791  51.090  1
411875  98.261  -66.795  51.044  1
411876  98.289  -66.791  50.996  1
411877  98.324  -66.787  50.951  1
411878  98.358  -66.784  50.910  1
411879  98.393  -66.780  50.870  1
411880  98.431  -66.782  50.830  1
411881  98.471  -66.785  50.790  1
411882  98.509  -66.788  50.748  1
411883  98.542  -66.796  50.704  1
411884  98.575  -66.805  50.658  1
411885  98.608  -66.814  50.609  1
411886  98.641  -66.822  50.559  1
411887  98.674  -66.831  50.507  1
411888  98.715  -66.838  50.455  1
411889  98.758  -66.846  50.402  1
411890  98.802  -66.849  50.348  1
411891  98.848  -66.852  50.293  1
411892  98.895  -66.853  50.237  1
411893  98.941  -66.856  50.182  1
411894  98.987  -66.858  50.128  1
411895  99.033  -66.860  50.073  1
411896  99.079  -66.862  50.019  1
411897  99.125  -66.864  49.966  1
411898  99.170  -66.866  49.912  1
411899  99.215  -66.872  49.858  1
411900  99.259  -66.885  49.804  1
411901  99.301  -66.899  49.750  1
411902  99.345  -66.912  49.696  1
411903  99.388  -66.925  49.641  1
411904  99.429  -66.937  49.588  1
411905  99.449  -66.933  49.536  1
411906  99.471  -66.929  49.483  1
411907  99.491  -66.925  49.430  1
411908  99.512  -66.921  49.378  1
411909  99.533  -66.917  49.326  1
411910  99.573  -66.931  49.275  1
411911  99.616  -66.948  49.223  1
411912  99.666  -66.964  49.172  1
411913  99.718  -66.979  49.122  1
411914  99.778  -67.001  49.073  1
411915  99.838  -67.022  49.025  1
411916  99.860  -67.030  48.978  1
411917  99.881  -67.038  48.932  1
411918  99.901  -67.046  48.885  1
411919  99.921  -67.053  48.838  1
411920  99.956  -67.054  48.792  1
411921  99.995  -67.053  48.749  1
411922  100.034  -67.050  48.705  1
411923  100.074  -67.048  48.662  1
411924  100.114  -67.047  48.619  1
411925  100.153  -67.044  48.576  1
411926  100.193  -67.042  48.535  1
411927  100.240  -67.040  48.494  1
411928  100.288  -67.038  48.453  1
411929  100.337  -67.036  48.413  1
411930  100.385  -67.034  48.372  1
412388  90.673  -66.132  54.966  1
412389  90.722  -66.142  54.970  1
412390  90.770  -66.152  54.976  1
412391  90.818  -66.161  54.980  1
412392  90.867  -66.171  54.984  1
412393  90.916  -66.181  54.989  1
412394  90.964  -66.190  54.993  1
412395  91.013  -66.200  54.999  1
412396  91.062  -66.207  55.003  1
412397  91.110  -66.213  55.009  1
412398  91.158  -66.219  55.017  1
412399  91.207  -66.226  55.027  1
412400  91.253  -66.236  55.037  1
412401  91.299  -66.248  55.047  1
412402  91.345  -66.259  55.056  1
412403  91.386  -66.262  55.062  1
412404  91.427  -66.263  55.068  1
412405  91.468  -66.263  55.072  1
412406  91.510  -66.266  55.073  1
412407  91.555  -66.281  55.071  1
412408  91.601  -66.296  55.066  1
412409  91.646  -66.310  55.064  1
412410  91.692  -66.326  55.064  1
412411  91.736  -66.331  55.063  1
412412  91.782  -66.334  55.060  1
412413  91.838  -66.347  55.060  1
412414  91.893  -66.360  55.060  1
412415  91.948  -66.373  55.059  1
412416  92.000  -66.374  55.057  1
412417  92.051  -66.374  55.055  1
412418  92.101  -66.374  55.049  1
412419  92.152  -66.373  55.042  1
412420  92.203  -66.373  55.034  1
412421  92.253  -66.373  55.026  1
412422  92.304  -66.373  55.017  1
412423  92.353  -66.379  55.009  1
412424  92.402  -66.389  54.999  1
412425  92.450  -66.398  54.991  1
412426  92.499  -66.408  54.986  1
412427  92.547  -66.418  54.986  1
412428  92.595  -66.427  54.985  1
412429  92.639  -66.419  54.982  1
412430  92.683  -66.410  54.974  1
412431  92.726  -66.401  54.956  1
412432  92.770  -66.392  54.933  1
412433  92.814  -66.384  54.908  1
412434  92.858  -66.375  54.882  1
412435  92.902  -66.367  54.857  1
412436  92.945  -66.357  54.836  1
412437  92.989  -66.349  54.820  1
412438  93.033  -66.340  54.805  1
412439  93.077  -66.332  54.787  1
412440  93.121  -66.323  54.763  1
412441  93.161  -66.311  54.731  1
412442  93.199  -66.297  54.695  1
412443  93.237  -66.282  54.657  1
412444  93.275  -66.269  54.620  1
412445  93.313  -66.255  54.586  1
412446  93.347  -66.250  54.556  1
412447  93.381  -66.245  54.529  1
412448  93.415  -66.240  54.505  1
412449  93.449  -66.235  54.483  1
412450  93.484  -66.229  54.462  1
412451  93.518  -66.224  54.446  1
412452  93.560  -66.229  54.433  1
412453  93.605  -66.235  54.420  1
412454  93.649  -66.243  54.407  1
412455  93.693  -66.251  54.394  1
412456  93.737  -66.258  54.379  1
412457  93.782  -66.266  54.363  1
412458  93.827  -66.273  54.347  1
412459  93.871  -66.281  54.330  1
412460  93.916  -66.288  54.309  1
412461  93.960  -66.296  54.286  1
412462  94.002  -66.301  54.262  1
412463  94.043  -66.306  54.238  1
412464  94.084  -66.310  54.214  1
412465  94.125  -66.315  54.192  1
412466  94.166  -66.320  54.171  1
412467  94.205  -66.326  54.149  1
412468  94.246  -66.331  54.125  1
412469  94.285  -66.336  54.096  1
412470  94.325  -66.342  54.066  1
412471  94.352  -66.342  54.035  1
412472  94.380  -66.342  54.005  1
412473  94.407  -66.342  53.977  1
412474  94.434  -66.342  53.951  1
412475  94.473  -66.342  53.924  1
412476  94.514  -66.341  53.898  1
412477  94.555  -66.341  53.872  1
412478  94.605  -66.344  53.845  1
412479  94.657  -66.348  53.821  1
412480  94.698  -66.350  53.800  1
412481  94.739  -66.361  53.784  1
412482  94.781  -66.376  53.769  1
412483  94.823  -66.391  53.753  1
412484  94.861  -66.402  53.734  1
412485  94.892  -66.409  53.715  1
412486  94.923  -66.416  53.694  1
412487  94.954  -66.422  53.669  1
412488  94.984  -66.429  53.644  1
412489  95.015  -66.436  53.617  1
412490  95.046  -66.442  53.588  1
412491  95.076  -66.448  53.559  1
412492  95.103  -66.449  53.528  1
412493  95.130  -66.450  53.498  1
412494  95.157  -66.451  53.470  1
412495  95.192  -66.455  53.444  1
412496  95.228  -66.460  53.421  1
412497  95.263  -66.464  53.404  1
412498  95.299  -66.469  53.389  1
412499  95.346  -66.466  53.376  1
412500  95.397  -66.461  53.367  1
412501  95.450  -66.457  53.358  1
412502  95.506  -66.455  53.350  1
412503  95.553  -66.460  53.339  1
412504  95.585  -66.473  53.328  1
412505  95.616  -66.486  53.317  1
412506  95.652  -66.496  53.302  1
412507  95.698  -66.501  53.285  1
412508  95.745  -66.505  53.266  1
412509  95.792  -66.509  53.247  1
412510  95.838  -66.513  53.230  1
412511  95.879  -66.513  53.212  1
412512  95.920  -66.513  53.192  1
412513  95.962  -66.513  53.172  1
412514  96.003  -66.513  53.151  1
412515  96.044  -66.512  53.132  1
412516  96.085  -66.512  53.111  1
412517  96.127  -66.511  53.086  1
412518  96.170  -66.507  53.059  1
412519  96.213  -66.505  53.030  1
412520  96.255  -66.502  52.996  1
412521  96.298  -66.500  52.961  1
412522  96.339  -66.498  52.926  1
412523  96.376  -66.501  52.891  1
412524  96.412  -66.502  52.859  1
412525  96.449  -66.505  52.829  1
412526  96.480  -66.501  52.801  1
412527  96.509  -66.495  52.775  1
412528  96.538  -66.489  52.751  1
412529  96.570  -66.486  52.726  1
412530  96.603  -66.483  52.702  1
412531  96.637  -66.480  52.677  1
412532  96.670  -66.478  52.650  1
412533  96.707  -66.474  52.620  1
412534  96.750  -66.468  52.584  1
412535  96.794  -66.463  52.547  1
412536  96.837  -66.457  52.510  1
412537  96.880  -66.451  52.475  1
412538  96.923  -66.447  52.445  1
412539  96.964  -66.444  52.419  1
412540  97.009  -66.441  52.396  1
412541  97.051  -66.451  52.374  1
412542  97.092  -66.462  52.354  1
412543  97.134  -66.473  52.335  1
412544  97.176  -66.483  52.315  1
412545  97.217  -66.494  52.293  1
412546  97.259  -66.504  52.268  1
412547  97.300  -66.514  52.239  1
412548  97.341  -66.519  52.206  1
412549  97.381  -66.523  52.169  1
412550  97.421  -66.528  52.131  1
412551  97.461  -66.533  52.092  1
412552  97.502  -66.537  52.051  1
412553  97.541  -66.543  52.009  1
412554  97.580  -66.557  51.966  1
412555  97.619  -66.570  51.923  1
412556  97.658  -66.583  51.880  1
412557  97.697  -66.596  51.840  1
412558  97.736  -66.609  51.798  1
412559  97.775  -66.622  51.757  1
412560  97.814  -66.635  51.716  1
412561  97.853  -66.647  51.674  1
412562  97.891  -66.655  51.635  1
412563  97.929  -66.664  51.595  1
412564  97.962  -66.668  51.553  1
412565  97.996  -66.672  51.509  1
412566  98.025  -66.677  51.465  1
412567  98.048  -66.686  51.422  1
412568  98.071  -66.694  51.380  1
412569  98.093  -66.702  51.342  1
412570  98.116  -66.711  51.305  1
412571  98.139  -66.720  51.265  1
412572  98.161  -66.728  51.224  1
412573  98.184  -66.737  51.182  1
412574  98.207  -66.745  51.140  1
412575  98.229  -66.753  51.095  1
412576  98.260  -66.754  51.048  1
412577  98.294  -66.750  50.998  1
412578  98.329  -66.746  50.951  1
412579  98.363  -66.742  50.908  1
412580  98.398  -66.738  50.867  1
412581  98.436  -66.740  50.828  1
412582  98.476  -66.743  50.788  1
412583  98.514  -66.746  50.747  1
412584  98.552  -66.750  50.703  1
412585  98.585  -66.759  50.658  1
412586  98.618  -66.768  50.609  1
412587  98.651  -66.776  50.559  1
412588  98.685  -66.785  50.507  1
412589  98.727  -66.792  50.455  1
412590  98.769  -66.799  50.401  1
412591  98.811  -66.806  50.347  1
412592  98.853  -66.814  50.292  1
412593  98.900  -66.815  50.237  1
412594  98.946  -66.818  50.182  1
412595  98.992  -66.820  50.128  1
412596  99.038  -66.822  50.073  1
412597  99.083  -66.824  50.019  1
412598  99.129  -66.826  49.965  1
412599  99.174  -66.828  49.911  1
412600  99.219  -66.837  49.857  1
412601  99.262  -66.850  49.802  1
412602  99.305  -66.864  49.747  1
412603  99.348  -66.878  49.693  1
412604  99.392  -66.890  49.640  1
412605  99.435  -66.904  49.586  1
412606  99.472  -66.912  49.533  1
412607  99.493  -66.909  49.480  1
412608  99.513  -66.905  49.426  1
412609  99.535  -66.901  49.374  1
412610  99.555  -66.896  49.322  1
412611  99.576  -66.893  49.270  1
412612  99.597  -66.888  49.218  1
412613  99.661  -66.914  49.166  1
412614  99.725  -66.939  49.115  1
412615  99.790  -66.964  49.067  1
412616  99.841  -66.978  49.019  1
412617  99.866  -66.986  48.973  1
412618  99.887  -66.994  48.926  1
412619  99.907  -67.002  48.879  1
412620  99.927  -67.009  48.832  1
412621  99.965  -67.009  48.786  1
412622  100.004  -67.006  48.743  1
412623  100.044  -67.004  48.699  1
412624  100.083  -67.003  48.656  1
412625  100.123  -67.000  48.614  1
412626  100.163  -66.998  48.571  1
412627  100.206  -66.996  48.529  1
412628  100.255  -66.994  48.488  1
412629  100.303  -66.992  48.448  1
412630  100.351  -66.990  48.408  1
412631  100.399  -66.987  48.367  1
413089  90.672  -66.089  54.967  1
413090  90.721  -66.099  54.971  1
413091  90.769  -66.108  54.976  1
413092  90.818  -66.118  54.980  1
413093  90.866  -66.128  54.983  1
413094  90.915  -66.137  54.988  1
413095  90.963  -66.145  54.991  1
413096  91.012  -66.151  54.995  1
413097  91.060  -66.157  54.999  1
413098  91.108  -66.164  55.004  1
413099  91.157  -66.170  55.010  1
413100  91.205  -66.177  55.018  1
413101  91.251  -66.189  55.027  1
413102  91.296  -66.201  55.037  1
413103  91.342  -66.212  55.047  1
413104  91.387  -66.222  55.054  1
413105  91.428  -66.223  55.063  1
413106  91.469  -66.223  55.068  1
413107  91.511  -66.227  55.071  1
413108  91.557  -66.242  55.071  1
413109  91.602  -66.257  55.070  1
413110  91.648  -66.272  55.067  1
413111  91.693  -66.287  55.066  1
413112  91.738  -66.301  55.065  1
413113  91.784  -66.309  55.064  1
413114  91.840  -66.321  55.064  1
413115  91.891  -66.323  55.064  1
413116  91.941  -66.323  55.064  1
413117  91.992  -66.322  55.064  1
413118  92.043  -66.322  55.064  1
413119  92.094  -66.322  55.062  1
413120  92.144  -66.321  55.056  1
413121  92.195  -66.321  55.049  1
413122  92.246  -66.320  55.041  1
413123  92.295  -66.327  55.032  1
413124  92.343  -66.337  55.024  1
413125  92.391  -66.347  55.013  1
413126  92.440  -66.357  55.004  1
413127  92.489  -66.367  55.000  1
413128  92.537  -66.376  54.999  1
413129  92.584  -66.380  54.998  1
413130  92.628  -66.372  54.993  1
413131  92.671  -66.363  54.982  1
413132  92.715  -66.354  54.961  1
413133  92.759  -66.345  54.936  1
413134  92.803  -66.337  54.909  1
413135  92.847  -66.329  54.883  1
413136  92.890  -66.320  54.859  1
413137  92.934  -66.311  54.839  1
413138  92.978  -66.302  54.825  1
413139  93.021  -66.294  54.810  1
413140  93.065  -66.285  54.793  1
413141  93.109  -66.276  54.771  1
413142  93.153  -66.267  54.741  1
413143  93.196  -66.258  54.706  1
413144  93.234  -66.244  54.671  1
413145  93.272  -66.229  54.635  1
413146  93.310  -66.216  54.602  1
413147  93.345  -66.210  54.573  1
413148  93.379  -66.204  54.546  1
413149  93.413  -66.199  54.522  1
413150  93.447  -66.194  54.500  1
413151  93.483  -66.191  54.481  1
413152  93.521  -66.191  54.466  1
413153  93.566  -66.191  54.452  1
413154  93.609  -66.197  54.439  1
413155  93.652  -66.204  54.428  1
413156  93.696  -66.210  54.415  1
413157  93.740  -66.217  54.399  1
413158  93.783  -66.225  54.383  1
413159  93.827  -66.232  54.366  1
413160  93.871  -66.239  54.348  1
413161  93.915  -66.246  54.328  1
413162  93.960  -66.254  54.305  1
413163  94.003  -66.260  54.282  1
413164  94.045  -66.265  54.257  1
413165  94.085  -66.270  54.231  1
413166  94.125  -66.276  54.205  1
413167  94.165  -66.281  54.180  1
413168  94.205  -66.286  54.156  1
413169  94.245  -66.292  54.131  1
413170  94.285  -66.297  54.102  1
413171  94.325  -66.302  54.072  1
413172  94.365  -66.307  54.043  1
413173  94.392  -66.307  54.015  1
413174  94.420  -66.307  53.990  1
413175  94.451  -66.307  53.967  1
413176  94.491  -66.307  53.941  1
413177  94.532  -66.307  53.914  1
413178  94.572  -66.307  53.886  1
413179  94.613  -66.307  53.858  1
413180  94.653  -66.307  53.835  1
413181  94.695  -66.310  53.818  1
413182  94.736  -66.325  53.805  1
413183  94.776  -66.340  53.792  1
413184  94.816  -66.355  53.777  1
413185  94.854  -66.369  53.760  1
413186  94.883  -66.373  53.740  1
413187  94.911  -66.378  53.718  1
413188  94.939  -66.382  53.692  1
413189  94.970  -66.389  53.667  1
413190  95.000  -66.395  53.640  1
413191  95.032  -66.402  53.611  1
413192  95.060  -66.407  53.581  1
413193  95.088  -66.407  53.549  1
413194  95.124  -66.412  53.517  1
413195  95.159  -66.417  53.488  1
413196  95.195  -66.421  53.461  1
413197  95.231  -66.425  53.438  1
413198  95.266  -66.429  53.420  1
413199  95.302  -66.434  53.404  1
413200  95.352  -66.429  53.391  1
413201  95.403  -66.423  53.382  1
413202  95.454  -66.418  53.373  1
413203  95.508  -66.415  53.365  1
413204  95.549  -66.423  53.353  1
413205  95.581  -66.437  53.340  1
413206  95.611  -66.454  53.327  1
413207  95.650  -66.463  53.312  1
413208  95.695  -66.461  53.295  1
413209  95.742  -66.466  53.277  1
413210  95.789  -66.470  53.259  1
413211  95.836  -66.475  53.241  1
413212  95.877  -66.475  53.223  1
413213  95.918  -66.475  53.203  1
413214  95.960  -66.474  53.182  1
413215  96.001  -66.474  53.160  1
413216  96.042  -66.474  53.138  1
413217  96.085  -66.472  53.116  1
413218  96.128  -66.467  53.092  1
413219  96.171  -66.463  53.065  1
413220  96.214  -66.460  53.034  1
413221  96.256  -66.458  53.000  1
413222  96.298  -66.455  52.967  1
413223  96.341  -66.453  52.934  1
413224  96.380  -66.453  52.902  1
413225  96.416  -66.455  52.873  1
413226  96.451  -66.455  52.843  1
413227  96.480  -66.450  52.816  1
413228  96.509  -66.444  52.791  1
413229  96.542  -66.442  52.767  1
413230  96.576  -66.439  52.741  1
413231  96.609  -66.436  52.718  1
413232  96.643  -66.434  52.693  1
413233  96.677  -66.431  52.667  1
413234  96.710  -66.429  52.636  1
413235  96.754  -66.423  52.600  1
413236  96.797  -66.417  52.561  1
413237  96.840  -66.411  52.521  1
413238  96.884  -66.405  52.483  1
413239  96.927  -66.400  52.451  1
413240  96.971  -66.397  52.422  1
413241  97.012  -66.407  52.398  1
413242  97.053  -66.417  52.376  1
413243  97.095  -66.428  52.356  1
413244  97.137  -66.439  52.336  1
413245  97.178  -66.449  52.317  1
413246  97.220  -66.460  52.293  1
413247  97.261  -66.470  52.265  1
413248  97.302  -66.479  52.236  1
413249  97.343  -66.483  52.203  1
413250  97.383  -66.488  52.167  1
413251  97.423  -66.492  52.128  1
413252  97.463  -66.497  52.088  1
413253  97.502  -66.502  52.047  1
413254  97.540  -66.510  52.005  1
413255  97.580  -66.523  51.962  1
413256  97.618  -66.536  51.919  1
413257  97.658  -66.549  51.878  1
413258  97.697  -66.562  51.838  1
413259  97.736  -66.575  51.797  1
413260  97.775  -66.589  51.757  1
413261  97.813  -66.601  51.717  1
413262  97.852  -66.608  51.677  1
413263  97.890  -66.617  51.640  1
413264  97.926  -66.624  51.602  1
413265  97.959  -66.627  51.560  1
413266  97.993  -66.632  51.517  1
413267  98.025  -66.636  51.472  1
413268  98.051  -66.643  51.427  1
413269  98.074  -66.652  51.385  1
413270  98.096  -66.660  51.345  1
413271  98.119  -66.669  51.308  1
413272  98.142  -66.677  51.268  1
413273  98.164  -66.686  51.227  1
413274  98.187  -66.694  51.185  1
413275  98.210  -66.702  51.143  1
413276  98.232  -66.711  51.098  1
413277  98.265  -66.712  51.051  1
413278  98.299  -66.708  51.001  1
413279  98.334  -66.705  50.952  1
413280  98.368  -66.701  50.908  1
413281  98.403  -66.697  50.866  1
413282  98.441  -66.699  50.827  1
413283  98.481  -66.702  50.787  1
413284  98.519  -66.705  50.746  1
413285  98.559  -66.708  50.702  1
413286  98.595  -66.713  50.657  1
413287  98.628  -66.721  50.608  1
413288  98.661  -66.730  50.558  1
413289  98.696  -66.739  50.506  1
413290  98.738  -66.746  50.454  1
413291  98.781  -66.753  50.400  1
413292  98.822  -66.760  50.345  1
413293  98.865  -66.768  50.291  1
413294  98.908  -66.774  50.237  1
413295  98.950  -66.780  50.182  1
413296  98.996  -66.782  50.128  1
413297  99.042  -66.784  50.073  1
413298  99.087  -66.787  50.018  1
413299  99.133  -66.788  49.963  1
413300  99.179  -66.790  49.909  1
413301  99.222  -66.802  49.855  1
413302  99.266  -66.816  49.800  1
413303  99.309  -66.829  49.745  1
413304  99.352  -66.843  49.691  1
413305  99.395  -66.856  49.639  1
413306  99.438  -66.869  49.586  1
413307  99.482  -66.883  49.532  1
413308  99.515  -66.888  49.477  1
413309  99.536  -66.884  49.423  1
413310  99.557  -66.881  49.371  1
413311  99.577  -66.877  49.318  1
413312  99.588  -66.856  49.265  1
413313  99.609  -66.851  49.212  1
413314  99.673  -66.877  49.160  1
413315  99.737  -66.902  49.110  1
413316  99.799  -66.925  49.061  1
413317  99.845  -66.934  49.014  1
413318  99.871  -66.942  48.967  1
413319  99.892  -66.950  48.921  1
413320  99.912  -66.958  48.873  1
413321  99.934  -66.965  48.826  1
413322  99.974  -66.962  48.781  1
413323  100.013  -66.960  48.737  1
413324  100.053  -66.959  48.693  1
413325  100.093  -66.956  48.650  1
413326  100.132  -66.954  48.607  1
413327  100.173  -66.953  48.566  1
413328  100.221  -66.950  48.525  1
413329  100.269  -66.948  48.484  1
413330  100.317  -66.946  48.443  1
413331  100.365  -66.943  48.403  1
413790  90.671  -66.046  54.968  1
413791  90.720  -66.055  54.972  1
413792  90.768  -66.065  54.976  1
413793  90.817  -66.075  54.980  1
413794  90.865  -66.084  54.983  1
413795  90.913  -66.090  54.987  1
413796  90.962  -66.097  54.990  1
413797  91.011  -66.103  54.993  1
413798  91.059  -66.109  54.996  1
413799  91.107  -66.115  55.000  1
413800  91.156  -66.121  55.004  1
413801  91.203  -66.130  55.009  1
413802  91.248  -66.141  55.017  1
413803  91.294  -66.154  55.026  1
413804  91.340  -66.165  55.035  1
413805  91.386  -66.176  55.044  1
413806  91.429  -66.182  55.055  1
413807  91.470  -66.183  55.063  1
413808  91.513  -66.188  55.067  1
413809  91.558  -66.204  55.069  1
413810  91.603  -66.219  55.070  1
413811  91.649  -66.233  55.067  1
413812  91.695  -66.248  55.065  1
413813  91.740  -66.263  55.065  1
413814  91.784  -66.270  55.065  1
413815  91.832  -66.271  55.065  1
413816  91.883  -66.270  55.065  1
413817  91.934  -66.270  55.066  1
413818  91.985  -66.270  55.067  1
413819  92.035  -66.270  55.069  1
413820  92.086  -66.270  55.068  1
413821  92.137  -66.269  55.066  1
413822  92.188  -66.269  55.062  1
413823  92.236  -66.276  55.057  1
413824  92.285  -66.286  55.050  1
413825  92.333  -66.295  55.040  1
413826  92.381  -66.305  55.029  1
413827  92.430  -66.315  55.019  1
413828  92.479  -66.325  55.014  1
413829  92.527  -66.335  55.012  1
413830  92.572  -66.334  55.010  1
413831  92.616  -66.325  55.003  1
413832  92.660  -66.317  54.988  1
413833  92.704  -66.307  54.965  1
413834  92.747  -66.299  54.937  1
413835  92.791  -66.290  54.909  1
413836  92.835  -66.282  54.883  1
413837  92.879  -66.273  54.859  1
413838  92.923  -66.264  54.840  1
413839  92.967  -66.255  54.826  1
413840  93.010  -66.247  54.813  1
413841  93.054  -66.238  54.798  1
413842  93.097  -66.229  54.779  1
413843  93.141  -66.220  54.749  1
413844  93.185  -66.212  54.717  1
413845  93.229  -66.203  54.684  1
413846  93.269  -66.191  54.651  1
413847  93.307  -66.177  54.618  1
413848  93.342  -66.169  54.590  1
413849  93.376  -66.164  54.564  1
413850  93.411  -66.159  54.540  1
413851  93.448  -66.158  54.519  1
413852  93.486  -66.157  54.501  1
413853  93.526  -66.157  54.486  1
413854  93.570  -66.157  54.472  1
413855  93.615  -66.159  54.459  1
413856  93.658  -66.166  54.448  1
413857  93.702  -66.172  54.435  1
413858  93.745  -66.179  54.420  1
413859  93.788  -66.186  54.404  1
413860  93.832  -66.193  54.387  1
413861  93.875  -66.200  54.368  1
413862  93.919  -66.207  54.347  1
413863  93.962  -66.213  54.324  1
413864  94.005  -66.220  54.299  1
413865  94.045  -66.226  54.273  1
413866  94.084  -66.231  54.246  1
413867  94.124  -66.236  54.217  1
413868  94.165  -66.241  54.189  1
413869  94.205  -66.247  54.163  1
413870  94.245  -66.252  54.136  1
413871  94.285  -66.257  54.108  1
413872  94.325  -66.263  54.080  1
413873  94.365  -66.268  54.053  1
413874  94.405  -66.273  54.028  1
413875  94.432  -66.273  54.006  1
413876  94.468  -66.273  53.983  1
413877  94.508  -66.273  53.956  1
413878  94.549  -66.273  53.926  1
413879  94.586  -66.274  53.896  1
413880  94.621  -66.276  53.870  1
413881  94.655  -66.279  53.850  1
413882  94.689  -66.282  53.835  1
413883  94.726  -66.289  53.823  1
413884  94.766  -66.304  53.813  1
413885  94.807  -66.320  53.799  1
413886  94.846  -66.335  53.783  1
413887  94.878  -66.342  53.763  1
413888  94.906  -66.346  53.741  1
413889  94.934  -66.351  53.715  1
413890  94.963  -66.356  53.691  1
413891  94.991  -66.361  53.666  1
413892  95.020  -66.365  53.637  1
413893  95.055  -66.369  53.607  1
413894  95.091  -66.373  53.573  1
413895  95.126  -66.377  53.540  1
413896  95.162  -66.382  53.509  1
413897  95.197  -66.386  53.480  1
413898  95.233  -66.390  53.457  1
413899  95.269  -66.395  53.438  1
413900  95.308  -66.397  53.421  1
413901  95.359  -66.392  53.407  1
413902  95.410  -66.386  53.397  1
413903  95.461  -66.381  53.389  1
413904  95.512  -66.376  53.379  1
413905  95.544  -66.391  53.366  1
413906  95.574  -66.408  53.352  1
413907  95.605  -66.426  53.337  1
413908  95.648  -66.429  53.322  1
413909  95.693  -66.428  53.306  1
413910  95.739  -66.427  53.288  1
413911  95.786  -66.432  53.270  1
413912  95.833  -66.436  53.251  1
413913  95.876  -66.436  53.233  1
413914  95.917  -66.436  53.212  1
413915  95.958  -66.436  53.190  1
413916  95.999  -66.436  53.166  1
413917  96.042  -66.433  53.144  1
413918  96.085  -66.429  53.121  1
413919  96.128  -66.424  53.096  1
413920  96.172  -66.420  53.069  1
413921  96.215  -66.416  53.039  1
413922  96.257  -66.413  53.007  1
413923  96.299  -66.411  52.976  1
413924  96.341  -66.407  52.947  1
413925  96.383  -66.406  52.919  1
413926  96.420  -66.408  52.890  1
413927  96.451  -66.404  52.860  1
413928  96.482  -66.400  52.831  1
413929  96.515  -66.398  52.804  1
413930  96.549  -66.395  52.781  1
413931  96.582  -66.392  52.756  1
413932  96.616  -66.390  52.731  1
413933  96.649  -66.387  52.707  1
413934  96.683  -66.385  52.681  1
413935  96.717  -66.382  52.651  1
413936  96.757  -66.377  52.615  1
413937  96.801  -66.371  52.575  1
413938  96.844  -66.366  52.533  1
413939  96.887  -66.360  52.493  1
413940  96.931  -66.361  52.457  1
413941  96.975  -66.364  52.426  1
413942  97.016  -66.373  52.399  1
413943  97.056  -66.384  52.375  1
413944  97.097  -66.394  52.354  1
413945  97.139  -66.404  52.334  1
413946  97.180  -66.415  52.315  1
413947  97.222  -66.426  52.291  1
413948  97.263  -66.436  52.264  1
413949  97.304  -66.443  52.234  1
413950  97.345  -66.448  52.199  1
413951  97.385  -66.452  52.163  1
413952  97.424  -66.457  52.125  1
413953  97.463  -66.462  52.085  1
413954  97.501  -66.467  52.043  1
413955  97.540  -66.476  52.001  1
413956  97.579  -66.489  51.960  1
413957  97.618  -66.502  51.919  1
413958  97.657  -66.515  51.879  1
413959  97.696  -66.528  51.841  1
413960  97.735  -66.542  51.803  1
413961  97.774  -66.554  51.764  1
413962  97.812  -66.561  51.725  1
413963  97.851  -66.570  51.686  1
413964  97.889  -66.578  51.647  1
413965  97.924  -66.583  51.607  1
413966  97.956  -66.588  51.565  1
413967  97.990  -66.592  51.520  1
413968  98.023  -66.596  51.475  1
413969  98.054  -66.601  51.432  1
413970  98.077  -66.609  51.390  1
413971  98.099  -66.617  51.349  1
413972  98.122  -66.627  51.310  1
413973  98.145  -66.635  51.271  1
413974  98.167  -66.643  51.230  1
413975  98.190  -66.652  51.187  1
413976  98.213  -66.660  51.142  1
413977  98.235  -66.668  51.096  1
413978  98.270  -66.669  51.047  1
413979  98.304  -66.667  50.997  1
413980  98.339  -66.663  50.949  1
413981  98.373  -66.659  50.905  1
413982  98.408  -66.655  50.864  1
413983  98.447  -66.658  50.824  1
413984  98.486  -66.661  50.785  1
413985  98.524  -66.664  50.744  1
413986  98.564  -66.667  50.700  1
413987  98.602  -66.670  50.655  1
413988  98.639  -66.676  50.606  1
413989  98.671  -66.684  50.556  1
413990  98.708  -66.693  50.505  1
413991  98.750  -66.699  50.452  1
413992  98.792  -66.707  50.399  1
413993  98.834  -66.714  50.345  1
413994  98.884  -66.722  50.291  1
413995  98.932  -66.730  50.237  1
413996  98.958  -66.740  50.183  1
413997  99.000  -66.744  50.127  1
413998  99.046  -66.746  50.071  1
413999  99.092  -66.749  50.016  1
414000  99.138  -66.751  49.961  1
414001  99.183  -66.755  49.905  1
414002  99.226  -66.768  49.850  1
414003  99.269  -66.781  49.795  1
414004  99.312  -66.794  49.742  1
414005  99.356  -66.808  49.690  1
414006  99.399  -66.821  49.637  1
414007  99.442  -66.834  49.584  1
414008  99.485  -66.848  49.531  1
414009  99.528  -66.861  49.477  1
414010  99.558  -66.864  49.421  1
414011  99.573  -66.849  49.367  1
414012  99.582  -66.825  49.313  1
414013  99.591  -66.802  49.260  1
414014  99.620  -66.814  49.207  1
414015  99.685  -66.840  49.155  1
414016  99.749  -66.865  49.105  1
414017  99.803  -66.881  49.056  1
414018  99.849  -66.890  49.008  1
414019  99.877  -66.898  48.960  1
414020  99.898  -66.906  48.914  1
414021  99.918  -66.913  48.867  1
414022  99.943  -66.918  48.821  1
414023  99.983  -66.916  48.775  1
414024  100.022  -66.915  48.731  1
414025  100.062  -66.912  48.688  1
414026  100.102  -66.910  48.646  1
414027  100.141  -66.909  48.603  1
414028  100.187  -66.906  48.561  1
414029  100.235  -66.904  48.519  1
414030  100.283  -66.902  48.478  1
414031  100.332  -66.900  48.438  1
414032  100.380  -66.898  48.398  1
414491  90.670  -66.002  54.969  1
414492  90.719  -66.012  54.973  1
414493  90.767  -66.022  54.976  1
414494  90.816  -66.029  54.979  1
414495  90.864  -66.035  54.983  1
414496  90.912  -66.041  54.985  1
414497  90.961  -66.047  54.988  1
414498  91.009  -66.053  54.990  1
414499  91.058  -66.060  54.992  1
414500  91.106  -66.066  54.995  1
414501  91.155  -66.072  54.998  1
414502  91.201  -66.083  55.003  1
414503  91.246  -66.094  55.007  1
414504  91.292  -66.106  55.014  1
414505  91.338  -66.118  55.022  1
414506  91.384  -66.129  55.032  1
414507  91.430  -66.141  55.045  1
414508  91.471  -66.143  55.054  1
414509  91.514  -66.150  55.060  1
414510  91.560  -66.165  55.065  1
414511  91.605  -66.179  55.066  1
414512  91.650  -66.194  55.064  1
414513  91.694  -66.201  55.062  1
414514  91.737  -66.207  55.062  1
414515  91.781  -66.213  55.063  1
414516  91.825  -66.219  55.063  1
414517  91.875  -66.218  55.064  1
414518  91.926  -66.218  55.065  1
414519  91.977  -66.217  55.067  1
414520  92.028  -66.217  55.071  1
414521  92.078  -66.216  55.071  1
414522  92.129  -66.216  55.071  1
414523  92.178  -66.225  55.070  1
414524  92.226  -66.235  55.068  1
414525  92.275  -66.245  55.062  1
414526  92.323  -66.254  55.053  1
414527  92.371  -66.263  55.043  1
414528  92.420  -66.273  55.033  1
414529  92.468  -66.283  55.027  1
414530  92.517  -66.293  55.025  1
414531  92.561  -66.287  55.021  1
414532  92.605  -66.279  55.011  1
414533  92.649  -66.270  54.993  1
414534  92.693  -66.261  54.966  1
414535  92.736  -66.252  54.936  1
414536  92.780  -66.244  54.908  1
414537  92.824  -66.235  54.882  1
414538  92.867  -66.226  54.858  1
414539  92.911  -66.217  54.840  1
414540  92.955  -66.209  54.826  1
414541  92.999  -66.200  54.813  1
414542  93.043  -66.191  54.800  1
414543  93.086  -66.182  54.783  1
414544  93.130  -66.174  54.757  1
414545  93.174  -66.165  54.727  1
414546  93.218  -66.157  54.696  1
414547  93.262  -66.147  54.664  1
414548  93.304  -66.138  54.635  1
414549  93.340  -66.129  54.609  1
414550  93.376  -66.126  54.583  1
414551  93.414  -66.125  54.560  1
414552  93.451  -66.124  54.540  1
414553  93.489  -66.123  54.522  1
414554  93.531  -66.123  54.506  1
414555  93.575  -66.123  54.493  1
414556  93.620  -66.123  54.480  1
414557  93.664  -66.127  54.467  1
414558  93.707  -66.134  54.455  1
414559  93.751  -66.141  54.441  1
414560  93.794  -66.147  54.425  1
414561  93.838  -66.154  54.407  1
414562  93.881  -66.162  54.388  1
414563  93.924  -66.169  54.366  1
414564  93.968  -66.176  54.341  1
414565  94.010  -66.182  54.316  1
414566  94.049  -66.187  54.288  1
414567  94.089  -66.192  54.260  1
414568  94.128  -66.197  54.230  1
414569  94.168  -66.202  54.201  1
414570  94.207  -66.207  54.173  1
414571  94.247  -66.213  54.146  1
414572  94.287  -66.218  54.118  1
414573  94.326  -66.223  54.091  1
414574  94.366  -66.229  54.066  1
414575  94.405  -66.234  54.041  1
414576  94.445  -66.239  54.019  1
414577  94.479  -66.241  53.994  1
414578  94.513  -66.244  53.965  1
414579  94.548  -66.247  53.934  1
414580  94.582  -66.249  53.904  1
414581  94.616  -66.251  53.880  1
414582  94.650  -66.254  53.863  1
414583  94.685  -66.257  53.850  1
414584  94.719  -66.259  53.839  1
414585  94.757  -66.269  53.831  1
414586  94.797  -66.284  53.818  1
414587  94.837  -66.299  53.802  1
414588  94.873  -66.310  53.783  1
414589  94.901  -66.315  53.762  1
414590  94.930  -66.320  53.738  1
414591  94.958  -66.324  53.716  1
414592  94.987  -66.329  53.692  1
414593  95.017  -66.333  53.664  1
414594  95.055  -66.335  53.635  1
414595  95.094  -66.339  53.601  1
414596  95.129  -66.342  53.567  1
414597  95.165  -66.347  53.535  1
414598  95.200  -66.351  53.505  1
414599  95.236  -66.356  53.480  1
414600  95.271  -66.360  53.458  1
414601  95.315  -66.360  53.439  1
414602  95.366  -66.354  53.424  1
414603  95.416  -66.349  53.413  1
414604  95.465  -66.346  53.403  1
414605  95.503  -66.351  53.392  1
414606  95.538  -66.362  53.379  1
414607  95.568  -66.380  53.363  1
414608  95.600  -66.397  53.347  1
414609  95.645  -66.395  53.331  1
414610  95.691  -66.394  53.315  1
414611  95.737  -66.393  53.298  1
414612  95.783  -66.392  53.280  1
414613  95.830  -66.397  53.261  1
414614  95.874  -66.398  53.242  1
414615  95.915  -66.398  53.220  1
414616  95.956  -66.398  53.196  1
414617  95.999  -66.395  53.172  1
414618  96.042  -66.390  53.148  1
414619  96.086  -66.386  53.124  1
414620  96.129  -66.381  53.099  1
414621  96.172  -66.376  53.072  1
414622  96.216  -66.373  53.044  1
414623  96.258  -66.370  53.016  1
414624  96.300  -66.367  52.988  1
414625  96.342  -66.364  52.963  1
414626  96.385  -66.361  52.938  1
414627  96.422  -66.359  52.909  1
414628  96.455  -66.356  52.877  1
414629  96.488  -66.354  52.846  1
414630  96.522  -66.351  52.817  1
414631  96.555  -66.348  52.793  1
414632  96.589  -66.346  52.769  1
414633  96.622  -66.343  52.744  1
414634  96.656  -66.341  52.719  1
414635  96.689  -66.339  52.693  1
414636  96.723  -66.335  52.664  1
414637  96.760  -66.332  52.629  1
414638  96.804  -66.326  52.588  1
414639  96.848  -66.323  52.546  1
414640  96.892  -66.325  52.503  1
414641  96.936  -66.327  52.465  1
414642  96.979  -66.330  52.430  1
414643  97.020  -66.340  52.400  1
414644  97.061  -66.351  52.374  1
414645  97.101  -66.361  52.351  1
414646  97.142  -66.370  52.332  1
414647  97.183  -66.381  52.312  1
414648  97.224  -66.392  52.289  1
414649  97.266  -66.402  52.262  1
414650  97.306  -66.407  52.232  1
414651  97.346  -66.412  52.198  1
414652  97.385  -66.417  52.161  1
414653  97.424  -66.422  52.124  1
414654  97.462  -66.427  52.084  1
414655  97.501  -66.433  52.042  1
414656  97.539  -66.442  52.000  1
414657  97.579  -66.455  51.960  1
414658  97.617  -66.468  51.921  1
414659  97.657  -66.482  51.884  1
414660  97.696  -66.495  51.848  1
414661  97.734  -66.507  51.810  1
414662  97.773  -66.515  51.771  1
414663  97.811  -66.523  51.733  1
414664  97.850  -66.531  51.694  1
414665  97.887  -66.539  51.653  1
414666  97.921  -66.543  51.612  1
414667  97.953  -66.548  51.568  1
414668  97.987  -66.552  51.523  1
414669  98.020  -66.556  51.479  1
414670  98.053  -66.560  51.437  1
414671  98.080  -66.567  51.395  1
414672  98.102  -66.575  51.354  1
414673  98.125  -66.584  51.314  1
414674  98.148  -66.592  51.273  1
414675  98.170  -66.601  51.231  1
414676  98.193  -66.609  51.186  1
414677  98.215  -66.617  51.140  1
414678  98.239  -66.625  51.091  1
414679  98.274  -66.625  51.042  1
414680  98.309  -66.625  50.992  1
414681  98.344  -66.622  50.944  1
414682  98.378  -66.617  50.899  1
414683  98.413  -66.614  50.857  1
414684  98.452  -66.617  50.818  1
414685  98.491  -66.620  50.778  1
414686  98.530  -66.623  50.737  1
414687  98.569  -66.626  50.694  1
414688  98.607  -66.629  50.651  1
414689  98.647  -66.632  50.604  1
414690  98.681  -66.638  50.555  1
414691  98.720  -66.646  50.505  1
414692  98.762  -66.653  50.452  1
414693  98.810  -66.661  50.399  1
414694  98.861  -66.669  50.345  1
414695  98.912  -66.677  50.291  1
414696  98.951  -66.686  50.238  1
414697  98.978  -66.696  50.183  1
414698  99.005  -66.706  50.126  1
414699  99.050  -66.708  50.070  1
414700  99.096  -66.711  50.014  1
414701  99.142  -66.713  49.958  1
414702  99.187  -66.720  49.902  1
414703  99.229  -66.733  49.847  1
414704  99.273  -66.746  49.793  1
414705  99.316  -66.760  49.740  1
414706  99.359  -66.773  49.689  1
414707  99.403  -66.787  49.636  1
414708  99.445  -66.799  49.582  1
414709  99.489  -66.813  49.529  1
414710  99.532  -66.821  49.474  1
414711  99.566  -66.819  49.418  1
414712  99.575  -66.795  49.363  1
414713  99.584  -66.771  49.310  1
414714  99.595  -66.762  49.256  1
414715  99.632  -66.777  49.202  1
414716  99.696  -66.802  49.150  1
414717  99.760  -66.827  49.100  1
414718  99.806  -66.837  49.050  1
414719  99.853  -66.846  49.002  1
414720  99.883  -66.853  48.954  1
414721  99.903  -66.862  48.908  1
414722  99.923  -66.869  48.862  1
414723  99.952  -66.872  48.815  1
414724  99.992  -66.871  48.769  1
414725  100.032  -66.868  48.726  1
414726  100.071  -66.866  48.684  1
414727  100.111  -66.865  48.641  1
414728  100.153  -66.862  48.598  1
414729  100.201  -66.860  48.556  1
414730  100.250  -66.858  48.513  1
414731  100.298  -66.856  48.474  1
414732  100.346  -66.854  48.434  1
414733  100.394  -66.852  48.394  1
415192  90.669  -65.959  54.970  1
415193  90.718  -65.968  54.974  1
415194  90.766  -65.974  54.976  1
415195  90.814  -65.980  54.979  1
415196  90.863  -65.986  54.981  1
415197  90.911  -65.992  54.984  1
415198  90.960  -65.998  54.985  1
415199  91.008  -66.005  54.987  1
415200  91.057  -66.011  54.988  1
415201  91.105  -66.017  54.990  1
415202  91.153  -66.025  54.991  1
415203  91.199  -66.036  54.995  1
415204  91.244  -66.047  54.999  1
415205  91.290  -66.059  55.004  1
415206  91.336  -66.070  55.011  1
415207  91.381  -66.082  55.022  1
415208  91.427  -66.094  55.036  1
415209  91.472  -66.103  55.046  1
415210  91.516  -66.111  55.053  1
415211  91.561  -66.126  55.058  1
415212  91.604  -66.133  55.059  1
415213  91.648  -66.139  55.059  1
415214  91.692  -66.144  55.059  1
415215  91.735  -66.151  55.059  1
415216  91.778  -66.157  55.060  1
415217  91.821  -66.163  55.059  1
415218  91.868  -66.166  55.059  1
415219  91.919  -66.166  55.060  1
415220  91.969  -66.165  55.062  1
415221  92.020  -66.165  55.067  1
415222  92.071  -66.164  55.069  1
415223  92.120  -66.173  55.071  1
415224  92.168  -66.183  55.073  1
415225  92.216  -66.193  55.074  1
415226  92.265  -66.203  55.070  1
415227  92.313  -66.213  55.063  1
415228  92.361  -66.223  55.054  1
415229  92.410  -66.232  55.044  1
415230  92.458  -66.241  55.037  1
415231  92.506  -66.249  55.034  1
415232  92.550  -66.240  55.028  1
415233  92.593  -66.232  55.015  1
415234  92.637  -66.223  54.995  1
415235  92.681  -66.214  54.967  1
415236  92.725  -66.206  54.936  1
415237  92.769  -66.197  54.908  1
415238  92.812  -66.188  54.882  1
415239  92.856  -66.179  54.858  1
415240  92.900  -66.171  54.840  1
415241  92.943  -66.162  54.825  1
415242  92.987  -66.154  54.813  1
415243  93.031  -66.144  54.801  1
415244  93.075  -66.136  54.785  1
415245  93.119  -66.127  54.762  1
415246  93.162  -66.119  54.734  1
415247  93.206  -66.110  54.704  1
415248  93.250  -66.101  54.674  1
415249  93.296  -66.097  54.647  1
415250  93.342  -66.093  54.623  1
415251  93.379  -66.092  54.600  1
415252  93.417  -66.091  54.579  1
415253  93.454  -66.091  54.562  1
415254  93.492  -66.090  54.546  1
415255  93.536  -66.090  54.529  1
415256  93.580  -66.089  54.514  1
415257  93.625  -66.089  54.499  1
415258  93.670  -66.089  54.486  1
415259  93.713  -66.096  54.474  1
415260  93.756  -66.103  54.461  1
415261  93.800  -66.110  54.446  1
415262  93.843  -66.116  54.429  1
415263  93.887  -66.123  54.408  1
415264  93.930  -66.130  54.383  1
415265  93.974  -66.137  54.357  1
415266  94.014  -66.142  54.330  1
415267  94.054  -66.147  54.302  1
415268  94.093  -66.153  54.273  1
415269  94.133  -66.158  54.244  1
415270  94.172  -66.163  54.216  1
415271  94.212  -66.169  54.187  1
415272  94.251  -66.174  54.162  1
415273  94.291  -66.179  54.134  1
415274  94.331  -66.185  54.106  1
415275  94.370  -66.190  54.079  1
415276  94.410  -66.194  54.054  1
415277  94.439  -66.204  54.029  1
415278  94.474  -66.211  54.002  1
415279  94.509  -66.219  53.972  1
415280  94.544  -66.222  53.941  1
415281  94.578  -66.224  53.912  1
415282  94.612  -66.226  53.891  1
415283  94.646  -66.229  53.875  1
415284  94.681  -66.232  53.863  1
415285  94.715  -66.234  53.855  1
415286  94.749  -66.237  53.847  1
415287  94.787  -66.248  53.836  1
415288  94.828  -66.263  53.820  1
415289  94.868  -66.279  53.802  1
415290  94.897  -66.283  53.781  1
415291  94.925  -66.288  53.760  1
415292  94.954  -66.292  53.739  1
415293  94.982  -66.297  53.716  1
415294  95.016  -66.301  53.690  1
415295  95.054  -66.304  53.662  1
415296  95.093  -66.306  53.629  1
415297  95.131  -66.308  53.595  1
415298  95.168  -66.312  53.561  1
415299  95.203  -66.317  53.530  1
415300  95.239  -66.321  53.503  1
415301  95.274  -66.326  53.480  1
415302  95.321  -66.323  53.459  1
415303  95.372  -66.317  53.442  1
415304  95.418  -66.316  53.427  1
415305  95.457  -66.321  53.416  1
415306  95.495  -66.326  53.404  1
415307  95.532  -66.333  53.391  1
415308  95.563  -66.351  53.376  1
415309  95.598  -66.364  53.360  1
415310  95.643  -66.362  53.343  1
415311  95.689  -66.361  53.326  1
415312  95.735  -66.359  53.308  1
415313  95.781  -66.358  53.290  1
415314  95.827  -66.358  53.270  1
415315  95.872  -66.361  53.249  1
415316  95.913  -66.361  53.225  1
415317  95.956  -66.356  53.200  1
415318  96.000  -66.351  53.176  1
415319  96.043  -66.348  53.150  1
415320  96.086  -66.343  53.126  1
415321  96.129  -66.339  53.101  1
415322  96.173  -66.334  53.076  1
415323  96.217  -66.329  53.052  1
415324  96.259  -66.326  53.027  1
415325  96.301  -66.323  53.004  1
415326  96.343  -66.320  52.980  1
415327  96.386  -66.317  52.955  1
415328  96.425  -66.314  52.926  1
415329  96.459  -66.310  52.893  1
415330  96.493  -66.308  52.859  1
415331  96.526  -66.305  52.828  1
415332  96.560  -66.303  52.803  1
415333  96.594  -66.300  52.781  1
415334  96.628  -66.297  52.757  1
415335  96.662  -66.295  52.731  1
415336  96.695  -66.292  52.705  1
415337  96.729  -66.289  52.676  1
415338  96.764  -66.286  52.642  1
415339  96.808  -66.287  52.602  1
415340  96.853  -66.289  52.559  1
415341  96.896  -66.291  52.515  1
415342  96.941  -66.293  52.473  1
415343  96.984  -66.297  52.436  1
415344  97.024  -66.307  52.402  1
415345  97.065  -66.317  52.373  1
415346  97.106  -66.327  52.348  1
415347  97.146  -66.337  52.327  1
415348  97.187  -66.348  52.309  1
415349  97.227  -66.357  52.287  1
415350  97.268  -66.367  52.261  1
415351  97.307  -66.372  52.231  1
415352  97.346  -66.377  52.198  1
415353  97.384  -66.382  52.162  1
415354  97.423  -66.387  52.125  1
415355  97.461  -66.392  52.085  1
415356  97.500  -66.397  52.041  1
415357  97.539  -66.408  52.001  1
415358  97.578  -66.421  51.962  1
415359  97.617  -66.435  51.926  1
415360  97.656  -66.448  51.891  1
415361  97.695  -66.460  51.856  1
415362  97.733  -66.468  51.817  1
415363  97.772  -66.476  51.779  1
415364  97.810  -66.484  51.741  1
415365  97.848  -66.492  51.700  1
415366  97.884  -66.499  51.659  1
415367  97.918  -66.503  51.616  1
415368  97.950  -66.508  51.571  1
415369  97.984  -66.511  51.526  1
415370  98.017  -66.516  51.484  1
415371  98.050  -66.520  51.443  1
415372  98.082  -66.524  51.401  1
415373  98.105  -66.533  51.360  1
415374  98.128  -66.542  51.318  1
415375  98.150  -66.550  51.275  1
415376  98.173  -66.558  51.231  1
415377  98.196  -66.567  51.184  1
415378  98.218  -66.575  51.136  1
415379  98.244  -66.581  51.085  1
415380  98.279  -66.581  51.036  1
415381  98.314  -66.581  50.987  1
415382  98.349  -66.580  50.939  1
415383  98.383  -66.577  50.892  1
415384  98.418  -66.573  50.850  1
415385  98.457  -66.576  50.810  1
415386  98.496  -66.579  50.770  1
415387  98.535  -66.582  50.729  1
415388  98.574  -66.585  50.688  1
415389  98.613  -66.587  50.646  1
415390  98.652  -66.590  50.601  1
415391  98.691  -66.593  50.553  1
415392  98.735  -66.600  50.505  1
415393  98.786  -66.608  50.453  1
415394  98.837  -66.616  50.400  1
415395  98.888  -66.624  50.346  1
415396  98.939  -66.632  50.292  1
415397  98.971  -66.642  50.238  1
415398  98.997  -66.652  50.183  1
415399  99.023  -66.663  50.125  1
415400  99.055  -66.671  50.068  1
415401  99.100  -66.673  50.011  1
415402  99.146  -66.675  49.955  1
415403  99.190  -66.685  49.900  1
415404  99.233  -66.699  49.846  1
415405  99.276  -66.711  49.792  1
415406  99.320  -66.725  49.740  1
415407  99.363  -66.738  49.688  1
415408  99.406  -66.750  49.635  1
415409  99.448  -66.755  49.580  1
415410  99.491  -66.762  49.525  1
415411  99.534  -66.767  49.470  1
415412  99.569  -66.765  49.414  1
415413  99.578  -66.740  49.360  1
415414  99.587  -66.716  49.306  1
415415  99.598  -66.722  49.252  1
415416  99.644  -66.740  49.197  1
415417  99.708  -66.765  49.146  1
415418  99.764  -66.784  49.094  1
415419  99.810  -66.793  49.045  1
415420  99.856  -66.801  48.996  1
415421  99.888  -66.809  48.949  1
415422  99.909  -66.817  48.903  1
415423  99.929  -66.825  48.856  1
415424  99.962  -66.827  48.809  1
415425  100.001  -66.824  48.764  1
415426  100.041  -66.822  48.721  1
415427  100.081  -66.821  48.679  1
415428  100.120  -66.818  48.636  1
415429  100.168  -66.816  48.593  1
415430  100.216  -66.814  48.551  1
415431  100.264  -66.812  48.509  1
415432  100.312  -66.810  48.469  1
415433  100.360  -66.808  48.430  1
415892  90.619  -65.906  54.968  1
415893  90.668  -65.912  54.971  1
415894  90.716  -65.919  54.974  1
415895  90.765  -65.925  54.976  1
415896  90.813  -65.931  54.978  1
415897  90.862  -65.937  54.980  1
415898  90.910  -65.944  54.981  1
415899  90.958  -65.950  54.982  1
415900  91.007  -65.956  54.982  1
415901  91.055  -65.962  54.983  1
415902  91.104  -65.968  54.983  1
415903  91.151  -65.978  54.985  1
415904  91.196  -65.989  54.987  1
415905  91.242  -66.000  54.991  1
415906  91.288  -66.012  54.995  1
415907  91.333  -66.023  55.001  1
415908  91.379  -66.035  55.012  1
415909  91.425  -66.047  55.025  1
415910  91.471  -66.058  55.036  1
415911  91.515  -66.065  55.045  1
415912  91.559  -66.070  55.050  1
415913  91.602  -66.076  55.052  1
415914  91.645  -66.082  55.053  1
415915  91.688  -66.088  55.055  1
415916  91.732  -66.094  55.057  1
415917  91.775  -66.100  55.057  1
415918  91.818  -66.106  55.057  1
415919  91.862  -66.112  55.057  1
415920  91.911  -66.113  55.056  1
415921  91.962  -66.113  55.057  1
415922  92.012  -66.113  55.059  1
415923  92.061  -66.122  55.062  1
415924  92.109  -66.132  55.066  1
415925  92.158  -66.141  55.069  1
415926  92.206  -66.151  55.069  1
415927  92.254  -66.161  55.066  1
415928  92.303  -66.171  55.062  1
415929  92.351  -66.181  55.056  1
415930  92.400  -66.191  55.048  1
415931  92.448  -66.200  55.042  1
415932  92.495  -66.202  55.037  1
415933  92.538  -66.194  55.028  1
415934  92.582  -66.185  55.014  1
415935  92.626  -66.176  54.994  1
415936  92.669  -66.167  54.966  1
415937  92.713  -66.159  54.936  1
415938  92.757  -66.150  54.908  1
415939  92.801  -66.141  54.883  1
415940  92.845  -66.132  54.859  1
415941  92.888  -66.124  54.840  1
415942  92.932  -66.115  54.825  1
415943  92.976  -66.107  54.813  1
415944  93.020  -66.097  54.801  1
415945  93.064  -66.089  54.787  1
415946  93.108  -66.081  54.765  1
415947  93.151  -66.072  54.739  1
415948  93.198  -66.069  54.711  1
415949  93.247  -66.071  54.682  1
415950  93.295  -66.066  54.658  1
415951  93.343  -66.060  54.637  1
415952  93.382  -66.058  54.617  1
415953  93.420  -66.057  54.599  1
415954  93.458  -66.056  54.584  1
415955  93.496  -66.056  54.569  1
415956  93.541  -66.056  54.552  1
415957  93.585  -66.056  54.536  1
415958  93.630  -66.056  54.520  1
415959  93.675  -66.056  54.507  1
415960  93.718  -66.057  54.495  1
415961  93.762  -66.064  54.481  1
415962  93.805  -66.071  54.467  1
415963  93.849  -66.078  54.450  1
415964  93.893  -66.085  54.429  1
415965  93.936  -66.091  54.404  1
415966  93.979  -66.098  54.376  1
415967  94.018  -66.103  54.348  1
415968  94.058  -66.109  54.318  1
415969  94.098  -66.114  54.290  1
415970  94.137  -66.119  54.262  1
415971  94.177  -66.125  54.234  1
415972  94.216  -66.130  54.206  1
415973  94.256  -66.135  54.180  1
415974  94.295  -66.140  54.150  1
415975  94.335  -66.144  54.120  1
415976  94.374  -66.148  54.090  1
415977  94.409  -66.154  54.063  1
415978  94.432  -66.169  54.034  1
415979  94.468  -66.176  54.005  1
415980  94.503  -66.183  53.976  1
415981  94.538  -66.191  53.946  1
415982  94.573  -66.198  53.921  1
415983  94.608  -66.202  53.902  1
415984  94.642  -66.204  53.888  1
415985  94.676  -66.207  53.877  1
415986  94.710  -66.210  53.869  1
415987  94.745  -66.212  53.862  1
415988  94.779  -66.214  53.852  1
415989  94.818  -66.228  53.837  1
415990  94.858  -66.242  53.819  1
415991  94.892  -66.251  53.800  1
415992  94.920  -66.257  53.780  1
415993  94.949  -66.261  53.760  1
415994  94.977  -66.266  53.739  1
415995  95.014  -66.269  53.715  1
415996  95.053  -66.271  53.687  1
415997  95.091  -66.273  53.655  1
415998  95.130  -66.276  53.622  1
415999  95.168  -66.279  53.588  1
416000  95.206  -66.282  53.554  1
416001  95.241  -66.286  53.525  1
416002  95.277  -66.291  53.501  1
416003  95.328  -66.285  53.479  1
416004  95.372  -66.286  53.458  1
416005  95.410  -66.292  53.440  1
416006  95.448  -66.297  53.428  1
416007  95.486  -66.302  53.417  1
416008  95.525  -66.307  53.404  1
416009  95.557  -66.323  53.390  1
416010  95.596  -66.330  53.374  1
416011  95.642  -66.329  53.356  1
416012  95.688  -66.327  53.338  1
416013  95.734  -66.326  53.319  1
416014  95.779  -66.324  53.300  1
416015  95.825  -66.323  53.278  1
416016  95.870  -66.323  53.257  1
416017  95.913  -66.318  53.233  1
416018  95.957  -66.314  53.207  1
416019  96.000  -66.309  53.182  1
416020  96.043  -66.304  53.157  1
416021  96.087  -66.300  53.132  1
416022  96.130  -66.295  53.108  1
416023  96.174  -66.291  53.083  1
416024  96.217  -66.286  53.061  1
416025  96.260  -66.282  53.039  1
416026  96.302  -66.279  53.017  1
416027  96.344  -66.276  52.995  1
416028  96.387  -66.273  52.971  1
416029  96.425  -66.270  52.941  1
416030  96.460  -66.266  52.909  1
416031  96.494  -66.264  52.874  1
416032  96.528  -66.261  52.841  1
416033  96.562  -66.259  52.815  1
416034  96.596  -66.256  52.793  1
416035  96.629  -66.253  52.768  1
416036  96.663  -66.251  52.742  1
416037  96.697  -66.248  52.716  1
416038  96.731  -66.245  52.687  1
416039  96.770  -66.250  52.653  1
416040  96.813  -66.253  52.613  1
416041  96.857  -66.255  52.570  1
416042  96.901  -66.257  52.525  1
416043  96.945  -66.259  52.480  1
416044  96.988  -66.263  52.441  1
416045  97.029  -66.273  52.407  1
416046  97.070  -66.284  52.376  1
416047  97.110  -66.294  52.348  1
416048  97.151  -66.304  52.324  1
416049  97.191  -66.314  52.304  1
416050  97.232  -66.324  52.283  1
416051  97.269  -66.331  52.258  1
416052  97.306  -66.337  52.229  1
416053  97.345  -66.342  52.197  1
416054  97.384  -66.347  52.162  1
416055  97.423  -66.352  52.124  1
416056  97.461  -66.357  52.085  1
416057  97.500  -66.362  52.044  1
416058  97.538  -66.375  52.005  1
416059  97.578  -66.388  51.969  1
416060  97.616  -66.401  51.934  1
416061  97.655  -66.413  51.899  1
416062  97.694  -66.421  51.866  1
416063  97.732  -66.429  51.827  1
416064  97.771  -66.437  51.788  1
416065  97.809  -66.445  51.749  1
416066  97.847  -66.454  51.707  1
416067  97.881  -66.459  51.666  1
416068  97.915  -66.463  51.622  1
416069  97.948  -66.467  51.576  1
416070  97.981  -66.472  51.532  1
416071  98.014  -66.476  51.489  1
416072  98.047  -66.480  51.448  1
416073  98.080  -66.484  51.406  1
416074  98.108  -66.490  51.364  1
416075  98.131  -66.499  51.321  1
416076  98.153  -66.508  51.276  1
416077  98.176  -66.516  51.229  1
416078  98.199  -66.524  51.180  1
416079  98.221  -66.533  51.130  1
416080  98.249  -66.538  51.080  1
416081  98.284  -66.537  51.030  1
416082  98.318  -66.537  50.981  1
416083  98.353  -66.537  50.934  1
416084  98.388  -66.535  50.889  1
416085  98.423  -66.532  50.846  1
416086  98.462  -66.535  50.804  1
416087  98.501  -66.538  50.763  1
416088  98.540  -66.540  50.722  1
416089  98.579  -66.543  50.681  1
416090  98.618  -66.546  50.639  1
416091  98.659  -66.549  50.597  1
416092  98.700  -66.552  50.551  1
416093  98.745  -66.556  50.503  1
416094  98.796  -66.564  50.453  1
416095  98.848  -66.572  50.400  1
416096  98.899  -66.580  50.346  1
416097  98.947  -66.588  50.292  1
416098  98.982  -66.598  50.238  1
416099  99.016  -66.608  50.182  1
416100  99.042  -66.618  50.124  1
416101  99.068  -66.629  50.066  1
416102  99.104  -66.635  50.010  1
416103  99.150  -66.637  49.954  1
416104  99.194  -66.650  49.900  1
416105  99.237  -66.664  49.845  1
416106  99.280  -66.677  49.791  1
416107  99.323  -66.685  49.738  1
416108  99.366  -66.690  49.685  1
416109  99.408  -66.696  49.632  1
416110  99.451  -66.701  49.578  1
416111  99.494  -66.706  49.522  1
416112  99.537  -66.712  49.465  1
416113  99.571  -66.710  49.409  1
416114  99.580  -66.686  49.355  1
416115  99.590  -66.676  49.301  1
416116  99.602  -66.682  49.247  1
416117  99.655  -66.703  49.194  1
416118  99.719  -66.728  49.142  1
416119  99.768  -66.740  49.090  1
416120  99.814  -66.748  49.040  1
416121  99.860  -66.757  48.992  1
416122  99.894  -66.765  48.945  1
416123  99.914  -66.773  48.898  1
416124  99.934  -66.781  48.851  1
416125  99.971  -66.780  48.805  1
416126  100.010  -66.778  48.759  1
416127  100.050  -66.777  48.717  1
416128  100.090  -66.774  48.674  1
416129  100.134  -66.772  48.632  1
416130  100.182  -66.770  48.589  1
416131  100.230  -66.768  48.547  1
416132  100.278  -66.766  48.506  1
416133  100.327  -66.764  48.466  1
416134  100.375  -66.762  48.426  1
416564  89.167  -65.750  55.027  1
416565  89.213  -65.754  55.016  1
416592  90.570  -65.851  54.966  1
416593  90.618  -65.857  54.969  1
416594  90.667  -65.863  54.972  1
416595  90.715  -65.869  54.975  1
416596  90.763  -65.876  54.977  1
416597  90.812  -65.882  54.978  1
416598  90.861  -65.888  54.978  1
416599  90.909  -65.894  54.979  1
416600  90.957  -65.900  54.979  1
416601  91.006  -65.906  54.979  1
416602  91.054  -65.912  54.978  1
416603  91.103  -65.919  54.978  1
416604  91.149  -65.930  54.979  1
416605  91.194  -65.942  54.980  1
416606  91.240  -65.953  54.983  1
416607  91.286  -65.965  54.987  1
416608  91.331  -65.976  54.991  1
416609  91.377  -65.988  54.998  1
416610  91.423  -65.999  55.010  1
416611  91.468  -66.010  55.022  1
416612  91.511  -66.021  55.032  1
416613  91.554  -66.026  55.039  1
416614  91.598  -66.029  55.044  1
416615  91.642  -66.033  55.047  1
416616  91.685  -66.036  55.050  1
416617  91.729  -66.040  55.054  1
416618  91.773  -66.044  55.054  1
416619  91.816  -66.050  55.055  1
416620  91.859  -66.056  55.055  1
416621  91.904  -66.061  55.053  1
416622  91.954  -66.061  55.052  1
416623  92.002  -66.071  55.052  1
416624  92.051  -66.081  55.055  1
416625  92.099  -66.091  55.058  1
416626  92.148  -66.100  55.061  1
416627  92.196  -66.110  55.060  1
416628  92.244  -66.119  55.058  1
416629  92.293  -66.129  55.055  1
416630  92.341  -66.139  55.051  1
416631  92.389  -66.149  55.045  1
416632  92.438  -66.159  55.040  1
416633  92.483  -66.156  55.033  1
416634  92.527  -66.147  55.023  1
416635  92.571  -66.138  55.009  1
416636  92.615  -66.129  54.991  1
416637  92.658  -66.121  54.964  1
416638  92.702  -66.112  54.936  1
416639  92.746  -66.103  54.909  1
416640  92.789  -66.094  54.885  1
416641  92.833  -66.086  54.863  1
416642  92.877  -66.077  54.843  1
416643  92.921  -66.069  54.826  1
416644  92.965  -66.060  54.813  1
416645  93.008  -66.051  54.801  1
416646  93.052  -66.042  54.786  1
416647  93.100  -66.042  54.766  1
416648  93.149  -66.044  54.742  1
416649  93.198  -66.045  54.715  1
416650  93.246  -66.042  54.690  1
416651  93.294  -66.035  54.669  1
416652  93.341  -66.028  54.650  1
416653  93.385  -66.025  54.634  1
416654  93.423  -66.024  54.620  1
416655  93.460  -66.023  54.607  1
416656  93.501  -66.022  54.591  1
416657  93.546  -66.022  54.575  1
416658  93.590  -66.022  54.559  1
416659  93.635  -66.022  54.542  1
416660  93.679  -66.022  54.529  1
416661  93.724  -66.022  54.516  1
416662  93.768  -66.026  54.502  1
416663  93.811  -66.033  54.488  1
416664  93.854  -66.040  54.471  1
416665  93.898  -66.047  54.450  1
416666  93.941  -66.053  54.425  1
416667  93.983  -66.060  54.397  1
416668  94.023  -66.065  54.368  1
416669  94.062  -66.070  54.338  1
416670  94.102  -66.075  54.310  1
416671  94.141  -66.081  54.282  1
416672  94.181  -66.085  54.254  1
416673  94.220  -66.091  54.225  1
416674  94.260  -66.096  54.197  1
416675  94.299  -66.099  54.167  1
416676  94.339  -66.103  54.136  1
416677  94.379  -66.107  54.104  1
416678  94.401  -66.120  54.073  1
416679  94.426  -66.133  54.042  1
416680  94.461  -66.141  54.013  1
416681  94.496  -66.148  53.983  1
416682  94.532  -66.156  53.955  1
416683  94.567  -66.163  53.933  1
416684  94.602  -66.171  53.915  1
416685  94.637  -66.179  53.902  1
416686  94.672  -66.182  53.892  1
416687  94.706  -66.185  53.886  1
416688  94.741  -66.187  53.879  1
416689  94.775  -66.189  53.869  1
416690  94.809  -66.192  53.855  1
416691  94.849  -66.207  53.838  1
416692  94.887  -66.220  53.818  1
416693  94.915  -66.225  53.799  1
416694  94.944  -66.229  53.780  1
416695  94.975  -66.234  53.759  1
416696  95.013  -66.236  53.736  1
416697  95.052  -66.238  53.709  1
416698  95.090  -66.241  53.678  1
416699  95.129  -66.244  53.645  1
416700  95.167  -66.246  53.611  1
416701  95.206  -66.249  53.578  1
416702  95.244  -66.251  53.547  1
416703  95.283  -66.254  53.521  1
416704  95.325  -66.256  53.497  1
416705  95.363  -66.262  53.474  1
416706  95.401  -66.267  53.453  1
416707  95.440  -66.273  53.440  1
416708  95.478  -66.278  53.429  1
416709  95.517  -66.283  53.418  1
416710  95.551  -66.295  53.405  1
416711  95.594  -66.297  53.390  1
416712  95.640  -66.295  53.372  1
416713  95.686  -66.294  53.352  1
416714  95.732  -66.292  53.331  1
416715  95.779  -66.288  53.310  1
416716  95.826  -66.285  53.288  1
416717  95.874  -66.282  53.266  1
416718  95.916  -66.276  53.241  1
416719  95.958  -66.270  53.216  1
416720  96.001  -66.266  53.190  1
416721  96.044  -66.261  53.166  1
416722  96.088  -66.257  53.141  1
416723  96.131  -66.252  53.117  1
416724  96.174  -66.248  53.094  1
416725  96.218  -66.243  53.071  1
416726  96.261  -66.238  53.051  1
416727  96.304  -66.235  53.030  1
416728  96.346  -66.232  53.008  1
416729  96.387  -66.229  52.984  1
416730  96.425  -66.226  52.955  1
416731  96.462  -66.223  52.923  1
416732  96.496  -66.220  52.889  1
416733  96.530  -66.217  52.856  1
416734  96.564  -66.215  52.827  1
416735  96.597  -66.212  52.803  1
416736  96.631  -66.209  52.778  1
416737  96.665  -66.207  52.752  1
416738  96.699  -66.204  52.726  1
416739  96.737  -66.207  52.696  1
416740  96.777  -66.214  52.661  1
416741  96.818  -66.219  52.622  1
416742  96.862  -66.221  52.579  1
416743  96.906  -66.223  52.533  1
416744  96.950  -66.224  52.488  1
416745  96.993  -66.230  52.448  1
416746  97.033  -66.240  52.412  1
416747  97.074  -66.251  52.380  1
416748  97.114  -66.260  52.350  1
416749  97.155  -66.270  52.323  1
416750  97.195  -66.281  52.300  1
416751  97.233  -66.288  52.277  1
416752  97.271  -66.294  52.253  1
416753  97.307  -66.301  52.226  1
416754  97.345  -66.307  52.194  1
416755  97.383  -66.312  52.160  1
416756  97.422  -66.317  52.123  1
416757  97.460  -66.323  52.085  1
416758  97.499  -66.328  52.046  1
416759  97.538  -66.341  52.010  1
416760  97.577  -66.354  51.976  1
416761  97.616  -66.366  51.942  1
416762  97.654  -66.374  51.908  1
416763  97.692  -66.382  51.875  1
416764  97.731  -66.390  51.837  1
416765  97.769  -66.398  51.797  1
416766  97.808  -66.407  51.757  1
416767  97.846  -66.414  51.714  1
416768  97.878  -66.419  51.670  1
416769  97.912  -66.423  51.626  1
416770  97.945  -66.427  51.582  1
416771  97.978  -66.432  51.537  1
416772  98.011  -66.436  51.495  1
416773  98.044  -66.440  51.453  1
416774  98.077  -66.444  51.411  1
416775  98.110  -66.448  51.367  1
416776  98.134  -66.457  51.322  1
416777  98.156  -66.465  51.276  1
416778  98.179  -66.473  51.226  1
416779  98.202  -66.482  51.176  1
416780  98.224  -66.490  51.125  1
416781  98.253  -66.494  51.074  1
416782  98.288  -66.494  51.025  1
416783  98.323  -66.493  50.977  1
416784  98.358  -66.493  50.931  1
416785  98.393  -66.493  50.887  1
416786  98.428  -66.491  50.844  1
416787  98.467  -66.493  50.801  1
416788  98.506  -66.496  50.759  1
416789  98.546  -66.499  50.716  1
416790  98.587  -66.502  50.675  1
416791  98.628  -66.505  50.635  1
416792  98.669  -66.508  50.593  1
416793  98.710  -66.510  50.549  1
416794  98.752  -66.513  50.501  1
416795  98.803  -66.520  50.452  1
416796  98.855  -66.529  50.399  1
416797  98.906  -66.536  50.345  1
416798  98.946  -66.545  50.290  1
416799  98.981  -66.555  50.234  1
416800  99.015  -66.565  50.178  1
416801  99.050  -66.575  50.121  1
416802  99.084  -66.585  50.065  1
416803  99.114  -66.596  50.009  1
416804  99.154  -66.602  49.953  1
416805  99.197  -66.614  49.898  1
416806  99.240  -66.620  49.844  1
416807  99.283  -66.625  49.789  1
416808  99.326  -66.630  49.734  1
416809  99.368  -66.636  49.681  1
416810  99.411  -66.641  49.627  1
416811  99.453  -66.646  49.572  1
416812  99.496  -66.652  49.516  1
416813  99.539  -66.657  49.461  1
416814  99.573  -66.655  49.405  1
416815  99.582  -66.631  49.350  1
416816  99.594  -66.636  49.296  1
416817  99.606  -66.642  49.243  1
416818  99.667  -66.666  49.190  1
416819  99.725  -66.686  49.138  1
416820  99.772  -66.695  49.086  1
416821  99.818  -66.704  49.036  1
416822  99.864  -66.713  48.987  1
416823  99.900  -66.721  48.940  1
416824  99.920  -66.729  48.893  1
416825  99.940  -66.737  48.847  1
416826  99.980  -66.734  48.800  1
416827  100.020  -66.733  48.755  1
416828  100.059  -66.730  48.713  1
416829  100.100  -66.728  48.670  1
416830  100.148  -66.726  48.628  1
416831  100.196  -66.724  48.586  1
416832  100.245  -66.722  48.544  1
416833  100.293  -66.720  48.502  1
416834  100.341  -66.718  48.463  1
416835  100.389  -66.716  48.423  1
417262  89.041  -65.680  55.063  1
417263  89.077  -65.689  55.054  1
417264  89.123  -65.693  55.043  1
417265  89.169  -65.697  55.033  1
417266  89.215  -65.701  55.022  1
417267  89.262  -65.705  55.011  1
417268  89.308  -65.709  55.001  1
417269  89.354  -65.712  54.990  1
417270  89.400  -65.716  54.979  1
417291  90.472  -65.790  54.962  1
417292  90.520  -65.796  54.965  1
417293  90.569  -65.802  54.968  1
417294  90.617  -65.809  54.971  1
417295  90.665  -65.815  54.973  1
417296  90.714  -65.821  54.976  1
417297  90.762  -65.827  54.977  1
417298  90.811  -65.833  54.977  1
417299  90.859  -65.839  54.977  1
417300  90.908  -65.845  54.976  1
417301  90.956  -65.852  54.976  1
417302  91.005  -65.858  54.975  1
417303  91.053  -65.864  54.973  1
417304  91.101  -65.872  54.973  1
417305  91.147  -65.883  54.973  1
417306  91.192  -65.894  54.973  1
417307  91.238  -65.906  54.975  1
417308  91.284  -65.918  54.978  1
417309  91.329  -65.929  54.981  1
417310  91.375  -65.941  54.986  1
417311  91.421  -65.952  54.994  1
417312  91.464  -65.963  55.004  1
417313  91.507  -65.974  55.013  1
417314  91.550  -65.984  55.022  1
417315  91.593  -65.988  55.031  1
417316  91.637  -65.991  55.039  1
417317  91.681  -65.994  55.045  1
417318  91.724  -65.997  55.048  1
417319  91.768  -66.001  55.049  1
417320  91.812  -66.004  55.050  1
417321  91.856  -66.008  55.050  1
417322  91.899  -66.011  55.049  1
417323  91.944  -66.019  55.048  1
417324  91.992  -66.029  55.047  1
417325  92.040  -66.039  55.047  1
417326  92.089  -66.049  55.049  1
417327  92.138  -66.059  55.050  1
417328  92.186  -66.068  55.049  1
417329  92.234  -66.078  55.047  1
417330  92.283  -66.088  55.044  1
417331  92.331  -66.097  55.041  1
417332  92.379  -66.107  55.037  1
417333  92.428  -66.117  55.033  1
417334  92.472  -66.109  55.026  1
417335  92.515  -66.100  55.015  1
417336  92.559  -66.091  55.001  1
417337  92.603  -66.083  54.985  1
417338  92.647  -66.074  54.962  1
417339  92.691  -66.066  54.937  1
417340  92.734  -66.056  54.912  1
417341  92.778  -66.048  54.889  1
417342  92.822  -66.039  54.867  1
417343  92.866  -66.031  54.847  1
417344  92.910  -66.022  54.830  1
417345  92.953  -66.013  54.814  1
417346  93.002  -66.015  54.802  1
417347  93.051  -66.016  54.787  1
417348  93.100  -66.018  54.768  1
417349  93.149  -66.019  54.745  1
417350  93.197  -66.017  54.723  1
417351  93.245  -66.010  54.701  1
417352  93.292  -66.004  54.685  1
417353  93.340  -65.997  54.671  1
417354  93.388  -65.991  54.659  1
417355  93.426  -65.990  54.648  1
417356  93.463  -65.989  54.635  1
417357  93.506  -65.989  54.619  1
417358  93.551  -65.988  54.602  1
417359  93.595  -65.988  54.584  1
417360  93.640  -65.988  54.566  1
417361  93.684  -65.988  54.552  1
417362  93.729  -65.988  54.539  1
417363  93.773  -65.988  54.525  1
417364  93.817  -65.994  54.510  1
417365  93.860  -66.001  54.493  1
417366  93.904  -66.008  54.471  1
417367  93.947  -66.015  54.446  1
417368  93.987  -66.021  54.419  1
417369  94.027  -66.025  54.391  1
417370  94.066  -66.031  54.362  1
417371  94.106  -66.036  54.333  1
417372  94.145  -66.041  54.303  1
417373  94.185  -66.047  54.273  1
417374  94.224  -66.050  54.244  1
417375  94.264  -66.053  54.215  1
417376  94.303  -66.057  54.185  1
417377  94.343  -66.061  54.153  1
417378  94.373  -66.070  54.121  1
417379  94.392  -66.087  54.086  1
417380  94.420  -66.098  54.054  1
417381  94.455  -66.106  54.023  1
417382  94.490  -66.113  53.994  1
417383  94.525  -66.120  53.967  1
417384  94.560  -66.128  53.948  1
417385  94.596  -66.135  53.931  1
417386  94.631  -66.143  53.918  1
417387  94.666  -66.151  53.910  1
417388  94.701  -66.158  53.904  1
417389  94.736  -66.162  53.897  1
417390  94.770  -66.165  53.887  1
417391  94.805  -66.167  53.873  1
417392  94.840  -66.171  53.856  1
417393  94.880  -66.186  53.837  1
417394  94.911  -66.193  53.819  1
417395  94.939  -66.198  53.800  1
417396  94.973  -66.201  53.778  1
417397  95.012  -66.204  53.755  1
417398  95.050  -66.207  53.729  1
417399  95.089  -66.209  53.698  1
417400  95.127  -66.211  53.665  1
417401  95.166  -66.214  53.631  1
417402  95.204  -66.216  53.597  1
417403  95.245  -66.218  53.565  1
417404  95.284  -66.221  53.538  1
417405  95.321  -66.227  53.512  1
417406  95.358  -66.234  53.488  1
417407  95.395  -66.240  53.467  1
417408  95.432  -66.247  53.452  1
417409  95.470  -66.253  53.442  1
417410  95.508  -66.258  53.432  1
417411  95.546  -66.264  53.421  1
417412  95.593  -66.262  53.406  1
417413  95.640  -66.258  53.388  1
417414  95.687  -66.255  53.368  1
417415  95.735  -66.251  53.346  1
417416  95.782  -66.248  53.323  1
417417  95.829  -66.245  53.300  1
417418  95.876  -66.241  53.276  1
417419  95.920  -66.237  53.251  1
417420  95.962  -66.231  53.226  1
417421  96.004  -66.225  53.200  1
417422  96.046  -66.219  53.176  1
417423  96.088  -66.213  53.153  1
417424  96.131  -66.209  53.129  1
417425  96.175  -66.204  53.106  1
417426  96.218  -66.200  53.083  1
417427  96.261  -66.195  53.062  1
417428  96.305  -66.191  53.041  1
417429  96.347  -66.188  53.019  1
417430  96.386  -66.185  52.995  1
417431  96.424  -66.182  52.968  1
417432  96.462  -66.179  52.937  1
417433  96.498  -66.176  52.904  1
417434  96.531  -66.173  52.870  1
417435  96.565  -66.171  52.836  1
417436  96.599  -66.168  52.811  1
417437  96.633  -66.165  52.786  1
417438  96.667  -66.163  52.760  1
417439  96.704  -66.165  52.732  1
417440  96.744  -66.172  52.702  1
417441  96.784  -66.178  52.666  1
417442  96.823  -66.184  52.627  1
417443  96.867  -66.186  52.584  1
417444  96.910  -66.188  52.540  1
417445  96.955  -66.190  52.496  1
417446  96.997  -66.197  52.454  1
417447  97.037  -66.207  52.418  1
417448  97.078  -66.217  52.386  1
417449  97.118  -66.227  52.356  1
417450  97.159  -66.237  52.325  1
417451  97.197  -66.245  52.297  1
417452  97.234  -66.251  52.272  1
417453  97.272  -66.257  52.248  1
417454  97.309  -66.264  52.222  1
417455  97.346  -66.270  52.190  1
417456  97.383  -66.277  52.157  1
417457  97.421  -66.282  52.122  1
417458  97.460  -66.287  52.085  1
417459  97.499  -66.294  52.048  1
417460  97.537  -66.307  52.015  1
417461  97.577  -66.319  51.982  1
417462  97.615  -66.327  51.950  1
417463  97.653  -66.335  51.917  1
417464  97.691  -66.344  51.884  1
417465  97.730  -66.351  51.847  1
417466  97.768  -66.360  51.806  1
417467  97.806  -66.368  51.764  1
417468  97.843  -66.375  51.720  1
417469  97.876  -66.379  51.675  1
417470  97.909  -66.383  51.631  1
417471  97.942  -66.387  51.587  1
417472  97.975  -66.392  51.543  1
417473  98.008  -66.395  51.501  1
417474  98.041  -66.400  51.459  1
417475  98.074  -66.404  51.415  1
417476  98.107  -66.408  51.370  1
417477  98.136  -66.414  51.323  1
417478  98.159  -66.423  51.274  1
417479  98.181  -66.431  51.224  1
417480  98.204  -66.439  51.172  1
417481  98.227  -66.448  51.120  1
417482  98.258  -66.450  51.069  1
417483  98.293  -66.450  51.022  1
417484  98.328  -66.450  50.976  1
417485  98.363  -66.449  50.930  1
417486  98.397  -66.449  50.887  1
417487  98.433  -66.449  50.843  1
417488  98.474  -66.452  50.800  1
417489  98.515  -66.454  50.756  1
417490  98.556  -66.458  50.713  1
417491  98.597  -66.460  50.671  1
417492  98.638  -66.463  50.632  1
417493  98.679  -66.466  50.591  1
417494  98.720  -66.468  50.546  1
417495  98.762  -66.471  50.499  1
417496  98.810  -66.477  50.450  1
417497  98.861  -66.485  50.398  1
417498  98.911  -66.493  50.343  1
417499  98.945  -66.503  50.287  1
417500  98.980  -66.513  50.230  1
417501  99.014  -66.523  50.173  1
417502  99.049  -66.533  50.118  1
417503  99.083  -66.542  50.063  1
417504  99.119  -66.555  50.007  1
417505  99.158  -66.564  49.951  1
417506  99.200  -66.565  49.896  1
417507  99.242  -66.565  49.841  1
417508  99.285  -66.570  49.785  1
417509  99.328  -66.576  49.729  1
417510  99.370  -66.581  49.676  1
417511  99.413  -66.586  49.621  1
417512  99.456  -66.592  49.565  1
417513  99.499  -66.597  49.510  1
417514  99.542  -66.602  49.456  1
417515  99.576  -66.601  49.400  1
417516  99.586  -66.590  49.346  1
417517  99.598  -66.596  49.292  1
417518  99.615  -66.604  49.239  1
417519  99.679  -66.629  49.186  1
417520  99.729  -66.642  49.135  1
417521  99.775  -66.651  49.083  1
417522  99.822  -66.660  49.032  1
417523  99.868  -66.668  48.982  1
417524  99.905  -66.677  48.935  1
417525  99.925  -66.685  48.888  1
417526  99.950  -66.690  48.842  1
417527  99.989  -66.689  48.796  1
417528  100.029  -66.686  48.751  1
417529  100.068  -66.684  48.709  1
417530  100.114  -66.683  48.667  1
417531  100.162  -66.680  48.624  1
417532  100.211  -66.678  48.583  1
417533  100.259  -66.676  48.541  1
417534  100.307  -66.674  48.498  1
417535  100.355  -66.672  48.458  1
417960  88.930  -65.603  55.100  1
417961  88.965  -65.613  55.090  1
417962  88.999  -65.622  55.080  1
417963  89.033  -65.632  55.070  1
417964  89.079  -65.636  55.061  1
417965  89.125  -65.640  55.051  1
417966  89.172  -65.643  55.041  1
417967  89.217  -65.648  55.030  1
417968  89.264  -65.652  55.018  1
417969  89.310  -65.655  55.009  1
417970  89.356  -65.659  54.997  1
417971  89.402  -65.663  54.986  1
417972  89.449  -65.667  54.975  1
417973  89.495  -65.671  54.964  1
417974  89.541  -65.675  54.954  1
417975  89.587  -65.679  54.945  1
417991  90.422  -65.734  54.962  1
417992  90.470  -65.740  54.964  1
417993  90.519  -65.747  54.967  1
417994  90.568  -65.753  54.970  1
417995  90.616  -65.759  54.973  1
417996  90.664  -65.765  54.975  1
417997  90.713  -65.771  54.976  1
417998  90.761  -65.778  54.977  1
417999  90.810  -65.784  54.976  1
418000  90.858  -65.790  54.975  1
418001  90.906  -65.796  54.973  1
418002  90.955  -65.803  54.972  1
418003  91.004  -65.809  54.970  1
418004  91.052  -65.815  54.969  1
418005  91.098  -65.825  54.968  1
418006  91.144  -65.836  54.966  1
418007  91.190  -65.847  54.965  1
418008  91.236  -65.859  54.966  1
418009  91.282  -65.871  54.968  1
418010  91.327  -65.882  54.970  1
418011  91.373  -65.894  54.974  1
418012  91.417  -65.905  54.980  1
418013  91.460  -65.916  54.987  1
418014  91.503  -65.926  54.995  1
418015  91.546  -65.937  55.005  1
418016  91.589  -65.945  55.017  1
418017  91.633  -65.948  55.028  1
418018  91.676  -65.952  55.037  1
418019  91.720  -65.955  55.041  1
418020  91.764  -65.959  55.042  1
418021  91.807  -65.962  55.043  1
418022  91.851  -65.966  55.044  1
418023  91.890  -65.974  55.044  1
418024  91.934  -65.983  55.044  1
418025  91.982  -65.988  55.043  1
418026  92.030  -65.997  55.041  1
418027  92.079  -66.007  55.040  1
418028  92.128  -66.017  55.039  1
418029  92.176  -66.027  55.036  1
418030  92.224  -66.036  55.034  1
418031  92.273  -66.046  55.032  1
418032  92.321  -66.056  55.030  1
418033  92.369  -66.066  55.027  1
418034  92.417  -66.071  55.021  1
418035  92.460  -66.062  55.014  1
418036  92.504  -66.053  55.004  1
418037  92.548  -66.044  54.992  1
418038  92.592  -66.036  54.977  1
418039  92.635  -66.027  54.958  1
418040  92.679  -66.019  54.938  1
418041  92.723  -66.010  54.916  1
418042  92.767  -66.001  54.894  1
418043  92.810  -65.992  54.873  1
418044  92.855  -65.986  54.853  1
418045  92.904  -65.988  54.835  1
418046  92.953  -65.989  54.817  1
418047  93.002  -65.991  54.802  1
418048  93.051  -65.991  54.788  1
418049  93.100  -65.993  54.769  1
418050  93.148  -65.993  54.750  1
418051  93.196  -65.986  54.732  1
418052  93.243  -65.979  54.714  1
418053  93.291  -65.972  54.702  1
418054  93.339  -65.966  54.693  1
418055  93.386  -65.959  54.686  1
418056  93.429  -65.956  54.677  1
418057  93.467  -65.955  54.665  1
418058  93.511  -65.955  54.648  1
418059  93.556  -65.955  54.630  1
418060  93.600  -65.955  54.610  1
418061  93.645  -65.955  54.591  1
418062  93.689  -65.954  54.576  1
418063  93.733  -65.954  54.562  1
418064  93.778  -65.954  54.548  1
418065  93.823  -65.956  54.533  1
418066  93.866  -65.963  54.514  1
418067  93.909  -65.970  54.492  1
418068  93.952  -65.976  54.469  1
418069  93.992  -65.981  54.443  1
418070  94.031  -65.987  54.415  1
418071  94.071  -65.992  54.385  1
418072  94.110  -65.997  54.354  1
418073  94.150  -66.001  54.324  1
418074  94.189  -66.005  54.294  1
418075  94.229  -66.008  54.265  1
418076  94.268  -66.012  54.235  1
418077  94.308  -66.016  54.204  1
418078  94.346  -66.019  54.171  1
418079  94.364  -66.036  54.138  1
418080  94.383  -66.053  54.104  1
418081  94.413  -66.063  54.072  1
418082  94.449  -66.070  54.040  1
418083  94.484  -66.078  54.011  1
418084  94.519  -66.085  53.984  1
418085  94.554  -66.093  53.965  1
418086  94.590  -66.100  53.950  1
418087  94.625  -66.108  53.939  1
418088  94.660  -66.115  53.930  1
418089  94.695  -66.122  53.924  1
418090  94.731  -66.130  53.916  1
418091  94.766  -66.138  53.905  1
418092  94.800  -66.142  53.891  1
418093  94.834  -66.144  53.875  1
418094  94.871  -66.151  53.857  1
418095  94.906  -66.162  53.840  1
418096  94.934  -66.166  53.820  1
418097  94.972  -66.169  53.798  1
418098  95.011  -66.172  53.774  1
418099  95.049  -66.174  53.748  1
418100  95.088  -66.176  53.717  1
418101  95.127  -66.179  53.683  1
418102  95.168  -66.179  53.648  1
418103  95.209  -66.179  53.614  1
418104  95.249  -66.180  53.581  1
418105  95.288  -66.184  53.554  1
418106  95.326  -66.190  53.527  1
418107  95.363  -66.197  53.501  1
418108  95.400  -66.203  53.480  1
418109  95.437  -66.210  53.464  1
418110  95.474  -66.216  53.454  1
418111  95.513  -66.222  53.446  1
418112  95.555  -66.226  53.436  1
418113  95.596  -66.222  53.422  1
418114  95.643  -66.218  53.404  1
418115  95.690  -66.215  53.383  1
418116  95.738  -66.211  53.361  1
418117  95.785  -66.208  53.337  1
418118  95.832  -66.204  53.312  1
418119  95.879  -66.201  53.287  1
418120  95.924  -66.197  53.262  1
418121  95.967  -66.191  53.236  1
418122  96.009  -66.185  53.210  1
418123  96.050  -66.180  53.186  1
418124  96.093  -66.174  53.163  1
418125  96.134  -66.168  53.140  1
418126  96.177  -66.163  53.117  1
418127  96.219  -66.157  53.094  1
418128  96.262  -66.152  53.073  1
418129  96.305  -66.147  53.051  1
418130  96.348  -66.144  53.029  1
418131  96.386  -66.141  53.005  1
418132  96.424  -66.138  52.979  1
418133  96.462  -66.135  52.949  1
418134  96.499  -66.132  52.916  1
418135  96.533  -66.129  52.882  1
418136  96.567  -66.127  52.847  1
418137  96.601  -66.124  52.818  1
418138  96.635  -66.121  52.791  1
418139  96.671  -66.123  52.764  1
418140  96.711  -66.129  52.735  1
418141  96.750  -66.135  52.703  1
418142  96.790  -66.141  52.667  1
418143  96.830  -66.147  52.629  1
418144  96.871  -66.152  52.587  1
418145  96.915  -66.154  52.543  1
418146  96.959  -66.156  52.500  1
418147  97.001  -66.163  52.460  1
418148  97.042  -66.173  52.424  1
418149  97.082  -66.184  52.392  1
418150  97.123  -66.194  52.362  1
418151  97.161  -66.201  52.330  1
418152  97.198  -66.207  52.299  1
418153  97.236  -66.214  52.271  1
418154  97.273  -66.220  52.245  1
418155  97.310  -66.227  52.217  1
418156  97.347  -66.234  52.186  1
418157  97.384  -66.241  52.154  1
418158  97.421  -66.247  52.121  1
418159  97.459  -66.252  52.088  1
418160  97.498  -66.260  52.054  1
418161  97.537  -66.272  52.020  1
418162  97.575  -66.280  51.986  1
418163  97.613  -66.288  51.953  1
418164  97.652  -66.297  51.922  1
418165  97.690  -66.304  51.890  1
418166  97.729  -66.313  51.854  1
418167  97.767  -66.321  51.814  1
418168  97.805  -66.329  51.772  1
418169  97.840  -66.335  51.729  1
418170  97.873  -66.339  51.682  1
418171  97.906  -66.343  51.637  1
418172  97.939  -66.347  51.593  1
418173  97.972  -66.351  51.549  1
418174  98.005  -66.356  51.507  1
418175  98.038  -66.360  51.462  1
418176  98.071  -66.364  51.417  1
418177  98.104  -66.368  51.371  1
418178  98.137  -66.373  51.323  1
418179  98.162  -66.380  51.272  1
418180  98.184  -66.389  51.220  1
418181  98.207  -66.397  51.168  1
418182  98.230  -66.405  51.117  1
418183  98.263  -66.406  51.067  1
418184  98.298  -66.406  51.023  1
418185  98.333  -66.406  50.977  1
418186  98.368  -66.406  50.931  1
418187  98.403  -66.406  50.887  1
418188  98.439  -66.409  50.843  1
418189  98.482  -66.411  50.798  1
418190  98.524  -66.414  50.754  1
418191  98.566  -66.416  50.710  1
418192  98.607  -66.418  50.667  1
418193  98.648  -66.421  50.628  1
418194  98.690  -66.424  50.587  1
418195  98.730  -66.426  50.543  1
418196  98.772  -66.429  50.497  1
418197  98.817  -66.434  50.447  1
418198  98.868  -66.442  50.395  1
418199  98.910  -66.451  50.341  1
418200  98.944  -66.461  50.285  1
418201  98.979  -66.470  50.228  1
418202  99.013  -66.480  50.170  1
418203  99.050  -66.493  50.113  1
418204  99.087  -66.507  50.058  1
418205  99.125  -66.521  50.003  1
418206  99.163  -66.535  49.948  1
418207  99.205  -66.535  49.892  1
418208  99.247  -66.535  49.835  1
418209  99.289  -66.536  49.779  1
418210  99.332  -66.536  49.724  1
418211  99.374  -66.536  49.670  1
418212  99.416  -66.536  49.615  1
418213  99.458  -66.537  49.559  1
418214  99.501  -66.542  49.504  1
418215  99.544  -66.548  49.449  1
418216  99.578  -66.546  49.395  1
418217  99.590  -66.550  49.341  1
418218  99.602  -66.556  49.288  1
418219  99.626  -66.567  49.235  1
418220  99.687  -66.589  49.182  1
418221  99.733  -66.598  49.130  1
418222  99.779  -66.606  49.079  1
418223  99.826  -66.615  49.028  1
418224  99.871  -66.624  48.979  1
418225  99.911  -66.633  48.931  1
418226  99.931  -66.641  48.884  1
418227  99.959  -66.645  48.838  1
418228  99.998  -66.643  48.793  1
418229  100.038  -66.640  48.749  1
418230  100.080  -66.639  48.706  1
418231  100.129  -66.636  48.664  1
418232  100.177  -66.634  48.622  1
418233  100.225  -66.632  48.580  1
418234  100.273  -66.630  48.538  1
418235  100.322  -66.628  48.497  1
418236  100.370  -66.626  48.457  1
418658  88.820  -65.526  55.144  1
418659  88.854  -65.536  55.131  1
418660  88.888  -65.545  55.120  1
418661  88.922  -65.555  55.108  1
418662  88.957  -65.564  55.098  1
418663  88.991  -65.574  55.088  1
418664  89.035  -65.579  55.079  1
418665  89.082  -65.583  55.070  1
418666  89.128  -65.586  55.060  1
418667  89.174  -65.590  55.050  1
418668  89.220  -65.594  55.039  1
418669  89.266  -65.598  55.027  1
418670  89.312  -65.602  55.017  1
418671  89.358  -65.606  55.006  1
418672  89.405  -65.610  54.995  1
418673  89.451  -65.614  54.984  1
418674  89.497  -65.618  54.973  1
418675  89.543  -65.622  54.962  1
418676  89.590  -65.626  54.952  1
418677  89.641  -65.618  54.945  1
418692  90.421  -65.686  54.965  1
418693  90.469  -65.692  54.967  1
418694  90.518  -65.698  54.969  1
418695  90.566  -65.704  54.972  1
418696  90.615  -65.710  54.975  1
418697  90.663  -65.716  54.976  1
418698  90.712  -65.723  54.976  1
418699  90.760  -65.729  54.977  1
418700  90.808  -65.735  54.976  1
418701  90.857  -65.741  54.974  1
418702  90.905  -65.747  54.972  1
418703  90.954  -65.753  54.970  1
418704  91.002  -65.759  54.967  1
418705  91.050  -65.766  54.964  1
418706  91.096  -65.778  54.962  1
418707  91.142  -65.789  54.960  1
418708  91.188  -65.800  54.959  1
418709  91.234  -65.812  54.958  1
418710  91.280  -65.823  54.959  1
418711  91.325  -65.835  54.960  1
418712  91.370  -65.847  54.963  1
418713  91.413  -65.857  54.967  1
418714  91.456  -65.868  54.973  1
418715  91.499  -65.878  54.978  1
418716  91.542  -65.889  54.987  1
418717  91.585  -65.900  55.000  1
418718  91.628  -65.906  55.014  1
418719  91.672  -65.909  55.026  1
418720  91.716  -65.913  55.032  1
418721  91.759  -65.916  55.031  1
418722  91.803  -65.920  55.033  1
418723  91.847  -65.923  55.035  1
418724  91.881  -65.937  55.038  1
418725  91.924  -65.947  55.040  1
418726  91.972  -65.953  55.039  1
418727  92.020  -65.958  55.036  1
418728  92.069  -65.966  55.034  1
418729  92.118  -65.975  55.033  1
418730  92.166  -65.985  55.030  1
418731  92.214  -65.995  55.027  1
418732  92.263  -66.004  55.025  1
418733  92.311  -66.014  55.022  1
418734  92.359  -66.024  55.017  1
418735  92.405  -66.024  55.009  1
418736  92.449  -66.016  55.002  1
418737  92.493  -66.006  54.992  1
418738  92.536  -65.998  54.981  1
418739  92.580  -65.989  54.969  1
418740  92.624  -65.981  54.952  1
418741  92.668  -65.972  54.933  1
418742  92.712  -65.963  54.914  1
418743  92.758  -65.959  54.895  1
418744  92.806  -65.960  54.875  1
418745  92.855  -65.962  54.856  1
418746  92.904  -65.963  54.837  1
418747  92.953  -65.964  54.819  1
418748  93.002  -65.966  54.803  1
418749  93.051  -65.967  54.788  1
418750  93.099  -65.968  54.772  1
418751  93.147  -65.961  54.757  1
418752  93.195  -65.954  54.744  1
418753  93.242  -65.948  54.730  1
418754  93.290  -65.941  54.722  1
418755  93.338  -65.934  54.717  1
418756  93.385  -65.928  54.713  1
418757  93.431  -65.922  54.707  1
418758  93.472  -65.922  54.696  1
418759  93.516  -65.922  54.679  1
418760  93.561  -65.922  54.659  1
418761  93.605  -65.921  54.638  1
418762  93.649  -65.921  54.617  1
418763  93.694  -65.921  54.600  1
418764  93.739  -65.921  54.586  1
418765  93.783  -65.921  54.572  1
418766  93.828  -65.920  54.556  1
418767  93.871  -65.925  54.536  1
418768  93.915  -65.931  54.514  1
418769  93.957  -65.937  54.492  1
418770  93.996  -65.943  54.467  1
418771  94.036  -65.948  54.438  1
418772  94.075  -65.952  54.407  1
418773  94.115  -65.956  54.376  1
418774  94.154  -65.959  54.345  1
418775  94.194  -65.963  54.315  1
418776  94.233  -65.966  54.287  1
418777  94.273  -65.970  54.255  1
418778  94.312  -65.973  54.222  1
418779  94.337  -65.986  54.189  1
418780  94.355  -66.002  54.156  1
418781  94.374  -66.019  54.124  1
418782  94.407  -66.028  54.091  1
418783  94.442  -66.035  54.060  1
418784  94.477  -66.043  54.030  1
418785  94.512  -66.050  54.003  1
418786  94.548  -66.057  53.985  1
418787  94.583  -66.065  53.972  1
418788  94.618  -66.072  53.962  1
418789  94.653  -66.080  53.954  1
418790  94.689  -66.088  53.948  1
418791  94.724  -66.095  53.940  1
418792  94.759  -66.103  53.929  1
418793  94.794  -66.110  53.915  1
418794  94.830  -66.117  53.899  1
418795  94.864  -66.122  53.882  1
418796  94.901  -66.130  53.863  1
418797  94.932  -66.135  53.841  1
418798  94.971  -66.137  53.817  1
418799  95.010  -66.139  53.792  1
418800  95.051  -66.140  53.762  1
418801  95.092  -66.141  53.731  1
418802  95.132  -66.141  53.698  1
418803  95.173  -66.141  53.663  1
418804  95.213  -66.142  53.628  1
418805  95.254  -66.143  53.594  1
418806  95.293  -66.147  53.566  1
418807  95.330  -66.153  53.539  1
418808  95.368  -66.160  53.513  1
418809  95.405  -66.166  53.491  1
418810  95.442  -66.172  53.476  1
418811  95.482  -66.177  53.466  1
418812  95.524  -66.182  53.459  1
418813  95.565  -66.186  53.451  1
418814  95.607  -66.184  53.439  1
418815  95.648  -66.179  53.421  1
418816  95.693  -66.175  53.399  1
418817  95.740  -66.171  53.376  1
418818  95.788  -66.168  53.351  1
418819  95.835  -66.164  53.325  1
418820  95.882  -66.161  53.299  1
418821  95.929  -66.157  53.273  1
418822  95.971  -66.152  53.247  1
418823  96.013  -66.146  53.220  1
418824  96.055  -66.140  53.196  1
418825  96.097  -66.135  53.173  1
418826  96.139  -66.129  53.150  1
418827  96.181  -66.122  53.127  1
418828  96.223  -66.117  53.104  1
418829  96.265  -66.111  53.082  1
418830  96.307  -66.106  53.059  1
418831  96.347  -66.100  53.037  1
418832  96.385  -66.097  53.014  1
418833  96.424  -66.094  52.988  1
418834  96.461  -66.091  52.959  1
418835  96.500  -66.088  52.927  1
418836  96.535  -66.085  52.892  1
418837  96.569  -66.083  52.856  1
418838  96.602  -66.080  52.825  1
418839  96.638  -66.081  52.796  1
418840  96.678  -66.087  52.767  1
418841  96.718  -66.093  52.737  1
418842  96.757  -66.099  52.704  1
418843  96.797  -66.105  52.668  1
418844  96.837  -66.111  52.631  1
418845  96.876  -66.117  52.590  1
418846  96.920  -66.120  52.548  1
418847  96.964  -66.122  52.507  1
418848  97.006  -66.130  52.467  1
418849  97.046  -66.140  52.431  1
418850  97.087  -66.150  52.399  1
418851  97.125  -66.158  52.368  1
418852  97.162  -66.164  52.336  1
418853  97.199  -66.171  52.304  1
418854  97.237  -66.177  52.273  1
418855  97.274  -66.184  52.243  1
418856  97.311  -66.191  52.215  1
418857  97.348  -66.197  52.184  1
418858  97.385  -66.204  52.152  1
418859  97.422  -66.210  52.122  1
418860  97.459  -66.217  52.092  1
418861  97.498  -66.225  52.060  1
418862  97.536  -66.233  52.025  1
418863  97.574  -66.241  51.990  1
418864  97.612  -66.250  51.956  1
418865  97.651  -66.258  51.925  1
418866  97.689  -66.266  51.893  1
418867  97.727  -66.274  51.858  1
418868  97.766  -66.282  51.820  1
418869  97.803  -66.290  51.779  1
418870  97.837  -66.295  51.736  1
418871  97.870  -66.298  51.690  1
418872  97.903  -66.303  51.645  1
418873  97.936  -66.307  51.600  1
418874  97.969  -66.311  51.555  1
418875  98.002  -66.316  51.510  1
418876  98.035  -66.320  51.463  1
418877  98.068  -66.324  51.416  1
418878  98.101  -66.328  51.368  1
418879  98.134  -66.332  51.319  1
418880  98.165  -66.338  51.267  1
418881  98.187  -66.346  51.215  1
418882  98.210  -66.354  51.164  1
418883  98.233  -66.363  51.115  1
418884  98.268  -66.363  51.067  1
418885  98.303  -66.362  51.023  1
418886  98.338  -66.362  50.977  1
418887  98.372  -66.362  50.932  1
418888  98.409  -66.366  50.887  1
418889  98.445  -66.369  50.842  1
418890  98.487  -66.371  50.796  1
418891  98.529  -66.373  50.750  1
418892  98.572  -66.376  50.704  1
418893  98.615  -66.378  50.659  1
418894  98.658  -66.379  50.619  1
418895  98.700  -66.382  50.578  1
418896  98.741  -66.385  50.536  1
418897  98.782  -66.388  50.490  1
418898  98.823  -66.391  50.442  1
418899  98.875  -66.398  50.391  1
418900  98.909  -66.408  50.338  1
418901  98.943  -66.418  50.283  1
418902  98.980  -66.431  50.225  1
418903  99.018  -66.445  50.166  1
418904  99.056  -66.460  50.108  1
418905  99.093  -66.474  50.052  1
418906  99.131  -66.489  49.996  1
418907  99.168  -66.503  49.941  1
418908  99.210  -66.505  49.884  1
418909  99.252  -66.505  49.828  1
418910  99.294  -66.505  49.772  1
418911  99.337  -66.505  49.718  1
418912  99.379  -66.506  49.663  1
418913  99.421  -66.506  49.609  1
418914  99.464  -66.506  49.554  1
418915  99.505  -66.507  49.499  1
418916  99.548  -66.507  49.444  1
418917  99.581  -66.505  49.391  1
418918  99.593  -66.511  49.337  1
418919  99.606  -66.516  49.284  1
418920  99.638  -66.530  49.231  1
418921  99.691  -66.545  49.179  1
418922  99.737  -66.553  49.126  1
418923  99.783  -66.562  49.075  1
418924  99.829  -66.571  49.025  1
418925  99.875  -66.580  48.976  1
418926  99.916  -66.589  48.928  1
418927  99.936  -66.596  48.882  1
418928  99.968  -66.599  48.836  1
418929  100.008  -66.596  48.791  1
418930  100.047  -66.595  48.747  1
418931  100.095  -66.592  48.704  1
418932  100.143  -66.590  48.662  1
418933  100.191  -66.588  48.620  1
418934  100.240  -66.586  48.578  1
418935  100.288  -66.584  48.536  1
418936  100.336  -66.582  48.495  1
418937  100.384  -66.580  48.455  1
419356  88.709  -65.449  55.192  1
419357  88.744  -65.458  55.177  1
419358  88.778  -65.468  55.164  1
419359  88.812  -65.477  55.151  1
419360  88.846  -65.487  55.139  1
419361  88.881  -65.497  55.128  1
419362  88.915  -65.506  55.117  1
419363  88.949  -65.516  55.107  1
419364  88.991  -65.521  55.098  1
419365  89.038  -65.525  55.090  1
419366  89.084  -65.530  55.080  1
419367  89.130  -65.533  55.070  1
419368  89.176  -65.537  55.060  1
419369  89.223  -65.541  55.049  1
419370  89.268  -65.545  55.038  1
419371  89.315  -65.549  55.027  1
419372  89.361  -65.553  55.016  1
419373  89.407  -65.557  55.005  1
419374  89.453  -65.561  54.993  1
419375  89.499  -65.564  54.982  1
419376  89.545  -65.568  54.970  1
419377  89.593  -65.571  54.960  1
419378  89.649  -65.553  54.951  1
419379  89.705  -65.542  54.944  1
419392  90.371  -65.630  54.963  1
419393  90.419  -65.637  54.966  1
419394  90.468  -65.643  54.970  1
419395  90.517  -65.649  54.972  1
419396  90.565  -65.655  54.974  1
419397  90.613  -65.662  54.976  1
419398  90.662  -65.668  54.977  1
419399  90.711  -65.674  54.977  1
419400  90.759  -65.680  54.976  1
419401  90.807  -65.686  54.975  1
419402  90.856  -65.692  54.973  1
419403  90.904  -65.699  54.971  1
419404  90.953  -65.705  54.967  1
419405  91.001  -65.711  54.964  1
419406  91.048  -65.719  54.960  1
419407  91.094  -65.731  54.957  1
419408  91.140  -65.742  54.954  1
419409  91.186  -65.753  54.952  1
419410  91.232  -65.765  54.950  1
419411  91.277  -65.776  54.949  1
419412  91.323  -65.787  54.950  1
419413  91.366  -65.799  54.952  1
419414  91.410  -65.809  54.955  1
419415  91.452  -65.820  54.959  1
419416  91.495  -65.831  54.964  1
419417  91.538  -65.842  54.972  1
419418  91.581  -65.853  54.983  1
419419  91.624  -65.863  54.996  1
419420  91.667  -65.867  55.008  1
419421  91.711  -65.871  55.014  1
419422  91.755  -65.874  55.016  1
419423  91.798  -65.878  55.020  1
419424  91.837  -65.887  55.025  1
419425  91.871  -65.901  55.030  1
419426  91.914  -65.911  55.033  1
419427  91.962  -65.916  55.034  1
419428  92.010  -65.922  55.033  1
419429  92.059  -65.928  55.032  1
419430  92.107  -65.934  55.031  1
419431  92.156  -65.944  55.028  1
419432  92.204  -65.953  55.025  1
419433  92.252  -65.963  55.021  1
419434  92.301  -65.972  55.016  1
419435  92.349  -65.982  55.007  1
419436  92.394  -65.978  54.998  1
419437  92.438  -65.969  54.989  1
419438  92.481  -65.960  54.980  1
419439  92.525  -65.951  54.970  1
419440  92.569  -65.943  54.960  1
419441  92.613  -65.934  54.944  1
419442  92.660  -65.931  54.928  1
419443  92.709  -65.933  54.911  1
419444  92.758  -65.934  54.893  1
419445  92.806  -65.936  54.874  1
419446  92.855  -65.937  54.856  1
419447  92.904  -65.938  54.837  1
419448  92.953  -65.940  54.820  1
419449  93.002  -65.941  54.804  1
419450  93.051  -65.943  54.791  1
419451  93.098  -65.937  54.779  1
419452  93.146  -65.930  54.768  1
419453  93.194  -65.923  54.758  1
419454  93.241  -65.916  54.748  1
419455  93.289  -65.910  54.741  1
419456  93.336  -65.903  54.738  1
419457  93.383  -65.897  54.736  1
419458  93.431  -65.890  54.732  1
419459  93.477  -65.888  54.723  1
419460  93.521  -65.887  54.707  1
419461  93.565  -65.887  54.687  1
419462  93.610  -65.887  54.666  1
419463  93.654  -65.887  54.644  1
419464  93.699  -65.887  54.624  1
419465  93.744  -65.887  54.609  1
419466  93.788  -65.887  54.594  1
419467  93.833  -65.887  54.579  1
419468  93.877  -65.887  54.560  1
419469  93.921  -65.894  54.539  1
419470  93.961  -65.899  54.515  1
419471  94.000  -65.903  54.489  1
419472  94.040  -65.906  54.460  1
419473  94.079  -65.910  54.429  1
419474  94.119  -65.914  54.396  1
419475  94.158  -65.917  54.366  1
419476  94.198  -65.921  54.337  1
419477  94.238  -65.925  54.309  1
419478  94.277  -65.928  54.275  1
419479  94.310  -65.935  54.240  1
419480  94.328  -65.952  54.206  1
419481  94.347  -65.969  54.175  1
419482  94.365  -65.984  54.142  1
419483  94.401  -65.992  54.110  1
419484  94.436  -66.000  54.080  1
419485  94.471  -66.007  54.050  1
419486  94.506  -66.015  54.024  1
419487  94.541  -66.022  54.007  1
419488  94.576  -66.030  53.996  1
419489  94.612  -66.038  53.986  1
419490  94.647  -66.045  53.980  1
419491  94.682  -66.052  53.976  1
419492  94.717  -66.060  53.967  1
419493  94.753  -66.067  53.956  1
419494  94.788  -66.075  53.942  1
419495  94.823  -66.082  53.925  1
419496  94.858  -66.090  53.908  1
419497  94.894  -66.097  53.888  1
419498  94.933  -66.100  53.865  1
419499  94.974  -66.101  53.838  1
419500  95.015  -66.101  53.809  1
419501  95.055  -66.102  53.777  1
419502  95.096  -66.103  53.743  1
419503  95.137  -66.103  53.709  1
419504  95.178  -66.104  53.674  1
419505  95.218  -66.104  53.639  1
419506  95.259  -66.105  53.606  1
419507  95.298  -66.110  53.576  1
419508  95.335  -66.116  53.548  1
419509  95.372  -66.122  53.523  1
419510  95.410  -66.129  53.502  1
419511  95.452  -66.133  53.489  1
419512  95.493  -66.138  53.480  1
419513  95.535  -66.142  53.473  1
419514  95.577  -66.147  53.465  1
419515  95.618  -66.146  53.452  1
419516  95.659  -66.141  53.434  1
419517  95.699  -66.135  53.413  1
419518  95.743  -66.131  53.389  1
419519  95.791  -66.128  53.363  1
419520  95.838  -66.124  53.337  1
419521  95.885  -66.121  53.310  1
419522  95.932  -66.117  53.283  1
419523  95.975  -66.112  53.256  1
419524  96.018  -66.107  53.227  1
419525  96.059  -66.100  53.203  1
419526  96.102  -66.095  53.180  1
419527  96.144  -66.089  53.158  1
419528  96.185  -66.083  53.136  1
419529  96.228  -66.078  53.112  1
419530  96.269  -66.072  53.089  1
419531  96.311  -66.068  53.066  1
419532  96.350  -66.063  53.043  1
419533  96.387  -66.057  53.020  1
419534  96.423  -66.051  52.994  1
419535  96.461  -66.047  52.966  1
419536  96.499  -66.044  52.934  1
419537  96.536  -66.041  52.899  1
419538  96.570  -66.039  52.864  1
419539  96.605  -66.038  52.831  1
419540  96.645  -66.044  52.800  1
419541  96.685  -66.050  52.770  1
419542  96.725  -66.056  52.740  1
419543  96.764  -66.063  52.706  1
419544  96.804  -66.069  52.671  1
419545  96.843  -66.075  52.633  1
419546  96.883  -66.082  52.594  1
419547  96.925  -66.086  52.553  1
419548  96.969  -66.088  52.515  1
419549  97.010  -66.097  52.476  1
419550  97.050  -66.107  52.439  1
419551  97.089  -66.115  52.405  1
419552  97.126  -66.121  52.375  1
419553  97.164  -66.128  52.343  1
419554  97.201  -66.134  52.311  1
419555  97.238  -66.141  52.277  1
419556  97.276  -66.147  52.243  1
419557  97.312  -66.154  52.213  1
419558  97.350  -66.160  52.182  1
419559  97.386  -66.167  52.151  1
419560  97.424  -66.173  52.123  1
419561  97.460  -66.180  52.097  1
419562  97.496  -66.186  52.066  1
419563  97.534  -66.194  52.031  1
419564  97.573  -66.203  51.994  1
419565  97.611  -66.211  51.959  1
419566  97.650  -66.219  51.926  1
419567  97.688  -66.227  51.895  1
419568  97.726  -66.235  51.861  1
419569  97.764  -66.244  51.825  1
419570  97.801  -66.251  51.784  1
419571  97.833  -66.254  51.742  1
419572  97.867  -66.259  51.697  1
419573  97.900  -66.263  51.652  1
419574  97.933  -66.267  51.605  1
419575  97.966  -66.271  51.559  1
419576  97.999  -66.276  51.511  1
419577  98.032  -66.279  51.463  1
419578  98.065  -66.284  51.413  1
419579  98.098  -66.288  51.363  1
419580  98.132  -66.292  51.314  1
419581  98.164  -66.297  51.262  1
419582  98.191  -66.304  51.211  1
419583  98.213  -66.312  51.162  1
419584  98.238  -66.319  51.115  1
419585  98.273  -66.319  51.069  1
419586  98.307  -66.319  51.024  1
419587  98.343  -66.319  50.978  1
419588  98.379  -66.322  50.932  1
419589  98.415  -66.326  50.886  1
419590  98.451  -66.329  50.840  1
419591  98.492  -66.332  50.794  1
419592  98.534  -66.333  50.746  1
419593  98.577  -66.335  50.697  1
419594  98.620  -66.338  50.649  1
419595  98.663  -66.340  50.607  1
419596  98.706  -66.342  50.566  1
419597  98.748  -66.344  50.524  1
419598  98.791  -66.346  50.480  1
419599  98.833  -66.348  50.435  1
419600  98.874  -66.356  50.385  1
419601  98.911  -66.370  50.334  1
419602  98.948  -66.384  50.279  1
419603  98.986  -66.398  50.222  1
419604  99.024  -66.413  50.163  1
419605  99.061  -66.427  50.103  1
419606  99.099  -66.442  50.045  1
419607  99.137  -66.455  49.988  1
419608  99.174  -66.470  49.932  1
419609  99.215  -66.475  49.876  1
419610  99.257  -66.475  49.821  1
419611  99.299  -66.476  49.765  1
419612  99.342  -66.476  49.711  1
419613  99.383  -66.476  49.657  1
419614  99.426  -66.476  49.603  1
419615  99.468  -66.476  49.549  1
419616  99.510  -66.470  49.494  1
419617  99.552  -66.466  49.439  1
419618  99.578  -66.467  49.387  1
419619  99.597  -66.470  49.333  1
419620  99.609  -66.476  49.280  1
419621  99.648  -66.492  49.228  1
419622  99.694  -66.500  49.176  1
419623  99.740  -66.509  49.123  1
419624  99.787  -66.518  49.071  1
419625  99.833  -66.527  49.022  1
419626  99.879  -66.536  48.974  1
419627  99.922  -66.545  48.926  1
419628  99.942  -66.552  48.880  1
419629  99.977  -66.552  48.834  1
419630  100.017  -66.551  48.789  1
419631  100.061  -66.549  48.745  1
419632  100.109  -66.546  48.703  1
419633  100.157  -66.544  48.660  1
419634  100.206  -66.542  48.618  1
419635  100.254  -66.540  48.576  1
419636  100.302  -66.538  48.535  1
419637  100.350  -66.536  48.493  1
419638  100.399  -66.534  48.453  1
420055  88.633  -65.381  55.230  1
420056  88.667  -65.391  55.213  1
420057  88.701  -65.400  55.196  1
420058  88.736  -65.410  55.183  1
420059  88.770  -65.420  55.170  1
420060  88.804  -65.429  55.158  1
420061  88.838  -65.439  55.148  1
420062  88.873  -65.449  55.138  1
420063  88.907  -65.458  55.128  1
420064  88.948  -65.464  55.118  1
420065  88.994  -65.468  55.109  1
420066  89.040  -65.472  55.101  1
420067  89.086  -65.476  55.092  1
420068  89.132  -65.480  55.082  1
420069  89.179  -65.484  55.072  1
420070  89.225  -65.488  55.061  1
420071  89.271  -65.492  55.049  1
420072  89.317  -65.496  55.038  1
420073  89.363  -65.499  55.027  1
420074  89.409  -65.503  55.015  1
420075  89.456  -65.508  55.004  1
420076  89.502  -65.511  54.991  1
420077  89.548  -65.515  54.979  1
420078  89.600  -65.506  54.968  1
420079  89.657  -65.489  54.959  1
420080  89.712  -65.492  54.951  1
420093  90.370  -65.581  54.965  1
420094  90.418  -65.587  54.968  1
420095  90.467  -65.594  54.971  1
420096  90.515  -65.600  54.974  1
420097  90.564  -65.606  54.976  1
420098  90.612  -65.612  54.978  1
420099  90.661  -65.618  54.979  1
420100  90.709  -65.624  54.978  1
420101  90.757  -65.630  54.977  1
420102  90.806  -65.637  54.976  1
420103  90.855  -65.643  54.973  1
420104  90.903  -65.649  54.969  1
420105  90.951  -65.655  54.964  1
420106  91.000  -65.662  54.959  1
420107  91.046  -65.671  54.955  1
420108  91.092  -65.684  54.951  1
420109  91.138  -65.695  54.947  1
420110  91.183  -65.706  54.944  1
420111  91.229  -65.718  54.942  1
420112  91.275  -65.729  54.940  1
420113  91.319  -65.740  54.940  1
420114  91.363  -65.751  54.941  1
420115  91.405  -65.762  54.943  1
420116  91.448  -65.773  54.947  1
420117  91.491  -65.784  54.951  1
420118  91.534  -65.794  54.958  1
420119  91.577  -65.805  54.967  1
420120  91.620  -65.815  54.978  1
420121  91.663  -65.825  54.988  1
420122  91.707  -65.828  54.994  1
420123  91.750  -65.832  54.999  1
420124  91.793  -65.837  55.004  1
420125  91.827  -65.851  55.009  1
420126  91.862  -65.865  55.015  1
420127  91.903  -65.875  55.019  1
420128  91.952  -65.881  55.022  1
420129  92.000  -65.886  55.022  1
420130  92.049  -65.892  55.022  1
420131  92.097  -65.897  55.023  1
420132  92.145  -65.903  55.022  1
420133  92.194  -65.912  55.019  1
420134  92.242  -65.922  55.014  1
420135  92.291  -65.931  55.008  1
420136  92.339  -65.939  54.998  1
420137  92.382  -65.931  54.987  1
420138  92.426  -65.922  54.977  1
420139  92.470  -65.913  54.967  1
420140  92.514  -65.904  54.958  1
420141  92.562  -65.904  54.949  1
420142  92.611  -65.906  54.935  1
420143  92.659  -65.907  54.921  1
420144  92.708  -65.909  54.906  1
420145  92.757  -65.910  54.889  1
420146  92.806  -65.911  54.871  1
420147  92.855  -65.912  54.854  1
420148  92.904  -65.914  54.836  1
420149  92.953  -65.916  54.820  1
420150  93.002  -65.917  54.807  1
420151  93.050  -65.912  54.795  1
420152  93.097  -65.905  54.787  1
420153  93.145  -65.898  54.779  1
420154  93.192  -65.892  54.772  1
420155  93.240  -65.885  54.764  1
420156  93.287  -65.878  54.760  1
420157  93.335  -65.872  54.758  1
420158  93.383  -65.866  54.756  1
420159  93.432  -65.862  54.753  1
420160  93.476  -65.862  54.745  1
420161  93.520  -65.862  54.731  1
420162  93.566  -65.861  54.713  1
420163  93.611  -65.859  54.692  1
420164  93.656  -65.859  54.670  1
420165  93.701  -65.857  54.649  1
420166  93.747  -65.856  54.632  1
420167  93.791  -65.855  54.617  1
420168  93.837  -65.854  54.600  1
420169  93.882  -65.853  54.583  1
420170  93.925  -65.854  54.561  1
420171  93.965  -65.858  54.536  1
420172  94.004  -65.862  54.509  1
420173  94.044  -65.865  54.480  1
420174  94.083  -65.868  54.448  1
420175  94.123  -65.872  54.418  1
420176  94.163  -65.875  54.387  1
420177  94.202  -65.879  54.357  1
420178  94.242  -65.882  54.326  1
420179  94.281  -65.886  54.293  1
420180  94.301  -65.902  54.258  1
420181  94.320  -65.918  54.224  1
420182  94.338  -65.934  54.191  1
420183  94.359  -65.950  54.157  1
420184  94.394  -65.957  54.126  1
420185  94.429  -65.965  54.096  1
420186  94.465  -65.972  54.069  1
420187  94.500  -65.980  54.045  1
420188  94.535  -65.987  54.031  1
420189  94.570  -65.994  54.021  1
420190  94.606  -66.002  54.014  1
420191  94.641  -66.010  54.009  1
420192  94.676  -66.017  54.005  1
420193  94.711  -66.025  53.998  1
420194  94.747  -66.032  53.986  1
420195  94.781  -66.040  53.972  1
420196  94.817  -66.047  53.955  1
420197  94.856  -66.051  53.935  1
420198  94.896  -66.056  53.915  1
420199  94.938  -66.057  53.890  1
420200  94.979  -66.060  53.860  1
420201  95.020  -66.062  53.826  1
420202  95.060  -66.064  53.791  1
420203  95.101  -66.066  53.755  1
420204  95.142  -66.066  53.719  1
420205  95.183  -66.066  53.683  1
420206  95.224  -66.067  53.648  1
420207  95.264  -66.068  53.615  1
420208  95.302  -66.072  53.585  1
420209  95.339  -66.079  53.557  1
420210  95.380  -66.084  53.533  1
420211  95.421  -66.088  53.513  1
420212  95.463  -66.093  53.502  1
420213  95.505  -66.097  53.494  1
420214  95.546  -66.102  53.487  1
420215  95.588  -66.107  53.478  1
420216  95.629  -66.108  53.465  1
420217  95.670  -66.103  53.448  1
420218  95.710  -66.097  53.426  1
420219  95.751  -66.092  53.401  1
420220  95.794  -66.087  53.375  1
420221  95.841  -66.084  53.348  1
420222  95.888  -66.081  53.320  1
420223  95.935  -66.077  53.292  1
420224  95.980  -66.072  53.264  1
420225  96.022  -66.067  53.235  1
420226  96.064  -66.061  53.210  1
420227  96.106  -66.055  53.187  1
420228  96.148  -66.050  53.165  1
420229  96.190  -66.044  53.143  1
420230  96.232  -66.038  53.119  1
420231  96.273  -66.035  53.095  1
420232  96.315  -66.031  53.072  1
420233  96.354  -66.026  53.048  1
420234  96.390  -66.020  53.023  1
420235  96.427  -66.014  52.995  1
420236  96.463  -66.008  52.967  1
420237  96.500  -66.003  52.936  1
420238  96.537  -65.997  52.903  1
420239  96.573  -65.996  52.870  1
420240  96.612  -66.002  52.837  1
420241  96.652  -66.008  52.805  1
420242  96.691  -66.014  52.775  1
420243  96.731  -66.020  52.745  1
420244  96.771  -66.026  52.712  1
420245  96.811  -66.033  52.677  1
420246  96.850  -66.039  52.640  1
420247  96.890  -66.045  52.601  1
420248  96.930  -66.051  52.561  1
420249  96.973  -66.053  52.523  1
420250  97.014  -66.063  52.484  1
420251  97.053  -66.072  52.447  1
420252  97.090  -66.078  52.412  1
420253  97.128  -66.085  52.380  1
420254  97.165  -66.091  52.349  1
420255  97.203  -66.097  52.317  1
420256  97.240  -66.103  52.284  1
420257  97.277  -66.110  52.248  1
420258  97.314  -66.116  52.214  1
420259  97.351  -66.123  52.181  1
420260  97.388  -66.130  52.152  1
420261  97.425  -66.137  52.125  1
420262  97.461  -66.143  52.100  1
420263  97.497  -66.149  52.069  1
420264  97.533  -66.156  52.035  1
420265  97.572  -66.164  51.999  1
420266  97.610  -66.172  51.963  1
420267  97.648  -66.180  51.928  1
420268  97.686  -66.188  51.897  1
420269  97.725  -66.197  51.864  1
420270  97.763  -66.205  51.827  1
420271  97.798  -66.210  51.788  1
420272  97.830  -66.214  51.746  1
420273  97.864  -66.219  51.701  1
420274  97.897  -66.223  51.655  1
420275  97.930  -66.227  51.608  1
420276  97.963  -66.231  51.560  1
420277  97.996  -66.235  51.510  1
420278  98.029  -66.239  51.460  1
420279  98.062  -66.244  51.410  1
420280  98.095  -66.248  51.359  1
420281  98.129  -66.252  51.309  1
420282  98.161  -66.257  51.259  1
420283  98.193  -66.261  51.210  1
420284  98.216  -66.270  51.163  1
420285  98.243  -66.275  51.118  1
420286  98.278  -66.275  51.071  1
420287  98.312  -66.276  51.025  1
420288  98.349  -66.279  50.979  1
420289  98.385  -66.282  50.932  1
420290  98.421  -66.285  50.886  1
420291  98.457  -66.288  50.839  1
420292  98.497  -66.292  50.790  1
420293  98.539  -66.294  50.742  1
420294  98.582  -66.296  50.692  1
420295  98.625  -66.298  50.641  1
420296  98.668  -66.300  50.593  1
420297  98.711  -66.302  50.550  1
420298  98.754  -66.304  50.506  1
420299  98.796  -66.306  50.464  1
420300  98.839  -66.310  50.422  1
420301  98.879  -66.318  50.376  1
420302  98.917  -66.335  50.326  1
420303  98.954  -66.351  50.273  1
420304  98.992  -66.366  50.217  1
420305  99.029  -66.379  50.159  1
420306  99.067  -66.394  50.100  1
420307  99.105  -66.408  50.041  1
420308  99.142  -66.423  49.983  1
420309  99.180  -66.437  49.925  1
420310  99.220  -66.445  49.869  1
420311  99.262  -66.445  49.814  1
420312  99.304  -66.445  49.759  1
420313  99.346  -66.445  49.705  1
420314  99.389  -66.445  49.651  1
420315  99.430  -66.440  49.597  1
420316  99.472  -66.435  49.544  1
420317  99.513  -66.429  49.490  1
420318  99.554  -66.425  49.436  1
420319  99.574  -66.429  49.383  1
420320  99.595  -66.432  49.330  1
420321  99.613  -66.436  49.278  1
420322  99.652  -66.447  49.226  1
420323  99.698  -66.456  49.173  1
420324  99.745  -66.465  49.120  1
420325  99.790  -66.473  49.069  1
420326  99.837  -66.483  49.020  1
420327  99.883  -66.492  48.972  1
420328  99.927  -66.501  48.925  1
420329  99.947  -66.508  48.878  1
420330  99.986  -66.507  48.833  1
420331  100.027  -66.505  48.788  1
420332  100.075  -66.502  48.744  1
420333  100.124  -66.500  48.702  1
420334  100.172  -66.498  48.658  1
420335  100.220  -66.496  48.616  1
420336  100.268  -66.494  48.575  1
420337  100.317  -66.492  48.533  1
420338  100.365  -66.490  48.491  1
420339  100.413  -66.488  48.452  1
420753  88.522  -65.304  55.283  1
420754  88.556  -65.314  55.265  1
420755  88.591  -65.323  55.249  1
420756  88.625  -65.333  55.234  1
420757  88.659  -65.342  55.218  1
420758  88.693  -65.352  55.203  1
420759  88.728  -65.361  55.189  1
420760  88.762  -65.371  55.177  1
420761  88.796  -65.381  55.166  1
420762  88.830  -65.390  55.158  1
420763  88.864  -65.400  55.149  1
420764  88.904  -65.407  55.140  1
420765  88.950  -65.411  55.130  1
420766  88.996  -65.415  55.121  1
420767  89.042  -65.419  55.113  1
420768  89.089  -65.423  55.105  1
420769  89.134  -65.427  55.095  1
420770  89.181  -65.430  55.084  1
420771  89.227  -65.435  55.074  1
420772  89.273  -65.439  55.061  1
420773  89.319  -65.442  55.050  1
420774  89.366  -65.446  55.039  1
420775  89.412  -65.450  55.027  1
420776  89.458  -65.454  55.016  1
420777  89.504  -65.458  55.002  1
420778  89.551  -65.459  54.989  1
420779  89.608  -65.442  54.978  1
420780  89.664  -65.438  54.968  1
420781  89.720  -65.442  54.959  1
420782  89.775  -65.447  54.951  1
420793  90.320  -65.527  54.960  1
420794  90.369  -65.533  54.966  1
420795  90.417  -65.539  54.970  1
420796  90.466  -65.545  54.972  1
420797  90.514  -65.551  54.975  1
420798  90.563  -65.557  54.978  1
420799  90.611  -65.563  54.979  1
420800  90.660  -65.570  54.979  1
420801  90.708  -65.576  54.979  1
420802  90.756  -65.582  54.979  1
420803  90.805  -65.588  54.977  1
420804  90.854  -65.594  54.972  1
420805  90.902  -65.600  54.967  1
420806  90.950  -65.606  54.962  1
420807  90.999  -65.613  54.956  1
420808  91.044  -65.624  54.951  1
420809  91.090  -65.636  54.946  1
420810  91.136  -65.648  54.942  1
420811  91.181  -65.659  54.938  1
420812  91.227  -65.671  54.935  1
420813  91.273  -65.682  54.932  1
420814  91.316  -65.693  54.929  1
420815  91.359  -65.703  54.930  1
420816  91.401  -65.715  54.932  1
420817  91.444  -65.725  54.935  1
420818  91.488  -65.736  54.938  1
420819  91.530  -65.746  54.944  1
420820  91.573  -65.757  54.951  1
420821  91.616  -65.768  54.959  1
420822  91.659  -65.779  54.968  1
420823  91.702  -65.786  54.974  1
420824  91.746  -65.790  54.980  1
420825  91.784  -65.800  54.986  1
420826  91.818  -65.815  54.991  1
420827  91.852  -65.829  54.996  1
420828  91.893  -65.839  55.001  1
420829  91.941  -65.844  55.004  1
420830  91.990  -65.850  55.006  1
420831  92.038  -65.856  55.008  1
420832  92.087  -65.862  55.010  1
420833  92.135  -65.867  55.011  1
420834  92.183  -65.873  55.009  1
420835  92.232  -65.880  55.003  1
420836  92.281  -65.890  54.996  1
420837  92.327  -65.893  54.985  1
420838  92.371  -65.884  54.973  1
420839  92.415  -65.875  54.962  1
420840  92.464  -65.877  54.953  1
420841  92.513  -65.878  54.944  1
420842  92.562  -65.880  54.936  1
420843  92.611  -65.881  54.923  1
420844  92.659  -65.883  54.910  1
420845  92.708  -65.884  54.897  1
420846  92.757  -65.885  54.883  1
420847  92.806  -65.887  54.868  1
420848  92.855  -65.888  54.853  1
420849  92.904  -65.890  54.838  1
420850  92.952  -65.891  54.824  1
420851  93.001  -65.887  54.812  1
420852  93.048  -65.881  54.803  1
420853  93.096  -65.874  54.796  1
420854  93.143  -65.867  54.791  1
420855  93.191  -65.860  54.785  1
420856  93.238  -65.854  54.779  1
420857  93.287  -65.848  54.776  1
420858  93.336  -65.844  54.774  1
420859  93.384  -65.840  54.772  1
420860  93.431  -65.837  54.769  1
420861  93.475  -65.837  54.764  1
420862  93.519  -65.837  54.751  1
420863  93.564  -65.837  54.735  1
420864  93.609  -65.835  54.716  1
420865  93.654  -65.834  54.694  1
420866  93.699  -65.834  54.673  1
420867  93.745  -65.832  54.655  1
420868  93.790  -65.831  54.638  1
420869  93.835  -65.830  54.621  1
420870  93.880  -65.829  54.603  1
420871  93.925  -65.824  54.580  1
420872  93.969  -65.816  54.554  1
420873  94.008  -65.819  54.526  1
420874  94.048  -65.823  54.497  1
420875  94.087  -65.827  54.466  1
420876  94.127  -65.830  54.436  1
420877  94.167  -65.834  54.405  1
420878  94.206  -65.837  54.373  1
420879  94.246  -65.840  54.342  1
420880  94.274  -65.851  54.309  1
420881  94.292  -65.868  54.275  1
420882  94.311  -65.884  54.242  1
420883  94.329  -65.900  54.209  1
420884  94.352  -65.914  54.175  1
420885  94.388  -65.922  54.144  1
420886  94.423  -65.929  54.115  1
420887  94.458  -65.937  54.088  1
420888  94.493  -65.944  54.067  1
420889  94.529  -65.952  54.054  1
420890  94.564  -65.959  54.046  1
420891  94.599  -65.967  54.042  1
420892  94.634  -65.975  54.038  1
420893  94.670  -65.982  54.035  1
420894  94.705  -65.989  54.027  1
420895  94.740  -65.997  54.016  1
420896  94.780  -66.001  54.001  1
420897  94.820  -66.005  53.983  1
420898  94.859  -66.009  53.962  1
420899  94.900  -66.012  53.939  1
420900  94.943  -66.013  53.911  1
420901  94.984  -66.016  53.879  1
420902  95.025  -66.018  53.843  1
420903  95.065  -66.021  53.803  1
420904  95.106  -66.023  53.764  1
420905  95.147  -66.025  53.727  1
420906  95.187  -66.028  53.692  1
420907  95.228  -66.030  53.656  1
420908  95.269  -66.030  53.623  1
420909  95.308  -66.035  53.592  1
420910  95.349  -66.040  53.564  1
420911  95.391  -66.044  53.541  1
420912  95.432  -66.049  53.525  1
420913  95.474  -66.053  53.516  1
420914  95.516  -66.058  53.509  1
420915  95.557  -66.063  53.500  1
420916  95.599  -66.067  53.489  1
420917  95.640  -66.070  53.479  1
420918  95.681  -66.065  53.461  1
420919  95.722  -66.060  53.439  1
420920  95.762  -66.054  53.414  1
420921  95.803  -66.049  53.387  1
420922  95.844  -66.044  53.359  1
420923  95.891  -66.040  53.329  1
420924  95.938  -66.037  53.299  1
420925  95.984  -66.033  53.271  1
420926  96.026  -66.027  53.242  1
420927  96.068  -66.022  53.217  1
420928  96.110  -66.016  53.195  1
420929  96.153  -66.010  53.172  1
420930  96.194  -66.005  53.150  1
420931  96.236  -66.001  53.127  1
420932  96.277  -65.998  53.102  1
420933  96.319  -65.994  53.077  1
420934  96.358  -65.989  53.051  1
420935  96.394  -65.983  53.024  1
420936  96.431  -65.977  52.995  1
420937  96.467  -65.972  52.965  1
420938  96.503  -65.966  52.935  1
420939  96.542  -65.958  52.904  1
420940  96.578  -65.959  52.872  1
420941  96.617  -65.966  52.840  1
420942  96.658  -65.972  52.808  1
420943  96.697  -65.978  52.778  1
420944  96.738  -65.984  52.748  1
420945  96.778  -65.991  52.717  1
420946  96.817  -65.997  52.682  1
420947  96.857  -66.003  52.646  1
420948  96.897  -66.009  52.608  1
420949  96.937  -66.015  52.569  1
420950  96.978  -66.019  52.531  1
420951  97.017  -66.028  52.492  1
420952  97.054  -66.035  52.454  1
420953  97.092  -66.041  52.418  1
420954  97.129  -66.047  52.385  1
420955  97.166  -66.054  52.353  1
420956  97.204  -66.060  52.322  1
420957  97.241  -66.067  52.288  1
420958  97.278  -66.073  52.253  1
420959  97.315  -66.080  52.217  1
420960  97.352  -66.087  52.184  1
420961  97.389  -66.093  52.154  1
420962  97.425  -66.100  52.126  1
420963  97.461  -66.106  52.101  1
420964  97.497  -66.112  52.071  1
420965  97.533  -66.118  52.037  1
420966  97.571  -66.125  52.002  1
420967  97.609  -66.133  51.966  1
420968  97.647  -66.141  51.931  1
420969  97.685  -66.150  51.899  1
420970  97.724  -66.158  51.865  1
420971  97.761  -66.166  51.829  1
420972  97.795  -66.170  51.790  1
420973  97.828  -66.174  51.747  1
420974  97.861  -66.179  51.702  1
420975  97.894  -66.182  51.656  1
420976  97.927  -66.187  51.607  1
420977  97.960  -66.191  51.558  1
420978  97.993  -66.195  51.506  1
420979  98.026  -66.200  51.456  1
420980  98.059  -66.204  51.406  1
420981  98.092  -66.208  51.356  1
420982  98.126  -66.212  51.307  1
420983  98.159  -66.216  51.259  1
420984  98.192  -66.220  51.211  1
420985  98.219  -66.227  51.166  1
420986  98.247  -66.232  51.120  1
420987  98.283  -66.232  51.072  1
420988  98.319  -66.235  51.025  1
420989  98.355  -66.238  50.978  1
420990  98.391  -66.242  50.932  1
420991  98.428  -66.245  50.885  1
420992  98.464  -66.249  50.836  1
420993  98.502  -66.252  50.787  1
420994  98.545  -66.254  50.737  1
420995  98.588  -66.256  50.686  1
420996  98.631  -66.258  50.634  1
420997  98.673  -66.260  50.583  1
420998  98.716  -66.262  50.535  1
420999  98.759  -66.265  50.489  1
421000  98.801  -66.270  50.444  1
421001  98.844  -66.274  50.402  1
421002  98.885  -66.281  50.356  1
421003  98.923  -66.293  50.309  1
421004  98.961  -66.310  50.257  1
421005  98.998  -66.326  50.203  1
421006  99.035  -66.343  50.147  1
421007  99.073  -66.360  50.091  1
421008  99.111  -66.376  50.035  1
421009  99.148  -66.390  49.978  1
421010  99.186  -66.404  49.921  1
421011  99.224  -66.415  49.866  1
421012  99.267  -66.415  49.813  1
421013  99.309  -66.414  49.758  1
421014  99.351  -66.409  49.703  1
421015  99.392  -66.404  49.649  1
421016  99.434  -66.399  49.595  1
421017  99.476  -66.394  49.541  1
421018  99.517  -66.389  49.487  1
421019  99.550  -66.387  49.433  1
421020  99.571  -66.391  49.380  1
421021  99.591  -66.394  49.328  1
421022  99.615  -66.398  49.275  1
421023  99.655  -66.403  49.223  1
421024  99.702  -66.412  49.171  1
421025  99.748  -66.420  49.119  1
421026  99.794  -66.429  49.068  1
421027  99.841  -66.439  49.019  1
421028  99.887  -66.448  48.972  1
421029  99.933  -66.456  48.924  1
421030  99.956  -66.463  48.877  1
421031  99.996  -66.461  48.832  1
421032  100.042  -66.458  48.787  1
421033  100.090  -66.456  48.743  1
421034  100.138  -66.454  48.700  1
421035  100.186  -66.452  48.657  1
421036  100.234  -66.450  48.615  1
421037  100.283  -66.448  48.574  1
421038  100.331  -66.446  48.532  1
421039  100.379  -66.444  48.490  1
421040  100.427  -66.442  48.451  1
421451  88.412  -65.227  55.341  1
421452  88.446  -65.236  55.321  1
421453  88.480  -65.246  55.302  1
421454  88.515  -65.256  55.283  1
421455  88.549  -65.265  55.267  1
421456  88.583  -65.275  55.253  1
421457  88.617  -65.284  55.239  1
421458  88.651  -65.294  55.224  1
421459  88.686  -65.304  55.211  1
421460  88.720  -65.313  55.198  1
421461  88.754  -65.323  55.187  1
421462  88.788  -65.333  55.177  1
421463  88.823  -65.342  55.168  1
421464  88.860  -65.350  55.162  1
421465  88.906  -65.354  55.153  1
421466  88.952  -65.358  55.144  1
421467  88.998  -65.361  55.134  1
421468  89.045  -65.366  55.127  1
421469  89.091  -65.370  55.118  1
421470  89.137  -65.373  55.108  1
421471  89.183  -65.377  55.098  1
421472  89.229  -65.381  55.087  1
421473  89.275  -65.385  55.074  1
421474  89.322  -65.389  55.063  1
421475  89.368  -65.393  55.051  1
421476  89.414  -65.397  55.040  1
421477  89.460  -65.401  55.028  1
421478  89.506  -65.405  55.013  1
421479  89.559  -65.395  55.000  1
421480  89.616  -65.384  54.987  1
421481  89.671  -65.389  54.977  1
421482  89.727  -65.393  54.967  1
421483  89.782  -65.397  54.958  1
421494  90.319  -65.477  54.961  1
421495  90.368  -65.483  54.966  1
421496  90.416  -65.489  54.971  1
421497  90.465  -65.496  54.974  1
421498  90.513  -65.502  54.976  1
421499  90.561  -65.508  54.979  1
421500  90.610  -65.514  54.980  1
421501  90.658  -65.521  54.980  1
421502  90.707  -65.527  54.980  1
421503  90.755  -65.533  54.979  1
421504  90.804  -65.539  54.977  1
421505  90.852  -65.546  54.971  1
421506  90.900  -65.552  54.965  1
421507  90.949  -65.558  54.959  1
421508  90.997  -65.566  54.954  1
421509  91.042  -65.577  54.947  1
421510  91.088  -65.589  54.941  1
421511  91.134  -65.600  54.936  1
421512  91.179  -65.612  54.931  1
421513  91.225  -65.624  54.927  1
421514  91.269  -65.634  54.923  1
421515  91.312  -65.645  54.921  1
421516  91.355  -65.656  54.921  1
421517  91.397  -65.667  54.922  1
421518  91.441  -65.677  54.924  1
421519  91.484  -65.688  54.927  1
421520  91.526  -65.699  54.932  1
421521  91.569  -65.710  54.938  1
421522  91.612  -65.721  54.946  1
421523  91.655  -65.731  54.953  1
421524  91.698  -65.742  54.960  1
421525  91.739  -65.749  54.964  1
421526  91.774  -65.764  54.968  1
421527  91.808  -65.778  54.971  1
421528  91.843  -65.793  54.974  1
421529  91.883  -65.803  54.978  1
421530  91.931  -65.809  54.981  1
421531  91.980  -65.814  54.986  1
421532  92.028  -65.820  54.990  1
421533  92.077  -65.825  54.993  1
421534  92.125  -65.831  54.995  1
421535  92.173  -65.837  54.994  1
421536  92.222  -65.843  54.989  1
421537  92.271  -65.848  54.982  1
421538  92.317  -65.848  54.970  1
421539  92.366  -65.850  54.957  1
421540  92.415  -65.851  54.947  1
421541  92.463  -65.853  54.938  1
421542  92.513  -65.854  54.929  1
421543  92.562  -65.856  54.922  1
421544  92.611  -65.856  54.911  1
421545  92.659  -65.858  54.900  1
421546  92.708  -65.859  54.889  1
421547  92.757  -65.861  54.877  1
421548  92.806  -65.862  54.864  1
421549  92.855  -65.864  54.851  1
421550  92.904  -65.865  54.839  1
421551  92.952  -65.862  54.827  1
421552  92.999  -65.856  54.819  1
421553  93.047  -65.849  54.812  1
421554  93.094  -65.842  54.808  1
421555  93.142  -65.836  54.803  1
421556  93.190  -65.830  54.798  1
421557  93.239  -65.826  54.791  1
421558  93.288  -65.821  54.787  1
421559  93.337  -65.817  54.785  1
421560  93.386  -65.812  54.783  1
421561  93.430  -65.812  54.781  1
421562  93.474  -65.812  54.777  1
421563  93.518  -65.812  54.767  1
421564  93.562  -65.812  54.753  1
421565  93.607  -65.812  54.736  1
421566  93.652  -65.810  54.717  1
421567  93.698  -65.809  54.697  1
421568  93.743  -65.809  54.679  1
421569  93.788  -65.807  54.659  1
421570  93.833  -65.806  54.638  1
421571  93.878  -65.805  54.617  1
421572  93.924  -65.799  54.594  1
421573  93.970  -65.784  54.568  1
421574  94.013  -65.778  54.541  1
421575  94.052  -65.781  54.514  1
421576  94.092  -65.784  54.483  1
421577  94.131  -65.788  54.451  1
421578  94.171  -65.791  54.419  1
421579  94.210  -65.795  54.387  1
421580  94.247  -65.801  54.356  1
421581  94.265  -65.817  54.325  1
421582  94.283  -65.834  54.293  1
421583  94.301  -65.850  54.261  1
421584  94.320  -65.867  54.228  1
421585  94.346  -65.879  54.195  1
421586  94.382  -65.887  54.163  1
421587  94.417  -65.894  54.134  1
421588  94.452  -65.902  54.108  1
421589  94.487  -65.909  54.089  1
421590  94.522  -65.916  54.077  1
421591  94.557  -65.924  54.070  1
421592  94.593  -65.931  54.067  1
421593  94.628  -65.939  54.066  1
421594  94.664  -65.947  54.063  1
421595  94.703  -65.950  54.056  1
421596  94.743  -65.954  54.044  1
421597  94.783  -65.958  54.028  1
421598  94.823  -65.963  54.008  1
421599  94.862  -65.966  53.985  1
421600  94.904  -65.969  53.959  1
421601  94.947  -65.970  53.929  1
421602  94.988  -65.972  53.895  1
421603  95.029  -65.975  53.856  1
421604  95.070  -65.977  53.815  1
421605  95.111  -65.979  53.774  1
421606  95.151  -65.981  53.735  1
421607  95.192  -65.984  53.699  1
421608  95.233  -65.987  53.663  1
421609  95.274  -65.990  53.629  1
421610  95.318  -65.994  53.598  1
421611  95.360  -66.000  53.571  1
421612  95.402  -66.004  53.550  1
421613  95.444  -66.009  53.538  1
421614  95.485  -66.013  53.531  1
421615  95.527  -66.018  53.524  1
421616  95.568  -66.022  53.515  1
421617  95.610  -66.027  53.504  1
421618  95.651  -66.031  53.491  1
421619  95.692  -66.028  53.474  1
421620  95.733  -66.022  53.452  1
421621  95.774  -66.016  53.427  1
421622  95.815  -66.011  53.399  1
421623  95.855  -66.006  53.369  1
421624  95.896  -66.000  53.338  1
421625  95.941  -65.997  53.308  1
421626  95.988  -65.993  53.280  1
421627  96.031  -65.988  53.251  1
421628  96.073  -65.981  53.226  1
421629  96.115  -65.976  53.202  1
421630  96.157  -65.972  53.179  1
421631  96.198  -65.969  53.157  1
421632  96.240  -65.965  53.133  1
421633  96.282  -65.961  53.108  1
421634  96.323  -65.957  53.081  1
421635  96.361  -65.952  53.053  1
421636  96.398  -65.946  53.023  1
421637  96.434  -65.941  52.992  1
421638  96.471  -65.934  52.961  1
421639  96.512  -65.925  52.930  1
421640  96.553  -65.916  52.899  1
421641  96.589  -65.918  52.868  1
421642  96.620  -65.930  52.838  1
421643  96.660  -65.936  52.807  1
421644  96.700  -65.942  52.777  1
421645  96.740  -65.948  52.749  1
421646  96.781  -65.954  52.719  1
421647  96.821  -65.960  52.685  1
421648  96.861  -65.966  52.650  1
421649  96.901  -65.972  52.613  1
421650  96.942  -65.979  52.576  1
421651  96.981  -65.984  52.538  1
421652  97.019  -65.991  52.499  1
421653  97.056  -65.998  52.460  1
421654  97.093  -66.004  52.422  1
421655  97.131  -66.011  52.388  1
421656  97.168  -66.017  52.356  1
421657  97.205  -66.024  52.325  1
421658  97.242  -66.030  52.292  1
421659  97.280  -66.037  52.257  1
421660  97.316  -66.043  52.221  1
421661  97.354  -66.050  52.187  1
421662  97.389  -66.056  52.155  1
421663  97.426  -66.062  52.127  1
421664  97.461  -66.069  52.101  1
421665  97.498  -66.075  52.070  1
421666  97.533  -66.081  52.038  1
421667  97.570  -66.087  52.003  1
421668  97.607  -66.094  51.968  1
421669  97.646  -66.103  51.933  1
421670  97.684  -66.111  51.901  1
421671  97.723  -66.119  51.866  1
421672  97.758  -66.125  51.829  1
421673  97.792  -66.130  51.789  1
421674  97.825  -66.135  51.746  1
421675  97.858  -66.138  51.701  1
421676  97.891  -66.143  51.654  1
421677  97.924  -66.147  51.605  1
421678  97.957  -66.151  51.555  1
421679  97.990  -66.155  51.502  1
421680  98.023  -66.160  51.452  1
421681  98.057  -66.163  51.404  1
421682  98.089  -66.168  51.356  1
421683  98.123  -66.172  51.307  1
421684  98.156  -66.176  51.260  1
421685  98.189  -66.181  51.214  1
421686  98.222  -66.185  51.168  1
421687  98.252  -66.188  51.121  1
421688  98.289  -66.191  51.073  1
421689  98.325  -66.195  51.024  1
421690  98.361  -66.198  50.978  1
421691  98.397  -66.202  50.931  1
421692  98.434  -66.205  50.882  1
421693  98.470  -66.209  50.833  1
421694  98.507  -66.212  50.783  1
421695  98.550  -66.214  50.731  1
421696  98.593  -66.216  50.679  1
421697  98.636  -66.218  50.626  1
421698  98.678  -66.220  50.573  1
421699  98.721  -66.225  50.523  1
421700  98.764  -66.229  50.474  1
421701  98.807  -66.234  50.427  1
421702  98.850  -66.238  50.381  1
421703  98.890  -66.245  50.335  1
421704  98.929  -66.252  50.288  1
421705  98.967  -66.268  50.239  1
421706  99.004  -66.285  50.187  1
421707  99.042  -66.301  50.135  1
421708  99.079  -66.318  50.082  1
421709  99.117  -66.335  50.028  1
421710  99.154  -66.351  49.974  1
421711  99.192  -66.368  49.919  1
421712  99.229  -66.382  49.866  1
421713  99.271  -66.378  49.814  1
421714  99.312  -66.373  49.759  1
421715  99.354  -66.368  49.705  1
421716  99.396  -66.363  49.650  1
421717  99.437  -66.358  49.595  1
421718  99.479  -66.353  49.541  1
421719  99.521  -66.348  49.486  1
421720  99.547  -66.349  49.432  1
421721  99.567  -66.353  49.378  1
421722  99.592  -66.356  49.326  1
421723  99.631  -66.361  49.274  1
421724  99.670  -66.364  49.222  1
421725  99.710  -66.370  49.170  1
421726  99.752  -66.376  49.119  1
421727  99.798  -66.386  49.068  1
421728  99.844  -66.394  49.019  1
421729  99.891  -66.403  48.972  1
421730  99.937  -66.412  48.924  1
421731  99.965  -66.417  48.877  1
421732  100.008  -66.414  48.831  1
421733  100.056  -66.412  48.786  1
421734  100.104  -66.411  48.741  1
421735  100.152  -66.408  48.699  1
421736  100.201  -66.406  48.657  1
421737  100.249  -66.404  48.615  1
421738  100.297  -66.402  48.573  1
421739  100.345  -66.400  48.531  1
421740  100.394  -66.398  48.490  1
421741  100.442  -66.395  48.450  1
422152  88.404  -65.179  55.335  1
422153  88.438  -65.188  55.317  1
422154  88.472  -65.198  55.300  1
422155  88.506  -65.207  55.283  1
422156  88.541  -65.217  55.269  1
422157  88.575  -65.226  55.256  1
422158  88.609  -65.236  55.244  1
422159  88.643  -65.245  55.231  1
422160  88.678  -65.255  55.220  1
422161  88.712  -65.265  55.208  1
422162  88.746  -65.274  55.199  1
422163  88.780  -65.284  55.190  1
422164  88.816  -65.293  55.182  1
422165  88.862  -65.297  55.175  1
422166  88.908  -65.301  55.168  1
422167  88.955  -65.304  55.159  1
422168  89.000  -65.308  55.150  1
422169  89.047  -65.312  55.142  1
422170  89.093  -65.317  55.132  1
422171  89.139  -65.320  55.123  1
422172  89.185  -65.324  55.112  1
422173  89.232  -65.328  55.099  1
422174  89.278  -65.332  55.088  1
422175  89.324  -65.336  55.076  1
422176  89.370  -65.340  55.064  1
422177  89.416  -65.344  55.052  1
422178  89.462  -65.348  55.039  1
422179  89.511  -65.348  55.025  1
422180  89.567  -65.330  55.011  1
422181  89.623  -65.335  54.997  1
422182  89.678  -65.339  54.986  1
422183  89.734  -65.343  54.975  1
422184  89.785  -65.351  54.965  1
422185  89.833  -65.361  54.957  1
422195  90.318  -65.428  54.962  1
422196  90.367  -65.434  54.967  1
422197  90.415  -65.441  54.971  1
422198  90.463  -65.447  54.975  1
422199  90.512  -65.453  54.978  1
422200  90.561  -65.459  54.980  1
422201  90.609  -65.465  54.982  1
422202  90.657  -65.471  54.981  1
422203  90.706  -65.477  54.980  1
422204  90.754  -65.484  54.978  1
422205  90.803  -65.490  54.974  1
422206  90.851  -65.496  54.968  1
422207  90.899  -65.502  54.963  1
422208  90.948  -65.508  54.957  1
422209  90.994  -65.519  54.950  1
422210  91.040  -65.530  54.943  1
422211  91.086  -65.542  54.937  1
422212  91.132  -65.553  54.930  1
422213  91.177  -65.564  54.925  1
422214  91.222  -65.576  54.920  1
422215  91.265  -65.586  54.915  1
422216  91.308  -65.598  54.913  1
422217  91.351  -65.608  54.913  1
422218  91.394  -65.619  54.913  1
422219  91.437  -65.630  54.914  1
422220  91.480  -65.640  54.916  1
422221  91.522  -65.652  54.921  1
422222  91.565  -65.662  54.927  1
422223  91.608  -65.673  54.933  1
422224  91.651  -65.684  54.941  1
422225  91.694  -65.696  54.949  1
422226  91.732  -65.712  54.954  1
422227  91.764  -65.727  54.957  1
422228  91.799  -65.742  54.958  1
422229  91.833  -65.756  54.959  1
422230  91.873  -65.767  54.960  1
422231  91.921  -65.773  54.961  1
422232  91.969  -65.778  54.964  1
422233  92.018  -65.784  54.969  1
422234  92.066  -65.790  54.972  1
422235  92.115  -65.795  54.975  1
422236  92.163  -65.801  54.974  1
422237  92.214  -65.803  54.970  1
422238  92.264  -65.805  54.964  1
422239  92.315  -65.815  54.954  1
422240  92.366  -65.825  54.941  1
422241  92.415  -65.827  54.930  1
422242  92.463  -65.828  54.921  1
422243  92.512  -65.829  54.914  1
422244  92.561  -65.831  54.908  1
422245  92.610  -65.832  54.899  1
422246  92.659  -65.834  54.890  1
422247  92.708  -65.835  54.881  1
422248  92.757  -65.837  54.871  1
422249  92.806  -65.837  54.859  1
422250  92.855  -65.839  54.848  1
422251  92.903  -65.837  54.838  1
422252  92.950  -65.831  54.829  1
422253  92.998  -65.824  54.825  1
422254  93.046  -65.818  54.821  1
422255  93.094  -65.812  54.818  1
422256  93.142  -65.807  54.815  1
422257  93.191  -65.803  54.809  1
422258  93.240  -65.799  54.803  1
422259  93.289  -65.794  54.798  1
422260  93.338  -65.790  54.795  1
422261  93.386  -65.786  54.793  1
422262  93.430  -65.787  54.791  1
422263  93.474  -65.787  54.788  1
422264  93.517  -65.787  54.779  1
422265  93.561  -65.787  54.767  1
422266  93.605  -65.787  54.752  1
422267  93.650  -65.787  54.736  1
422268  93.696  -65.785  54.718  1
422269  93.741  -65.784  54.698  1
422270  93.786  -65.783  54.678  1
422271  93.831  -65.782  54.655  1
422272  93.876  -65.781  54.632  1
422273  93.922  -65.774  54.607  1
422274  93.968  -65.759  54.581  1
422275  94.014  -65.744  54.554  1
422276  94.057  -65.739  54.527  1
422277  94.096  -65.743  54.496  1
422278  94.136  -65.746  54.464  1
422279  94.175  -65.749  54.432  1
422280  94.215  -65.753  54.402  1
422281  94.238  -65.767  54.375  1
422282  94.256  -65.784  54.345  1
422283  94.274  -65.800  54.314  1
422284  94.293  -65.816  54.282  1
422285  94.311  -65.833  54.248  1
422286  94.340  -65.844  54.214  1
422287  94.375  -65.851  54.183  1
422288  94.410  -65.859  54.154  1
422289  94.445  -65.866  54.130  1
422290  94.481  -65.874  54.111  1
422291  94.516  -65.881  54.099  1
422292  94.551  -65.889  54.092  1
422293  94.587  -65.896  54.090  1
422294  94.627  -65.900  54.090  1
422295  94.667  -65.903  54.090  1
422296  94.706  -65.908  54.083  1
422297  94.746  -65.912  54.070  1
422298  94.786  -65.916  54.052  1
422299  94.826  -65.920  54.029  1
422300  94.865  -65.924  54.004  1
422301  94.908  -65.925  53.977  1
422302  94.951  -65.926  53.945  1
422303  94.993  -65.928  53.908  1
422304  95.034  -65.931  53.868  1
422305  95.075  -65.933  53.826  1
422306  95.115  -65.935  53.784  1
422307  95.156  -65.938  53.744  1
422308  95.197  -65.941  53.706  1
422309  95.238  -65.943  53.670  1
422310  95.281  -65.950  53.636  1
422311  95.323  -65.949  53.605  1
422312  95.367  -65.956  53.579  1
422313  95.411  -65.963  53.560  1
422314  95.454  -65.969  53.550  1
422315  95.496  -65.974  53.544  1
422316  95.538  -65.978  53.538  1
422317  95.579  -65.983  53.530  1
422318  95.621  -65.988  53.519  1
422319  95.662  -65.992  53.506  1
422320  95.703  -65.990  53.488  1
422321  95.744  -65.984  53.466  1
422322  95.785  -65.979  53.440  1
422323  95.826  -65.974  53.410  1
422324  95.867  -65.968  53.380  1
422325  95.907  -65.963  53.349  1
422326  95.948  -65.957  53.318  1
422327  95.991  -65.953  53.289  1
422328  96.035  -65.948  53.260  1
422329  96.077  -65.943  53.235  1
422330  96.119  -65.939  53.210  1
422331  96.161  -65.935  53.186  1
422332  96.202  -65.931  53.164  1
422333  96.244  -65.928  53.140  1
422334  96.286  -65.925  53.114  1
422335  96.327  -65.921  53.085  1
422336  96.365  -65.915  53.055  1
422337  96.401  -65.909  53.022  1
422338  96.442  -65.901  52.990  1
422339  96.483  -65.892  52.957  1
422340  96.524  -65.884  52.924  1
422341  96.565  -65.875  52.892  1
422342  96.601  -65.876  52.861  1
422343  96.631  -65.888  52.830  1
422344  96.663  -65.900  52.801  1
422345  96.702  -65.906  52.772  1
422346  96.743  -65.912  52.743  1
422347  96.783  -65.918  52.712  1
422348  96.823  -65.925  52.679  1
422349  96.864  -65.931  52.644  1
422350  96.904  -65.937  52.608  1
422351  96.944  -65.943  52.571  1
422352  96.983  -65.948  52.535  1
422353  97.021  -65.954  52.496  1
422354  97.058  -65.960  52.457  1
422355  97.095  -65.967  52.421  1
422356  97.132  -65.974  52.386  1
422357  97.169  -65.981  52.354  1
422358  97.206  -65.987  52.324  1
422359  97.243  -65.994  52.292  1
422360  97.281  -66.000  52.256  1
422361  97.318  -66.006  52.221  1
422362  97.354  -66.013  52.187  1
422363  97.390  -66.019  52.154  1
422364  97.426  -66.025  52.124  1
422365  97.462  -66.031  52.097  1
422366  97.498  -66.037  52.065  1
422367  97.534  -66.044  52.033  1
422368  97.570  -66.050  52.000  1
422369  97.606  -66.056  51.966  1
422370  97.645  -66.064  51.933  1
422371  97.683  -66.072  51.901  1
422372  97.721  -66.081  51.864  1
422373  97.755  -66.086  51.825  1
422374  97.789  -66.090  51.784  1
422375  97.822  -66.094  51.740  1
422376  97.855  -66.098  51.696  1
422377  97.888  -66.103  51.650  1
422378  97.921  -66.107  51.602  1
422379  97.954  -66.111  51.552  1
422380  97.987  -66.115  51.501  1
422381  98.020  -66.119  51.452  1
422382  98.054  -66.123  51.406  1
422383  98.086  -66.128  51.360  1
422384  98.120  -66.132  51.312  1
422385  98.153  -66.136  51.263  1
422386  98.187  -66.141  51.216  1
422387  98.222  -66.145  51.169  1
422388  98.262  -66.154  51.122  1
422389  98.296  -66.154  51.073  1
422390  98.332  -66.155  51.024  1
422391  98.368  -66.158  50.976  1
422392  98.404  -66.162  50.928  1
422393  98.440  -66.165  50.877  1
422394  98.477  -66.169  50.827  1
422395  98.513  -66.172  50.775  1
422396  98.555  -66.174  50.723  1
422397  98.598  -66.176  50.670  1
422398  98.641  -66.180  50.618  1
422399  98.684  -66.185  50.565  1
422400  98.726  -66.189  50.513  1
422401  98.769  -66.193  50.463  1
422402  98.812  -66.198  50.416  1
422403  98.855  -66.202  50.366  1
422404  98.895  -66.209  50.318  1
422405  98.934  -66.216  50.269  1
422406  98.974  -66.226  50.221  1
422407  99.011  -66.242  50.172  1
422408  99.048  -66.259  50.123  1
422409  99.086  -66.276  50.072  1
422410  99.123  -66.293  50.022  1
422411  99.160  -66.310  49.971  1
422412  99.198  -66.326  49.921  1
422413  99.237  -66.331  49.869  1
422414  99.277  -66.332  49.817  1
422415  99.316  -66.332  49.763  1
422416  99.358  -66.327  49.708  1
422417  99.400  -66.322  49.653  1
422418  99.441  -66.317  49.598  1
422419  99.483  -66.312  49.543  1
422420  99.522  -66.308  49.488  1
422421  99.543  -66.311  49.434  1
422422  99.569  -66.315  49.379  1
422423  99.609  -66.319  49.327  1
422424  99.647  -66.323  49.274  1
422425  99.686  -66.327  49.223  1
422426  99.725  -66.332  49.172  1
422427  99.766  -66.338  49.120  1
422428  99.806  -66.343  49.069  1
422429  99.848  -66.350  49.020  1
422430  99.894  -66.359  48.971  1
422431  99.940  -66.368  48.924  1
422432  99.974  -66.370  48.877  1
422433  100.022  -66.369  48.831  1
422434  100.070  -66.367  48.786  1
422435  100.119  -66.364  48.742  1
422436  100.167  -66.362  48.699  1
422437  100.215  -66.360  48.656  1
422438  100.263  -66.358  48.614  1
422439  100.312  -66.356  48.572  1
422440  100.360  -66.354  48.530  1
422441  100.408  -66.351  48.488  1
422442  100.456  -66.350  48.450  1
422853  88.396  -65.130  55.331  1
422854  88.430  -65.140  55.315  1
422855  88.464  -65.149  55.299  1
422856  88.498  -65.159  55.283  1
422857  88.533  -65.168  55.270  1
422858  88.567  -65.178  55.259  1
422859  88.601  -65.188  55.248  1
422860  88.635  -65.197  55.239  1
422861  88.670  -65.207  55.230  1
422862  88.704  -65.217  55.220  1
422863  88.738  -65.226  55.212  1
422864  88.772  -65.235  55.204  1
422865  88.818  -65.239  55.197  1
422866  88.864  -65.243  55.190  1
422867  88.911  -65.248  55.183  1
422868  88.957  -65.251  55.176  1
422869  89.003  -65.255  55.167  1
422870  89.049  -65.259  55.159  1
422871  89.095  -65.263  55.149  1
422872  89.141  -65.267  55.138  1
422873  89.188  -65.271  55.127  1
422874  89.234  -65.275  55.114  1
422875  89.280  -65.279  55.102  1
422876  89.326  -65.282  55.089  1
422877  89.373  -65.286  55.077  1
422878  89.418  -65.290  55.065  1
422879  89.465  -65.295  55.050  1
422880  89.518  -65.283  55.036  1
422881  89.574  -65.281  55.022  1
422882  89.630  -65.286  55.008  1
422883  89.685  -65.289  54.996  1
422884  89.735  -65.298  54.984  1
422885  89.784  -65.308  54.973  1
422886  89.832  -65.317  54.963  1
422896  90.317  -65.380  54.963  1
422897  90.365  -65.386  54.968  1
422898  90.414  -65.392  54.972  1
422899  90.462  -65.398  54.976  1
422900  90.511  -65.404  54.979  1
422901  90.559  -65.410  54.981  1
422902  90.607  -65.417  54.982  1
422903  90.656  -65.423  54.982  1
422904  90.705  -65.429  54.980  1
422905  90.753  -65.435  54.978  1
422906  90.801  -65.441  54.973  1
422907  90.850  -65.447  54.967  1
422908  90.898  -65.453  54.961  1
422909  90.946  -65.460  54.955  1
422910  90.992  -65.472  54.948  1
422911  91.038  -65.483  54.941  1
422912  91.084  -65.495  54.934  1
422913  91.130  -65.506  54.927  1
422914  91.175  -65.517  54.920  1
422915  91.218  -65.528  54.914  1
422916  91.261  -65.539  54.909  1
422917  91.304  -65.550  54.906  1
422918  91.347  -65.561  54.904  1
422919  91.390  -65.571  54.904  1
422920  91.433  -65.583  54.905  1
422921  91.475  -65.593  54.907  1
422922  91.518  -65.604  54.911  1
422923  91.562  -65.615  54.916  1
422924  91.604  -65.625  54.922  1
422925  91.646  -65.638  54.931  1
422926  91.686  -65.655  54.940  1
422927  91.726  -65.672  54.946  1
422928  91.760  -65.689  54.949  1
422929  91.789  -65.705  54.949  1
422930  91.823  -65.720  54.950  1
422931  91.862  -65.731  54.947  1
422932  91.911  -65.737  54.945  1
422933  91.959  -65.743  54.945  1
422934  92.008  -65.748  54.948  1
422935  92.057  -65.752  54.949  1
422936  92.108  -65.753  54.951  1
422937  92.158  -65.755  54.951  1
422938  92.209  -65.756  54.948  1
422939  92.260  -65.758  54.943  1
422940  92.310  -65.769  54.934  1
422941  92.362  -65.781  54.923  1
422942  92.413  -65.792  54.914  1
422943  92.463  -65.803  54.907  1
422944  92.512  -65.805  54.903  1
422945  92.561  -65.806  54.899  1
422946  92.610  -65.808  54.892  1
422947  92.659  -65.809  54.883  1
422948  92.708  -65.810  54.874  1
422949  92.757  -65.812  54.863  1
422950  92.805  -65.813  54.852  1
422951  92.854  -65.812  54.843  1
422952  92.902  -65.806  54.835  1
422953  92.949  -65.800  54.831  1
422954  92.997  -65.793  54.829  1
422955  93.046  -65.789  54.828  1
422956  93.095  -65.785  54.828  1
422957  93.144  -65.781  54.825  1
422958  93.193  -65.776  54.820  1
422959  93.241  -65.771  54.813  1
422960  93.290  -65.768  54.808  1
422961  93.339  -65.763  54.804  1
422962  93.386  -65.761  54.801  1
422963  93.429  -65.762  54.800  1
422964  93.473  -65.762  54.797  1
422965  93.517  -65.762  54.789  1
422966  93.560  -65.762  54.779  1
422967  93.604  -65.762  54.765  1
422968  93.648  -65.762  54.752  1
422969  93.694  -65.762  54.734  1
422970  93.739  -65.760  54.715  1
422971  93.784  -65.759  54.694  1
422972  93.829  -65.758  54.671  1
422973  93.874  -65.757  54.646  1
422974  93.920  -65.749  54.620  1
422975  93.966  -65.734  54.593  1
422976  94.012  -65.720  54.566  1
422977  94.058  -65.705  54.538  1
422978  94.101  -65.701  54.507  1
422979  94.140  -65.704  54.475  1
422980  94.180  -65.708  54.445  1
422981  94.210  -65.716  54.416  1
422982  94.228  -65.733  54.390  1
422983  94.247  -65.749  54.362  1
422984  94.265  -65.766  54.331  1
422985  94.284  -65.783  54.298  1
422986  94.302  -65.799  54.265  1
422987  94.333  -65.809  54.232  1
422988  94.368  -65.816  54.201  1
422989  94.404  -65.824  54.174  1
422990  94.439  -65.831  54.150  1
422991  94.474  -65.839  54.131  1
422992  94.511  -65.845  54.119  1
422993  94.551  -65.849  54.113  1
422994  94.590  -65.853  54.112  1
422995  94.630  -65.857  54.113  1
422996  94.670  -65.861  54.112  1
422997  94.709  -65.865  54.104  1
422998  94.749  -65.869  54.089  1
422999  94.789  -65.873  54.070  1
423000  94.829  -65.877  54.046  1
423001  94.869  -65.881  54.019  1
423002  94.912  -65.882  53.990  1
423003  94.955  -65.883  53.956  1
423004  94.998  -65.884  53.919  1
423005  95.039  -65.887  53.879  1
423006  95.079  -65.889  53.835  1
423007  95.120  -65.892  53.793  1
423008  95.161  -65.894  53.753  1
423009  95.202  -65.897  53.714  1
423010  95.244  -65.901  53.677  1
423011  95.288  -65.909  53.643  1
423012  95.327  -65.903  53.613  1
423013  95.372  -65.910  53.588  1
423014  95.416  -65.917  53.570  1
423015  95.460  -65.925  53.561  1
423016  95.505  -65.931  53.557  1
423017  95.548  -65.938  53.552  1
423018  95.590  -65.943  53.544  1
423019  95.632  -65.947  53.534  1
423020  95.673  -65.952  53.521  1
423021  95.714  -65.952  53.503  1
423022  95.755  -65.947  53.479  1
423023  95.796  -65.941  53.452  1
423024  95.837  -65.936  53.421  1
423025  95.878  -65.931  53.392  1
423026  95.918  -65.925  53.360  1
423027  95.959  -65.920  53.328  1
423028  96.000  -65.914  53.298  1
423029  96.040  -65.909  53.269  1
423030  96.081  -65.906  53.244  1
423031  96.123  -65.902  53.218  1
423032  96.165  -65.898  53.193  1
423033  96.206  -65.895  53.170  1
423034  96.248  -65.891  53.146  1
423035  96.290  -65.887  53.119  1
423036  96.331  -65.884  53.089  1
423037  96.372  -65.876  53.056  1
423038  96.413  -65.868  53.022  1
423039  96.454  -65.859  52.988  1
423040  96.495  -65.850  52.954  1
423041  96.536  -65.842  52.919  1
423042  96.577  -65.834  52.886  1
423043  96.612  -65.834  52.853  1
423044  96.643  -65.847  52.821  1
423045  96.673  -65.859  52.792  1
423046  96.705  -65.870  52.763  1
423047  96.745  -65.876  52.735  1
423048  96.786  -65.882  52.703  1
423049  96.826  -65.888  52.670  1
423050  96.866  -65.894  52.635  1
423051  96.906  -65.900  52.599  1
423052  96.946  -65.906  52.563  1
423053  96.985  -65.911  52.527  1
423054  97.023  -65.916  52.489  1
423055  97.061  -65.923  52.451  1
423056  97.097  -65.930  52.414  1
423057  97.134  -65.937  52.380  1
423058  97.171  -65.943  52.348  1
423059  97.208  -65.950  52.318  1
423060  97.245  -65.956  52.286  1
423061  97.282  -65.963  52.251  1
423062  97.318  -65.969  52.216  1
423063  97.354  -65.975  52.181  1
423064  97.390  -65.981  52.148  1
423065  97.426  -65.988  52.116  1
423066  97.462  -65.994  52.087  1
423067  97.498  -66.000  52.055  1
423068  97.534  -66.006  52.024  1
423069  97.570  -66.012  51.993  1
423070  97.606  -66.019  51.961  1
423071  97.644  -66.025  51.928  1
423072  97.682  -66.034  51.895  1
423073  97.720  -66.041  51.858  1
423074  97.753  -66.046  51.818  1
423075  97.786  -66.050  51.776  1
423076  97.819  -66.054  51.731  1
423077  97.852  -66.058  51.686  1
423078  97.885  -66.063  51.641  1
423079  97.918  -66.066  51.594  1
423080  97.951  -66.071  51.547  1
423081  97.984  -66.075  51.500  1
423082  98.017  -66.079  51.454  1
423083  98.052  -66.084  51.409  1
423084  98.086  -66.088  51.364  1
423085  98.121  -66.093  51.317  1
423086  98.155  -66.097  51.267  1
423087  98.190  -66.102  51.219  1
423088  98.240  -66.124  51.171  1
423089  98.277  -66.128  51.122  1
423090  98.312  -66.128  51.072  1
423091  98.346  -66.129  51.021  1
423092  98.380  -66.129  50.971  1
423093  98.415  -66.129  50.921  1
423094  98.449  -66.129  50.870  1
423095  98.484  -66.130  50.821  1
423096  98.519  -66.132  50.769  1
423097  98.560  -66.135  50.716  1
423098  98.603  -66.140  50.662  1
423099  98.646  -66.144  50.608  1
423100  98.689  -66.148  50.556  1
423101  98.731  -66.153  50.506  1
423102  98.774  -66.157  50.456  1
423103  98.817  -66.162  50.407  1
423104  98.860  -66.166  50.356  1
423105  98.900  -66.172  50.307  1
423106  98.939  -66.181  50.258  1
423107  98.979  -66.188  50.211  1
423108  99.017  -66.201  50.166  1
423109  99.055  -66.217  50.118  1
423110  99.092  -66.234  50.069  1
423111  99.130  -66.251  50.021  1
423112  99.167  -66.267  49.973  1
423113  99.205  -66.279  49.924  1
423114  99.244  -66.279  49.875  1
423115  99.284  -66.280  49.821  1
423116  99.324  -66.282  49.766  1
423117  99.363  -66.282  49.710  1
423118  99.403  -66.281  49.655  1
423119  99.445  -66.276  49.600  1
423120  99.487  -66.271  49.547  1
423121  99.519  -66.270  49.493  1
423122  99.547  -66.273  49.438  1
423123  99.585  -66.277  49.382  1
423124  99.624  -66.282  49.328  1
423125  99.663  -66.285  49.276  1
423126  99.702  -66.289  49.224  1
423127  99.740  -66.294  49.172  1
423128  99.781  -66.299  49.120  1
423129  99.821  -66.305  49.070  1
423130  99.861  -66.310  49.020  1
423131  99.902  -66.317  48.971  1
423132  99.944  -66.323  48.924  1
423133  99.988  -66.325  48.877  1
423134  100.037  -66.323  48.831  1
423135  100.085  -66.320  48.786  1
423136  100.133  -66.318  48.741  1
423137  100.181  -66.317  48.698  1
423138  100.229  -66.314  48.656  1
423139  100.278  -66.312  48.613  1
423140  100.326  -66.310  48.571  1
423141  100.374  -66.307  48.529  1
423142  100.422  -66.306  48.487  1
423143  100.471  -66.304  48.448  1
423554  88.388  -65.082  55.326  1
423555  88.422  -65.091  55.312  1
423556  88.457  -65.101  55.299  1
423557  88.491  -65.110  55.285  1
423558  88.525  -65.120  55.274  1
423559  88.559  -65.129  55.265  1
423560  88.594  -65.139  55.256  1
423561  88.628  -65.149  55.249  1
423562  88.662  -65.158  55.241  1
423563  88.696  -65.168  55.233  1
423564  88.731  -65.177  55.226  1
423565  88.774  -65.182  55.220  1
423566  88.821  -65.186  55.215  1
423567  88.867  -65.190  55.208  1
423568  88.913  -65.194  55.200  1
423569  88.959  -65.198  55.192  1
423570  89.005  -65.202  55.186  1
423571  89.051  -65.206  55.177  1
423572  89.098  -65.210  55.167  1
423573  89.144  -65.213  55.155  1
423574  89.190  -65.217  55.142  1
423575  89.236  -65.222  55.130  1
423576  89.282  -65.226  55.116  1
423577  89.328  -65.229  55.104  1
423578  89.375  -65.233  55.091  1
423579  89.421  -65.237  55.078  1
423580  89.469  -65.236  55.063  1
423581  89.526  -65.227  55.048  1
423582  89.581  -65.232  55.033  1
423583  89.637  -65.235  55.019  1
423584  89.686  -65.245  55.006  1
423585  89.734  -65.254  54.993  1
423586  89.783  -65.263  54.981  1
423587  89.831  -65.269  54.971  1
423588  89.880  -65.275  54.963  1
423597  90.316  -65.330  54.963  1
423598  90.364  -65.336  54.968  1
423599  90.412  -65.342  54.973  1
423600  90.461  -65.349  54.976  1
423601  90.510  -65.355  54.979  1
423602  90.558  -65.361  54.981  1
423603  90.606  -65.367  54.983  1
423604  90.655  -65.373  54.982  1
423605  90.704  -65.380  54.981  1
423606  90.752  -65.386  54.978  1
423607  90.800  -65.392  54.972  1
423608  90.849  -65.398  54.967  1
423609  90.897  -65.405  54.960  1
423610  90.944  -65.413  54.953  1
423611  90.990  -65.424  54.946  1
423612  91.036  -65.436  54.938  1
423613  91.082  -65.448  54.931  1
423614  91.127  -65.459  54.923  1
423615  91.171  -65.470  54.916  1
423616  91.214  -65.481  54.910  1
423617  91.257  -65.492  54.904  1
423618  91.300  -65.502  54.900  1
423619  91.343  -65.513  54.898  1
423620  91.386  -65.524  54.896  1
423621  91.429  -65.535  54.896  1
423622  91.472  -65.546  54.898  1
423623  91.515  -65.556  54.901  1
423624  91.558  -65.567  54.906  1
423625  91.599  -65.581  54.912  1
423626  91.639  -65.598  54.922  1
423627  91.678  -65.615  54.931  1
423628  91.718  -65.631  54.938  1
423629  91.758  -65.649  54.942  1
423630  91.788  -65.665  54.944  1
423631  91.815  -65.683  54.945  1
423632  91.852  -65.695  54.941  1
423633  91.901  -65.700  54.935  1
423634  91.952  -65.702  54.930  1
423635  92.002  -65.702  54.926  1
423636  92.053  -65.704  54.924  1
423637  92.103  -65.705  54.925  1
423638  92.154  -65.707  54.925  1
423639  92.205  -65.709  54.924  1
423640  92.255  -65.712  54.920  1
423641  92.306  -65.724  54.912  1
423642  92.357  -65.736  54.904  1
423643  92.408  -65.747  54.898  1
423644  92.459  -65.759  54.894  1
423645  92.510  -65.770  54.892  1
423646  92.561  -65.781  54.890  1
423647  92.610  -65.784  54.883  1
423648  92.659  -65.784  54.875  1
423649  92.708  -65.786  54.866  1
423650  92.757  -65.787  54.855  1
423651  92.805  -65.788  54.845  1
423652  92.853  -65.781  54.836  1
423653  92.901  -65.775  54.830  1
423654  92.949  -65.771  54.828  1
423655  92.998  -65.767  54.829  1
423656  93.047  -65.762  54.831  1
423657  93.096  -65.758  54.832  1
423658  93.145  -65.753  54.831  1
423659  93.194  -65.749  54.829  1
423660  93.242  -65.745  54.822  1
423661  93.291  -65.740  54.816  1
423662  93.340  -65.737  54.811  1
423663  93.384  -65.736  54.806  1
423664  93.428  -65.736  54.805  1
423665  93.472  -65.737  54.800  1
423666  93.516  -65.737  54.794  1
423667  93.560  -65.737  54.785  1
423668  93.604  -65.737  54.772  1
423669  93.647  -65.738  54.760  1
423670  93.692  -65.737  54.745  1
423671  93.737  -65.737  54.728  1
423672  93.782  -65.735  54.708  1
423673  93.827  -65.734  54.684  1
423674  93.872  -65.733  54.659  1
423675  93.918  -65.724  54.632  1
423676  93.964  -65.710  54.604  1
423677  94.010  -65.695  54.575  1
423678  94.056  -65.680  54.547  1
423679  94.103  -65.665  54.515  1
423680  94.144  -65.662  54.485  1
423681  94.183  -65.666  54.457  1
423682  94.201  -65.683  54.431  1
423683  94.220  -65.699  54.403  1
423684  94.238  -65.715  54.375  1
423685  94.257  -65.732  54.344  1
423686  94.275  -65.749  54.311  1
423687  94.293  -65.765  54.279  1
423688  94.327  -65.774  54.248  1
423689  94.362  -65.781  54.219  1
423690  94.398  -65.788  54.193  1
423691  94.434  -65.794  54.170  1
423692  94.474  -65.799  54.152  1
423693  94.514  -65.803  54.140  1
423694  94.554  -65.806  54.135  1
423695  94.593  -65.811  54.133  1
423696  94.633  -65.815  54.134  1
423697  94.673  -65.818  54.132  1
423698  94.712  -65.822  54.123  1
423699  94.752  -65.827  54.107  1
423700  94.792  -65.831  54.085  1
423701  94.832  -65.834  54.059  1
423702  94.873  -65.837  54.029  1
423703  94.916  -65.838  53.999  1
423704  94.959  -65.840  53.965  1
423705  95.002  -65.840  53.927  1
423706  95.044  -65.843  53.887  1
423707  95.084  -65.845  53.844  1
423708  95.125  -65.848  53.803  1
423709  95.166  -65.850  53.762  1
423710  95.206  -65.853  53.723  1
423711  95.251  -65.862  53.685  1
423712  95.295  -65.868  53.652  1
423713  95.334  -65.861  53.622  1
423714  95.377  -65.865  53.597  1
423715  95.421  -65.872  53.580  1
423716  95.465  -65.879  53.572  1
423717  95.510  -65.886  53.567  1
423718  95.554  -65.893  53.562  1
423719  95.598  -65.900  53.556  1
423720  95.642  -65.907  53.547  1
423721  95.684  -65.912  53.535  1
423722  95.726  -65.914  53.517  1
423723  95.766  -65.909  53.494  1
423724  95.807  -65.903  53.466  1
423725  95.848  -65.898  53.435  1
423726  95.887  -65.892  53.403  1
423727  95.926  -65.886  53.371  1
423728  95.965  -65.880  53.339  1
423729  96.004  -65.874  53.309  1
423730  96.044  -65.869  53.280  1
423731  96.085  -65.865  53.254  1
423732  96.127  -65.862  53.227  1
423733  96.169  -65.859  53.201  1
423734  96.210  -65.855  53.176  1
423735  96.252  -65.851  53.151  1
423736  96.294  -65.847  53.122  1
423737  96.337  -65.844  53.091  1
423738  96.382  -65.835  53.058  1
423739  96.425  -65.826  53.024  1
423740  96.465  -65.818  52.988  1
423741  96.506  -65.809  52.952  1
423742  96.547  -65.800  52.917  1
423743  96.588  -65.792  52.880  1
423744  96.624  -65.793  52.844  1
423745  96.654  -65.806  52.811  1
423746  96.685  -65.818  52.781  1
423747  96.715  -65.829  52.752  1
423748  96.748  -65.840  52.723  1
423749  96.788  -65.846  52.691  1
423750  96.828  -65.852  52.656  1
423751  96.869  -65.858  52.621  1
423752  96.909  -65.865  52.586  1
423753  96.948  -65.869  52.552  1
423754  96.987  -65.874  52.516  1
423755  97.026  -65.879  52.478  1
423756  97.063  -65.886  52.440  1
423757  97.100  -65.892  52.404  1
423758  97.137  -65.899  52.370  1
423759  97.174  -65.906  52.338  1
423760  97.211  -65.912  52.308  1
423761  97.247  -65.919  52.276  1
423762  97.282  -65.923  52.241  1
423763  97.319  -65.931  52.206  1
423764  97.355  -65.937  52.171  1
423765  97.391  -65.944  52.137  1
423766  97.427  -65.950  52.104  1
423767  97.463  -65.956  52.073  1
423768  97.499  -65.963  52.042  1
423769  97.535  -65.969  52.011  1
423770  97.571  -65.975  51.981  1
423771  97.607  -65.981  51.951  1
423772  97.643  -65.988  51.920  1
423773  97.680  -65.995  51.886  1
423774  97.717  -66.001  51.849  1
423775  97.750  -66.006  51.808  1
423776  97.783  -66.010  51.765  1
423777  97.816  -66.014  51.720  1
423778  97.849  -66.019  51.676  1
423779  97.882  -66.022  51.632  1
423780  97.917  -66.027  51.588  1
423781  97.951  -66.031  51.543  1
423782  97.986  -66.036  51.500  1
423783  98.020  -66.041  51.456  1
423784  98.055  -66.045  51.412  1
423785  98.089  -66.050  51.367  1
423786  98.124  -66.055  51.321  1
423787  98.158  -66.060  51.270  1
423788  98.196  -66.066  51.221  1
423789  98.258  -66.102  51.172  1
423790  98.293  -66.102  51.122  1
423791  98.327  -66.103  51.070  1
423792  98.360  -66.102  51.017  1
423793  98.393  -66.101  50.965  1
423794  98.426  -66.100  50.913  1
423795  98.459  -66.099  50.863  1
423796  98.492  -66.098  50.814  1
423797  98.525  -66.097  50.762  1
423798  98.565  -66.099  50.709  1
423799  98.608  -66.103  50.654  1
423800  98.651  -66.108  50.600  1
423801  98.694  -66.113  50.548  1
423802  98.736  -66.117  50.499  1
423803  98.779  -66.122  50.449  1
423804  98.822  -66.125  50.398  1
423805  98.865  -66.130  50.347  1
423806  98.906  -66.137  50.297  1
423807  98.945  -66.144  50.249  1
423808  98.984  -66.153  50.204  1
423809  99.023  -66.160  50.161  1
423810  99.061  -66.176  50.115  1
423811  99.098  -66.192  50.067  1
423812  99.136  -66.209  50.020  1
423813  99.173  -66.226  49.974  1
423814  99.213  -66.227  49.927  1
423815  99.252  -66.228  49.878  1
423816  99.291  -66.229  49.824  1
423817  99.331  -66.230  49.768  1
423818  99.370  -66.231  49.711  1
423819  99.410  -66.232  49.657  1
423820  99.449  -66.233  49.603  1
423821  99.490  -66.230  49.551  1
423822  99.524  -66.232  49.497  1
423823  99.563  -66.236  49.441  1
423824  99.602  -66.240  49.385  1
423825  99.640  -66.245  49.331  1
423826  99.679  -66.248  49.278  1
423827  99.718  -66.252  49.225  1
423828  99.757  -66.257  49.173  1
423829  99.796  -66.261  49.121  1
423830  99.836  -66.266  49.070  1
423831  99.876  -66.273  49.020  1
423832  99.917  -66.278  48.971  1
423833  99.956  -66.282  48.924  1
423834  100.003  -66.279  48.877  1
423835  100.051  -66.276  48.831  1
423836  100.099  -66.274  48.786  1
423837  100.147  -66.273  48.740  1
423838  100.196  -66.270  48.697  1
423839  100.244  -66.268  48.655  1
423840  100.292  -66.266  48.613  1
423841  100.340  -66.263  48.570  1
423842  100.388  -66.262  48.528  1
423843  100.437  -66.260  48.487  1
423844  100.485  -66.257  48.446  1
424255  88.380  -65.033  55.321  1
424256  88.414  -65.043  55.310  1
424257  88.449  -65.053  55.298  1
424258  88.483  -65.062  55.287  1
424259  88.517  -65.072  55.278  1
424260  88.551  -65.081  55.271  1
424261  88.586  -65.091  55.264  1
424262  88.620  -65.101  55.258  1
424263  88.654  -65.110  55.252  1
424264  88.688  -65.120  55.247  1
424265  88.731  -65.125  55.243  1
424266  88.777  -65.129  55.240  1
424267  88.823  -65.133  55.236  1
424268  88.869  -65.137  55.231  1
424269  88.915  -65.141  55.223  1
424270  88.962  -65.145  55.214  1
424271  89.008  -65.148  55.204  1
424272  89.054  -65.153  55.196  1
424273  89.100  -65.157  55.185  1
424274  89.146  -65.160  55.173  1
424275  89.192  -65.164  55.159  1
424276  89.239  -65.168  55.146  1
424277  89.284  -65.172  55.132  1
424278  89.331  -65.176  55.119  1
424279  89.377  -65.180  55.107  1
424280  89.423  -65.184  55.092  1
424281  89.477  -65.173  55.077  1
424282  89.533  -65.177  55.061  1
424283  89.588  -65.182  55.046  1
424284  89.636  -65.192  55.030  1
424285  89.685  -65.201  55.017  1
424286  89.733  -65.207  55.003  1
424287  89.781  -65.213  54.990  1
424288  89.830  -65.220  54.979  1
424289  89.879  -65.226  54.969  1
424299  90.363  -65.288  54.970  1
424300  90.411  -65.294  54.974  1
424301  90.460  -65.300  54.978  1
424302  90.508  -65.306  54.981  1
424303  90.557  -65.312  54.983  1
424304  90.605  -65.318  54.984  1
424305  90.654  -65.325  54.983  1
424306  90.702  -65.331  54.981  1
424307  90.750  -65.337  54.978  1
424308  90.799  -65.343  54.973  1
424309  90.848  -65.349  54.966  1
424310  90.896  -65.355  54.959  1
424311  90.942  -65.366  54.952  1
424312  90.988  -65.377  54.944  1
424313  91.034  -65.389  54.936  1
424314  91.079  -65.401  54.929  1
424315  91.124  -65.412  54.920  1
424316  91.167  -65.423  54.913  1
424317  91.210  -65.433  54.906  1
424318  91.253  -65.444  54.899  1
424319  91.296  -65.455  54.894  1
424320  91.339  -65.466  54.891  1
424321  91.382  -65.477  54.889  1
424322  91.425  -65.487  54.888  1
424323  91.468  -65.498  54.890  1
424324  91.511  -65.508  54.892  1
424325  91.552  -65.524  54.897  1
424326  91.591  -65.541  54.903  1
424327  91.631  -65.558  54.913  1
424328  91.671  -65.574  54.922  1
424329  91.711  -65.591  54.930  1
424330  91.750  -65.608  54.936  1
424331  91.788  -65.625  54.939  1
424332  91.815  -65.643  54.940  1
424333  91.844  -65.659  54.936  1
424334  91.896  -65.655  54.929  1
424335  91.947  -65.654  54.921  1
424336  91.998  -65.655  54.913  1
424337  92.049  -65.657  54.905  1
424338  92.099  -65.659  54.902  1
424339  92.149  -65.660  54.900  1
424340  92.200  -65.662  54.899  1
424341  92.250  -65.668  54.897  1
424342  92.302  -65.679  54.891  1
424343  92.353  -65.690  54.885  1
424344  92.404  -65.702  54.881  1
424345  92.454  -65.713  54.880  1
424346  92.506  -65.724  54.880  1
424347  92.557  -65.737  54.879  1
424348  92.607  -65.748  54.873  1
424349  92.658  -65.759  54.866  1
424350  92.708  -65.762  54.857  1
424351  92.757  -65.763  54.847  1
424352  92.804  -65.757  54.837  1
424353  92.853  -65.753  54.829  1
424354  92.902  -65.749  54.824  1
424355  92.951  -65.744  54.824  1
424356  93.000  -65.740  54.827  1
424357  93.049  -65.735  54.830  1
424358  93.097  -65.731  54.833  1
424359  93.146  -65.727  54.834  1
424360  93.195  -65.722  54.834  1
424361  93.243  -65.718  54.828  1
424362  93.292  -65.714  54.822  1
424363  93.340  -65.710  54.816  1
424364  93.384  -65.711  54.811  1
424365  93.428  -65.711  54.807  1
424366  93.472  -65.712  54.802  1
424367  93.515  -65.712  54.795  1
424368  93.559  -65.712  54.786  1
424369  93.603  -65.712  54.774  1
424370  93.647  -65.712  54.764  1
424371  93.690  -65.713  54.751  1
424372  93.735  -65.712  54.735  1
424373  93.780  -65.711  54.717  1
424374  93.826  -65.710  54.693  1
424375  93.870  -65.709  54.667  1
424376  93.916  -65.700  54.640  1
424377  93.963  -65.685  54.612  1
424378  94.008  -65.670  54.582  1
424379  94.054  -65.655  54.553  1
424380  94.101  -65.640  54.523  1
424381  94.146  -65.625  54.493  1
424382  94.174  -65.632  54.465  1
424383  94.193  -65.649  54.439  1
424384  94.211  -65.665  54.411  1
424385  94.229  -65.682  54.382  1
424386  94.248  -65.698  54.351  1
424387  94.266  -65.715  54.320  1
424388  94.285  -65.731  54.290  1
424389  94.321  -65.738  54.260  1
424390  94.358  -65.744  54.234  1
424391  94.398  -65.748  54.211  1
424392  94.437  -65.752  54.191  1
424393  94.477  -65.756  54.174  1
424394  94.517  -65.760  54.162  1
424395  94.557  -65.764  54.157  1
424396  94.596  -65.768  54.155  1
424397  94.636  -65.772  54.154  1
424398  94.676  -65.776  54.151  1
424399  94.715  -65.780  54.140  1
424400  94.755  -65.784  54.122  1
424401  94.795  -65.788  54.098  1
424402  94.835  -65.792  54.069  1
424403  94.877  -65.794  54.038  1
424404  94.920  -65.795  54.006  1
424405  94.963  -65.796  53.972  1
424406  95.006  -65.797  53.935  1
424407  95.048  -65.799  53.895  1
424408  95.089  -65.802  53.853  1
424409  95.130  -65.804  53.812  1
424410  95.171  -65.806  53.771  1
424411  95.213  -65.812  53.732  1
424412  95.258  -65.822  53.694  1
424413  95.301  -65.826  53.662  1
424414  95.340  -65.820  53.632  1
424415  95.382  -65.819  53.608  1
424416  95.426  -65.826  53.591  1
424417  95.470  -65.833  53.582  1
424418  95.515  -65.840  53.576  1
424419  95.559  -65.847  53.571  1
424420  95.603  -65.855  53.566  1
424421  95.647  -65.862  53.558  1
424422  95.691  -65.868  53.547  1
424423  95.735  -65.875  53.530  1
424424  95.774  -65.870  53.507  1
424425  95.813  -65.864  53.480  1
424426  95.852  -65.858  53.448  1
424427  95.891  -65.852  53.416  1
424428  95.930  -65.846  53.384  1
424429  95.969  -65.840  53.351  1
424430  96.008  -65.834  53.320  1
424431  96.048  -65.829  53.291  1
424432  96.090  -65.825  53.264  1
424433  96.131  -65.821  53.236  1
424434  96.173  -65.818  53.208  1
424435  96.215  -65.815  53.181  1
424436  96.256  -65.811  53.154  1
424437  96.299  -65.808  53.123  1
424438  96.343  -65.804  53.090  1
424439  96.387  -65.796  53.056  1
424440  96.433  -65.786  53.020  1
424441  96.477  -65.776  52.984  1
424442  96.518  -65.768  52.948  1
424443  96.559  -65.759  52.912  1
424444  96.600  -65.750  52.873  1
424445  96.636  -65.752  52.835  1
424446  96.666  -65.764  52.800  1
424447  96.696  -65.776  52.768  1
424448  96.727  -65.788  52.738  1
424449  96.757  -65.800  52.709  1
424450  96.791  -65.810  52.675  1
424451  96.831  -65.816  52.640  1
424452  96.871  -65.822  52.605  1
424453  96.911  -65.828  52.570  1
424454  96.950  -65.833  52.536  1
424455  96.989  -65.837  52.502  1
424456  97.028  -65.842  52.464  1
424457  97.066  -65.848  52.427  1
424458  97.102  -65.855  52.391  1
424459  97.139  -65.862  52.357  1
424460  97.176  -65.868  52.324  1
424461  97.213  -65.875  52.292  1
424462  97.249  -65.881  52.259  1
424463  97.280  -65.882  52.224  1
424464  97.321  -65.892  52.190  1
424465  97.357  -65.898  52.154  1
424466  97.393  -65.905  52.119  1
424467  97.429  -65.911  52.086  1
424468  97.464  -65.918  52.054  1
424469  97.500  -65.924  52.023  1
424470  97.536  -65.931  51.992  1
424471  97.572  -65.937  51.962  1
424472  97.607  -65.944  51.932  1
424473  97.643  -65.950  51.903  1
424474  97.679  -65.956  51.871  1
424475  97.714  -65.961  51.834  1
424476  97.747  -65.966  51.793  1
424477  97.782  -65.970  51.750  1
424478  97.816  -65.975  51.708  1
424479  97.851  -65.979  51.667  1
424480  97.885  -65.984  51.627  1
424481  97.920  -65.989  51.586  1
424482  97.954  -65.994  51.543  1
424483  97.989  -65.998  51.501  1
424484  98.023  -66.003  51.458  1
424485  98.058  -66.007  51.414  1
424486  98.092  -66.012  51.369  1
424487  98.127  -66.016  51.322  1
424488  98.161  -66.021  51.273  1
424489  98.214  -66.045  51.222  1
424490  98.263  -66.065  51.171  1
424491  98.300  -66.069  51.119  1
424492  98.333  -66.068  51.066  1
424493  98.366  -66.067  51.013  1
424494  98.398  -66.066  50.960  1
424495  98.432  -66.065  50.906  1
424496  98.464  -66.064  50.855  1
424497  98.498  -66.063  50.805  1
424498  98.530  -66.062  50.754  1
424499  98.568  -66.063  50.700  1
424500  98.613  -66.068  50.646  1
424501  98.656  -66.072  50.593  1
424502  98.699  -66.076  50.543  1
424503  98.742  -66.081  50.493  1
424504  98.785  -66.085  50.441  1
424505  98.828  -66.090  50.390  1
424506  98.870  -66.094  50.339  1
424507  98.911  -66.101  50.291  1
424508  98.950  -66.109  50.244  1
424509  98.989  -66.116  50.198  1
424510  99.028  -66.124  50.154  1
424511  99.067  -66.134  50.112  1
424512  99.104  -66.151  50.065  1
424513  99.142  -66.167  50.019  1
424514  99.181  -66.174  49.973  1
424515  99.220  -66.176  49.927  1
424516  99.260  -66.176  49.877  1
424517  99.299  -66.178  49.824  1
424518  99.339  -66.179  49.769  1
424519  99.378  -66.179  49.713  1
424520  99.417  -66.181  49.659  1
424521  99.457  -66.186  49.607  1
424522  99.497  -66.191  49.554  1
424523  99.539  -66.194  49.500  1
424524  99.578  -66.198  49.444  1
424525  99.617  -66.203  49.389  1
424526  99.656  -66.207  49.334  1
424527  99.695  -66.211  49.280  1
424528  99.734  -66.215  49.226  1
424529  99.773  -66.219  49.172  1
424530  99.811  -66.223  49.120  1
424531  99.851  -66.229  49.069  1
424532  99.892  -66.234  49.019  1
424533  99.930  -66.239  48.971  1
424534  99.970  -66.235  48.924  1
424535  100.017  -66.232  48.876  1
424536  100.065  -66.230  48.831  1
424537  100.114  -66.229  48.785  1
424538  100.162  -66.226  48.740  1
424539  100.210  -66.224  48.696  1
424540  100.258  -66.222  48.653  1
424541  100.307  -66.220  48.611  1
424542  100.355  -66.218  48.569  1
424543  100.403  -66.216  48.527  1
424544  100.451  -66.213  48.486  1
424545  100.499  -66.211  48.446  1
424956  88.372  -64.985  55.318  1
424957  88.406  -64.994  55.309  1
424958  88.440  -65.004  55.299  1
424959  88.475  -65.013  55.289  1
424960  88.509  -65.023  55.282  1
424961  88.543  -65.033  55.276  1
424962  88.577  -65.042  55.272  1
424963  88.612  -65.052  55.268  1
424964  88.646  -65.061  55.265  1
424965  88.687  -65.068  55.263  1
424966  88.733  -65.072  55.262  1
424967  88.779  -65.076  55.263  1
424968  88.825  -65.080  55.263  1
424969  88.872  -65.084  55.258  1
424970  88.917  -65.088  55.250  1
424971  88.964  -65.091  55.239  1
424972  89.010  -65.095  55.225  1
424973  89.056  -65.099  55.215  1
424974  89.102  -65.104  55.204  1
424975  89.148  -65.107  55.191  1
424976  89.195  -65.111  55.176  1
424977  89.241  -65.115  55.163  1
424978  89.287  -65.119  55.148  1
424979  89.333  -65.123  55.134  1
424980  89.379  -65.127  55.120  1
424981  89.428  -65.125  55.107  1
424982  89.484  -65.123  55.090  1
424983  89.538  -65.129  55.074  1
424984  89.587  -65.139  55.058  1
424985  89.635  -65.146  55.042  1
424986  89.683  -65.152  55.028  1
424987  89.732  -65.158  55.013  1
424988  89.780  -65.164  54.999  1
424989  89.829  -65.170  54.987  1
424990  89.877  -65.177  54.975  1
424991  89.926  -65.183  54.968  1
425000  90.362  -65.239  54.971  1
425001  90.410  -65.245  54.975  1
425002  90.459  -65.251  54.979  1
425003  90.507  -65.257  54.982  1
425004  90.555  -65.264  54.984  1
425005  90.604  -65.270  54.984  1
425006  90.653  -65.276  54.983  1
425007  90.701  -65.282  54.981  1
425008  90.749  -65.288  54.978  1
425009  90.798  -65.294  54.973  1
425010  90.846  -65.300  54.966  1
425011  90.894  -65.308  54.959  1
425012  90.940  -65.319  54.951  1
425013  90.986  -65.330  54.943  1
425014  91.031  -65.342  54.934  1
425015  91.077  -65.353  54.927  1
425016  91.120  -65.364  54.918  1
425017  91.163  -65.375  54.910  1
425018  91.207  -65.386  54.902  1
425019  91.249  -65.396  54.895  1
425020  91.292  -65.408  54.889  1
425021  91.335  -65.418  54.885  1
425022  91.378  -65.429  54.882  1
425023  91.421  -65.439  54.881  1
425024  91.464  -65.450  54.882  1
425025  91.504  -65.467  54.883  1
425026  91.544  -65.483  54.887  1
425027  91.584  -65.500  54.894  1
425028  91.624  -65.517  54.903  1
425029  91.663  -65.534  54.913  1
425030  91.703  -65.551  54.921  1
425031  91.743  -65.568  54.927  1
425032  91.783  -65.584  54.931  1
425033  91.816  -65.602  54.931  1
425034  91.843  -65.619  54.928  1
425035  91.888  -65.621  54.921  1
425036  91.940  -65.618  54.912  1
425037  91.992  -65.613  54.901  1
425038  92.044  -65.610  54.890  1
425039  92.094  -65.612  54.884  1
425040  92.145  -65.613  54.880  1
425041  92.196  -65.615  54.878  1
425042  92.246  -65.622  54.876  1
425043  92.297  -65.633  54.872  1
425044  92.348  -65.645  54.867  1
425045  92.399  -65.656  54.865  1
425046  92.450  -65.668  54.866  1
425047  92.501  -65.680  54.866  1
425048  92.552  -65.691  54.865  1
425049  92.603  -65.702  54.861  1
425050  92.654  -65.715  54.854  1
425051  92.706  -65.727  54.846  1
425052  92.757  -65.730  54.836  1
425053  92.806  -65.728  54.826  1
425054  92.855  -65.725  54.820  1
425055  92.903  -65.721  54.817  1
425056  92.952  -65.717  54.817  1
425057  93.001  -65.713  54.821  1
425058  93.050  -65.709  54.826  1
425059  93.098  -65.704  54.830  1
425060  93.147  -65.699  54.832  1
425061  93.196  -65.696  54.833  1
425062  93.245  -65.691  54.830  1
425063  93.294  -65.687  54.825  1
425064  93.340  -65.685  54.820  1
425065  93.383  -65.685  54.814  1
425066  93.427  -65.686  54.807  1
425067  93.471  -65.686  54.801  1
425068  93.515  -65.687  54.794  1
425069  93.558  -65.687  54.784  1
425070  93.602  -65.687  54.774  1
425071  93.646  -65.687  54.766  1
425072  93.690  -65.687  54.754  1
425073  93.733  -65.688  54.740  1
425074  93.778  -65.687  54.722  1
425075  93.824  -65.686  54.699  1
425076  93.869  -65.685  54.672  1
425077  93.914  -65.675  54.645  1
425078  93.961  -65.660  54.616  1
425079  94.006  -65.646  54.587  1
425080  94.053  -65.630  54.556  1
425081  94.099  -65.615  54.526  1
425082  94.120  -65.627  54.497  1
425083  94.142  -65.638  54.469  1
425084  94.163  -65.649  54.441  1
425085  94.185  -65.661  54.413  1
425086  94.206  -65.672  54.383  1
425087  94.227  -65.683  54.353  1
425088  94.249  -65.694  54.324  1
425089  94.282  -65.693  54.297  1
425090  94.321  -65.697  54.271  1
425091  94.361  -65.702  54.249  1
425092  94.401  -65.705  54.230  1
425093  94.440  -65.709  54.213  1
425094  94.480  -65.713  54.197  1
425095  94.520  -65.718  54.185  1
425096  94.560  -65.721  54.178  1
425097  94.599  -65.725  54.174  1
425098  94.639  -65.730  54.171  1
425099  94.679  -65.734  54.164  1
425100  94.718  -65.737  54.150  1
425101  94.758  -65.741  54.130  1
425102  94.798  -65.746  54.105  1
425103  94.838  -65.749  54.075  1
425104  94.881  -65.750  54.043  1
425105  94.924  -65.752  54.011  1
425106  94.967  -65.753  53.977  1
425107  95.011  -65.754  53.941  1
425108  95.053  -65.756  53.901  1
425109  95.094  -65.758  53.859  1
425110  95.134  -65.760  53.819  1
425111  95.176  -65.763  53.780  1
425112  95.220  -65.773  53.741  1
425113  95.265  -65.782  53.704  1
425114  95.308  -65.784  53.673  1
425115  95.347  -65.778  53.645  1
425116  95.387  -65.774  53.621  1
425117  95.431  -65.781  53.604  1
425118  95.475  -65.787  53.592  1
425119  95.520  -65.795  53.584  1
425120  95.564  -65.802  53.578  1
425121  95.608  -65.809  53.574  1
425122  95.652  -65.816  53.567  1
425123  95.696  -65.823  53.556  1
425124  95.737  -65.825  53.541  1
425125  95.777  -65.827  53.520  1
425126  95.817  -65.824  53.493  1
425127  95.856  -65.818  53.462  1
425128  95.895  -65.812  53.430  1
425129  95.934  -65.806  53.397  1
425130  95.973  -65.800  53.364  1
425131  96.012  -65.794  53.331  1
425132  96.052  -65.789  53.302  1
425133  96.094  -65.785  53.273  1
425134  96.135  -65.782  53.244  1
425135  96.177  -65.778  53.215  1
425136  96.219  -65.774  53.186  1
425137  96.261  -65.771  53.156  1
425138  96.305  -65.768  53.123  1
425139  96.348  -65.764  53.088  1
425140  96.393  -65.757  53.052  1
425141  96.438  -65.747  53.015  1
425142  96.483  -65.737  52.978  1
425143  96.529  -65.726  52.942  1
425144  96.571  -65.718  52.905  1
425145  96.612  -65.709  52.867  1
425146  96.647  -65.711  52.827  1
425147  96.677  -65.722  52.790  1
425148  96.708  -65.734  52.756  1
425149  96.738  -65.746  52.724  1
425150  96.768  -65.759  52.693  1
425151  96.799  -65.771  52.658  1
425152  96.833  -65.780  52.623  1
425153  96.874  -65.786  52.588  1
425154  96.913  -65.791  52.554  1
425155  96.952  -65.796  52.520  1
425156  96.991  -65.800  52.486  1
425157  97.030  -65.805  52.449  1
425158  97.068  -65.811  52.412  1
425159  97.105  -65.818  52.377  1
425160  97.142  -65.824  52.342  1
425161  97.179  -65.831  52.309  1
425162  97.216  -65.837  52.276  1
425163  97.244  -65.837  52.241  1
425164  97.278  -65.840  52.205  1
425165  97.320  -65.851  52.170  1
425166  97.359  -65.859  52.134  1
425167  97.394  -65.865  52.100  1
425168  97.430  -65.872  52.067  1
425169  97.466  -65.878  52.035  1
425170  97.502  -65.885  52.001  1
425171  97.537  -65.892  51.970  1
425172  97.573  -65.898  51.939  1
425173  97.609  -65.905  51.910  1
425174  97.645  -65.911  51.883  1
425175  97.681  -65.914  51.852  1
425176  97.717  -65.914  51.816  1
425177  97.751  -65.923  51.777  1
425178  97.785  -65.932  51.736  1
425179  97.819  -65.937  51.696  1
425180  97.854  -65.941  51.657  1
425181  97.888  -65.946  51.619  1
425182  97.923  -65.950  51.581  1
425183  97.957  -65.955  51.540  1
425184  97.992  -65.959  51.499  1
425185  98.026  -65.964  51.457  1
425186  98.061  -65.969  51.413  1
425187  98.095  -65.973  51.369  1
425188  98.130  -65.978  51.322  1
425189  98.169  -65.988  51.272  1
425190  98.222  -66.012  51.221  1
425191  98.262  -66.022  51.168  1
425192  98.300  -66.028  51.115  1
425193  98.337  -66.031  51.062  1
425194  98.371  -66.032  51.009  1
425195  98.404  -66.031  50.955  1
425196  98.437  -66.030  50.902  1
425197  98.470  -66.029  50.850  1
425198  98.503  -66.028  50.799  1
425199  98.536  -66.027  50.747  1
425200  98.571  -66.027  50.696  1
425201  98.616  -66.031  50.644  1
425202  98.660  -66.036  50.592  1
425203  98.704  -66.041  50.541  1
425204  98.747  -66.045  50.489  1
425205  98.790  -66.050  50.437  1
425206  98.833  -66.053  50.385  1
425207  98.875  -66.058  50.333  1
425208  98.916  -66.065  50.284  1
425209  98.955  -66.072  50.238  1
425210  98.994  -66.081  50.192  1
425211  99.033  -66.088  50.148  1
425212  99.073  -66.096  50.107  1
425213  99.111  -66.109  50.061  1
425214  99.149  -66.122  50.015  1
425215  99.188  -66.122  49.969  1
425216  99.228  -66.124  49.922  1
425217  99.267  -66.125  49.873  1
425218  99.307  -66.130  49.821  1
425219  99.347  -66.135  49.768  1
425220  99.386  -66.140  49.715  1
425221  99.426  -66.145  49.661  1
425222  99.466  -66.150  49.608  1
425223  99.506  -66.154  49.554  1
425224  99.549  -66.157  49.500  1
425225  99.591  -66.160  49.445  1
425226  99.631  -66.164  49.392  1
425227  99.670  -66.168  49.338  1
425228  99.709  -66.172  49.283  1
425229  99.749  -66.177  49.228  1
425230  99.788  -66.181  49.174  1
425231  99.827  -66.185  49.121  1
425232  99.866  -66.190  49.069  1
425233  99.905  -66.195  49.019  1
425234  99.944  -66.201  48.971  1
425235  99.983  -66.188  48.923  1
425236  100.031  -66.186  48.876  1
425237  100.080  -66.185  48.830  1
425238  100.128  -66.182  48.784  1
425239  100.176  -66.180  48.739  1
425240  100.224  -66.178  48.695  1
425241  100.273  -66.176  48.653  1
425242  100.321  -66.174  48.610  1
425243  100.369  -66.172  48.568  1
425244  100.417  -66.169  48.526  1
425245  100.466  -66.168  48.484  1
425246  100.514  -66.166  48.445  1
425656  88.330  -64.927  55.325  1
425657  88.364  -64.937  55.315  1
425658  88.399  -64.946  55.307  1
425659  88.433  -64.956  55.299  1
425660  88.467  -64.965  55.291  1
425661  88.501  -64.975  55.286  1
425662  88.536  -64.985  55.283  1
425663  88.570  -64.994  55.280  1
425664  88.604  -65.004  55.279  1
425665  88.643  -65.011  55.279  1
425666  88.689  -65.015  55.280  1
425667  88.735  -65.019  55.284  1
425668  88.781  -65.022  55.293  1
425669  88.828  -65.026  55.295  1
425670  88.874  -65.030  55.292  1
425671  88.920  -65.035  55.282  1
425672  88.966  -65.038  55.268  1
425673  89.012  -65.042  55.249  1
425674  89.058  -65.046  55.235  1
425675  89.105  -65.050  55.222  1
425676  89.151  -65.054  55.209  1
425677  89.197  -65.058  55.194  1
425678  89.243  -65.062  55.180  1
425679  89.290  -65.066  55.165  1
425680  89.335  -65.069  55.150  1
425681  89.382  -65.073  55.135  1
425682  89.436  -65.069  55.121  1
425683  89.488  -65.076  55.105  1
425684  89.537  -65.085  55.088  1
425685  89.586  -65.091  55.071  1
425686  89.634  -65.097  55.054  1
425687  89.682  -65.103  55.037  1
425688  89.731  -65.110  55.022  1
425689  89.779  -65.116  55.009  1
425690  89.828  -65.122  54.995  1
425691  89.876  -65.128  54.983  1
425692  89.924  -65.134  54.974  1
425702  90.409  -65.196  54.975  1
425703  90.457  -65.202  54.979  1
425704  90.506  -65.208  54.982  1
425705  90.554  -65.214  54.984  1
425706  90.603  -65.220  54.984  1
425707  90.651  -65.226  54.983  1
425708  90.699  -65.232  54.981  1
425709  90.748  -65.239  54.978  1
425710  90.797  -65.245  54.973  1
425711  90.845  -65.251  54.966  1
425712  90.892  -65.261  54.958  1
425713  90.938  -65.272  54.950  1
425714  90.983  -65.283  54.942  1
425715  91.029  -65.295  54.933  1
425716  91.074  -65.306  54.925  1
425717  91.116  -65.317  54.916  1
425718  91.160  -65.327  54.907  1
425719  91.203  -65.338  54.899  1
425720  91.245  -65.349  54.890  1
425721  91.288  -65.360  54.884  1
425722  91.331  -65.370  54.879  1
425723  91.374  -65.381  54.876  1
425724  91.417  -65.392  54.874  1
425725  91.456  -65.410  54.874  1
425726  91.496  -65.427  54.875  1
425727  91.536  -65.443  54.879  1
425728  91.576  -65.460  54.884  1
425729  91.615  -65.477  54.892  1
425730  91.655  -65.494  54.901  1
425731  91.695  -65.511  54.910  1
425732  91.735  -65.527  54.916  1
425733  91.775  -65.544  54.919  1
425734  91.814  -65.561  54.919  1
425735  91.844  -65.578  54.916  1
425736  91.880  -65.588  54.911  1
425737  91.932  -65.584  54.902  1
425738  91.984  -65.580  54.890  1
425739  92.036  -65.577  54.878  1
425740  92.088  -65.572  54.869  1
425741  92.140  -65.568  54.863  1
425742  92.191  -65.568  54.859  1
425743  92.242  -65.577  54.857  1
425744  92.293  -65.589  54.854  1
425745  92.345  -65.602  54.851  1
425746  92.397  -65.615  54.851  1
425747  92.448  -65.628  54.853  1
425748  92.500  -65.641  54.853  1
425749  92.552  -65.654  54.851  1
425750  92.603  -65.668  54.847  1
425751  92.655  -65.674  54.842  1
425752  92.706  -65.676  54.833  1
425753  92.757  -65.679  54.824  1
425754  92.808  -65.680  54.816  1
425755  92.858  -65.682  54.812  1
425756  92.909  -65.684  54.811  1
425757  92.957  -65.680  54.810  1
425758  93.005  -65.677  54.814  1
425759  93.054  -65.674  54.817  1
425760  93.102  -65.671  54.820  1
425761  93.150  -65.668  54.823  1
425762  93.199  -65.664  54.825  1
425763  93.248  -65.661  54.823  1
425764  93.296  -65.658  54.820  1
425765  93.339  -65.660  54.815  1
425766  93.382  -65.660  54.809  1
425767  93.426  -65.661  54.802  1
425768  93.470  -65.661  54.795  1
425769  93.514  -65.661  54.787  1
425770  93.558  -65.662  54.778  1
425771  93.602  -65.662  54.769  1
425772  93.645  -65.662  54.761  1
425773  93.689  -65.662  54.752  1
425774  93.733  -65.663  54.739  1
425775  93.777  -65.663  54.721  1
425776  93.822  -65.662  54.698  1
425777  93.867  -65.661  54.673  1
425778  93.913  -65.650  54.645  1
425779  93.959  -65.636  54.616  1
425780  94.005  -65.621  54.588  1
425781  94.041  -65.616  54.558  1
425782  94.063  -65.627  54.526  1
425783  94.084  -65.638  54.497  1
425784  94.106  -65.649  54.468  1
425785  94.127  -65.661  54.438  1
425786  94.152  -65.667  54.409  1
425787  94.185  -65.663  54.380  1
425788  94.218  -65.659  54.352  1
425789  94.252  -65.654  54.326  1
425790  94.286  -65.654  54.303  1
425791  94.325  -65.655  54.282  1
425792  94.364  -65.659  54.265  1
425793  94.404  -65.663  54.250  1
425794  94.443  -65.667  54.235  1
425795  94.483  -65.671  54.220  1
425796  94.523  -65.675  54.208  1
425797  94.563  -65.679  54.199  1
425798  94.602  -65.683  54.192  1
425799  94.642  -65.687  54.185  1
425800  94.682  -65.691  54.173  1
425801  94.721  -65.695  54.157  1
425802  94.761  -65.699  54.136  1
425803  94.801  -65.703  54.110  1
425804  94.842  -65.705  54.079  1
425805  94.885  -65.707  54.046  1
425806  94.928  -65.709  54.014  1
425807  94.971  -65.709  53.981  1
425808  95.015  -65.711  53.945  1
425809  95.057  -65.712  53.906  1
425810  95.099  -65.714  53.866  1
425811  95.139  -65.716  53.826  1
425812  95.183  -65.724  53.788  1
425813  95.228  -65.734  53.751  1
425814  95.272  -65.743  53.716  1
425815  95.314  -65.743  53.686  1
425816  95.353  -65.737  53.659  1
425817  95.393  -65.731  53.638  1
425818  95.436  -65.735  53.622  1
425819  95.480  -65.742  53.609  1
425820  95.524  -65.749  53.598  1
425821  95.568  -65.756  53.587  1
425822  95.613  -65.763  53.579  1
425823  95.657  -65.771  53.572  1
425824  95.699  -65.774  53.562  1
425825  95.740  -65.776  53.547  1
425826  95.780  -65.778  53.528  1
425827  95.820  -65.780  53.503  1
425828  95.860  -65.778  53.475  1
425829  95.899  -65.772  53.442  1
425830  95.938  -65.766  53.409  1
425831  95.977  -65.760  53.375  1
425832  96.016  -65.754  53.344  1
425833  96.056  -65.749  53.312  1
425834  96.098  -65.745  53.281  1
425835  96.139  -65.742  53.250  1
425836  96.181  -65.738  53.219  1
425837  96.224  -65.734  53.190  1
425838  96.267  -65.731  53.157  1
425839  96.311  -65.727  53.122  1
425840  96.355  -65.724  53.085  1
425841  96.398  -65.718  53.047  1
425842  96.444  -65.708  53.008  1
425843  96.489  -65.697  52.971  1
425844  96.534  -65.687  52.935  1
425845  96.580  -65.677  52.899  1
425846  96.623  -65.667  52.861  1
425847  96.659  -65.669  52.821  1
425848  96.689  -65.681  52.781  1
425849  96.720  -65.693  52.744  1
425850  96.750  -65.705  52.709  1
425851  96.780  -65.717  52.676  1
425852  96.810  -65.729  52.641  1
425853  96.840  -65.741  52.607  1
425854  96.876  -65.749  52.572  1
425855  96.915  -65.754  52.537  1
425856  96.954  -65.759  52.503  1
425857  96.993  -65.764  52.470  1
425858  97.032  -65.768  52.433  1
425859  97.071  -65.774  52.396  1
425860  97.107  -65.780  52.361  1
425861  97.144  -65.787  52.327  1
425862  97.181  -65.793  52.294  1
425863  97.217  -65.799  52.259  1
425864  97.240  -65.794  52.222  1
425865  97.276  -65.800  52.185  1
425866  97.318  -65.810  52.149  1
425867  97.361  -65.820  52.114  1
425868  97.396  -65.827  52.081  1
425869  97.432  -65.833  52.048  1
425870  97.468  -65.840  52.015  1
425871  97.504  -65.847  51.980  1
425872  97.539  -65.853  51.947  1
425873  97.575  -65.859  51.916  1
425874  97.611  -65.865  51.887  1
425875  97.647  -65.872  51.860  1
425876  97.683  -65.868  51.830  1
425877  97.720  -65.864  51.796  1
425878  97.755  -65.865  51.759  1
425879  97.790  -65.875  51.721  1
425880  97.823  -65.884  51.683  1
425881  97.858  -65.894  51.646  1
425882  97.892  -65.903  51.610  1
425883  97.926  -65.912  51.572  1
425884  97.960  -65.916  51.534  1
425885  97.995  -65.921  51.494  1
425886  98.029  -65.925  51.453  1
425887  98.064  -65.930  51.411  1
425888  98.098  -65.934  51.367  1
425889  98.133  -65.939  51.320  1
425890  98.181  -65.959  51.270  1
425891  98.221  -65.969  51.218  1
425892  98.261  -65.979  51.165  1
425893  98.299  -65.985  51.111  1
425894  98.337  -65.990  51.058  1
425895  98.374  -65.994  51.005  1
425896  98.410  -65.996  50.952  1
425897  98.442  -65.995  50.900  1
425898  98.475  -65.994  50.848  1
425899  98.508  -65.993  50.796  1
425900  98.541  -65.992  50.745  1
425901  98.574  -65.991  50.694  1
425902  98.619  -65.995  50.643  1
425903  98.663  -66.000  50.592  1
425904  98.708  -66.004  50.540  1
425905  98.752  -66.009  50.487  1
425906  98.795  -66.013  50.435  1
425907  98.838  -66.018  50.382  1
425908  98.880  -66.022  50.329  1
425909  98.921  -66.029  50.279  1
425910  98.960  -66.037  50.231  1
425911  98.999  -66.044  50.186  1
425912  99.039  -66.053  50.142  1
425913  99.078  -66.060  50.099  1
425914  99.117  -66.068  50.055  1
425915  99.157  -66.073  50.009  1
425916  99.196  -66.078  49.963  1
425917  99.236  -66.084  49.915  1
425918  99.276  -66.088  49.865  1
425919  99.315  -66.094  49.816  1
425920  99.355  -66.099  49.766  1
425921  99.395  -66.103  49.714  1
425922  99.435  -66.109  49.661  1
425923  99.475  -66.114  49.607  1
425924  99.515  -66.118  49.554  1
425925  99.558  -66.121  49.500  1
425926  99.600  -66.123  49.446  1
425927  99.643  -66.126  49.394  1
425928  99.684  -66.129  49.340  1
425929  99.723  -66.134  49.285  1
425930  99.762  -66.138  49.229  1
425931  99.801  -66.142  49.176  1
425932  99.840  -66.147  49.122  1
425933  99.879  -66.151  49.069  1
425934  99.919  -66.157  49.019  1
425935  99.958  -66.154  48.970  1
425936  99.998  -66.142  48.923  1
425937  100.046  -66.141  48.876  1
425938  100.094  -66.138  48.829  1
425939  100.142  -66.136  48.783  1
425940  100.191  -66.134  48.738  1
425941  100.239  -66.132  48.695  1
425942  100.287  -66.130  48.652  1
425943  100.335  -66.128  48.610  1
425944  100.384  -66.125  48.568  1
425945  100.432  -66.124  48.525  1
425946  100.480  -66.122  48.482  1
425947  100.528  -66.119  48.443  1
426357  88.322  -64.878  55.321  1
426358  88.356  -64.888  55.312  1
426359  88.391  -64.897  55.305  1
426360  88.425  -64.907  55.298  1
426361  88.459  -64.917  55.293  1
426362  88.493  -64.926  55.290  1
426363  88.528  -64.936  55.288  1
426364  88.562  -64.945  55.287  1
426365  88.599  -64.953  55.288  1
426366  88.645  -64.957  55.291  1
426367  88.691  -64.962  55.297  1
426368  88.738  -64.966  55.307  1
426369  88.784  -64.969  55.322  1
426370  88.830  -64.973  55.327  1
426371  88.876  -64.977  55.323  1
426372  88.922  -64.981  55.313  1
426373  88.968  -64.985  55.297  1
426374  89.015  -64.989  55.276  1
426375  89.061  -64.993  55.257  1
426376  89.107  -64.997  55.241  1
426377  89.153  -65.000  55.227  1
426378  89.199  -65.004  55.214  1
426379  89.245  -65.009  55.198  1
426380  89.292  -65.013  55.183  1
426381  89.338  -65.016  55.167  1
426382  89.387  -65.016  55.151  1
426383  89.439  -65.023  55.135  1
426384  89.487  -65.029  55.119  1
426385  89.536  -65.035  55.102  1
426386  89.584  -65.041  55.084  1
426387  89.633  -65.048  55.066  1
426388  89.681  -65.054  55.046  1
426389  89.730  -65.060  55.031  1
426390  89.778  -65.066  55.017  1
426391  89.826  -65.072  55.004  1
426392  89.875  -65.079  54.990  1
426393  89.923  -65.085  54.979  1
426394  89.972  -65.091  54.972  1
426404  90.456  -65.153  54.979  1
426405  90.505  -65.159  54.982  1
426406  90.553  -65.165  54.982  1
426407  90.602  -65.172  54.983  1
426408  90.650  -65.178  54.982  1
426409  90.698  -65.184  54.980  1
426410  90.747  -65.190  54.978  1
426411  90.796  -65.196  54.972  1
426412  90.844  -65.202  54.966  1
426413  90.890  -65.213  54.958  1
426414  90.936  -65.225  54.950  1
426415  90.981  -65.236  54.941  1
426416  91.027  -65.248  54.932  1
426417  91.070  -65.258  54.923  1
426418  91.113  -65.269  54.914  1
426419  91.156  -65.280  54.905  1
426420  91.199  -65.291  54.896  1
426421  91.241  -65.301  54.886  1
426422  91.285  -65.312  54.879  1
426423  91.327  -65.323  54.874  1
426424  91.369  -65.336  54.869  1
426425  91.409  -65.352  54.866  1
426426  91.449  -65.369  54.865  1
426427  91.489  -65.386  54.866  1
426428  91.528  -65.403  54.869  1
426429  91.568  -65.420  54.874  1
426430  91.608  -65.436  54.880  1
426431  91.648  -65.453  54.888  1
426432  91.687  -65.470  54.896  1
426433  91.727  -65.487  54.902  1
426434  91.767  -65.504  54.906  1
426435  91.807  -65.521  54.906  1
426436  91.844  -65.538  54.903  1
426437  91.871  -65.555  54.897  1
426438  91.923  -65.551  54.889  1
426439  91.976  -65.547  54.876  1
426440  92.027  -65.543  54.865  1
426441  92.079  -65.539  54.856  1
426442  92.132  -65.535  54.848  1
426443  92.187  -65.533  54.842  1
426444  92.241  -65.541  54.841  1
426445  92.293  -65.554  54.839  1
426446  92.345  -65.567  54.838  1
426447  92.397  -65.580  54.838  1
426448  92.448  -65.593  54.839  1
426449  92.500  -65.607  54.840  1
426450  92.552  -65.617  54.838  1
426451  92.603  -65.620  54.833  1
426452  92.654  -65.622  54.827  1
426453  92.706  -65.625  54.820  1
426454  92.757  -65.628  54.812  1
426455  92.808  -65.630  54.807  1
426456  92.858  -65.631  54.805  1
426457  92.909  -65.633  54.805  1
426458  92.959  -65.635  54.805  1
426459  93.010  -65.637  54.806  1
426460  93.059  -65.636  54.807  1
426461  93.108  -65.633  54.809  1
426462  93.156  -65.630  54.811  1
426463  93.204  -65.626  54.813  1
426464  93.253  -65.623  54.812  1
426465  93.300  -65.621  54.809  1
426466  93.343  -65.623  54.804  1
426467  93.386  -65.626  54.799  1
426468  93.429  -65.628  54.790  1
426469  93.472  -65.631  54.783  1
426470  93.514  -65.633  54.775  1
426471  93.557  -65.637  54.766  1
426472  93.601  -65.637  54.758  1
426473  93.645  -65.637  54.753  1
426474  93.688  -65.637  54.745  1
426475  93.732  -65.637  54.733  1
426476  93.776  -65.638  54.716  1
426477  93.820  -65.638  54.693  1
426478  93.865  -65.637  54.667  1
426479  93.911  -65.626  54.640  1
426480  93.957  -65.611  54.612  1
426481  93.984  -65.616  54.582  1
426482  94.005  -65.627  54.551  1
426483  94.027  -65.639  54.520  1
426484  94.057  -65.638  54.490  1
426485  94.090  -65.633  54.459  1
426486  94.123  -65.629  54.430  1
426487  94.156  -65.624  54.402  1
426488  94.189  -65.620  54.376  1
426489  94.222  -65.615  54.350  1
426490  94.256  -65.613  54.327  1
426491  94.290  -65.615  54.309  1
426492  94.328  -65.616  54.295  1
426493  94.367  -65.618  54.282  1
426494  94.407  -65.621  54.270  1
426495  94.447  -65.624  54.257  1
426496  94.486  -65.628  54.244  1
426497  94.526  -65.632  54.231  1
426498  94.566  -65.637  54.219  1
426499  94.606  -65.640  54.208  1
426500  94.645  -65.644  54.195  1
426501  94.685  -65.649  54.180  1
426502  94.724  -65.652  54.162  1
426503  94.764  -65.656  54.140  1
426504  94.804  -65.660  54.112  1
426505  94.846  -65.662  54.081  1
426506  94.889  -65.664  54.049  1
426507  94.932  -65.665  54.017  1
426508  94.975  -65.666  53.984  1
426509  95.019  -65.667  53.949  1
426510  95.062  -65.668  53.912  1
426511  95.103  -65.670  53.873  1
426512  95.145  -65.674  53.835  1
426513  95.190  -65.684  53.797  1
426514  95.235  -65.693  53.761  1
426515  95.279  -65.703  53.730  1
426516  95.321  -65.702  53.700  1
426517  95.360  -65.696  53.676  1
426518  95.399  -65.689  53.657  1
426519  95.441  -65.690  53.641  1
426520  95.485  -65.696  53.629  1
426521  95.529  -65.703  53.614  1
426522  95.573  -65.711  53.599  1
426523  95.618  -65.718  53.586  1
426524  95.662  -65.724  53.576  1
426525  95.702  -65.726  53.566  1
426526  95.742  -65.727  53.553  1
426527  95.782  -65.729  53.535  1
426528  95.823  -65.731  53.511  1
426529  95.863  -65.732  53.483  1
426530  95.903  -65.732  53.452  1
426531  95.942  -65.726  53.419  1
426532  95.981  -65.720  53.386  1
426533  96.020  -65.714  53.354  1
426534  96.060  -65.709  53.321  1
426535  96.102  -65.705  53.288  1
426536  96.144  -65.702  53.256  1
426537  96.186  -65.698  53.224  1
426538  96.230  -65.694  53.193  1
426539  96.273  -65.691  53.159  1
426540  96.317  -65.687  53.122  1
426541  96.360  -65.684  53.083  1
426542  96.404  -65.679  53.043  1
426543  96.449  -65.668  53.003  1
426544  96.495  -65.659  52.964  1
426545  96.540  -65.648  52.927  1
426546  96.585  -65.638  52.891  1
426547  96.630  -65.628  52.854  1
426548  96.671  -65.629  52.815  1
426549  96.701  -65.641  52.776  1
426550  96.732  -65.653  52.737  1
426551  96.762  -65.665  52.699  1
426552  96.793  -65.677  52.663  1
426553  96.823  -65.690  52.626  1
426554  96.853  -65.702  52.590  1
426555  96.884  -65.710  52.555  1
426556  96.917  -65.718  52.519  1
426557  96.956  -65.722  52.485  1
426558  96.995  -65.727  52.452  1
426559  97.034  -65.731  52.416  1
426560  97.073  -65.736  52.380  1
426561  97.110  -65.743  52.345  1
426562  97.147  -65.749  52.312  1
426563  97.184  -65.756  52.277  1
426564  97.212  -65.756  52.241  1
426565  97.235  -65.750  52.203  1
426566  97.274  -65.758  52.166  1
426567  97.316  -65.768  52.129  1
426568  97.359  -65.779  52.096  1
426569  97.398  -65.787  52.063  1
426570  97.434  -65.794  52.030  1
426571  97.469  -65.800  51.995  1
426572  97.505  -65.807  51.960  1
426573  97.541  -65.814  51.925  1
426574  97.577  -65.820  51.893  1
426575  97.612  -65.827  51.863  1
426576  97.649  -65.828  51.834  1
426577  97.686  -65.823  51.805  1
426578  97.723  -65.818  51.772  1
426579  97.759  -65.813  51.738  1
426580  97.794  -65.818  51.701  1
426581  97.828  -65.827  51.666  1
426582  97.862  -65.837  51.631  1
426583  97.896  -65.846  51.596  1
426584  97.930  -65.855  51.559  1
426585  97.964  -65.865  51.521  1
426586  97.999  -65.874  51.485  1
426587  98.032  -65.883  51.447  1
426588  98.067  -65.892  51.406  1
426589  98.101  -65.897  51.363  1
426590  98.140  -65.906  51.317  1
426591  98.180  -65.916  51.266  1
426592  98.220  -65.926  51.214  1
426593  98.260  -65.937  51.162  1
426594  98.298  -65.944  51.108  1
426595  98.336  -65.947  51.055  1
426596  98.373  -65.952  51.003  1
426597  98.411  -65.956  50.951  1
426598  98.448  -65.960  50.901  1
426599  98.481  -65.959  50.851  1
426600  98.513  -65.958  50.800  1
426601  98.547  -65.957  50.747  1
426602  98.579  -65.956  50.696  1
426603  98.622  -65.959  50.645  1
426604  98.666  -65.964  50.594  1
426605  98.711  -65.969  50.541  1
426606  98.756  -65.973  50.487  1
426607  98.800  -65.978  50.433  1
426608  98.843  -65.982  50.379  1
426609  98.885  -65.986  50.325  1
426610  98.926  -65.993  50.274  1
426611  98.965  -66.001  50.225  1
426612  99.004  -66.009  50.178  1
426613  99.044  -66.016  50.133  1
426614  99.082  -66.024  50.089  1
426615  99.121  -66.030  50.045  1
426616  99.163  -66.036  49.999  1
426617  99.205  -66.042  49.952  1
426618  99.245  -66.047  49.903  1
426619  99.285  -66.052  49.854  1
426620  99.325  -66.057  49.807  1
426621  99.364  -66.063  49.759  1
426622  99.404  -66.067  49.710  1
426623  99.443  -66.072  49.658  1
426624  99.483  -66.078  49.605  1
426625  99.524  -66.082  49.552  1
426626  99.567  -66.084  49.499  1
426627  99.610  -66.087  49.447  1
426628  99.652  -66.089  49.394  1
426629  99.695  -66.092  49.340  1
426630  99.736  -66.095  49.284  1
426631  99.776  -66.099  49.230  1
426632  99.815  -66.103  49.175  1
426633  99.854  -66.108  49.122  1
426634  99.893  -66.113  49.069  1
426635  99.932  -66.118  49.018  1
426636  99.971  -66.107  48.970  1
426637  100.012  -66.097  48.922  1
426638  100.060  -66.094  48.875  1
426639  100.109  -66.092  48.828  1
426640  100.157  -66.090  48.782  1
426641  100.205  -66.088  48.737  1
426642  100.253  -66.086  48.693  1
426643  100.301  -66.084  48.650  1
426644  100.350  -66.082  48.608  1
426645  100.398  -66.080  48.565  1
426646  100.446  -66.078  48.523  1
426647  100.494  -66.075  48.481  1
426648  100.542  -66.074  48.442  1
427058  88.314  -64.830  55.318  1
427059  88.348  -64.840  55.311  1
427060  88.383  -64.849  55.304  1
427061  88.417  -64.859  55.298  1
427062  88.451  -64.869  55.294  1
427063  88.485  -64.878  55.293  1
427064  88.520  -64.888  55.293  1
427065  88.555  -64.897  55.294  1
427066  88.601  -64.900  55.297  1
427067  88.647  -64.904  55.303  1
427068  88.694  -64.908  55.312  1
427069  88.740  -64.912  55.327  1
427070  88.786  -64.916  55.347  1
427071  88.832  -64.920  55.353  1
427072  88.878  -64.924  55.349  1
427073  88.924  -64.928  55.337  1
427074  88.971  -64.931  55.320  1
427075  89.017  -64.935  55.298  1
427076  89.063  -64.940  55.279  1
427077  89.109  -64.944  55.262  1
427078  89.156  -64.947  55.247  1
427079  89.201  -64.951  55.232  1
427080  89.248  -64.955  55.216  1
427081  89.294  -64.959  55.202  1
427082  89.340  -64.963  55.188  1
427083  89.389  -64.968  55.171  1
427084  89.438  -64.974  55.151  1
427085  89.486  -64.981  55.134  1
427086  89.535  -64.987  55.116  1
427087  89.583  -64.993  55.097  1
427088  89.631  -64.999  55.078  1
427089  89.680  -65.005  55.058  1
427090  89.729  -65.011  55.040  1
427091  89.777  -65.017  55.025  1
427092  89.825  -65.024  55.011  1
427093  89.874  -65.030  54.997  1
427094  89.922  -65.036  54.985  1
427095  89.971  -65.042  54.977  1
427107  90.552  -65.116  54.982  1
427108  90.600  -65.123  54.983  1
427109  90.649  -65.129  54.981  1
427110  90.697  -65.135  54.980  1
427111  90.746  -65.141  54.977  1
427112  90.794  -65.147  54.971  1
427113  90.842  -65.154  54.965  1
427114  90.888  -65.166  54.957  1
427115  90.934  -65.178  54.949  1
427116  90.979  -65.189  54.940  1
427117  91.023  -65.200  54.931  1
427118  91.066  -65.210  54.922  1
427119  91.109  -65.222  54.913  1
427120  91.152  -65.232  54.903  1
427121  91.194  -65.243  54.892  1
427122  91.238  -65.254  54.883  1
427123  91.281  -65.264  54.875  1
427124  91.322  -65.279  54.868  1
427125  91.362  -65.295  54.863  1
427126  91.401  -65.312  54.859  1
427127  91.441  -65.329  54.857  1
427128  91.481  -65.345  54.857  1
427129  91.521  -65.363  54.858  1
427130  91.561  -65.380  54.862  1
427131  91.600  -65.396  54.866  1
427132  91.640  -65.413  54.874  1
427133  91.680  -65.430  54.881  1
427134  91.720  -65.447  54.887  1
427135  91.759  -65.464  54.893  1
427136  91.799  -65.480  54.893  1
427137  91.839  -65.497  54.890  1
427138  91.871  -65.514  54.884  1
427139  91.915  -65.517  54.875  1
427140  91.967  -65.514  54.863  1
427141  92.019  -65.510  54.852  1
427142  92.071  -65.506  54.843  1
427143  92.126  -65.504  54.836  1
427144  92.184  -65.505  54.830  1
427145  92.242  -65.506  54.828  1
427146  92.294  -65.520  54.826  1
427147  92.345  -65.533  54.824  1
427148  92.397  -65.546  54.825  1
427149  92.449  -65.559  54.825  1
427150  92.500  -65.563  54.825  1
427151  92.552  -65.566  54.822  1
427152  92.603  -65.568  54.818  1
427153  92.654  -65.571  54.814  1
427154  92.706  -65.574  54.809  1
427155  92.757  -65.577  54.805  1
427156  92.808  -65.579  54.803  1
427157  92.858  -65.580  54.802  1
427158  92.909  -65.582  54.802  1
427159  92.959  -65.583  54.801  1
427160  93.010  -65.586  54.799  1
427161  93.060  -65.587  54.797  1
427162  93.111  -65.589  54.795  1
427163  93.161  -65.591  54.795  1
427164  93.210  -65.588  54.797  1
427165  93.258  -65.585  54.796  1
427166  93.304  -65.583  54.793  1
427167  93.347  -65.586  54.788  1
427168  93.390  -65.589  54.782  1
427169  93.433  -65.592  54.774  1
427170  93.476  -65.594  54.766  1
427171  93.518  -65.597  54.759  1
427172  93.561  -65.599  54.752  1
427173  93.604  -65.602  54.746  1
427174  93.647  -65.605  54.743  1
427175  93.690  -65.608  54.736  1
427176  93.732  -65.610  54.725  1
427177  93.775  -65.613  54.708  1
427178  93.819  -65.613  54.685  1
427179  93.863  -65.613  54.660  1
427180  93.905  -65.605  54.633  1
427181  93.929  -65.613  54.604  1
427182  93.962  -65.608  54.575  1
427183  93.995  -65.605  54.544  1
427184  94.028  -65.600  54.514  1
427185  94.061  -65.596  54.483  1
427186  94.094  -65.591  54.453  1
427187  94.127  -65.586  54.424  1
427188  94.160  -65.582  54.398  1
427189  94.193  -65.577  54.375  1
427190  94.226  -65.573  54.354  1
427191  94.260  -65.574  54.334  1
427192  94.295  -65.575  54.318  1
427193  94.331  -65.577  54.307  1
427194  94.370  -65.578  54.298  1
427195  94.410  -65.580  54.288  1
427196  94.450  -65.582  54.277  1
427197  94.489  -65.586  54.265  1
427198  94.529  -65.590  54.253  1
427199  94.569  -65.594  54.240  1
427200  94.609  -65.598  54.225  1
427201  94.648  -65.602  54.207  1
427202  94.688  -65.605  54.187  1
427203  94.728  -65.610  54.164  1
427204  94.767  -65.614  54.139  1
427205  94.807  -65.618  54.112  1
427206  94.850  -65.619  54.081  1
427207  94.893  -65.620  54.051  1
427208  94.936  -65.621  54.021  1
427209  94.979  -65.622  53.990  1
427210  95.023  -65.624  53.958  1
427211  95.066  -65.624  53.922  1
427212  95.108  -65.627  53.885  1
427213  95.153  -65.635  53.846  1
427214  95.197  -65.644  53.809  1
427215  95.242  -65.654  53.776  1
427216  95.286  -65.663  53.744  1
427217  95.327  -65.660  53.716  1
427218  95.367  -65.654  53.693  1
427219  95.406  -65.648  53.677  1
427220  95.446  -65.643  53.663  1
427221  95.490  -65.651  53.649  1
427222  95.534  -65.658  53.633  1
427223  95.579  -65.665  53.614  1
427224  95.623  -65.672  53.596  1
427225  95.664  -65.675  53.581  1
427226  95.704  -65.677  53.570  1
427227  95.745  -65.678  53.557  1
427228  95.785  -65.680  53.540  1
427229  95.825  -65.681  53.517  1
427230  95.866  -65.683  53.489  1
427231  95.906  -65.685  53.459  1
427232  95.946  -65.686  53.428  1
427233  95.985  -65.680  53.396  1
427234  96.024  -65.674  53.364  1
427235  96.064  -65.669  53.329  1
427236  96.106  -65.665  53.294  1
427237  96.148  -65.662  53.260  1
427238  96.192  -65.658  53.227  1
427239  96.235  -65.654  53.194  1
427240  96.279  -65.651  53.159  1
427241  96.322  -65.647  53.121  1
427242  96.366  -65.643  53.081  1
427243  96.410  -65.640  53.041  1
427244  96.455  -65.630  52.999  1
427245  96.500  -65.619  52.960  1
427246  96.545  -65.609  52.921  1
427247  96.590  -65.600  52.883  1
427248  96.632  -65.601  52.846  1
427249  96.674  -65.601  52.808  1
427250  96.715  -65.602  52.770  1
427251  96.745  -65.614  52.730  1
427252  96.775  -65.626  52.691  1
427253  96.806  -65.638  52.653  1
427254  96.836  -65.650  52.613  1
427255  96.866  -65.661  52.576  1
427256  96.897  -65.668  52.540  1
427257  96.928  -65.677  52.504  1
427258  96.958  -65.685  52.469  1
427259  96.997  -65.690  52.435  1
427260  97.036  -65.694  52.399  1
427261  97.075  -65.699  52.363  1
427262  97.112  -65.705  52.329  1
427263  97.150  -65.712  52.296  1
427264  97.184  -65.716  52.261  1
427265  97.207  -65.712  52.225  1
427266  97.230  -65.707  52.186  1
427267  97.272  -65.717  52.147  1
427268  97.314  -65.727  52.110  1
427269  97.357  -65.738  52.077  1
427270  97.399  -65.748  52.044  1
427271  97.436  -65.755  52.011  1
427272  97.471  -65.762  51.976  1
427273  97.507  -65.768  51.940  1
427274  97.543  -65.774  51.905  1
427275  97.579  -65.781  51.872  1
427276  97.614  -65.787  51.840  1
427277  97.651  -65.781  51.810  1
427278  97.688  -65.777  51.779  1
427279  97.725  -65.772  51.747  1
427280  97.761  -65.768  51.713  1
427281  97.799  -65.762  51.679  1
427282  97.833  -65.769  51.645  1
427283  97.867  -65.779  51.611  1
427284  97.901  -65.788  51.576  1
427285  97.935  -65.798  51.540  1
427286  97.969  -65.807  51.503  1
427287  98.003  -65.816  51.469  1
427288  98.037  -65.826  51.433  1
427289  98.071  -65.840  51.394  1
427290  98.103  -65.857  51.353  1
427291  98.139  -65.862  51.309  1
427292  98.179  -65.873  51.259  1
427293  98.219  -65.884  51.208  1
427294  98.259  -65.894  51.157  1
427295  98.298  -65.902  51.104  1
427296  98.335  -65.906  51.052  1
427297  98.372  -65.910  51.002  1
427298  98.410  -65.914  50.951  1
427299  98.447  -65.919  50.902  1
427300  98.485  -65.922  50.853  1
427301  98.519  -65.923  50.803  1
427302  98.552  -65.922  50.751  1
427303  98.585  -65.921  50.701  1
427304  98.625  -65.923  50.651  1
427305  98.669  -65.928  50.598  1
427306  98.714  -65.932  50.544  1
427307  98.759  -65.937  50.488  1
427308  98.803  -65.941  50.432  1
427309  98.848  -65.946  50.377  1
427310  98.890  -65.950  50.323  1
427311  98.931  -65.957  50.270  1
427312  98.970  -65.965  50.220  1
427313  99.009  -65.972  50.171  1
427314  99.047  -65.980  50.124  1
427315  99.084  -65.987  50.079  1
427316  99.124  -65.991  50.034  1
427317  99.166  -65.996  49.987  1
427318  99.211  -66.004  49.939  1
427319  99.254  -66.011  49.889  1
427320  99.293  -66.016  49.841  1
427321  99.333  -66.021  49.794  1
427322  99.373  -66.026  49.748  1
427323  99.413  -66.031  49.702  1
427324  99.452  -66.036  49.654  1
427325  99.492  -66.041  49.601  1
427326  99.534  -66.045  49.548  1
427327  99.576  -66.047  49.495  1
427328  99.619  -66.050  49.443  1
427329  99.661  -66.053  49.390  1
427330  99.704  -66.056  49.337  1
427331  99.747  -66.058  49.283  1
427332  99.789  -66.060  49.229  1
427333  99.828  -66.065  49.175  1
427334  99.867  -66.069  49.121  1
427335  99.907  -66.074  49.068  1
427336  99.945  -66.072  49.017  1
427337  99.984  -66.060  48.968  1
427338  100.027  -66.050  48.922  1
427339  100.075  -66.048  48.874  1
427340  100.123  -66.046  48.827  1
427341  100.171  -66.044  48.781  1
427342  100.219  -66.042  48.735  1
427343  100.268  -66.040  48.693  1
427344  100.316  -66.038  48.650  1
427345  100.364  -66.036  48.606  1
427346  100.412  -66.034  48.564  1
427347  100.461  -66.031  48.522  1
427348  100.509  -66.029  48.480  1
427759  88.307  -64.781  55.315  1
427760  88.340  -64.791  55.308  1
427761  88.375  -64.801  55.303  1
427762  88.409  -64.810  55.299  1
427763  88.444  -64.820  55.296  1
427764  88.478  -64.829  55.295  1
427765  88.512  -64.839  55.297  1
427766  88.557  -64.844  55.300  1
427767  88.604  -64.847  55.305  1
427768  88.650  -64.851  55.312  1
427769  88.696  -64.855  55.323  1
427770  88.742  -64.859  55.340  1
427771  88.788  -64.862  55.361  1
427772  88.834  -64.867  55.370  1
427773  88.881  -64.871  55.367  1
427774  88.927  -64.875  55.355  1
427775  88.973  -64.878  55.339  1
427776  89.019  -64.882  55.318  1
427777  89.065  -64.886  55.300  1
427778  89.112  -64.891  55.283  1
427779  89.158  -64.894  55.267  1
427780  89.204  -64.898  55.250  1
427781  89.250  -64.902  55.235  1
427782  89.296  -64.906  55.221  1
427783  89.344  -64.915  55.207  1
427784  89.389  -64.922  55.192  1
427785  89.437  -64.925  55.170  1
427786  89.485  -64.931  55.150  1
427787  89.533  -64.938  55.131  1
427788  89.582  -64.944  55.111  1
427789  89.630  -64.950  55.090  1
427790  89.679  -64.957  55.069  1
427791  89.727  -64.963  55.049  1
427792  89.776  -64.969  55.032  1
427793  89.824  -64.975  55.016  1
427794  89.873  -64.981  55.002  1
427795  89.921  -64.987  54.989  1
427796  89.969  -64.993  54.980  1
427797  90.018  -65.000  54.973  1
427810  90.648  -65.079  54.981  1
427811  90.696  -65.086  54.979  1
427812  90.745  -65.092  54.976  1
427813  90.793  -65.098  54.970  1
427814  90.840  -65.107  54.963  1
427815  90.886  -65.119  54.956  1
427816  90.932  -65.130  54.948  1
427817  90.976  -65.141  54.939  1
427818  91.019  -65.152  54.930  1
427819  91.062  -65.163  54.920  1
427820  91.105  -65.174  54.910  1
427821  91.148  -65.185  54.900  1
427822  91.191  -65.195  54.889  1
427823  91.234  -65.206  54.879  1
427824  91.275  -65.221  54.870  1
427825  91.314  -65.238  54.863  1
427826  91.354  -65.255  54.857  1
427827  91.394  -65.272  54.852  1
427828  91.434  -65.289  54.849  1
427829  91.473  -65.305  54.848  1
427830  91.513  -65.322  54.848  1
427831  91.553  -65.339  54.850  1
427832  91.593  -65.356  54.852  1
427833  91.633  -65.373  54.858  1
427834  91.672  -65.389  54.865  1
427835  91.712  -65.406  54.871  1
427836  91.752  -65.423  54.878  1
427837  91.792  -65.440  54.879  1
427838  91.831  -65.457  54.877  1
427839  91.871  -65.474  54.870  1
427840  91.907  -65.484  54.862  1
427841  91.959  -65.480  54.851  1
427842  92.011  -65.477  54.840  1
427843  92.066  -65.474  54.831  1
427844  92.124  -65.475  54.824  1
427845  92.182  -65.475  54.820  1
427846  92.240  -65.475  54.816  1
427847  92.294  -65.485  54.814  1
427848  92.346  -65.498  54.812  1
427849  92.398  -65.506  54.811  1
427850  92.449  -65.509  54.811  1
427851  92.500  -65.511  54.810  1
427852  92.552  -65.514  54.807  1
427853  92.603  -65.517  54.804  1
427854  92.654  -65.520  54.802  1
427855  92.706  -65.523  54.800  1
427856  92.757  -65.526  54.799  1
427857  92.808  -65.527  54.798  1
427858  92.858  -65.530  54.797  1
427859  92.909  -65.531  54.796  1
427860  92.959  -65.533  54.793  1
427861  93.010  -65.535  54.790  1
427862  93.060  -65.536  54.786  1
427863  93.111  -65.538  54.782  1
427864  93.161  -65.539  54.779  1
427865  93.212  -65.542  54.778  1
427866  93.262  -65.543  54.775  1
427867  93.308  -65.546  54.771  1
427868  93.351  -65.549  54.765  1
427869  93.394  -65.551  54.759  1
427870  93.436  -65.553  54.753  1
427871  93.479  -65.555  54.747  1
427872  93.521  -65.558  54.741  1
427873  93.564  -65.560  54.735  1
427874  93.607  -65.563  54.732  1
427875  93.649  -65.565  54.730  1
427876  93.692  -65.568  54.725  1
427877  93.734  -65.570  54.715  1
427878  93.777  -65.572  54.699  1
427879  93.820  -65.574  54.676  1
427880  93.863  -65.577  54.651  1
427881  93.900  -65.575  54.623  1
427882  93.932  -65.571  54.594  1
427883  93.966  -65.566  54.564  1
427884  93.998  -65.561  54.536  1
427885  94.032  -65.557  54.506  1
427886  94.064  -65.552  54.477  1
427887  94.098  -65.549  54.449  1
427888  94.131  -65.544  54.421  1
427889  94.164  -65.539  54.398  1
427890  94.197  -65.535  54.378  1
427891  94.230  -65.532  54.361  1
427892  94.265  -65.533  54.345  1
427893  94.299  -65.535  54.330  1
427894  94.335  -65.536  54.320  1
427895  94.374  -65.538  54.312  1
427896  94.413  -65.539  54.305  1
427897  94.453  -65.541  54.295  1
427898  94.492  -65.543  54.285  1
427899  94.532  -65.547  54.273  1
427900  94.572  -65.552  54.259  1
427901  94.612  -65.555  54.241  1
427902  94.651  -65.559  54.220  1
427903  94.691  -65.563  54.195  1
427904  94.731  -65.568  54.168  1
427905  94.770  -65.571  54.141  1
427906  94.811  -65.574  54.112  1
427907  94.854  -65.576  54.082  1
427908  94.897  -65.577  54.053  1
427909  94.941  -65.578  54.025  1
427910  94.983  -65.579  53.997  1
427911  95.027  -65.580  53.967  1
427912  95.070  -65.581  53.933  1
427913  95.114  -65.586  53.896  1
427914  95.160  -65.596  53.859  1
427915  95.204  -65.605  53.823  1
427916  95.249  -65.614  53.791  1
427917  95.294  -65.624  53.761  1
427918  95.334  -65.619  53.733  1
427919  95.373  -65.612  53.713  1
427920  95.412  -65.606  53.698  1
427921  95.452  -65.600  53.685  1
427922  95.495  -65.605  53.673  1
427923  95.539  -65.612  53.654  1
427924  95.584  -65.619  53.633  1
427925  95.626  -65.624  53.611  1
427926  95.667  -65.626  53.590  1
427927  95.707  -65.627  53.576  1
427928  95.747  -65.629  53.561  1
427929  95.788  -65.630  53.543  1
427930  95.828  -65.632  53.519  1
427931  95.868  -65.634  53.493  1
427932  95.908  -65.636  53.464  1
427933  95.949  -65.637  53.434  1
427934  95.989  -65.639  53.402  1
427935  96.028  -65.633  53.371  1
427936  96.068  -65.629  53.334  1
427937  96.110  -65.625  53.298  1
427938  96.154  -65.621  53.262  1
427939  96.197  -65.618  53.227  1
427940  96.241  -65.615  53.192  1
427941  96.285  -65.611  53.157  1
427942  96.328  -65.607  53.119  1
427943  96.372  -65.603  53.079  1
427944  96.415  -65.599  53.040  1
427945  96.461  -65.590  52.999  1
427946  96.506  -65.580  52.958  1
427947  96.550  -65.573  52.916  1
427948  96.592  -65.573  52.876  1
427949  96.633  -65.574  52.838  1
427950  96.675  -65.574  52.800  1
427951  96.717  -65.574  52.762  1
427952  96.758  -65.575  52.724  1
427953  96.788  -65.587  52.685  1
427954  96.819  -65.599  52.646  1
427955  96.849  -65.611  52.604  1
427956  96.880  -65.619  52.565  1
427957  96.910  -65.627  52.527  1
427958  96.941  -65.635  52.490  1
427959  96.971  -65.643  52.454  1
427960  97.002  -65.652  52.419  1
427961  97.038  -65.658  52.383  1
427962  97.077  -65.662  52.348  1
427963  97.115  -65.668  52.313  1
427964  97.152  -65.674  52.280  1
427965  97.179  -65.673  52.245  1
427966  97.202  -65.668  52.209  1
427967  97.227  -65.665  52.171  1
427968  97.270  -65.676  52.129  1
427969  97.312  -65.686  52.093  1
427970  97.355  -65.696  52.059  1
427971  97.397  -65.707  52.025  1
427972  97.437  -65.716  51.991  1
427973  97.473  -65.723  51.957  1
427974  97.509  -65.729  51.920  1
427975  97.544  -65.736  51.886  1
427976  97.580  -65.742  51.852  1
427977  97.617  -65.740  51.818  1
427978  97.654  -65.736  51.786  1
427979  97.690  -65.731  51.755  1
427980  97.727  -65.727  51.722  1
427981  97.764  -65.721  51.688  1
427982  97.801  -65.717  51.655  1
427983  97.838  -65.712  51.623  1
427984  97.872  -65.721  51.590  1
427985  97.906  -65.731  51.555  1
427986  97.940  -65.740  51.519  1
427987  97.972  -65.758  51.484  1
427988  98.005  -65.778  51.451  1
427989  98.037  -65.797  51.416  1
427990  98.071  -65.812  51.379  1
427991  98.106  -65.818  51.340  1
427992  98.141  -65.823  51.298  1
427993  98.178  -65.831  51.250  1
427994  98.218  -65.840  51.201  1
427995  98.258  -65.851  51.151  1
427996  98.297  -65.859  51.099  1
427997  98.335  -65.864  51.048  1
427998  98.372  -65.868  51.000  1
427999  98.409  -65.872  50.951  1
428000  98.447  -65.876  50.903  1
428001  98.484  -65.881  50.855  1
428002  98.521  -65.884  50.805  1
428003  98.557  -65.887  50.755  1
428004  98.590  -65.886  50.706  1
428005  98.628  -65.887  50.656  1
428006  98.672  -65.891  50.603  1
428007  98.717  -65.896  50.547  1
428008  98.762  -65.900  50.489  1
428009  98.806  -65.905  50.431  1
428010  98.851  -65.909  50.374  1
428011  98.896  -65.914  50.319  1
428012  98.936  -65.921  50.265  1
428013  98.974  -65.928  50.213  1
428014  99.011  -65.935  50.162  1
428015  99.049  -65.943  50.113  1
428016  99.087  -65.948  50.066  1
428017  99.128  -65.952  50.020  1
428018  99.168  -65.956  49.973  1
428019  99.213  -65.964  49.924  1
428020  99.258  -65.972  49.874  1
428021  99.302  -65.980  49.828  1
428022  99.342  -65.985  49.781  1
428023  99.381  -65.990  49.736  1
428024  99.421  -65.995  49.692  1
428025  99.461  -66.000  49.647  1
428026  99.501  -66.005  49.596  1
428027  99.543  -66.008  49.543  1
428028  99.585  -66.011  49.490  1
428029  99.628  -66.013  49.437  1
428030  99.671  -66.016  49.385  1
428031  99.713  -66.019  49.333  1
428032  99.756  -66.022  49.280  1
428033  99.798  -66.024  49.227  1
428034  99.841  -66.027  49.173  1
428035  99.881  -66.031  49.119  1
428036  99.920  -66.035  49.066  1
428037  99.959  -66.025  49.015  1
428038  99.998  -66.013  48.967  1
428039  100.041  -66.004  48.921  1
428040  100.089  -66.003  48.873  1
428041  100.137  -66.000  48.826  1
428042  100.186  -65.998  48.780  1
428043  100.234  -65.996  48.734  1
428044  100.282  -65.994  48.691  1
428045  100.330  -65.992  48.649  1
428046  100.379  -65.990  48.605  1
428047  100.427  -65.988  48.562  1
428048  100.475  -65.985  48.520  1
428049  100.524  -65.984  48.478  1
428460  88.298  -64.733  55.312  1
428461  88.333  -64.743  55.306  1
428462  88.367  -64.753  55.302  1
428463  88.401  -64.762  55.299  1
428464  88.435  -64.772  55.297  1
428465  88.470  -64.781  55.297  1
428466  88.514  -64.786  55.300  1
428467  88.560  -64.790  55.304  1
428468  88.606  -64.794  55.310  1
428469  88.652  -64.798  55.318  1
428470  88.698  -64.802  55.330  1
428471  88.745  -64.806  55.346  1
428472  88.790  -64.809  55.368  1
428473  88.837  -64.813  55.376  1
428474  88.883  -64.817  55.374  1
428475  88.929  -64.822  55.363  1
428476  88.975  -64.825  55.348  1
428477  89.022  -64.829  55.331  1
428478  89.067  -64.833  55.316  1
428479  89.114  -64.837  55.301  1
428480  89.160  -64.841  55.285  1
428481  89.206  -64.845  55.268  1
428482  89.259  -64.846  55.253  1
428483  89.312  -64.850  55.239  1
428484  89.349  -64.869  55.225  1
428485  89.390  -64.881  55.213  1
428486  89.438  -64.883  55.191  1
428487  89.485  -64.885  55.167  1
428488  89.532  -64.888  55.146  1
428489  89.581  -64.895  55.126  1
428490  89.629  -64.901  55.103  1
428491  89.678  -64.907  55.080  1
428492  89.726  -64.913  55.059  1
428493  89.774  -64.919  55.040  1
428494  89.823  -64.925  55.023  1
428495  89.872  -64.932  55.007  1
428496  89.920  -64.938  54.995  1
428497  89.968  -64.944  54.985  1
428498  90.017  -64.950  54.977  1
428509  90.549  -65.019  54.981  1
428510  90.598  -65.025  54.981  1
428511  90.647  -65.031  54.981  1
428512  90.695  -65.037  54.979  1
428513  90.743  -65.043  54.975  1
428514  90.792  -65.049  54.969  1
428515  90.838  -65.060  54.962  1
428516  90.884  -65.072  54.955  1
428517  90.929  -65.083  54.946  1
428518  90.972  -65.094  54.937  1
428519  91.015  -65.105  54.928  1
428520  91.058  -65.116  54.918  1
428521  91.101  -65.126  54.907  1
428522  91.144  -65.137  54.897  1
428523  91.187  -65.148  54.886  1
428524  91.227  -65.164  54.876  1
428525  91.267  -65.181  54.866  1
428526  91.307  -65.198  54.857  1
428527  91.347  -65.214  54.851  1
428528  91.386  -65.232  54.845  1
428529  91.426  -65.248  54.841  1
428530  91.466  -65.265  54.838  1
428531  91.506  -65.282  54.837  1
428532  91.545  -65.298  54.838  1
428533  91.585  -65.316  54.839  1
428534  91.625  -65.333  54.843  1
428535  91.665  -65.349  54.849  1
428536  91.705  -65.366  54.854  1
428537  91.744  -65.383  54.861  1
428538  91.784  -65.400  54.866  1
428539  91.824  -65.417  54.865  1
428540  91.864  -65.433  54.861  1
428541  91.899  -65.451  54.852  1
428542  91.950  -65.447  54.841  1
428543  92.005  -65.445  54.830  1
428544  92.064  -65.445  54.820  1
428545  92.122  -65.445  54.813  1
428546  92.180  -65.446  54.808  1
428547  92.238  -65.446  54.806  1
428548  92.294  -65.449  54.802  1
428549  92.346  -65.452  54.799  1
428550  92.397  -65.455  54.796  1
428551  92.448  -65.458  54.796  1
428552  92.500  -65.461  54.795  1
428553  92.551  -65.464  54.793  1
428554  92.602  -65.466  54.791  1
428555  92.654  -65.469  54.791  1
428556  92.705  -65.471  54.792  1
428557  92.757  -65.474  54.793  1
428558  92.808  -65.477  54.792  1
428559  92.858  -65.479  54.790  1
428560  92.908  -65.481  54.788  1
428561  92.958  -65.483  54.784  1
428562  93.008  -65.486  54.779  1
428563  93.058  -65.488  54.773  1
428564  93.109  -65.490  54.768  1
428565  93.158  -65.492  54.763  1
428566  93.209  -65.495  54.759  1
428567  93.259  -65.497  54.754  1
428568  93.307  -65.501  54.748  1
428569  93.351  -65.503  54.742  1
428570  93.393  -65.505  54.736  1
428571  93.436  -65.508  54.730  1
428572  93.479  -65.511  54.725  1
428573  93.521  -65.513  54.720  1
428574  93.564  -65.515  54.717  1
428575  93.607  -65.517  54.715  1
428576  93.649  -65.520  54.714  1
428577  93.692  -65.522  54.709  1
428578  93.734  -65.525  54.699  1
428579  93.777  -65.527  54.684  1
428580  93.820  -65.530  54.662  1
428581  93.864  -65.533  54.637  1
428582  93.903  -65.533  54.611  1
428583  93.936  -65.528  54.584  1
428584  93.969  -65.524  54.555  1
428585  94.002  -65.519  54.529  1
428586  94.035  -65.514  54.502  1
428587  94.068  -65.510  54.475  1
428588  94.101  -65.505  54.450  1
428589  94.134  -65.501  54.426  1
428590  94.168  -65.496  54.405  1
428591  94.200  -65.492  54.388  1
428592  94.235  -65.492  54.373  1
428593  94.269  -65.494  54.359  1
428594  94.304  -65.496  54.345  1
428595  94.339  -65.497  54.336  1
428596  94.378  -65.499  54.327  1
428597  94.417  -65.500  54.319  1
428598  94.456  -65.502  54.311  1
428599  94.496  -65.503  54.302  1
428600  94.535  -65.505  54.291  1
428601  94.575  -65.508  54.276  1
428602  94.615  -65.513  54.257  1
428603  94.654  -65.517  54.233  1
428604  94.694  -65.521  54.204  1
428605  94.734  -65.525  54.174  1
428606  94.773  -65.529  54.144  1
428607  94.815  -65.531  54.113  1
428608  94.858  -65.532  54.083  1
428609  94.901  -65.533  54.056  1
428610  94.945  -65.534  54.030  1
428611  94.987  -65.536  54.004  1
428612  95.031  -65.538  53.975  1
428613  95.075  -65.542  53.942  1
428614  95.119  -65.546  53.907  1
428615  95.166  -65.555  53.871  1
428616  95.211  -65.565  53.837  1
428617  95.256  -65.574  53.807  1
428618  95.301  -65.583  53.778  1
428619  95.340  -65.577  53.751  1
428620  95.380  -65.571  53.731  1
428621  95.419  -65.564  53.718  1
428622  95.458  -65.558  53.706  1
428623  95.500  -65.559  53.694  1
428624  95.544  -65.567  53.675  1
428625  95.588  -65.574  53.652  1
428626  95.628  -65.575  53.628  1
428627  95.669  -65.577  53.603  1
428628  95.709  -65.578  53.585  1
428629  95.750  -65.580  53.567  1
428630  95.790  -65.582  53.547  1
428631  95.830  -65.583  53.524  1
428632  95.871  -65.585  53.496  1
428633  95.911  -65.586  53.466  1
428634  95.951  -65.588  53.436  1
428635  95.991  -65.590  53.405  1
428636  96.032  -65.591  53.374  1
428637  96.073  -65.589  53.337  1
428638  96.116  -65.585  53.300  1
428639  96.160  -65.581  53.263  1
428640  96.203  -65.577  53.226  1
428641  96.247  -65.574  53.190  1
428642  96.291  -65.571  53.155  1
428643  96.334  -65.567  53.117  1
428644  96.378  -65.563  53.078  1
428645  96.421  -65.560  53.039  1
428646  96.466  -65.551  53.000  1
428647  96.510  -65.546  52.959  1
428648  96.552  -65.546  52.917  1
428649  96.594  -65.546  52.876  1
428650  96.636  -65.546  52.833  1
428651  96.677  -65.546  52.794  1
428652  96.719  -65.546  52.755  1
428653  96.761  -65.547  52.717  1
428654  96.801  -65.549  52.678  1
428655  96.831  -65.561  52.639  1
428656  96.862  -65.569  52.597  1
428657  96.893  -65.577  52.555  1
428658  96.924  -65.586  52.516  1
428659  96.954  -65.593  52.478  1
428660  96.985  -65.602  52.442  1
428661  97.016  -65.610  52.407  1
428662  97.046  -65.618  52.370  1
428663  97.079  -65.625  52.334  1
428664  97.117  -65.630  52.300  1
428665  97.151  -65.634  52.266  1
428666  97.174  -65.630  52.231  1
428667  97.197  -65.624  52.195  1
428668  97.226  -65.624  52.156  1
428669  97.268  -65.634  52.115  1
428670  97.310  -65.645  52.078  1
428671  97.353  -65.655  52.042  1
428672  97.395  -65.666  52.007  1
428673  97.438  -65.676  51.973  1
428674  97.475  -65.684  51.939  1
428675  97.511  -65.690  51.904  1
428676  97.546  -65.696  51.869  1
428677  97.583  -65.699  51.833  1
428678  97.619  -65.695  51.799  1
428679  97.656  -65.690  51.765  1
428680  97.693  -65.685  51.732  1
428681  97.730  -65.680  51.698  1
428682  97.767  -65.676  51.664  1
428683  97.803  -65.671  51.632  1
428684  97.840  -65.667  51.600  1
428685  97.875  -65.676  51.568  1
428686  97.907  -65.696  51.533  1
428687  97.939  -65.715  51.498  1
428688  97.971  -65.735  51.463  1
428689  98.004  -65.755  51.431  1
428690  98.038  -65.768  51.397  1
428691  98.073  -65.774  51.362  1
428692  98.108  -65.779  51.324  1
428693  98.144  -65.784  51.284  1
428694  98.179  -65.789  51.237  1
428695  98.217  -65.798  51.191  1
428696  98.257  -65.808  51.143  1
428697  98.297  -65.818  51.094  1
428698  98.334  -65.821  51.044  1
428699  98.371  -65.826  50.997  1
428700  98.409  -65.830  50.950  1
428701  98.446  -65.834  50.903  1
428702  98.483  -65.838  50.856  1
428703  98.521  -65.843  50.806  1
428704  98.558  -65.847  50.759  1
428705  98.595  -65.851  50.710  1
428706  98.630  -65.851  50.659  1
428707  98.675  -65.856  50.607  1
428708  98.720  -65.860  50.549  1
428709  98.765  -65.865  50.490  1
428710  98.809  -65.869  50.430  1
428711  98.853  -65.874  50.370  1
428712  98.897  -65.878  50.313  1
428713  98.938  -65.884  50.258  1
428714  98.976  -65.891  50.204  1
428715  99.013  -65.898  50.152  1
428716  99.051  -65.905  50.100  1
428717  99.091  -65.909  50.051  1
428718  99.131  -65.913  50.004  1
428719  99.171  -65.917  49.957  1
428720  99.215  -65.924  49.908  1
428721  99.260  -65.932  49.860  1
428722  99.305  -65.941  49.813  1
428723  99.350  -65.948  49.767  1
428724  99.390  -65.953  49.724  1
428725  99.430  -65.959  49.681  1
428726  99.470  -65.964  49.638  1
428727  99.509  -65.969  49.588  1
428728  99.552  -65.972  49.536  1
428729  99.594  -65.975  49.483  1
428730  99.637  -65.977  49.430  1
428731  99.680  -65.980  49.377  1
428732  99.722  -65.982  49.325  1
428733  99.765  -65.984  49.274  1
428734  99.807  -65.988  49.223  1
428735  99.850  -65.990  49.170  1
428736  99.893  -65.993  49.115  1
428737  99.934  -65.991  49.063  1
428738  99.973  -65.978  49.014  1
428739  100.011  -65.966  48.967  1
428740  100.055  -65.959  48.920  1
428741  100.104  -65.956  48.872  1
428742  100.152  -65.954  48.825  1
428743  100.200  -65.952  48.779  1
428744  100.248  -65.950  48.734  1
428745  100.296  -65.948  48.690  1
428746  100.345  -65.946  48.647  1
428747  100.393  -65.944  48.603  1
428748  100.441  -65.941  48.560  1
428749  100.489  -65.940  48.519  1
429161  88.290  -64.685  55.309  1
429162  88.325  -64.694  55.304  1
429163  88.359  -64.704  55.301  1
429164  88.393  -64.713  55.299  1
429165  88.427  -64.723  55.298  1
429166  88.470  -64.729  55.298  1
429167  88.516  -64.733  55.302  1
429168  88.562  -64.737  55.307  1
429169  88.608  -64.740  55.314  1
429170  88.654  -64.744  55.323  1
429171  88.700  -64.749  55.334  1
429172  88.747  -64.753  55.350  1
429173  88.793  -64.756  55.371  1
429174  88.839  -64.760  55.380  1
429175  88.885  -64.764  55.379  1
429176  88.931  -64.768  55.370  1
429177  88.978  -64.772  55.356  1
429178  89.024  -64.776  55.343  1
429179  89.070  -64.780  55.331  1
429180  89.116  -64.784  55.319  1
429181  89.162  -64.787  55.303  1
429182  89.222  -64.785  55.285  1
429183  89.280  -64.785  55.270  1
429184  89.317  -64.803  55.257  1
429185  89.354  -64.822  55.244  1
429186  89.391  -64.840  55.232  1
429187  89.439  -64.842  55.212  1
429188  89.486  -64.844  55.189  1
429189  89.533  -64.847  55.164  1
429190  89.581  -64.849  55.139  1
429191  89.628  -64.852  55.113  1
429192  89.676  -64.858  55.090  1
429193  89.725  -64.864  55.068  1
429194  89.773  -64.871  55.049  1
429195  89.822  -64.877  55.031  1
429196  89.870  -64.883  55.014  1
429197  89.918  -64.889  55.001  1
429198  89.967  -64.895  54.991  1
429199  90.016  -64.901  54.983  1
429200  90.064  -64.907  54.976  1
429205  90.306  -64.938  54.972  1
429206  90.355  -64.944  54.975  1
429207  90.403  -64.950  54.977  1
429208  90.452  -64.957  54.979  1
429209  90.500  -64.963  54.981  1
429210  90.548  -64.969  54.980  1
429211  90.597  -64.975  54.981  1
429212  90.646  -64.982  54.980  1
429213  90.694  -64.988  54.978  1
429214  90.742  -64.994  54.974  1
429215  90.790  -65.002  54.968  1
429216  90.836  -65.013  54.961  1
429217  90.881  -65.025  54.953  1
429218  90.926  -65.035  54.945  1
429219  90.968  -65.047  54.935  1
429220  91.011  -65.057  54.925  1
429221  91.054  -65.068  54.915  1
429222  91.097  -65.079  54.905  1
429223  91.140  -65.090  54.894  1
429224  91.179  -65.107  54.883  1
429225  91.219  -65.124  54.873  1
429226  91.259  -65.141  54.862  1
429227  91.299  -65.157  54.853  1
429228  91.338  -65.174  54.845  1
429229  91.378  -65.191  54.837  1
429230  91.418  -65.208  54.832  1
429231  91.458  -65.225  54.829  1
429232  91.498  -65.242  54.827  1
429233  91.537  -65.258  54.827  1
429234  91.577  -65.275  54.827  1
429235  91.617  -65.292  54.830  1
429236  91.657  -65.309  54.834  1
429237  91.697  -65.326  54.838  1
429238  91.736  -65.342  54.846  1
429239  91.776  -65.359  54.853  1
429240  91.816  -65.376  54.855  1
429241  91.856  -65.393  54.851  1
429242  91.895  -65.410  54.843  1
429243  91.945  -65.416  54.831  1
429244  92.003  -65.414  54.820  1
429245  92.061  -65.411  54.809  1
429246  92.119  -65.408  54.801  1
429247  92.176  -65.405  54.796  1
429248  92.235  -65.403  54.793  1
429249  92.292  -65.402  54.789  1
429250  92.349  -65.402  54.786  1
429251  92.401  -65.405  54.784  1
429252  92.452  -65.408  54.782  1
429253  92.503  -65.411  54.780  1
429254  92.555  -65.414  54.779  1
429255  92.606  -65.416  54.779  1
429256  92.657  -65.419  54.780  1
429257  92.709  -65.421  54.781  1
429258  92.760  -65.424  54.781  1
429259  92.809  -65.429  54.781  1
429260  92.857  -65.432  54.779  1
429261  92.905  -65.435  54.776  1
429262  92.955  -65.437  54.771  1
429263  93.005  -65.439  54.766  1
429264  93.055  -65.442  54.759  1
429265  93.105  -65.444  54.752  1
429266  93.155  -65.446  54.746  1
429267  93.205  -65.449  54.740  1
429268  93.256  -65.451  54.734  1
429269  93.303  -65.455  54.727  1
429270  93.350  -65.458  54.719  1
429271  93.393  -65.461  54.713  1
429272  93.435  -65.463  54.707  1
429273  93.478  -65.465  54.703  1
429274  93.521  -65.467  54.700  1
429275  93.564  -65.470  54.697  1
429276  93.606  -65.473  54.696  1
429277  93.649  -65.475  54.695  1
429278  93.692  -65.477  54.690  1
429279  93.734  -65.480  54.681  1
429280  93.777  -65.483  54.668  1
429281  93.822  -65.486  54.647  1
429282  93.866  -65.489  54.624  1
429283  93.907  -65.489  54.599  1
429284  93.940  -65.486  54.575  1
429285  93.973  -65.481  54.550  1
429286  94.006  -65.477  54.526  1
429287  94.039  -65.472  54.502  1
429288  94.072  -65.467  54.480  1
429289  94.105  -65.463  54.459  1
429290  94.138  -65.458  54.437  1
429291  94.171  -65.454  54.417  1
429292  94.205  -65.452  54.401  1
429293  94.240  -65.453  54.387  1
429294  94.274  -65.455  54.375  1
429295  94.309  -65.456  54.362  1
429296  94.343  -65.458  54.353  1
429297  94.381  -65.459  54.344  1
429298  94.420  -65.461  54.335  1
429299  94.460  -65.462  54.325  1
429300  94.499  -65.464  54.315  1
429301  94.539  -65.465  54.302  1
429302  94.578  -65.467  54.287  1
429303  94.618  -65.470  54.267  1
429304  94.657  -65.474  54.242  1
429305  94.697  -65.478  54.214  1
429306  94.737  -65.482  54.182  1
429307  94.776  -65.486  54.149  1
429308  94.819  -65.488  54.117  1
429309  94.862  -65.489  54.088  1
429310  94.905  -65.490  54.062  1
429311  94.949  -65.491  54.036  1
429312  94.992  -65.495  54.009  1
429313  95.036  -65.499  53.980  1
429314  95.080  -65.502  53.949  1
429315  95.124  -65.505  53.916  1
429316  95.171  -65.515  53.883  1
429317  95.217  -65.525  53.851  1
429318  95.263  -65.535  53.822  1
429319  95.308  -65.543  53.795  1
429320  95.347  -65.536  53.769  1
429321  95.386  -65.530  53.750  1
429322  95.425  -65.524  53.737  1
429323  95.464  -65.517  53.727  1
429324  95.505  -65.514  53.715  1
429325  95.549  -65.521  53.696  1
429326  95.591  -65.524  53.672  1
429327  95.631  -65.526  53.646  1
429328  95.671  -65.527  53.618  1
429329  95.711  -65.529  53.595  1
429330  95.752  -65.531  53.574  1
429331  95.793  -65.533  53.552  1
429332  95.833  -65.534  53.529  1
429333  95.873  -65.536  53.499  1
429334  95.913  -65.539  53.468  1
429335  95.954  -65.544  53.436  1
429336  95.993  -65.549  53.405  1
429337  96.034  -65.555  53.374  1
429338  96.076  -65.550  53.338  1
429339  96.120  -65.546  53.300  1
429340  96.164  -65.543  53.261  1
429341  96.208  -65.539  53.223  1
429342  96.252  -65.535  53.187  1
429343  96.296  -65.531  53.152  1
429344  96.339  -65.527  53.114  1
429345  96.383  -65.524  53.076  1
429346  96.427  -65.520  53.037  1
429347  96.470  -65.518  52.998  1
429348  96.511  -65.518  52.958  1
429349  96.553  -65.518  52.917  1
429350  96.595  -65.518  52.875  1
429351  96.636  -65.519  52.831  1
429352  96.678  -65.519  52.789  1
429353  96.720  -65.519  52.749  1
429354  96.761  -65.519  52.710  1
429355  96.803  -65.519  52.671  1
429356  96.845  -65.520  52.632  1
429357  96.879  -65.526  52.589  1
429358  96.909  -65.534  52.547  1
429359  96.939  -65.543  52.506  1
429360  96.969  -65.551  52.467  1
429361  97.000  -65.559  52.430  1
429362  97.030  -65.568  52.394  1
429363  97.060  -65.577  52.357  1
429364  97.090  -65.585  52.320  1
429365  97.121  -65.593  52.286  1
429366  97.148  -65.590  52.251  1
429367  97.175  -65.585  52.215  1
429368  97.203  -65.580  52.179  1
429369  97.226  -65.585  52.142  1
429370  97.266  -65.593  52.100  1
429371  97.308  -65.604  52.062  1
429372  97.351  -65.614  52.025  1
429373  97.393  -65.624  51.990  1
429374  97.436  -65.635  51.955  1
429375  97.476  -65.645  51.922  1
429376  97.513  -65.651  51.889  1
429377  97.548  -65.658  51.854  1
429378  97.585  -65.654  51.818  1
429379  97.622  -65.649  51.781  1
429380  97.659  -65.644  51.747  1
429381  97.696  -65.640  51.712  1
429382  97.732  -65.636  51.677  1
429383  97.768  -65.637  51.643  1
429384  97.804  -65.640  51.610  1
429385  97.840  -65.642  51.577  1
429386  97.874  -65.653  51.544  1
429387  97.906  -65.673  51.511  1
429388  97.938  -65.693  51.476  1
429389  97.971  -65.713  51.442  1
429390  98.005  -65.724  51.412  1
429391  98.040  -65.729  51.379  1
429392  98.075  -65.734  51.345  1
429393  98.110  -65.740  51.308  1
429394  98.146  -65.745  51.268  1
429395  98.181  -65.750  51.224  1
429396  98.216  -65.756  51.179  1
429397  98.256  -65.765  51.132  1
429398  98.296  -65.775  51.085  1
429399  98.334  -65.780  51.037  1
429400  98.371  -65.784  50.992  1
429401  98.408  -65.788  50.947  1
429402  98.445  -65.792  50.901  1
429403  98.483  -65.796  50.854  1
429404  98.520  -65.800  50.806  1
429405  98.558  -65.805  50.758  1
429406  98.595  -65.809  50.710  1
429407  98.633  -65.814  50.660  1
429408  98.676  -65.819  50.607  1
429409  98.720  -65.824  50.548  1
429410  98.764  -65.828  50.488  1
429411  98.808  -65.834  50.428  1
429412  98.852  -65.838  50.367  1
429413  98.896  -65.843  50.308  1
429414  98.940  -65.847  50.251  1
429415  98.978  -65.854  50.196  1
429416  99.015  -65.861  50.141  1
429417  99.055  -65.866  50.088  1
429418  99.095  -65.870  50.037  1
429419  99.135  -65.875  49.989  1
429420  99.175  -65.878  49.941  1
429421  99.218  -65.884  49.893  1
429422  99.263  -65.892  49.845  1
429423  99.307  -65.900  49.798  1
429424  99.352  -65.909  49.754  1
429425  99.397  -65.916  49.710  1
429426  99.439  -65.922  49.668  1
429427  99.478  -65.928  49.626  1
429428  99.518  -65.932  49.579  1
429429  99.561  -65.935  49.528  1
429430  99.604  -65.937  49.476  1
429431  99.646  -65.941  49.423  1
429432  99.689  -65.943  49.369  1
429433  99.731  -65.946  49.318  1
429434  99.774  -65.948  49.267  1
429435  99.822  -65.955  49.216  1
429436  99.870  -65.962  49.165  1
429437  99.919  -65.969  49.112  1
429438  99.947  -65.944  49.061  1
429439  99.986  -65.931  49.012  1
429440  100.025  -65.918  48.964  1
429441  100.070  -65.912  48.917  1
429442  100.118  -65.910  48.870  1
429443  100.167  -65.908  48.823  1
429444  100.214  -65.906  48.777  1
429445  100.263  -65.904  48.732  1
429446  100.311  -65.902  48.687  1
429447  100.359  -65.900  48.645  1
429448  100.407  -65.897  48.601  1
429449  100.456  -65.896  48.558  1
429450  100.504  -65.894  48.516  1
429863  88.317  -64.646  55.303  1
429864  88.351  -64.656  55.300  1
429865  88.385  -64.665  55.299  1
429866  88.426  -64.671  55.298  1
429867  88.472  -64.675  55.300  1
429868  88.518  -64.680  55.304  1
429869  88.564  -64.684  55.310  1
429870  88.611  -64.687  55.317  1
429871  88.657  -64.691  55.326  1
429872  88.703  -64.695  55.338  1
429873  88.749  -64.699  55.354  1
429874  88.795  -64.703  55.374  1
429875  88.841  -64.707  55.384  1
429876  88.888  -64.711  55.383  1
429877  88.934  -64.715  55.376  1
429878  88.980  -64.718  55.365  1
429879  89.026  -64.722  55.353  1
429880  89.072  -64.727  55.344  1
429881  89.121  -64.729  55.334  1
429882  89.185  -64.725  55.318  1
429883  89.248  -64.720  55.300  1
429884  89.285  -64.739  55.286  1
429885  89.322  -64.757  55.274  1
429886  89.358  -64.776  55.261  1
429887  89.396  -64.794  55.250  1
429888  89.440  -64.802  55.231  1
429889  89.487  -64.804  55.208  1
429890  89.534  -64.806  55.181  1
429891  89.582  -64.809  55.152  1
429892  89.629  -64.811  55.124  1
429893  89.676  -64.813  55.100  1
429894  89.724  -64.815  55.077  1
429895  89.772  -64.822  55.057  1
429896  89.821  -64.828  55.038  1
429897  89.869  -64.834  55.021  1
429898  89.917  -64.840  55.006  1
429899  89.966  -64.847  54.995  1
429900  90.014  -64.853  54.987  1
429901  90.063  -64.859  54.981  1
429902  90.111  -64.865  54.977  1
429903  90.160  -64.871  54.975  1
429904  90.208  -64.877  54.974  1
429905  90.257  -64.883  54.974  1
429906  90.305  -64.890  54.975  1
429907  90.354  -64.896  54.976  1
429908  90.402  -64.902  54.978  1
429909  90.450  -64.908  54.980  1
429910  90.499  -64.914  54.981  1
429911  90.547  -64.920  54.981  1
429912  90.596  -64.926  54.981  1
429913  90.644  -64.933  54.980  1
429914  90.692  -64.939  54.977  1
429915  90.741  -64.945  54.973  1
429916  90.788  -64.954  54.967  1
429917  90.833  -64.966  54.960  1
429918  90.879  -64.978  54.952  1
429919  90.922  -64.988  54.943  1
429920  90.964  -64.999  54.933  1
429921  91.007  -65.010  54.923  1
429922  91.050  -65.020  54.913  1
429923  91.092  -65.033  54.902  1
429924  91.132  -65.050  54.891  1
429925  91.172  -65.066  54.880  1
429926  91.212  -65.083  54.869  1
429927  91.251  -65.101  54.858  1
429928  91.291  -65.117  54.848  1
429929  91.331  -65.134  54.839  1
429930  91.371  -65.151  54.831  1
429931  91.411  -65.167  54.825  1
429932  91.450  -65.185  54.821  1
429933  91.490  -65.201  54.818  1
429934  91.530  -65.218  54.815  1
429935  91.570  -65.235  54.816  1
429936  91.609  -65.252  54.818  1
429937  91.649  -65.269  54.821  1
429938  91.689  -65.286  54.825  1
429939  91.729  -65.302  54.833  1
429940  91.769  -65.319  54.842  1
429941  91.810  -65.334  54.845  1
429942  91.855  -65.344  54.842  1
429943  91.900  -65.355  54.835  1
429944  91.941  -65.369  54.822  1
429945  91.999  -65.367  54.809  1
429946  92.057  -65.364  54.798  1
429947  92.115  -65.361  54.790  1
429948  92.173  -65.358  54.784  1
429949  92.231  -65.355  54.780  1
429950  92.288  -65.354  54.776  1
429951  92.345  -65.355  54.773  1
429952  92.402  -65.356  54.771  1
429953  92.456  -65.358  54.768  1
429954  92.507  -65.361  54.766  1
429955  92.559  -65.364  54.765  1
429956  92.610  -65.366  54.765  1
429957  92.661  -65.369  54.766  1
429958  92.713  -65.372  54.766  1
429959  92.763  -65.376  54.766  1
429960  92.812  -65.380  54.765  1
429961  92.860  -65.383  54.764  1
429962  92.907  -65.386  54.761  1
429963  92.955  -65.389  54.756  1
429964  93.003  -65.392  54.751  1
429965  93.052  -65.395  54.745  1
429966  93.102  -65.397  54.738  1
429967  93.152  -65.399  54.733  1
429968  93.202  -65.402  54.726  1
429969  93.252  -65.404  54.719  1
429970  93.300  -65.408  54.711  1
429971  93.348  -65.412  54.703  1
429972  93.393  -65.415  54.696  1
429973  93.435  -65.418  54.689  1
429974  93.478  -65.420  54.685  1
429975  93.520  -65.423  54.681  1
429976  93.563  -65.425  54.678  1
429977  93.606  -65.427  54.676  1
429978  93.648  -65.430  54.673  1
429979  93.691  -65.432  54.668  1
429980  93.734  -65.435  54.661  1
429981  93.778  -65.438  54.649  1
429982  93.823  -65.441  54.631  1
429983  93.867  -65.445  54.610  1
429984  93.911  -65.447  54.589  1
429985  93.943  -65.442  54.568  1
429986  93.977  -65.438  54.547  1
429987  94.010  -65.433  54.527  1
429988  94.043  -65.430  54.508  1
429989  94.076  -65.425  54.490  1
429990  94.109  -65.420  54.472  1
429991  94.142  -65.416  54.452  1
429992  94.175  -65.411  54.433  1
429993  94.209  -65.412  54.416  1
429994  94.244  -65.414  54.402  1
429995  94.278  -65.415  54.390  1
429996  94.313  -65.417  54.378  1
429997  94.348  -65.418  54.367  1
429998  94.384  -65.420  54.357  1
429999  94.424  -65.421  54.347  1
430000  94.463  -65.423  54.336  1
430001  94.502  -65.424  54.324  1
430002  94.542  -65.426  54.309  1
430003  94.581  -65.427  54.292  1
430004  94.621  -65.429  54.272  1
430005  94.660  -65.432  54.248  1
430006  94.700  -65.436  54.221  1
430007  94.740  -65.439  54.188  1
430008  94.780  -65.443  54.154  1
430009  94.823  -65.444  54.121  1
430010  94.866  -65.445  54.092  1
430011  94.910  -65.448  54.065  1
430012  94.954  -65.452  54.040  1
430013  94.997  -65.455  54.013  1
430014  95.042  -65.458  53.983  1
430015  95.086  -65.462  53.953  1
430016  95.129  -65.466  53.922  1
430017  95.176  -65.474  53.892  1
430018  95.222  -65.485  53.864  1
430019  95.269  -65.495  53.837  1
430020  95.314  -65.501  53.811  1
430021  95.353  -65.495  53.788  1
430022  95.392  -65.488  53.769  1
430023  95.431  -65.482  53.756  1
430024  95.471  -65.476  53.745  1
430025  95.510  -65.469  53.731  1
430026  95.553  -65.474  53.713  1
430027  95.593  -65.475  53.690  1
430028  95.633  -65.477  53.662  1
430029  95.674  -65.479  53.633  1
430030  95.714  -65.484  53.607  1
430031  95.754  -65.489  53.582  1
430032  95.795  -65.494  53.558  1
430033  95.835  -65.499  53.531  1
430034  95.875  -65.505  53.502  1
430035  95.915  -65.509  53.469  1
430036  95.955  -65.514  53.435  1
430037  95.995  -65.520  53.402  1
430038  96.037  -65.517  53.370  1
430039  96.079  -65.512  53.334  1
430040  96.123  -65.508  53.296  1
430041  96.167  -65.505  53.257  1
430042  96.210  -65.501  53.219  1
430043  96.255  -65.497  53.183  1
430044  96.299  -65.493  53.148  1
430045  96.342  -65.489  53.110  1
430046  96.386  -65.486  53.072  1
430047  96.430  -65.483  53.033  1
430048  96.468  -65.486  52.995  1
430049  96.507  -65.489  52.955  1
430050  96.548  -65.489  52.915  1
430051  96.590  -65.489  52.874  1
430052  96.632  -65.489  52.830  1
430053  96.673  -65.489  52.785  1
430054  96.715  -65.490  52.744  1
430055  96.757  -65.490  52.703  1
430056  96.798  -65.490  52.663  1
430057  96.840  -65.491  52.624  1
430058  96.883  -65.492  52.581  1
430059  96.926  -65.492  52.539  1
430060  96.967  -65.494  52.497  1
430061  96.997  -65.503  52.457  1
430062  97.027  -65.511  52.418  1
430063  97.058  -65.520  52.382  1
430064  97.088  -65.528  52.344  1
430065  97.118  -65.536  52.306  1
430066  97.148  -65.545  52.272  1
430067  97.176  -65.541  52.235  1
430068  97.203  -65.536  52.199  1
430069  97.205  -65.534  52.163  1
430070  97.231  -65.550  52.126  1
430071  97.272  -65.558  52.084  1
430072  97.311  -65.567  52.046  1
430073  97.351  -65.575  52.008  1
430074  97.391  -65.583  51.972  1
430075  97.434  -65.593  51.938  1
430076  97.476  -65.604  51.907  1
430077  97.514  -65.612  51.874  1
430078  97.550  -65.613  51.839  1
430079  97.587  -65.608  51.802  1
430080  97.624  -65.604  51.764  1
430081  97.660  -65.606  51.727  1
430082  97.696  -65.608  51.692  1
430083  97.732  -65.610  51.657  1
430084  97.768  -65.612  51.622  1
430085  97.803  -65.615  51.588  1
430086  97.840  -65.617  51.555  1
430087  97.873  -65.631  51.521  1
430088  97.905  -65.651  51.488  1
430089  97.938  -65.671  51.455  1
430090  97.972  -65.680  51.421  1
430091  98.007  -65.684  51.391  1
430092  98.042  -65.690  51.359  1
430093  98.078  -65.695  51.326  1
430094  98.113  -65.700  51.290  1
430095  98.148  -65.705  51.251  1
430096  98.183  -65.711  51.210  1
430097  98.219  -65.716  51.166  1
430098  98.255  -65.722  51.121  1
430099  98.295  -65.733  51.075  1
430100  98.333  -65.737  51.030  1
430101  98.370  -65.742  50.986  1
430102  98.408  -65.746  50.942  1
430103  98.445  -65.750  50.897  1
430104  98.482  -65.754  50.851  1
430105  98.519  -65.759  50.804  1
430106  98.557  -65.764  50.756  1
430107  98.595  -65.769  50.707  1
430108  98.636  -65.774  50.656  1
430109  98.678  -65.780  50.603  1
430110  98.721  -65.786  50.544  1
430111  98.764  -65.791  50.483  1
430112  98.807  -65.797  50.423  1
430113  98.851  -65.802  50.364  1
430114  98.895  -65.806  50.304  1
430115  98.939  -65.812  50.246  1
430116  98.980  -65.817  50.190  1
430117  99.018  -65.824  50.134  1
430118  99.058  -65.828  50.079  1
430119  99.098  -65.831  50.027  1
430120  99.139  -65.836  49.976  1
430121  99.179  -65.840  49.928  1
430122  99.220  -65.844  49.880  1
430123  99.265  -65.853  49.832  1
430124  99.309  -65.860  49.786  1
430125  99.354  -65.868  49.741  1
430126  99.399  -65.876  49.698  1
430127  99.444  -65.884  49.655  1
430128  99.487  -65.891  49.614  1
430129  99.527  -65.896  49.569  1
430130  99.570  -65.899  49.520  1
430131  99.613  -65.901  49.468  1
430132  99.657  -65.906  49.415  1
430133  99.706  -65.912  49.362  1
430134  99.755  -65.920  49.310  1
430135  99.804  -65.928  49.260  1
430136  99.853  -65.935  49.210  1
430137  99.902  -65.942  49.160  1
430138  99.934  -65.925  49.110  1
430139  99.961  -65.897  49.059  1
430140  99.999  -65.884  49.010  1
430141  100.038  -65.871  48.962  1
430142  100.084  -65.866  48.914  1
430143  100.132  -65.864  48.867  1
430144  100.181  -65.862  48.821  1
430145  100.229  -65.860  48.774  1
430146  100.277  -65.858  48.729  1
430147  100.325  -65.856  48.685  1
430148  100.373  -65.854  48.643  1
430149  100.422  -65.852  48.599  1
430150  100.470  -65.850  48.556  1
430564  88.309  -64.597  55.302  1
430565  88.343  -64.607  55.299  1
430566  88.382  -64.615  55.298  1
430567  88.428  -64.618  55.299  1
430568  88.474  -64.622  55.301  1
430569  88.521  -64.626  55.306  1
430570  88.567  -64.631  55.312  1
430571  88.613  -64.634  55.320  1
430572  88.659  -64.638  55.329  1
430573  88.705  -64.642  55.340  1
430574  88.751  -64.646  55.356  1
430575  88.798  -64.649  55.376  1
430576  88.844  -64.654  55.387  1
430577  88.890  -64.658  55.389  1
430578  88.936  -64.662  55.382  1
430579  88.982  -64.665  55.372  1
430580  89.028  -64.669  55.363  1
430581  89.084  -64.668  55.353  1
430582  89.147  -64.664  55.343  1
430583  89.210  -64.660  55.327  1
430584  89.253  -64.674  55.311  1
430585  89.290  -64.693  55.300  1
430586  89.327  -64.711  55.289  1
430587  89.364  -64.730  55.276  1
430588  89.400  -64.748  55.266  1
430589  89.441  -64.761  55.249  1
430590  89.488  -64.763  55.226  1
430591  89.536  -64.765  55.198  1
430592  89.583  -64.768  55.166  1
430593  89.630  -64.770  55.135  1
430594  89.678  -64.772  55.109  1
430595  89.725  -64.775  55.086  1
430596  89.772  -64.777  55.064  1
430597  89.819  -64.779  55.045  1
430598  89.868  -64.785  55.028  1
430599  89.916  -64.791  55.013  1
430600  89.965  -64.797  55.001  1
430601  90.013  -64.803  54.993  1
430602  90.061  -64.809  54.986  1
430603  90.110  -64.815  54.982  1
430604  90.159  -64.822  54.980  1
430605  90.207  -64.828  54.979  1
430606  90.255  -64.834  54.978  1
430607  90.304  -64.841  54.979  1
430608  90.353  -64.847  54.979  1
430609  90.401  -64.853  54.981  1
430610  90.449  -64.859  54.982  1
430611  90.498  -64.866  54.983  1
430612  90.546  -64.872  54.983  1
430613  90.595  -64.878  54.982  1
430614  90.643  -64.884  54.980  1
430615  90.691  -64.890  54.977  1
430616  90.740  -64.896  54.972  1
430617  90.786  -64.907  54.966  1
430618  90.831  -64.919  54.959  1
430619  90.875  -64.930  54.950  1
430620  90.918  -64.941  54.941  1
430621  90.961  -64.951  54.931  1
430622  91.004  -64.962  54.921  1
430623  91.045  -64.975  54.910  1
430624  91.085  -64.993  54.899  1
430625  91.124  -65.010  54.888  1
430626  91.164  -65.026  54.877  1
430627  91.204  -65.043  54.865  1
430628  91.244  -65.060  54.853  1
430629  91.284  -65.077  54.843  1
430630  91.323  -65.094  54.834  1
430631  91.363  -65.110  54.825  1
430632  91.403  -65.127  54.818  1
430633  91.443  -65.145  54.813  1
430634  91.483  -65.161  54.809  1
430635  91.522  -65.178  54.806  1
430636  91.562  -65.195  54.806  1
430637  91.602  -65.211  54.807  1
430638  91.642  -65.229  54.809  1
430639  91.684  -65.242  54.813  1
430640  91.729  -65.251  54.821  1
430641  91.775  -65.261  54.830  1
430642  91.820  -65.272  54.835  1
430643  91.865  -65.282  54.833  1
430644  91.910  -65.292  54.825  1
430645  91.955  -65.301  54.812  1
430646  91.995  -65.318  54.799  1
430647  92.053  -65.315  54.787  1
430648  92.111  -65.313  54.778  1
430649  92.169  -65.310  54.770  1
430650  92.227  -65.307  54.766  1
430651  92.284  -65.306  54.761  1
430652  92.341  -65.307  54.758  1
430653  92.398  -65.308  54.755  1
430654  92.455  -65.309  54.754  1
430655  92.511  -65.311  54.752  1
430656  92.563  -65.314  54.751  1
430657  92.614  -65.316  54.751  1
430658  92.665  -65.319  54.750  1
430659  92.716  -65.323  54.749  1
430660  92.766  -65.327  54.747  1
430661  92.815  -65.332  54.746  1
430662  92.863  -65.335  54.745  1
430663  92.910  -65.338  54.744  1
430664  92.958  -65.341  54.740  1
430665  93.005  -65.344  54.735  1
430666  93.053  -65.347  54.730  1
430667  93.100  -65.350  54.724  1
430668  93.149  -65.353  54.719  1
430669  93.199  -65.355  54.713  1
430670  93.249  -65.358  54.706  1
430671  93.296  -65.362  54.698  1
430672  93.344  -65.366  54.689  1
430673  93.392  -65.370  54.681  1
430674  93.435  -65.373  54.675  1
430675  93.478  -65.375  54.669  1
430676  93.520  -65.377  54.665  1
430677  93.563  -65.380  54.661  1
430678  93.606  -65.383  54.659  1
430679  93.648  -65.385  54.655  1
430680  93.691  -65.387  54.651  1
430681  93.735  -65.390  54.646  1
430682  93.780  -65.394  54.637  1
430683  93.824  -65.397  54.623  1
430684  93.868  -65.400  54.606  1
430685  93.913  -65.403  54.588  1
430686  93.947  -65.400  54.570  1
430687  93.980  -65.395  54.552  1
430688  94.013  -65.391  54.537  1
430689  94.047  -65.386  54.523  1
430690  94.079  -65.382  54.508  1
430691  94.113  -65.378  54.492  1
430692  94.145  -65.373  54.472  1
430693  94.179  -65.371  54.452  1
430694  94.214  -65.373  54.434  1
430695  94.249  -65.374  54.417  1
430696  94.283  -65.376  54.403  1
430697  94.318  -65.377  54.390  1
430698  94.352  -65.379  54.376  1
430699  94.388  -65.380  54.364  1
430700  94.427  -65.382  54.353  1
430701  94.467  -65.383  54.342  1
430702  94.506  -65.384  54.327  1
430703  94.545  -65.386  54.311  1
430704  94.584  -65.387  54.294  1
430705  94.624  -65.389  54.274  1
430706  94.664  -65.390  54.250  1
430707  94.703  -65.393  54.224  1
430708  94.743  -65.397  54.193  1
430709  94.784  -65.400  54.158  1
430710  94.827  -65.401  54.123  1
430711  94.871  -65.405  54.094  1
430712  94.915  -65.408  54.068  1
430713  94.959  -65.411  54.042  1
430714  95.003  -65.415  54.015  1
430715  95.047  -65.419  53.986  1
430716  95.091  -65.422  53.957  1
430717  95.135  -65.426  53.928  1
430718  95.181  -65.434  53.901  1
430719  95.228  -65.444  53.875  1
430720  95.274  -65.455  53.850  1
430721  95.316  -65.452  53.825  1
430722  95.355  -65.445  53.804  1
430723  95.395  -65.440  53.786  1
430724  95.435  -65.435  53.771  1
430725  95.474  -65.429  53.758  1
430726  95.514  -65.430  53.744  1
430727  95.555  -65.434  53.726  1
430728  95.595  -65.439  53.704  1
430729  95.635  -65.444  53.677  1
430730  95.676  -65.449  53.649  1
430731  95.716  -65.455  53.619  1
430732  95.756  -65.459  53.591  1
430733  95.797  -65.464  53.563  1
430734  95.837  -65.470  53.534  1
430735  95.877  -65.474  53.503  1
430736  95.917  -65.480  53.470  1
430737  95.957  -65.485  53.435  1
430738  95.999  -65.483  53.399  1
430739  96.040  -65.479  53.365  1
430740  96.082  -65.474  53.328  1
430741  96.126  -65.470  53.290  1
430742  96.170  -65.467  53.252  1
430743  96.214  -65.463  53.214  1
430744  96.257  -65.459  53.178  1
430745  96.301  -65.455  53.142  1
430746  96.345  -65.452  53.104  1
430747  96.389  -65.449  53.066  1
430748  96.432  -65.447  53.028  1
430749  96.470  -65.451  52.990  1
430750  96.507  -65.455  52.951  1
430751  96.545  -65.460  52.911  1
430752  96.586  -65.461  52.870  1
430753  96.627  -65.461  52.827  1
430754  96.669  -65.461  52.783  1
430755  96.711  -65.461  52.741  1
430756  96.752  -65.461  52.699  1
430757  96.794  -65.461  52.657  1
430758  96.836  -65.461  52.616  1
430759  96.879  -65.463  52.573  1
430760  96.922  -65.464  52.530  1
430761  96.964  -65.464  52.488  1
430762  97.007  -65.465  52.447  1
430763  97.049  -65.467  52.406  1
430764  97.085  -65.471  52.368  1
430765  97.115  -65.480  52.330  1
430766  97.146  -65.488  52.291  1
430767  97.176  -65.496  52.255  1
430768  97.204  -65.492  52.218  1
430769  97.196  -65.484  52.182  1
430770  97.211  -65.499  52.145  1
430771  97.237  -65.516  52.108  1
430772  97.277  -65.524  52.069  1
430773  97.317  -65.533  52.031  1
430774  97.357  -65.541  51.990  1
430775  97.397  -65.549  51.953  1
430776  97.437  -65.557  51.921  1
430777  97.476  -65.565  51.890  1
430778  97.516  -65.573  51.856  1
430779  97.552  -65.575  51.820  1
430780  97.588  -65.577  51.783  1
430781  97.624  -65.579  51.745  1
430782  97.660  -65.581  51.707  1
430783  97.696  -65.583  51.672  1
430784  97.731  -65.585  51.637  1
430785  97.768  -65.587  51.602  1
430786  97.803  -65.590  51.567  1
430787  97.839  -65.592  51.532  1
430788  97.872  -65.608  51.497  1
430789  97.904  -65.628  51.464  1
430790  97.939  -65.635  51.431  1
430791  97.974  -65.640  51.397  1
430792  98.010  -65.646  51.367  1
430793  98.045  -65.651  51.336  1
430794  98.080  -65.656  51.303  1
430795  98.115  -65.662  51.269  1
430796  98.151  -65.666  51.234  1
430797  98.186  -65.671  51.194  1
430798  98.221  -65.677  51.152  1
430799  98.256  -65.682  51.109  1
430800  98.294  -65.690  51.065  1
430801  98.332  -65.696  51.021  1
430802  98.369  -65.700  50.979  1
430803  98.407  -65.704  50.936  1
430804  98.444  -65.709  50.893  1
430805  98.482  -65.714  50.847  1
430806  98.519  -65.719  50.801  1
430807  98.557  -65.724  50.751  1
430808  98.595  -65.730  50.701  1
430809  98.638  -65.735  50.649  1
430810  98.681  -65.741  50.592  1
430811  98.724  -65.746  50.534  1
430812  98.767  -65.753  50.475  1
430813  98.809  -65.758  50.417  1
430814  98.853  -65.764  50.359  1
430815  98.896  -65.769  50.301  1
430816  98.938  -65.775  50.243  1
430817  98.982  -65.780  50.186  1
430818  99.021  -65.785  50.130  1
430819  99.062  -65.789  50.073  1
430820  99.102  -65.793  50.020  1
430821  99.142  -65.796  49.967  1
430822  99.183  -65.801  49.917  1
430823  99.222  -65.805  49.869  1
430824  99.267  -65.812  49.821  1
430825  99.312  -65.821  49.775  1
430826  99.357  -65.828  49.730  1
430827  99.402  -65.837  49.686  1
430828  99.446  -65.844  49.644  1
430829  99.491  -65.853  49.603  1
430830  99.540  -65.860  49.559  1
430831  99.591  -65.871  49.510  1
430832  99.640  -65.878  49.458  1
430833  99.689  -65.886  49.406  1
430834  99.737  -65.893  49.353  1
430835  99.787  -65.900  49.303  1
430836  99.836  -65.908  49.253  1
430837  99.885  -65.916  49.205  1
430838  99.927  -65.913  49.157  1
430839  99.947  -65.878  49.107  1
430840  99.974  -65.850  49.057  1
430841  100.013  -65.837  49.008  1
430842  100.052  -65.824  48.959  1
430843  100.099  -65.820  48.912  1
430844  100.147  -65.818  48.866  1
430845  100.195  -65.816  48.819  1
430846  100.244  -65.814  48.772  1
430847  100.291  -65.812  48.727  1
430848  100.340  -65.810  48.684  1
430849  100.388  -65.808  48.640  1
430850  100.436  -65.806  48.596  1
430851  100.484  -65.803  48.553  1
431265  88.301  -64.549  55.301  1
431266  88.338  -64.557  55.299  1
431267  88.384  -64.562  55.298  1
431268  88.430  -64.565  55.299  1
431269  88.477  -64.569  55.302  1
431270  88.523  -64.573  55.307  1
431271  88.569  -64.577  55.314  1
431272  88.615  -64.580  55.321  1
431273  88.662  -64.585  55.331  1
431274  88.707  -64.589  55.342  1
431275  88.754  -64.593  55.358  1
431276  88.800  -64.596  55.377  1
431277  88.846  -64.600  55.390  1
431278  88.892  -64.604  55.394  1
431279  88.939  -64.609  55.389  1
431280  88.984  -64.612  55.380  1
431281  89.047  -64.608  55.370  1
431282  89.110  -64.604  55.359  1
431283  89.173  -64.599  55.347  1
431284  89.221  -64.609  55.332  1
431285  89.257  -64.627  55.319  1
431286  89.295  -64.646  55.309  1
431287  89.331  -64.665  55.300  1
431288  89.368  -64.684  55.289  1
431289  89.405  -64.702  55.277  1
431290  89.442  -64.720  55.261  1
431291  89.489  -64.722  55.238  1
431292  89.537  -64.725  55.209  1
431293  89.584  -64.727  55.176  1
431294  89.631  -64.729  55.144  1
431295  89.679  -64.731  55.118  1
431296  89.726  -64.734  55.094  1
431297  89.773  -64.736  55.072  1
431298  89.821  -64.738  55.052  1
431299  89.868  -64.740  55.035  1
431300  89.915  -64.743  55.020  1
431301  89.964  -64.748  55.008  1
431302  90.012  -64.754  54.999  1
431303  90.060  -64.761  54.992  1
431304  90.109  -64.767  54.988  1
431305  90.157  -64.773  54.985  1
431306  90.206  -64.779  54.984  1
431307  90.254  -64.785  54.984  1
431308  90.303  -64.791  54.984  1
431309  90.351  -64.797  54.984  1
431310  90.399  -64.804  54.985  1
431311  90.448  -64.810  54.986  1
431312  90.497  -64.816  54.986  1
431313  90.545  -64.822  54.986  1
431314  90.593  -64.828  54.985  1
431315  90.642  -64.834  54.982  1
431316  90.690  -64.841  54.978  1
431317  90.738  -64.849  54.973  1
431318  90.784  -64.860  54.966  1
431319  90.828  -64.872  54.958  1
431320  90.871  -64.882  54.949  1
431321  90.914  -64.893  54.940  1
431322  90.957  -64.903  54.930  1
431323  90.998  -64.919  54.919  1
431324  91.037  -64.935  54.908  1
431325  91.077  -64.952  54.896  1
431326  91.117  -64.969  54.885  1
431327  91.157  -64.986  54.873  1
431328  91.196  -65.003  54.862  1
431329  91.236  -65.019  54.850  1
431330  91.276  -65.037  54.838  1
431331  91.316  -65.054  54.829  1
431332  91.356  -65.070  54.820  1
431333  91.395  -65.087  54.812  1
431334  91.435  -65.104  54.805  1
431335  91.475  -65.121  54.800  1
431336  91.515  -65.138  54.797  1
431337  91.559  -65.149  54.796  1
431338  91.604  -65.159  54.796  1
431339  91.649  -65.169  54.797  1
431340  91.694  -65.179  54.800  1
431341  91.739  -65.189  54.807  1
431342  91.785  -65.199  54.816  1
431343  91.829  -65.209  54.821  1
431344  91.875  -65.219  54.821  1
431345  91.920  -65.229  54.814  1
431346  91.965  -65.239  54.802  1
431347  92.002  -65.258  54.789  1
431348  92.049  -65.267  54.776  1
431349  92.107  -65.264  54.765  1
431350  92.165  -65.261  54.757  1
431351  92.223  -65.259  54.752  1
431352  92.280  -65.258  54.747  1
431353  92.337  -65.260  54.743  1
431354  92.394  -65.261  54.740  1
431355  92.451  -65.262  54.739  1
431356  92.508  -65.263  54.737  1
431357  92.565  -65.264  54.735  1
431358  92.618  -65.267  54.734  1
431359  92.669  -65.269  54.732  1
431360  92.719  -65.274  54.729  1
431361  92.768  -65.279  54.726  1
431362  92.818  -65.283  54.724  1
431363  92.866  -65.287  54.723  1
431364  92.913  -65.290  54.723  1
431365  92.961  -65.293  54.721  1
431366  93.008  -65.296  54.717  1
431367  93.056  -65.299  54.713  1
431368  93.103  -65.302  54.709  1
431369  93.151  -65.305  54.706  1
431370  93.199  -65.308  54.701  1
431371  93.246  -65.311  54.695  1
431372  93.293  -65.316  54.686  1
431373  93.341  -65.320  54.677  1
431374  93.389  -65.324  54.669  1
431375  93.435  -65.328  54.662  1
431376  93.478  -65.330  54.657  1
431377  93.520  -65.333  54.652  1
431378  93.563  -65.335  54.647  1
431379  93.606  -65.337  54.646  1
431380  93.648  -65.340  54.643  1
431381  93.693  -65.343  54.640  1
431382  93.737  -65.346  54.636  1
431383  93.781  -65.349  54.630  1
431384  93.826  -65.353  54.619  1
431385  93.870  -65.356  54.606  1
431386  93.914  -65.359  54.591  1
431387  93.951  -65.358  54.575  1
431388  93.984  -65.353  54.561  1
431389  94.017  -65.348  54.549  1
431390  94.050  -65.344  54.538  1
431391  94.083  -65.339  54.524  1
431392  94.116  -65.335  54.509  1
431393  94.149  -65.330  54.489  1
431394  94.184  -65.332  54.468  1
431395  94.218  -65.333  54.448  1
431396  94.253  -65.334  54.428  1
431397  94.288  -65.336  54.410  1
431398  94.323  -65.337  54.396  1
431399  94.357  -65.339  54.381  1
431400  94.392  -65.340  54.367  1
431401  94.430  -65.342  54.354  1
431402  94.470  -65.343  54.343  1
431403  94.509  -65.345  54.327  1
431404  94.549  -65.346  54.310  1
431405  94.588  -65.348  54.292  1
431406  94.627  -65.349  54.271  1
431407  94.667  -65.351  54.247  1
431408  94.706  -65.352  54.222  1
431409  94.746  -65.355  54.192  1
431410  94.788  -65.358  54.159  1
431411  94.832  -65.361  54.125  1
431412  94.877  -65.364  54.095  1
431413  94.920  -65.368  54.068  1
431414  94.964  -65.372  54.042  1
431415  95.008  -65.375  54.016  1
431416  95.052  -65.379  53.988  1
431417  95.096  -65.383  53.961  1
431418  95.140  -65.386  53.935  1
431419  95.186  -65.394  53.909  1
431420  95.233  -65.404  53.885  1
431421  95.275  -65.404  53.861  1
431422  95.315  -65.398  53.837  1
431423  95.354  -65.392  53.817  1
431424  95.394  -65.389  53.799  1
431425  95.433  -65.393  53.783  1
431426  95.472  -65.398  53.769  1
431427  95.511  -65.404  53.753  1
431428  95.557  -65.404  53.735  1
431429  95.597  -65.409  53.715  1
431430  95.637  -65.414  53.690  1
431431  95.678  -65.419  53.664  1
431432  95.718  -65.424  53.632  1
431433  95.758  -65.430  53.600  1
431434  95.798  -65.435  53.568  1
431435  95.838  -65.439  53.537  1
431436  95.879  -65.445  53.505  1
431437  95.919  -65.450  53.471  1
431438  95.960  -65.451  53.435  1
431439  96.002  -65.446  53.398  1
431440  96.044  -65.442  53.363  1
431441  96.086  -65.437  53.324  1
431442  96.129  -65.433  53.286  1
431443  96.173  -65.429  53.248  1
431444  96.217  -65.425  53.209  1
431445  96.260  -65.421  53.172  1
431446  96.304  -65.417  53.136  1
431447  96.348  -65.414  53.098  1
431448  96.391  -65.412  53.060  1
431449  96.433  -65.412  53.023  1
431450  96.471  -65.416  52.986  1
431451  96.508  -65.420  52.947  1
431452  96.546  -65.425  52.907  1
431453  96.583  -65.430  52.867  1
431454  96.623  -65.431  52.825  1
431455  96.665  -65.432  52.782  1
431456  96.706  -65.432  52.739  1
431457  96.748  -65.432  52.696  1
431458  96.790  -65.432  52.653  1
431459  96.832  -65.433  52.612  1
431460  96.875  -65.433  52.569  1
431461  96.917  -65.435  52.525  1
431462  96.960  -65.436  52.483  1
431463  97.002  -65.436  52.441  1
431464  97.045  -65.437  52.398  1
431465  97.087  -65.439  52.358  1
431466  97.130  -65.439  52.318  1
431467  97.173  -65.440  52.278  1
431468  97.204  -65.448  52.240  1
431469  97.197  -65.440  52.201  1
431470  97.196  -65.445  52.164  1
431471  97.217  -65.465  52.128  1
431472  97.243  -65.482  52.092  1
431473  97.283  -65.490  52.054  1
431474  97.323  -65.499  52.016  1
431475  97.363  -65.506  51.976  1
431476  97.402  -65.514  51.938  1
431477  97.442  -65.523  51.905  1
431478  97.483  -65.531  51.873  1
431479  97.522  -65.540  51.838  1
431480  97.559  -65.546  51.801  1
431481  97.593  -65.549  51.763  1
431482  97.627  -65.552  51.725  1
431483  97.660  -65.555  51.687  1
431484  97.695  -65.558  51.653  1
431485  97.731  -65.560  51.618  1
431486  97.767  -65.562  51.582  1
431487  97.803  -65.564  51.546  1
431488  97.839  -65.567  51.511  1
431489  97.871  -65.585  51.477  1
431490  97.907  -65.590  51.444  1
431491  97.942  -65.596  51.410  1
431492  97.977  -65.601  51.376  1
431493  98.012  -65.606  51.344  1
431494  98.048  -65.612  51.312  1
431495  98.083  -65.617  51.280  1
431496  98.118  -65.622  51.247  1
431497  98.153  -65.627  51.214  1
431498  98.189  -65.633  51.177  1
431499  98.224  -65.638  51.137  1
431500  98.259  -65.643  51.097  1
431501  98.294  -65.648  51.055  1
431502  98.332  -65.654  51.013  1
431503  98.369  -65.659  50.971  1
431504  98.407  -65.664  50.928  1
431505  98.444  -65.669  50.885  1
431506  98.482  -65.674  50.840  1
431507  98.519  -65.680  50.793  1
431508  98.557  -65.685  50.743  1
431509  98.596  -65.690  50.692  1
431510  98.640  -65.696  50.637  1
431511  98.684  -65.702  50.580  1
431512  98.726  -65.707  50.521  1
431513  98.769  -65.713  50.462  1
431514  98.812  -65.718  50.405  1
431515  98.855  -65.724  50.349  1
431516  98.898  -65.730  50.291  1
431517  98.941  -65.736  50.236  1
431518  98.983  -65.741  50.179  1
431519  99.026  -65.745  50.121  1
431520  99.066  -65.749  50.065  1
431521  99.106  -65.754  50.011  1
431522  99.146  -65.758  49.960  1
431523  99.186  -65.762  49.910  1
431524  99.226  -65.766  49.862  1
431525  99.269  -65.772  49.814  1
431526  99.314  -65.781  49.768  1
431527  99.359  -65.788  49.723  1
431528  99.407  -65.796  49.678  1
431529  99.457  -65.802  49.633  1
431530  99.507  -65.808  49.590  1
431531  99.558  -65.814  49.546  1
431532  99.609  -65.824  49.498  1
431533  99.659  -65.834  49.448  1
431534  99.709  -65.844  49.397  1
431535  99.760  -65.855  49.347  1
431536  99.810  -65.865  49.298  1
431537  99.860  -65.875  49.250  1
431538  99.909  -65.885  49.202  1
431539  99.940  -65.866  49.154  1
431540  99.961  -65.831  49.103  1
431541  99.987  -65.802  49.053  1
431542  100.026  -65.790  49.004  1
431543  100.065  -65.777  48.956  1
431544  100.113  -65.774  48.908  1
431545  100.161  -65.772  48.862  1
431546  100.209  -65.770  48.815  1
431547  100.258  -65.768  48.769  1
431548  100.306  -65.766  48.724  1
431549  100.354  -65.764  48.680  1
431550  100.403  -65.762  48.637  1
431551  100.451  -65.759  48.594  1
431552  100.496  -65.759  48.551  1
431967  88.340  -64.504  55.299  1
431968  88.387  -64.508  55.299  1
431969  88.433  -64.512  55.299  1
431970  88.479  -64.516  55.301  1
431971  88.525  -64.520  55.308  1
431972  88.571  -64.524  55.314  1
431973  88.617  -64.527  55.322  1
431974  88.664  -64.531  55.331  1
431975  88.710  -64.536  55.342  1
431976  88.756  -64.540  55.357  1
431977  88.802  -64.543  55.377  1
431978  88.848  -64.547  55.393  1
431979  88.895  -64.551  55.398  1
431980  88.947  -64.552  55.396  1
431981  89.010  -64.548  55.387  1
431982  89.073  -64.543  55.376  1
431983  89.136  -64.539  55.362  1
431984  89.188  -64.544  55.348  1
431985  89.225  -64.562  55.334  1
431986  89.262  -64.581  55.324  1
431987  89.299  -64.599  55.316  1
431988  89.336  -64.618  55.309  1
431989  89.373  -64.637  55.300  1
431990  89.410  -64.656  55.287  1
431991  89.447  -64.674  55.270  1
431992  89.490  -64.682  55.245  1
431993  89.538  -64.684  55.215  1
431994  89.585  -64.687  55.181  1
431995  89.632  -64.689  55.151  1
431996  89.680  -64.691  55.124  1
431997  89.727  -64.693  55.100  1
431998  89.774  -64.695  55.078  1
431999  89.822  -64.697  55.058  1
432000  89.869  -64.700  55.042  1
432001  89.916  -64.702  55.028  1
432002  89.964  -64.704  55.016  1
432003  90.011  -64.706  55.006  1
432004  90.059  -64.712  55.000  1
432005  90.108  -64.718  54.996  1
432006  90.156  -64.724  54.992  1
432007  90.204  -64.730  54.989  1
432008  90.253  -64.737  54.990  1
432009  90.302  -64.743  54.989  1
432010  90.350  -64.749  54.990  1
432011  90.398  -64.755  54.991  1
432012  90.447  -64.761  54.991  1
432013  90.496  -64.767  54.991  1
432014  90.544  -64.773  54.990  1
432015  90.592  -64.780  54.988  1
432016  90.641  -64.786  54.985  1
432017  90.689  -64.792  54.980  1
432018  90.736  -64.802  54.975  1
432019  90.781  -64.813  54.967  1
432020  90.824  -64.824  54.958  1
432021  90.867  -64.834  54.949  1
432022  90.910  -64.846  54.938  1
432023  90.950  -64.862  54.928  1
432024  90.990  -64.878  54.917  1
432025  91.030  -64.895  54.905  1
432026  91.070  -64.912  54.894  1
432027  91.109  -64.929  54.882  1
432028  91.149  -64.946  54.870  1
432029  91.189  -64.963  54.858  1
432030  91.229  -64.979  54.846  1
432031  91.269  -64.996  54.834  1
432032  91.308  -65.013  54.824  1
432033  91.348  -65.030  54.814  1
432034  91.388  -65.046  54.805  1
432035  91.433  -65.056  54.798  1
432036  91.478  -65.066  54.793  1
432037  91.523  -65.076  54.789  1
432038  91.569  -65.086  54.787  1
432039  91.614  -65.096  54.786  1
432040  91.659  -65.107  54.786  1
432041  91.704  -65.116  54.786  1
432042  91.749  -65.126  54.792  1
432043  91.794  -65.136  54.799  1
432044  91.840  -65.146  54.805  1
432045  91.884  -65.157  54.807  1
432046  91.930  -65.166  54.801  1
432047  91.975  -65.176  54.790  1
432048  92.020  -65.186  54.777  1
432049  92.045  -65.220  54.765  1
432050  92.103  -65.217  54.752  1
432051  92.161  -65.213  54.743  1
432052  92.219  -65.210  54.737  1
432053  92.276  -65.210  54.733  1
432054  92.333  -65.212  54.729  1
432055  92.390  -65.213  54.726  1
432056  92.447  -65.214  54.724  1
432057  92.504  -65.215  54.722  1
432058  92.561  -65.217  54.720  1
432059  92.618  -65.217  54.718  1
432060  92.672  -65.220  54.714  1
432061  92.722  -65.226  54.709  1
432062  92.771  -65.230  54.706  1
432063  92.820  -65.235  54.703  1
432064  92.868  -65.239  54.702  1
432065  92.916  -65.242  54.701  1
432066  92.964  -65.245  54.699  1
432067  93.011  -65.248  54.696  1
432068  93.059  -65.251  54.693  1
432069  93.107  -65.254  54.690  1
432070  93.154  -65.257  54.688  1
432071  93.200  -65.261  54.685  1
432072  93.245  -65.266  54.681  1
432073  93.291  -65.270  54.674  1
432074  93.337  -65.273  54.666  1
432075  93.385  -65.278  54.658  1
432076  93.433  -65.282  54.652  1
432077  93.477  -65.285  54.648  1
432078  93.520  -65.287  54.645  1
432079  93.563  -65.290  54.641  1
432080  93.606  -65.292  54.640  1
432081  93.649  -65.295  54.638  1
432082  93.694  -65.298  54.636  1
432083  93.738  -65.302  54.633  1
432084  93.782  -65.305  54.628  1
432085  93.827  -65.308  54.619  1
432086  93.871  -65.311  54.609  1
432087  93.915  -65.315  54.597  1
432088  93.955  -65.315  54.583  1
432089  93.988  -65.311  54.572  1
432090  94.021  -65.306  54.563  1
432091  94.054  -65.301  54.552  1
432092  94.087  -65.297  54.538  1
432093  94.120  -65.292  54.522  1
432094  94.153  -65.290  54.503  1
432095  94.188  -65.292  54.481  1
432096  94.223  -65.293  54.459  1
432097  94.258  -65.295  54.437  1
432098  94.292  -65.296  54.416  1
432099  94.327  -65.298  54.400  1
432100  94.361  -65.299  54.383  1
432101  94.396  -65.301  54.368  1
432102  94.434  -65.302  54.354  1
432103  94.473  -65.304  54.342  1
432104  94.512  -65.305  54.325  1
432105  94.552  -65.307  54.308  1
432106  94.592  -65.308  54.289  1
432107  94.631  -65.310  54.267  1
432108  94.670  -65.311  54.244  1
432109  94.710  -65.313  54.218  1
432110  94.751  -65.315  54.189  1
432111  94.795  -65.319  54.157  1
432112  94.838  -65.322  54.125  1
432113  94.882  -65.325  54.094  1
432114  94.925  -65.328  54.068  1
432115  94.970  -65.332  54.043  1
432116  95.014  -65.336  54.019  1
432117  95.057  -65.339  53.993  1
432118  95.101  -65.343  53.967  1
432119  95.145  -65.346  53.942  1
432120  95.191  -65.353  53.916  1
432121  95.234  -65.356  53.892  1
432122  95.274  -65.350  53.868  1
432123  95.313  -65.351  53.844  1
432124  95.352  -65.357  53.823  1
432125  95.391  -65.361  53.804  1
432126  95.430  -65.367  53.786  1
432127  95.470  -65.372  53.771  1
432128  95.511  -65.376  53.755  1
432129  95.558  -65.374  53.738  1
432130  95.599  -65.380  53.719  1
432131  95.639  -65.384  53.697  1
432132  95.680  -65.389  53.670  1
432133  95.720  -65.395  53.641  1
432134  95.760  -65.399  53.609  1
432135  95.800  -65.405  53.575  1
432136  95.840  -65.410  53.539  1
432137  95.881  -65.414  53.505  1
432138  95.921  -65.417  53.471  1
432139  95.963  -65.413  53.435  1
432140  96.005  -65.408  53.399  1
432141  96.047  -65.404  53.363  1
432142  96.089  -65.399  53.325  1
432143  96.131  -65.395  53.286  1
432144  96.175  -65.392  53.247  1
432145  96.220  -65.387  53.206  1
432146  96.263  -65.383  53.167  1
432147  96.307  -65.380  53.131  1
432148  96.350  -65.378  53.093  1
432149  96.393  -65.376  53.055  1
432150  96.434  -65.377  53.019  1
432151  96.472  -65.382  52.981  1
432152  96.509  -65.386  52.943  1
432153  96.547  -65.390  52.904  1
432154  96.584  -65.395  52.864  1
432155  96.622  -65.398  52.822  1
432156  96.660  -65.402  52.781  1
432157  96.702  -65.402  52.738  1
432158  96.743  -65.403  52.695  1
432159  96.785  -65.403  52.652  1
432160  96.827  -65.404  52.611  1
432161  96.870  -65.405  52.567  1
432162  96.913  -65.405  52.523  1
432163  96.955  -65.407  52.480  1
432164  96.998  -65.408  52.436  1
432165  97.040  -65.408  52.394  1
432166  97.083  -65.409  52.351  1
432167  97.125  -65.410  52.308  1
432168  97.167  -65.410  52.266  1
432169  97.191  -65.402  52.226  1
432170  97.181  -65.390  52.185  1
432171  97.202  -65.411  52.147  1
432172  97.223  -65.430  52.111  1
432173  97.248  -65.448  52.075  1
432174  97.289  -65.456  52.038  1
432175  97.328  -65.464  52.001  1
432176  97.368  -65.472  51.961  1
432177  97.408  -65.480  51.924  1
432178  97.448  -65.489  51.889  1
432179  97.488  -65.498  51.856  1
432180  97.528  -65.507  51.820  1
432181  97.568  -65.516  51.782  1
432182  97.602  -65.519  51.743  1
432183  97.636  -65.522  51.705  1
432184  97.669  -65.525  51.668  1
432185  97.704  -65.528  51.634  1
432186  97.737  -65.532  51.599  1
432187  97.771  -65.535  51.562  1
432188  97.805  -65.538  51.527  1
432189  97.838  -65.541  51.492  1
432190  97.873  -65.546  51.459  1
432191  97.909  -65.551  51.425  1
432192  97.943  -65.556  51.391  1
432193  97.979  -65.561  51.357  1
432194  98.013  -65.567  51.323  1
432195  98.049  -65.572  51.289  1
432196  98.084  -65.577  51.257  1
432197  98.119  -65.583  51.224  1
432198  98.154  -65.588  51.193  1
432199  98.189  -65.593  51.157  1
432200  98.224  -65.598  51.120  1
432201  98.259  -65.603  51.082  1
432202  98.294  -65.608  51.043  1
432203  98.332  -65.615  51.002  1
432204  98.369  -65.620  50.960  1
432205  98.407  -65.625  50.918  1
432206  98.444  -65.630  50.875  1
432207  98.482  -65.636  50.831  1
432208  98.519  -65.641  50.783  1
432209  98.557  -65.646  50.733  1
432210  98.598  -65.651  50.680  1
432211  98.643  -65.656  50.625  1
432212  98.686  -65.662  50.567  1
432213  98.729  -65.668  50.508  1
432214  98.772  -65.674  50.449  1
432215  98.814  -65.679  50.393  1
432216  98.857  -65.685  50.337  1
432217  98.900  -65.691  50.280  1
432218  98.942  -65.697  50.225  1
432219  98.986  -65.701  50.168  1
432220  99.030  -65.704  50.111  1
432221  99.070  -65.709  50.054  1
432222  99.110  -65.713  50.001  1
432223  99.150  -65.718  49.951  1
432224  99.190  -65.722  49.903  1
432225  99.230  -65.727  49.855  1
432226  99.273  -65.732  49.809  1
432227  99.323  -65.738  49.762  1
432228  99.373  -65.744  49.717  1
432229  99.424  -65.750  49.670  1
432230  99.475  -65.756  49.623  1
432231  99.525  -65.762  49.579  1
432232  99.575  -65.768  49.534  1
432233  99.626  -65.777  49.488  1
432234  99.677  -65.787  49.439  1
432235  99.727  -65.797  49.390  1
432236  99.777  -65.808  49.341  1
432237  99.826  -65.818  49.293  1
432238  99.870  -65.828  49.246  1
432239  99.919  -65.834  49.199  1
432240  99.954  -65.818  49.150  1
432241  99.974  -65.783  49.099  1
432242  100.001  -65.755  49.049  1
432243  100.040  -65.743  49.000  1
432244  100.079  -65.731  48.952  1
432245  100.127  -65.728  48.904  1
432246  100.176  -65.726  48.857  1
432247  100.224  -65.724  48.812  1
432248  100.272  -65.722  48.765  1
432249  100.321  -65.720  48.720  1
432250  100.368  -65.718  48.676  1
432251  100.417  -65.715  48.634  1
432252  100.465  -65.714  48.591  1
432253  100.506  -65.717  48.548  1
432668  88.343  -64.451  55.300  1
432669  88.389  -64.455  55.299  1
432670  88.435  -64.458  55.300  1
432671  88.481  -64.462  55.302  1
432672  88.528  -64.467  55.308  1
432673  88.573  -64.471  55.314  1
432674  88.620  -64.474  55.322  1
432675  88.666  -64.478  55.330  1
432676  88.712  -64.482  55.340  1
432677  88.758  -64.486  55.353  1
432678  88.805  -64.490  55.370  1
432679  88.850  -64.494  55.386  1
432680  88.909  -64.492  55.394  1
432681  88.973  -64.487  55.393  1
432682  89.036  -64.483  55.387  1
432683  89.099  -64.479  55.375  1
432684  89.156  -64.479  55.361  1
432685  89.193  -64.498  55.348  1
432686  89.230  -64.516  55.335  1
432687  89.267  -64.535  55.326  1
432688  89.304  -64.553  55.320  1
432689  89.341  -64.572  55.315  1
432690  89.378  -64.590  55.308  1
432691  89.414  -64.609  55.295  1
432692  89.452  -64.627  55.275  1
432693  89.492  -64.641  55.249  1
432694  89.539  -64.643  55.217  1
432695  89.587  -64.646  55.184  1
432696  89.634  -64.648  55.155  1
432697  89.681  -64.650  55.130  1
432698  89.729  -64.653  55.106  1
432699  89.776  -64.655  55.084  1
432700  89.823  -64.657  55.065  1
432701  89.871  -64.659  55.049  1
432702  89.917  -64.662  55.035  1
432703  89.965  -64.664  55.024  1
432704  90.012  -64.666  55.015  1
432705  90.059  -64.668  55.009  1
432706  90.107  -64.671  55.004  1
432707  90.155  -64.675  55.001  1
432708  90.203  -64.681  54.998  1
432709  90.252  -64.687  54.998  1
432710  90.300  -64.693  54.998  1
432711  90.349  -64.700  54.998  1
432712  90.397  -64.706  54.999  1
432713  90.446  -64.712  54.998  1
432714  90.494  -64.718  54.997  1
432715  90.542  -64.725  54.996  1
432716  90.591  -64.731  54.993  1
432717  90.640  -64.737  54.989  1
432718  90.688  -64.743  54.983  1
432719  90.734  -64.755  54.977  1
432720  90.777  -64.765  54.969  1
432721  90.820  -64.776  54.960  1
432722  90.863  -64.787  54.949  1
432723  90.902  -64.804  54.937  1
432724  90.942  -64.822  54.927  1
432725  90.982  -64.838  54.915  1
432726  91.022  -64.855  54.903  1
432727  91.062  -64.872  54.891  1
432728  91.101  -64.888  54.879  1
432729  91.141  -64.906  54.867  1
432730  91.181  -64.922  54.854  1
432731  91.221  -64.939  54.842  1
432732  91.262  -64.953  54.830  1
432733  91.308  -64.963  54.818  1
432734  91.353  -64.973  54.808  1
432735  91.398  -64.984  54.799  1
432736  91.443  -64.994  54.791  1
432737  91.488  -65.004  54.785  1
432738  91.533  -65.013  54.780  1
432739  91.579  -65.024  54.777  1
432740  91.624  -65.034  54.774  1
432741  91.669  -65.044  54.773  1
432742  91.714  -65.054  54.772  1
432743  91.759  -65.063  54.775  1
432744  91.804  -65.074  54.779  1
432745  91.849  -65.084  54.783  1
432746  91.894  -65.094  54.785  1
432747  91.940  -65.104  54.781  1
432748  91.985  -65.114  54.772  1
432749  92.030  -65.124  54.761  1
432750  92.064  -65.146  54.750  1
432751  92.099  -65.168  54.737  1
432752  92.157  -65.166  54.727  1
432753  92.215  -65.163  54.722  1
432754  92.272  -65.163  54.718  1
432755  92.329  -65.164  54.715  1
432756  92.386  -65.166  54.712  1
432757  92.443  -65.166  54.710  1
432758  92.500  -65.168  54.707  1
432759  92.562  -65.168  54.705  1
432760  92.620  -65.169  54.701  1
432761  92.672  -65.172  54.697  1
432762  92.724  -65.177  54.691  1
432763  92.774  -65.182  54.686  1
432764  92.823  -65.186  54.683  1
432765  92.871  -65.190  54.681  1
432766  92.919  -65.193  54.680  1
432767  92.967  -65.196  54.677  1
432768  93.014  -65.199  54.675  1
432769  93.062  -65.202  54.673  1
432770  93.109  -65.206  54.671  1
432771  93.154  -65.210  54.670  1
432772  93.199  -65.215  54.668  1
432773  93.245  -65.220  54.664  1
432774  93.290  -65.224  54.659  1
432775  93.337  -65.228  54.652  1
432776  93.382  -65.232  54.646  1
432777  93.429  -65.235  54.642  1
432778  93.477  -65.240  54.640  1
432779  93.519  -65.242  54.639  1
432780  93.562  -65.245  54.637  1
432781  93.607  -65.248  54.635  1
432782  93.651  -65.251  54.634  1
432783  93.695  -65.254  54.632  1
432784  93.740  -65.257  54.630  1
432785  93.784  -65.261  54.625  1
432786  93.828  -65.264  54.618  1
432787  93.872  -65.267  54.611  1
432788  93.917  -65.270  54.602  1
432789  93.959  -65.272  54.592  1
432790  93.992  -65.267  54.581  1
432791  94.025  -65.263  54.572  1
432792  94.058  -65.259  54.561  1
432793  94.090  -65.254  54.547  1
432794  94.124  -65.250  54.530  1
432795  94.158  -65.251  54.510  1
432796  94.193  -65.252  54.489  1
432797  94.227  -65.254  54.466  1
432798  94.262  -65.255  54.443  1
432799  94.297  -65.257  54.420  1
432800  94.332  -65.258  54.401  1
432801  94.366  -65.260  54.384  1
432802  94.401  -65.261  54.368  1
432803  94.437  -65.263  54.353  1
432804  94.477  -65.264  54.340  1
432805  94.516  -65.266  54.323  1
432806  94.555  -65.267  54.304  1
432807  94.595  -65.269  54.285  1
432808  94.634  -65.270  54.263  1
432809  94.674  -65.272  54.240  1
432810  94.714  -65.274  54.213  1
432811  94.759  -65.278  54.184  1
432812  94.803  -65.281  54.154  1
432813  94.846  -65.285  54.123  1
432814  94.890  -65.288  54.094  1
432815  94.933  -65.291  54.069  1
432816  94.977  -65.294  54.045  1
432817  95.020  -65.297  54.022  1
432818  95.063  -65.301  53.997  1
432819  95.107  -65.304  53.973  1
432820  95.150  -65.307  53.948  1
432821  95.193  -65.310  53.922  1
432822  95.233  -65.315  53.897  1
432823  95.271  -65.320  53.872  1
432824  95.311  -65.325  53.849  1
432825  95.350  -65.330  53.826  1
432826  95.389  -65.335  53.805  1
432827  95.428  -65.340  53.786  1
432828  95.467  -65.345  53.769  1
432829  95.510  -65.348  53.753  1
432830  95.558  -65.347  53.736  1
432831  95.601  -65.349  53.719  1
432832  95.641  -65.355  53.701  1
432833  95.681  -65.360  53.674  1
432834  95.722  -65.364  53.645  1
432835  95.762  -65.370  53.613  1
432836  95.802  -65.375  53.578  1
432837  95.842  -65.380  53.540  1
432838  95.883  -65.384  53.504  1
432839  95.924  -65.380  53.469  1
432840  95.966  -65.375  53.433  1
432841  96.008  -65.370  53.397  1
432842  96.050  -65.366  53.362  1
432843  96.092  -65.361  53.325  1
432844  96.134  -65.358  53.286  1
432845  96.178  -65.354  53.246  1
432846  96.222  -65.350  53.204  1
432847  96.266  -65.346  53.163  1
432848  96.309  -65.344  53.125  1
432849  96.352  -65.342  53.087  1
432850  96.395  -65.341  53.050  1
432851  96.435  -65.342  53.014  1
432852  96.473  -65.347  52.978  1
432853  96.511  -65.351  52.940  1
432854  96.548  -65.355  52.901  1
432855  96.586  -65.360  52.861  1
432856  96.623  -65.364  52.819  1
432857  96.661  -65.368  52.778  1
432858  96.698  -65.373  52.736  1
432859  96.739  -65.373  52.694  1
432860  96.781  -65.373  52.651  1
432861  96.823  -65.375  52.609  1
432862  96.866  -65.376  52.566  1
432863  96.908  -65.376  52.522  1
432864  96.951  -65.377  52.478  1
432865  96.993  -65.377  52.435  1
432866  97.034  -65.377  52.391  1
432867  97.076  -65.376  52.349  1
432868  97.118  -65.376  52.305  1
432869  97.160  -65.376  52.259  1
432870  97.162  -65.359  52.215  1
432871  97.184  -65.358  52.172  1
432872  97.208  -65.376  52.131  1
432873  97.229  -65.396  52.094  1
432874  97.254  -65.414  52.057  1
432875  97.294  -65.422  52.021  1
432876  97.334  -65.430  51.985  1
432877  97.374  -65.438  51.946  1
432878  97.414  -65.446  51.909  1
432879  97.454  -65.455  51.874  1
432880  97.494  -65.464  51.842  1
432881  97.534  -65.474  51.803  1
432882  97.574  -65.483  51.764  1
432883  97.611  -65.489  51.725  1
432884  97.645  -65.492  51.687  1
432885  97.678  -65.495  51.651  1
432886  97.712  -65.499  51.616  1
432887  97.746  -65.502  51.579  1
432888  97.780  -65.504  51.543  1
432889  97.812  -65.502  51.508  1
432890  97.845  -65.501  51.475  1
432891  97.873  -65.506  51.442  1
432892  97.907  -65.511  51.409  1
432893  97.942  -65.517  51.376  1
432894  97.977  -65.522  51.340  1
432895  98.012  -65.527  51.304  1
432896  98.047  -65.532  51.269  1
432897  98.082  -65.537  51.234  1
432898  98.117  -65.543  51.201  1
432899  98.152  -65.548  51.170  1
432900  98.187  -65.553  51.136  1
432901  98.222  -65.558  51.100  1
432902  98.257  -65.564  51.063  1
432903  98.295  -65.569  51.025  1
432904  98.332  -65.574  50.987  1
432905  98.369  -65.580  50.948  1
432906  98.407  -65.586  50.907  1
432907  98.444  -65.591  50.864  1
432908  98.482  -65.596  50.819  1
432909  98.519  -65.602  50.770  1
432910  98.557  -65.607  50.720  1
432911  98.601  -65.612  50.667  1
432912  98.645  -65.618  50.612  1
432913  98.688  -65.623  50.554  1
432914  98.731  -65.628  50.495  1
432915  98.774  -65.634  50.437  1
432916  98.817  -65.640  50.380  1
432917  98.859  -65.646  50.324  1
432918  98.902  -65.652  50.267  1
432919  98.943  -65.658  50.210  1
432920  98.988  -65.661  50.153  1
432921  99.034  -65.663  50.097  1
432922  99.074  -65.667  50.042  1
432923  99.115  -65.672  49.989  1
432924  99.154  -65.677  49.941  1
432925  99.194  -65.681  49.894  1
432926  99.234  -65.686  49.849  1
432927  99.278  -65.688  49.805  1
432928  99.332  -65.694  49.757  1
432929  99.386  -65.699  49.710  1
432930  99.440  -65.705  49.663  1
432931  99.492  -65.711  49.615  1
432932  99.543  -65.717  49.570  1
432933  99.593  -65.723  49.524  1
432934  99.643  -65.730  49.479  1
432935  99.694  -65.740  49.433  1
432936  99.743  -65.751  49.386  1
432937  99.787  -65.761  49.337  1
432938  99.831  -65.771  49.290  1
432939  99.874  -65.782  49.242  1
432940  99.937  -65.775  49.195  1
432941  99.967  -65.771  49.146  1
432942  99.988  -65.736  49.094  1
432943  100.014  -65.708  49.044  1
432944  100.053  -65.695  48.995  1
432945  100.093  -65.684  48.948  1
432946  100.142  -65.682  48.900  1
432947  100.190  -65.680  48.853  1
432948  100.239  -65.678  48.807  1
432949  100.286  -65.676  48.761  1
432950  100.335  -65.674  48.715  1
432951  100.383  -65.671  48.672  1
432952  100.431  -65.670  48.630  1
432953  100.477  -65.669  48.588  1
432954  100.516  -65.674  48.546  1
433369  88.345  -64.398  55.300  1
433370  88.391  -64.402  55.300  1
433371  88.437  -64.405  55.301  1
433372  88.484  -64.409  55.304  1
433373  88.530  -64.413  55.308  1
433374  88.576  -64.418  55.314  1
433375  88.622  -64.421  55.321  1
433376  88.668  -64.425  55.328  1
433377  88.714  -64.429  55.338  1
433378  88.761  -64.433  55.348  1
433379  88.809  -64.436  55.362  1
433380  88.872  -64.431  55.376  1
433381  88.935  -64.427  55.385  1
433382  88.998  -64.423  55.385  1
433383  89.061  -64.418  55.380  1
433384  89.124  -64.414  55.369  1
433385  89.161  -64.433  55.355  1
433386  89.198  -64.452  55.342  1
433387  89.235  -64.470  55.329  1
433388  89.272  -64.489  55.322  1
433389  89.309  -64.507  55.317  1
433390  89.345  -64.526  55.312  1
433391  89.382  -64.544  55.305  1
433392  89.419  -64.563  55.292  1
433393  89.456  -64.581  55.273  1
433394  89.493  -64.600  55.247  1
433395  89.540  -64.602  55.217  1
433396  89.588  -64.605  55.186  1
433397  89.635  -64.607  55.159  1
433398  89.682  -64.609  55.134  1
433399  89.730  -64.612  55.111  1
433400  89.777  -64.614  55.089  1
433401  89.824  -64.616  55.072  1
433402  89.872  -64.618  55.057  1
433403  89.919  -64.621  55.043  1
433404  89.966  -64.623  55.032  1
433405  90.014  -64.625  55.023  1
433406  90.061  -64.627  55.018  1
433407  90.108  -64.630  55.014  1
433408  90.156  -64.632  55.011  1
433409  90.203  -64.634  55.009  1
433410  90.251  -64.638  55.007  1
433411  90.299  -64.645  55.008  1
433412  90.347  -64.651  55.008  1
433413  90.396  -64.657  55.008  1
433414  90.445  -64.663  55.007  1
433415  90.493  -64.669  55.006  1
433416  90.541  -64.675  55.005  1
433417  90.590  -64.681  55.001  1
433418  90.638  -64.688  54.996  1
433419  90.686  -64.696  54.989  1
433420  90.730  -64.707  54.981  1
433421  90.773  -64.718  54.972  1
433422  90.815  -64.731  54.962  1
433423  90.855  -64.747  54.950  1
433424  90.895  -64.764  54.938  1
433425  90.935  -64.781  54.926  1
433426  90.974  -64.798  54.913  1
433427  91.014  -64.815  54.901  1
433428  91.054  -64.831  54.889  1
433429  91.094  -64.848  54.876  1
433430  91.137  -64.861  54.863  1
433431  91.182  -64.871  54.850  1
433432  91.227  -64.881  54.837  1
433433  91.273  -64.891  54.825  1
433434  91.317  -64.901  54.813  1
433435  91.363  -64.911  54.802  1
433436  91.408  -64.921  54.793  1
433437  91.453  -64.931  54.785  1
433438  91.498  -64.941  54.777  1
433439  91.543  -64.951  54.772  1
433440  91.588  -64.961  54.767  1
433441  91.634  -64.971  54.763  1
433442  91.678  -64.981  54.760  1
433443  91.724  -64.991  54.758  1
433444  91.769  -65.001  54.758  1
433445  91.814  -65.011  54.760  1
433446  91.859  -65.021  54.762  1
433447  91.905  -65.032  54.762  1
433448  91.949  -65.041  54.757  1
433449  91.995  -65.051  54.750  1
433450  92.040  -65.061  54.741  1
433451  92.085  -65.071  54.730  1
433452  92.104  -65.110  54.719  1
433453  92.153  -65.117  54.711  1
433454  92.211  -65.114  54.707  1
433455  92.268  -65.116  54.704  1
433456  92.325  -65.116  54.701  1
433457  92.382  -65.118  54.698  1
433458  92.441  -65.119  54.694  1
433459  92.507  -65.119  54.691  1
433460  92.569  -65.120  54.687  1
433461  92.618  -65.120  54.683  1
433462  92.669  -65.123  54.678  1
433463  92.724  -65.128  54.673  1
433464  92.777  -65.133  54.668  1
433465  92.826  -65.138  54.664  1
433466  92.874  -65.142  54.661  1
433467  92.922  -65.145  54.660  1
433468  92.970  -65.148  54.658  1
433469  93.017  -65.151  54.655  1
433470  93.063  -65.155  54.654  1
433471  93.108  -65.160  54.652  1
433472  93.153  -65.164  54.650  1
433473  93.199  -65.169  54.649  1
433474  93.245  -65.173  54.647  1
433475  93.290  -65.178  54.643  1
433476  93.336  -65.182  54.637  1
433477  93.382  -65.186  54.634  1
433478  93.428  -65.190  54.633  1
433479  93.474  -65.194  54.633  1
433480  93.519  -65.198  54.634  1
433481  93.564  -65.201  54.632  1
433482  93.608  -65.204  54.630  1
433483  93.652  -65.207  54.629  1
433484  93.697  -65.210  54.627  1
433485  93.741  -65.213  54.625  1
433486  93.785  -65.217  54.621  1
433487  93.830  -65.220  54.617  1
433488  93.874  -65.223  54.611  1
433489  93.918  -65.226  54.604  1
433490  93.963  -65.229  54.595  1
433491  93.995  -65.225  54.586  1
433492  94.029  -65.220  54.576  1
433493  94.061  -65.216  54.564  1
433494  94.095  -65.211  54.549  1
433495  94.128  -65.210  54.532  1
433496  94.163  -65.211  54.511  1
433497  94.197  -65.213  54.490  1
433498  94.232  -65.214  54.468  1
433499  94.267  -65.216  54.445  1
433500  94.301  -65.217  54.422  1
433501  94.336  -65.219  54.401  1
433502  94.371  -65.220  54.383  1
433503  94.405  -65.222  54.367  1
433504  94.441  -65.223  54.351  1
433505  94.480  -65.225  54.336  1
433506  94.520  -65.226  54.318  1
433507  94.559  -65.228  54.300  1
433508  94.598  -65.229  54.281  1
433509  94.638  -65.231  54.260  1
433510  94.678  -65.232  54.236  1
433511  94.722  -65.236  54.209  1
433512  94.766  -65.240  54.180  1
433513  94.811  -65.244  54.150  1
433514  94.854  -65.247  54.120  1
433515  94.898  -65.251  54.094  1
433516  94.941  -65.254  54.071  1
433517  94.984  -65.257  54.049  1
433518  95.028  -65.260  54.027  1
433519  95.071  -65.263  54.003  1
433520  95.115  -65.267  53.979  1
433521  95.158  -65.270  53.953  1
433522  95.195  -65.279  53.927  1
433523  95.230  -65.289  53.901  1
433524  95.269  -65.293  53.875  1
433525  95.308  -65.298  53.851  1
433526  95.347  -65.304  53.827  1
433527  95.387  -65.308  53.805  1
433528  95.426  -65.314  53.784  1
433529  95.465  -65.319  53.765  1
433530  95.510  -65.320  53.749  1
433531  95.557  -65.319  53.732  1
433532  95.603  -65.320  53.716  1
433533  95.643  -65.325  53.700  1
433534  95.683  -65.329  53.674  1
433535  95.724  -65.335  53.646  1
433536  95.764  -65.340  53.614  1
433537  95.804  -65.345  53.578  1
433538  95.844  -65.350  53.540  1
433539  95.886  -65.346  53.502  1
433540  95.928  -65.342  53.465  1
433541  95.970  -65.338  53.429  1
433542  96.012  -65.333  53.392  1
433543  96.053  -65.329  53.359  1
433544  96.095  -65.324  53.323  1
433545  96.137  -65.320  53.285  1
433546  96.181  -65.316  53.245  1
433547  96.225  -65.312  53.202  1
433548  96.268  -65.309  53.160  1
433549  96.311  -65.308  53.120  1
433550  96.355  -65.307  53.082  1
433551  96.397  -65.305  53.045  1
433552  96.437  -65.308  53.010  1
433553  96.474  -65.312  52.973  1
433554  96.512  -65.317  52.935  1
433555  96.549  -65.320  52.896  1
433556  96.587  -65.325  52.856  1
433557  96.624  -65.329  52.815  1
433558  96.662  -65.333  52.774  1
433559  96.699  -65.338  52.733  1
433560  96.737  -65.342  52.691  1
433561  96.777  -65.345  52.649  1
433562  96.818  -65.345  52.606  1
433563  96.860  -65.345  52.563  1
433564  96.902  -65.345  52.520  1
433565  96.944  -65.344  52.476  1
433566  96.985  -65.344  52.433  1
433567  97.027  -65.344  52.389  1
433568  97.069  -65.343  52.347  1
433569  97.111  -65.343  52.301  1
433570  97.138  -65.336  52.254  1
433571  97.145  -65.325  52.208  1
433572  97.180  -65.333  52.163  1
433573  97.215  -65.342  52.119  1
433574  97.235  -65.361  52.079  1
433575  97.260  -65.380  52.041  1
433576  97.300  -65.388  52.003  1
433577  97.340  -65.395  51.967  1
433578  97.380  -65.404  51.929  1
433579  97.420  -65.413  51.893  1
433580  97.460  -65.422  51.860  1
433581  97.500  -65.431  51.828  1
433582  97.540  -65.440  51.788  1
433583  97.580  -65.449  51.748  1
433584  97.620  -65.458  51.708  1
433585  97.654  -65.461  51.671  1
433586  97.687  -65.465  51.634  1
433587  97.721  -65.468  51.598  1
433588  97.754  -65.467  51.562  1
433589  97.787  -65.464  51.525  1
433590  97.819  -65.463  51.491  1
433591  97.852  -65.461  51.459  1
433592  97.880  -65.466  51.426  1
433593  97.909  -65.471  51.393  1
433594  97.941  -65.477  51.359  1
433595  97.975  -65.482  51.322  1
433596  98.011  -65.487  51.284  1
433597  98.045  -65.492  51.248  1
433598  98.081  -65.498  51.214  1
433599  98.116  -65.502  51.181  1
433600  98.151  -65.508  51.149  1
433601  98.186  -65.513  51.115  1
433602  98.221  -65.518  51.078  1
433603  98.258  -65.524  51.041  1
433604  98.295  -65.530  51.004  1
433605  98.333  -65.535  50.967  1
433606  98.370  -65.541  50.932  1
433607  98.407  -65.546  50.893  1
433608  98.444  -65.552  50.852  1
433609  98.482  -65.557  50.808  1
433610  98.519  -65.562  50.761  1
433611  98.559  -65.568  50.710  1
433612  98.603  -65.573  50.657  1
433613  98.647  -65.578  50.601  1
433614  98.691  -65.583  50.544  1
433615  98.733  -65.590  50.489  1
433616  98.776  -65.595  50.431  1
433617  98.818  -65.601  50.373  1
433618  98.861  -65.607  50.315  1
433619  98.903  -65.613  50.257  1
433620  98.945  -65.619  50.199  1
433621  98.991  -65.621  50.141  1
433622  99.037  -65.623  50.085  1
433623  99.079  -65.626  50.030  1
433624  99.119  -65.630  49.978  1
433625  99.159  -65.635  49.929  1
433626  99.199  -65.640  49.883  1
433627  99.237  -65.642  49.839  1
433628  99.282  -65.645  49.796  1
433629  99.336  -65.650  49.751  1
433630  99.390  -65.656  49.703  1
433631  99.444  -65.662  49.655  1
433632  99.498  -65.667  49.607  1
433633  99.552  -65.673  49.561  1
433634  99.606  -65.678  49.517  1
433635  99.659  -65.684  49.473  1
433636  99.704  -65.693  49.427  1
433637  99.748  -65.704  49.380  1
433638  99.791  -65.715  49.332  1
433639  99.836  -65.725  49.284  1
433640  99.879  -65.735  49.236  1
433641  99.957  -65.716  49.188  1
433642  99.981  -65.724  49.138  1
433643  100.001  -65.689  49.088  1
433644  100.028  -65.661  49.038  1
433645  100.067  -65.648  48.989  1
433646  100.108  -65.638  48.941  1
433647  100.156  -65.637  48.894  1
433648  100.204  -65.634  48.848  1
433649  100.253  -65.632  48.802  1
433650  100.301  -65.630  48.757  1
433651  100.349  -65.627  48.712  1
433652  100.398  -65.626  48.668  1
433653  100.445  -65.624  48.627  1
433654  100.487  -65.627  48.584  1
433655  100.526  -65.632  48.542  1
434071  88.394  -64.349  55.302  1
434072  88.439  -64.352  55.303  1
434073  88.486  -64.356  55.305  1
434074  88.532  -64.360  55.309  1
434075  88.578  -64.364  55.314  1
434076  88.624  -64.367  55.320  1
434077  88.671  -64.372  55.326  1
434078  88.717  -64.376  55.334  1
434079  88.772  -64.375  55.342  1
434080  88.835  -64.371  55.352  1
434081  88.898  -64.367  55.362  1
434082  88.961  -64.362  55.369  1
434083  89.024  -64.358  55.371  1
434084  89.088  -64.354  55.367  1
434085  89.129  -64.368  55.358  1
434086  89.166  -64.386  55.346  1
434087  89.202  -64.405  55.334  1
434088  89.240  -64.424  55.322  1
434089  89.276  -64.443  55.315  1
434090  89.313  -64.461  55.311  1
434091  89.350  -64.480  55.307  1
434092  89.387  -64.498  55.298  1
434093  89.424  -64.517  55.284  1
434094  89.461  -64.535  55.266  1
434095  89.498  -64.554  55.243  1
434096  89.541  -64.562  55.216  1
434097  89.589  -64.564  55.189  1
434098  89.636  -64.566  55.162  1
434099  89.683  -64.568  55.139  1
434100  89.731  -64.571  55.118  1
434101  89.778  -64.573  55.097  1
434102  89.825  -64.575  55.080  1
434103  89.873  -64.577  55.065  1
434104  89.920  -64.580  55.052  1
434105  89.967  -64.582  55.041  1
434106  90.015  -64.584  55.033  1
434107  90.062  -64.587  55.028  1
434108  90.109  -64.589  55.024  1
434109  90.157  -64.591  55.021  1
434110  90.204  -64.593  55.020  1
434111  90.251  -64.596  55.018  1
434112  90.299  -64.598  55.018  1
434113  90.346  -64.602  55.019  1
434114  90.395  -64.608  55.019  1
434115  90.443  -64.614  55.019  1
434116  90.492  -64.620  55.018  1
434117  90.540  -64.627  55.016  1
434118  90.589  -64.633  55.012  1
434119  90.637  -64.639  55.006  1
434120  90.683  -64.649  54.998  1
434121  90.727  -64.659  54.988  1
434122  90.768  -64.673  54.978  1
434123  90.808  -64.690  54.966  1
434124  90.848  -64.707  54.953  1
434125  90.887  -64.724  54.940  1
434126  90.927  -64.740  54.926  1
434127  90.967  -64.757  54.913  1
434128  91.011  -64.769  54.899  1
434129  91.057  -64.778  54.887  1
434130  91.102  -64.788  54.873  1
434131  91.147  -64.798  54.860  1
434132  91.192  -64.808  54.846  1
434133  91.237  -64.819  54.833  1
434134  91.282  -64.828  54.821  1
434135  91.327  -64.838  54.808  1
434136  91.373  -64.848  54.798  1
434137  91.418  -64.859  54.788  1
434138  91.463  -64.869  54.778  1
434139  91.508  -64.878  54.770  1
434140  91.553  -64.888  54.763  1
434141  91.598  -64.898  54.758  1
434142  91.643  -64.909  54.753  1
434143  91.688  -64.919  54.749  1
434144  91.734  -64.928  54.745  1
434145  91.779  -64.938  54.743  1
434146  91.824  -64.949  54.742  1
434147  91.869  -64.959  54.740  1
434148  91.914  -64.969  54.737  1
434149  91.959  -64.978  54.733  1
434150  92.005  -64.988  54.727  1
434151  92.050  -64.999  54.719  1
434152  92.095  -65.009  54.710  1
434153  92.126  -65.035  54.701  1
434154  92.149  -65.069  54.695  1
434155  92.207  -65.067  54.692  1
434156  92.264  -65.068  54.689  1
434157  92.321  -65.069  54.686  1
434158  92.386  -65.069  54.684  1
434159  92.452  -65.069  54.680  1
434160  92.517  -65.070  54.675  1
434161  92.567  -65.070  54.671  1
434162  92.616  -65.071  54.666  1
434163  92.667  -65.073  54.662  1
434164  92.721  -65.079  54.658  1
434165  92.776  -65.085  54.653  1
434166  92.829  -65.089  54.649  1
434167  92.877  -65.094  54.646  1
434168  92.925  -65.097  54.644  1
434169  92.972  -65.101  54.641  1
434170  93.017  -65.105  54.638  1
434171  93.062  -65.110  54.636  1
434172  93.108  -65.114  54.635  1
434173  93.153  -65.119  54.633  1
434174  93.199  -65.123  54.631  1
434175  93.244  -65.127  54.629  1
434176  93.289  -65.132  54.626  1
434177  93.335  -65.136  54.624  1
434178  93.381  -65.140  54.623  1
434179  93.427  -65.144  54.623  1
434180  93.474  -65.148  54.625  1
434181  93.519  -65.152  54.626  1
434182  93.565  -65.156  54.624  1
434183  93.610  -65.160  54.623  1
434184  93.653  -65.163  54.622  1
434185  93.698  -65.166  54.620  1
434186  93.742  -65.169  54.619  1
434187  93.786  -65.173  54.617  1
434188  93.831  -65.176  54.615  1
434189  93.875  -65.179  54.610  1
434190  93.919  -65.182  54.604  1
434191  93.964  -65.185  54.596  1
434192  93.999  -65.182  54.588  1
434193  94.032  -65.178  54.577  1
434194  94.065  -65.173  54.563  1
434195  94.098  -65.169  54.548  1
434196  94.133  -65.170  54.531  1
434197  94.168  -65.172  54.511  1
434198  94.202  -65.173  54.489  1
434199  94.237  -65.175  54.468  1
434200  94.271  -65.176  54.445  1
434201  94.306  -65.178  54.422  1
434202  94.341  -65.179  54.401  1
434203  94.376  -65.181  54.382  1
434204  94.410  -65.182  54.364  1
434205  94.445  -65.184  54.348  1
434206  94.484  -65.185  54.332  1
434207  94.523  -65.186  54.313  1
434208  94.562  -65.188  54.294  1
434209  94.602  -65.189  54.275  1
434210  94.641  -65.191  54.254  1
434211  94.686  -65.195  54.230  1
434212  94.730  -65.199  54.204  1
434213  94.774  -65.203  54.177  1
434214  94.818  -65.207  54.147  1
434215  94.862  -65.210  54.117  1
434216  94.905  -65.213  54.092  1
434217  94.949  -65.216  54.069  1
434218  94.992  -65.220  54.048  1
434219  95.036  -65.223  54.027  1
434220  95.079  -65.226  54.004  1
434221  95.122  -65.229  53.980  1
434222  95.162  -65.235  53.955  1
434223  95.202  -65.241  53.929  1
434224  95.229  -65.261  53.903  1
434225  95.267  -65.267  53.876  1
434226  95.306  -65.272  53.849  1
434227  95.345  -65.277  53.824  1
434228  95.384  -65.282  53.801  1
434229  95.423  -65.287  53.780  1
434230  95.462  -65.292  53.760  1
434231  95.509  -65.292  53.743  1
434232  95.557  -65.291  53.727  1
434233  95.605  -65.290  53.710  1
434234  95.645  -65.295  53.692  1
434235  95.685  -65.300  53.668  1
434236  95.726  -65.305  53.640  1
434237  95.766  -65.310  53.609  1
434238  95.806  -65.315  53.575  1
434239  95.847  -65.314  53.538  1
434240  95.889  -65.309  53.500  1
434241  95.931  -65.304  53.461  1
434242  95.973  -65.300  53.423  1
434243  96.015  -65.295  53.386  1
434244  96.056  -65.291  53.351  1
434245  96.099  -65.286  53.318  1
434246  96.141  -65.282  53.281  1
434247  96.184  -65.278  53.241  1
434248  96.228  -65.275  53.201  1
434249  96.270  -65.273  53.158  1
434250  96.314  -65.272  53.117  1
434251  96.357  -65.270  53.078  1
434252  96.399  -65.270  53.041  1
434253  96.438  -65.273  53.004  1
434254  96.475  -65.277  52.968  1
434255  96.513  -65.282  52.930  1
434256  96.550  -65.286  52.891  1
434257  96.588  -65.290  52.850  1
434258  96.625  -65.295  52.810  1
434259  96.663  -65.299  52.769  1
434260  96.701  -65.304  52.728  1
434261  96.741  -65.310  52.687  1
434262  96.781  -65.315  52.645  1
434263  96.811  -65.311  52.602  1
434264  96.853  -65.311  52.558  1
434265  96.895  -65.311  52.515  1
434266  96.937  -65.311  52.472  1
434267  96.978  -65.311  52.429  1
434268  97.020  -65.310  52.386  1
434269  97.062  -65.310  52.343  1
434270  97.104  -65.310  52.297  1
434271  97.108  -65.294  52.249  1
434272  97.141  -65.300  52.202  1
434273  97.176  -65.308  52.155  1
434274  97.212  -65.315  52.109  1
434275  97.242  -65.327  52.067  1
434276  97.265  -65.345  52.026  1
434277  97.306  -65.353  51.986  1
434278  97.346  -65.362  51.949  1
434279  97.385  -65.371  51.912  1
434280  97.426  -65.380  51.877  1
434281  97.465  -65.389  51.845  1
434282  97.506  -65.398  51.812  1
434283  97.545  -65.408  51.773  1
434284  97.586  -65.417  51.732  1
434285  97.626  -65.426  51.692  1
434286  97.663  -65.432  51.655  1
434287  97.696  -65.431  51.618  1
434288  97.728  -65.429  51.582  1
434289  97.760  -65.427  51.544  1
434290  97.793  -65.425  51.508  1
434291  97.825  -65.423  51.474  1
434292  97.858  -65.421  51.442  1
434293  97.887  -65.426  51.409  1
434294  97.916  -65.431  51.376  1
434295  97.944  -65.436  51.341  1
434296  97.974  -65.442  51.303  1
434297  98.009  -65.447  51.264  1
434298  98.044  -65.452  51.228  1
434299  98.079  -65.458  51.194  1
434300  98.114  -65.463  51.161  1
434301  98.149  -65.468  51.127  1
434302  98.184  -65.473  51.092  1
434303  98.221  -65.479  51.055  1
434304  98.258  -65.484  51.018  1
434305  98.296  -65.490  50.982  1
434306  98.333  -65.496  50.947  1
434307  98.370  -65.501  50.915  1
434308  98.407  -65.507  50.880  1
434309  98.444  -65.512  50.840  1
434310  98.482  -65.517  50.797  1
434311  98.519  -65.523  50.750  1
434312  98.561  -65.528  50.700  1
434313  98.605  -65.533  50.646  1
434314  98.650  -65.539  50.591  1
434315  98.693  -65.544  50.534  1
434316  98.735  -65.550  50.479  1
434317  98.778  -65.556  50.422  1
434318  98.820  -65.562  50.363  1
434319  98.862  -65.568  50.303  1
434320  98.904  -65.574  50.245  1
434321  98.947  -65.579  50.186  1
434322  98.993  -65.581  50.128  1
434323  99.039  -65.583  50.072  1
434324  99.083  -65.585  50.018  1
434325  99.123  -65.590  49.965  1
434326  99.163  -65.594  49.917  1
434327  99.202  -65.598  49.871  1
434328  99.239  -65.598  49.828  1
434329  99.286  -65.602  49.786  1
434330  99.340  -65.607  49.742  1
434331  99.394  -65.612  49.696  1
434332  99.447  -65.618  49.648  1
434333  99.501  -65.624  49.601  1
434334  99.555  -65.629  49.555  1
434335  99.610  -65.634  49.511  1
434336  99.664  -65.637  49.467  1
434337  99.709  -65.647  49.421  1
434338  99.753  -65.658  49.373  1
434339  99.796  -65.668  49.325  1
434340  99.840  -65.678  49.277  1
434341  99.893  -65.681  49.229  1
434342  99.975  -65.657  49.180  1
434343  99.994  -65.677  49.131  1
434344  100.014  -65.641  49.081  1
434345  100.041  -65.614  49.031  1
434346  100.080  -65.601  48.982  1
434347  100.123  -65.593  48.935  1
434348  100.171  -65.590  48.888  1
434349  100.219  -65.588  48.842  1
434350  100.267  -65.586  48.797  1
434351  100.316  -65.584  48.752  1
434352  100.363  -65.582  48.707  1
434353  100.412  -65.580  48.664  1
434354  100.459  -65.579  48.622  1
434355  100.497  -65.584  48.579  1
434772  88.396  -64.295  55.304  1
434773  88.442  -64.299  55.304  1
434774  88.488  -64.303  55.306  1
434775  88.534  -64.307  55.310  1
434776  88.580  -64.311  55.314  1
434777  88.627  -64.314  55.319  1
434778  88.673  -64.318  55.324  1
434779  88.735  -64.315  55.330  1
434780  88.798  -64.311  55.335  1
434781  88.861  -64.306  55.342  1
434782  88.924  -64.302  55.348  1
434783  88.987  -64.298  55.353  1
434784  89.050  -64.293  55.354  1
434785  89.097  -64.303  55.351  1
434786  89.133  -64.322  55.343  1
434787  89.171  -64.340  55.333  1
434788  89.207  -64.359  55.323  1
434789  89.244  -64.377  55.313  1
434790  89.281  -64.396  55.307  1
434791  89.318  -64.414  55.302  1
434792  89.355  -64.433  55.298  1
434793  89.392  -64.452  55.288  1
434794  89.428  -64.471  55.274  1
434795  89.466  -64.489  55.258  1
434796  89.503  -64.508  55.239  1
434797  89.543  -64.521  55.215  1
434798  89.590  -64.524  55.191  1
434799  89.637  -64.526  55.167  1
434800  89.685  -64.528  55.145  1
434801  89.732  -64.530  55.125  1
434802  89.779  -64.533  55.106  1
434803  89.827  -64.535  55.090  1
434804  89.874  -64.537  55.075  1
434805  89.921  -64.540  55.062  1
434806  89.969  -64.542  55.051  1
434807  90.016  -64.544  55.045  1
434808  90.063  -64.546  55.040  1
434809  90.110  -64.549  55.036  1
434810  90.158  -64.551  55.034  1
434811  90.205  -64.553  55.033  1
434812  90.252  -64.555  55.032  1
434813  90.300  -64.558  55.033  1
434814  90.347  -64.560  55.034  1
434815  90.394  -64.562  55.034  1
434816  90.442  -64.565  55.034  1
434817  90.490  -64.571  55.033  1
434818  90.539  -64.577  55.031  1
434819  90.588  -64.584  55.027  1
434820  90.636  -64.590  55.021  1
434821  90.680  -64.601  55.009  1
434822  90.721  -64.616  54.998  1
434823  90.760  -64.633  54.985  1
434824  90.800  -64.649  54.972  1
434825  90.841  -64.665  54.958  1
434826  90.886  -64.675  54.943  1
434827  90.931  -64.686  54.928  1
434828  90.976  -64.696  54.913  1
434829  91.021  -64.706  54.899  1
434830  91.067  -64.715  54.884  1
434831  91.111  -64.725  54.871  1
434832  91.157  -64.736  54.857  1
434833  91.202  -64.746  54.843  1
434834  91.247  -64.756  54.830  1
434835  91.292  -64.765  54.817  1
434836  91.338  -64.776  54.804  1
434837  91.382  -64.786  54.793  1
434838  91.428  -64.796  54.783  1
434839  91.472  -64.806  54.773  1
434840  91.518  -64.815  54.764  1
434841  91.563  -64.826  54.756  1
434842  91.608  -64.836  54.749  1
434843  91.653  -64.846  54.744  1
434844  91.699  -64.856  54.738  1
434845  91.743  -64.866  54.734  1
434846  91.789  -64.876  54.730  1
434847  91.834  -64.886  54.727  1
434848  91.879  -64.896  54.723  1
434849  91.924  -64.906  54.719  1
434850  91.969  -64.916  54.713  1
434851  92.014  -64.926  54.707  1
434852  92.060  -64.936  54.700  1
434853  92.104  -64.946  54.693  1
434854  92.148  -64.958  54.685  1
434855  92.166  -64.998  54.680  1
434856  92.203  -65.019  54.677  1
434857  92.266  -65.020  54.673  1
434858  92.332  -65.020  54.671  1
434859  92.398  -65.020  54.669  1
434860  92.463  -65.021  54.665  1
434861  92.515  -65.021  54.660  1
434862  92.564  -65.022  54.655  1
434863  92.614  -65.022  54.651  1
434864  92.664  -65.024  54.647  1
434865  92.719  -65.030  54.644  1
434866  92.774  -65.035  54.639  1
434867  92.829  -65.041  54.635  1
434868  92.880  -65.045  54.633  1
434869  92.926  -65.050  54.630  1
434870  92.971  -65.054  54.627  1
434871  93.016  -65.059  54.623  1
434872  93.062  -65.063  54.621  1
434873  93.108  -65.068  54.618  1
434874  93.153  -65.072  54.617  1
434875  93.198  -65.077  54.616  1
434876  93.243  -65.082  54.614  1
434877  93.289  -65.086  54.612  1
434878  93.335  -65.090  54.612  1
434879  93.380  -65.094  54.613  1
434880  93.427  -65.098  54.614  1
434881  93.473  -65.102  54.616  1
434882  93.518  -65.106  54.618  1
434883  93.564  -65.110  54.617  1
434884  93.609  -65.114  54.617  1
434885  93.655  -65.118  54.617  1
434886  93.699  -65.122  54.616  1
434887  93.744  -65.125  54.616  1
434888  93.788  -65.128  54.615  1
434889  93.832  -65.131  54.612  1
434890  93.876  -65.135  54.608  1
434891  93.921  -65.138  54.602  1
434892  93.965  -65.141  54.595  1
434893  94.003  -65.140  54.585  1
434894  94.036  -65.135  54.575  1
434895  94.069  -65.131  54.562  1
434896  94.103  -65.129  54.546  1
434897  94.137  -65.131  54.528  1
434898  94.172  -65.132  54.509  1
434899  94.207  -65.133  54.488  1
434900  94.242  -65.135  54.466  1
434901  94.276  -65.136  54.443  1
434902  94.311  -65.138  54.421  1
434903  94.345  -65.139  54.399  1
434904  94.380  -65.141  54.379  1
434905  94.415  -65.142  54.360  1
434906  94.450  -65.144  54.343  1
434907  94.487  -65.145  54.326  1
434908  94.526  -65.147  54.307  1
434909  94.566  -65.148  54.287  1
434910  94.605  -65.150  54.268  1
434911  94.649  -65.154  54.246  1
434912  94.693  -65.157  54.223  1
434913  94.737  -65.161  54.199  1
434914  94.781  -65.165  54.172  1
434915  94.826  -65.169  54.143  1
434916  94.870  -65.173  54.114  1
434917  94.913  -65.176  54.088  1
434918  94.957  -65.179  54.065  1
434919  95.000  -65.182  54.045  1
434920  95.043  -65.185  54.025  1
434921  95.086  -65.189  54.003  1
434922  95.126  -65.195  53.979  1
434923  95.166  -65.201  53.955  1
434924  95.206  -65.207  53.930  1
434925  95.236  -65.223  53.903  1
434926  95.264  -65.240  53.875  1
434927  95.304  -65.245  53.847  1
434928  95.343  -65.251  53.820  1
434929  95.382  -65.255  53.796  1
434930  95.421  -65.261  53.774  1
434931  95.460  -65.266  53.753  1
434932  95.508  -65.264  53.737  1
434933  95.556  -65.264  53.721  1
434934  95.604  -65.262  53.703  1
434935  95.647  -65.265  53.683  1
434936  95.687  -65.270  53.660  1
434937  95.728  -65.275  53.633  1
434938  95.768  -65.280  53.602  1
434939  95.809  -65.280  53.569  1
434940  95.850  -65.276  53.532  1
434941  95.892  -65.271  53.494  1
434942  95.935  -65.267  53.456  1
434943  95.976  -65.262  53.418  1
434944  96.018  -65.257  53.380  1
434945  96.060  -65.253  53.343  1
434946  96.102  -65.248  53.308  1
434947  96.144  -65.244  53.273  1
434948  96.187  -65.240  53.235  1
434949  96.230  -65.239  53.197  1
434950  96.273  -65.238  53.154  1
434951  96.316  -65.236  53.114  1
434952  96.359  -65.235  53.074  1
434953  96.401  -65.234  53.033  1
434954  96.439  -65.239  52.995  1
434955  96.476  -65.242  52.959  1
434956  96.514  -65.247  52.921  1
434957  96.551  -65.251  52.881  1
434958  96.589  -65.255  52.841  1
434959  96.629  -65.261  52.801  1
434960  96.669  -65.267  52.761  1
434961  96.709  -65.273  52.720  1
434962  96.749  -65.279  52.679  1
434963  96.789  -65.285  52.637  1
434964  96.814  -65.281  52.594  1
434965  96.846  -65.278  52.550  1
434966  96.888  -65.278  52.507  1
434967  96.929  -65.277  52.463  1
434968  96.971  -65.277  52.421  1
434969  97.013  -65.276  52.379  1
434970  97.054  -65.276  52.336  1
434971  97.084  -65.271  52.291  1
434972  97.102  -65.267  52.244  1
434973  97.137  -65.274  52.196  1
434974  97.172  -65.282  52.148  1
434975  97.208  -65.289  52.101  1
434976  97.243  -65.297  52.057  1
434977  97.272  -65.311  52.015  1
434978  97.311  -65.320  51.972  1
434979  97.352  -65.329  51.932  1
434980  97.391  -65.338  51.895  1
434981  97.432  -65.347  51.860  1
434982  97.471  -65.356  51.827  1
434983  97.510  -65.363  51.796  1
434984  97.549  -65.370  51.757  1
434985  97.588  -65.377  51.715  1
434986  97.627  -65.385  51.675  1
434987  97.667  -65.391  51.638  1
434988  97.702  -65.392  51.602  1
434989  97.735  -65.389  51.565  1
434990  97.767  -65.388  51.527  1
434991  97.800  -65.386  51.490  1
434992  97.832  -65.384  51.456  1
434993  97.865  -65.382  51.424  1
434994  97.894  -65.386  51.392  1
434995  97.923  -65.392  51.358  1
434996  97.951  -65.397  51.322  1
434997  97.980  -65.402  51.282  1
434998  98.008  -65.407  51.243  1
434999  98.043  -65.412  51.207  1
435000  98.078  -65.417  51.173  1
435001  98.113  -65.423  51.139  1
435002  98.148  -65.428  51.106  1
435003  98.184  -65.433  51.069  1
435004  98.222  -65.439  51.032  1
435005  98.259  -65.445  50.995  1
435006  98.296  -65.450  50.961  1
435007  98.334  -65.456  50.928  1
435008  98.370  -65.461  50.899  1
435009  98.408  -65.467  50.867  1
435010  98.445  -65.473  50.830  1
435011  98.482  -65.478  50.786  1
435012  98.519  -65.483  50.738  1
435013  98.564  -65.489  50.688  1
435014  98.608  -65.494  50.635  1
435015  98.652  -65.499  50.580  1
435016  98.695  -65.505  50.523  1
435017  98.737  -65.511  50.466  1
435018  98.779  -65.517  50.408  1
435019  98.821  -65.524  50.349  1
435020  98.863  -65.530  50.289  1
435021  98.906  -65.536  50.230  1
435022  98.950  -65.539  50.171  1
435023  98.996  -65.541  50.115  1
435024  99.042  -65.543  50.059  1
435025  99.088  -65.544  50.005  1
435026  99.128  -65.549  49.952  1
435027  99.167  -65.553  49.903  1
435028  99.205  -65.554  49.858  1
435029  99.242  -65.555  49.816  1
435030  99.289  -65.558  49.774  1
435031  99.343  -65.564  49.731  1
435032  99.397  -65.569  49.688  1
435033  99.451  -65.575  49.642  1
435034  99.505  -65.580  49.596  1
435035  99.559  -65.585  49.551  1
435036  99.614  -65.588  49.506  1
435037  99.668  -65.591  49.461  1
435038  99.713  -65.601  49.413  1
435039  99.757  -65.611  49.365  1
435040  99.801  -65.621  49.317  1
435041  99.845  -65.632  49.269  1
435042  99.911  -65.622  49.221  1
435043  99.994  -65.598  49.172  1
435044  100.007  -65.630  49.123  1
435045  100.028  -65.594  49.073  1
435046  100.055  -65.567  49.024  1
435047  100.093  -65.554  48.976  1
435048  100.137  -65.546  48.928  1
435049  100.185  -65.544  48.882  1
435050  100.233  -65.542  48.837  1
435051  100.281  -65.540  48.791  1
435052  100.330  -65.538  48.745  1
435053  100.378  -65.536  48.702  1
435054  100.426  -65.533  48.659  1
435055  100.469  -65.536  48.617  1
435056  100.507  -65.541  48.575  1
435473  88.398  -64.242  55.306  1
435474  88.445  -64.245  55.305  1
435475  88.490  -64.249  55.307  1
435476  88.537  -64.254  55.310  1
435477  88.583  -64.258  55.314  1
435478  88.634  -64.259  55.318  1
435479  88.697  -64.255  55.322  1
435480  88.760  -64.250  55.327  1
435481  88.824  -64.245  55.330  1
435482  88.887  -64.242  55.333  1
435483  88.950  -64.237  55.337  1
435484  89.013  -64.233  55.340  1
435485  89.064  -64.239  55.340  1
435486  89.101  -64.257  55.337  1
435487  89.138  -64.276  55.331  1
435488  89.175  -64.294  55.323  1
435489  89.212  -64.313  55.315  1
435490  89.249  -64.331  55.309  1
435491  89.286  -64.350  55.304  1
435492  89.323  -64.368  55.300  1
435493  89.359  -64.387  55.295  1
435494  89.397  -64.405  55.287  1
435495  89.434  -64.424  55.275  1
435496  89.470  -64.443  55.259  1
435497  89.507  -64.461  55.241  1
435498  89.544  -64.480  55.219  1
435499  89.591  -64.483  55.196  1
435500  89.638  -64.485  55.174  1
435501  89.686  -64.487  55.153  1
435502  89.733  -64.490  55.133  1
435503  89.780  -64.492  55.114  1
435504  89.828  -64.494  55.099  1
435505  89.875  -64.496  55.085  1
435506  89.922  -64.499  55.073  1
435507  89.970  -64.501  55.063  1
435508  90.017  -64.503  55.058  1
435509  90.064  -64.505  55.053  1
435510  90.112  -64.508  55.050  1
435511  90.159  -64.510  55.048  1
435512  90.206  -64.512  55.047  1
435513  90.254  -64.515  55.047  1
435514  90.301  -64.517  55.049  1
435515  90.348  -64.519  55.051  1
435516  90.396  -64.521  55.052  1
435517  90.443  -64.524  55.053  1
435518  90.490  -64.526  55.053  1
435519  90.538  -64.528  55.051  1
435520  90.586  -64.535  55.048  1
435521  90.633  -64.543  55.042  1
435522  90.673  -64.559  55.031  1
435523  90.715  -64.573  55.018  1
435524  90.760  -64.583  55.002  1
435525  90.805  -64.593  54.986  1
435526  90.851  -64.603  54.968  1
435527  90.896  -64.613  54.948  1
435528  90.941  -64.623  54.931  1
435529  90.986  -64.633  54.915  1
435530  91.031  -64.643  54.899  1
435531  91.076  -64.653  54.882  1
435532  91.121  -64.663  54.869  1
435533  91.167  -64.673  54.854  1
435534  91.212  -64.683  54.840  1
435535  91.257  -64.693  54.826  1
435536  91.302  -64.703  54.813  1
435537  91.347  -64.713  54.800  1
435538  91.392  -64.723  54.789  1
435539  91.437  -64.733  54.779  1
435540  91.483  -64.743  54.767  1
435541  91.528  -64.753  54.758  1
435542  91.573  -64.763  54.749  1
435543  91.618  -64.773  54.741  1
435544  91.663  -64.784  54.735  1
435545  91.708  -64.794  54.729  1
435546  91.753  -64.803  54.724  1
435547  91.799  -64.813  54.719  1
435548  91.844  -64.823  54.714  1
435549  91.889  -64.834  54.709  1
435550  91.934  -64.844  54.704  1
435551  91.979  -64.853  54.698  1
435552  92.024  -64.863  54.692  1
435553  92.069  -64.874  54.685  1
435554  92.115  -64.884  54.679  1
435555  92.160  -64.894  54.673  1
435556  92.188  -64.922  54.668  1
435557  92.217  -64.963  54.664  1
435558  92.277  -64.971  54.660  1
435559  92.343  -64.972  54.657  1
435560  92.409  -64.972  54.655  1
435561  92.464  -64.972  54.651  1
435562  92.513  -64.972  54.647  1
435563  92.562  -64.973  54.642  1
435564  92.611  -64.973  54.640  1
435565  92.662  -64.975  54.635  1
435566  92.717  -64.981  54.631  1
435567  92.771  -64.986  54.628  1
435568  92.826  -64.991  54.625  1
435569  92.876  -65.003  54.623  1
435570  92.924  -65.012  54.618  1
435571  92.970  -65.014  54.615  1
435572  93.016  -65.016  54.611  1
435573  93.061  -65.019  54.607  1
435574  93.107  -65.022  54.603  1
435575  93.152  -65.026  54.602  1
435576  93.198  -65.031  54.602  1
435577  93.243  -65.035  54.602  1
435578  93.289  -65.040  54.602  1
435579  93.334  -65.044  54.602  1
435580  93.380  -65.048  54.604  1
435581  93.426  -65.052  54.606  1
435582  93.471  -65.057  54.608  1
435583  93.517  -65.060  54.610  1
435584  93.562  -65.064  54.611  1
435585  93.608  -65.069  54.612  1
435586  93.653  -65.072  54.612  1
435587  93.699  -65.076  54.613  1
435588  93.745  -65.080  54.613  1
435589  93.789  -65.084  54.613  1
435590  93.834  -65.087  54.611  1
435591  93.878  -65.090  54.607  1
435592  93.922  -65.094  54.600  1
435593  93.967  -65.097  54.593  1
435594  94.006  -65.097  54.584  1
435595  94.040  -65.092  54.574  1
435596  94.072  -65.088  54.560  1
435597  94.107  -65.089  54.543  1
435598  94.142  -65.091  54.525  1
435599  94.177  -65.092  54.506  1
435600  94.211  -65.094  54.484  1
435601  94.246  -65.095  54.462  1
435602  94.280  -65.097  54.439  1
435603  94.315  -65.098  54.416  1
435604  94.350  -65.100  54.394  1
435605  94.385  -65.101  54.373  1
435606  94.419  -65.103  54.353  1
435607  94.454  -65.104  54.334  1
435608  94.490  -65.106  54.316  1
435609  94.530  -65.107  54.298  1
435610  94.569  -65.109  54.279  1
435611  94.612  -65.112  54.259  1
435612  94.657  -65.116  54.238  1
435613  94.700  -65.120  54.213  1
435614  94.745  -65.123  54.189  1
435615  94.789  -65.127  54.162  1
435616  94.833  -65.131  54.134  1
435617  94.877  -65.135  54.108  1
435618  94.921  -65.138  54.082  1
435619  94.964  -65.141  54.059  1
435620  95.007  -65.145  54.039  1
435621  95.051  -65.148  54.020  1
435622  95.091  -65.154  53.999  1
435623  95.130  -65.160  53.977  1
435624  95.170  -65.166  53.954  1
435625  95.210  -65.172  53.928  1
435626  95.243  -65.185  53.900  1
435627  95.269  -65.205  53.872  1
435628  95.301  -65.219  53.844  1
435629  95.340  -65.224  53.816  1
435630  95.380  -65.229  53.790  1
435631  95.418  -65.234  53.767  1
435632  95.460  -65.238  53.746  1
435633  95.508  -65.236  53.729  1
435634  95.555  -65.235  53.713  1
435635  95.603  -65.234  53.694  1
435636  95.649  -65.235  53.674  1
435637  95.689  -65.240  53.651  1
435638  95.730  -65.245  53.624  1
435639  95.770  -65.247  53.594  1
435640  95.812  -65.242  53.560  1
435641  95.854  -65.238  53.524  1
435642  95.896  -65.233  53.487  1
435643  95.938  -65.229  53.450  1
435644  95.979  -65.224  53.411  1
435645  96.021  -65.220  53.373  1
435646  96.063  -65.216  53.334  1
435647  96.105  -65.211  53.299  1
435648  96.148  -65.204  53.264  1
435649  96.189  -65.203  53.228  1
435650  96.232  -65.203  53.190  1
435651  96.275  -65.201  53.149  1
435652  96.318  -65.201  53.110  1
435653  96.361  -65.199  53.069  1
435654  96.402  -65.199  53.027  1
435655  96.440  -65.204  52.987  1
435656  96.477  -65.207  52.949  1
435657  96.516  -65.213  52.910  1
435658  96.556  -65.219  52.870  1
435659  96.597  -65.225  52.830  1
435660  96.637  -65.231  52.790  1
435661  96.677  -65.236  52.751  1
435662  96.717  -65.242  52.711  1
435663  96.757  -65.248  52.671  1
435664  96.797  -65.254  52.629  1
435665  96.827  -65.254  52.587  1
435666  96.847  -65.247  52.542  1
435667  96.880  -65.244  52.497  1
435668  96.922  -65.244  52.453  1
435669  96.964  -65.244  52.410  1
435670  97.006  -65.243  52.369  1
435671  97.047  -65.243  52.326  1
435672  97.063  -65.233  52.281  1
435673  97.098  -65.241  52.234  1
435674  97.133  -65.248  52.187  1
435675  97.168  -65.256  52.139  1
435676  97.204  -65.264  52.093  1
435677  97.239  -65.271  52.049  1
435678  97.277  -65.274  52.006  1
435679  97.314  -65.281  51.962  1
435680  97.353  -65.288  51.920  1
435681  97.391  -65.295  51.880  1
435682  97.430  -65.302  51.842  1
435683  97.469  -65.310  51.808  1
435684  97.508  -65.317  51.776  1
435685  97.547  -65.324  51.738  1
435686  97.586  -65.332  51.697  1
435687  97.625  -65.339  51.656  1
435688  97.665  -65.345  51.619  1
435689  97.706  -65.350  51.583  1
435690  97.741  -65.350  51.545  1
435691  97.774  -65.348  51.507  1
435692  97.806  -65.346  51.469  1
435693  97.839  -65.344  51.435  1
435694  97.871  -65.342  51.401  1
435695  97.901  -65.346  51.368  1
435696  97.929  -65.351  51.334  1
435697  97.958  -65.357  51.299  1
435698  97.987  -65.362  51.260  1
435699  98.015  -65.367  51.221  1
435700  98.043  -65.373  51.184  1
435701  98.077  -65.377  51.149  1
435702  98.111  -65.383  51.115  1
435703  98.148  -65.389  51.082  1
435704  98.185  -65.394  51.046  1
435705  98.222  -65.399  51.010  1
435706  98.260  -65.405  50.976  1
435707  98.297  -65.411  50.943  1
435708  98.334  -65.416  50.911  1
435709  98.371  -65.422  50.880  1
435710  98.408  -65.427  50.848  1
435711  98.446  -65.432  50.812  1
435712  98.483  -65.436  50.769  1
435713  98.522  -65.441  50.721  1
435714  98.566  -65.445  50.670  1
435715  98.610  -65.449  50.615  1
435716  98.654  -65.453  50.559  1
435717  98.697  -65.460  50.502  1
435718  98.738  -65.467  50.445  1
435719  98.781  -65.473  50.387  1
435720  98.823  -65.480  50.329  1
435721  98.865  -65.486  50.270  1
435722  98.904  -65.492  50.211  1
435723  98.949  -65.496  50.154  1
435724  98.998  -65.501  50.097  1
435725  99.044  -65.502  50.041  1
435726  99.090  -65.504  49.987  1
435727  99.132  -65.508  49.936  1
435728  99.170  -65.509  49.890  1
435729  99.207  -65.510  49.847  1
435730  99.244  -65.511  49.806  1
435731  99.293  -65.514  49.767  1
435732  99.347  -65.521  49.725  1
435733  99.401  -65.526  49.682  1
435734  99.455  -65.531  49.638  1
435735  99.509  -65.536  49.591  1
435736  99.563  -65.539  49.545  1
435737  99.618  -65.542  49.500  1
435738  99.672  -65.545  49.453  1
435739  99.718  -65.554  49.405  1
435740  99.762  -65.564  49.356  1
435741  99.806  -65.575  49.307  1
435742  99.850  -65.585  49.259  1
435743  99.930  -65.563  49.211  1
435744  100.013  -65.539  49.163  1
435745  100.020  -65.583  49.114  1
435746  100.041  -65.547  49.065  1
435747  100.068  -65.520  49.015  1
435748  100.107  -65.507  48.967  1
435749  100.151  -65.500  48.920  1
435750  100.200  -65.498  48.875  1
435751  100.248  -65.496  48.830  1
435752  100.296  -65.494  48.784  1
435753  100.344  -65.492  48.740  1
435754  100.393  -65.489  48.696  1
435755  100.440  -65.488  48.654  1
435756  100.479  -65.493  48.612  1
435757  100.517  -65.499  48.570  1
436175  88.447  -64.192  55.308  1
436176  88.493  -64.196  55.309  1
436177  88.539  -64.200  55.312  1
436178  88.597  -64.198  55.315  1
436179  88.660  -64.194  55.318  1
436180  88.723  -64.189  55.320  1
436181  88.786  -64.186  55.324  1
436182  88.849  -64.181  55.326  1
436183  88.913  -64.176  55.327  1
436184  88.972  -64.176  55.328  1
436185  89.021  -64.187  55.330  1
436186  89.069  -64.197  55.329  1
436187  89.107  -64.214  55.326  1
436188  89.143  -64.230  55.322  1
436189  89.180  -64.248  55.315  1
436190  89.217  -64.267  55.311  1
436191  89.254  -64.285  55.308  1
436192  89.291  -64.304  55.305  1
436193  89.327  -64.322  55.301  1
436194  89.365  -64.341  55.298  1
436195  89.401  -64.359  55.291  1
436196  89.438  -64.378  55.281  1
436197  89.475  -64.396  55.267  1
436198  89.512  -64.415  55.248  1
436199  89.549  -64.433  55.226  1
436200  89.592  -64.442  55.204  1
436201  89.639  -64.444  55.183  1
436202  89.687  -64.446  55.162  1
436203  89.734  -64.449  55.144  1
436204  89.781  -64.451  55.125  1
436205  89.829  -64.453  55.110  1
436206  89.876  -64.455  55.097  1
436207  89.923  -64.458  55.086  1
436208  89.971  -64.460  55.077  1
436209  90.018  -64.462  55.071  1
436210  90.065  -64.464  55.067  1
436211  90.113  -64.467  55.064  1
436212  90.160  -64.469  55.064  1
436213  90.207  -64.471  55.063  1
436214  90.255  -64.474  55.065  1
436215  90.302  -64.476  55.067  1
436216  90.350  -64.478  55.070  1
436217  90.397  -64.480  55.072  1
436218  90.444  -64.483  55.075  1
436219  90.492  -64.485  55.075  1
436220  90.539  -64.487  55.075  1
436221  90.588  -64.486  55.072  1
436222  90.635  -64.494  55.066  1
436223  90.679  -64.505  55.055  1
436224  90.725  -64.515  55.040  1
436225  90.770  -64.524  55.023  1
436226  90.815  -64.534  55.003  1
436227  90.860  -64.544  54.983  1
436228  90.905  -64.554  54.957  1
436229  90.950  -64.564  54.936  1
436230  90.996  -64.574  54.917  1
436231  91.041  -64.584  54.899  1
436232  91.086  -64.594  54.882  1
436233  91.131  -64.604  54.868  1
436234  91.176  -64.614  54.853  1
436235  91.221  -64.624  54.838  1
436236  91.266  -64.634  54.823  1
436237  91.311  -64.643  54.810  1
436238  91.357  -64.654  54.796  1
436239  91.402  -64.664  54.785  1
436240  91.447  -64.674  54.773  1
436241  91.492  -64.684  54.762  1
436242  91.537  -64.693  54.752  1
436243  91.582  -64.703  54.743  1
436244  91.628  -64.713  54.735  1
436245  91.673  -64.724  54.728  1
436246  91.718  -64.734  54.720  1
436247  91.763  -64.743  54.715  1
436248  91.808  -64.753  54.709  1
436249  91.853  -64.763  54.703  1
436250  91.898  -64.773  54.697  1
436251  91.944  -64.783  54.692  1
436252  91.989  -64.793  54.685  1
436253  92.034  -64.803  54.679  1
436254  92.079  -64.813  54.673  1
436255  92.124  -64.823  54.667  1
436256  92.169  -64.833  54.661  1
436257  92.215  -64.847  54.656  1
436258  92.249  -64.888  54.652  1
436259  92.288  -64.922  54.648  1
436260  92.354  -64.922  54.645  1
436261  92.413  -64.922  54.642  1
436262  92.462  -64.923  54.639  1
436263  92.511  -64.924  54.635  1
436264  92.560  -64.924  54.631  1
436265  92.609  -64.925  54.629  1
436266  92.659  -64.926  54.624  1
436267  92.714  -64.931  54.620  1
436268  92.769  -64.937  54.617  1
436269  92.821  -64.946  54.614  1
436270  92.870  -64.959  54.612  1
436271  92.920  -64.972  54.608  1
436272  92.968  -64.982  54.604  1
436273  93.013  -64.984  54.600  1
436274  93.059  -64.987  54.597  1
436275  93.105  -64.989  54.595  1
436276  93.150  -64.991  54.594  1
436277  93.196  -64.994  54.596  1
436278  93.242  -64.997  54.597  1
436279  93.288  -64.999  54.598  1
436280  93.333  -65.001  54.599  1
436281  93.379  -65.003  54.599  1
436282  93.425  -65.007  54.600  1
436283  93.470  -65.010  54.602  1
436284  93.516  -65.015  54.604  1
436285  93.561  -65.019  54.606  1
436286  93.607  -65.022  54.607  1
436287  93.652  -65.026  54.609  1
436288  93.698  -65.031  54.611  1
436289  93.744  -65.035  54.612  1
436290  93.789  -65.038  54.611  1
436291  93.835  -65.043  54.610  1
436292  93.879  -65.046  54.605  1
436293  93.923  -65.049  54.598  1
436294  93.968  -65.052  54.592  1
436295  94.010  -65.054  54.583  1
436296  94.043  -65.050  54.571  1
436297  94.077  -65.048  54.557  1
436298  94.112  -65.050  54.540  1
436299  94.146  -65.051  54.520  1
436300  94.181  -65.053  54.501  1
436301  94.216  -65.054  54.479  1
436302  94.251  -65.056  54.456  1
436303  94.285  -65.057  54.434  1
436304  94.320  -65.059  54.409  1
436305  94.354  -65.060  54.387  1
436306  94.389  -65.062  54.366  1
436307  94.424  -65.063  54.345  1
436308  94.459  -65.065  54.325  1
436309  94.494  -65.066  54.307  1
436310  94.533  -65.068  54.288  1
436311  94.575  -65.071  54.269  1
436312  94.620  -65.075  54.249  1
436313  94.664  -65.079  54.228  1
436314  94.708  -65.082  54.203  1
436315  94.752  -65.086  54.179  1
436316  94.796  -65.090  54.153  1
436317  94.841  -65.094  54.126  1
436318  94.885  -65.098  54.103  1
436319  94.928  -65.101  54.078  1
436320  94.972  -65.104  54.056  1
436321  95.015  -65.107  54.035  1
436322  95.055  -65.113  54.015  1
436323  95.095  -65.120  53.994  1
436324  95.135  -65.125  53.972  1
436325  95.175  -65.131  53.949  1
436326  95.214  -65.137  53.925  1
436327  95.250  -65.148  53.898  1
436328  95.276  -65.167  53.870  1
436329  95.303  -65.188  53.839  1
436330  95.338  -65.197  53.810  1
436331  95.377  -65.202  53.782  1
436332  95.416  -65.207  53.758  1
436333  95.459  -65.210  53.737  1
436334  95.507  -65.209  53.719  1
436335  95.555  -65.207  53.703  1
436336  95.603  -65.207  53.686  1
436337  95.651  -65.205  53.667  1
436338  95.691  -65.210  53.644  1
436339  95.732  -65.213  53.616  1
436340  95.773  -65.210  53.585  1
436341  95.815  -65.205  53.550  1
436342  95.857  -65.201  53.514  1
436343  95.899  -65.196  53.478  1
436344  95.941  -65.192  53.440  1
436345  95.983  -65.184  53.402  1
436346  96.026  -65.177  53.365  1
436347  96.069  -65.170  53.326  1
436348  96.111  -65.163  53.290  1
436349  96.151  -65.158  53.253  1
436350  96.192  -65.158  53.217  1
436351  96.235  -65.159  53.182  1
436352  96.277  -65.160  53.142  1
436353  96.320  -65.161  53.104  1
436354  96.363  -65.163  53.064  1
436355  96.404  -65.165  53.022  1
436356  96.444  -65.171  52.980  1
436357  96.484  -65.176  52.938  1
436358  96.524  -65.182  52.897  1
436359  96.565  -65.188  52.858  1
436360  96.605  -65.195  52.818  1
436361  96.645  -65.200  52.778  1
436362  96.685  -65.206  52.740  1
436363  96.725  -65.212  52.700  1
436364  96.765  -65.218  52.661  1
436365  96.805  -65.223  52.621  1
436366  96.841  -65.227  52.579  1
436367  96.860  -65.220  52.533  1
436368  96.879  -65.213  52.487  1
436369  96.915  -65.210  52.442  1
436370  96.957  -65.210  52.399  1
436371  96.999  -65.210  52.357  1
436372  97.031  -65.206  52.314  1
436373  97.058  -65.208  52.270  1
436374  97.094  -65.216  52.224  1
436375  97.129  -65.223  52.177  1
436376  97.164  -65.231  52.130  1
436377  97.203  -65.232  52.085  1
436378  97.242  -65.233  52.041  1
436379  97.282  -65.234  51.997  1
436380  97.317  -65.238  51.953  1
436381  97.350  -65.242  51.910  1
436382  97.389  -65.249  51.867  1
436383  97.428  -65.257  51.826  1
436384  97.467  -65.264  51.789  1
436385  97.506  -65.271  51.755  1
436386  97.544  -65.279  51.717  1
436387  97.584  -65.286  51.677  1
436388  97.623  -65.293  51.637  1
436389  97.663  -65.299  51.598  1
436390  97.704  -65.304  51.562  1
436391  97.745  -65.309  51.525  1
436392  97.780  -65.308  51.487  1
436393  97.813  -65.307  51.449  1
436394  97.846  -65.304  51.414  1
436395  97.878  -65.303  51.379  1
436396  97.908  -65.306  51.344  1
436397  97.936  -65.311  51.310  1
436398  97.965  -65.317  51.274  1
436399  97.993  -65.322  51.237  1
436400  98.022  -65.327  51.198  1
436401  98.051  -65.333  51.161  1
436402  98.079  -65.338  51.126  1
436403  98.111  -65.342  51.093  1
436404  98.149  -65.348  51.058  1
436405  98.186  -65.352  51.023  1
436406  98.224  -65.357  50.990  1
436407  98.261  -65.361  50.958  1
436408  98.298  -65.367  50.926  1
436409  98.336  -65.371  50.893  1
436410  98.373  -65.376  50.861  1
436411  98.411  -65.380  50.827  1
436412  98.448  -65.386  50.790  1
436413  98.486  -65.390  50.748  1
436414  98.525  -65.395  50.700  1
436415  98.569  -65.398  50.648  1
436416  98.614  -65.402  50.592  1
436417  98.656  -65.408  50.535  1
436418  98.698  -65.414  50.478  1
436419  98.740  -65.421  50.422  1
436420  98.782  -65.428  50.365  1
436421  98.824  -65.434  50.308  1
436422  98.861  -65.439  50.250  1
436423  98.899  -65.445  50.191  1
436424  98.943  -65.449  50.135  1
436425  98.992  -65.454  50.078  1
436426  99.042  -65.458  50.023  1
436427  99.090  -65.462  49.970  1
436428  99.135  -65.465  49.921  1
436429  99.172  -65.465  49.877  1
436430  99.210  -65.466  49.837  1
436431  99.247  -65.467  49.799  1
436432  99.296  -65.471  49.761  1
436433  99.351  -65.477  49.720  1
436434  99.405  -65.483  49.677  1
436435  99.458  -65.487  49.632  1
436436  99.513  -65.490  49.586  1
436437  99.567  -65.493  49.539  1
436438  99.622  -65.496  49.493  1
436439  99.677  -65.499  49.445  1
436440  99.723  -65.508  49.396  1
436441  99.767  -65.518  49.346  1
436442  99.811  -65.528  49.296  1
436443  99.866  -65.529  49.248  1
436444  99.949  -65.504  49.201  1
436445  100.032  -65.480  49.153  1
436446  100.034  -65.533  49.104  1
436447  100.054  -65.499  49.055  1
436448  100.081  -65.472  49.006  1
436449  100.120  -65.460  48.958  1
436450  100.165  -65.454  48.912  1
436451  100.214  -65.452  48.867  1
436452  100.262  -65.450  48.823  1
436453  100.311  -65.448  48.778  1
436454  100.358  -65.445  48.734  1
436455  100.407  -65.444  48.690  1
436456  100.450  -65.445  48.648  1
436457  100.489  -65.451  48.607  1
436458  100.527  -65.456  48.565  1
436876  88.449  -64.139  55.311  1
436877  88.497  -64.142  55.311  1
436878  88.560  -64.138  55.313  1
436879  88.623  -64.133  55.315  1
436880  88.686  -64.129  55.317  1
436881  88.749  -64.125  55.319  1
436882  88.812  -64.120  55.321  1
436883  88.876  -64.117  55.322  1
436884  88.924  -64.126  55.323  1
436885  88.973  -64.137  55.325  1
436886  89.022  -64.148  55.325  1
436887  89.071  -64.157  55.323  1
436888  89.113  -64.172  55.321  1
436889  89.149  -64.189  55.318  1
436890  89.185  -64.205  55.314  1
436891  89.222  -64.222  55.313  1
436892  89.258  -64.239  55.311  1
436893  89.296  -64.258  55.309  1
436894  89.332  -64.276  55.306  1
436895  89.369  -64.295  55.305  1
436896  89.406  -64.313  55.301  1
436897  89.443  -64.332  55.292  1
436898  89.480  -64.350  55.278  1
436899  89.517  -64.369  55.258  1
436900  89.553  -64.387  55.235  1
436901  89.594  -64.402  55.214  1
436902  89.641  -64.404  55.193  1
436903  89.688  -64.406  55.173  1
436904  89.736  -64.408  55.155  1
436905  89.783  -64.411  55.137  1
436906  89.830  -64.413  55.122  1
436907  89.878  -64.415  55.109  1
436908  89.925  -64.418  55.099  1
436909  89.972  -64.420  55.091  1
436910  90.020  -64.422  55.085  1
436911  90.067  -64.424  55.082  1
436912  90.114  -64.426  55.080  1
436913  90.162  -64.428  55.080  1
436914  90.209  -64.430  55.081  1
436915  90.256  -64.433  55.086  1
436916  90.303  -64.435  55.090  1
436917  90.351  -64.437  55.094  1
436918  90.399  -64.438  55.098  1
436919  90.449  -64.436  55.101  1
436920  90.498  -64.436  55.102  1
436921  90.548  -64.434  55.101  1
436922  90.595  -64.439  55.097  1
436923  90.641  -64.451  55.092  1
436924  90.687  -64.458  55.082  1
436925  90.733  -64.466  55.066  1
436926  90.778  -64.475  55.046  1
436927  90.823  -64.486  55.023  1
436928  90.869  -64.496  54.999  1
436929  90.913  -64.505  54.968  1
436930  90.959  -64.515  54.942  1
436931  91.004  -64.525  54.920  1
436932  91.049  -64.535  54.900  1
436933  91.094  -64.545  54.882  1
436934  91.139  -64.555  54.866  1
436935  91.184  -64.565  54.851  1
436936  91.230  -64.575  54.835  1
436937  91.275  -64.585  54.820  1
436938  91.320  -64.595  54.806  1
436939  91.365  -64.605  54.793  1
436940  91.410  -64.615  54.780  1
436941  91.455  -64.624  54.768  1
436942  91.501  -64.635  54.757  1
436943  91.545  -64.645  54.746  1
436944  91.591  -64.655  54.737  1
436945  91.636  -64.665  54.729  1
436946  91.681  -64.674  54.721  1
436947  91.726  -64.684  54.713  1
436948  91.772  -64.694  54.707  1
436949  91.816  -64.704  54.700  1
436950  91.862  -64.715  54.694  1
436951  91.907  -64.725  54.688  1
436952  91.952  -64.734  54.683  1
436953  91.997  -64.744  54.677  1
436954  92.042  -64.754  54.670  1
436955  92.087  -64.764  54.664  1
436956  92.133  -64.774  54.657  1
436957  92.178  -64.784  54.651  1
436958  92.224  -64.794  54.647  1
436959  92.269  -64.825  54.642  1
436960  92.313  -64.855  54.638  1
436961  92.362  -64.873  54.635  1
436962  92.411  -64.874  54.631  1
436963  92.460  -64.875  54.627  1
436964  92.509  -64.875  54.625  1
436965  92.558  -64.875  54.622  1
436966  92.607  -64.875  54.619  1
436967  92.657  -64.877  54.615  1
436968  92.712  -64.882  54.611  1
436969  92.766  -64.889  54.607  1
436970  92.815  -64.902  54.604  1
436971  92.864  -64.915  54.602  1
436972  92.914  -64.928  54.598  1
436973  92.963  -64.941  54.595  1
436974  93.011  -64.952  54.591  1
436975  93.057  -64.954  54.589  1
436976  93.103  -64.957  54.589  1
436977  93.148  -64.959  54.589  1
436978  93.194  -64.962  54.591  1
436979  93.240  -64.964  54.594  1
436980  93.285  -64.966  54.594  1
436981  93.333  -64.966  54.596  1
436982  93.382  -64.963  54.597  1
436983  93.427  -64.966  54.597  1
436984  93.472  -64.969  54.599  1
436985  93.517  -64.972  54.600  1
436986  93.562  -64.975  54.601  1
436987  93.607  -64.978  54.602  1
436988  93.652  -64.982  54.604  1
436989  93.697  -64.985  54.606  1
436990  93.743  -64.989  54.607  1
436991  93.788  -64.993  54.606  1
436992  93.834  -64.997  54.603  1
436993  93.880  -65.001  54.599  1
436994  93.925  -65.005  54.592  1
436995  93.969  -65.008  54.586  1
436996  94.013  -65.011  54.578  1
436997  94.047  -65.007  54.566  1
436998  94.082  -65.009  54.551  1
436999  94.116  -65.010  54.533  1
437000  94.151  -65.012  54.514  1
437001  94.186  -65.013  54.492  1
437002  94.220  -65.015  54.470  1
437003  94.255  -65.016  54.448  1
437004  94.290  -65.018  54.426  1
437005  94.325  -65.019  54.402  1
437006  94.359  -65.021  54.379  1
437007  94.394  -65.022  54.357  1
437008  94.428  -65.024  54.337  1
437009  94.463  -65.025  54.317  1
437010  94.498  -65.027  54.298  1
437011  94.539  -65.029  54.277  1
437012  94.583  -65.033  54.257  1
437013  94.627  -65.037  54.238  1
437014  94.671  -65.041  54.217  1
437015  94.715  -65.044  54.193  1
437016  94.760  -65.048  54.169  1
437017  94.804  -65.052  54.144  1
437018  94.848  -65.056  54.119  1
437019  94.892  -65.060  54.098  1
437020  94.936  -65.063  54.075  1
437021  94.979  -65.067  54.053  1
437022  95.019  -65.073  54.032  1
437023  95.059  -65.079  54.012  1
437024  95.099  -65.085  53.990  1
437025  95.139  -65.091  53.968  1
437026  95.179  -65.096  53.946  1
437027  95.219  -65.102  53.922  1
437028  95.257  -65.110  53.897  1
437029  95.283  -65.129  53.868  1
437030  95.310  -65.150  53.836  1
437031  95.336  -65.170  53.805  1
437032  95.375  -65.176  53.775  1
437033  95.414  -65.181  53.749  1
437034  95.458  -65.182  53.727  1
437035  95.506  -65.181  53.710  1
437036  95.554  -65.179  53.694  1
437037  95.602  -65.179  53.679  1
437038  95.650  -65.177  53.661  1
437039  95.693  -65.180  53.638  1
437040  95.735  -65.176  53.612  1
437041  95.776  -65.172  53.581  1
437042  95.819  -65.164  53.547  1
437043  95.862  -65.157  53.509  1
437044  95.905  -65.150  53.471  1
437045  95.948  -65.142  53.433  1
437046  95.990  -65.135  53.394  1
437047  96.033  -65.128  53.356  1
437048  96.075  -65.122  53.317  1
437049  96.114  -65.117  53.280  1
437050  96.154  -65.113  53.243  1
437051  96.195  -65.113  53.206  1
437052  96.238  -65.114  53.170  1
437053  96.281  -65.116  53.132  1
437054  96.323  -65.116  53.095  1
437055  96.366  -65.118  53.056  1
437056  96.406  -65.126  53.016  1
437057  96.448  -65.134  52.975  1
437058  96.488  -65.141  52.933  1
437059  96.530  -65.148  52.892  1
437060  96.571  -65.156  52.850  1
437061  96.612  -65.163  52.809  1
437062  96.653  -65.170  52.768  1
437063  96.693  -65.176  52.728  1
437064  96.733  -65.181  52.689  1
437065  96.773  -65.187  52.650  1
437066  96.813  -65.193  52.610  1
437067  96.853  -65.199  52.569  1
437068  96.874  -65.192  52.524  1
437069  96.893  -65.185  52.479  1
437070  96.912  -65.179  52.434  1
437071  96.949  -65.176  52.388  1
437072  96.991  -65.176  52.345  1
437073  97.019  -65.175  52.302  1
437074  97.054  -65.182  52.259  1
437075  97.090  -65.190  52.213  1
437076  97.129  -65.191  52.167  1
437077  97.168  -65.192  52.121  1
437078  97.208  -65.192  52.075  1
437079  97.247  -65.193  52.031  1
437080  97.287  -65.195  51.989  1
437081  97.323  -65.197  51.944  1
437082  97.357  -65.201  51.901  1
437083  97.390  -65.205  51.856  1
437084  97.426  -65.210  51.813  1
437085  97.465  -65.218  51.771  1
437086  97.504  -65.226  51.734  1
437087  97.542  -65.232  51.696  1
437088  97.581  -65.240  51.657  1
437089  97.620  -65.248  51.617  1
437090  97.660  -65.253  51.578  1
437091  97.702  -65.258  51.541  1
437092  97.743  -65.263  51.505  1
437093  97.785  -65.267  51.467  1
437094  97.819  -65.267  51.429  1
437095  97.852  -65.265  51.393  1
437096  97.884  -65.264  51.357  1
437097  97.915  -65.266  51.320  1
437098  97.943  -65.271  51.284  1
437099  97.971  -65.276  51.248  1
437100  98.000  -65.282  51.210  1
437101  98.028  -65.287  51.174  1
437102  98.057  -65.292  51.138  1
437103  98.081  -65.296  51.105  1
437104  98.112  -65.300  51.071  1
437105  98.151  -65.302  51.036  1
437106  98.189  -65.306  51.002  1
437107  98.226  -65.311  50.971  1
437108  98.264  -65.315  50.941  1
437109  98.301  -65.320  50.909  1
437110  98.339  -65.325  50.876  1
437111  98.376  -65.329  50.841  1
437112  98.414  -65.334  50.803  1
437113  98.451  -65.339  50.764  1
437114  98.488  -65.344  50.721  1
437115  98.527  -65.348  50.674  1
437116  98.572  -65.352  50.622  1
437117  98.616  -65.357  50.566  1
437118  98.657  -65.363  50.509  1
437119  98.700  -65.370  50.452  1
437120  98.742  -65.376  50.398  1
437121  98.781  -65.383  50.343  1
437122  98.818  -65.388  50.286  1
437123  98.856  -65.392  50.229  1
437124  98.893  -65.398  50.170  1
437125  98.938  -65.402  50.114  1
437126  98.987  -65.407  50.058  1
437127  99.035  -65.411  50.004  1
437128  99.085  -65.415  49.953  1
437129  99.132  -65.419  49.906  1
437130  99.175  -65.422  49.865  1
437131  99.212  -65.423  49.828  1
437132  99.250  -65.423  49.793  1
437133  99.300  -65.428  49.754  1
437134  99.354  -65.433  49.714  1
437135  99.408  -65.438  49.672  1
437136  99.463  -65.441  49.626  1
437137  99.517  -65.444  49.579  1
437138  99.572  -65.447  49.532  1
437139  99.626  -65.450  49.484  1
437140  99.681  -65.453  49.436  1
437141  99.728  -65.461  49.386  1
437142  99.772  -65.471  49.335  1
437143  99.816  -65.482  49.285  1
437144  99.885  -65.470  49.237  1
437145  99.968  -65.445  49.190  1
437146  100.051  -65.420  49.142  1
437147  100.051  -65.477  49.094  1
437148  100.068  -65.452  49.044  1
437149  100.095  -65.425  48.996  1
437150  100.134  -65.412  48.949  1
437151  100.180  -65.408  48.904  1
437152  100.228  -65.406  48.859  1
437153  100.277  -65.404  48.815  1
437154  100.325  -65.402  48.771  1
437155  100.373  -65.400  48.727  1
437156  100.421  -65.398  48.684  1
437157  100.460  -65.403  48.643  1
437158  100.498  -65.408  48.600  1
437159  100.537  -65.414  48.560  1
437577  88.460  -64.082  55.312  1
437578  88.523  -64.078  55.312  1
437579  88.586  -64.073  55.313  1
437580  88.649  -64.069  55.314  1
437581  88.712  -64.064  55.317  1
437582  88.775  -64.060  55.318  1
437583  88.828  -64.067  55.319  1
437584  88.877  -64.077  55.320  1
437585  88.926  -64.087  55.321  1
437586  88.975  -64.098  55.322  1
437587  89.024  -64.108  55.322  1
437588  89.073  -64.118  55.321  1
437589  89.118  -64.130  55.320  1
437590  89.155  -64.147  55.319  1
437591  89.191  -64.164  55.318  1
437592  89.228  -64.180  55.320  1
437593  89.264  -64.197  55.321  1
437594  89.301  -64.214  55.321  1
437595  89.337  -64.230  55.320  1
437596  89.374  -64.248  55.319  1
437597  89.411  -64.267  55.314  1
437598  89.448  -64.286  55.305  1
437599  89.484  -64.304  55.290  1
437600  89.522  -64.323  55.271  1
437601  89.558  -64.341  55.248  1
437602  89.595  -64.360  55.226  1
437603  89.642  -64.363  55.205  1
437604  89.689  -64.365  55.186  1
437605  89.737  -64.367  55.168  1
437606  89.784  -64.370  55.151  1
437607  89.831  -64.372  55.136  1
437608  89.879  -64.374  55.123  1
437609  89.926  -64.377  55.113  1
437610  89.973  -64.379  55.105  1
437611  90.021  -64.381  55.099  1
437612  90.068  -64.383  55.097  1
437613  90.115  -64.386  55.097  1
437614  90.163  -64.388  55.097  1
437615  90.211  -64.389  55.101  1
437616  90.260  -64.388  55.108  1
437617  90.309  -64.387  55.115  1
437618  90.359  -64.386  55.120  1
437619  90.408  -64.384  55.124  1
437620  90.458  -64.383  55.127  1
437621  90.508  -64.382  55.130  1
437622  90.557  -64.380  55.129  1
437623  90.602  -64.396  55.124  1
437624  90.647  -64.407  55.115  1
437625  90.693  -64.414  55.102  1
437626  90.739  -64.422  55.086  1
437627  90.786  -64.430  55.065  1
437628  90.831  -64.437  55.039  1
437629  90.877  -64.446  55.010  1
437630  90.922  -64.456  54.976  1
437631  90.967  -64.466  54.947  1
437632  91.012  -64.477  54.922  1
437633  91.058  -64.486  54.900  1
437634  91.102  -64.496  54.881  1
437635  91.148  -64.506  54.864  1
437636  91.193  -64.516  54.848  1
437637  91.238  -64.526  54.832  1
437638  91.283  -64.536  54.817  1
437639  91.328  -64.546  54.801  1
437640  91.373  -64.556  54.789  1
437641  91.419  -64.566  54.776  1
437642  91.464  -64.576  54.764  1
437643  91.509  -64.586  54.752  1
437644  91.554  -64.596  54.741  1
437645  91.599  -64.606  54.732  1
437646  91.644  -64.615  54.723  1
437647  91.689  -64.626  54.714  1
437648  91.735  -64.636  54.706  1
437649  91.780  -64.646  54.699  1
437650  91.825  -64.656  54.693  1
437651  91.870  -64.665  54.686  1
437652  91.915  -64.675  54.680  1
437653  91.960  -64.685  54.674  1
437654  92.006  -64.696  54.669  1
437655  92.051  -64.706  54.662  1
437656  92.096  -64.715  54.656  1
437657  92.141  -64.725  54.650  1
437658  92.186  -64.735  54.644  1
437659  92.233  -64.745  54.640  1
437660  92.278  -64.772  54.636  1
437661  92.322  -64.802  54.631  1
437662  92.367  -64.821  54.627  1
437663  92.411  -64.824  54.623  1
437664  92.458  -64.825  54.621  1
437665  92.507  -64.826  54.618  1
437666  92.556  -64.826  54.615  1
437667  92.604  -64.827  54.611  1
437668  92.654  -64.828  54.607  1
437669  92.709  -64.834  54.603  1
437670  92.760  -64.844  54.599  1
437671  92.809  -64.857  54.596  1
437672  92.858  -64.870  54.592  1
437673  92.908  -64.883  54.588  1
437674  92.956  -64.897  54.586  1
437675  93.006  -64.910  54.584  1
437676  93.055  -64.922  54.584  1
437677  93.100  -64.924  54.584  1
437678  93.146  -64.926  54.586  1
437679  93.192  -64.929  54.589  1
437680  93.237  -64.931  54.591  1
437681  93.283  -64.934  54.592  1
437682  93.335  -64.926  54.594  1
437683  93.384  -64.922  54.595  1
437684  93.429  -64.925  54.596  1
437685  93.474  -64.928  54.596  1
437686  93.519  -64.931  54.596  1
437687  93.564  -64.935  54.597  1
437688  93.609  -64.938  54.597  1
437689  93.654  -64.941  54.598  1
437690  93.699  -64.944  54.599  1
437691  93.744  -64.947  54.599  1
437692  93.789  -64.950  54.597  1
437693  93.834  -64.953  54.593  1
437694  93.879  -64.957  54.588  1
437695  93.924  -64.960  54.582  1
437696  93.970  -64.963  54.576  1
437697  94.015  -64.967  54.569  1
437698  94.052  -64.968  54.558  1
437699  94.086  -64.969  54.544  1
437700  94.121  -64.971  54.526  1
437701  94.155  -64.972  54.506  1
437702  94.190  -64.974  54.485  1
437703  94.224  -64.975  54.462  1
437704  94.258  -64.977  54.439  1
437705  94.292  -64.979  54.417  1
437706  94.326  -64.981  54.392  1
437707  94.359  -64.982  54.369  1
437708  94.394  -64.985  54.347  1
437709  94.427  -64.986  54.327  1
437710  94.461  -64.987  54.308  1
437711  94.494  -64.985  54.288  1
437712  94.552  -64.992  54.267  1
437713  94.600  -64.997  54.245  1
437714  94.643  -65.000  54.224  1
437715  94.686  -65.004  54.203  1
437716  94.730  -65.008  54.180  1
437717  94.773  -65.012  54.157  1
437718  94.817  -65.016  54.135  1
437719  94.860  -65.019  54.113  1
437720  94.903  -65.022  54.094  1
437721  94.944  -65.026  54.074  1
437722  94.984  -65.032  54.052  1
437723  95.024  -65.038  54.031  1
437724  95.063  -65.044  54.011  1
437725  95.103  -65.050  53.989  1
437726  95.143  -65.056  53.966  1
437727  95.183  -65.061  53.943  1
437728  95.223  -65.067  53.920  1
437729  95.263  -65.073  53.896  1
437730  95.290  -65.092  53.867  1
437731  95.317  -65.112  53.835  1
437732  95.343  -65.132  53.802  1
437733  95.372  -65.149  53.770  1
437734  95.411  -65.154  53.742  1
437735  95.458  -65.154  53.719  1
437736  95.506  -65.153  53.701  1
437737  95.553  -65.152  53.686  1
437738  95.602  -65.151  53.671  1
437739  95.650  -65.145  53.655  1
437740  95.698  -65.137  53.633  1
437741  95.741  -65.130  53.608  1
437742  95.783  -65.123  53.578  1
437743  95.826  -65.116  53.545  1
437744  95.869  -65.108  53.506  1
437745  95.912  -65.101  53.467  1
437746  95.955  -65.094  53.428  1
437747  95.997  -65.086  53.389  1
437748  96.038  -65.081  53.351  1
437749  96.078  -65.076  53.312  1
437750  96.117  -65.072  53.273  1
437751  96.156  -65.067  53.234  1
437752  96.199  -65.068  53.196  1
437753  96.241  -65.069  53.158  1
437754  96.284  -65.070  53.121  1
437755  96.327  -65.072  53.084  1
437756  96.368  -65.078  53.046  1
437757  96.408  -65.086  53.008  1
437758  96.449  -65.094  52.968  1
437759  96.490  -65.101  52.927  1
437760  96.531  -65.109  52.886  1
437761  96.573  -65.116  52.844  1
437762  96.614  -65.124  52.802  1
437763  96.655  -65.131  52.759  1
437764  96.696  -65.138  52.718  1
437765  96.737  -65.146  52.678  1
437766  96.779  -65.154  52.639  1
437767  96.820  -65.160  52.599  1
437768  96.861  -65.168  52.559  1
437769  96.887  -65.166  52.515  1
437770  96.906  -65.158  52.471  1
437771  96.926  -65.151  52.426  1
437772  96.945  -65.144  52.381  1
437773  96.979  -65.141  52.336  1
437774  97.016  -65.148  52.293  1
437775  97.055  -65.149  52.248  1
437776  97.095  -65.150  52.202  1
437777  97.134  -65.151  52.156  1
437778  97.173  -65.151  52.110  1
437779  97.213  -65.152  52.065  1
437780  97.252  -65.154  52.021  1
437781  97.292  -65.154  51.978  1
437782  97.330  -65.156  51.933  1
437783  97.363  -65.160  51.890  1
437784  97.397  -65.165  51.846  1
437785  97.431  -65.169  51.802  1
437786  97.464  -65.173  51.759  1
437787  97.501  -65.179  51.719  1
437788  97.540  -65.187  51.678  1
437789  97.579  -65.194  51.638  1
437790  97.618  -65.201  51.598  1
437791  97.658  -65.207  51.558  1
437792  97.700  -65.212  51.521  1
437793  97.741  -65.217  51.484  1
437794  97.783  -65.222  51.447  1
437795  97.824  -65.226  51.410  1
437796  97.859  -65.226  51.372  1
437797  97.891  -65.224  51.335  1
437798  97.921  -65.226  51.297  1
437799  97.950  -65.232  51.259  1
437800  97.979  -65.237  51.221  1
437801  98.007  -65.242  51.184  1
437802  98.033  -65.246  51.148  1
437803  98.057  -65.250  51.114  1
437804  98.080  -65.254  51.082  1
437805  98.114  -65.257  51.049  1
437806  98.152  -65.261  51.012  1
437807  98.190  -65.263  50.980  1
437808  98.228  -65.266  50.950  1
437809  98.266  -65.269  50.920  1
437810  98.304  -65.273  50.889  1
437811  98.341  -65.279  50.855  1
437812  98.379  -65.283  50.816  1
437813  98.416  -65.288  50.775  1
437814  98.453  -65.292  50.733  1
437815  98.491  -65.298  50.688  1
437816  98.530  -65.302  50.643  1
437817  98.574  -65.305  50.593  1
437818  98.617  -65.311  50.540  1
437819  98.659  -65.318  50.485  1
437820  98.701  -65.325  50.429  1
437821  98.739  -65.330  50.374  1
437822  98.776  -65.336  50.318  1
437823  98.813  -65.341  50.261  1
437824  98.850  -65.345  50.204  1
437825  98.887  -65.351  50.146  1
437826  98.932  -65.355  50.090  1
437827  98.981  -65.360  50.036  1
437828  99.030  -65.364  49.984  1
437829  99.078  -65.368  49.936  1
437830  99.125  -65.372  49.892  1
437831  99.171  -65.376  49.851  1
437832  99.215  -65.379  49.816  1
437833  99.252  -65.380  49.782  1
437834  99.304  -65.384  49.745  1
437835  99.358  -65.389  49.705  1
437836  99.413  -65.392  49.662  1
437837  99.467  -65.395  49.616  1
437838  99.521  -65.398  49.569  1
437839  99.576  -65.401  49.522  1
437840  99.630  -65.404  49.474  1
437841  99.685  -65.407  49.424  1
437842  99.732  -65.414  49.374  1
437843  99.777  -65.425  49.323  1
437844  99.821  -65.435  49.272  1
437845  99.904  -65.411  49.224  1
437846  99.987  -65.386  49.177  1
437847  100.070  -65.361  49.130  1
437848  100.066  -65.421  49.082  1
437849  100.081  -65.405  49.033  1
437850  100.109  -65.378  48.986  1
437851  100.147  -65.365  48.940  1
437852  100.195  -65.362  48.895  1
437853  100.243  -65.360  48.851  1
437854  100.291  -65.358  48.807  1
437855  100.339  -65.356  48.763  1
437856  100.388  -65.354  48.719  1
437857  100.431  -65.355  48.677  1
437858  100.470  -65.361  48.636  1
437859  100.508  -65.365  48.594  1
437860  100.547  -65.370  48.554  1
438279  88.548  -64.013  55.315  1
438280  88.612  -64.008  55.315  1
438281  88.675  -64.004  55.315  1
438282  88.732  -64.006  55.317  1
438283  88.780  -64.016  55.318  1
438284  88.830  -64.027  55.319  1
438285  88.879  -64.038  55.320  1
438286  88.927  -64.048  55.320  1
438287  88.976  -64.058  55.321  1
438288  89.025  -64.069  55.322  1
438289  89.074  -64.079  55.322  1
438290  89.123  -64.089  55.322  1
438291  89.161  -64.105  55.323  1
438292  89.197  -64.122  55.324  1
438293  89.234  -64.139  55.329  1
438294  89.270  -64.155  55.333  1
438295  89.307  -64.172  55.335  1
438296  89.343  -64.189  55.335  1
438297  89.379  -64.205  55.332  1
438298  89.416  -64.222  55.326  1
438299  89.452  -64.239  55.317  1
438300  89.489  -64.258  55.304  1
438301  89.526  -64.276  55.285  1
438302  89.563  -64.295  55.263  1
438303  89.600  -64.314  55.240  1
438304  89.643  -64.322  55.219  1
438305  89.690  -64.324  55.200  1
438306  89.738  -64.327  55.181  1
438307  89.785  -64.329  55.164  1
438308  89.832  -64.331  55.149  1
438309  89.880  -64.333  55.136  1
438310  89.927  -64.336  55.126  1
438311  89.974  -64.338  55.118  1
438312  90.022  -64.340  55.114  1
438313  90.071  -64.339  55.112  1
438314  90.120  -64.338  55.113  1
438315  90.170  -64.337  55.116  1
438316  90.220  -64.336  55.123  1
438317  90.269  -64.334  55.133  1
438318  90.319  -64.333  55.142  1
438319  90.368  -64.332  55.147  1
438320  90.417  -64.330  55.152  1
438321  90.467  -64.329  55.154  1
438322  90.517  -64.328  55.158  1
438323  90.564  -64.334  55.157  1
438324  90.608  -64.351  55.151  1
438325  90.653  -64.363  55.139  1
438326  90.699  -64.371  55.124  1
438327  90.745  -64.378  55.105  1
438328  90.792  -64.386  55.081  1
438329  90.838  -64.393  55.051  1
438330  90.884  -64.401  55.017  1
438331  90.930  -64.408  54.981  1
438332  90.975  -64.418  54.950  1
438333  91.021  -64.427  54.923  1
438334  91.066  -64.437  54.899  1
438335  91.111  -64.447  54.880  1
438336  91.156  -64.458  54.861  1
438337  91.201  -64.468  54.844  1
438338  91.246  -64.477  54.827  1
438339  91.292  -64.487  54.813  1
438340  91.336  -64.497  54.798  1
438341  91.382  -64.507  54.784  1
438342  91.427  -64.517  54.771  1
438343  91.472  -64.527  54.759  1
438344  91.517  -64.537  54.747  1
438345  91.563  -64.547  54.736  1
438346  91.607  -64.557  54.726  1
438347  91.653  -64.567  54.717  1
438348  91.698  -64.577  54.708  1
438349  91.743  -64.587  54.700  1
438350  91.788  -64.596  54.693  1
438351  91.834  -64.607  54.686  1
438352  91.878  -64.617  54.680  1
438353  91.924  -64.627  54.673  1
438354  91.969  -64.637  54.666  1
438355  92.014  -64.646  54.662  1
438356  92.059  -64.656  54.656  1
438357  92.104  -64.666  54.649  1
438358  92.149  -64.676  54.644  1
438359  92.195  -64.687  54.638  1
438360  92.242  -64.696  54.634  1
438361  92.288  -64.719  54.629  1
438362  92.333  -64.749  54.625  1
438363  92.376  -64.765  54.621  1
438364  92.421  -64.769  54.618  1
438365  92.464  -64.772  54.616  1
438366  92.508  -64.775  54.613  1
438367  92.554  -64.778  54.610  1
438368  92.602  -64.778  54.608  1
438369  92.652  -64.779  54.603  1
438370  92.704  -64.787  54.599  1
438371  92.754  -64.800  54.595  1
438372  92.803  -64.813  54.590  1
438373  92.852  -64.826  54.586  1
438374  92.901  -64.839  54.583  1
438375  92.950  -64.852  54.581  1
438376  93.000  -64.865  54.580  1
438377  93.049  -64.878  54.581  1
438378  93.098  -64.891  54.582  1
438379  93.144  -64.894  54.584  1
438380  93.190  -64.897  54.587  1
438381  93.235  -64.899  54.590  1
438382  93.285  -64.894  54.592  1
438383  93.337  -64.887  54.594  1
438384  93.387  -64.881  54.595  1
438385  93.432  -64.884  54.595  1
438386  93.477  -64.888  54.594  1
438387  93.522  -64.891  54.594  1
438388  93.567  -64.894  54.594  1
438389  93.612  -64.897  54.592  1
438390  93.657  -64.900  54.591  1
438391  93.702  -64.903  54.591  1
438392  93.747  -64.906  54.589  1
438393  93.792  -64.910  54.585  1
438394  93.837  -64.913  54.580  1
438395  93.882  -64.916  54.575  1
438396  93.927  -64.919  54.569  1
438397  93.969  -64.920  54.564  1
438398  94.010  -64.919  54.558  1
438399  94.046  -64.928  54.548  1
438400  94.081  -64.932  54.535  1
438401  94.115  -64.935  54.517  1
438402  94.149  -64.936  54.498  1
438403  94.183  -64.938  54.476  1
438404  94.217  -64.940  54.453  1
438405  94.251  -64.941  54.429  1
438406  94.285  -64.943  54.406  1
438407  94.319  -64.944  54.381  1
438408  94.352  -64.947  54.357  1
438409  94.386  -64.946  54.336  1
438410  94.418  -64.944  54.316  1
438411  94.451  -64.943  54.298  1
438412  94.484  -64.941  54.277  1
438413  94.545  -64.949  54.255  1
438414  94.607  -64.957  54.233  1
438415  94.668  -64.966  54.212  1
438416  94.711  -64.969  54.191  1
438417  94.754  -64.972  54.168  1
438418  94.797  -64.976  54.146  1
438419  94.841  -64.980  54.125  1
438420  94.884  -64.984  54.104  1
438421  94.919  -64.987  54.086  1
438422  94.949  -64.988  54.068  1
438423  94.985  -64.994  54.048  1
438424  95.028  -65.004  54.029  1
438425  95.068  -65.009  54.009  1
438426  95.108  -65.015  53.987  1
438427  95.147  -65.021  53.964  1
438428  95.188  -65.026  53.941  1
438429  95.228  -65.032  53.918  1
438430  95.267  -65.038  53.893  1
438431  95.298  -65.054  53.865  1
438432  95.324  -65.074  53.834  1
438433  95.350  -65.094  53.800  1
438434  95.376  -65.115  53.767  1
438435  95.409  -65.128  53.736  1
438436  95.457  -65.126  53.711  1
438437  95.506  -65.121  53.692  1
438438  95.554  -65.113  53.676  1
438439  95.604  -65.105  53.661  1
438440  95.653  -65.097  53.645  1
438441  95.701  -65.089  53.626  1
438442  95.748  -65.081  53.602  1
438443  95.791  -65.074  53.574  1
438444  95.833  -65.066  53.543  1
438445  95.876  -65.060  53.505  1
438446  95.919  -65.052  53.466  1
438447  95.962  -65.044  53.428  1
438448  96.002  -65.040  53.390  1
438449  96.041  -65.035  53.351  1
438450  96.081  -65.031  53.312  1
438451  96.120  -65.026  53.271  1
438452  96.159  -65.022  53.228  1
438453  96.202  -65.023  53.187  1
438454  96.245  -65.024  53.148  1
438455  96.287  -65.025  53.109  1
438456  96.329  -65.029  53.072  1
438457  96.369  -65.038  53.035  1
438458  96.409  -65.046  52.997  1
438459  96.450  -65.054  52.958  1
438460  96.491  -65.062  52.919  1
438461  96.532  -65.069  52.880  1
438462  96.574  -65.076  52.839  1
438463  96.615  -65.084  52.796  1
438464  96.656  -65.091  52.751  1
438465  96.697  -65.099  52.709  1
438466  96.739  -65.106  52.668  1
438467  96.780  -65.113  52.627  1
438468  96.821  -65.121  52.587  1
438469  96.854  -65.123  52.547  1
438470  96.876  -65.119  52.504  1
438471  96.898  -65.114  52.462  1
438472  96.921  -65.110  52.418  1
438473  96.944  -65.105  52.374  1
438474  96.982  -65.108  52.329  1
438475  97.021  -65.108  52.284  1
438476  97.060  -65.109  52.239  1
438477  97.100  -65.110  52.193  1
438478  97.139  -65.110  52.147  1
438479  97.178  -65.112  52.101  1
438480  97.218  -65.113  52.056  1
438481  97.257  -65.113  52.011  1
438482  97.297  -65.114  51.967  1
438483  97.336  -65.115  51.922  1
438484  97.370  -65.120  51.878  1
438485  97.403  -65.124  51.835  1
438486  97.437  -65.128  51.791  1
438487  97.470  -65.132  51.748  1
438488  97.504  -65.137  51.706  1
438489  97.538  -65.141  51.664  1
438490  97.577  -65.148  51.622  1
438491  97.615  -65.156  51.582  1
438492  97.656  -65.161  51.541  1
438493  97.698  -65.166  51.502  1
438494  97.739  -65.171  51.464  1
438495  97.781  -65.176  51.427  1
438496  97.822  -65.180  51.389  1
438497  97.864  -65.185  51.351  1
438498  97.897  -65.184  51.313  1
438499  97.928  -65.186  51.275  1
438500  97.957  -65.192  51.236  1
438501  97.985  -65.197  51.197  1
438502  98.008  -65.201  51.159  1
438503  98.032  -65.204  51.124  1
438504  98.056  -65.208  51.090  1
438505  98.080  -65.212  51.057  1
438506  98.115  -65.215  51.025  1
438507  98.153  -65.218  50.989  1
438508  98.191  -65.221  50.957  1
438509  98.229  -65.223  50.927  1
438510  98.268  -65.226  50.896  1
438511  98.305  -65.229  50.865  1
438512  98.344  -65.232  50.831  1
438513  98.381  -65.237  50.790  1
438514  98.419  -65.242  50.748  1
438515  98.456  -65.246  50.704  1
438516  98.494  -65.251  50.659  1
438517  98.533  -65.255  50.615  1
438518  98.576  -65.260  50.566  1
438519  98.619  -65.267  50.514  1
438520  98.659  -65.273  50.461  1
438521  98.696  -65.278  50.405  1
438522  98.733  -65.283  50.350  1
438523  98.771  -65.289  50.293  1
438524  98.808  -65.294  50.236  1
438525  98.845  -65.299  50.179  1
438526  98.882  -65.304  50.122  1
438527  98.926  -65.309  50.068  1
438528  98.975  -65.313  50.015  1
438529  99.024  -65.317  49.965  1
438530  99.072  -65.321  49.918  1
438531  99.118  -65.325  49.875  1
438532  99.165  -65.329  49.836  1
438533  99.211  -65.333  49.803  1
438534  99.254  -65.336  49.770  1
438535  99.308  -65.339  49.733  1
438536  99.362  -65.342  49.693  1
438537  99.417  -65.345  49.650  1
438538  99.471  -65.348  49.604  1
438539  99.525  -65.351  49.557  1
438540  99.580  -65.355  49.510  1
438541  99.635  -65.358  49.461  1
438542  99.689  -65.361  49.411  1
438543  99.737  -65.368  49.360  1
438544  99.781  -65.378  49.309  1
438545  99.840  -65.376  49.259  1
438546  99.923  -65.351  49.211  1
438547  100.006  -65.326  49.164  1
438548  100.089  -65.302  49.118  1
438549  100.082  -65.364  49.071  1
438550  100.094  -65.358  49.022  1
438551  100.122  -65.331  48.975  1
438552  100.160  -65.318  48.931  1
438553  100.209  -65.316  48.887  1
438554  100.257  -65.314  48.843  1
438555  100.305  -65.312  48.799  1
438556  100.354  -65.310  48.755  1
438557  100.402  -65.308  48.712  1
438558  100.441  -65.312  48.670  1
438559  100.480  -65.317  48.629  1
438560  100.519  -65.323  48.589  1
438561  100.557  -65.328  48.548  1
438981  88.635  -63.946  55.316  1
438982  88.684  -63.957  55.316  1
438983  88.733  -63.966  55.318  1
438984  88.782  -63.977  55.319  1
438985  88.831  -63.988  55.320  1
438986  88.880  -63.998  55.320  1
438987  88.929  -64.008  55.321  1
438988  88.978  -64.019  55.322  1
438989  89.027  -64.029  55.322  1
438990  89.076  -64.039  55.324  1
438991  89.125  -64.050  55.326  1
438992  89.166  -64.064  55.328  1
438993  89.203  -64.081  55.333  1
438994  89.239  -64.098  55.340  1
438995  89.276  -64.114  55.347  1
438996  89.312  -64.130  55.351  1
438997  89.349  -64.147  55.350  1
438998  89.385  -64.164  55.345  1
438999  89.421  -64.180  55.338  1
439000  89.458  -64.197  55.329  1
439001  89.494  -64.214  55.318  1
439002  89.531  -64.230  55.301  1
439003  89.568  -64.248  55.279  1
439004  89.605  -64.267  55.256  1
439005  89.645  -64.282  55.234  1
439006  89.692  -64.283  55.214  1
439007  89.739  -64.286  55.195  1
439008  89.787  -64.288  55.178  1
439009  89.834  -64.290  55.163  1
439010  89.882  -64.291  55.150  1
439011  89.932  -64.289  55.140  1
439012  89.981  -64.289  55.133  1
439013  90.031  -64.287  55.129  1
439014  90.080  -64.286  55.128  1
439015  90.129  -64.285  55.129  1
439016  90.179  -64.283  55.133  1
439017  90.229  -64.282  55.142  1
439018  90.278  -64.280  55.155  1
439019  90.328  -64.280  55.166  1
439020  90.377  -64.278  55.174  1
439021  90.427  -64.276  55.179  1
439022  90.476  -64.276  55.182  1
439023  90.526  -64.274  55.186  1
439024  90.570  -64.290  55.186  1
439025  90.614  -64.307  55.180  1
439026  90.660  -64.319  55.165  1
439027  90.706  -64.327  55.147  1
439028  90.752  -64.334  55.123  1
439029  90.798  -64.342  55.094  1
439030  90.844  -64.349  55.060  1
439031  90.890  -64.357  55.022  1
439032  90.936  -64.364  54.984  1
439033  90.982  -64.372  54.952  1
439034  91.029  -64.380  54.924  1
439035  91.074  -64.389  54.898  1
439036  91.119  -64.399  54.878  1
439037  91.164  -64.408  54.858  1
439038  91.210  -64.418  54.840  1
439039  91.255  -64.428  54.823  1
439040  91.300  -64.438  54.808  1
439041  91.345  -64.449  54.794  1
439042  91.390  -64.458  54.779  1
439043  91.435  -64.468  54.766  1
439044  91.481  -64.478  54.754  1
439045  91.526  -64.488  54.742  1
439046  91.571  -64.498  54.731  1
439047  91.616  -64.508  54.721  1
439048  91.661  -64.518  54.712  1
439049  91.706  -64.528  54.704  1
439050  91.751  -64.538  54.695  1
439051  91.797  -64.548  54.688  1
439052  91.842  -64.558  54.681  1
439053  91.887  -64.568  54.674  1
439054  91.932  -64.577  54.668  1
439055  91.977  -64.587  54.662  1
439056  92.022  -64.598  54.657  1
439057  92.067  -64.608  54.650  1
439058  92.112  -64.618  54.644  1
439059  92.158  -64.627  54.638  1
439060  92.203  -64.637  54.633  1
439061  92.251  -64.647  54.628  1
439062  92.298  -64.666  54.624  1
439063  92.342  -64.696  54.620  1
439064  92.386  -64.711  54.616  1
439065  92.430  -64.714  54.614  1
439066  92.474  -64.717  54.612  1
439067  92.518  -64.720  54.610  1
439068  92.562  -64.723  54.608  1
439069  92.606  -64.726  54.606  1
439070  92.649  -64.731  54.602  1
439071  92.698  -64.743  54.597  1
439072  92.747  -64.756  54.592  1
439073  92.797  -64.769  54.586  1
439074  92.846  -64.782  54.582  1
439075  92.895  -64.795  54.580  1
439076  92.944  -64.808  54.579  1
439077  92.994  -64.821  54.579  1
439078  93.043  -64.834  54.579  1
439079  93.092  -64.847  54.581  1
439080  93.141  -64.859  54.583  1
439081  93.188  -64.864  54.586  1
439082  93.236  -64.862  54.590  1
439083  93.287  -64.855  54.592  1
439084  93.339  -64.847  54.595  1
439085  93.389  -64.841  54.596  1
439086  93.434  -64.844  54.596  1
439087  93.479  -64.847  54.596  1
439088  93.524  -64.850  54.595  1
439089  93.569  -64.853  54.592  1
439090  93.614  -64.857  54.589  1
439091  93.659  -64.860  54.586  1
439092  93.704  -64.863  54.583  1
439093  93.749  -64.866  54.579  1
439094  93.794  -64.869  54.574  1
439095  93.838  -64.872  54.568  1
439096  93.879  -64.871  54.561  1
439097  93.919  -64.869  54.554  1
439098  93.960  -64.868  54.550  1
439099  93.999  -64.872  54.544  1
439100  94.035  -64.881  54.536  1
439101  94.072  -64.890  54.524  1
439102  94.108  -64.898  54.508  1
439103  94.142  -64.900  54.487  1
439104  94.176  -64.902  54.465  1
439105  94.210  -64.903  54.442  1
439106  94.244  -64.905  54.417  1
439107  94.277  -64.907  54.393  1
439108  94.310  -64.906  54.369  1
439109  94.343  -64.904  54.345  1
439110  94.376  -64.902  54.324  1
439111  94.408  -64.900  54.305  1
439112  94.441  -64.899  54.287  1
439113  94.476  -64.898  54.266  1
439114  94.539  -64.906  54.244  1
439115  94.601  -64.915  54.221  1
439116  94.663  -64.923  54.201  1
439117  94.725  -64.931  54.180  1
439118  94.779  -64.938  54.157  1
439119  94.822  -64.941  54.135  1
439120  94.865  -64.945  54.114  1
439121  94.895  -64.947  54.094  1
439122  94.924  -64.949  54.076  1
439123  94.954  -64.950  54.059  1
439124  94.985  -64.954  54.041  1
439125  95.028  -64.963  54.023  1
439126  95.070  -64.972  54.005  1
439127  95.112  -64.980  53.984  1
439128  95.152  -64.986  53.961  1
439129  95.192  -64.992  53.938  1
439130  95.232  -64.997  53.914  1
439131  95.272  -65.004  53.889  1
439132  95.305  -65.016  53.862  1
439133  95.331  -65.036  53.830  1
439134  95.357  -65.057  53.796  1
439135  95.384  -65.077  53.763  1
439136  95.417  -65.090  53.730  1
439137  95.460  -65.088  53.703  1
439138  95.508  -65.072  53.681  1
439139  95.557  -65.065  53.663  1
439140  95.606  -65.057  53.647  1
439141  95.655  -65.048  53.631  1
439142  95.704  -65.041  53.614  1
439143  95.753  -65.032  53.592  1
439144  95.798  -65.025  53.566  1
439145  95.840  -65.018  53.537  1
439146  95.883  -65.010  53.501  1
439147  95.925  -65.003  53.464  1
439148  95.965  -64.999  53.427  1
439149  96.005  -64.994  53.390  1
439150  96.044  -64.990  53.351  1
439151  96.083  -64.985  53.312  1
439152  96.123  -64.981  53.270  1
439153  96.163  -64.977  53.227  1
439154  96.205  -64.978  53.184  1
439155  96.248  -64.979  53.144  1
439156  96.291  -64.981  53.104  1
439157  96.330  -64.989  53.066  1
439158  96.371  -64.997  53.028  1
439159  96.411  -65.006  52.988  1
439160  96.451  -65.015  52.947  1
439161  96.493  -65.022  52.909  1
439162  96.534  -65.029  52.870  1
439163  96.575  -65.037  52.831  1
439164  96.616  -65.044  52.791  1
439165  96.657  -65.052  52.749  1
439166  96.698  -65.059  52.706  1
439167  96.740  -65.066  52.662  1
439168  96.781  -65.074  52.618  1
439169  96.817  -65.078  52.575  1
439170  96.839  -65.073  52.533  1
439171  96.862  -65.069  52.490  1
439172  96.884  -65.064  52.448  1
439173  96.913  -65.063  52.407  1
439174  96.951  -65.067  52.364  1
439175  96.989  -65.071  52.322  1
439176  97.027  -65.070  52.279  1
439177  97.065  -65.069  52.234  1
439178  97.104  -65.069  52.188  1
439179  97.144  -65.071  52.142  1
439180  97.183  -65.072  52.094  1
439181  97.223  -65.072  52.048  1
439182  97.262  -65.073  52.002  1
439183  97.302  -65.074  51.957  1
439184  97.341  -65.076  51.912  1
439185  97.376  -65.079  51.866  1
439186  97.410  -65.083  51.822  1
439187  97.444  -65.087  51.779  1
439188  97.477  -65.091  51.736  1
439189  97.511  -65.096  51.695  1
439190  97.544  -65.100  51.652  1
439191  97.578  -65.104  51.611  1
439192  97.613  -65.110  51.569  1
439193  97.654  -65.115  51.528  1
439194  97.696  -65.120  51.486  1
439195  97.737  -65.125  51.446  1
439196  97.779  -65.129  51.407  1
439197  97.820  -65.135  51.368  1
439198  97.862  -65.139  51.329  1
439199  97.903  -65.144  51.292  1
439200  97.935  -65.146  51.253  1
439201  97.960  -65.151  51.213  1
439202  97.984  -65.154  51.174  1
439203  98.008  -65.158  51.135  1
439204  98.031  -65.162  51.100  1
439205  98.055  -65.166  51.065  1
439206  98.079  -65.170  51.032  1
439207  98.116  -65.173  51.000  1
439208  98.154  -65.176  50.965  1
439209  98.192  -65.179  50.933  1
439210  98.230  -65.182  50.901  1
439211  98.269  -65.184  50.870  1
439212  98.306  -65.187  50.838  1
439213  98.345  -65.190  50.803  1
439214  98.383  -65.193  50.763  1
439215  98.421  -65.196  50.720  1
439216  98.459  -65.200  50.676  1
439217  98.496  -65.204  50.634  1
439218  98.535  -65.209  50.589  1
439219  98.578  -65.215  50.541  1
439220  98.616  -65.220  50.489  1
439221  98.653  -65.226  50.435  1
439222  98.691  -65.231  50.380  1
439223  98.728  -65.236  50.324  1
439224  98.765  -65.242  50.268  1
439225  98.802  -65.247  50.211  1
439226  98.840  -65.252  50.153  1
439227  98.877  -65.257  50.097  1
439228  98.920  -65.262  50.046  1
439229  98.970  -65.266  49.995  1
439230  99.018  -65.270  49.947  1
439231  99.065  -65.274  49.901  1
439232  99.112  -65.278  49.858  1
439233  99.158  -65.282  49.821  1
439234  99.205  -65.286  49.789  1
439235  99.256  -65.288  49.756  1
439236  99.312  -65.293  49.720  1
439237  99.366  -65.296  49.679  1
439238  99.421  -65.299  49.636  1
439239  99.476  -65.302  49.590  1
439240  99.530  -65.305  49.543  1
439241  99.584  -65.308  49.496  1
439242  99.639  -65.311  49.446  1
439243  99.693  -65.314  49.396  1
439244  99.742  -65.321  49.345  1
439245  99.786  -65.332  49.295  1
439246  99.859  -65.317  49.246  1
439247  99.941  -65.292  49.199  1
439248  100.025  -65.267  49.151  1
439249  100.108  -65.243  49.104  1
439250  100.099  -65.308  49.058  1
439251  100.108  -65.311  49.011  1
439252  100.135  -65.284  48.966  1
439253  100.175  -65.272  48.921  1
439254  100.223  -65.270  48.878  1
439255  100.272  -65.268  48.834  1
439256  100.320  -65.266  48.791  1
439257  100.368  -65.264  48.748  1
439258  100.412  -65.264  48.705  1
439259  100.451  -65.270  48.662  1
439260  100.490  -65.275  48.622  1
439261  100.528  -65.280  48.583  1
439262  100.567  -65.286  48.542  1
439682  88.637  -63.907  55.318  1
439683  88.686  -63.917  55.318  1
439684  88.735  -63.927  55.319  1
439685  88.784  -63.938  55.320  1
439686  88.833  -63.948  55.320  1
439687  88.882  -63.958  55.321  1
439688  88.930  -63.969  55.322  1
439689  88.979  -63.979  55.323  1
439690  89.029  -63.990  55.324  1
439691  89.077  -64.000  55.327  1
439692  89.126  -64.010  55.330  1
439693  89.172  -64.023  55.335  1
439694  89.208  -64.039  55.343  1
439695  89.245  -64.056  55.353  1
439696  89.281  -64.073  55.360  1
439697  89.318  -64.089  55.364  1
439698  89.354  -64.106  55.363  1
439699  89.391  -64.123  55.358  1
439700  89.427  -64.139  55.351  1
439701  89.464  -64.155  55.343  1
439702  89.500  -64.172  55.334  1
439703  89.537  -64.189  55.319  1
439704  89.574  -64.205  55.298  1
439705  89.610  -64.222  55.274  1
439706  89.647  -64.239  55.250  1
439707  89.693  -64.242  55.228  1
439708  89.743  -64.241  55.210  1
439709  89.792  -64.240  55.192  1
439710  89.842  -64.239  55.177  1
439711  89.891  -64.237  55.164  1
439712  89.941  -64.236  55.153  1
439713  89.990  -64.235  55.147  1
439714  90.040  -64.233  55.144  1
439715  90.089  -64.232  55.143  1
439716  90.139  -64.231  55.144  1
439717  90.188  -64.229  55.149  1
439718  90.238  -64.228  55.160  1
439719  90.288  -64.226  55.174  1
439720  90.337  -64.226  55.188  1
439721  90.386  -64.224  55.199  1
439722  90.436  -64.223  55.206  1
439723  90.485  -64.222  55.210  1
439724  90.532  -64.229  55.212  1
439725  90.577  -64.246  55.211  1
439726  90.621  -64.263  55.205  1
439727  90.666  -64.275  55.190  1
439728  90.712  -64.283  55.169  1
439729  90.758  -64.290  55.140  1
439730  90.804  -64.298  55.105  1
439731  90.851  -64.305  55.067  1
439732  90.896  -64.313  55.025  1
439733  90.943  -64.320  54.986  1
439734  90.989  -64.328  54.952  1
439735  91.035  -64.336  54.923  1
439736  91.081  -64.343  54.897  1
439737  91.128  -64.351  54.875  1
439738  91.173  -64.360  54.855  1
439739  91.218  -64.370  54.836  1
439740  91.263  -64.380  54.819  1
439741  91.308  -64.389  54.803  1
439742  91.354  -64.399  54.789  1
439743  91.398  -64.409  54.775  1
439744  91.444  -64.419  54.762  1
439745  91.489  -64.430  54.750  1
439746  91.534  -64.439  54.738  1
439747  91.579  -64.449  54.727  1
439748  91.625  -64.459  54.717  1
439749  91.669  -64.469  54.708  1
439750  91.715  -64.479  54.699  1
439751  91.760  -64.489  54.691  1
439752  91.805  -64.499  54.684  1
439753  91.850  -64.509  54.677  1
439754  91.895  -64.519  54.670  1
439755  91.940  -64.529  54.664  1
439756  91.986  -64.539  54.658  1
439757  92.030  -64.549  54.653  1
439758  92.076  -64.559  54.647  1
439759  92.121  -64.568  54.640  1
439760  92.166  -64.579  54.635  1
439761  92.211  -64.589  54.630  1
439762  92.260  -64.599  54.626  1
439763  92.307  -64.614  54.622  1
439764  92.352  -64.643  54.618  1
439765  92.396  -64.656  54.615  1
439766  92.440  -64.659  54.613  1
439767  92.484  -64.662  54.611  1
439768  92.527  -64.665  54.610  1
439769  92.571  -64.668  54.609  1
439770  92.613  -64.672  54.606  1
439771  92.642  -64.685  54.601  1
439772  92.691  -64.699  54.596  1
439773  92.740  -64.712  54.590  1
439774  92.790  -64.725  54.584  1
439775  92.839  -64.737  54.581  1
439776  92.888  -64.750  54.579  1
439777  92.938  -64.763  54.579  1
439778  92.987  -64.776  54.580  1
439779  93.037  -64.790  54.580  1
439780  93.086  -64.803  54.581  1
439781  93.135  -64.815  54.583  1
439782  93.188  -64.826  54.586  1
439783  93.238  -64.822  54.590  1
439784  93.289  -64.815  54.593  1
439785  93.340  -64.808  54.598  1
439786  93.392  -64.801  54.600  1
439787  93.437  -64.804  54.600  1
439788  93.482  -64.807  54.599  1
439789  93.526  -64.810  54.596  1
439790  93.572  -64.813  54.592  1
439791  93.617  -64.816  54.587  1
439792  93.661  -64.819  54.582  1
439793  93.707  -64.822  54.577  1
439794  93.748  -64.822  54.572  1
439795  93.788  -64.821  54.566  1
439796  93.829  -64.820  54.559  1
439797  93.870  -64.819  54.551  1
439798  93.910  -64.818  54.543  1
439799  93.951  -64.816  54.536  1
439800  93.988  -64.824  54.530  1
439801  94.025  -64.833  54.521  1
439802  94.061  -64.843  54.509  1
439803  94.097  -64.852  54.494  1
439804  94.134  -64.861  54.474  1
439805  94.169  -64.866  54.453  1
439806  94.202  -64.867  54.429  1
439807  94.235  -64.865  54.404  1
439808  94.268  -64.863  54.379  1
439809  94.300  -64.862  54.354  1
439810  94.333  -64.860  54.332  1
439811  94.365  -64.858  54.313  1
439812  94.398  -64.856  54.295  1
439813  94.431  -64.855  54.276  1
439814  94.470  -64.855  54.255  1
439815  94.532  -64.863  54.233  1
439816  94.594  -64.872  54.211  1
439817  94.657  -64.880  54.190  1
439818  94.718  -64.888  54.169  1
439819  94.781  -64.897  54.147  1
439820  94.839  -64.905  54.125  1
439821  94.870  -64.907  54.103  1
439822  94.899  -64.910  54.083  1
439823  94.929  -64.911  54.064  1
439824  94.958  -64.913  54.047  1
439825  94.988  -64.915  54.031  1
439826  95.028  -64.922  54.014  1
439827  95.070  -64.931  53.997  1
439828  95.113  -64.941  53.977  1
439829  95.155  -64.950  53.956  1
439830  95.196  -64.957  53.933  1
439831  95.236  -64.963  53.909  1
439832  95.276  -64.969  53.884  1
439833  95.312  -64.978  53.857  1
439834  95.338  -64.999  53.825  1
439835  95.365  -65.019  53.791  1
439836  95.399  -65.032  53.757  1
439837  95.437  -65.041  53.724  1
439838  95.476  -65.049  53.695  1
439839  95.514  -65.058  53.670  1
439840  95.562  -65.041  53.649  1
439841  95.610  -65.022  53.631  1
439842  95.658  -65.004  53.616  1
439843  95.706  -64.992  53.599  1
439844  95.755  -64.984  53.579  1
439845  95.804  -64.976  53.555  1
439846  95.847  -64.969  53.527  1
439847  95.889  -64.962  53.494  1
439848  95.928  -64.957  53.458  1
439849  95.968  -64.953  53.423  1
439850  96.008  -64.948  53.387  1
439851  96.047  -64.944  53.350  1
439852  96.086  -64.940  53.310  1
439853  96.125  -64.935  53.268  1
439854  96.166  -64.932  53.224  1
439855  96.208  -64.933  53.181  1
439856  96.251  -64.935  53.140  1
439857  96.292  -64.941  53.100  1
439858  96.332  -64.949  53.062  1
439859  96.373  -64.957  53.023  1
439860  96.412  -64.966  52.981  1
439861  96.453  -64.975  52.940  1
439862  96.493  -64.982  52.900  1
439863  96.535  -64.990  52.861  1
439864  96.576  -64.997  52.822  1
439865  96.617  -65.004  52.783  1
439866  96.659  -65.012  52.744  1
439867  96.700  -65.019  52.701  1
439868  96.741  -65.027  52.657  1
439869  96.780  -65.033  52.611  1
439870  96.803  -65.029  52.564  1
439871  96.825  -65.024  52.520  1
439872  96.847  -65.019  52.477  1
439873  96.882  -65.021  52.434  1
439874  96.920  -65.025  52.393  1
439875  96.958  -65.029  52.353  1
439876  96.996  -65.033  52.312  1
439877  97.034  -65.034  52.271  1
439878  97.072  -65.033  52.227  1
439879  97.110  -65.032  52.182  1
439880  97.149  -65.031  52.135  1
439881  97.188  -65.032  52.087  1
439882  97.228  -65.032  52.039  1
439883  97.267  -65.034  51.993  1
439884  97.307  -65.035  51.948  1
439885  97.346  -65.035  51.901  1
439886  97.383  -65.038  51.856  1
439887  97.417  -65.042  51.812  1
439888  97.450  -65.046  51.769  1
439889  97.484  -65.051  51.726  1
439890  97.517  -65.055  51.685  1
439891  97.551  -65.059  51.642  1
439892  97.585  -65.063  51.600  1
439893  97.616  -65.068  51.559  1
439894  97.646  -65.072  51.518  1
439895  97.677  -65.076  51.475  1
439896  97.719  -65.081  51.433  1
439897  97.760  -65.085  51.391  1
439898  97.803  -65.090  51.350  1
439899  97.845  -65.095  51.310  1
439900  97.887  -65.100  51.273  1
439901  97.930  -65.104  51.234  1
439902  97.959  -65.108  51.196  1
439903  97.984  -65.112  51.157  1
439904  98.007  -65.116  51.118  1
439905  98.031  -65.120  51.082  1
439906  98.055  -65.123  51.048  1
439907  98.079  -65.127  51.014  1
439908  98.117  -65.130  50.980  1
439909  98.155  -65.133  50.943  1
439910  98.193  -65.136  50.909  1
439911  98.231  -65.139  50.876  1
439912  98.270  -65.142  50.843  1
439913  98.308  -65.145  50.810  1
439914  98.346  -65.148  50.775  1
439915  98.384  -65.151  50.734  1
439916  98.422  -65.154  50.690  1
439917  98.460  -65.157  50.647  1
439918  98.498  -65.160  50.606  1
439919  98.536  -65.163  50.562  1
439920  98.573  -65.168  50.514  1
439921  98.610  -65.173  50.462  1
439922  98.648  -65.179  50.408  1
439923  98.685  -65.184  50.354  1
439924  98.722  -65.189  50.299  1
439925  98.760  -65.195  50.243  1
439926  98.797  -65.200  50.186  1
439927  98.834  -65.205  50.129  1
439928  98.871  -65.210  50.074  1
439929  98.915  -65.215  50.025  1
439930  98.963  -65.219  49.977  1
439931  99.011  -65.223  49.929  1
439932  99.058  -65.227  49.883  1
439933  99.104  -65.231  49.842  1
439934  99.151  -65.235  49.805  1
439935  99.204  -65.236  49.771  1
439936  99.257  -65.238  49.738  1
439937  99.310  -65.239  49.703  1
439938  99.368  -65.246  49.661  1
439939  99.425  -65.253  49.619  1
439940  99.480  -65.256  49.573  1
439941  99.534  -65.259  49.526  1
439942  99.588  -65.262  49.478  1
439943  99.643  -65.265  49.429  1
439944  99.698  -65.268  49.379  1
439945  99.747  -65.275  49.329  1
439946  99.794  -65.282  49.280  1
439947  99.877  -65.257  49.231  1
439948  99.961  -65.233  49.185  1
439949  100.044  -65.208  49.138  1
439950  100.124  -65.187  49.092  1
439951  100.115  -65.252  49.047  1
439952  100.121  -65.264  49.001  1
439953  100.149  -65.237  48.956  1
439954  100.190  -65.226  48.912  1
439955  100.238  -65.224  48.869  1
439956  100.286  -65.222  48.826  1
439957  100.334  -65.220  48.784  1
439958  100.382  -65.218  48.741  1
439959  100.422  -65.222  48.697  1
439960  100.461  -65.227  48.656  1
439961  100.500  -65.232  48.615  1
439962  100.539  -65.238  48.575  1
439963  100.577  -65.242  48.535  1
440384  88.687  -63.878  55.320  1
440385  88.736  -63.888  55.321  1
440386  88.785  -63.898  55.321  1
440387  88.834  -63.909  55.321  1
440388  88.883  -63.919  55.322  1
440389  88.932  -63.929  55.323  1
440390  88.981  -63.940  55.326  1
440391  89.030  -63.951  55.328  1
440392  89.079  -63.960  55.331  1
440393  89.128  -63.971  55.336  1
440394  89.177  -63.982  55.343  1
440395  89.214  -63.998  55.353  1
440396  89.251  -64.014  55.365  1
440397  89.287  -64.031  55.373  1
440398  89.324  -64.048  55.378  1
440399  89.361  -64.064  55.377  1
440400  89.397  -64.081  55.372  1
440401  89.433  -64.098  55.367  1
440402  89.470  -64.114  55.362  1
440403  89.506  -64.131  55.356  1
440404  89.543  -64.148  55.343  1
440405  89.579  -64.164  55.321  1
440406  89.615  -64.181  55.296  1
440407  89.656  -64.192  55.269  1
440408  89.703  -64.189  55.244  1
440409  89.752  -64.187  55.225  1
440410  89.802  -64.186  55.207  1
440411  89.851  -64.185  55.192  1
440412  89.900  -64.183  55.178  1
440413  89.950  -64.182  55.166  1
440414  90.000  -64.181  55.161  1
440415  90.049  -64.179  55.158  1
440416  90.099  -64.178  55.158  1
440417  90.148  -64.177  55.160  1
440418  90.197  -64.176  55.165  1
440419  90.247  -64.174  55.176  1
440420  90.297  -64.173  55.191  1
440421  90.346  -64.172  55.207  1
440422  90.396  -64.170  55.222  1
440423  90.445  -64.169  55.232  1
440424  90.495  -64.168  55.236  1
440425  90.539  -64.185  55.237  1
440426  90.583  -64.201  55.234  1
440427  90.627  -64.218  55.227  1
440428  90.672  -64.231  55.210  1
440429  90.718  -64.239  55.184  1
440430  90.764  -64.246  55.151  1
440431  90.811  -64.254  55.111  1
440432  90.857  -64.261  55.069  1
440433  90.903  -64.269  55.026  1
440434  90.949  -64.276  54.986  1
440435  90.995  -64.284  54.952  1
440436  91.041  -64.292  54.922  1
440437  91.087  -64.299  54.894  1
440438  91.134  -64.307  54.871  1
440439  91.180  -64.314  54.850  1
440440  91.226  -64.322  54.831  1
440441  91.272  -64.330  54.814  1
440442  91.317  -64.341  54.798  1
440443  91.362  -64.351  54.783  1
440444  91.407  -64.361  54.770  1
440445  91.452  -64.371  54.757  1
440446  91.497  -64.380  54.745  1
440447  91.542  -64.390  54.734  1
440448  91.588  -64.400  54.723  1
440449  91.633  -64.410  54.713  1
440450  91.678  -64.421  54.704  1
440451  91.723  -64.430  54.696  1
440452  91.768  -64.440  54.687  1
440453  91.813  -64.450  54.680  1
440454  91.858  -64.460  54.673  1
440455  91.904  -64.470  54.667  1
440456  91.949  -64.480  54.661  1
440457  91.994  -64.490  54.655  1
440458  92.039  -64.500  54.649  1
440459  92.084  -64.510  54.644  1
440460  92.129  -64.520  54.638  1
440461  92.174  -64.530  54.633  1
440462  92.220  -64.540  54.628  1
440463  92.269  -64.549  54.624  1
440464  92.317  -64.561  54.621  1
440465  92.361  -64.591  54.618  1
440466  92.406  -64.601  54.615  1
440467  92.449  -64.604  54.613  1
440468  92.493  -64.607  54.612  1
440469  92.537  -64.610  54.611  1
440470  92.578  -64.615  54.610  1
440471  92.607  -64.627  54.606  1
440472  92.637  -64.640  54.600  1
440473  92.684  -64.653  54.595  1
440474  92.733  -64.666  54.590  1
440475  92.783  -64.679  54.587  1
440476  92.832  -64.693  54.584  1
440477  92.881  -64.706  54.583  1
440478  92.930  -64.718  54.583  1
440479  92.980  -64.731  54.583  1
440480  93.029  -64.744  54.583  1
440481  93.078  -64.757  54.584  1
440482  93.129  -64.769  54.587  1
440483  93.194  -64.771  54.590  1
440484  93.242  -64.774  54.594  1
440485  93.291  -64.775  54.598  1
440486  93.342  -64.769  54.604  1
440487  93.394  -64.762  54.607  1
440488  93.439  -64.763  54.608  1
440489  93.484  -64.767  54.605  1
440490  93.529  -64.770  54.599  1
440491  93.574  -64.773  54.594  1
440492  93.617  -64.774  54.588  1
440493  93.658  -64.773  54.582  1
440494  93.698  -64.772  54.574  1
440495  93.739  -64.771  54.568  1
440496  93.779  -64.769  54.560  1
440497  93.820  -64.768  54.552  1
440498  93.860  -64.767  54.543  1
440499  93.901  -64.765  54.534  1
440500  93.940  -64.768  54.525  1
440501  93.977  -64.777  54.516  1
440502  94.013  -64.786  54.506  1
440503  94.050  -64.795  54.494  1
440504  94.086  -64.804  54.480  1
440505  94.123  -64.813  54.461  1
440506  94.161  -64.822  54.439  1
440507  94.192  -64.823  54.416  1
440508  94.225  -64.821  54.391  1
440509  94.258  -64.819  54.366  1
440510  94.290  -64.818  54.341  1
440511  94.323  -64.816  54.319  1
440512  94.356  -64.814  54.300  1
440513  94.389  -64.812  54.283  1
440514  94.421  -64.811  54.264  1
440515  94.463  -64.812  54.244  1
440516  94.526  -64.821  54.223  1
440517  94.588  -64.829  54.201  1
440518  94.650  -64.837  54.180  1
440519  94.712  -64.846  54.158  1
440520  94.774  -64.854  54.137  1
440521  94.828  -64.864  54.115  1
440522  94.874  -64.869  54.093  1
440523  94.904  -64.872  54.071  1
440524  94.933  -64.873  54.052  1
440525  94.963  -64.875  54.034  1
440526  94.992  -64.877  54.018  1
440527  95.028  -64.882  54.002  1
440528  95.070  -64.891  53.985  1
440529  95.113  -64.900  53.964  1
440530  95.155  -64.910  53.943  1
440531  95.197  -64.919  53.920  1
440532  95.240  -64.928  53.897  1
440533  95.280  -64.934  53.872  1
440534  95.320  -64.941  53.845  1
440535  95.346  -64.961  53.815  1
440536  95.380  -64.973  53.782  1
440537  95.418  -64.982  53.747  1
440538  95.457  -64.991  53.713  1
440539  95.495  -65.000  53.683  1
440540  95.534  -65.009  53.656  1
440541  95.572  -65.017  53.634  1
440542  95.616  -65.011  53.615  1
440543  95.664  -64.993  53.598  1
440544  95.712  -64.975  53.581  1
440545  95.760  -64.957  53.562  1
440546  95.808  -64.938  53.539  1
440547  95.852  -64.921  53.513  1
440548  95.892  -64.916  53.482  1
440549  95.932  -64.912  53.448  1
440550  95.971  -64.907  53.414  1
440551  96.010  -64.903  53.380  1
440552  96.050  -64.898  53.345  1
440553  96.089  -64.894  53.307  1
440554  96.128  -64.889  53.265  1
440555  96.169  -64.887  53.222  1
440556  96.212  -64.888  53.179  1
440557  96.253  -64.891  53.137  1
440558  96.294  -64.900  53.097  1
440559  96.334  -64.909  53.059  1
440560  96.374  -64.917  53.019  1
440561  96.414  -64.926  52.977  1
440562  96.455  -64.935  52.936  1
440563  96.495  -64.943  52.893  1
440564  96.536  -64.950  52.852  1
440565  96.578  -64.957  52.812  1
440566  96.619  -64.965  52.774  1
440567  96.660  -64.972  52.736  1
440568  96.701  -64.980  52.695  1
440569  96.742  -64.987  52.651  1
440570  96.765  -64.983  52.604  1
440571  96.788  -64.978  52.555  1
440572  96.813  -64.975  52.509  1
440573  96.851  -64.979  52.465  1
440574  96.889  -64.983  52.421  1
440575  96.927  -64.987  52.380  1
440576  96.965  -64.991  52.341  1
440577  97.003  -64.995  52.302  1
440578  97.041  -64.998  52.261  1
440579  97.079  -64.997  52.219  1
440580  97.117  -64.995  52.175  1
440581  97.156  -64.994  52.128  1
440582  97.194  -64.993  52.079  1
440583  97.233  -64.993  52.031  1
440584  97.272  -64.994  51.985  1
440585  97.311  -64.994  51.939  1
440586  97.351  -64.995  51.891  1
440587  97.389  -64.997  51.846  1
440588  97.423  -65.001  51.801  1
440589  97.457  -65.006  51.757  1
440590  97.490  -65.010  51.715  1
440591  97.524  -65.014  51.673  1
440592  97.557  -65.019  51.631  1
440593  97.588  -65.022  51.589  1
440594  97.619  -65.027  51.547  1
440595  97.650  -65.032  51.505  1
440596  97.678  -65.035  51.462  1
440597  97.706  -65.039  51.419  1
440598  97.733  -65.043  51.376  1
440599  97.773  -65.047  51.334  1
440600  97.815  -65.052  51.294  1
440601  97.857  -65.057  51.256  1
440602  97.899  -65.062  51.218  1
440603  97.946  -65.066  51.180  1
440604  97.983  -65.069  51.142  1
440605  98.007  -65.073  51.102  1
440606  98.030  -65.078  51.066  1
440607  98.054  -65.082  51.031  1
440608  98.080  -65.085  50.996  1
440609  98.118  -65.088  50.960  1
440610  98.156  -65.091  50.921  1
440611  98.194  -65.094  50.885  1
440612  98.232  -65.097  50.850  1
440613  98.271  -65.100  50.816  1
440614  98.309  -65.103  50.782  1
440615  98.347  -65.105  50.746  1
440616  98.385  -65.108  50.704  1
440617  98.423  -65.111  50.660  1
440618  98.461  -65.115  50.616  1
440619  98.499  -65.118  50.573  1
440620  98.535  -65.121  50.531  1
440621  98.570  -65.123  50.483  1
440622  98.605  -65.126  50.432  1
440623  98.642  -65.132  50.380  1
440624  98.679  -65.137  50.326  1
440625  98.717  -65.142  50.272  1
440626  98.754  -65.148  50.216  1
440627  98.791  -65.153  50.159  1
440628  98.829  -65.158  50.103  1
440629  98.866  -65.163  50.050  1
440630  98.909  -65.168  50.004  1
440631  98.958  -65.172  49.958  1
440632  99.005  -65.176  49.911  1
440633  99.051  -65.180  49.866  1
440634  99.098  -65.184  49.824  1
440635  99.151  -65.185  49.787  1
440636  99.205  -65.186  49.752  1
440637  99.258  -65.187  49.719  1
440638  99.311  -65.188  49.683  1
440639  99.366  -65.192  49.643  1
440640  99.424  -65.200  49.600  1
440641  99.482  -65.207  49.555  1
440642  99.539  -65.213  49.507  1
440643  99.593  -65.216  49.459  1
440644  99.647  -65.219  49.411  1
440645  99.702  -65.222  49.362  1
440646  99.752  -65.228  49.313  1
440647  99.814  -65.223  49.265  1
440648  99.897  -65.198  49.217  1
440649  99.980  -65.174  49.171  1
440650  100.062  -65.149  49.126  1
440651  100.139  -65.131  49.080  1
440652  100.131  -65.195  49.035  1
440653  100.135  -65.217  48.990  1
440654  100.162  -65.189  48.946  1
440655  100.204  -65.180  48.902  1
440656  100.252  -65.178  48.860  1
440657  100.300  -65.176  48.818  1
440658  100.349  -65.174  48.776  1
440659  100.394  -65.174  48.733  1
440660  100.432  -65.179  48.690  1
440661  100.471  -65.185  48.649  1
440662  100.510  -65.190  48.608  1
440663  100.549  -65.195  48.568  1
440664  100.587  -65.200  48.529  1
441085  88.689  -63.838  55.321  1
441086  88.738  -63.848  55.321  1
441087  88.787  -63.859  55.322  1
441088  88.836  -63.869  55.322  1
441089  88.885  -63.879  55.323  1
441090  88.933  -63.890  55.324  1
441091  88.983  -63.900  55.327  1
441092  89.032  -63.910  55.331  1
441093  89.081  -63.921  55.335  1
441094  89.129  -63.932  55.340  1
441095  89.179  -63.942  55.350  1
441096  89.220  -63.956  55.363  1
441097  89.257  -63.973  55.375  1
441098  89.293  -63.989  55.385  1
441099  89.330  -64.006  55.390  1
441100  89.366  -64.023  55.391  1
441101  89.402  -64.039  55.387  1
441102  89.439  -64.056  55.385  1
441103  89.475  -64.073  55.383  1
441104  89.512  -64.089  55.378  1
441105  89.548  -64.106  55.366  1
441106  89.585  -64.123  55.344  1
441107  89.624  -64.136  55.317  1
441108  89.669  -64.140  55.288  1
441109  89.716  -64.137  55.261  1
441110  89.762  -64.134  55.240  1
441111  89.811  -64.132  55.221  1
441112  89.860  -64.131  55.205  1
441113  89.910  -64.129  55.191  1
441114  89.959  -64.129  55.180  1
441115  90.009  -64.127  55.174  1
441116  90.058  -64.126  55.171  1
441117  90.108  -64.124  55.171  1
441118  90.157  -64.123  55.174  1
441119  90.207  -64.122  55.181  1
441120  90.256  -64.120  55.191  1
441121  90.306  -64.120  55.206  1
441122  90.356  -64.118  55.223  1
441123  90.405  -64.117  55.240  1
441124  90.454  -64.115  55.253  1
441125  90.501  -64.124  55.260  1
441126  90.545  -64.141  55.260  1
441127  90.589  -64.157  55.255  1
441128  90.634  -64.174  55.244  1
441129  90.678  -64.187  55.224  1
441130  90.725  -64.195  55.194  1
441131  90.770  -64.202  55.156  1
441132  90.817  -64.210  55.113  1
441133  90.863  -64.217  55.069  1
441134  90.909  -64.225  55.026  1
441135  90.955  -64.233  54.986  1
441136  91.002  -64.240  54.951  1
441137  91.047  -64.248  54.920  1
441138  91.094  -64.255  54.891  1
441139  91.140  -64.263  54.867  1
441140  91.186  -64.270  54.846  1
441141  91.232  -64.278  54.826  1
441142  91.278  -64.286  54.808  1
441143  91.324  -64.293  54.793  1
441144  91.370  -64.302  54.778  1
441145  91.416  -64.311  54.765  1
441146  91.460  -64.321  54.753  1
441147  91.506  -64.332  54.742  1
441148  91.551  -64.342  54.731  1
441149  91.596  -64.352  54.720  1
441150  91.641  -64.361  54.710  1
441151  91.686  -64.371  54.701  1
441152  91.731  -64.381  54.693  1
441153  91.777  -64.391  54.685  1
441154  91.821  -64.402  54.678  1
441155  91.867  -64.411  54.671  1
441156  91.912  -64.421  54.665  1
441157  91.957  -64.431  54.659  1
441158  92.002  -64.441  54.653  1
441159  92.048  -64.451  54.647  1
441160  92.092  -64.461  54.643  1
441161  92.138  -64.471  54.638  1
441162  92.183  -64.481  54.631  1
441163  92.229  -64.491  54.627  1
441164  92.278  -64.501  54.624  1
441165  92.326  -64.511  54.621  1
441166  92.371  -64.538  54.620  1
441167  92.415  -64.546  54.616  1
441168  92.459  -64.549  54.614  1
441169  92.503  -64.552  54.613  1
441170  92.544  -64.557  54.611  1
441171  92.573  -64.570  54.610  1
441172  92.602  -64.583  54.605  1
441173  92.631  -64.596  54.600  1
441174  92.676  -64.609  54.595  1
441175  92.726  -64.621  54.592  1
441176  92.775  -64.634  54.589  1
441177  92.825  -64.647  54.586  1
441178  92.874  -64.660  54.585  1
441179  92.923  -64.673  54.585  1
441180  92.973  -64.687  54.584  1
441181  93.022  -64.700  54.585  1
441182  93.071  -64.712  54.587  1
441183  93.145  -64.713  54.590  1
441184  93.200  -64.715  54.594  1
441185  93.249  -64.719  54.599  1
441186  93.297  -64.722  54.604  1
441187  93.345  -64.726  54.610  1
441188  93.396  -64.722  54.614  1
441189  93.441  -64.723  54.616  1
441190  93.486  -64.726  54.614  1
441191  93.527  -64.725  54.607  1
441192  93.567  -64.724  54.599  1
441193  93.608  -64.722  54.592  1
441194  93.648  -64.721  54.584  1
441195  93.689  -64.720  54.575  1
441196  93.729  -64.718  54.568  1
441197  93.770  -64.718  54.560  1
441198  93.811  -64.716  54.551  1
441199  93.851  -64.715  54.541  1
441200  93.892  -64.714  54.529  1
441201  93.929  -64.721  54.517  1
441202  93.966  -64.730  54.506  1
441203  94.002  -64.739  54.493  1
441204  94.039  -64.748  54.480  1
441205  94.075  -64.757  54.465  1
441206  94.115  -64.766  54.447  1
441207  94.153  -64.775  54.426  1
441208  94.182  -64.778  54.404  1
441209  94.215  -64.777  54.381  1
441210  94.248  -64.775  54.354  1
441211  94.280  -64.774  54.329  1
441212  94.313  -64.772  54.306  1
441213  94.346  -64.770  54.286  1
441214  94.379  -64.769  54.269  1
441215  94.411  -64.767  54.252  1
441216  94.457  -64.769  54.232  1
441217  94.519  -64.778  54.212  1
441218  94.581  -64.786  54.191  1
441219  94.643  -64.794  54.170  1
441220  94.705  -64.803  54.148  1
441221  94.764  -64.812  54.127  1
441222  94.815  -64.822  54.104  1
441223  94.862  -64.828  54.082  1
441224  94.908  -64.834  54.060  1
441225  94.938  -64.835  54.039  1
441226  94.968  -64.837  54.020  1
441227  94.997  -64.839  54.003  1
441228  95.028  -64.842  53.987  1
441229  95.070  -64.851  53.969  1
441230  95.113  -64.860  53.949  1
441231  95.155  -64.869  53.928  1
441232  95.198  -64.878  53.906  1
441233  95.240  -64.887  53.882  1
441234  95.282  -64.896  53.859  1
441235  95.325  -64.905  53.833  1
441236  95.361  -64.916  53.803  1
441237  95.400  -64.924  53.770  1
441238  95.438  -64.933  53.734  1
441239  95.477  -64.941  53.701  1
441240  95.515  -64.950  53.670  1
441241  95.554  -64.959  53.642  1
441242  95.592  -64.968  53.618  1
441243  95.631  -64.976  53.598  1
441244  95.671  -64.982  53.580  1
441245  95.719  -64.963  53.563  1
441246  95.766  -64.946  53.544  1
441247  95.814  -64.928  53.522  1
441248  95.858  -64.908  53.495  1
441249  95.896  -64.887  53.464  1
441250  95.935  -64.866  53.432  1
441251  95.974  -64.862  53.399  1
441252  96.013  -64.857  53.366  1
441253  96.052  -64.853  53.333  1
441254  96.092  -64.848  53.297  1
441255  96.131  -64.844  53.256  1
441256  96.172  -64.842  53.213  1
441257  96.215  -64.843  53.171  1
441258  96.255  -64.852  53.130  1
441259  96.295  -64.860  53.090  1
441260  96.335  -64.869  53.051  1
441261  96.376  -64.877  53.012  1
441262  96.416  -64.886  52.971  1
441263  96.456  -64.894  52.929  1
441264  96.497  -64.903  52.887  1
441265  96.537  -64.910  52.846  1
441266  96.579  -64.918  52.805  1
441267  96.620  -64.925  52.764  1
441268  96.661  -64.933  52.724  1
441269  96.702  -64.940  52.683  1
441270  96.729  -64.938  52.641  1
441271  96.751  -64.934  52.596  1
441272  96.782  -64.934  52.548  1
441273  96.820  -64.938  52.503  1
441274  96.858  -64.941  52.457  1
441275  96.896  -64.945  52.412  1
441276  96.934  -64.949  52.369  1
441277  96.972  -64.953  52.329  1
441278  97.010  -64.957  52.290  1
441279  97.048  -64.961  52.252  1
441280  97.086  -64.960  52.211  1
441281  97.124  -64.960  52.167  1
441282  97.163  -64.958  52.121  1
441283  97.201  -64.957  52.073  1
441284  97.239  -64.956  52.024  1
441285  97.278  -64.954  51.977  1
441286  97.316  -64.954  51.929  1
441287  97.356  -64.955  51.882  1
441288  97.395  -64.957  51.835  1
441289  97.430  -64.960  51.789  1
441290  97.463  -64.965  51.745  1
441291  97.497  -64.969  51.702  1
441292  97.529  -64.973  51.660  1
441293  97.560  -64.978  51.619  1
441294  97.592  -64.982  51.576  1
441295  97.623  -64.986  51.532  1
441296  97.654  -64.991  51.490  1
441297  97.682  -64.994  51.447  1
441298  97.710  -64.998  51.405  1
441299  97.737  -65.002  51.361  1
441300  97.765  -65.007  51.319  1
441301  97.793  -65.010  51.279  1
441302  97.828  -65.014  51.243  1
441303  97.870  -65.019  51.205  1
441304  97.914  -65.024  51.167  1
441305  97.962  -65.028  51.128  1
441306  98.006  -65.032  51.088  1
441307  98.030  -65.035  51.052  1
441308  98.054  -65.039  51.016  1
441309  98.081  -65.043  50.979  1
441310  98.119  -65.046  50.940  1
441311  98.157  -65.048  50.900  1
441312  98.196  -65.051  50.861  1
441313  98.233  -65.054  50.824  1
441314  98.272  -65.057  50.789  1
441315  98.310  -65.060  50.753  1
441316  98.348  -65.063  50.717  1
441317  98.386  -65.066  50.675  1
441318  98.424  -65.070  50.630  1
441319  98.461  -65.073  50.583  1
441320  98.499  -65.076  50.537  1
441321  98.534  -65.079  50.495  1
441322  98.569  -65.082  50.449  1
441323  98.604  -65.085  50.400  1
441324  98.639  -65.087  50.349  1
441325  98.674  -65.090  50.296  1
441326  98.711  -65.095  50.242  1
441327  98.748  -65.101  50.187  1
441328  98.786  -65.106  50.131  1
441329  98.823  -65.111  50.077  1
441330  98.860  -65.116  50.026  1
441331  98.903  -65.121  49.984  1
441332  98.951  -65.125  49.938  1
441333  98.998  -65.129  49.892  1
441334  99.046  -65.132  49.848  1
441335  99.099  -65.133  49.806  1
441336  99.152  -65.135  49.768  1
441337  99.206  -65.135  49.733  1
441338  99.259  -65.137  49.698  1
441339  99.312  -65.138  49.663  1
441340  99.365  -65.139  49.623  1
441341  99.422  -65.145  49.581  1
441342  99.480  -65.153  49.535  1
441343  99.538  -65.160  49.488  1
441344  99.596  -65.168  49.440  1
441345  99.651  -65.173  49.392  1
441346  99.706  -65.176  49.345  1
441347  99.757  -65.182  49.297  1
441348  99.832  -65.163  49.249  1
441349  99.915  -65.139  49.203  1
441350  99.998  -65.115  49.158  1
441351  100.081  -65.090  49.114  1
441352  100.155  -65.075  49.069  1
441353  100.146  -65.139  49.023  1
441354  100.148  -65.169  48.979  1
441355  100.176  -65.142  48.935  1
441356  100.218  -65.134  48.893  1
441357  100.267  -65.132  48.851  1
441358  100.315  -65.130  48.809  1
441359  100.363  -65.128  48.768  1
441360  100.404  -65.132  48.724  1
441361  100.442  -65.137  48.682  1
441362  100.481  -65.141  48.642  1
441363  100.520  -65.147  48.602  1
441364  100.559  -65.152  48.562  1
441787  88.740  -63.809  55.322  1
441788  88.788  -63.819  55.322  1
441789  88.837  -63.830  55.323  1
441790  88.886  -63.840  55.324  1
441791  88.935  -63.850  55.326  1
441792  88.984  -63.861  55.329  1
441793  89.033  -63.871  55.333  1
441794  89.082  -63.882  55.338  1
441795  89.131  -63.892  55.345  1
441796  89.180  -63.903  55.355  1
441797  89.226  -63.914  55.369  1
441798  89.262  -63.931  55.383  1
441799  89.299  -63.947  55.395  1
441800  89.335  -63.964  55.403  1
441801  89.372  -63.981  55.405  1
441802  89.408  -63.998  55.402  1
441803  89.445  -64.014  55.401  1
441804  89.481  -64.031  55.399  1
441805  89.518  -64.048  55.395  1
441806  89.554  -64.064  55.384  1
441807  89.592  -64.080  55.363  1
441808  89.636  -64.087  55.337  1
441809  89.682  -64.088  55.308  1
441810  89.728  -64.085  55.279  1
441811  89.775  -64.082  55.255  1
441812  89.821  -64.079  55.235  1
441813  89.870  -64.077  55.218  1
441814  89.919  -64.076  55.204  1
441815  89.968  -64.075  55.193  1
441816  90.018  -64.073  55.187  1
441817  90.068  -64.072  55.184  1
441818  90.117  -64.071  55.184  1
441819  90.167  -64.070  55.187  1
441820  90.216  -64.068  55.196  1
441821  90.265  -64.067  55.205  1
441822  90.315  -64.066  55.219  1
441823  90.365  -64.064  55.236  1
441824  90.414  -64.063  55.254  1
441825  90.463  -64.063  55.270  1
441826  90.507  -64.079  55.279  1
441827  90.551  -64.096  55.281  1
441828  90.596  -64.113  55.274  1
441829  90.640  -64.129  55.259  1
441830  90.685  -64.143  55.232  1
441831  90.731  -64.151  55.196  1
441832  90.777  -64.158  55.154  1
441833  90.823  -64.166  55.109  1
441834  90.869  -64.173  55.065  1
441835  90.916  -64.181  55.023  1
441836  90.962  -64.189  54.985  1
441837  91.008  -64.196  54.950  1
441838  91.054  -64.204  54.917  1
441839  91.100  -64.211  54.888  1
441840  91.146  -64.219  54.863  1
441841  91.192  -64.226  54.841  1
441842  91.238  -64.234  54.820  1
441843  91.285  -64.242  54.801  1
441844  91.331  -64.249  54.787  1
441845  91.377  -64.257  54.774  1
441846  91.423  -64.264  54.761  1
441847  91.469  -64.273  54.749  1
441848  91.514  -64.283  54.738  1
441849  91.559  -64.292  54.728  1
441850  91.604  -64.302  54.718  1
441851  91.650  -64.313  54.708  1
441852  91.695  -64.323  54.699  1
441853  91.740  -64.333  54.691  1
441854  91.785  -64.342  54.683  1
441855  91.830  -64.352  54.676  1
441856  91.875  -64.362  54.669  1
441857  91.920  -64.372  54.663  1
441858  91.965  -64.382  54.657  1
441859  92.011  -64.392  54.651  1
441860  92.056  -64.402  54.646  1
441861  92.101  -64.412  54.642  1
441862  92.146  -64.422  54.637  1
441863  92.191  -64.432  54.630  1
441864  92.238  -64.442  54.627  1
441865  92.287  -64.452  54.624  1
441866  92.335  -64.461  54.621  1
441867  92.381  -64.485  54.620  1
441868  92.425  -64.491  54.618  1
441869  92.469  -64.494  54.615  1
441870  92.509  -64.499  54.613  1
441871  92.538  -64.512  54.611  1
441872  92.567  -64.524  54.609  1
441873  92.596  -64.537  54.605  1
441874  92.626  -64.550  54.600  1
441875  92.669  -64.563  54.596  1
441876  92.719  -64.576  54.593  1
441877  92.768  -64.590  54.590  1
441878  92.817  -64.602  54.588  1
441879  92.867  -64.615  54.586  1
441880  92.916  -64.628  54.586  1
441881  92.966  -64.641  54.585  1
441882  93.015  -64.654  54.587  1
441883  93.084  -64.657  54.589  1
441884  93.158  -64.657  54.592  1
441885  93.206  -64.660  54.597  1
441886  93.255  -64.664  54.604  1
441887  93.303  -64.667  54.610  1
441888  93.351  -64.671  54.615  1
441889  93.400  -64.674  54.621  1
441890  93.436  -64.675  54.623  1
441891  93.477  -64.674  54.621  1
441892  93.517  -64.673  54.614  1
441893  93.558  -64.671  54.604  1
441894  93.599  -64.671  54.595  1
441895  93.639  -64.669  54.586  1
441896  93.680  -64.668  54.577  1
441897  93.720  -64.667  54.570  1
441898  93.761  -64.665  54.562  1
441899  93.801  -64.665  54.551  1
441900  93.842  -64.663  54.539  1
441901  93.882  -64.664  54.526  1
441902  93.918  -64.673  54.513  1
441903  93.955  -64.682  54.500  1
441904  93.991  -64.691  54.486  1
441905  94.028  -64.700  54.472  1
441906  94.066  -64.710  54.455  1
441907  94.112  -64.720  54.437  1
441908  94.145  -64.726  54.416  1
441909  94.174  -64.732  54.394  1
441910  94.205  -64.733  54.371  1
441911  94.238  -64.731  54.345  1
441912  94.270  -64.730  54.318  1
441913  94.303  -64.728  54.293  1
441914  94.336  -64.726  54.270  1
441915  94.368  -64.725  54.251  1
441916  94.401  -64.723  54.234  1
441917  94.450  -64.727  54.217  1
441918  94.512  -64.735  54.198  1
441919  94.574  -64.743  54.178  1
441920  94.637  -64.752  54.157  1
441921  94.699  -64.760  54.135  1
441922  94.751  -64.770  54.114  1
441923  94.802  -64.780  54.092  1
441924  94.850  -64.787  54.070  1
441925  94.896  -64.792  54.049  1
441926  94.942  -64.797  54.026  1
441927  94.973  -64.800  54.005  1
441928  95.002  -64.802  53.986  1
441929  95.032  -64.803  53.968  1
441930  95.070  -64.811  53.950  1
441931  95.113  -64.819  53.932  1
441932  95.156  -64.828  53.911  1
441933  95.198  -64.837  53.889  1
441934  95.240  -64.847  53.866  1
441935  95.282  -64.856  53.845  1
441936  95.328  -64.864  53.819  1
441937  95.375  -64.872  53.789  1
441938  95.415  -64.879  53.756  1
441939  95.455  -64.886  53.721  1
441940  95.495  -64.894  53.688  1
441941  95.535  -64.900  53.656  1
441942  95.573  -64.910  53.627  1
441943  95.612  -64.918  53.601  1
441944  95.651  -64.927  53.579  1
441945  95.689  -64.935  53.562  1
441946  95.728  -64.944  53.545  1
441947  95.773  -64.935  53.525  1
441948  95.821  -64.916  53.503  1
441949  95.863  -64.896  53.477  1
441950  95.901  -64.875  53.444  1
441951  95.939  -64.853  53.412  1
441952  95.978  -64.832  53.381  1
441953  96.016  -64.812  53.350  1
441954  96.055  -64.807  53.320  1
441955  96.095  -64.803  53.285  1
441956  96.134  -64.798  53.246  1
441957  96.175  -64.797  53.204  1
441958  96.217  -64.803  53.162  1
441959  96.257  -64.812  53.121  1
441960  96.297  -64.820  53.081  1
441961  96.337  -64.828  53.041  1
441962  96.377  -64.837  53.001  1
441963  96.417  -64.846  52.961  1
441964  96.458  -64.854  52.920  1
441965  96.498  -64.862  52.880  1
441966  96.539  -64.871  52.840  1
441967  96.580  -64.878  52.799  1
441968  96.621  -64.885  52.758  1
441969  96.662  -64.893  52.716  1
441970  96.692  -64.893  52.674  1
441971  96.714  -64.888  52.631  1
441972  96.751  -64.891  52.587  1
441973  96.789  -64.896  52.543  1
441974  96.827  -64.900  52.499  1
441975  96.865  -64.903  52.453  1
441976  96.903  -64.907  52.408  1
441977  96.941  -64.911  52.363  1
441978  96.979  -64.915  52.319  1
441979  97.017  -64.919  52.279  1
441980  97.055  -64.923  52.241  1
441981  97.093  -64.924  52.201  1
441982  97.131  -64.923  52.158  1
441983  97.169  -64.922  52.113  1
441984  97.208  -64.920  52.065  1
441985  97.246  -64.919  52.018  1
441986  97.284  -64.918  51.970  1
441987  97.322  -64.916  51.922  1
441988  97.361  -64.916  51.873  1
441989  97.400  -64.916  51.825  1
441990  97.436  -64.919  51.778  1
441991  97.469  -64.924  51.733  1
441992  97.501  -64.928  51.689  1
441993  97.532  -64.932  51.646  1
441994  97.564  -64.937  51.603  1
441995  97.595  -64.941  51.560  1
441996  97.626  -64.945  51.518  1
441997  97.657  -64.950  51.474  1
441998  97.686  -64.953  51.431  1
441999  97.714  -64.957  51.389  1
442000  97.742  -64.962  51.346  1
442001  97.770  -64.966  51.304  1
442002  97.797  -64.969  51.264  1
442003  97.824  -64.973  51.228  1
442004  97.852  -64.977  51.190  1
442005  97.882  -64.982  51.152  1
442006  97.930  -64.985  51.113  1
442007  97.978  -64.989  51.074  1
442008  98.025  -64.993  51.037  1
442009  98.053  -64.997  51.000  1
442010  98.082  -65.000  50.962  1
442011  98.120  -65.004  50.922  1
442012  98.158  -65.007  50.882  1
442013  98.197  -65.010  50.842  1
442014  98.234  -65.013  50.802  1
442015  98.273  -65.016  50.764  1
442016  98.310  -65.019  50.727  1
442017  98.348  -65.022  50.688  1
442018  98.386  -65.025  50.648  1
442019  98.424  -65.029  50.603  1
442020  98.462  -65.032  50.554  1
442021  98.498  -65.035  50.505  1
442022  98.533  -65.037  50.458  1
442023  98.568  -65.040  50.411  1
442024  98.603  -65.043  50.363  1
442025  98.638  -65.045  50.311  1
442026  98.673  -65.048  50.259  1
442027  98.708  -65.051  50.205  1
442028  98.743  -65.054  50.152  1
442029  98.780  -65.059  50.100  1
442030  98.817  -65.064  50.050  1
442031  98.855  -65.069  50.001  1
442032  98.898  -65.074  49.959  1
442033  98.945  -65.078  49.915  1
442034  98.994  -65.081  49.872  1
442035  99.047  -65.082  49.830  1
442036  99.100  -65.083  49.789  1
442037  99.153  -65.085  49.752  1
442038  99.207  -65.085  49.717  1
442039  99.260  -65.086  49.682  1
442040  99.313  -65.088  49.645  1
442041  99.366  -65.088  49.604  1
442042  99.420  -65.091  49.562  1
442043  99.478  -65.099  49.517  1
442044  99.536  -65.107  49.469  1
442045  99.594  -65.114  49.422  1
442046  99.652  -65.122  49.375  1
442047  99.710  -65.129  49.329  1
442048  99.768  -65.129  49.282  1
442049  99.851  -65.104  49.235  1
442050  99.934  -65.080  49.188  1
442051  100.017  -65.056  49.144  1
442052  100.101  -65.031  49.101  1
442053  100.171  -65.018  49.057  1
442054  100.162  -65.083  49.013  1
442055  100.161  -65.122  48.969  1
442056  100.189  -65.095  48.925  1
442057  100.233  -65.088  48.883  1
442058  100.281  -65.086  48.843  1
442059  100.329  -65.084  48.802  1
442060  100.375  -65.084  48.759  1
442061  100.414  -65.088  48.717  1
442062  100.453  -65.094  48.676  1
442063  100.491  -65.099  48.635  1
442064  100.530  -65.104  48.596  1
442065  100.568  -65.110  48.556  1
442457  87.353  -63.545  55.740  1
442458  87.387  -63.554  55.721  1
442459  87.421  -63.564  55.703  1
442460  87.456  -63.573  55.683  1
442461  87.490  -63.583  55.664  1
442462  87.524  -63.593  55.645  1
442463  87.558  -63.602  55.627  1
442464  87.592  -63.612  55.609  1
442465  87.627  -63.622  55.589  1
442466  87.661  -63.631  55.570  1
442488  88.741  -63.769  55.324  1
442489  88.790  -63.780  55.324  1
442490  88.839  -63.791  55.325  1
442491  88.888  -63.800  55.326  1
442492  88.937  -63.811  55.328  1
442493  88.986  -63.822  55.331  1
442494  89.035  -63.831  55.336  1
442495  89.084  -63.842  55.342  1
442496  89.132  -63.853  55.349  1
442497  89.182  -63.863  55.359  1
442498  89.231  -63.873  55.374  1
442499  89.268  -63.889  55.389  1
442500  89.305  -63.906  55.404  1
442501  89.341  -63.922  55.415  1
442502  89.378  -63.939  55.417  1
442503  89.414  -63.956  55.415  1
442504  89.451  -63.973  55.413  1
442505  89.487  -63.989  55.411  1
442506  89.524  -64.006  55.408  1
442507  89.560  -64.023  55.396  1
442508  89.604  -64.031  55.378  1
442509  89.649  -64.038  55.354  1
442510  89.694  -64.036  55.325  1
442511  89.741  -64.034  55.294  1
442512  89.788  -64.031  55.269  1
442513  89.834  -64.028  55.248  1
442514  89.881  -64.025  55.231  1
442515  89.928  -64.022  55.218  1
442516  89.978  -64.021  55.206  1
442517  90.027  -64.020  55.200  1
442518  90.077  -64.018  55.196  1
442519  90.126  -64.017  55.197  1
442520  90.176  -64.016  55.200  1
442521  90.225  -64.014  55.209  1
442522  90.275  -64.013  55.219  1
442523  90.324  -64.012  55.231  1
442524  90.374  -64.010  55.246  1
442525  90.424  -64.009  55.265  1
442526  90.469  -64.019  55.285  1
442527  90.514  -64.035  55.296  1
442528  90.558  -64.052  55.298  1
442529  90.602  -64.069  55.291  1
442530  90.646  -64.085  55.271  1
442531  90.691  -64.099  55.239  1
442532  90.737  -64.107  55.200  1
442533  90.783  -64.114  55.155  1
442534  90.829  -64.122  55.107  1
442535  90.876  -64.129  55.062  1
442536  90.922  -64.137  55.020  1
442537  90.968  -64.145  54.982  1
442538  91.014  -64.152  54.946  1
442539  91.060  -64.160  54.912  1
442540  91.106  -64.167  54.883  1
442541  91.153  -64.175  54.857  1
442542  91.199  -64.182  54.835  1
442543  91.245  -64.190  54.815  1
442544  91.291  -64.198  54.797  1
442545  91.337  -64.205  54.782  1
442546  91.383  -64.213  54.769  1
442547  91.429  -64.220  54.756  1
442548  91.475  -64.228  54.745  1
442549  91.522  -64.236  54.734  1
442550  91.568  -64.244  54.724  1
442551  91.612  -64.254  54.715  1
442552  91.658  -64.264  54.706  1
442553  91.703  -64.273  54.697  1
442554  91.748  -64.283  54.689  1
442555  91.793  -64.293  54.681  1
442556  91.839  -64.304  54.674  1
442557  91.883  -64.314  54.667  1
442558  91.929  -64.323  54.661  1
442559  91.974  -64.333  54.654  1
442560  92.019  -64.343  54.650  1
442561  92.064  -64.353  54.646  1
442562  92.109  -64.363  54.640  1
442563  92.154  -64.374  54.635  1
442564  92.200  -64.383  54.630  1
442565  92.247  -64.393  54.627  1
442566  92.295  -64.403  54.624  1
442567  92.344  -64.413  54.622  1
442568  92.390  -64.433  54.621  1
442569  92.434  -64.436  54.618  1
442570  92.475  -64.441  54.615  1
442571  92.504  -64.454  54.612  1
442572  92.532  -64.467  54.610  1
442573  92.562  -64.480  54.607  1
442574  92.591  -64.493  54.604  1
442575  92.620  -64.505  54.600  1
442576  92.662  -64.518  54.595  1
442577  92.712  -64.531  54.592  1
442578  92.761  -64.544  54.588  1
442579  92.810  -64.557  54.586  1
442580  92.860  -64.571  54.585  1
442581  92.909  -64.584  54.584  1
442582  92.958  -64.596  54.585  1
442583  93.023  -64.602  54.587  1
442584  93.100  -64.601  54.590  1
442585  93.164  -64.602  54.594  1
442586  93.213  -64.606  54.601  1
442587  93.261  -64.609  54.608  1
442588  93.309  -64.612  54.614  1
442589  93.358  -64.615  54.620  1
442590  93.401  -64.617  54.624  1
442591  93.427  -64.624  54.627  1
442592  93.468  -64.622  54.626  1
442593  93.508  -64.621  54.618  1
442594  93.549  -64.620  54.608  1
442595  93.589  -64.618  54.597  1
442596  93.630  -64.618  54.588  1
442597  93.671  -64.616  54.580  1
442598  93.711  -64.615  54.572  1
442599  93.752  -64.614  54.563  1
442600  93.792  -64.612  54.552  1
442601  93.833  -64.612  54.538  1
442602  93.871  -64.617  54.523  1
442603  93.907  -64.626  54.510  1
442604  93.943  -64.635  54.496  1
442605  93.980  -64.644  54.481  1
442606  94.017  -64.653  54.465  1
442607  94.063  -64.663  54.447  1
442608  94.108  -64.673  54.427  1
442609  94.137  -64.678  54.406  1
442610  94.166  -64.684  54.383  1
442611  94.195  -64.689  54.360  1
442612  94.227  -64.687  54.334  1
442613  94.260  -64.686  54.306  1
442614  94.293  -64.684  54.279  1
442615  94.326  -64.682  54.253  1
442616  94.358  -64.681  54.233  1
442617  94.391  -64.679  54.215  1
442618  94.443  -64.684  54.198  1
442619  94.506  -64.692  54.181  1
442620  94.568  -64.700  54.163  1
442621  94.630  -64.709  54.143  1
442622  94.687  -64.718  54.122  1
442623  94.739  -64.728  54.101  1
442624  94.789  -64.737  54.079  1
442625  94.838  -64.745  54.058  1
442626  94.884  -64.751  54.036  1
442627  94.930  -64.756  54.013  1
442628  94.976  -64.762  53.989  1
442629  95.007  -64.764  53.968  1
442630  95.036  -64.765  53.948  1
442631  95.070  -64.770  53.929  1
442632  95.113  -64.779  53.911  1
442633  95.156  -64.788  53.891  1
442634  95.198  -64.797  53.869  1
442635  95.240  -64.806  53.846  1
442636  95.285  -64.815  53.825  1
442637  95.334  -64.823  53.801  1
442638  95.383  -64.831  53.774  1
442639  95.425  -64.838  53.742  1
442640  95.466  -64.845  53.706  1
442641  95.506  -64.853  53.672  1
442642  95.546  -64.859  53.641  1
442643  95.586  -64.867  53.611  1
442644  95.626  -64.874  53.584  1
442645  95.667  -64.881  53.559  1
442646  95.706  -64.888  53.543  1
442647  95.747  -64.895  53.526  1
442648  95.786  -64.903  53.506  1
442649  95.827  -64.905  53.483  1
442650  95.868  -64.884  53.456  1
442651  95.906  -64.863  53.422  1
442652  95.945  -64.842  53.391  1
442653  95.983  -64.821  53.361  1
442654  96.021  -64.799  53.332  1
442655  96.059  -64.778  53.305  1
442656  96.098  -64.757  53.271  1
442657  96.137  -64.753  53.235  1
442658  96.178  -64.754  53.196  1
442659  96.218  -64.762  53.153  1
442660  96.258  -64.772  53.111  1
442661  96.299  -64.780  53.070  1
442662  96.339  -64.788  53.029  1
442663  96.379  -64.797  52.988  1
442664  96.419  -64.806  52.948  1
442665  96.459  -64.814  52.910  1
442666  96.500  -64.822  52.872  1
442667  96.540  -64.831  52.833  1
442668  96.581  -64.838  52.794  1
442669  96.622  -64.846  52.755  1
442670  96.655  -64.848  52.710  1
442671  96.682  -64.846  52.666  1
442672  96.720  -64.850  52.623  1
442673  96.758  -64.853  52.581  1
442674  96.796  -64.857  52.539  1
442675  96.834  -64.862  52.496  1
442676  96.872  -64.866  52.451  1
442677  96.910  -64.869  52.404  1
442678  96.948  -64.873  52.357  1
442679  96.986  -64.877  52.311  1
442680  97.024  -64.881  52.269  1
442681  97.062  -64.884  52.230  1
442682  97.100  -64.888  52.191  1
442683  97.138  -64.887  52.149  1
442684  97.176  -64.885  52.104  1
442685  97.215  -64.884  52.058  1
442686  97.253  -64.883  52.011  1
442687  97.291  -64.881  51.963  1
442688  97.329  -64.881  51.915  1
442689  97.368  -64.879  51.865  1
442690  97.406  -64.878  51.815  1
442691  97.442  -64.878  51.767  1
442692  97.473  -64.883  51.721  1
442693  97.504  -64.887  51.676  1
442694  97.535  -64.891  51.633  1
442695  97.567  -64.896  51.589  1
442696  97.598  -64.900  51.546  1
442697  97.629  -64.904  51.503  1
442698  97.660  -64.909  51.460  1
442699  97.690  -64.913  51.416  1
442700  97.718  -64.917  51.373  1
442701  97.746  -64.921  51.331  1
442702  97.774  -64.925  51.289  1
442703  97.801  -64.928  51.248  1
442704  97.829  -64.932  51.212  1
442705  97.857  -64.937  51.174  1
442706  97.887  -64.940  51.136  1
442707  97.924  -64.941  51.097  1
442708  97.963  -64.946  51.059  1
442709  98.004  -64.950  51.021  1
442710  98.044  -64.954  50.983  1
442711  98.083  -64.958  50.945  1
442712  98.121  -64.961  50.905  1
442713  98.159  -64.965  50.865  1
442714  98.197  -64.968  50.823  1
442715  98.235  -64.971  50.781  1
442716  98.273  -64.974  50.740  1
442717  98.311  -64.977  50.701  1
442718  98.349  -64.981  50.661  1
442719  98.387  -64.984  50.620  1
442720  98.425  -64.987  50.575  1
442721  98.462  -64.990  50.527  1
442722  98.498  -64.993  50.475  1
442723  98.532  -64.995  50.425  1
442724  98.568  -64.998  50.377  1
442725  98.602  -65.001  50.327  1
442726  98.638  -65.004  50.276  1
442727  98.672  -65.007  50.224  1
442728  98.707  -65.009  50.172  1
442729  98.742  -65.012  50.122  1
442730  98.777  -65.015  50.073  1
442731  98.812  -65.017  50.027  1
442732  98.849  -65.022  49.981  1
442733  98.891  -65.027  49.940  1
442734  98.942  -65.029  49.897  1
442735  98.995  -65.031  49.855  1
442736  99.048  -65.032  49.814  1
442737  99.101  -65.033  49.774  1
442738  99.154  -65.034  49.736  1
442739  99.208  -65.035  49.701  1
442740  99.262  -65.035  49.666  1
442741  99.315  -65.036  49.628  1
442742  99.369  -65.036  49.586  1
442743  99.421  -65.039  49.543  1
442744  99.477  -65.047  49.497  1
442745  99.535  -65.055  49.451  1
442746  99.593  -65.063  49.404  1
442747  99.651  -65.071  49.358  1
442748  99.709  -65.079  49.312  1
442749  99.784  -65.070  49.267  1
442750  99.870  -65.045  49.221  1
442751  99.953  -65.021  49.175  1
442752  100.036  -64.997  49.132  1
442753  100.119  -64.972  49.089  1
442754  100.188  -64.962  49.046  1
442755  100.179  -65.026  49.002  1
442756  100.174  -65.075  48.959  1
442757  100.203  -65.048  48.916  1
442758  100.247  -65.042  48.874  1
442759  100.295  -65.040  48.834  1
442760  100.344  -65.038  48.793  1
442761  100.385  -65.041  48.751  1
442762  100.424  -65.046  48.710  1
442763  100.463  -65.051  48.668  1
442764  100.501  -65.057  48.628  1
442765  100.540  -65.062  48.589  1
442766  100.578  -65.067  48.550  1
443157  87.311  -63.487  55.764  1
443158  87.345  -63.496  55.747  1
443159  87.379  -63.506  55.729  1
443160  87.414  -63.515  55.711  1
443161  87.448  -63.525  55.693  1
443162  87.482  -63.534  55.674  1
443163  87.516  -63.544  55.656  1
443164  87.551  -63.553  55.639  1
443165  87.585  -63.563  55.621  1
443166  87.619  -63.573  55.602  1
443167  87.653  -63.582  55.584  1
443168  87.688  -63.592  55.566  1
443169  87.731  -63.597  55.551  1
443189  88.743  -63.730  55.325  1
443190  88.791  -63.741  55.325  1
443191  88.840  -63.751  55.326  1
443192  88.889  -63.761  55.327  1
443193  88.939  -63.772  55.329  1
443194  88.987  -63.782  55.333  1
443195  89.036  -63.792  55.338  1
443196  89.085  -63.803  55.344  1
443197  89.134  -63.813  55.352  1
443198  89.183  -63.823  55.363  1
443199  89.232  -63.834  55.377  1
443200  89.274  -63.847  55.393  1
443201  89.311  -63.864  55.411  1
443202  89.347  -63.881  55.424  1
443203  89.384  -63.897  55.427  1
443204  89.420  -63.914  55.426  1
443205  89.456  -63.931  55.424  1
443206  89.493  -63.947  55.421  1
443207  89.529  -63.964  55.418  1
443208  89.571  -63.974  55.407  1
443209  89.616  -63.982  55.390  1
443210  89.661  -63.988  55.367  1
443211  89.707  -63.985  55.340  1
443212  89.754  -63.982  55.308  1
443213  89.801  -63.979  55.282  1
443214  89.847  -63.976  55.261  1
443215  89.893  -63.973  55.243  1
443216  89.940  -63.969  55.229  1
443217  89.987  -63.967  55.218  1
443218  90.036  -63.966  55.211  1
443219  90.086  -63.964  55.207  1
443220  90.135  -63.963  55.207  1
443221  90.185  -63.962  55.210  1
443222  90.234  -63.960  55.220  1
443223  90.284  -63.960  55.229  1
443224  90.333  -63.958  55.241  1
443225  90.383  -63.957  55.256  1
443226  90.432  -63.958  55.275  1
443227  90.476  -63.975  55.298  1
443228  90.520  -63.991  55.310  1
443229  90.564  -64.008  55.311  1
443230  90.608  -64.025  55.304  1
443231  90.653  -64.041  55.281  1
443232  90.697  -64.055  55.246  1
443233  90.743  -64.063  55.204  1
443234  90.790  -64.070  55.158  1
443235  90.836  -64.078  55.108  1
443236  90.882  -64.085  55.060  1
443237  90.928  -64.093  55.018  1
443238  90.974  -64.101  54.978  1
443239  91.020  -64.108  54.942  1
443240  91.067  -64.116  54.907  1
443241  91.112  -64.123  54.877  1
443242  91.159  -64.131  54.851  1
443243  91.205  -64.139  54.829  1
443244  91.251  -64.146  54.809  1
443245  91.297  -64.154  54.791  1
443246  91.344  -64.161  54.777  1
443247  91.389  -64.169  54.763  1
443248  91.436  -64.176  54.751  1
443249  91.482  -64.184  54.740  1
443250  91.528  -64.192  54.730  1
443251  91.574  -64.199  54.721  1
443252  91.620  -64.207  54.712  1
443253  91.666  -64.215  54.703  1
443254  91.711  -64.225  54.694  1
443255  91.756  -64.235  54.686  1
443256  91.802  -64.245  54.679  1
443257  91.847  -64.255  54.672  1
443258  91.892  -64.264  54.665  1
443259  91.937  -64.274  54.658  1
443260  91.982  -64.285  54.653  1
443261  92.027  -64.295  54.648  1
443262  92.073  -64.305  54.644  1
443263  92.118  -64.314  54.639  1
443264  92.163  -64.324  54.634  1
443265  92.208  -64.334  54.630  1
443266  92.256  -64.344  54.627  1
443267  92.304  -64.354  54.625  1
443268  92.353  -64.364  54.623  1
443269  92.400  -64.377  54.622  1
443270  92.440  -64.383  54.618  1
443271  92.469  -64.396  54.615  1
443272  92.498  -64.409  54.611  1
443273  92.527  -64.422  54.608  1
443274  92.556  -64.435  54.605  1
443275  92.585  -64.448  54.603  1
443276  92.615  -64.461  54.599  1
443277  92.655  -64.474  54.594  1
443278  92.704  -64.486  54.590  1
443279  92.754  -64.499  54.586  1
443280  92.803  -64.512  54.584  1
443281  92.852  -64.525  54.582  1
443282  92.902  -64.538  54.582  1
443283  92.962  -64.546  54.584  1
443284  93.039  -64.545  54.587  1
443285  93.116  -64.544  54.591  1
443286  93.170  -64.547  54.597  1
443287  93.219  -64.550  54.604  1
443288  93.267  -64.554  54.611  1
443289  93.315  -64.557  54.617  1
443290  93.362  -64.559  54.622  1
443291  93.400  -64.561  54.625  1
443292  93.424  -64.568  54.627  1
443293  93.459  -64.571  54.625  1
443294  93.499  -64.569  54.618  1
443295  93.540  -64.568  54.608  1
443296  93.580  -64.567  54.597  1
443297  93.621  -64.565  54.588  1
443298  93.661  -64.565  54.580  1
443299  93.702  -64.563  54.570  1
443300  93.743  -64.562  54.559  1
443301  93.783  -64.561  54.547  1
443302  93.823  -64.560  54.534  1
443303  93.860  -64.569  54.520  1
443304  93.896  -64.578  54.507  1
443305  93.932  -64.588  54.492  1
443306  93.969  -64.597  54.477  1
443307  94.014  -64.607  54.460  1
443308  94.059  -64.616  54.439  1
443309  94.100  -64.625  54.417  1
443310  94.129  -64.631  54.394  1
443311  94.158  -64.636  54.371  1
443312  94.187  -64.642  54.347  1
443313  94.218  -64.643  54.321  1
443314  94.251  -64.642  54.293  1
443315  94.283  -64.640  54.264  1
443316  94.316  -64.638  54.236  1
443317  94.348  -64.637  54.214  1
443318  94.381  -64.635  54.196  1
443319  94.437  -64.641  54.179  1
443320  94.499  -64.649  54.164  1
443321  94.561  -64.658  54.148  1
443322  94.624  -64.666  54.129  1
443323  94.675  -64.676  54.109  1
443324  94.726  -64.686  54.087  1
443325  94.777  -64.696  54.066  1
443326  94.826  -64.704  54.045  1
443327  94.873  -64.709  54.024  1
443328  94.918  -64.715  53.999  1
443329  94.965  -64.721  53.975  1
443330  95.011  -64.726  53.951  1
443331  95.041  -64.728  53.928  1
443332  95.071  -64.730  53.909  1
443333  95.113  -64.739  53.889  1
443334  95.156  -64.748  53.869  1
443335  95.198  -64.757  53.847  1
443336  95.242  -64.765  53.825  1
443337  95.291  -64.774  53.803  1
443338  95.340  -64.781  53.781  1
443339  95.389  -64.790  53.755  1
443340  95.437  -64.797  53.723  1
443341  95.476  -64.804  53.689  1
443342  95.517  -64.812  53.654  1
443343  95.557  -64.819  53.622  1
443344  95.597  -64.826  53.593  1
443345  95.637  -64.833  53.565  1
443346  95.677  -64.840  53.541  1
443347  95.718  -64.847  53.524  1
443348  95.758  -64.854  53.506  1
443349  95.798  -64.862  53.486  1
443350  95.837  -64.868  53.463  1
443351  95.873  -64.869  53.436  1
443352  95.912  -64.859  53.401  1
443353  95.951  -64.839  53.369  1
443354  95.989  -64.817  53.339  1
443355  96.028  -64.795  53.312  1
443356  96.065  -64.773  53.287  1
443357  96.104  -64.751  53.257  1
443358  96.142  -64.729  53.222  1
443359  96.181  -64.726  53.184  1
443360  96.221  -64.728  53.142  1
443361  96.260  -64.731  53.097  1
443362  96.300  -64.740  53.054  1
443363  96.340  -64.748  53.013  1
443364  96.381  -64.756  52.972  1
443365  96.421  -64.765  52.932  1
443366  96.461  -64.774  52.895  1
443367  96.501  -64.782  52.859  1
443368  96.541  -64.791  52.824  1
443369  96.583  -64.799  52.787  1
443370  96.618  -64.803  52.751  1
443371  96.651  -64.804  52.708  1
443372  96.689  -64.808  52.664  1
443373  96.727  -64.812  52.621  1
443374  96.765  -64.815  52.579  1
443375  96.803  -64.819  52.537  1
443376  96.841  -64.823  52.493  1
443377  96.879  -64.828  52.446  1
443378  96.917  -64.831  52.399  1
443379  96.955  -64.835  52.350  1
443380  96.993  -64.839  52.303  1
443381  97.031  -64.843  52.259  1
443382  97.069  -64.847  52.219  1
443383  97.107  -64.850  52.180  1
443384  97.145  -64.850  52.139  1
443385  97.183  -64.850  52.096  1
443386  97.222  -64.848  52.051  1
443387  97.260  -64.847  52.005  1
443388  97.298  -64.846  51.958  1
443389  97.336  -64.844  51.909  1
443390  97.375  -64.843  51.857  1
443391  97.413  -64.841  51.806  1
443392  97.441  -64.837  51.757  1
443393  97.476  -64.842  51.710  1
443394  97.507  -64.847  51.665  1
443395  97.538  -64.850  51.623  1
443396  97.570  -64.855  51.577  1
443397  97.601  -64.859  51.532  1
443398  97.632  -64.863  51.489  1
443399  97.664  -64.868  51.446  1
443400  97.695  -64.872  51.402  1
443401  97.723  -64.876  51.359  1
443402  97.750  -64.880  51.316  1
443403  97.778  -64.884  51.274  1
443404  97.806  -64.888  51.232  1
443405  97.833  -64.892  51.194  1
443406  97.861  -64.896  51.156  1
443407  97.895  -64.898  51.119  1
443408  97.932  -64.899  51.081  1
443409  97.968  -64.901  51.042  1
443410  98.008  -64.906  51.004  1
443411  98.049  -64.910  50.966  1
443412  98.087  -64.914  50.927  1
443413  98.123  -64.919  50.888  1
443414  98.160  -64.923  50.847  1
443415  98.198  -64.926  50.804  1
443416  98.236  -64.929  50.760  1
443417  98.274  -64.932  50.716  1
443418  98.312  -64.936  50.675  1
443419  98.350  -64.939  50.635  1
443420  98.387  -64.942  50.593  1
443421  98.426  -64.945  50.548  1
443422  98.462  -64.948  50.499  1
443423  98.497  -64.951  50.448  1
443424  98.532  -64.953  50.397  1
443425  98.567  -64.957  50.345  1
443426  98.602  -64.960  50.294  1
443427  98.637  -64.962  50.243  1
443428  98.671  -64.965  50.192  1
443429  98.707  -64.967  50.143  1
443430  98.741  -64.970  50.096  1
443431  98.777  -64.972  50.050  1
443432  98.811  -64.975  50.006  1
443433  98.849  -64.977  49.963  1
443434  98.891  -64.976  49.924  1
443435  98.946  -64.976  49.882  1
443436  99.000  -64.977  49.840  1
443437  99.054  -64.977  49.799  1
443438  99.108  -64.978  49.761  1
443439  99.161  -64.978  49.722  1
443440  99.215  -64.978  49.686  1
443441  99.270  -64.978  49.649  1
443442  99.324  -64.979  49.611  1
443443  99.375  -64.983  49.569  1
443444  99.423  -64.991  49.524  1
443445  99.476  -64.999  49.478  1
443446  99.534  -65.007  49.432  1
443447  99.592  -65.014  49.386  1
443448  99.650  -65.022  49.340  1
443449  99.708  -65.030  49.296  1
443450  99.793  -65.013  49.251  1
443451  99.888  -64.987  49.207  1
443452  99.972  -64.962  49.162  1
443453  100.055  -64.938  49.119  1
443454  100.138  -64.913  49.077  1
443455  100.204  -64.906  49.034  1
443456  100.195  -64.970  48.991  1
443457  100.188  -65.027  48.949  1
443458  100.216  -65.001  48.907  1
443459  100.262  -64.996  48.866  1
443460  100.310  -64.994  48.825  1
443461  100.356  -64.993  48.785  1
443462  100.395  -64.998  48.743  1
443463  100.434  -65.004  48.701  1
443464  100.472  -65.009  48.661  1
443465  100.511  -65.014  48.621  1
443466  100.550  -65.019  48.581  1
443467  100.588  -65.024  48.543  1
443857  87.269  -63.429  55.786  1
443858  87.303  -63.438  55.770  1
443859  87.337  -63.448  55.754  1
443860  87.371  -63.457  55.736  1
443861  87.406  -63.467  55.719  1
443862  87.440  -63.477  55.702  1
443863  87.474  -63.486  55.684  1
443864  87.508  -63.496  55.667  1
443865  87.543  -63.506  55.650  1
443866  87.577  -63.515  55.632  1
443867  87.611  -63.524  55.614  1
443868  87.645  -63.534  55.597  1
443869  87.687  -63.540  55.580  1
443870  87.733  -63.544  55.564  1
443871  87.779  -63.548  55.548  1
443872  87.826  -63.552  55.531  1
443890  88.744  -63.690  55.327  1
443891  88.793  -63.701  55.327  1
443892  88.842  -63.712  55.327  1
443893  88.891  -63.722  55.328  1
443894  88.940  -63.732  55.330  1
443895  88.989  -63.743  55.334  1
443896  89.038  -63.753  55.339  1
443897  89.087  -63.763  55.345  1
443898  89.136  -63.774  55.353  1
443899  89.185  -63.784  55.364  1
443900  89.234  -63.794  55.378  1
443901  89.280  -63.806  55.395  1
443902  89.316  -63.823  55.413  1
443903  89.353  -63.840  55.428  1
443904  89.389  -63.857  55.434  1
443905  89.426  -63.873  55.435  1
443906  89.462  -63.889  55.433  1
443907  89.498  -63.906  55.431  1
443908  89.539  -63.918  55.427  1
443909  89.584  -63.925  55.416  1
443910  89.628  -63.932  55.398  1
443911  89.674  -63.936  55.375  1
443912  89.720  -63.933  55.350  1
443913  89.767  -63.930  55.320  1
443914  89.813  -63.927  55.294  1
443915  89.860  -63.924  55.272  1
443916  89.906  -63.921  55.255  1
443917  89.953  -63.918  55.239  1
443918  89.999  -63.915  55.228  1
443919  90.046  -63.912  55.221  1
443920  90.095  -63.910  55.218  1
443921  90.145  -63.910  55.217  1
443922  90.194  -63.908  55.221  1
443923  90.244  -63.907  55.230  1
443924  90.293  -63.906  55.240  1
443925  90.342  -63.904  55.252  1
443926  90.392  -63.903  55.266  1
443927  90.438  -63.913  55.284  1
443928  90.482  -63.930  55.305  1
443929  90.526  -63.947  55.315  1
443930  90.571  -63.963  55.317  1
443931  90.615  -63.980  55.308  1
443932  90.659  -63.997  55.283  1
443933  90.704  -64.011  55.245  1
443934  90.750  -64.019  55.203  1
443935  90.796  -64.026  55.158  1
443936  90.842  -64.034  55.110  1
443937  90.888  -64.041  55.064  1
443938  90.934  -64.049  55.017  1
443939  90.980  -64.057  54.975  1
443940  91.027  -64.064  54.937  1
443941  91.073  -64.072  54.902  1
443942  91.119  -64.079  54.871  1
443943  91.165  -64.087  54.846  1
443944  91.211  -64.095  54.823  1
443945  91.257  -64.102  54.803  1
443946  91.303  -64.110  54.785  1
443947  91.350  -64.117  54.771  1
443948  91.396  -64.125  54.757  1
443949  91.442  -64.132  54.746  1
443950  91.488  -64.140  54.736  1
443951  91.534  -64.148  54.726  1
443952  91.580  -64.155  54.717  1
443953  91.627  -64.163  54.708  1
443954  91.673  -64.170  54.700  1
443955  91.719  -64.178  54.692  1
443956  91.765  -64.186  54.684  1
443957  91.810  -64.196  54.677  1
443958  91.855  -64.206  54.670  1
443959  91.900  -64.216  54.664  1
443960  91.945  -64.226  54.658  1
443961  91.991  -64.236  54.653  1
443962  92.036  -64.245  54.647  1
443963  92.081  -64.255  54.643  1
443964  92.126  -64.265  54.638  1
443965  92.171  -64.276  54.633  1
443966  92.216  -64.286  54.630  1
443967  92.265  -64.295  54.627  1
443968  92.313  -64.305  54.625  1
443969  92.362  -64.315  54.624  1
443970  92.405  -64.326  54.623  1
443971  92.434  -64.339  54.618  1
443972  92.463  -64.352  54.614  1
443973  92.493  -64.364  54.611  1
443974  92.522  -64.377  54.607  1
443975  92.551  -64.389  54.604  1
443976  92.580  -64.402  54.601  1
443977  92.609  -64.415  54.597  1
443978  92.648  -64.428  54.592  1
443979  92.697  -64.441  54.587  1
443980  92.746  -64.454  54.585  1
443981  92.796  -64.468  54.581  1
443982  92.845  -64.480  54.580  1
443983  92.901  -64.490  54.581  1
443984  92.978  -64.490  54.582  1
443985  93.055  -64.489  54.587  1
443986  93.129  -64.488  54.593  1
443987  93.177  -64.492  54.600  1
443988  93.225  -64.495  54.606  1
443989  93.274  -64.499  54.613  1
443990  93.321  -64.500  54.618  1
443991  93.366  -64.500  54.622  1
443992  93.398  -64.505  54.624  1
443993  93.423  -64.512  54.624  1
443994  93.449  -64.518  54.621  1
443995  93.490  -64.518  54.614  1
443996  93.531  -64.516  54.604  1
443997  93.571  -64.515  54.594  1
443998  93.612  -64.514  54.584  1
443999  93.652  -64.512  54.575  1
444000  93.693  -64.511  54.564  1
444001  93.733  -64.510  54.552  1
444002  93.774  -64.508  54.540  1
444003  93.812  -64.513  54.527  1
444004  93.849  -64.522  54.514  1
444005  93.885  -64.531  54.500  1
444006  93.922  -64.540  54.485  1
444007  93.965  -64.550  54.469  1
444008  94.010  -64.560  54.450  1
444009  94.056  -64.570  54.428  1
444010  94.092  -64.577  54.404  1
444011  94.121  -64.583  54.379  1
444012  94.150  -64.588  54.354  1
444013  94.179  -64.594  54.328  1
444014  94.208  -64.599  54.301  1
444015  94.241  -64.597  54.274  1
444016  94.273  -64.596  54.245  1
444017  94.306  -64.594  54.218  1
444018  94.338  -64.593  54.195  1
444019  94.371  -64.590  54.175  1
444020  94.430  -64.598  54.159  1
444021  94.493  -64.606  54.144  1
444022  94.555  -64.615  54.130  1
444023  94.611  -64.624  54.112  1
444024  94.662  -64.634  54.094  1
444025  94.713  -64.643  54.074  1
444026  94.764  -64.653  54.053  1
444027  94.815  -64.662  54.032  1
444028  94.860  -64.668  54.011  1
444029  94.907  -64.674  53.986  1
444030  94.953  -64.679  53.961  1
444031  94.999  -64.684  53.936  1
444032  95.045  -64.690  53.910  1
444033  95.075  -64.692  53.888  1
444034  95.113  -64.699  53.868  1
444035  95.156  -64.708  53.847  1
444036  95.199  -64.716  53.825  1
444037  95.248  -64.725  53.803  1
444038  95.297  -64.732  53.781  1
444039  95.345  -64.740  53.759  1
444040  95.395  -64.748  53.733  1
444041  95.444  -64.756  53.703  1
444042  95.487  -64.763  53.669  1
444043  95.528  -64.771  53.634  1
444044  95.567  -64.778  53.603  1
444045  95.608  -64.785  53.573  1
444046  95.648  -64.792  53.545  1
444047  95.688  -64.800  53.522  1
444048  95.729  -64.806  53.504  1
444049  95.768  -64.813  53.484  1
444050  95.809  -64.821  53.463  1
444051  95.845  -64.825  53.441  1
444052  95.879  -64.828  53.414  1
444053  95.915  -64.827  53.380  1
444054  95.955  -64.818  53.347  1
444055  95.995  -64.809  53.317  1
444056  96.035  -64.800  53.291  1
444057  96.074  -64.778  53.267  1
444058  96.112  -64.756  53.239  1
444059  96.150  -64.734  53.206  1
444060  96.189  -64.734  53.169  1
444061  96.229  -64.736  53.128  1
444062  96.268  -64.737  53.083  1
444063  96.307  -64.739  53.039  1
444064  96.346  -64.741  52.997  1
444065  96.386  -64.743  52.955  1
444066  96.425  -64.744  52.915  1
444067  96.464  -64.747  52.879  1
444068  96.504  -64.748  52.845  1
444069  96.543  -64.751  52.812  1
444070  96.582  -64.758  52.779  1
444071  96.620  -64.762  52.745  1
444072  96.658  -64.765  52.704  1
444073  96.696  -64.770  52.661  1
444074  96.734  -64.774  52.617  1
444075  96.772  -64.778  52.574  1
444076  96.810  -64.781  52.529  1
444077  96.848  -64.785  52.484  1
444078  96.886  -64.789  52.437  1
444079  96.924  -64.794  52.389  1
444080  96.962  -64.797  52.340  1
444081  97.000  -64.801  52.295  1
444082  97.038  -64.805  52.250  1
444083  97.076  -64.809  52.209  1
444084  97.114  -64.812  52.168  1
444085  97.152  -64.814  52.126  1
444086  97.190  -64.813  52.083  1
444087  97.228  -64.812  52.039  1
444088  97.266  -64.810  51.994  1
444089  97.305  -64.809  51.949  1
444090  97.343  -64.808  51.903  1
444091  97.381  -64.806  51.851  1
444092  97.410  -64.799  51.800  1
444093  97.439  -64.794  51.753  1
444094  97.474  -64.800  51.707  1
444095  97.510  -64.805  51.660  1
444096  97.541  -64.809  51.616  1
444097  97.573  -64.814  51.570  1
444098  97.604  -64.819  51.525  1
444099  97.636  -64.823  51.481  1
444100  97.667  -64.827  51.437  1
444101  97.698  -64.831  51.392  1
444102  97.727  -64.835  51.347  1
444103  97.754  -64.839  51.303  1
444104  97.782  -64.844  51.259  1
444105  97.810  -64.847  51.217  1
444106  97.838  -64.851  51.177  1
444107  97.868  -64.854  51.138  1
444108  97.904  -64.856  51.101  1
444109  97.940  -64.857  51.064  1
444110  97.977  -64.859  51.025  1
444111  98.013  -64.861  50.987  1
444112  98.054  -64.865  50.948  1
444113  98.093  -64.869  50.908  1
444114  98.129  -64.874  50.867  1
444115  98.165  -64.878  50.826  1
444116  98.201  -64.883  50.783  1
444117  98.236  -64.888  50.738  1
444118  98.274  -64.891  50.693  1
444119  98.312  -64.894  50.650  1
444120  98.350  -64.897  50.608  1
444121  98.388  -64.900  50.564  1
444122  98.426  -64.904  50.518  1
444123  98.461  -64.906  50.472  1
444124  98.496  -64.910  50.424  1
444125  98.531  -64.912  50.376  1
444126  98.566  -64.915  50.324  1
444127  98.601  -64.917  50.271  1
444128  98.636  -64.920  50.218  1
444129  98.671  -64.923  50.168  1
444130  98.711  -64.924  50.121  1
444131  98.750  -64.925  50.075  1
444132  98.790  -64.925  50.030  1
444133  98.830  -64.926  49.988  1
444134  98.870  -64.927  49.947  1
444135  98.912  -64.924  49.909  1
444136  98.955  -64.920  49.868  1
444137  99.008  -64.920  49.827  1
444138  99.062  -64.920  49.786  1
444139  99.116  -64.921  49.748  1
444140  99.169  -64.921  49.710  1
444141  99.224  -64.922  49.673  1
444142  99.278  -64.922  49.634  1
444143  99.329  -64.926  49.593  1
444144  99.376  -64.934  49.550  1
444145  99.424  -64.942  49.503  1
444146  99.476  -64.950  49.457  1
444147  99.534  -64.958  49.411  1
444148  99.591  -64.966  49.367  1
444149  99.650  -64.973  49.324  1
444150  99.709  -64.980  49.281  1
444151  99.803  -64.954  49.237  1
444152  99.897  -64.928  49.193  1
444153  99.991  -64.903  49.149  1
444154  100.074  -64.878  49.106  1
444155  100.157  -64.853  49.064  1
444156  100.219  -64.849  49.022  1
444157  100.211  -64.914  48.981  1
444158  100.202  -64.978  48.939  1
444159  100.229  -64.954  48.897  1
444160  100.276  -64.950  48.856  1
444161  100.324  -64.947  48.816  1
444162  100.366  -64.950  48.776  1
444163  100.405  -64.956  48.736  1
444164  100.443  -64.961  48.694  1
444165  100.482  -64.966  48.653  1
444166  100.521  -64.971  48.614  1
444167  100.560  -64.976  48.575  1
444168  100.599  -64.982  48.536  1
444556  87.192  -63.361  55.823  1
444557  87.226  -63.371  55.807  1
444558  87.261  -63.380  55.792  1
444559  87.295  -63.390  55.776  1
444560  87.329  -63.399  55.761  1
444561  87.363  -63.409  55.744  1
444562  87.398  -63.418  55.728  1
444563  87.432  -63.428  55.711  1
444564  87.466  -63.437  55.695  1
444565  87.500  -63.447  55.678  1
444566  87.535  -63.457  55.661  1
444567  87.569  -63.466  55.643  1
444568  87.603  -63.476  55.626  1
444569  87.643  -63.483  55.610  1
444570  87.689  -63.487  55.593  1
444571  87.735  -63.490  55.577  1
444572  87.782  -63.495  55.561  1
444573  87.835  -63.495  55.545  1
444574  87.898  -63.491  55.527  1
444575  87.961  -63.487  55.508  1
444591  88.746  -63.651  55.330  1
444592  88.794  -63.662  55.329  1
444593  88.843  -63.672  55.328  1
444594  88.893  -63.682  55.330  1
444595  88.942  -63.693  55.332  1
444596  88.990  -63.703  55.335  1
444597  89.039  -63.713  55.340  1
444598  89.089  -63.724  55.347  1
444599  89.137  -63.734  55.354  1
444600  89.186  -63.744  55.365  1
444601  89.235  -63.755  55.378  1
444602  89.284  -63.766  55.395  1
444603  89.322  -63.781  55.414  1
444604  89.358  -63.798  55.430  1
444605  89.395  -63.815  55.438  1
444606  89.431  -63.831  55.441  1
444607  89.468  -63.848  55.441  1
444608  89.507  -63.862  55.440  1
444609  89.551  -63.869  55.436  1
444610  89.596  -63.875  55.425  1
444611  89.641  -63.882  55.406  1
444612  89.686  -63.884  55.383  1
444613  89.733  -63.882  55.359  1
444614  89.779  -63.878  55.332  1
444615  89.826  -63.875  55.305  1
444616  89.873  -63.872  55.283  1
444617  89.919  -63.869  55.264  1
444618  89.965  -63.866  55.249  1
444619  90.012  -63.863  55.238  1
444620  90.058  -63.860  55.231  1
444621  90.105  -63.857  55.228  1
444622  90.154  -63.856  55.229  1
444623  90.203  -63.854  55.232  1
444624  90.253  -63.853  55.240  1
444625  90.302  -63.852  55.250  1
444626  90.352  -63.850  55.264  1
444627  90.400  -63.853  55.278  1
444628  90.445  -63.869  55.293  1
444629  90.488  -63.886  55.308  1
444630  90.533  -63.903  55.317  1
444631  90.577  -63.919  55.318  1
444632  90.621  -63.936  55.308  1
444633  90.665  -63.953  55.281  1
444634  90.710  -63.967  55.241  1
444635  90.756  -63.975  55.198  1
444636  90.802  -63.982  55.153  1
444637  90.849  -63.990  55.106  1
444638  90.894  -63.998  55.062  1
444639  90.941  -64.005  55.015  1
444640  90.987  -64.013  54.972  1
444641  91.033  -64.020  54.932  1
444642  91.079  -64.028  54.896  1
444643  91.125  -64.035  54.866  1
444644  91.171  -64.043  54.840  1
444645  91.218  -64.051  54.817  1
444646  91.263  -64.058  54.798  1
444647  91.310  -64.066  54.780  1
444648  91.356  -64.073  54.766  1
444649  91.402  -64.081  54.753  1
444650  91.448  -64.088  54.742  1
444651  91.495  -64.096  54.732  1
444652  91.540  -64.104  54.723  1
444653  91.587  -64.111  54.714  1
444654  91.633  -64.119  54.706  1
444655  91.679  -64.126  54.698  1
444656  91.725  -64.134  54.690  1
444657  91.771  -64.142  54.682  1
444658  91.817  -64.149  54.676  1
444659  91.864  -64.157  54.670  1
444660  91.909  -64.167  54.663  1
444661  91.954  -64.176  54.658  1
444662  91.999  -64.187  54.652  1
444663  92.044  -64.197  54.647  1
444664  92.089  -64.207  54.642  1
444665  92.135  -64.217  54.638  1
444666  92.179  -64.226  54.633  1
444667  92.225  -64.236  54.629  1
444668  92.274  -64.246  54.626  1
444669  92.322  -64.256  54.624  1
444670  92.368  -64.266  54.623  1
444671  92.406  -64.276  54.621  1
444672  92.430  -64.292  54.617  1
444673  92.458  -64.306  54.612  1
444674  92.487  -64.319  54.607  1
444675  92.516  -64.332  54.604  1
444676  92.545  -64.345  54.600  1
444677  92.574  -64.358  54.597  1
444678  92.603  -64.371  54.593  1
444679  92.641  -64.383  54.588  1
444680  92.690  -64.396  54.583  1
444681  92.739  -64.409  54.581  1
444682  92.789  -64.422  54.579  1
444683  92.840  -64.434  54.578  1
444684  92.917  -64.433  54.579  1
444685  92.994  -64.433  54.581  1
444686  93.070  -64.432  54.586  1
444687  93.135  -64.433  54.593  1
444688  93.183  -64.436  54.600  1
444689  93.231  -64.440  54.606  1
444690  93.279  -64.443  54.612  1
444691  93.325  -64.443  54.617  1
444692  93.371  -64.443  54.619  1
444693  93.396  -64.449  54.619  1
444694  93.421  -64.456  54.617  1
444695  93.446  -64.464  54.613  1
444696  93.481  -64.465  54.606  1
444697  93.521  -64.464  54.597  1
444698  93.562  -64.463  54.587  1
444699  93.603  -64.461  54.576  1
444700  93.643  -64.461  54.566  1
444701  93.684  -64.459  54.554  1
444702  93.724  -64.458  54.542  1
444703  93.765  -64.457  54.530  1
444704  93.801  -64.466  54.519  1
444705  93.838  -64.475  54.506  1
444706  93.874  -64.484  54.492  1
444707  93.916  -64.493  54.476  1
444708  93.962  -64.503  54.458  1
444709  94.007  -64.513  54.438  1
444710  94.052  -64.523  54.414  1
444711  94.084  -64.530  54.389  1
444712  94.113  -64.535  54.362  1
444713  94.142  -64.540  54.334  1
444714  94.171  -64.546  54.308  1
444715  94.200  -64.552  54.281  1
444716  94.230  -64.553  54.254  1
444717  94.263  -64.552  54.226  1
444718  94.296  -64.550  54.200  1
444719  94.329  -64.549  54.177  1
444720  94.361  -64.547  54.156  1
444721  94.424  -64.555  54.139  1
444722  94.486  -64.564  54.124  1
444723  94.547  -64.572  54.110  1
444724  94.599  -64.582  54.094  1
444725  94.649  -64.592  54.077  1
444726  94.700  -64.602  54.058  1
444727  94.752  -64.612  54.039  1
444728  94.803  -64.621  54.020  1
444729  94.849  -64.627  54.000  1
444730  94.895  -64.632  53.977  1
444731  94.941  -64.637  53.952  1
444732  94.987  -64.643  53.925  1
444733  95.033  -64.649  53.896  1
444734  95.079  -64.654  53.870  1
444735  95.113  -64.659  53.846  1
444736  95.156  -64.667  53.823  1
444737  95.205  -64.675  53.801  1
444738  95.254  -64.683  53.778  1
444739  95.303  -64.691  53.757  1
444740  95.351  -64.699  53.735  1
444741  95.400  -64.707  53.709  1
444742  95.449  -64.715  53.679  1
444743  95.498  -64.723  53.647  1
444744  95.538  -64.730  53.615  1
444745  95.579  -64.737  53.584  1
444746  95.619  -64.744  53.553  1
444747  95.659  -64.751  53.526  1
444748  95.699  -64.759  53.500  1
444749  95.739  -64.765  53.480  1
444750  95.779  -64.773  53.460  1
444751  95.819  -64.779  53.438  1
444752  95.852  -64.782  53.416  1
444753  95.887  -64.785  53.390  1
444754  95.920  -64.788  53.358  1
444755  95.958  -64.785  53.325  1
444756  95.998  -64.776  53.294  1
444757  96.038  -64.767  53.269  1
444758  96.078  -64.758  53.245  1
444759  96.118  -64.748  53.219  1
444760  96.158  -64.740  53.188  1
444761  96.197  -64.737  53.152  1
444762  96.237  -64.736  53.112  1
444763  96.275  -64.734  53.069  1
444764  96.315  -64.731  53.024  1
444765  96.354  -64.729  52.981  1
444766  96.393  -64.727  52.938  1
444767  96.432  -64.725  52.898  1
444768  96.471  -64.722  52.862  1
444769  96.511  -64.720  52.830  1
444770  96.550  -64.718  52.800  1
444771  96.586  -64.718  52.769  1
444772  96.626  -64.723  52.736  1
444773  96.665  -64.728  52.697  1
444774  96.703  -64.731  52.655  1
444775  96.741  -64.736  52.611  1
444776  96.779  -64.740  52.567  1
444777  96.817  -64.743  52.520  1
444778  96.855  -64.747  52.473  1
444779  96.893  -64.751  52.425  1
444780  96.931  -64.755  52.378  1
444781  96.969  -64.759  52.331  1
444782  97.007  -64.763  52.288  1
444783  97.045  -64.767  52.243  1
444784  97.083  -64.771  52.200  1
444785  97.121  -64.775  52.157  1
444786  97.159  -64.778  52.114  1
444787  97.197  -64.777  52.069  1
444788  97.235  -64.775  52.026  1
444789  97.274  -64.775  51.982  1
444790  97.312  -64.773  51.939  1
444791  97.350  -64.772  51.893  1
444792  97.384  -64.768  51.843  1
444793  97.408  -64.756  51.794  1
444794  97.437  -64.753  51.748  1
444795  97.472  -64.758  51.703  1
444796  97.508  -64.763  51.657  1
444797  97.543  -64.769  51.612  1
444798  97.576  -64.773  51.565  1
444799  97.607  -64.778  51.519  1
444800  97.639  -64.782  51.474  1
444801  97.670  -64.786  51.429  1
444802  97.701  -64.790  51.383  1
444803  97.731  -64.795  51.337  1
444804  97.759  -64.799  51.291  1
444805  97.787  -64.803  51.246  1
444806  97.814  -64.806  51.202  1
444807  97.842  -64.810  51.161  1
444808  97.876  -64.812  51.121  1
444809  97.913  -64.814  51.082  1
444810  97.949  -64.815  51.044  1
444811  97.985  -64.817  51.006  1
444812  98.021  -64.819  50.968  1
444813  98.058  -64.820  50.928  1
444814  98.098  -64.825  50.887  1
444815  98.135  -64.829  50.846  1
444816  98.170  -64.834  50.804  1
444817  98.206  -64.838  50.760  1
444818  98.242  -64.843  50.715  1
444819  98.278  -64.848  50.669  1
444820  98.313  -64.853  50.626  1
444821  98.351  -64.856  50.583  1
444822  98.389  -64.859  50.539  1
444823  98.426  -64.862  50.494  1
444824  98.460  -64.865  50.448  1
444825  98.495  -64.868  50.402  1
444826  98.532  -64.869  50.353  1
444827  98.572  -64.870  50.303  1
444828  98.612  -64.871  50.250  1
444829  98.652  -64.872  50.197  1
444830  98.692  -64.872  50.148  1
444831  98.731  -64.873  50.101  1
444832  98.771  -64.874  50.056  1
444833  98.811  -64.875  50.013  1
444834  98.851  -64.876  49.972  1
444835  98.891  -64.877  49.932  1
444836  98.933  -64.873  49.894  1
444837  98.977  -64.869  49.854  1
444838  99.019  -64.865  49.813  1
444839  99.070  -64.864  49.772  1
444840  99.124  -64.864  49.734  1
444841  99.178  -64.865  49.696  1
444842  99.232  -64.865  49.658  1
444843  99.282  -64.869  49.618  1
444844  99.330  -64.878  49.575  1
444845  99.378  -64.885  49.530  1
444846  99.426  -64.894  49.483  1
444847  99.475  -64.901  49.437  1
444848  99.533  -64.909  49.393  1
444849  99.591  -64.917  49.350  1
444850  99.649  -64.925  49.308  1
444851  99.718  -64.922  49.265  1
444852  99.812  -64.897  49.222  1
444853  99.906  -64.871  49.178  1
444854  100.000  -64.845  49.135  1
444855  100.093  -64.819  49.093  1
444856  100.176  -64.794  49.051  1
444857  100.235  -64.793  49.010  1
444858  100.227  -64.858  48.970  1
444859  100.218  -64.922  48.929  1
444860  100.243  -64.906  48.887  1
444861  100.290  -64.904  48.847  1
444862  100.338  -64.903  48.807  1
444863  100.376  -64.908  48.768  1
444864  100.415  -64.913  48.728  1
444865  100.454  -64.918  48.688  1
444866  100.492  -64.923  48.647  1
444867  100.531  -64.928  48.607  1
444868  100.570  -64.934  48.569  1
444869  100.609  -64.939  48.530  1
445256  87.150  -63.303  55.841  1
445257  87.184  -63.313  55.826  1
445258  87.218  -63.322  55.811  1
445259  87.253  -63.332  55.797  1
445260  87.287  -63.341  55.782  1
445261  87.321  -63.351  55.767  1
445262  87.355  -63.361  55.751  1
445263  87.390  -63.370  55.736  1
445264  87.424  -63.380  55.720  1
445265  87.458  -63.390  55.704  1
445266  87.493  -63.399  55.688  1
445267  87.527  -63.408  55.672  1
445268  87.561  -63.418  55.655  1
445269  87.600  -63.426  55.639  1
445270  87.645  -63.430  55.623  1
445271  87.692  -63.433  55.606  1
445272  87.738  -63.437  55.590  1
445273  87.797  -63.435  55.574  1
445274  87.860  -63.430  55.558  1
445275  87.915  -63.435  55.540  1
445276  87.964  -63.446  55.522  1
445277  88.013  -63.456  55.504  1
445278  88.062  -63.466  55.486  1
445292  88.747  -63.612  55.332  1
445293  88.796  -63.622  55.331  1
445294  88.845  -63.633  55.330  1
445295  88.894  -63.643  55.331  1
445296  88.943  -63.653  55.333  1
445297  88.992  -63.664  55.336  1
445298  89.041  -63.674  55.341  1
445299  89.090  -63.684  55.348  1
445300  89.139  -63.695  55.355  1
445301  89.188  -63.705  55.364  1
445302  89.237  -63.715  55.377  1
445303  89.286  -63.726  55.394  1
445304  89.328  -63.740  55.414  1
445305  89.365  -63.756  55.429  1
445306  89.401  -63.773  55.439  1
445307  89.438  -63.790  55.444  1
445308  89.474  -63.806  55.446  1
445309  89.519  -63.813  55.446  1
445310  89.564  -63.819  55.444  1
445311  89.608  -63.826  55.433  1
445312  89.653  -63.833  55.415  1
445313  89.699  -63.832  55.392  1
445314  89.746  -63.829  55.368  1
445315  89.792  -63.826  55.342  1
445316  89.839  -63.823  55.315  1
445317  89.885  -63.820  55.292  1
445318  89.932  -63.818  55.274  1
445319  89.978  -63.815  55.259  1
445320  90.025  -63.812  55.248  1
445321  90.072  -63.809  55.241  1
445322  90.118  -63.806  55.238  1
445323  90.164  -63.803  55.238  1
445324  90.213  -63.800  55.241  1
445325  90.262  -63.799  55.252  1
445326  90.312  -63.798  55.265  1
445327  90.361  -63.797  55.279  1
445328  90.407  -63.809  55.292  1
445329  90.451  -63.825  55.303  1
445330  90.495  -63.842  55.311  1
445331  90.539  -63.859  55.315  1
445332  90.583  -63.875  55.314  1
445333  90.627  -63.892  55.304  1
445334  90.672  -63.909  55.275  1
445335  90.716  -63.923  55.234  1
445336  90.762  -63.931  55.189  1
445337  90.808  -63.938  55.144  1
445338  90.855  -63.946  55.099  1
445339  90.901  -63.954  55.056  1
445340  90.947  -63.961  55.011  1
445341  90.993  -63.969  54.967  1
445342  91.039  -63.976  54.926  1
445343  91.085  -63.984  54.891  1
445344  91.132  -63.991  54.861  1
445345  91.178  -63.999  54.834  1
445346  91.224  -64.007  54.812  1
445347  91.270  -64.014  54.793  1
445348  91.316  -64.022  54.776  1
445349  91.362  -64.029  54.762  1
445350  91.409  -64.037  54.749  1
445351  91.454  -64.045  54.739  1
445352  91.501  -64.052  54.729  1
445353  91.547  -64.060  54.720  1
445354  91.593  -64.067  54.711  1
445355  91.639  -64.075  54.703  1
445356  91.685  -64.082  54.695  1
445357  91.731  -64.090  54.688  1
445358  91.778  -64.098  54.681  1
445359  91.823  -64.105  54.675  1
445360  91.870  -64.113  54.669  1
445361  91.916  -64.120  54.662  1
445362  91.962  -64.128  54.657  1
445363  92.007  -64.138  54.651  1
445364  92.053  -64.148  54.646  1
445365  92.098  -64.157  54.641  1
445366  92.143  -64.168  54.637  1
445367  92.188  -64.178  54.633  1
445368  92.234  -64.188  54.629  1
445369  92.283  -64.198  54.625  1
445370  92.329  -64.208  54.622  1
445371  92.369  -64.217  54.620  1
445372  92.406  -64.228  54.617  1
445373  92.431  -64.244  54.613  1
445374  92.456  -64.259  54.608  1
445375  92.482  -64.274  54.603  1
445376  92.511  -64.287  54.600  1
445377  92.540  -64.300  54.595  1
445378  92.569  -64.313  54.591  1
445379  92.598  -64.325  54.588  1
445380  92.634  -64.338  54.584  1
445381  92.683  -64.352  54.580  1
445382  92.732  -64.364  54.578  1
445383  92.782  -64.377  54.576  1
445384  92.856  -64.377  54.576  1
445385  92.933  -64.377  54.578  1
445386  93.009  -64.377  54.580  1
445387  93.086  -64.376  54.584  1
445388  93.141  -64.378  54.590  1
445389  93.190  -64.381  54.596  1
445390  93.237  -64.384  54.602  1
445391  93.283  -64.384  54.607  1
445392  93.329  -64.385  54.611  1
445393  93.370  -64.386  54.611  1
445394  93.395  -64.393  54.609  1
445395  93.420  -64.401  54.606  1
445396  93.444  -64.408  54.601  1
445397  93.472  -64.414  54.594  1
445398  93.512  -64.412  54.585  1
445399  93.553  -64.411  54.575  1
445400  93.593  -64.410  54.563  1
445401  93.634  -64.408  54.551  1
445402  93.674  -64.408  54.540  1
445403  93.715  -64.406  54.529  1
445404  93.754  -64.409  54.519  1
445405  93.790  -64.418  54.508  1
445406  93.827  -64.427  54.494  1
445407  93.867  -64.437  54.479  1
445408  93.913  -64.447  54.462  1
445409  93.958  -64.457  54.442  1
445410  94.003  -64.467  54.420  1
445411  94.047  -64.476  54.396  1
445412  94.076  -64.481  54.370  1
445413  94.105  -64.487  54.342  1
445414  94.134  -64.493  54.313  1
445415  94.163  -64.498  54.286  1
445416  94.192  -64.504  54.260  1
445417  94.221  -64.509  54.234  1
445418  94.253  -64.508  54.207  1
445419  94.286  -64.506  54.181  1
445420  94.319  -64.505  54.158  1
445421  94.355  -64.504  54.137  1
445422  94.417  -64.512  54.119  1
445423  94.480  -64.521  54.103  1
445424  94.535  -64.530  54.089  1
445425  94.586  -64.540  54.074  1
445426  94.637  -64.549  54.058  1
445427  94.688  -64.559  54.041  1
445428  94.739  -64.569  54.023  1
445429  94.790  -64.579  54.005  1
445430  94.837  -64.585  53.986  1
445431  94.883  -64.591  53.964  1
445432  94.929  -64.596  53.939  1
445433  94.975  -64.602  53.912  1
445434  95.021  -64.607  53.881  1
445435  95.067  -64.613  53.852  1
445436  95.113  -64.618  53.825  1
445437  95.162  -64.626  53.801  1
445438  95.210  -64.634  53.778  1
445439  95.259  -64.642  53.755  1
445440  95.308  -64.649  53.734  1
445441  95.357  -64.658  53.711  1
445442  95.406  -64.665  53.686  1
445443  95.455  -64.674  53.657  1
445444  95.503  -64.681  53.627  1
445445  95.549  -64.689  53.596  1
445446  95.589  -64.696  53.565  1
445447  95.629  -64.703  53.536  1
445448  95.670  -64.710  53.508  1
445449  95.710  -64.718  53.481  1
445450  95.750  -64.725  53.457  1
445451  95.790  -64.732  53.434  1
445452  95.826  -64.737  53.410  1
445453  95.860  -64.740  53.387  1
445454  95.894  -64.743  53.362  1
445455  95.928  -64.746  53.332  1
445456  95.962  -64.749  53.299  1
445457  96.001  -64.743  53.269  1
445458  96.041  -64.734  53.243  1
445459  96.081  -64.725  53.219  1
445460  96.121  -64.716  53.193  1
445461  96.161  -64.706  53.162  1
445462  96.203  -64.696  53.128  1
445463  96.243  -64.695  53.091  1
445464  96.282  -64.693  53.049  1
445465  96.321  -64.690  53.008  1
445466  96.360  -64.688  52.966  1
445467  96.399  -64.686  52.922  1
445468  96.439  -64.684  52.881  1
445469  96.478  -64.681  52.844  1
445470  96.517  -64.679  52.814  1
445471  96.555  -64.678  52.784  1
445472  96.590  -64.679  52.754  1
445473  96.629  -64.684  52.721  1
445474  96.668  -64.688  52.684  1
445475  96.708  -64.693  52.643  1
445476  96.747  -64.697  52.600  1
445477  96.786  -64.702  52.554  1
445478  96.824  -64.706  52.507  1
445479  96.862  -64.709  52.460  1
445480  96.900  -64.713  52.414  1
445481  96.938  -64.717  52.369  1
445482  96.976  -64.721  52.326  1
445483  97.014  -64.725  52.284  1
445484  97.052  -64.729  52.238  1
445485  97.090  -64.733  52.193  1
445486  97.128  -64.737  52.148  1
445487  97.166  -64.740  52.102  1
445488  97.204  -64.740  52.056  1
445489  97.242  -64.740  52.012  1
445490  97.281  -64.738  51.969  1
445491  97.319  -64.737  51.925  1
445492  97.357  -64.736  51.880  1
445493  97.382  -64.725  51.834  1
445494  97.405  -64.714  51.788  1
445495  97.435  -64.710  51.743  1
445496  97.470  -64.715  51.699  1
445497  97.506  -64.721  51.654  1
445498  97.541  -64.726  51.608  1
445499  97.577  -64.731  51.561  1
445500  97.610  -64.737  51.515  1
445501  97.642  -64.741  51.469  1
445502  97.673  -64.745  51.423  1
445503  97.704  -64.750  51.376  1
445504  97.736  -64.754  51.328  1
445505  97.764  -64.758  51.281  1
445506  97.791  -64.762  51.234  1
445507  97.818  -64.765  51.188  1
445508  97.848  -64.769  51.145  1
445509  97.884  -64.771  51.104  1
445510  97.921  -64.772  51.064  1
445511  97.957  -64.774  51.024  1
445512  97.994  -64.775  50.985  1
445513  98.030  -64.777  50.947  1
445514  98.066  -64.778  50.907  1
445515  98.103  -64.780  50.866  1
445516  98.140  -64.784  50.823  1
445517  98.176  -64.789  50.780  1
445518  98.212  -64.794  50.736  1
445519  98.247  -64.798  50.691  1
445520  98.283  -64.803  50.646  1
445521  98.319  -64.808  50.601  1
445522  98.355  -64.813  50.559  1
445523  98.391  -64.819  50.516  1
445524  98.433  -64.817  50.472  1
445525  98.473  -64.818  50.427  1
445526  98.513  -64.819  50.380  1
445527  98.553  -64.819  50.330  1
445528  98.593  -64.820  50.280  1
445529  98.633  -64.821  50.229  1
445530  98.672  -64.822  50.177  1
445531  98.712  -64.822  50.129  1
445532  98.752  -64.823  50.084  1
445533  98.792  -64.824  50.039  1
445534  98.832  -64.825  49.997  1
445535  98.872  -64.825  49.957  1
445536  98.912  -64.826  49.918  1
445537  98.955  -64.822  49.879  1
445538  98.998  -64.818  49.839  1
445539  99.041  -64.813  49.799  1
445540  99.084  -64.809  49.758  1
445541  99.132  -64.807  49.719  1
445542  99.186  -64.808  49.681  1
445543  99.236  -64.812  49.642  1
445544  99.284  -64.821  49.600  1
445545  99.332  -64.828  49.556  1
445546  99.379  -64.837  49.510  1
445547  99.427  -64.844  49.464  1
445548  99.475  -64.853  49.419  1
445549  99.533  -64.860  49.375  1
445550  99.590  -64.869  49.332  1
445551  99.648  -64.876  49.290  1
445552  99.727  -64.864  49.249  1
445553  99.822  -64.838  49.206  1
445554  99.916  -64.812  49.164  1
445555  100.009  -64.787  49.121  1
445556  100.104  -64.761  49.079  1
445557  100.195  -64.736  49.039  1
445558  100.252  -64.737  48.999  1
445559  100.243  -64.801  48.959  1
445560  100.234  -64.866  48.919  1
445561  100.257  -64.860  48.877  1
445562  100.305  -64.858  48.839  1
445563  100.348  -64.860  48.799  1
445564  100.386  -64.865  48.759  1
445565  100.425  -64.870  48.720  1
445566  100.464  -64.875  48.681  1
445567  100.502  -64.881  48.640  1
445568  100.541  -64.886  48.601  1
445569  100.580  -64.891  48.563  1
445570  100.619  -64.897  48.525  1
445956  87.108  -63.245  55.859  1
445957  87.142  -63.255  55.845  1
445958  87.177  -63.264  55.831  1
445959  87.211  -63.274  55.817  1
445960  87.245  -63.283  55.803  1
445961  87.279  -63.293  55.788  1
445962  87.314  -63.302  55.773  1
445963  87.348  -63.312  55.758  1
445964  87.382  -63.321  55.744  1
445965  87.416  -63.331  55.728  1
445966  87.450  -63.341  55.713  1
445967  87.485  -63.350  55.698  1
445968  87.519  -63.360  55.683  1
445969  87.555  -63.368  55.666  1
445970  87.602  -63.372  55.650  1
445971  87.648  -63.377  55.635  1
445972  87.697  -63.379  55.618  1
445973  87.760  -63.374  55.603  1
445974  87.819  -63.375  55.587  1
445975  87.867  -63.386  55.571  1
445976  87.916  -63.396  55.553  1
445977  87.965  -63.406  55.535  1
445978  88.014  -63.417  55.517  1
445979  88.063  -63.427  55.498  1
445980  88.112  -63.437  55.480  1
445981  88.161  -63.448  55.464  1
445993  88.749  -63.572  55.334  1
445994  88.798  -63.583  55.333  1
445995  88.847  -63.593  55.332  1
445996  88.896  -63.603  55.333  1
445997  88.945  -63.614  55.334  1
445998  88.993  -63.625  55.338  1
445999  89.042  -63.634  55.342  1
446000  89.092  -63.645  55.349  1
446001  89.140  -63.656  55.355  1
446002  89.189  -63.665  55.365  1
446003  89.238  -63.676  55.377  1
446004  89.287  -63.687  55.391  1
446005  89.334  -63.698  55.409  1
446006  89.370  -63.715  55.425  1
446007  89.407  -63.731  55.437  1
446008  89.443  -63.748  55.444  1
446009  89.487  -63.756  55.447  1
446010  89.531  -63.763  55.449  1
446011  89.576  -63.770  55.448  1
446012  89.621  -63.777  55.440  1
446013  89.666  -63.784  55.424  1
446014  89.712  -63.781  55.402  1
446015  89.758  -63.778  55.378  1
446016  89.805  -63.775  55.351  1
446017  89.851  -63.772  55.325  1
446018  89.898  -63.769  55.302  1
446019  89.945  -63.766  55.283  1
446020  89.991  -63.763  55.269  1
446021  90.038  -63.759  55.258  1
446022  90.084  -63.756  55.251  1
446023  90.130  -63.753  55.248  1
446024  90.177  -63.751  55.248  1
446025  90.224  -63.748  55.253  1
446026  90.271  -63.745  55.264  1
446027  90.321  -63.744  55.278  1
446028  90.369  -63.747  55.292  1
446029  90.413  -63.764  55.304  1
446030  90.457  -63.781  55.313  1
446031  90.502  -63.797  55.317  1
446032  90.545  -63.814  55.317  1
446033  90.590  -63.831  55.312  1
446034  90.634  -63.847  55.299  1
446035  90.678  -63.864  55.269  1
446036  90.723  -63.879  55.227  1
446037  90.768  -63.887  55.181  1
446038  90.815  -63.894  55.134  1
446039  90.861  -63.902  55.088  1
446040  90.907  -63.910  55.045  1
446041  90.953  -63.917  55.001  1
446042  91.000  -63.925  54.958  1
446043  91.045  -63.932  54.920  1
446044  91.092  -63.940  54.886  1
446045  91.138  -63.947  54.856  1
446046  91.184  -63.955  54.829  1
446047  91.230  -63.963  54.807  1
446048  91.276  -63.970  54.788  1
446049  91.322  -63.978  54.772  1
446050  91.369  -63.985  54.758  1
446051  91.415  -63.993  54.746  1
446052  91.461  -64.001  54.735  1
446053  91.507  -64.008  54.726  1
446054  91.553  -64.016  54.717  1
446055  91.599  -64.023  54.708  1
446056  91.645  -64.031  54.700  1
446057  91.692  -64.038  54.693  1
446058  91.738  -64.046  54.687  1
446059  91.784  -64.054  54.680  1
446060  91.830  -64.061  54.674  1
446061  91.876  -64.069  54.668  1
446062  91.922  -64.076  54.662  1
446063  91.968  -64.084  54.657  1
446064  92.015  -64.092  54.651  1
446065  92.061  -64.099  54.646  1
446066  92.106  -64.109  54.642  1
446067  92.151  -64.119  54.637  1
446068  92.197  -64.129  54.633  1
446069  92.243  -64.139  54.628  1
446070  92.289  -64.148  54.624  1
446071  92.330  -64.158  54.621  1
446072  92.370  -64.168  54.619  1
446073  92.406  -64.179  54.615  1
446074  92.431  -64.195  54.610  1
446075  92.456  -64.211  54.605  1
446076  92.481  -64.226  54.600  1
446077  92.506  -64.242  54.596  1
446078  92.534  -64.255  54.591  1
446079  92.563  -64.267  54.587  1
446080  92.592  -64.280  54.583  1
446081  92.626  -64.293  54.581  1
446082  92.675  -64.306  54.577  1
446083  92.725  -64.319  54.576  1
446084  92.795  -64.322  54.575  1
446085  92.872  -64.321  54.575  1
446086  92.948  -64.320  54.576  1
446087  93.025  -64.320  54.578  1
446088  93.099  -64.320  54.581  1
446089  93.147  -64.323  54.586  1
446090  93.196  -64.327  54.591  1
446091  93.241  -64.327  54.596  1
446092  93.287  -64.327  54.600  1
446093  93.334  -64.327  54.602  1
446094  93.368  -64.330  54.601  1
446095  93.393  -64.337  54.598  1
446096  93.418  -64.345  54.593  1
446097  93.443  -64.352  54.588  1
446098  93.468  -64.358  54.581  1
446099  93.503  -64.361  54.572  1
446100  93.543  -64.359  54.561  1
446101  93.584  -64.358  54.548  1
446102  93.625  -64.357  54.535  1
446103  93.665  -64.355  54.525  1
446104  93.706  -64.355  54.515  1
446105  93.743  -64.362  54.505  1
446106  93.779  -64.371  54.494  1
446107  93.819  -64.380  54.478  1
446108  93.864  -64.390  54.461  1
446109  93.909  -64.400  54.442  1
446110  93.954  -64.410  54.421  1
446111  93.999  -64.420  54.399  1
446112  94.040  -64.428  54.373  1
446113  94.068  -64.433  54.347  1
446114  94.097  -64.439  54.319  1
446115  94.126  -64.445  54.292  1
446116  94.155  -64.450  54.264  1
446117  94.184  -64.455  54.238  1
446118  94.213  -64.461  54.212  1
446119  94.243  -64.464  54.187  1
446120  94.276  -64.462  54.162  1
446121  94.309  -64.461  54.140  1
446122  94.348  -64.461  54.119  1
446123  94.411  -64.470  54.100  1
446124  94.471  -64.478  54.082  1
446125  94.522  -64.488  54.067  1
446126  94.573  -64.498  54.051  1
446127  94.624  -64.508  54.037  1
446128  94.675  -64.518  54.021  1
446129  94.726  -64.527  54.003  1
446130  94.777  -64.537  53.985  1
446131  94.825  -64.544  53.966  1
446132  94.871  -64.549  53.945  1
446133  94.917  -64.555  53.922  1
446134  94.963  -64.561  53.894  1
446135  95.009  -64.566  53.865  1
446136  95.055  -64.571  53.835  1
446137  95.108  -64.578  53.807  1
446138  95.162  -64.586  53.781  1
446139  95.216  -64.593  53.757  1
446140  95.265  -64.600  53.734  1
446141  95.314  -64.609  53.711  1
446142  95.363  -64.616  53.688  1
446143  95.412  -64.624  53.664  1
446144  95.461  -64.632  53.637  1
446145  95.510  -64.640  53.608  1
446146  95.558  -64.648  53.577  1
446147  95.600  -64.656  53.548  1
446148  95.640  -64.662  53.520  1
446149  95.680  -64.670  53.492  1
446150  95.721  -64.677  53.466  1
446151  95.761  -64.684  53.438  1
446152  95.800  -64.690  53.412  1
446153  95.834  -64.693  53.386  1
446154  95.868  -64.696  53.360  1
446155  95.902  -64.700  53.335  1
446156  95.936  -64.703  53.306  1
446157  95.970  -64.706  53.275  1
446158  96.004  -64.709  53.243  1
446159  96.043  -64.702  53.215  1
446160  96.083  -64.693  53.189  1
446161  96.123  -64.684  53.163  1
446162  96.164  -64.674  53.134  1
446163  96.208  -64.660  53.100  1
446164  96.249  -64.653  53.066  1
446165  96.288  -64.652  53.028  1
446166  96.327  -64.649  52.989  1
446167  96.367  -64.647  52.948  1
446168  96.406  -64.645  52.906  1
446169  96.445  -64.643  52.864  1
446170  96.484  -64.640  52.827  1
446171  96.523  -64.638  52.797  1
446172  96.558  -64.639  52.768  1
446173  96.594  -64.640  52.737  1
446174  96.632  -64.644  52.704  1
446175  96.672  -64.649  52.667  1
446176  96.711  -64.653  52.627  1
446177  96.751  -64.658  52.584  1
446178  96.790  -64.662  52.538  1
446179  96.829  -64.667  52.492  1
446180  96.869  -64.671  52.447  1
446181  96.907  -64.675  52.402  1
446182  96.945  -64.679  52.359  1
446183  96.983  -64.683  52.318  1
446184  97.021  -64.687  52.276  1
446185  97.059  -64.691  52.230  1
446186  97.097  -64.695  52.184  1
446187  97.135  -64.699  52.140  1
446188  97.173  -64.703  52.094  1
446189  97.211  -64.704  52.048  1
446190  97.249  -64.703  52.005  1
446191  97.288  -64.702  51.963  1
446192  97.326  -64.700  51.920  1
446193  97.356  -64.694  51.877  1
446194  97.380  -64.682  51.829  1
446195  97.403  -64.671  51.783  1
446196  97.433  -64.668  51.738  1
446197  97.468  -64.674  51.694  1
446198  97.504  -64.679  51.649  1
446199  97.539  -64.684  51.603  1
446200  97.575  -64.690  51.556  1
446201  97.610  -64.695  51.509  1
446202  97.645  -64.700  51.462  1
446203  97.676  -64.705  51.414  1
446204  97.708  -64.709  51.367  1
446205  97.739  -64.713  51.320  1
446206  97.768  -64.717  51.272  1
446207  97.795  -64.722  51.224  1
446208  97.823  -64.725  51.177  1
446209  97.857  -64.728  51.132  1
446210  97.893  -64.729  51.089  1
446211  97.929  -64.730  51.047  1
446212  97.965  -64.731  51.005  1
446213  98.002  -64.733  50.964  1
446214  98.038  -64.734  50.925  1
446215  98.075  -64.736  50.885  1
446216  98.112  -64.736  50.843  1
446217  98.146  -64.744  50.800  1
446218  98.182  -64.750  50.756  1
446219  98.218  -64.756  50.711  1
446220  98.254  -64.762  50.666  1
446221  98.290  -64.768  50.621  1
446222  98.326  -64.773  50.577  1
446223  98.362  -64.779  50.534  1
446224  98.398  -64.784  50.492  1
446225  98.445  -64.777  50.450  1
446226  98.494  -64.768  50.405  1
446227  98.533  -64.769  50.358  1
446228  98.574  -64.769  50.309  1
446229  98.614  -64.770  50.258  1
446230  98.653  -64.771  50.207  1
446231  98.693  -64.772  50.159  1
446232  98.733  -64.772  50.113  1
446233  98.773  -64.773  50.068  1
446234  98.812  -64.774  50.025  1
446235  98.852  -64.775  49.984  1
446236  98.892  -64.775  49.944  1
446237  98.933  -64.775  49.904  1
446238  98.976  -64.771  49.865  1
446239  99.019  -64.766  49.824  1
446240  99.062  -64.762  49.783  1
446241  99.105  -64.758  49.743  1
446242  99.148  -64.754  49.705  1
446243  99.190  -64.756  49.666  1
446244  99.238  -64.764  49.625  1
446245  99.285  -64.772  49.582  1
446246  99.333  -64.780  49.537  1
446247  99.381  -64.788  49.491  1
446248  99.429  -64.796  49.444  1
446249  99.477  -64.804  49.399  1
446250  99.532  -64.812  49.356  1
446251  99.590  -64.819  49.313  1
446252  99.648  -64.828  49.272  1
446253  99.737  -64.806  49.232  1
446254  99.831  -64.781  49.191  1
446255  99.925  -64.755  49.149  1
446256  100.019  -64.729  49.107  1
446257  100.113  -64.703  49.067  1
446258  100.207  -64.678  49.027  1
446259  100.268  -64.681  48.988  1
446260  100.259  -64.745  48.949  1
446261  100.250  -64.810  48.909  1
446262  100.271  -64.814  48.869  1
446263  100.319  -64.812  48.830  1
446264  100.357  -64.817  48.792  1
446265  100.396  -64.822  48.752  1
446266  100.435  -64.828  48.713  1
446267  100.474  -64.833  48.673  1
446268  100.512  -64.838  48.633  1
446269  100.551  -64.844  48.594  1
446270  100.590  -64.848  48.556  1
446271  100.628  -64.853  48.518  1
446656  87.066  -63.187  55.877  1
446657  87.100  -63.197  55.864  1
446658  87.134  -63.206  55.850  1
446659  87.168  -63.216  55.836  1
446660  87.203  -63.225  55.822  1
446661  87.237  -63.235  55.809  1
446662  87.271  -63.245  55.795  1
446663  87.305  -63.254  55.781  1
446664  87.340  -63.264  55.765  1
446665  87.374  -63.274  55.751  1
446666  87.408  -63.283  55.737  1
446667  87.442  -63.292  55.723  1
446668  87.477  -63.302  55.707  1
446669  87.511  -63.311  55.693  1
446670  87.558  -63.315  55.677  1
446671  87.604  -63.319  55.662  1
446672  87.660  -63.318  55.647  1
446673  87.722  -63.315  55.630  1
446674  87.771  -63.325  55.615  1
446675  87.820  -63.336  55.600  1
446676  87.869  -63.346  55.584  1
446677  87.918  -63.356  55.566  1
446678  87.967  -63.367  55.547  1
446679  88.016  -63.377  55.529  1
446680  88.065  -63.387  55.511  1
446681  88.114  -63.398  55.492  1
446682  88.163  -63.408  55.474  1
446683  88.212  -63.418  55.458  1
446684  88.261  -63.429  55.441  1
446694  88.750  -63.533  55.337  1
446695  88.799  -63.543  55.335  1
446696  88.848  -63.553  55.334  1
446697  88.897  -63.564  55.335  1
446698  88.946  -63.574  55.336  1
446699  88.995  -63.585  55.340  1
446700  89.044  -63.595  55.344  1
446701  89.093  -63.606  55.350  1
446702  89.142  -63.616  55.356  1
446703  89.191  -63.626  55.365  1
446704  89.240  -63.637  55.377  1
446705  89.289  -63.647  55.390  1
446706  89.338  -63.657  55.405  1
446707  89.376  -63.673  55.420  1
446708  89.412  -63.690  55.432  1
446709  89.454  -63.700  55.439  1
446710  89.499  -63.707  55.444  1
446711  89.544  -63.714  55.448  1
446712  89.589  -63.721  55.449  1
446713  89.633  -63.728  55.443  1
446714  89.678  -63.732  55.430  1
446715  89.725  -63.729  55.409  1
446716  89.771  -63.726  55.384  1
446717  89.818  -63.723  55.356  1
446718  89.865  -63.720  55.331  1
446719  89.911  -63.717  55.309  1
446720  89.957  -63.714  55.291  1
446721  90.004  -63.711  55.277  1
446722  90.050  -63.708  55.267  1
446723  90.097  -63.705  55.261  1
446724  90.144  -63.702  55.259  1
446725  90.190  -63.699  55.259  1
446726  90.237  -63.696  55.266  1
446727  90.283  -63.693  55.277  1
446728  90.330  -63.690  55.290  1
446729  90.375  -63.703  55.303  1
446730  90.419  -63.720  55.314  1
446731  90.464  -63.737  55.323  1
446732  90.508  -63.753  55.325  1
446733  90.552  -63.770  55.322  1
446734  90.596  -63.787  55.314  1
446735  90.640  -63.803  55.296  1
446736  90.684  -63.820  55.264  1
446737  90.729  -63.835  55.223  1
446738  90.775  -63.843  55.177  1
446739  90.821  -63.850  55.128  1
446740  90.867  -63.858  55.082  1
446741  90.913  -63.866  55.037  1
446742  90.959  -63.873  54.994  1
446743  91.006  -63.881  54.953  1
446744  91.052  -63.888  54.914  1
446745  91.098  -63.896  54.880  1
446746  91.144  -63.904  54.851  1
446747  91.190  -63.911  54.826  1
446748  91.236  -63.919  54.804  1
446749  91.283  -63.926  54.784  1
446750  91.329  -63.934  54.768  1
446751  91.375  -63.941  54.754  1
446752  91.421  -63.949  54.743  1
446753  91.467  -63.957  54.732  1
446754  91.513  -63.964  54.722  1
446755  91.560  -63.972  54.714  1
446756  91.605  -63.979  54.706  1
446757  91.652  -63.987  54.699  1
446758  91.698  -63.994  54.692  1
446759  91.744  -64.002  54.686  1
446760  91.790  -64.010  54.680  1
446761  91.837  -64.017  54.674  1
446762  91.882  -64.025  54.668  1
446763  91.929  -64.032  54.663  1
446764  91.975  -64.040  54.658  1
446765  92.021  -64.048  54.651  1
446766  92.067  -64.055  54.647  1
446767  92.113  -64.063  54.642  1
446768  92.159  -64.070  54.638  1
446769  92.205  -64.080  54.633  1
446770  92.250  -64.090  54.628  1
446771  92.290  -64.100  54.624  1
446772  92.331  -64.110  54.621  1
446773  92.371  -64.119  54.617  1
446774  92.406  -64.131  54.613  1
446775  92.431  -64.146  54.608  1
446776  92.456  -64.162  54.603  1
446777  92.481  -64.177  54.599  1
446778  92.506  -64.192  54.594  1
446779  92.531  -64.208  54.590  1
446780  92.558  -64.223  54.586  1
446781  92.587  -64.236  54.582  1
446782  92.619  -64.248  54.579  1
446783  92.668  -64.261  54.576  1
446784  92.734  -64.266  54.575  1
446785  92.811  -64.265  54.574  1
446786  92.887  -64.264  54.574  1
446787  92.965  -64.264  54.573  1
446788  93.041  -64.264  54.575  1
446789  93.106  -64.264  54.577  1
446790  93.154  -64.268  54.580  1
446791  93.200  -64.269  54.584  1
446792  93.246  -64.269  54.587  1
446793  93.292  -64.269  54.588  1
446794  93.338  -64.269  54.589  1
446795  93.367  -64.274  54.587  1
446796  93.392  -64.282  54.584  1
446797  93.416  -64.289  54.580  1
446798  93.441  -64.295  54.575  1
446799  93.466  -64.303  54.567  1
446800  93.494  -64.308  54.557  1
446801  93.534  -64.308  54.544  1
446802  93.575  -64.306  54.531  1
446803  93.615  -64.305  54.519  1
446804  93.656  -64.304  54.508  1
446805  93.695  -64.305  54.499  1
446806  93.731  -64.314  54.489  1
446807  93.770  -64.324  54.476  1
446808  93.815  -64.334  54.459  1
446809  93.860  -64.344  54.441  1
446810  93.905  -64.353  54.420  1
446811  93.951  -64.363  54.398  1
446812  93.996  -64.373  54.376  1
446813  94.032  -64.380  54.350  1
446814  94.060  -64.386  54.323  1
446815  94.089  -64.391  54.297  1
446816  94.118  -64.397  54.270  1
446817  94.147  -64.402  54.243  1
446818  94.176  -64.408  54.217  1
446819  94.205  -64.413  54.191  1
446820  94.234  -64.419  54.167  1
446821  94.266  -64.418  54.144  1
446822  94.298  -64.417  54.122  1
446823  94.342  -64.418  54.101  1
446824  94.404  -64.427  54.081  1
446825  94.459  -64.436  54.062  1
446826  94.509  -64.446  54.045  1
446827  94.560  -64.455  54.028  1
446828  94.612  -64.465  54.013  1
446829  94.663  -64.475  53.997  1
446830  94.713  -64.485  53.979  1
446831  94.765  -64.495  53.960  1
446832  94.813  -64.502  53.940  1
446833  94.859  -64.508  53.918  1
446834  94.905  -64.514  53.894  1
446835  94.951  -64.519  53.869  1
446836  94.997  -64.524  53.841  1
446837  95.050  -64.531  53.815  1
446838  95.104  -64.539  53.788  1
446839  95.158  -64.546  53.763  1
446840  95.211  -64.553  53.739  1
446841  95.266  -64.560  53.715  1
446842  95.320  -64.567  53.691  1
446843  95.369  -64.575  53.667  1
446844  95.417  -64.583  53.642  1
446845  95.466  -64.591  53.616  1
446846  95.515  -64.599  53.590  1
446847  95.564  -64.607  53.561  1
446848  95.611  -64.615  53.534  1
446849  95.651  -64.621  53.507  1
446850  95.691  -64.629  53.482  1
446851  95.732  -64.636  53.456  1
446852  95.772  -64.643  53.428  1
446853  95.808  -64.647  53.399  1
446854  95.841  -64.650  53.369  1
446855  95.876  -64.654  53.338  1
446856  95.909  -64.657  53.310  1
446857  95.944  -64.660  53.281  1
446858  95.978  -64.663  53.251  1
446859  96.012  -64.666  53.218  1
446860  96.046  -64.669  53.185  1
446861  96.086  -64.660  53.156  1
446862  96.126  -64.651  53.131  1
446863  96.166  -64.642  53.103  1
446864  96.210  -64.627  53.071  1
446865  96.255  -64.613  53.037  1
446866  96.295  -64.611  53.004  1
446867  96.334  -64.609  52.968  1
446868  96.373  -64.606  52.929  1
446869  96.412  -64.604  52.889  1
446870  96.451  -64.602  52.848  1
446871  96.490  -64.599  52.812  1
446872  96.528  -64.599  52.782  1
446873  96.562  -64.599  52.752  1
446874  96.597  -64.600  52.720  1
446875  96.636  -64.604  52.687  1
446876  96.675  -64.609  52.649  1
446877  96.715  -64.613  52.610  1
446878  96.754  -64.618  52.569  1
446879  96.794  -64.622  52.524  1
446880  96.833  -64.627  52.480  1
446881  96.872  -64.631  52.437  1
446882  96.912  -64.636  52.393  1
446883  96.951  -64.641  52.351  1
446884  96.990  -64.645  52.310  1
446885  97.028  -64.649  52.267  1
446886  97.066  -64.653  52.222  1
446887  97.104  -64.657  52.178  1
446888  97.142  -64.661  52.134  1
446889  97.180  -64.665  52.089  1
446890  97.218  -64.668  52.044  1
446891  97.256  -64.667  52.001  1
446892  97.294  -64.665  51.959  1
446893  97.330  -64.662  51.917  1
446894  97.354  -64.651  51.873  1
446895  97.377  -64.640  51.824  1
446896  97.401  -64.628  51.777  1
446897  97.431  -64.626  51.732  1
446898  97.466  -64.631  51.688  1
446899  97.502  -64.637  51.642  1
446900  97.537  -64.642  51.596  1
446901  97.573  -64.647  51.549  1
446902  97.608  -64.653  51.502  1
446903  97.643  -64.658  51.455  1
446904  97.679  -64.663  51.407  1
446905  97.711  -64.668  51.359  1
446906  97.742  -64.672  51.312  1
446907  97.772  -64.677  51.264  1
446908  97.800  -64.681  51.215  1
446909  97.829  -64.684  51.167  1
446910  97.865  -64.685  51.121  1
446911  97.901  -64.687  51.076  1
446912  97.938  -64.688  51.032  1
446913  97.974  -64.690  50.988  1
446914  98.011  -64.691  50.946  1
446915  98.052  -64.688  50.904  1
446916  98.088  -64.688  50.863  1
446917  98.114  -64.695  50.821  1
446918  98.145  -64.703  50.778  1
446919  98.185  -64.713  50.733  1
446920  98.225  -64.722  50.687  1
446921  98.261  -64.728  50.642  1
446922  98.297  -64.733  50.598  1
446923  98.333  -64.739  50.553  1
446924  98.368  -64.744  50.510  1
446925  98.405  -64.750  50.468  1
446926  98.452  -64.742  50.425  1
446927  98.501  -64.733  50.381  1
446928  98.550  -64.724  50.335  1
446929  98.594  -64.719  50.287  1
446930  98.634  -64.720  50.237  1
446931  98.674  -64.721  50.188  1
446932  98.714  -64.722  50.141  1
446933  98.754  -64.722  50.097  1
446934  98.793  -64.723  50.054  1
446935  98.833  -64.724  50.013  1
446936  98.873  -64.725  49.972  1
446937  98.913  -64.725  49.931  1
446938  98.954  -64.723  49.890  1
446939  98.997  -64.719  49.850  1
446940  99.041  -64.715  49.809  1
446941  99.083  -64.711  49.768  1
446942  99.127  -64.707  49.728  1
446943  99.165  -64.709  49.690  1
446944  99.203  -64.712  49.650  1
446945  99.240  -64.715  49.606  1
446946  99.287  -64.723  49.562  1
446947  99.335  -64.731  49.516  1
446948  99.383  -64.739  49.471  1
446949  99.430  -64.747  49.425  1
446950  99.478  -64.755  49.381  1
446951  99.532  -64.763  49.338  1
446952  99.589  -64.771  49.297  1
446953  99.652  -64.774  49.255  1
446954  99.747  -64.748  49.215  1
446955  99.840  -64.722  49.175  1
446956  99.934  -64.696  49.134  1
446957  100.028  -64.671  49.093  1
446958  100.122  -64.645  49.055  1
446959  100.191  -64.643  49.016  1
446960  100.246  -64.656  48.977  1
446961  100.275  -64.689  48.939  1
446962  100.266  -64.753  48.899  1
446963  100.285  -64.768  48.860  1
446964  100.329  -64.769  48.821  1
446965  100.367  -64.775  48.783  1
446966  100.406  -64.780  48.745  1
446967  100.445  -64.785  48.706  1
446968  100.484  -64.790  48.666  1
446969  100.522  -64.796  48.626  1
446970  100.561  -64.800  48.588  1
446971  100.600  -64.806  48.550  1
446972  100.638  -64.811  48.512  1
447357  87.070  -63.145  55.884  1
447358  87.098  -63.151  55.870  1
447359  87.127  -63.158  55.855  1
447360  87.160  -63.167  55.842  1
447361  87.195  -63.177  55.828  1
447362  87.229  -63.186  55.814  1
447363  87.263  -63.196  55.801  1
447364  87.297  -63.205  55.788  1
447365  87.332  -63.215  55.773  1
447366  87.366  -63.225  55.759  1
447367  87.400  -63.234  55.745  1
447368  87.434  -63.244  55.732  1
447369  87.469  -63.254  55.717  1
447370  87.514  -63.258  55.702  1
447371  87.560  -63.262  55.687  1
447372  87.623  -63.258  55.673  1
447373  87.675  -63.265  55.658  1
447374  87.723  -63.275  55.643  1
447375  87.773  -63.286  55.627  1
447376  87.822  -63.296  55.612  1
447377  87.870  -63.307  55.595  1
447378  87.919  -63.317  55.579  1
447379  87.969  -63.327  55.561  1
447380  88.017  -63.338  55.542  1
447381  88.066  -63.348  55.523  1
447382  88.115  -63.358  55.504  1
447383  88.165  -63.369  55.485  1
447384  88.213  -63.379  55.467  1
447385  88.262  -63.390  55.450  1
447386  88.311  -63.400  55.434  1
447394  88.703  -63.483  55.344  1
447395  88.752  -63.493  55.341  1
447396  88.801  -63.504  55.339  1
447397  88.850  -63.514  55.337  1
447398  88.899  -63.524  55.338  1
447399  88.948  -63.535  55.339  1
447400  88.996  -63.545  55.342  1
447401  89.046  -63.556  55.346  1
447402  89.095  -63.566  55.351  1
447403  89.143  -63.577  55.358  1
447404  89.192  -63.587  55.366  1
447405  89.242  -63.597  55.376  1
447406  89.291  -63.608  55.388  1
447407  89.339  -63.618  55.402  1
447408  89.382  -63.631  55.415  1
447409  89.422  -63.644  55.425  1
447410  89.467  -63.651  55.433  1
447411  89.512  -63.658  55.440  1
447412  89.556  -63.665  55.445  1
447413  89.601  -63.672  55.448  1
447414  89.646  -63.678  55.444  1
447415  89.691  -63.680  55.433  1
447416  89.738  -63.677  55.414  1
447417  89.784  -63.674  55.388  1
447418  89.831  -63.671  55.361  1
447419  89.877  -63.669  55.337  1
447420  89.923  -63.665  55.317  1
447421  89.970  -63.662  55.298  1
447422  90.017  -63.659  55.285  1
447423  90.063  -63.656  55.276  1
447424  90.110  -63.653  55.271  1
447425  90.156  -63.650  55.269  1
447426  90.203  -63.647  55.271  1
447427  90.249  -63.644  55.282  1
447428  90.295  -63.646  55.292  1
447429  90.335  -63.650  55.302  1
447430  90.378  -63.662  55.314  1
447431  90.426  -63.676  55.321  1
447432  90.470  -63.693  55.328  1
447433  90.514  -63.709  55.332  1
447434  90.558  -63.726  55.331  1
447435  90.602  -63.743  55.321  1
447436  90.647  -63.759  55.297  1
447437  90.691  -63.776  55.261  1
447438  90.735  -63.792  55.221  1
447439  90.781  -63.800  55.177  1
447440  90.827  -63.807  55.128  1
447441  90.874  -63.815  55.079  1
447442  90.920  -63.822  55.033  1
447443  90.966  -63.830  54.989  1
447444  91.012  -63.838  54.948  1
447445  91.058  -63.845  54.909  1
447446  91.104  -63.853  54.875  1
447447  91.150  -63.860  54.846  1
447448  91.196  -63.868  54.821  1
447449  91.243  -63.875  54.799  1
447450  91.289  -63.883  54.779  1
447451  91.335  -63.891  54.764  1
447452  91.381  -63.898  54.751  1
447453  91.427  -63.906  54.739  1
447454  91.473  -63.913  54.729  1
447455  91.520  -63.921  54.719  1
447456  91.566  -63.929  54.712  1
447457  91.612  -63.936  54.704  1
447458  91.658  -63.944  54.697  1
447459  91.704  -63.951  54.691  1
447460  91.750  -63.959  54.685  1
447461  91.796  -63.966  54.679  1
447462  91.843  -63.974  54.674  1
447463  91.889  -63.982  54.668  1
447464  91.935  -63.989  54.663  1
447465  91.981  -63.997  54.658  1
447466  92.027  -64.004  54.653  1
447467  92.074  -64.013  54.648  1
447468  92.121  -64.021  54.643  1
447469  92.168  -64.030  54.638  1
447470  92.214  -64.034  54.633  1
447471  92.251  -64.041  54.628  1
447472  92.291  -64.051  54.624  1
447473  92.332  -64.060  54.620  1
447474  92.372  -64.070  54.616  1
447475  92.406  -64.082  54.611  1
447476  92.431  -64.098  54.606  1
447477  92.456  -64.114  54.602  1
447478  92.481  -64.129  54.598  1
447479  92.506  -64.144  54.593  1
447480  92.531  -64.160  54.590  1
447481  92.557  -64.175  54.587  1
447482  92.582  -64.190  54.583  1
447483  92.612  -64.203  54.580  1
447484  92.673  -64.211  54.577  1
447485  92.749  -64.210  54.576  1
447486  92.827  -64.209  54.575  1
447487  92.903  -64.208  54.575  1
447488  92.980  -64.208  54.575  1
447489  93.057  -64.207  54.576  1
447490  93.112  -64.209  54.578  1
447491  93.158  -64.211  54.580  1
447492  93.204  -64.211  54.581  1
447493  93.250  -64.211  54.583  1
447494  93.296  -64.211  54.583  1
447495  93.340  -64.211  54.581  1
447496  93.365  -64.219  54.577  1
447497  93.390  -64.226  54.573  1
447498  93.415  -64.233  54.569  1
447499  93.440  -64.240  54.563  1
447500  93.465  -64.247  54.555  1
447501  93.490  -64.254  54.543  1
447502  93.525  -64.255  54.530  1
447503  93.565  -64.255  54.515  1
447504  93.606  -64.253  54.502  1
447505  93.646  -64.251  54.490  1
447506  93.684  -64.258  54.479  1
447507  93.721  -64.267  54.466  1
447508  93.766  -64.277  54.452  1
447509  93.812  -64.287  54.435  1
447510  93.856  -64.297  54.416  1
447511  93.902  -64.307  54.395  1
447512  93.947  -64.317  54.373  1
447513  93.992  -64.326  54.350  1
447514  94.024  -64.333  54.325  1
447515  94.053  -64.338  54.300  1
447516  94.081  -64.343  54.274  1
447517  94.110  -64.349  54.247  1
447518  94.139  -64.355  54.222  1
447519  94.168  -64.360  54.196  1
447520  94.197  -64.365  54.171  1
447521  94.226  -64.371  54.147  1
447522  94.256  -64.374  54.125  1
447523  94.288  -64.372  54.104  1
447524  94.335  -64.376  54.084  1
447525  94.395  -64.384  54.063  1
447526  94.446  -64.394  54.042  1
447527  94.497  -64.404  54.023  1
447528  94.548  -64.414  54.006  1
447529  94.599  -64.424  53.989  1
447530  94.650  -64.433  53.972  1
447531  94.701  -64.443  53.955  1
447532  94.752  -64.453  53.936  1
447533  94.801  -64.461  53.914  1
447534  94.847  -64.467  53.892  1
447535  94.893  -64.472  53.868  1
447536  94.939  -64.478  53.844  1
447537  94.991  -64.484  53.819  1
447538  95.045  -64.492  53.795  1
447539  95.099  -64.499  53.771  1
447540  95.153  -64.506  53.747  1
447541  95.207  -64.513  53.724  1
447542  95.261  -64.520  53.699  1
447543  95.315  -64.527  53.674  1
447544  95.370  -64.534  53.650  1
447545  95.423  -64.542  53.625  1
447546  95.472  -64.549  53.600  1
447547  95.521  -64.558  53.575  1
447548  95.570  -64.565  53.549  1
447549  95.619  -64.574  53.524  1
447550  95.662  -64.580  53.500  1
447551  95.702  -64.588  53.476  1
447552  95.742  -64.595  53.450  1
447553  95.781  -64.602  53.421  1
447554  95.815  -64.605  53.390  1
447555  95.849  -64.608  53.358  1
447556  95.883  -64.611  53.324  1
447557  95.917  -64.614  53.293  1
447558  95.951  -64.617  53.262  1
447559  95.985  -64.620  53.230  1
447560  96.019  -64.623  53.198  1
447561  96.053  -64.626  53.164  1
447562  96.088  -64.627  53.134  1
447563  96.128  -64.618  53.106  1
447564  96.169  -64.609  53.076  1
447565  96.213  -64.596  53.044  1
447566  96.257  -64.581  53.012  1
447567  96.301  -64.570  52.980  1
447568  96.340  -64.568  52.945  1
447569  96.379  -64.565  52.910  1
447570  96.418  -64.563  52.874  1
447571  96.457  -64.561  52.838  1
447572  96.497  -64.559  52.805  1
447573  96.532  -64.559  52.774  1
447574  96.567  -64.560  52.742  1
447575  96.601  -64.562  52.708  1
447576  96.639  -64.565  52.673  1
447577  96.678  -64.569  52.636  1
447578  96.718  -64.574  52.598  1
447579  96.757  -64.578  52.559  1
447580  96.797  -64.583  52.519  1
447581  96.836  -64.587  52.476  1
447582  96.876  -64.592  52.433  1
447583  96.915  -64.596  52.389  1
447584  96.954  -64.601  52.345  1
447585  96.994  -64.606  52.302  1
447586  97.033  -64.610  52.259  1
447587  97.073  -64.615  52.216  1
447588  97.111  -64.618  52.174  1
447589  97.149  -64.623  52.131  1
447590  97.187  -64.627  52.087  1
447591  97.225  -64.631  52.042  1
447592  97.263  -64.631  51.999  1
447593  97.301  -64.630  51.957  1
447594  97.328  -64.620  51.913  1
447595  97.352  -64.609  51.868  1
447596  97.376  -64.597  51.818  1
447597  97.405  -64.587  51.771  1
447598  97.434  -64.590  51.725  1
447599  97.475  -64.586  51.680  1
447600  97.508  -64.590  51.635  1
447601  97.537  -64.599  51.588  1
447602  97.571  -64.606  51.541  1
447603  97.606  -64.611  51.494  1
447604  97.641  -64.616  51.447  1
447605  97.677  -64.621  51.400  1
447606  97.712  -64.627  51.352  1
447607  97.745  -64.631  51.304  1
447608  97.776  -64.636  51.256  1
447609  97.804  -64.640  51.208  1
447610  97.837  -64.642  51.159  1
447611  97.873  -64.643  51.111  1
447612  97.910  -64.645  51.064  1
447613  97.948  -64.645  51.019  1
447614  97.989  -64.642  50.974  1
447615  98.030  -64.639  50.930  1
447616  98.064  -64.640  50.886  1
447617  98.090  -64.647  50.842  1
447618  98.116  -64.653  50.799  1
447619  98.144  -64.660  50.756  1
447620  98.184  -64.671  50.711  1
447621  98.225  -64.681  50.665  1
447622  98.266  -64.691  50.620  1
447623  98.303  -64.699  50.575  1
447624  98.339  -64.705  50.531  1
447625  98.375  -64.710  50.487  1
447626  98.411  -64.715  50.444  1
447627  98.459  -64.707  50.400  1
447628  98.508  -64.698  50.357  1
447629  98.557  -64.689  50.312  1
447630  98.605  -64.680  50.265  1
447631  98.654  -64.671  50.217  1
447632  98.695  -64.670  50.170  1
447633  98.734  -64.671  50.125  1
447634  98.774  -64.671  50.082  1
447635  98.814  -64.672  50.041  1
447636  98.854  -64.673  50.000  1
447637  98.894  -64.674  49.958  1
447638  98.934  -64.674  49.916  1
447639  98.976  -64.672  49.876  1
447640  99.019  -64.668  49.834  1
447641  99.062  -64.664  49.794  1
447642  99.105  -64.659  49.753  1
447643  99.143  -64.662  49.713  1
447644  99.181  -64.666  49.674  1
447645  99.218  -64.670  49.632  1
447646  99.256  -64.673  49.587  1
447647  99.293  -64.677  49.541  1
447648  99.337  -64.683  49.496  1
447649  99.384  -64.690  49.451  1
447650  99.432  -64.699  49.407  1
447651  99.480  -64.706  49.364  1
447652  99.531  -64.715  49.322  1
447653  99.589  -64.722  49.281  1
447654  99.662  -64.716  49.239  1
447655  99.756  -64.690  49.200  1
447656  99.850  -64.665  49.160  1
447657  99.944  -64.639  49.120  1
447658  100.035  -64.615  49.080  1
447659  100.090  -64.627  49.042  1
447660  100.145  -64.639  49.004  1
447661  100.200  -64.650  48.966  1
447662  100.255  -64.662  48.928  1
447663  100.282  -64.697  48.890  1
447664  100.300  -64.722  48.850  1
447665  100.339  -64.727  48.812  1
447666  100.378  -64.732  48.774  1
447667  100.416  -64.737  48.736  1
447668  100.455  -64.743  48.698  1
447669  100.494  -64.747  48.659  1
447670  100.533  -64.753  48.619  1
447671  100.571  -64.758  48.581  1
447672  100.610  -64.763  48.544  1
447673  100.648  -64.769  48.505  1
448057  87.046  -63.096  55.904  1
448058  87.074  -63.102  55.890  1
448059  87.103  -63.109  55.876  1
448060  87.130  -63.115  55.863  1
448061  87.158  -63.122  55.848  1
448062  87.187  -63.129  55.834  1
448063  87.221  -63.138  55.820  1
448064  87.256  -63.148  55.807  1
448065  87.290  -63.158  55.794  1
448066  87.324  -63.167  55.781  1
448067  87.358  -63.177  55.767  1
448068  87.393  -63.186  55.754  1
448069  87.427  -63.195  55.741  1
448070  87.470  -63.201  55.727  1
448071  87.522  -63.202  55.712  1
448072  87.578  -63.205  55.698  1
448073  87.627  -63.215  55.683  1
448074  87.676  -63.226  55.669  1
448075  87.725  -63.236  55.654  1
448076  87.774  -63.246  55.639  1
448077  87.823  -63.257  55.623  1
448078  87.872  -63.267  55.607  1
448079  87.921  -63.277  55.590  1
448080  87.970  -63.288  55.572  1
448081  88.019  -63.299  55.553  1
448082  88.068  -63.308  55.534  1
448083  88.117  -63.319  55.515  1
448084  88.166  -63.330  55.496  1
448085  88.215  -63.339  55.478  1
448086  88.264  -63.350  55.459  1
448087  88.313  -63.361  55.442  1
448088  88.362  -63.371  55.427  1
448095  88.704  -63.443  55.348  1
448096  88.753  -63.454  55.345  1
448097  88.803  -63.465  55.343  1
448098  88.851  -63.474  55.341  1
448099  88.900  -63.485  55.342  1
448100  88.949  -63.496  55.343  1
448101  88.998  -63.506  55.345  1
448102  89.047  -63.516  55.349  1
448103  89.096  -63.527  55.353  1
448104  89.145  -63.537  55.359  1
448105  89.194  -63.547  55.367  1
448106  89.243  -63.558  55.375  1
448107  89.292  -63.568  55.386  1
448108  89.341  -63.578  55.401  1
448109  89.390  -63.587  55.413  1
448110  89.435  -63.594  55.424  1
448111  89.479  -63.602  55.432  1
448112  89.524  -63.609  55.438  1
448113  89.568  -63.615  55.442  1
448114  89.613  -63.622  55.445  1
448115  89.658  -63.629  55.442  1
448116  89.704  -63.628  55.433  1
448117  89.750  -63.625  55.416  1
448118  89.797  -63.622  55.390  1
448119  89.843  -63.619  55.365  1
448120  89.890  -63.616  55.343  1
448121  89.937  -63.613  55.323  1
448122  89.983  -63.610  55.304  1
448123  90.029  -63.607  55.292  1
448124  90.076  -63.604  55.284  1
448125  90.122  -63.602  55.279  1
448126  90.168  -63.602  55.279  1
448127  90.214  -63.603  55.285  1
448128  90.259  -63.604  55.297  1
448129  90.305  -63.606  55.307  1
448130  90.334  -63.615  55.315  1
448131  90.373  -63.628  55.323  1
448132  90.423  -63.640  55.327  1
448133  90.472  -63.652  55.330  1
448134  90.521  -63.665  55.335  1
448135  90.565  -63.681  55.336  1
448136  90.609  -63.698  55.328  1
448137  90.653  -63.715  55.302  1
448138  90.697  -63.731  55.266  1
448139  90.741  -63.748  55.228  1
448140  90.788  -63.756  55.186  1
448141  90.834  -63.763  55.137  1
448142  90.880  -63.771  55.085  1
448143  90.926  -63.778  55.035  1
448144  90.972  -63.786  54.988  1
448145  91.018  -63.794  54.945  1
448146  91.065  -63.801  54.905  1
448147  91.110  -63.809  54.871  1
448148  91.157  -63.816  54.841  1
448149  91.203  -63.824  54.816  1
448150  91.249  -63.831  54.794  1
448151  91.295  -63.839  54.775  1
448152  91.342  -63.847  54.761  1
448153  91.387  -63.854  54.747  1
448154  91.434  -63.862  54.736  1
448155  91.480  -63.869  54.726  1
448156  91.526  -63.877  54.717  1
448157  91.572  -63.885  54.710  1
448158  91.618  -63.892  54.702  1
448159  91.664  -63.900  54.696  1
448160  91.711  -63.908  54.691  1
448161  91.758  -63.916  54.684  1
448162  91.805  -63.925  54.679  1
448163  91.853  -63.934  54.674  1
448164  91.899  -63.942  54.669  1
448165  91.947  -63.951  54.663  1
448166  91.994  -63.960  54.658  1
448167  92.041  -63.968  54.654  1
448168  92.088  -63.977  54.649  1
448169  92.135  -63.985  54.644  1
448170  92.178  -63.986  54.638  1
448171  92.223  -63.988  54.633  1
448172  92.254  -63.992  54.628  1
448173  92.292  -64.002  54.624  1
448174  92.333  -64.012  54.619  1
448175  92.373  -64.021  54.615  1
448176  92.406  -64.034  54.611  1
448177  92.431  -64.049  54.607  1
448178  92.456  -64.064  54.603  1
448179  92.481  -64.080  54.598  1
448180  92.506  -64.095  54.594  1
448181  92.531  -64.110  54.591  1
448182  92.557  -64.126  54.588  1
448183  92.582  -64.142  54.585  1
448184  92.621  -64.154  54.582  1
448185  92.689  -64.154  54.580  1
448186  92.766  -64.153  54.578  1
448187  92.842  -64.152  54.579  1
448188  92.919  -64.151  54.580  1
448189  92.996  -64.151  54.580  1
448190  93.070  -64.151  54.581  1
448191  93.117  -64.153  54.582  1
448192  93.163  -64.153  54.583  1
448193  93.209  -64.153  54.583  1
448194  93.255  -64.153  54.582  1
448195  93.300  -64.153  54.581  1
448196  93.339  -64.156  54.577  1
448197  93.363  -64.163  54.571  1
448198  93.389  -64.170  54.566  1
448199  93.413  -64.177  54.561  1
448200  93.438  -64.184  54.554  1
448201  93.463  -64.191  54.545  1
448202  93.488  -64.198  54.532  1
448203  93.516  -64.204  54.517  1
448204  93.556  -64.202  54.500  1
448205  93.597  -64.201  54.485  1
448206  93.637  -64.202  54.471  1
448207  93.673  -64.211  54.457  1
448208  93.717  -64.220  54.443  1
448209  93.763  -64.230  54.427  1
448210  93.807  -64.240  54.410  1
448211  93.853  -64.250  54.390  1
448212  93.898  -64.260  54.369  1
448213  93.943  -64.270  54.347  1
448214  93.987  -64.279  54.324  1
448215  94.015  -64.285  54.299  1
448216  94.045  -64.290  54.275  1
448217  94.073  -64.295  54.250  1
448218  94.102  -64.301  54.225  1
448219  94.131  -64.307  54.202  1
448220  94.160  -64.312  54.178  1
448221  94.189  -64.317  54.152  1
448222  94.218  -64.323  54.128  1
448223  94.247  -64.329  54.107  1
448224  94.279  -64.328  54.086  1
448225  94.329  -64.333  54.065  1
448226  94.382  -64.342  54.045  1
448227  94.433  -64.352  54.024  1
448228  94.484  -64.362  54.003  1
448229  94.535  -64.372  53.983  1
448230  94.586  -64.382  53.965  1
448231  94.637  -64.392  53.948  1
448232  94.688  -64.402  53.930  1
448233  94.739  -64.411  53.912  1
448234  94.789  -64.420  53.890  1
448235  94.835  -64.426  53.867  1
448236  94.882  -64.431  53.844  1
448237  94.932  -64.437  53.820  1
448238  94.987  -64.445  53.797  1
448239  95.041  -64.452  53.776  1
448240  95.095  -64.459  53.754  1
448241  95.149  -64.466  53.733  1
448242  95.203  -64.474  53.711  1
448243  95.257  -64.480  53.685  1
448244  95.311  -64.487  53.659  1
448245  95.365  -64.495  53.635  1
448246  95.419  -64.502  53.610  1
448247  95.473  -64.509  53.586  1
448248  95.527  -64.516  53.563  1
448249  95.576  -64.524  53.539  1
448250  95.624  -64.532  53.516  1
448251  95.673  -64.540  53.494  1
448252  95.713  -64.547  53.472  1
448253  95.753  -64.554  53.446  1
448254  95.789  -64.559  53.416  1
448255  95.823  -64.562  53.383  1
448256  95.857  -64.565  53.349  1
448257  95.891  -64.568  53.314  1
448258  95.925  -64.571  53.279  1
448259  95.959  -64.574  53.245  1
448260  95.993  -64.577  53.212  1
448261  96.027  -64.580  53.179  1
448262  96.061  -64.584  53.146  1
448263  96.095  -64.587  53.115  1
448264  96.131  -64.586  53.085  1
448265  96.171  -64.577  53.054  1
448266  96.215  -64.564  53.022  1
448267  96.259  -64.549  52.990  1
448268  96.305  -64.534  52.960  1
448269  96.346  -64.527  52.928  1
448270  96.385  -64.524  52.896  1
448271  96.425  -64.522  52.866  1
448272  96.464  -64.520  52.835  1
448273  96.501  -64.519  52.804  1
448274  96.535  -64.520  52.773  1
448275  96.571  -64.521  52.741  1
448276  96.605  -64.522  52.707  1
448277  96.643  -64.524  52.673  1
448278  96.682  -64.530  52.635  1
448279  96.721  -64.534  52.597  1
448280  96.761  -64.539  52.558  1
448281  96.800  -64.543  52.517  1
448282  96.839  -64.548  52.475  1
448283  96.879  -64.552  52.431  1
448284  96.919  -64.557  52.386  1
448285  96.958  -64.562  52.341  1
448286  96.997  -64.566  52.297  1
448287  97.037  -64.571  52.253  1
448288  97.076  -64.575  52.212  1
448289  97.115  -64.580  52.171  1
448290  97.155  -64.584  52.129  1
448291  97.194  -64.589  52.084  1
448292  97.232  -64.593  52.039  1
448293  97.270  -64.594  51.996  1
448294  97.302  -64.589  51.952  1
448295  97.326  -64.577  51.907  1
448296  97.355  -64.567  51.859  1
448297  97.384  -64.556  51.810  1
448298  97.413  -64.546  51.763  1
448299  97.441  -64.553  51.717  1
448300  97.475  -64.555  51.671  1
448301  97.516  -64.551  51.626  1
448302  97.557  -64.547  51.581  1
448303  97.589  -64.552  51.535  1
448304  97.619  -64.561  51.488  1
448305  97.648  -64.569  51.440  1
448306  97.678  -64.577  51.394  1
448307  97.710  -64.584  51.347  1
448308  97.745  -64.590  51.300  1
448309  97.780  -64.595  51.252  1
448310  97.809  -64.599  51.204  1
448311  97.846  -64.600  51.155  1
448312  97.886  -64.598  51.106  1
448313  97.927  -64.596  51.058  1
448314  97.967  -64.593  51.010  1
448315  98.009  -64.590  50.963  1
448316  98.040  -64.593  50.917  1
448317  98.067  -64.599  50.871  1
448318  98.092  -64.606  50.825  1
448319  98.119  -64.612  50.781  1
448320  98.144  -64.618  50.737  1
448321  98.184  -64.629  50.692  1
448322  98.224  -64.639  50.646  1
448323  98.265  -64.649  50.600  1
448324  98.305  -64.659  50.554  1
448325  98.346  -64.670  50.510  1
448326  98.382  -64.676  50.467  1
448327  98.418  -64.681  50.424  1
448328  98.466  -64.672  50.380  1
448329  98.515  -64.663  50.336  1
448330  98.564  -64.654  50.291  1
448331  98.612  -64.645  50.246  1
448332  98.661  -64.636  50.200  1
448333  98.709  -64.627  50.155  1
448334  98.755  -64.621  50.112  1
448335  98.795  -64.621  50.070  1
448336  98.835  -64.622  50.029  1
448337  98.875  -64.623  49.987  1
448338  98.915  -64.624  49.944  1
448339  98.954  -64.624  49.901  1
448340  98.997  -64.621  49.859  1
448341  99.040  -64.617  49.818  1
448342  99.083  -64.613  49.777  1
448343  99.120  -64.617  49.737  1
448344  99.158  -64.620  49.697  1
448345  99.196  -64.624  49.656  1
448346  99.233  -64.627  49.613  1
448347  99.271  -64.631  49.568  1
448348  99.308  -64.634  49.522  1
448349  99.346  -64.637  49.476  1
448350  99.386  -64.642  49.432  1
448351  99.434  -64.649  49.389  1
448352  99.482  -64.658  49.347  1
448353  99.530  -64.665  49.305  1
448354  99.588  -64.674  49.266  1
448355  99.672  -64.658  49.225  1
448356  99.765  -64.632  49.186  1
448357  99.859  -64.606  49.146  1
448358  99.934  -64.599  49.106  1
448359  99.989  -64.611  49.068  1
448360  100.044  -64.622  49.031  1
448361  100.099  -64.634  48.993  1
448362  100.154  -64.646  48.955  1
448363  100.209  -64.657  48.918  1
448364  100.264  -64.669  48.879  1
448365  100.310  -64.679  48.840  1
448366  100.349  -64.684  48.802  1
448367  100.388  -64.690  48.765  1
448368  100.426  -64.694  48.728  1
448369  100.465  -64.700  48.689  1
448370  100.504  -64.705  48.651  1
448371  100.542  -64.710  48.612  1
448372  100.581  -64.715  48.574  1
448373  100.620  -64.721  48.537  1
448374  100.658  -64.726  48.500  1
448758  87.050  -63.054  55.910  1
448759  87.078  -63.060  55.896  1
448760  87.107  -63.067  55.883  1
448761  87.134  -63.073  55.869  1
448762  87.162  -63.079  55.855  1
448763  87.191  -63.086  55.841  1
448764  87.219  -63.092  55.826  1
448765  87.248  -63.099  55.813  1
448766  87.282  -63.109  55.800  1
448767  87.316  -63.118  55.788  1
448768  87.350  -63.128  55.775  1
448769  87.385  -63.138  55.762  1
448770  87.426  -63.144  55.751  1
448771  87.482  -63.145  55.738  1
448772  87.531  -63.155  55.723  1
448773  87.580  -63.165  55.709  1
448774  87.629  -63.176  55.694  1
448775  87.678  -63.186  55.679  1
448776  87.727  -63.196  55.665  1
448777  87.776  -63.207  55.650  1
448778  87.825  -63.217  55.634  1
448779  87.873  -63.227  55.618  1
448780  87.923  -63.238  55.601  1
448781  87.972  -63.249  55.583  1
448782  88.021  -63.259  55.565  1
448783  88.069  -63.269  55.546  1
448784  88.118  -63.280  55.527  1
448785  88.168  -63.290  55.508  1
448786  88.216  -63.300  55.489  1
448787  88.265  -63.311  55.470  1
448788  88.314  -63.321  55.452  1
448789  88.363  -63.331  55.436  1
448790  88.412  -63.342  55.419  1
448791  88.461  -63.352  55.403  1
448795  88.660  -63.391  55.359  1
448796  88.710  -63.400  55.353  1
448797  88.761  -63.409  55.349  1
448798  88.811  -63.418  55.346  1
448799  88.861  -63.427  55.345  1
448800  88.912  -63.436  55.346  1
448801  88.963  -63.445  55.346  1
448802  89.013  -63.454  55.348  1
448803  89.063  -63.463  55.352  1
448804  89.114  -63.471  55.355  1
448805  89.165  -63.480  55.361  1
448806  89.215  -63.490  55.367  1
448807  89.265  -63.499  55.374  1
448808  89.309  -63.514  55.383  1
448809  89.351  -63.529  55.397  1
448810  89.400  -63.533  55.410  1
448811  89.446  -63.544  55.422  1
448812  89.491  -63.552  55.431  1
448813  89.536  -63.559  55.437  1
448814  89.581  -63.566  55.441  1
448815  89.625  -63.573  55.442  1
448816  89.670  -63.580  55.439  1
448817  89.717  -63.577  55.430  1
448818  89.763  -63.574  55.414  1
448819  89.810  -63.571  55.390  1
448820  89.856  -63.568  55.367  1
448821  89.903  -63.565  55.347  1
448822  89.949  -63.562  55.328  1
448823  89.996  -63.559  55.309  1
448824  90.042  -63.558  55.296  1
448825  90.087  -63.559  55.289  1
448826  90.132  -63.560  55.286  1
448827  90.178  -63.562  55.288  1
448828  90.224  -63.563  55.300  1
448829  90.269  -63.565  55.312  1
448830  90.314  -63.565  55.322  1
448831  90.334  -63.581  55.328  1
448832  90.368  -63.595  55.332  1
448833  90.417  -63.606  55.333  1
448834  90.467  -63.618  55.332  1
448835  90.517  -63.630  55.335  1
448836  90.567  -63.641  55.338  1
448837  90.615  -63.654  55.333  1
448838  90.659  -63.671  55.306  1
448839  90.704  -63.687  55.273  1
448840  90.748  -63.704  55.238  1
448841  90.794  -63.712  55.197  1
448842  90.840  -63.719  55.148  1
448843  90.886  -63.727  55.093  1
448844  90.932  -63.734  55.038  1
448845  90.978  -63.742  54.987  1
448846  91.025  -63.750  54.943  1
448847  91.071  -63.757  54.903  1
448848  91.117  -63.765  54.868  1
448849  91.163  -63.772  54.838  1
448850  91.209  -63.780  54.812  1
448851  91.255  -63.788  54.790  1
448852  91.301  -63.795  54.771  1
448853  91.348  -63.803  54.757  1
448854  91.395  -63.812  54.743  1
448855  91.442  -63.820  54.732  1
448856  91.490  -63.828  54.723  1
448857  91.536  -63.838  54.715  1
448858  91.584  -63.846  54.707  1
448859  91.631  -63.855  54.700  1
448860  91.678  -63.863  54.694  1
448861  91.725  -63.872  54.690  1
448862  91.772  -63.881  54.684  1
448863  91.819  -63.889  54.679  1
448864  91.866  -63.898  54.674  1
448865  91.914  -63.907  54.670  1
448866  91.960  -63.915  54.665  1
448867  92.008  -63.924  54.660  1
448868  92.055  -63.932  54.655  1
448869  92.100  -63.938  54.650  1
448870  92.143  -63.938  54.645  1
448871  92.187  -63.938  54.639  1
448872  92.232  -63.941  54.634  1
448873  92.267  -63.946  54.629  1
448874  92.293  -63.953  54.624  1
448875  92.333  -63.963  54.620  1
448876  92.374  -63.973  54.616  1
448877  92.406  -63.985  54.612  1
448878  92.431  -64.001  54.609  1
448879  92.456  -64.016  54.604  1
448880  92.482  -64.032  54.600  1
448881  92.506  -64.047  54.596  1
448882  92.531  -64.062  54.595  1
448883  92.557  -64.078  54.592  1
448884  92.605  -64.089  54.589  1
448885  92.666  -64.093  54.587  1
448886  92.733  -64.094  54.585  1
448887  92.800  -64.095  54.585  1
448888  92.867  -64.095  54.585  1
448889  92.935  -64.095  54.586  1
448890  93.012  -64.095  54.588  1
448891  93.075  -64.095  54.589  1
448892  93.121  -64.095  54.589  1
448893  93.167  -64.095  54.590  1
448894  93.213  -64.095  54.590  1
448895  93.259  -64.095  54.588  1
448896  93.304  -64.095  54.584  1
448897  93.337  -64.100  54.579  1
448898  93.362  -64.107  54.571  1
448899  93.387  -64.114  54.564  1
448900  93.412  -64.121  54.558  1
448901  93.437  -64.128  54.548  1
448902  93.462  -64.135  54.537  1
448903  93.486  -64.142  54.523  1
448904  93.511  -64.149  54.505  1
448905  93.547  -64.151  54.487  1
448906  93.587  -64.149  54.468  1
448907  93.626  -64.154  54.452  1
448908  93.669  -64.164  54.436  1
448909  93.714  -64.174  54.419  1
448910  93.759  -64.184  54.401  1
448911  93.804  -64.194  54.384  1
448912  93.849  -64.203  54.364  1
448913  93.895  -64.213  54.343  1
448914  93.939  -64.223  54.321  1
448915  93.979  -64.231  54.297  1
448916  94.008  -64.236  54.273  1
448917  94.037  -64.242  54.249  1
448918  94.065  -64.248  54.226  1
448919  94.095  -64.253  54.202  1
448920  94.123  -64.258  54.180  1
448921  94.152  -64.264  54.156  1
448922  94.181  -64.270  54.131  1
448923  94.210  -64.275  54.108  1
448924  94.239  -64.281  54.088  1
448925  94.269  -64.284  54.068  1
448926  94.319  -64.290  54.047  1
448927  94.369  -64.300  54.026  1
448928  94.420  -64.310  54.004  1
448929  94.472  -64.320  53.982  1
448930  94.523  -64.330  53.961  1
448931  94.573  -64.339  53.943  1
448932  94.625  -64.349  53.925  1
448933  94.676  -64.359  53.908  1
448934  94.726  -64.369  53.891  1
448935  94.777  -64.379  53.869  1
448936  94.824  -64.384  53.847  1
448937  94.874  -64.391  53.825  1
448938  94.928  -64.398  53.801  1
448939  94.982  -64.405  53.778  1
448940  95.036  -64.412  53.758  1
448941  95.090  -64.419  53.738  1
448942  95.144  -64.427  53.717  1
448943  95.198  -64.433  53.695  1
448944  95.252  -64.441  53.672  1
448945  95.307  -64.448  53.647  1
448946  95.360  -64.455  53.624  1
448947  95.414  -64.462  53.600  1
448948  95.469  -64.469  53.576  1
448949  95.523  -64.477  53.552  1
448950  95.577  -64.483  53.530  1
448951  95.630  -64.491  53.508  1
448952  95.679  -64.499  53.487  1
448953  95.724  -64.506  53.466  1
448954  95.763  -64.512  53.441  1
448955  95.797  -64.515  53.410  1
448956  95.831  -64.519  53.378  1
448957  95.865  -64.522  53.344  1
448958  95.899  -64.525  53.308  1
448959  95.933  -64.528  53.270  1
448960  95.967  -64.531  53.233  1
448961  96.001  -64.534  53.197  1
448962  96.035  -64.537  53.163  1
448963  96.068  -64.540  53.131  1
448964  96.103  -64.543  53.099  1
448965  96.136  -64.546  53.069  1
448966  96.174  -64.544  53.038  1
448967  96.217  -64.531  53.004  1
448968  96.262  -64.517  52.974  1
448969  96.307  -64.502  52.945  1
448970  96.352  -64.488  52.916  1
448971  96.392  -64.483  52.889  1
448972  96.431  -64.481  52.862  1
448973  96.470  -64.479  52.834  1
448974  96.505  -64.480  52.805  1
448975  96.539  -64.481  52.775  1
448976  96.575  -64.482  52.744  1
448977  96.609  -64.483  52.712  1
448978  96.646  -64.485  52.678  1
448979  96.685  -64.490  52.640  1
448980  96.725  -64.494  52.601  1
448981  96.764  -64.499  52.561  1
448982  96.803  -64.503  52.518  1
448983  96.843  -64.508  52.475  1
448984  96.882  -64.512  52.430  1
448985  96.922  -64.517  52.384  1
448986  96.961  -64.521  52.337  1
448987  97.001  -64.526  52.292  1
448988  97.040  -64.530  52.249  1
448989  97.080  -64.536  52.209  1
448990  97.119  -64.540  52.169  1
448991  97.158  -64.545  52.126  1
448992  97.198  -64.549  52.081  1
448993  97.237  -64.554  52.035  1
448994  97.277  -64.558  51.991  1
448995  97.305  -64.547  51.946  1
448996  97.334  -64.537  51.900  1
448997  97.363  -64.525  51.852  1
448998  97.391  -64.515  51.803  1
448999  97.420  -64.510  51.756  1
449000  97.448  -64.517  51.710  1
449001  97.476  -64.524  51.665  1
449002  97.516  -64.521  51.619  1
449003  97.557  -64.517  51.575  1
449004  97.598  -64.512  51.529  1
449005  97.639  -64.508  51.482  1
449006  97.671  -64.514  51.435  1
449007  97.701  -64.522  51.388  1
449008  97.730  -64.530  51.343  1
449009  97.760  -64.540  51.296  1
449010  97.789  -64.548  51.248  1
449011  97.823  -64.552  51.200  1
449012  97.864  -64.549  51.151  1
449013  97.905  -64.546  51.101  1
449014  97.946  -64.543  51.051  1
449015  97.987  -64.541  51.003  1
449016  98.017  -64.545  50.955  1
449017  98.043  -64.552  50.907  1
449018  98.069  -64.558  50.860  1
449019  98.095  -64.565  50.813  1
449020  98.121  -64.571  50.767  1
449021  98.147  -64.577  50.722  1
449022  98.183  -64.587  50.676  1
449023  98.223  -64.597  50.630  1
449024  98.264  -64.607  50.583  1
449025  98.304  -64.618  50.537  1
449026  98.345  -64.627  50.492  1
449027  98.385  -64.638  50.449  1
449028  98.425  -64.646  50.407  1
449029  98.474  -64.637  50.363  1
449030  98.522  -64.628  50.319  1
449031  98.571  -64.619  50.274  1
449032  98.619  -64.610  50.229  1
449033  98.668  -64.601  50.184  1
449034  98.717  -64.592  50.140  1
449035  98.765  -64.583  50.098  1
449036  98.814  -64.574  50.057  1
449037  98.855  -64.572  50.016  1
449038  98.896  -64.573  49.972  1
449039  98.935  -64.574  49.928  1
449040  98.976  -64.574  49.885  1
449041  99.018  -64.570  49.842  1
449042  99.060  -64.567  49.801  1
449043  99.098  -64.571  49.759  1
449044  99.136  -64.574  49.718  1
449045  99.173  -64.577  49.678  1
449046  99.211  -64.580  49.636  1
449047  99.249  -64.584  49.592  1
449048  99.286  -64.588  49.548  1
449049  99.324  -64.591  49.502  1
449050  99.361  -64.595  49.458  1
449051  99.399  -64.598  49.414  1
449052  99.436  -64.602  49.372  1
449053  99.483  -64.609  49.330  1
449054  99.531  -64.617  49.290  1
449055  99.587  -64.624  49.251  1
449056  99.681  -64.599  49.212  1
449057  99.775  -64.574  49.172  1
449058  99.833  -64.582  49.132  1
449059  99.888  -64.594  49.093  1
449060  99.943  -64.606  49.055  1
449061  99.998  -64.618  49.018  1
449062  100.058  -64.627  48.981  1
449063  100.129  -64.633  48.944  1
449064  100.200  -64.637  48.906  1
449065  100.267  -64.639  48.869  1
449066  100.310  -64.643  48.830  1
449067  100.346  -64.650  48.793  1
449068  100.382  -64.658  48.756  1
449069  100.419  -64.664  48.718  1
449070  100.459  -64.668  48.681  1
449071  100.498  -64.673  48.643  1
449072  100.537  -64.678  48.604  1
449073  100.577  -64.683  48.567  1
449074  100.616  -64.687  48.531  1
449075  100.655  -64.692  48.494  1
449459  87.054  -63.011  55.916  1
449460  87.082  -63.017  55.903  1
449461  87.110  -63.024  55.890  1
449462  87.138  -63.030  55.876  1
449463  87.166  -63.037  55.863  1
449464  87.195  -63.043  55.849  1
449465  87.223  -63.050  55.833  1
449466  87.251  -63.057  55.820  1
449467  87.279  -63.063  55.807  1
449468  87.308  -63.070  55.796  1
449469  87.342  -63.079  55.784  1
449470  87.385  -63.086  55.773  1
449471  87.434  -63.095  55.764  1
449472  87.484  -63.105  55.751  1
449473  87.533  -63.116  55.737  1
449474  87.581  -63.126  55.721  1
449475  87.630  -63.136  55.704  1
449476  87.679  -63.147  55.689  1
449477  87.728  -63.157  55.674  1
449478  87.777  -63.167  55.659  1
449479  87.827  -63.177  55.644  1
449480  87.877  -63.186  55.628  1
449481  87.928  -63.195  55.612  1
449482  87.978  -63.205  55.594  1
449483  88.029  -63.213  55.576  1
449484  88.079  -63.222  55.558  1
449485  88.130  -63.231  55.539  1
449486  88.180  -63.240  55.519  1
449487  88.231  -63.249  55.500  1
449488  88.281  -63.258  55.481  1
449489  88.332  -63.267  55.462  1
449490  88.382  -63.276  55.445  1
449491  88.433  -63.285  55.427  1
449492  88.483  -63.293  55.412  1
449493  88.534  -63.302  55.398  1
449496  88.685  -63.330  55.365  1
449497  88.736  -63.338  55.358  1
449498  88.786  -63.347  55.354  1
449499  88.837  -63.356  55.351  1
449500  88.887  -63.365  55.349  1
449501  88.937  -63.374  55.349  1
449502  88.988  -63.383  55.350  1
449503  89.039  -63.392  55.352  1
449504  89.089  -63.401  55.355  1
449505  89.139  -63.410  55.358  1
449506  89.186  -63.422  55.362  1
449507  89.229  -63.437  55.366  1
449508  89.271  -63.452  55.372  1
449509  89.314  -63.468  55.380  1
449510  89.356  -63.484  55.391  1
449511  89.409  -63.477  55.405  1
449512  89.456  -63.489  55.419  1
449513  89.502  -63.500  55.429  1
449514  89.548  -63.509  55.437  1
449515  89.593  -63.517  55.440  1
449516  89.638  -63.524  55.441  1
449517  89.683  -63.528  55.437  1
449518  89.730  -63.524  55.427  1
449519  89.776  -63.521  55.411  1
449520  89.822  -63.519  55.388  1
449521  89.869  -63.516  55.367  1
449522  89.915  -63.514  55.347  1
449523  89.961  -63.515  55.328  1
449524  90.006  -63.516  55.310  1
449525  90.051  -63.518  55.298  1
449526  90.097  -63.519  55.291  1
449527  90.143  -63.521  55.290  1
449528  90.188  -63.521  55.294  1
449529  90.233  -63.523  55.310  1
449530  90.279  -63.524  55.324  1
449531  90.320  -63.528  55.335  1
449532  90.333  -63.546  55.341  1
449533  90.363  -63.561  55.342  1
449534  90.413  -63.573  55.339  1
449535  90.462  -63.584  55.334  1
449536  90.512  -63.596  55.333  1
449537  90.562  -63.607  55.336  1
449538  90.611  -63.619  55.335  1
449539  90.661  -63.631  55.310  1
449540  90.710  -63.643  55.283  1
449541  90.754  -63.659  55.250  1
449542  90.800  -63.668  55.210  1
449543  90.847  -63.675  55.159  1
449544  90.892  -63.683  55.099  1
449545  90.939  -63.690  55.040  1
449546  90.985  -63.698  54.986  1
449547  91.032  -63.707  54.940  1
449548  91.079  -63.715  54.900  1
449549  91.127  -63.724  54.865  1
449550  91.173  -63.733  54.835  1
449551  91.221  -63.741  54.808  1
449552  91.267  -63.750  54.786  1
449553  91.315  -63.759  54.768  1
449554  91.362  -63.767  54.754  1
449555  91.409  -63.776  54.741  1
449556  91.456  -63.784  54.729  1
449557  91.503  -63.793  54.720  1
449558  91.551  -63.802  54.713  1
449559  91.597  -63.810  54.707  1
449560  91.645  -63.819  54.700  1
449561  91.692  -63.828  54.695  1
449562  91.739  -63.836  54.690  1
449563  91.786  -63.845  54.685  1
449564  91.833  -63.853  54.681  1
449565  91.880  -63.862  54.676  1
449566  91.927  -63.871  54.672  1
449567  91.975  -63.879  54.667  1
449568  92.021  -63.888  54.662  1
449569  92.066  -63.890  54.657  1
449570  92.108  -63.890  54.652  1
449571  92.151  -63.889  54.647  1
449572  92.195  -63.889  54.642  1
449573  92.241  -63.895  54.636  1
449574  92.280  -63.900  54.631  1
449575  92.299  -63.905  54.626  1
449576  92.334  -63.914  54.622  1
449577  92.374  -63.923  54.619  1
449578  92.406  -63.937  54.615  1
449579  92.431  -63.952  54.611  1
449580  92.456  -63.967  54.607  1
449581  92.482  -63.983  54.604  1
449582  92.507  -63.998  54.600  1
449583  92.543  -64.012  54.598  1
449584  92.593  -64.023  54.597  1
449585  92.645  -64.032  54.594  1
449586  92.712  -64.033  54.592  1
449587  92.779  -64.033  54.591  1
449588  92.846  -64.034  54.591  1
449589  92.913  -64.035  54.591  1
449590  92.980  -64.035  54.592  1
449591  93.039  -64.038  54.595  1
449592  93.080  -64.038  54.595  1
449593  93.126  -64.037  54.596  1
449594  93.171  -64.037  54.596  1
449595  93.217  -64.037  54.595  1
449596  93.263  -64.037  54.591  1
449597  93.309  -64.038  54.587  1
449598  93.336  -64.044  54.580  1
449599  93.360  -64.051  54.572  1
449600  93.386  -64.058  54.563  1
449601  93.410  -64.065  54.556  1
449602  93.435  -64.072  54.544  1
449603  93.460  -64.079  54.531  1
449604  93.485  -64.086  54.515  1
449605  93.510  -64.093  54.496  1
449606  93.538  -64.098  54.476  1
449607  93.578  -64.098  54.454  1
449608  93.620  -64.107  54.434  1
449609  93.665  -64.117  54.414  1
449610  93.710  -64.127  54.395  1
449611  93.755  -64.137  54.376  1
449612  93.800  -64.147  54.357  1
449613  93.846  -64.157  54.337  1
449614  93.891  -64.167  54.316  1
449615  93.936  -64.176  54.294  1
449616  93.971  -64.183  54.271  1
449617  94.000  -64.189  54.247  1
449618  94.029  -64.194  54.224  1
449619  94.058  -64.200  54.201  1
449620  94.086  -64.205  54.178  1
449621  94.115  -64.211  54.155  1
449622  94.144  -64.217  54.132  1
449623  94.173  -64.222  54.109  1
449624  94.202  -64.227  54.087  1
449625  94.231  -64.233  54.070  1
449626  94.262  -64.240  54.049  1
449627  94.309  -64.249  54.029  1
449628  94.358  -64.258  54.007  1
449629  94.408  -64.268  53.984  1
449630  94.459  -64.278  53.961  1
449631  94.510  -64.288  53.940  1
449632  94.561  -64.298  53.921  1
449633  94.612  -64.308  53.903  1
449634  94.663  -64.317  53.886  1
449635  94.714  -64.327  53.870  1
449636  94.765  -64.337  53.849  1
449637  94.816  -64.344  53.828  1
449638  94.870  -64.351  53.806  1
449639  94.924  -64.358  53.783  1
449640  94.978  -64.365  53.760  1
449641  95.032  -64.372  53.740  1
449642  95.086  -64.380  53.720  1
449643  95.140  -64.386  53.700  1
449644  95.194  -64.394  53.679  1
449645  95.248  -64.401  53.657  1
449646  95.302  -64.408  53.634  1
449647  95.356  -64.415  53.612  1
449648  95.410  -64.422  53.589  1
449649  95.464  -64.430  53.565  1
449650  95.518  -64.436  53.543  1
449651  95.572  -64.444  53.521  1
449652  95.626  -64.451  53.500  1
449653  95.680  -64.458  53.479  1
449654  95.734  -64.465  53.459  1
449655  95.770  -64.470  53.433  1
449656  95.805  -64.473  53.402  1
449657  95.838  -64.476  53.370  1
449658  95.873  -64.479  53.336  1
449659  95.906  -64.482  53.300  1
449660  95.941  -64.485  53.263  1
449661  95.974  -64.488  53.225  1
449662  96.009  -64.491  53.190  1
449663  96.042  -64.495  53.156  1
449664  96.077  -64.498  53.124  1
449665  96.110  -64.501  53.093  1
449666  96.145  -64.504  53.062  1
449667  96.178  -64.507  53.031  1
449668  96.219  -64.499  53.000  1
449669  96.264  -64.485  52.972  1
449670  96.309  -64.470  52.945  1
449671  96.354  -64.455  52.918  1
449672  96.398  -64.443  52.892  1
449673  96.437  -64.440  52.867  1
449674  96.474  -64.439  52.838  1
449675  96.509  -64.441  52.807  1
449676  96.543  -64.442  52.778  1
449677  96.578  -64.443  52.749  1
449678  96.613  -64.443  52.719  1
449679  96.649  -64.446  52.685  1
449680  96.688  -64.450  52.647  1
449681  96.728  -64.455  52.607  1
449682  96.767  -64.459  52.565  1
449683  96.807  -64.464  52.520  1
449684  96.846  -64.468  52.475  1
449685  96.886  -64.473  52.429  1
449686  96.925  -64.477  52.381  1
449687  96.964  -64.482  52.334  1
449688  97.004  -64.486  52.289  1
449689  97.043  -64.491  52.247  1
449690  97.083  -64.496  52.207  1
449691  97.123  -64.499  52.167  1
449692  97.163  -64.503  52.124  1
449693  97.203  -64.507  52.077  1
449694  97.242  -64.511  52.032  1
449695  97.283  -64.515  51.987  1
449696  97.312  -64.505  51.941  1
449697  97.341  -64.495  51.893  1
449698  97.370  -64.484  51.845  1
449699  97.398  -64.474  51.798  1
449700  97.427  -64.474  51.752  1
449701  97.455  -64.480  51.706  1
449702  97.484  -64.487  51.660  1
449703  97.517  -64.490  51.614  1
449704  97.558  -64.486  51.570  1
449705  97.598  -64.482  51.523  1
449706  97.639  -64.478  51.476  1
449707  97.680  -64.474  51.429  1
449708  97.721  -64.470  51.383  1
449709  97.753  -64.475  51.337  1
449710  97.783  -64.483  51.291  1
449711  97.812  -64.493  51.244  1
449712  97.843  -64.500  51.196  1
449713  97.883  -64.497  51.146  1
449714  97.925  -64.494  51.095  1
449715  97.965  -64.492  51.045  1
449716  97.993  -64.497  50.995  1
449717  98.019  -64.504  50.947  1
449718  98.045  -64.510  50.899  1
449719  98.071  -64.517  50.850  1
449720  98.097  -64.523  50.802  1
449721  98.123  -64.530  50.755  1
449722  98.149  -64.536  50.709  1
449723  98.182  -64.544  50.662  1
449724  98.223  -64.555  50.615  1
449725  98.263  -64.565  50.569  1
449726  98.303  -64.575  50.523  1
449727  98.344  -64.586  50.477  1
449728  98.384  -64.596  50.433  1
449729  98.430  -64.597  50.391  1
449730  98.479  -64.591  50.348  1
449731  98.528  -64.585  50.304  1
449732  98.577  -64.578  50.258  1
449733  98.626  -64.572  50.213  1
449734  98.675  -64.566  50.168  1
449735  98.724  -64.557  50.125  1
449736  98.772  -64.548  50.083  1
449737  98.821  -64.539  50.042  1
449738  98.869  -64.530  50.000  1
449739  98.916  -64.523  49.956  1
449740  98.956  -64.524  49.912  1
449741  98.997  -64.522  49.868  1
449742  99.038  -64.521  49.825  1
449743  99.075  -64.524  49.782  1
449744  99.113  -64.528  49.740  1
449745  99.151  -64.531  49.698  1
449746  99.188  -64.535  49.657  1
449747  99.226  -64.538  49.615  1
449748  99.264  -64.542  49.572  1
449749  99.301  -64.545  49.527  1
449750  99.339  -64.549  49.483  1
449751  99.376  -64.552  49.440  1
449752  99.414  -64.555  49.397  1
449753  99.451  -64.559  49.355  1
449754  99.489  -64.562  49.314  1
449755  99.533  -64.568  49.274  1
449756  99.596  -64.568  49.237  1
449757  99.678  -64.554  49.198  1
449758  99.732  -64.566  49.158  1
449759  99.791  -64.576  49.119  1
449760  99.863  -64.581  49.081  1
449761  99.934  -64.587  49.043  1
449762  100.005  -64.592  49.006  1
449763  100.076  -64.596  48.968  1
449764  100.147  -64.602  48.932  1
449765  100.212  -64.602  48.895  1
449766  100.274  -64.600  48.857  1
449767  100.311  -64.606  48.819  1
449768  100.346  -64.614  48.783  1
449769  100.382  -64.621  48.746  1
449770  100.418  -64.629  48.709  1
449771  100.454  -64.637  48.672  1
449772  100.489  -64.644  48.635  1
449773  100.528  -64.649  48.597  1
449774  100.567  -64.654  48.560  1
449775  100.606  -64.659  48.525  1
449776  100.645  -64.664  48.487  1
450160  87.058  -62.968  55.925  1
450161  87.086  -62.975  55.912  1
450162  87.114  -62.982  55.898  1
450163  87.142  -62.988  55.884  1
450164  87.170  -62.995  55.871  1
450165  87.199  -63.001  55.857  1
450166  87.227  -63.007  55.843  1
450167  87.255  -63.014  55.827  1
450168  87.283  -63.020  55.814  1
450169  87.311  -63.027  55.803  1
450170  87.348  -63.029  55.794  1
450171  87.398  -63.035  55.785  1
450172  87.448  -63.044  55.776  1
450173  87.499  -63.053  55.764  1
450174  87.549  -63.062  55.750  1
450175  87.600  -63.070  55.734  1
450176  87.650  -63.079  55.716  1
450177  87.701  -63.089  55.699  1
450178  87.751  -63.098  55.683  1
450179  87.802  -63.107  55.668  1
450180  87.852  -63.115  55.653  1
450181  87.903  -63.124  55.637  1
450182  87.954  -63.133  55.621  1
450183  88.004  -63.142  55.604  1
450184  88.054  -63.151  55.587  1
450185  88.105  -63.160  55.568  1
450186  88.155  -63.169  55.550  1
450187  88.206  -63.178  55.531  1
450188  88.256  -63.187  55.512  1
450189  88.307  -63.195  55.492  1
450190  88.357  -63.205  55.472  1
450191  88.408  -63.214  55.453  1
450192  88.458  -63.223  55.436  1
450193  88.509  -63.232  55.420  1
450194  88.559  -63.240  55.406  1
450195  88.610  -63.249  55.392  1
450197  88.711  -63.267  55.371  1
450198  88.761  -63.277  55.364  1
450199  88.812  -63.285  55.359  1
450200  88.862  -63.294  55.355  1
450201  88.913  -63.303  55.354  1
450202  88.963  -63.312  55.353  1
450203  89.014  -63.321  55.354  1
450204  89.063  -63.331  55.355  1
450205  89.106  -63.346  55.358  1
450206  89.148  -63.361  55.360  1
450207  89.191  -63.377  55.363  1
450208  89.233  -63.392  55.367  1
450209  89.276  -63.407  55.371  1
450210  89.318  -63.422  55.376  1
450211  89.365  -63.431  55.386  1
450212  89.419  -63.423  55.400  1
450213  89.466  -63.434  55.415  1
450214  89.512  -63.445  55.427  1
450215  89.559  -63.456  55.435  1
450216  89.605  -63.467  55.438  1
450217  89.650  -63.474  55.439  1
450218  89.696  -63.476  55.435  1
450219  89.742  -63.473  55.424  1
450220  89.789  -63.470  55.406  1
450221  89.834  -63.471  55.385  1
450222  89.880  -63.472  55.364  1
450223  89.925  -63.474  55.344  1
450224  89.970  -63.475  55.326  1
450225  90.016  -63.477  55.310  1
450226  90.061  -63.477  55.299  1
450227  90.107  -63.479  55.292  1
450228  90.152  -63.480  55.292  1
450229  90.197  -63.482  55.297  1
450230  90.243  -63.483  55.313  1
450231  90.289  -63.484  55.329  1
450232  90.319  -63.493  55.342  1
450233  90.333  -63.512  55.349  1
450234  90.358  -63.528  55.350  1
450235  90.408  -63.539  55.345  1
450236  90.457  -63.550  55.337  1
450237  90.507  -63.562  55.333  1
450238  90.557  -63.574  55.333  1
450239  90.606  -63.585  55.330  1
450240  90.656  -63.596  55.312  1
450241  90.706  -63.609  55.286  1
450242  90.758  -63.619  55.254  1
450243  90.810  -63.628  55.216  1
450244  90.858  -63.637  55.162  1
450245  90.904  -63.645  55.098  1
450246  90.952  -63.654  55.038  1
450247  90.999  -63.662  54.984  1
450248  91.046  -63.671  54.938  1
450249  91.093  -63.680  54.897  1
450250  91.140  -63.688  54.862  1
450251  91.187  -63.697  54.831  1
450252  91.234  -63.706  54.805  1
450253  91.282  -63.714  54.783  1
450254  91.328  -63.723  54.766  1
450255  91.376  -63.731  54.751  1
450256  91.423  -63.740  54.739  1
450257  91.470  -63.749  54.728  1
450258  91.517  -63.757  54.719  1
450259  91.564  -63.766  54.713  1
450260  91.611  -63.775  54.707  1
450261  91.658  -63.783  54.701  1
450262  91.706  -63.792  54.695  1
450263  91.752  -63.800  54.691  1
450264  91.800  -63.809  54.687  1
450265  91.847  -63.818  54.683  1
450266  91.894  -63.826  54.679  1
450267  91.941  -63.835  54.675  1
450268  91.988  -63.842  54.671  1
450269  92.030  -63.841  54.667  1
450270  92.073  -63.841  54.662  1
450271  92.117  -63.841  54.656  1
450272  92.159  -63.841  54.650  1
450273  92.204  -63.843  54.644  1
450274  92.250  -63.848  54.638  1
450275  92.292  -63.854  54.634  1
450276  92.312  -63.859  54.630  1
450277  92.335  -63.865  54.626  1
450278  92.375  -63.875  54.623  1
450279  92.407  -63.888  54.619  1
450280  92.431  -63.904  54.615  1
450281  92.456  -63.919  54.611  1
450282  92.482  -63.934  54.608  1
450283  92.530  -63.945  54.605  1
450284  92.580  -63.957  54.602  1
450285  92.630  -63.968  54.601  1
450286  92.691  -63.973  54.601  1
450287  92.758  -63.973  54.598  1
450288  92.824  -63.973  54.597  1
450289  92.891  -63.974  54.598  1
450290  92.958  -63.974  54.598  1
450291  93.009  -63.980  54.598  1
450292  93.048  -63.986  54.600  1
450293  93.087  -63.986  54.601  1
450294  93.132  -63.984  54.601  1
450295  93.176  -63.981  54.600  1
450296  93.221  -63.979  54.598  1
450297  93.267  -63.979  54.594  1
450298  93.309  -63.981  54.589  1
450299  93.334  -63.988  54.582  1
450300  93.359  -63.995  54.573  1
450301  93.383  -64.002  54.563  1
450302  93.409  -64.009  54.553  1
450303  93.433  -64.016  54.540  1
450304  93.459  -64.023  54.525  1
450305  93.483  -64.030  54.507  1
450306  93.508  -64.038  54.487  1
450307  93.533  -64.045  54.465  1
450308  93.571  -64.051  54.442  1
450309  93.616  -64.061  54.419  1
450310  93.661  -64.071  54.396  1
450311  93.706  -64.080  54.375  1
450312  93.752  -64.090  54.353  1
450313  93.797  -64.100  54.332  1
450314  93.842  -64.110  54.310  1
450315  93.887  -64.120  54.289  1
450316  93.932  -64.129  54.266  1
450317  93.963  -64.135  54.244  1
450318  93.992  -64.141  54.220  1
450319  94.020  -64.146  54.197  1
450320  94.050  -64.152  54.175  1
450321  94.078  -64.157  54.152  1
450322  94.107  -64.163  54.130  1
450323  94.136  -64.168  54.107  1
450324  94.165  -64.174  54.085  1
450325  94.194  -64.179  54.065  1
450326  94.247  -64.203  54.049  1
450327  94.294  -64.220  54.029  1
450328  94.322  -64.214  54.008  1
450329  94.372  -64.223  53.986  1
450330  94.422  -64.233  53.964  1
450331  94.472  -64.242  53.941  1
450332  94.521  -64.251  53.921  1
450333  94.571  -64.261  53.902  1
450334  94.621  -64.270  53.883  1
450335  94.671  -64.280  53.865  1
450336  94.720  -64.290  53.848  1
450337  94.769  -64.296  53.830  1
450338  94.821  -64.301  53.810  1
450339  94.875  -64.308  53.789  1
450340  94.929  -64.315  53.765  1
450341  94.984  -64.322  53.742  1
450342  95.038  -64.330  53.722  1
450343  95.092  -64.336  53.702  1
450344  95.146  -64.343  53.683  1
450345  95.200  -64.351  53.663  1
450346  95.255  -64.358  53.642  1
450347  95.309  -64.365  53.620  1
450348  95.363  -64.372  53.599  1
450349  95.417  -64.379  53.577  1
450350  95.471  -64.386  53.554  1
450351  95.526  -64.393  53.534  1
450352  95.580  -64.400  53.512  1
450353  95.634  -64.408  53.490  1
450354  95.688  -64.414  53.470  1
450355  95.733  -64.421  53.450  1
450356  95.765  -64.419  53.423  1
450357  95.799  -64.422  53.392  1
450358  95.833  -64.425  53.359  1
450359  95.867  -64.428  53.326  1
450360  95.901  -64.431  53.291  1
450361  95.935  -64.434  53.256  1
450362  95.969  -64.437  53.220  1
450363  96.003  -64.440  53.185  1
450364  96.037  -64.444  53.152  1
450365  96.071  -64.447  53.120  1
450366  96.105  -64.450  53.088  1
450367  96.139  -64.453  53.057  1
450368  96.176  -64.449  53.027  1
450369  96.221  -64.441  52.999  1
450370  96.265  -64.433  52.974  1
450371  96.311  -64.425  52.949  1
450372  96.356  -64.418  52.924  1
450373  96.401  -64.409  52.898  1
450374  96.443  -64.399  52.871  1
450375  96.477  -64.401  52.840  1
450376  96.513  -64.402  52.809  1
450377  96.547  -64.402  52.781  1
450378  96.582  -64.403  52.752  1
450379  96.617  -64.405  52.722  1
450380  96.652  -64.405  52.689  1
450381  96.692  -64.410  52.650  1
450382  96.731  -64.414  52.609  1
450383  96.770  -64.419  52.566  1
450384  96.810  -64.424  52.521  1
450385  96.850  -64.429  52.474  1
450386  96.889  -64.433  52.426  1
450387  96.929  -64.437  52.377  1
450388  96.969  -64.441  52.329  1
450389  97.009  -64.445  52.285  1
450390  97.048  -64.449  52.244  1
450391  97.089  -64.452  52.204  1
450392  97.129  -64.456  52.162  1
450393  97.168  -64.460  52.118  1
450394  97.208  -64.464  52.071  1
450395  97.248  -64.468  52.025  1
450396  97.288  -64.471  51.980  1
450397  97.320  -64.464  51.933  1
450398  97.349  -64.454  51.885  1
450399  97.377  -64.443  51.838  1
450400  97.405  -64.432  51.793  1
450401  97.434  -64.437  51.748  1
450402  97.462  -64.444  51.702  1
450403  97.491  -64.451  51.654  1
450404  97.519  -64.458  51.608  1
450405  97.558  -64.456  51.562  1
450406  97.599  -64.452  51.515  1
450407  97.640  -64.448  51.468  1
450408  97.680  -64.443  51.421  1
450409  97.721  -64.439  51.375  1
450410  97.762  -64.436  51.329  1
450411  97.803  -64.431  51.283  1
450412  97.835  -64.437  51.237  1
450413  97.865  -64.446  51.190  1
450414  97.903  -64.446  51.141  1
450415  97.943  -64.443  51.090  1
450416  97.969  -64.449  51.040  1
450417  97.995  -64.456  50.989  1
450418  98.021  -64.462  50.939  1
450419  98.047  -64.469  50.890  1
450420  98.073  -64.475  50.841  1
450421  98.099  -64.482  50.792  1
450422  98.125  -64.488  50.744  1
450423  98.151  -64.495  50.697  1
450424  98.181  -64.502  50.650  1
450425  98.222  -64.513  50.604  1
450426  98.263  -64.523  50.557  1
450427  98.303  -64.533  50.511  1
450428  98.344  -64.543  50.464  1
450429  98.388  -64.546  50.418  1
450430  98.435  -64.545  50.375  1
450431  98.484  -64.539  50.331  1
450432  98.533  -64.533  50.287  1
450433  98.582  -64.526  50.242  1
450434  98.631  -64.520  50.196  1
450435  98.680  -64.514  50.152  1
450436  98.729  -64.508  50.109  1
450437  98.778  -64.501  50.067  1
450438  98.827  -64.495  50.024  1
450439  98.876  -64.489  49.981  1
450440  98.925  -64.483  49.938  1
450441  98.974  -64.476  49.894  1
450442  99.015  -64.475  49.850  1
450443  99.053  -64.478  49.806  1
450444  99.091  -64.482  49.762  1
450445  99.128  -64.485  49.719  1
450446  99.166  -64.489  49.677  1
450447  99.203  -64.493  49.636  1
450448  99.240  -64.496  49.594  1
450449  99.278  -64.499  49.551  1
450450  99.315  -64.503  49.508  1
450451  99.352  -64.507  49.464  1
450452  99.390  -64.511  49.422  1
450453  99.427  -64.514  49.381  1
450454  99.464  -64.518  49.340  1
450455  99.501  -64.521  49.300  1
450456  99.539  -64.525  49.260  1
450457  99.596  -64.530  49.222  1
450458  99.667  -64.535  49.183  1
450459  99.739  -64.540  49.144  1
450460  99.810  -64.546  49.106  1
450461  99.881  -64.551  49.068  1
450462  99.952  -64.556  49.030  1
450463  100.023  -64.561  48.993  1
450464  100.095  -64.566  48.956  1
450465  100.158  -64.565  48.919  1
450466  100.221  -64.563  48.882  1
450467  100.276  -64.562  48.845  1
450468  100.312  -64.570  48.808  1
450469  100.347  -64.577  48.772  1
450470  100.383  -64.584  48.736  1
450471  100.419  -64.592  48.699  1
450472  100.455  -64.599  48.663  1
450473  100.490  -64.607  48.626  1
450474  100.525  -64.615  48.589  1
450475  100.561  -64.622  48.552  1
450476  100.597  -64.630  48.517  1
450477  100.635  -64.635  48.482  1
450857  86.949  -62.900  55.991  1
450858  86.978  -62.907  55.978  1
450859  87.006  -62.913  55.963  1
450860  87.034  -62.919  55.949  1
450861  87.062  -62.926  55.935  1
450862  87.090  -62.932  55.921  1
450863  87.118  -62.939  55.907  1
450864  87.146  -62.945  55.894  1
450865  87.175  -62.952  55.880  1
450866  87.203  -62.958  55.866  1
450867  87.230  -62.965  55.851  1
450868  87.259  -62.972  55.837  1
450869  87.287  -62.978  55.823  1
450870  87.325  -62.979  55.811  1
450871  87.374  -62.974  55.801  1
450872  87.423  -62.973  55.794  1
450873  87.474  -62.982  55.786  1
450874  87.525  -62.991  55.775  1
450875  87.575  -63.000  55.762  1
450876  87.625  -63.009  55.747  1
450877  87.676  -63.017  55.729  1
450878  87.726  -63.026  55.710  1
450879  87.777  -63.035  55.693  1
450880  87.827  -63.045  55.676  1
450881  87.878  -63.054  55.661  1
450882  87.928  -63.062  55.646  1
450883  87.979  -63.071  55.630  1
450884  88.030  -63.080  55.614  1
450885  88.080  -63.089  55.597  1
450886  88.130  -63.098  55.579  1
450887  88.181  -63.107  55.562  1
450888  88.232  -63.116  55.542  1
450889  88.282  -63.125  55.523  1
450890  88.332  -63.134  55.503  1
450891  88.383  -63.142  55.483  1
450892  88.433  -63.151  55.463  1
450893  88.484  -63.161  55.445  1
450894  88.534  -63.170  55.429  1
450895  88.585  -63.179  55.413  1
450896  88.635  -63.187  55.400  1
450897  88.686  -63.196  55.387  1
450898  88.736  -63.205  55.377  1
450899  88.787  -63.214  55.369  1
450900  88.837  -63.224  55.363  1
450901  88.888  -63.232  55.360  1
450902  88.939  -63.241  55.359  1
450903  88.983  -63.255  55.358  1
450904  89.026  -63.270  55.357  1
450905  89.068  -63.285  55.358  1
450906  89.111  -63.301  55.360  1
450907  89.153  -63.316  55.362  1
450908  89.196  -63.331  55.365  1
450909  89.238  -63.346  55.367  1
450910  89.281  -63.361  55.370  1
450911  89.323  -63.377  55.374  1
450912  89.374  -63.376  55.381  1
450913  89.428  -63.368  55.394  1
450914  89.475  -63.379  55.409  1
450915  89.522  -63.390  55.422  1
450916  89.568  -63.401  55.431  1
450917  89.615  -63.412  55.436  1
450918  89.662  -63.424  55.436  1
450919  89.708  -63.427  55.431  1
450920  89.753  -63.428  55.420  1
450921  89.799  -63.430  55.402  1
450922  89.844  -63.431  55.380  1
450923  89.889  -63.433  55.359  1
450924  89.935  -63.433  55.340  1
450925  89.980  -63.435  55.323  1
450926  90.026  -63.437  55.308  1
450927  90.071  -63.438  55.298  1
450928  90.116  -63.439  55.292  1
450929  90.162  -63.440  55.291  1
450930  90.207  -63.442  55.296  1
450931  90.253  -63.443  55.312  1
450932  90.298  -63.444  55.330  1
450933  90.319  -63.459  55.344  1
450934  90.332  -63.477  55.353  1
450935  90.353  -63.493  55.356  1
450936  90.403  -63.505  55.349  1
450937  90.453  -63.517  55.340  1
450938  90.502  -63.528  55.333  1
450939  90.552  -63.540  55.330  1
450940  90.602  -63.551  55.326  1
450941  90.651  -63.563  55.311  1
450942  90.703  -63.574  55.285  1
450943  90.761  -63.583  55.251  1
450944  90.820  -63.592  55.210  1
450945  90.871  -63.601  55.156  1
450946  90.919  -63.609  55.093  1
450947  90.965  -63.618  55.033  1
450948  91.013  -63.627  54.980  1
450949  91.060  -63.635  54.934  1
450950  91.107  -63.644  54.894  1
450951  91.154  -63.653  54.859  1
450952  91.201  -63.661  54.829  1
450953  91.248  -63.670  54.803  1
450954  91.295  -63.678  54.782  1
450955  91.343  -63.687  54.764  1
450956  91.389  -63.696  54.750  1
450957  91.437  -63.704  54.738  1
450958  91.484  -63.713  54.729  1
450959  91.531  -63.722  54.720  1
450960  91.578  -63.730  54.713  1
450961  91.625  -63.739  54.708  1
450962  91.672  -63.747  54.702  1
450963  91.719  -63.756  54.697  1
450964  91.767  -63.765  54.693  1
450965  91.813  -63.773  54.689  1
450966  91.861  -63.782  54.686  1
450967  91.908  -63.791  54.682  1
450968  91.952  -63.794  54.680  1
450969  91.995  -63.794  54.677  1
450970  92.038  -63.794  54.674  1
450971  92.081  -63.793  54.668  1
450972  92.124  -63.793  54.662  1
450973  92.167  -63.793  54.655  1
450974  92.213  -63.797  54.648  1
450975  92.260  -63.802  54.643  1
450976  92.305  -63.808  54.638  1
450977  92.324  -63.813  54.634  1
450978  92.344  -63.818  54.631  1
450979  92.376  -63.825  54.627  1
450980  92.407  -63.839  54.624  1
450981  92.432  -63.855  54.620  1
450982  92.467  -63.868  54.616  1
450983  92.517  -63.879  54.613  1
450984  92.567  -63.891  54.610  1
450985  92.617  -63.901  54.608  1
450986  92.669  -63.911  54.607  1
450987  92.736  -63.912  54.606  1
450988  92.803  -63.913  54.605  1
450989  92.870  -63.913  54.604  1
450990  92.937  -63.913  54.604  1
450991  92.980  -63.922  54.603  1
450992  93.019  -63.931  54.604  1
450993  93.057  -63.933  54.604  1
450994  93.095  -63.933  54.605  1
450995  93.138  -63.932  54.605  1
450996  93.183  -63.929  54.604  1
450997  93.227  -63.926  54.601  1
450998  93.272  -63.923  54.596  1
450999  93.308  -63.925  54.590  1
451000  93.334  -63.932  54.583  1
451001  93.360  -63.938  54.574  1
451002  93.386  -63.945  54.562  1
451003  93.411  -63.952  54.551  1
451004  93.437  -63.959  54.536  1
451005  93.463  -63.966  54.519  1
451006  93.488  -63.973  54.500  1
451007  93.514  -63.979  54.478  1
451008  93.540  -63.986  54.455  1
451009  93.572  -64.001  54.431  1
451010  93.612  -64.014  54.406  1
451011  93.657  -64.024  54.381  1
451012  93.703  -64.034  54.357  1
451013  93.748  -64.044  54.332  1
451014  93.793  -64.054  54.308  1
451015  93.838  -64.063  54.285  1
451016  93.884  -64.073  54.262  1
451017  93.926  -64.082  54.240  1
451018  93.955  -64.088  54.217  1
451019  93.984  -64.093  54.194  1
451020  94.013  -64.098  54.171  1
451021  94.042  -64.104  54.148  1
451022  94.070  -64.110  54.126  1
451023  94.100  -64.115  54.104  1
451024  94.128  -64.120  54.082  1
451025  94.176  -64.140  54.062  1
451026  94.231  -64.166  54.042  1
451027  94.287  -64.192  54.026  1
451028  94.323  -64.195  54.006  1
451029  94.347  -64.186  53.986  1
451030  94.386  -64.188  53.965  1
451031  94.435  -64.198  53.943  1
451032  94.485  -64.207  53.922  1
451033  94.535  -64.217  53.903  1
451034  94.584  -64.226  53.884  1
451035  94.634  -64.236  53.865  1
451036  94.684  -64.245  53.846  1
451037  94.734  -64.255  53.828  1
451038  94.781  -64.254  53.809  1
451039  94.831  -64.257  53.790  1
451040  94.886  -64.264  53.768  1
451041  94.939  -64.271  53.745  1
451042  94.994  -64.278  53.724  1
451043  95.048  -64.285  53.705  1
451044  95.102  -64.292  53.686  1
451045  95.157  -64.299  53.666  1
451046  95.210  -64.306  53.647  1
451047  95.265  -64.314  53.626  1
451048  95.319  -64.320  53.606  1
451049  95.373  -64.328  53.585  1
451050  95.427  -64.335  53.565  1
451051  95.481  -64.342  53.543  1
451052  95.536  -64.349  53.522  1
451053  95.590  -64.356  53.501  1
451054  95.642  -64.363  53.479  1
451055  95.686  -64.370  53.457  1
451056  95.731  -64.377  53.436  1
451057  95.758  -64.367  53.408  1
451058  95.792  -64.370  53.378  1
451059  95.826  -64.373  53.346  1
451060  95.860  -64.377  53.313  1
451061  95.894  -64.380  53.279  1
451062  95.927  -64.383  53.248  1
451063  95.962  -64.386  53.216  1
451064  95.995  -64.389  53.182  1
451065  96.030  -64.392  53.149  1
451066  96.063  -64.395  53.118  1
451067  96.098  -64.398  53.086  1
451068  96.133  -64.396  53.055  1
451069  96.177  -64.383  53.027  1
451070  96.222  -64.374  53.001  1
451071  96.267  -64.367  52.978  1
451072  96.312  -64.359  52.955  1
451073  96.358  -64.351  52.931  1
451074  96.404  -64.347  52.904  1
451075  96.452  -64.355  52.875  1
451076  96.486  -64.357  52.842  1
451077  96.520  -64.359  52.811  1
451078  96.553  -64.361  52.782  1
451079  96.587  -64.363  52.753  1
451080  96.621  -64.365  52.723  1
451081  96.656  -64.366  52.691  1
451082  96.695  -64.371  52.651  1
451083  96.735  -64.374  52.608  1
451084  96.775  -64.378  52.564  1
451085  96.815  -64.382  52.518  1
451086  96.855  -64.386  52.470  1
451087  96.895  -64.389  52.421  1
451088  96.935  -64.393  52.371  1
451089  96.974  -64.397  52.322  1
451090  97.014  -64.401  52.280  1
451091  97.054  -64.405  52.240  1
451092  97.094  -64.408  52.199  1
451093  97.134  -64.412  52.156  1
451094  97.174  -64.416  52.112  1
451095  97.214  -64.420  52.064  1
451096  97.254  -64.424  52.018  1
451097  97.294  -64.428  51.972  1
451098  97.327  -64.423  51.924  1
451099  97.356  -64.412  51.876  1
451100  97.384  -64.402  51.830  1
451101  97.413  -64.393  51.786  1
451102  97.441  -64.400  51.741  1
451103  97.469  -64.408  51.696  1
451104  97.498  -64.414  51.649  1
451105  97.526  -64.422  51.602  1
451106  97.558  -64.426  51.555  1
451107  97.599  -64.421  51.508  1
451108  97.640  -64.418  51.461  1
451109  97.681  -64.413  51.414  1
451110  97.722  -64.409  51.368  1
451111  97.762  -64.405  51.322  1
451112  97.803  -64.401  51.276  1
451113  97.845  -64.397  51.230  1
451114  97.885  -64.392  51.184  1
451115  97.920  -64.395  51.136  1
451116  97.946  -64.402  51.085  1
451117  97.971  -64.408  51.034  1
451118  97.998  -64.414  50.983  1
451119  98.023  -64.421  50.932  1
451120  98.050  -64.427  50.881  1
451121  98.075  -64.434  50.831  1
451122  98.101  -64.440  50.782  1
451123  98.128  -64.447  50.733  1
451124  98.153  -64.453  50.686  1
451125  98.180  -64.460  50.639  1
451126  98.221  -64.471  50.592  1
451127  98.262  -64.481  50.545  1
451128  98.303  -64.490  50.498  1
451129  98.348  -64.493  50.451  1
451130  98.392  -64.496  50.404  1
451131  98.440  -64.493  50.359  1
451132  98.489  -64.486  50.315  1
451133  98.538  -64.480  50.270  1
451134  98.587  -64.474  50.226  1
451135  98.636  -64.468  50.181  1
451136  98.685  -64.461  50.137  1
451137  98.734  -64.455  50.094  1
451138  98.783  -64.449  50.051  1
451139  98.832  -64.443  50.007  1
451140  98.881  -64.436  49.964  1
451141  98.928  -64.436  49.920  1
451142  98.974  -64.438  49.876  1
451143  99.014  -64.442  49.832  1
451144  99.052  -64.445  49.787  1
451145  99.089  -64.449  49.743  1
451146  99.126  -64.452  49.700  1
451147  99.163  -64.456  49.657  1
451148  99.201  -64.459  49.615  1
451149  99.238  -64.463  49.573  1
451150  99.275  -64.467  49.531  1
451151  99.312  -64.471  49.489  1
451152  99.350  -64.474  49.447  1
451153  99.387  -64.477  49.405  1
451154  99.424  -64.481  49.365  1
451155  99.462  -64.485  49.326  1
451156  99.499  -64.488  49.286  1
451157  99.544  -64.494  49.246  1
451158  99.615  -64.499  49.207  1
451159  99.686  -64.505  49.169  1
451160  99.757  -64.510  49.131  1
451161  99.829  -64.515  49.092  1
451162  99.900  -64.521  49.054  1
451163  99.971  -64.525  49.016  1
451164  100.041  -64.530  48.980  1
451165  100.104  -64.527  48.943  1
451166  100.167  -64.526  48.907  1
451167  100.229  -64.524  48.871  1
451168  100.277  -64.525  48.833  1
451169  100.313  -64.533  48.797  1
451170  100.348  -64.540  48.761  1
451171  100.384  -64.548  48.726  1
451172  100.420  -64.555  48.690  1
451173  100.455  -64.563  48.653  1
451174  100.491  -64.571  48.617  1
451175  100.527  -64.578  48.581  1
451176  100.562  -64.585  48.545  1
451177  100.598  -64.593  48.511  1
451555  86.869  -62.838  56.042  1
451556  86.898  -62.844  56.028  1
451557  86.925  -62.851  56.015  1
451558  86.953  -62.857  56.001  1
451559  86.982  -62.864  55.987  1
451560  87.010  -62.870  55.974  1
451561  87.038  -62.877  55.959  1
451562  87.066  -62.883  55.945  1
451563  87.094  -62.890  55.932  1
451564  87.122  -62.897  55.916  1
451565  87.150  -62.903  55.903  1
451566  87.179  -62.910  55.889  1
451567  87.206  -62.916  55.874  1
451568  87.234  -62.923  55.859  1
451569  87.263  -62.929  55.846  1
451570  87.303  -62.929  55.832  1
451571  87.352  -62.924  55.819  1
451572  87.401  -62.919  55.809  1
451573  87.449  -62.915  55.801  1
451574  87.499  -62.919  55.793  1
451575  87.550  -62.929  55.782  1
451576  87.601  -62.938  55.769  1
451577  87.651  -62.947  55.754  1
451578  87.701  -62.956  55.738  1
451579  87.752  -62.964  55.719  1
451580  87.802  -62.973  55.701  1
451581  87.853  -62.982  55.685  1
451582  87.904  -62.992  55.670  1
451583  87.954  -63.001  55.655  1
451584  88.004  -63.009  55.640  1
451585  88.055  -63.018  55.625  1
451586  88.106  -63.027  55.608  1
451587  88.156  -63.036  55.589  1
451588  88.206  -63.045  55.573  1
451589  88.257  -63.054  55.554  1
451590  88.308  -63.063  55.534  1
451591  88.358  -63.072  55.514  1
451592  88.408  -63.081  55.494  1
451593  88.459  -63.089  55.473  1
451594  88.509  -63.098  55.455  1
451595  88.560  -63.108  55.438  1
451596  88.610  -63.117  55.421  1
451597  88.661  -63.126  55.407  1
451598  88.711  -63.134  55.393  1
451599  88.762  -63.143  55.383  1
451600  88.813  -63.152  55.374  1
451601  88.860  -63.164  55.369  1
451602  88.903  -63.179  55.364  1
451603  88.945  -63.194  55.362  1
451604  88.988  -63.209  55.361  1
451605  89.030  -63.224  55.361  1
451606  89.073  -63.239  55.360  1
451607  89.115  -63.255  55.362  1
451608  89.158  -63.270  55.364  1
451609  89.200  -63.286  55.365  1
451610  89.243  -63.301  55.367  1
451611  89.285  -63.316  55.368  1
451612  89.328  -63.331  55.371  1
451613  89.384  -63.321  55.377  1
451614  89.439  -63.312  55.389  1
451615  89.485  -63.324  55.403  1
451616  89.532  -63.335  55.416  1
451617  89.579  -63.346  55.426  1
451618  89.625  -63.358  55.432  1
451619  89.671  -63.374  55.432  1
451620  89.717  -63.386  55.426  1
451621  89.763  -63.389  55.414  1
451622  89.809  -63.390  55.397  1
451623  89.854  -63.391  55.376  1
451624  89.899  -63.393  55.356  1
451625  89.945  -63.394  55.338  1
451626  89.990  -63.395  55.320  1
451627  90.036  -63.396  55.305  1
451628  90.081  -63.398  55.295  1
451629  90.126  -63.399  55.289  1
451630  90.172  -63.400  55.287  1
451631  90.217  -63.402  55.290  1
451632  90.263  -63.403  55.304  1
451633  90.305  -63.406  55.321  1
451634  90.318  -63.424  55.338  1
451635  90.332  -63.442  55.350  1
451636  90.348  -63.459  55.354  1
451637  90.398  -63.471  55.350  1
451638  90.448  -63.483  55.342  1
451639  90.497  -63.494  55.334  1
451640  90.547  -63.506  55.328  1
451641  90.597  -63.518  55.324  1
451642  90.647  -63.529  55.307  1
451643  90.706  -63.538  55.280  1
451644  90.764  -63.547  55.243  1
451645  90.823  -63.556  55.196  1
451646  90.882  -63.565  55.145  1
451647  90.932  -63.574  55.083  1
451648  90.979  -63.582  55.025  1
451649  91.026  -63.591  54.974  1
451650  91.074  -63.600  54.930  1
451651  91.121  -63.608  54.891  1
451652  91.168  -63.617  54.857  1
451653  91.215  -63.625  54.827  1
451654  91.262  -63.634  54.802  1
451655  91.309  -63.643  54.781  1
451656  91.356  -63.651  54.764  1
451657  91.403  -63.660  54.750  1
451658  91.450  -63.669  54.739  1
451659  91.498  -63.677  54.730  1
451660  91.545  -63.686  54.721  1
451661  91.592  -63.694  54.715  1
451662  91.639  -63.703  54.710  1
451663  91.686  -63.712  54.705  1
451664  91.733  -63.720  54.700  1
451665  91.780  -63.729  54.696  1
451666  91.827  -63.737  54.693  1
451667  91.874  -63.746  54.690  1
451668  91.918  -63.746  54.689  1
451669  91.960  -63.745  54.687  1
451670  92.003  -63.745  54.684  1
451671  92.046  -63.745  54.680  1
451672  92.089  -63.744  54.675  1
451673  92.132  -63.744  54.669  1
451674  92.176  -63.745  54.662  1
451675  92.223  -63.750  54.655  1
451676  92.269  -63.756  54.650  1
451677  92.316  -63.761  54.645  1
451678  92.337  -63.766  54.640  1
451679  92.357  -63.772  54.636  1
451680  92.377  -63.777  54.632  1
451681  92.407  -63.791  54.629  1
451682  92.454  -63.802  54.625  1
451683  92.504  -63.813  54.621  1
451684  92.555  -63.824  54.618  1
451685  92.604  -63.835  54.616  1
451686  92.654  -63.847  54.614  1
451687  92.714  -63.851  54.613  1
451688  92.781  -63.852  54.613  1
451689  92.848  -63.852  54.612  1
451690  92.911  -63.854  54.611  1
451691  92.950  -63.863  54.610  1
451692  92.989  -63.872  54.610  1
451693  93.028  -63.880  54.609  1
451694  93.066  -63.880  54.609  1
451695  93.105  -63.880  54.608  1
451696  93.145  -63.879  54.607  1
451697  93.190  -63.877  54.605  1
451698  93.234  -63.874  54.601  1
451699  93.279  -63.871  54.596  1
451700  93.316  -63.869  54.591  1
451701  93.344  -63.872  54.583  1
451702  93.369  -63.879  54.574  1
451703  93.395  -63.886  54.562  1
451704  93.421  -63.893  54.549  1
451705  93.446  -63.900  54.533  1
451706  93.473  -63.907  54.515  1
451707  93.498  -63.913  54.494  1
451708  93.524  -63.920  54.471  1
451709  93.550  -63.929  54.447  1
451710  93.583  -63.945  54.421  1
451711  93.617  -63.963  54.395  1
451712  93.654  -63.977  54.369  1
451713  93.699  -63.987  54.343  1
451714  93.744  -63.997  54.314  1
451715  93.789  -64.007  54.287  1
451716  93.835  -64.016  54.262  1
451717  93.880  -64.026  54.237  1
451718  93.918  -64.034  54.215  1
451719  93.947  -64.039  54.192  1
451720  93.976  -64.045  54.168  1
451721  94.005  -64.051  54.145  1
451722  94.034  -64.056  54.122  1
451723  94.063  -64.062  54.099  1
451724  94.105  -64.077  54.077  1
451725  94.160  -64.103  54.057  1
451726  94.216  -64.129  54.038  1
451727  94.272  -64.154  54.019  1
451728  94.316  -64.165  54.002  1
451729  94.351  -64.170  53.982  1
451730  94.376  -64.161  53.962  1
451731  94.400  -64.153  53.943  1
451732  94.449  -64.162  53.924  1
451733  94.499  -64.172  53.903  1
451734  94.549  -64.181  53.885  1
451735  94.598  -64.191  53.867  1
451736  94.648  -64.201  53.848  1
451737  94.698  -64.210  53.829  1
451738  94.746  -64.212  53.810  1
451739  94.793  -64.212  53.791  1
451740  94.841  -64.212  53.770  1
451741  94.896  -64.220  53.749  1
451742  94.950  -64.226  53.727  1
451743  95.004  -64.234  53.707  1
451744  95.058  -64.241  53.688  1
451745  95.112  -64.248  53.669  1
451746  95.167  -64.255  53.650  1
451747  95.220  -64.262  53.631  1
451748  95.275  -64.269  53.610  1
451749  95.329  -64.276  53.591  1
451750  95.383  -64.283  53.572  1
451751  95.438  -64.291  53.552  1
451752  95.491  -64.298  53.531  1
451753  95.546  -64.305  53.510  1
451754  95.596  -64.311  53.487  1
451755  95.640  -64.318  53.464  1
451756  95.684  -64.325  53.441  1
451757  95.727  -64.331  53.418  1
451758  95.753  -64.320  53.390  1
451759  95.784  -64.318  53.360  1
451760  95.818  -64.321  53.330  1
451761  95.852  -64.324  53.301  1
451762  95.886  -64.327  53.272  1
451763  95.920  -64.330  53.243  1
451764  95.954  -64.333  53.212  1
451765  95.988  -64.336  53.179  1
451766  96.022  -64.339  53.146  1
451767  96.056  -64.342  53.113  1
451768  96.092  -64.342  53.081  1
451769  96.133  -64.323  53.052  1
451770  96.179  -64.316  53.026  1
451771  96.224  -64.308  53.003  1
451772  96.269  -64.300  52.981  1
451773  96.314  -64.292  52.960  1
451774  96.361  -64.291  52.935  1
451775  96.413  -64.300  52.907  1
451776  96.463  -64.309  52.877  1
451777  96.497  -64.311  52.844  1
451778  96.531  -64.313  52.812  1
451779  96.565  -64.315  52.781  1
451780  96.598  -64.317  52.751  1
451781  96.632  -64.320  52.721  1
451782  96.666  -64.322  52.688  1
451783  96.703  -64.327  52.649  1
451784  96.741  -64.331  52.605  1
451785  96.781  -64.335  52.559  1
451786  96.820  -64.339  52.510  1
451787  96.861  -64.342  52.462  1
451788  96.900  -64.346  52.413  1
451789  96.940  -64.350  52.362  1
451790  96.980  -64.354  52.313  1
451791  97.020  -64.358  52.273  1
451792  97.060  -64.361  52.232  1
451793  97.100  -64.365  52.192  1
451794  97.140  -64.369  52.150  1
451795  97.180  -64.373  52.104  1
451796  97.220  -64.377  52.058  1
451797  97.259  -64.380  52.010  1
451798  97.299  -64.384  51.963  1
451799  97.334  -64.382  51.915  1
451800  97.363  -64.371  51.867  1
451801  97.391  -64.360  51.821  1
451802  97.420  -64.357  51.777  1
451803  97.448  -64.364  51.734  1
451804  97.476  -64.371  51.689  1
451805  97.505  -64.378  51.643  1
451806  97.533  -64.385  51.597  1
451807  97.562  -64.392  51.549  1
451808  97.599  -64.391  51.502  1
451809  97.640  -64.387  51.454  1
451810  97.681  -64.383  51.407  1
451811  97.722  -64.379  51.361  1
451812  97.763  -64.375  51.315  1
451813  97.804  -64.371  51.269  1
451814  97.845  -64.367  51.223  1
451815  97.885  -64.362  51.177  1
451816  97.920  -64.361  51.130  1
451817  97.946  -64.366  51.080  1
451818  97.973  -64.371  51.028  1
451819  97.999  -64.375  50.976  1
451820  98.026  -64.380  50.924  1
451821  98.052  -64.386  50.872  1
451822  98.078  -64.392  50.822  1
451823  98.103  -64.399  50.772  1
451824  98.130  -64.405  50.723  1
451825  98.156  -64.412  50.675  1
451826  98.181  -64.418  50.628  1
451827  98.220  -64.428  50.581  1
451828  98.262  -64.436  50.534  1
451829  98.307  -64.439  50.486  1
451830  98.351  -64.443  50.439  1
451831  98.396  -64.446  50.391  1
451832  98.445  -64.440  50.345  1
451833  98.494  -64.434  50.299  1
451834  98.543  -64.428  50.254  1
451835  98.592  -64.421  50.210  1
451836  98.641  -64.415  50.167  1
451837  98.690  -64.409  50.122  1
451838  98.739  -64.403  50.079  1
451839  98.788  -64.396  50.035  1
451840  98.834  -64.397  49.990  1
451841  98.880  -64.400  49.947  1
451842  98.926  -64.403  49.902  1
451843  98.973  -64.405  49.858  1
451844  99.012  -64.408  49.814  1
451845  99.049  -64.412  49.768  1
451846  99.086  -64.416  49.725  1
451847  99.124  -64.419  49.681  1
451848  99.161  -64.423  49.637  1
451849  99.198  -64.427  49.595  1
451850  99.235  -64.430  49.553  1
451851  99.273  -64.433  49.511  1
451852  99.310  -64.437  49.471  1
451853  99.347  -64.441  49.430  1
451854  99.384  -64.445  49.389  1
451855  99.422  -64.449  49.349  1
451856  99.454  -64.452  49.311  1
451857  99.491  -64.458  49.271  1
451858  99.562  -64.464  49.232  1
451859  99.633  -64.469  49.193  1
451860  99.704  -64.474  49.155  1
451861  99.776  -64.480  49.117  1
451862  99.847  -64.485  49.079  1
451863  99.918  -64.490  49.041  1
451864  99.986  -64.493  49.003  1
451865  100.049  -64.490  48.966  1
451866  100.112  -64.489  48.930  1
451867  100.175  -64.487  48.894  1
451868  100.238  -64.485  48.859  1
451869  100.278  -64.489  48.822  1
451870  100.314  -64.496  48.786  1
451871  100.349  -64.504  48.750  1
451872  100.385  -64.511  48.715  1
451873  100.420  -64.518  48.680  1
451874  100.456  -64.526  48.644  1
451875  100.492  -64.533  48.609  1
451876  100.528  -64.541  48.573  1
451877  100.563  -64.549  48.538  1
451878  100.599  -64.556  48.505  1
452256  86.873  -62.795  56.053  1
452257  86.902  -62.802  56.040  1
452258  86.929  -62.809  56.026  1
452259  86.957  -62.815  56.013  1
452260  86.986  -62.822  56.000  1
452261  87.014  -62.828  55.986  1
452262  87.042  -62.835  55.972  1
452263  87.070  -62.841  55.958  1
452264  87.098  -62.847  55.943  1
452265  87.126  -62.854  55.928  1
452266  87.154  -62.860  55.913  1
452267  87.183  -62.867  55.899  1
452268  87.210  -62.873  55.883  1
452269  87.238  -62.880  55.868  1
452270  87.280  -62.879  55.854  1
452271  87.329  -62.875  55.840  1
452272  87.378  -62.869  55.828  1
452273  87.427  -62.865  55.817  1
452274  87.476  -62.860  55.806  1
452275  87.525  -62.858  55.798  1
452276  87.575  -62.866  55.788  1
452277  87.626  -62.876  55.776  1
452278  87.677  -62.885  55.760  1
452279  87.727  -62.894  55.744  1
452280  87.777  -62.903  55.726  1
452281  87.828  -62.911  55.709  1
452282  87.879  -62.920  55.693  1
452283  87.929  -62.929  55.679  1
452284  87.980  -62.938  55.664  1
452285  88.030  -62.948  55.650  1
452286  88.080  -62.956  55.635  1
452287  88.131  -62.965  55.619  1
452288  88.182  -62.974  55.601  1
452289  88.232  -62.983  55.583  1
452290  88.282  -62.992  55.565  1
452291  88.333  -63.001  55.545  1
452292  88.384  -63.010  55.525  1
452293  88.434  -63.019  55.505  1
452294  88.484  -63.028  55.483  1
452295  88.535  -63.036  55.465  1
452296  88.586  -63.045  55.447  1
452297  88.636  -63.054  55.429  1
452298  88.686  -63.064  55.414  1
452299  88.737  -63.073  55.401  1
452300  88.780  -63.087  55.389  1
452301  88.823  -63.102  55.380  1
452302  88.865  -63.118  55.374  1
452303  88.908  -63.133  55.368  1
452304  88.950  -63.148  55.366  1
452305  88.993  -63.164  55.365  1
452306  89.035  -63.179  55.364  1
452307  89.078  -63.194  55.363  1
452308  89.120  -63.209  55.364  1
452309  89.163  -63.225  55.366  1
452310  89.205  -63.240  55.366  1
452311  89.248  -63.255  55.366  1
452312  89.291  -63.270  55.366  1
452313  89.337  -63.278  55.369  1
452314  89.393  -63.266  55.373  1
452315  89.448  -63.257  55.381  1
452316  89.494  -63.268  55.393  1
452317  89.541  -63.280  55.407  1
452318  89.588  -63.291  55.418  1
452319  89.634  -63.305  55.425  1
452320  89.679  -63.326  55.425  1
452321  89.726  -63.337  55.419  1
452322  89.772  -63.346  55.407  1
452323  89.818  -63.350  55.391  1
452324  89.864  -63.351  55.372  1
452325  89.909  -63.352  55.353  1
452326  89.955  -63.354  55.336  1
452327  90.000  -63.355  55.319  1
452328  90.045  -63.356  55.301  1
452329  90.091  -63.358  55.291  1
452330  90.136  -63.359  55.284  1
452331  90.182  -63.360  55.281  1
452332  90.227  -63.361  55.283  1
452333  90.272  -63.363  55.293  1
452334  90.304  -63.371  55.309  1
452335  90.318  -63.390  55.327  1
452336  90.331  -63.408  55.341  1
452337  90.344  -63.425  55.346  1
452338  90.393  -63.437  55.343  1
452339  90.443  -63.449  55.337  1
452340  90.493  -63.461  55.330  1
452341  90.542  -63.472  55.322  1
452342  90.592  -63.484  55.312  1
452343  90.650  -63.493  55.292  1
452344  90.709  -63.502  55.263  1
452345  90.767  -63.511  55.225  1
452346  90.826  -63.520  55.179  1
452347  90.885  -63.529  55.126  1
452348  90.943  -63.538  55.069  1
452349  90.993  -63.546  55.016  1
452350  91.040  -63.555  54.967  1
452351  91.087  -63.564  54.926  1
452352  91.135  -63.572  54.888  1
452353  91.182  -63.581  54.854  1
452354  91.229  -63.590  54.826  1
452355  91.276  -63.598  54.802  1
452356  91.323  -63.607  54.781  1
452357  91.370  -63.615  54.765  1
452358  91.417  -63.624  54.751  1
452359  91.464  -63.633  54.740  1
452360  91.512  -63.641  54.731  1
452361  91.559  -63.650  54.723  1
452362  91.606  -63.659  54.717  1
452363  91.653  -63.667  54.712  1
452364  91.700  -63.676  54.708  1
452365  91.747  -63.684  54.704  1
452366  91.794  -63.694  54.700  1
452367  91.840  -63.697  54.698  1
452368  91.882  -63.697  54.697  1
452369  91.925  -63.697  54.696  1
452370  91.968  -63.697  54.696  1
452371  92.011  -63.697  54.693  1
452372  92.054  -63.697  54.688  1
452373  92.097  -63.697  54.682  1
452374  92.140  -63.696  54.675  1
452375  92.185  -63.699  54.669  1
452376  92.232  -63.704  54.661  1
452377  92.279  -63.709  54.656  1
452378  92.325  -63.715  54.651  1
452379  92.350  -63.720  54.646  1
452380  92.369  -63.725  54.643  1
452381  92.389  -63.731  54.639  1
452382  92.442  -63.736  54.635  1
452383  92.492  -63.747  54.631  1
452384  92.542  -63.758  54.626  1
452385  92.591  -63.769  54.624  1
452386  92.641  -63.780  54.621  1
452387  92.693  -63.791  54.619  1
452388  92.760  -63.791  54.619  1
452389  92.827  -63.791  54.619  1
452390  92.882  -63.796  54.618  1
452391  92.921  -63.805  54.618  1
452392  92.959  -63.814  54.617  1
452393  92.998  -63.823  54.616  1
452394  93.037  -63.827  54.615  1
452395  93.075  -63.827  54.613  1
452396  93.114  -63.827  54.611  1
452397  93.152  -63.827  54.609  1
452398  93.196  -63.825  54.606  1
452399  93.241  -63.822  54.601  1
452400  93.286  -63.819  54.596  1
452401  93.320  -63.816  54.590  1
452402  93.353  -63.813  54.582  1
452403  93.379  -63.820  54.572  1
452404  93.405  -63.827  54.559  1
452405  93.430  -63.834  54.545  1
452406  93.457  -63.841  54.529  1
452407  93.482  -63.847  54.510  1
452408  93.508  -63.854  54.488  1
452409  93.534  -63.861  54.464  1
452410  93.562  -63.872  54.439  1
452411  93.595  -63.889  54.412  1
452412  93.628  -63.907  54.385  1
452413  93.661  -63.923  54.357  1
452414  93.695  -63.940  54.329  1
452415  93.741  -63.950  54.298  1
452416  93.786  -63.960  54.270  1
452417  93.831  -63.969  54.243  1
452418  93.876  -63.979  54.216  1
452419  93.910  -63.986  54.191  1
452420  93.939  -63.991  54.168  1
452421  93.968  -63.998  54.144  1
452422  93.997  -64.003  54.119  1
452423  94.034  -64.014  54.096  1
452424  94.089  -64.040  54.073  1
452425  94.145  -64.066  54.053  1
452426  94.193  -64.081  54.032  1
452427  94.235  -64.091  54.013  1
452428  94.278  -64.101  53.994  1
452429  94.320  -64.111  53.977  1
452430  94.366  -64.129  53.958  1
452431  94.404  -64.136  53.939  1
452432  94.428  -64.128  53.922  1
452433  94.463  -64.127  53.906  1
452434  94.512  -64.136  53.888  1
452435  94.562  -64.146  53.870  1
452436  94.612  -64.155  53.852  1
452437  94.662  -64.165  53.834  1
452438  94.710  -64.170  53.814  1
452439  94.758  -64.170  53.794  1
452440  94.805  -64.170  53.774  1
452441  94.852  -64.169  53.753  1
452442  94.906  -64.176  53.731  1
452443  94.960  -64.182  53.711  1
452444  95.014  -64.189  53.691  1
452445  95.068  -64.197  53.672  1
452446  95.122  -64.204  53.653  1
452447  95.177  -64.211  53.633  1
452448  95.231  -64.218  53.614  1
452449  95.285  -64.225  53.595  1
452450  95.339  -64.232  53.576  1
452451  95.393  -64.239  53.558  1
452452  95.448  -64.246  53.539  1
452453  95.502  -64.254  53.519  1
452454  95.549  -64.261  53.498  1
452455  95.593  -64.267  53.474  1
452456  95.637  -64.273  53.450  1
452457  95.681  -64.280  53.425  1
452458  95.723  -64.284  53.400  1
452459  95.749  -64.274  53.372  1
452460  95.777  -64.266  53.344  1
452461  95.811  -64.269  53.316  1
452462  95.845  -64.272  53.289  1
452463  95.879  -64.275  53.264  1
452464  95.913  -64.278  53.237  1
452465  95.947  -64.281  53.208  1
452466  95.981  -64.284  53.176  1
452467  96.015  -64.287  53.143  1
452468  96.049  -64.289  53.109  1
452469  96.092  -64.270  53.077  1
452470  96.135  -64.258  53.049  1
452471  96.180  -64.249  53.025  1
452472  96.225  -64.242  53.003  1
452473  96.270  -64.234  52.983  1
452474  96.319  -64.235  52.961  1
452475  96.370  -64.244  52.937  1
452476  96.421  -64.254  52.909  1
452477  96.473  -64.263  52.879  1
452478  96.508  -64.265  52.847  1
452479  96.542  -64.267  52.814  1
452480  96.576  -64.270  52.781  1
452481  96.609  -64.271  52.749  1
452482  96.643  -64.273  52.717  1
452483  96.678  -64.276  52.681  1
452484  96.715  -64.281  52.641  1
452485  96.752  -64.286  52.597  1
452486  96.789  -64.290  52.549  1
452487  96.826  -64.295  52.499  1
452488  96.866  -64.299  52.450  1
452489  96.906  -64.303  52.401  1
452490  96.946  -64.307  52.351  1
452491  96.985  -64.311  52.303  1
452492  97.026  -64.314  52.261  1
452493  97.066  -64.318  52.222  1
452494  97.105  -64.322  52.183  1
452495  97.145  -64.326  52.141  1
452496  97.185  -64.330  52.096  1
452497  97.225  -64.333  52.049  1
452498  97.265  -64.337  52.001  1
452499  97.305  -64.341  51.953  1
452500  97.342  -64.340  51.906  1
452501  97.370  -64.330  51.859  1
452502  97.399  -64.319  51.814  1
452503  97.427  -64.320  51.771  1
452504  97.455  -64.327  51.728  1
452505  97.484  -64.335  51.684  1
452506  97.512  -64.342  51.639  1
452507  97.540  -64.349  51.592  1
452508  97.569  -64.356  51.546  1
452509  97.600  -64.361  51.498  1
452510  97.641  -64.357  51.450  1
452511  97.681  -64.352  51.403  1
452512  97.722  -64.349  51.357  1
452513  97.763  -64.344  51.311  1
452514  97.804  -64.340  51.265  1
452515  97.845  -64.336  51.218  1
452516  97.886  -64.331  51.171  1
452517  97.920  -64.330  51.123  1
452518  97.946  -64.334  51.073  1
452519  97.972  -64.339  51.022  1
452520  97.999  -64.343  50.970  1
452521  98.025  -64.349  50.918  1
452522  98.052  -64.353  50.865  1
452523  98.078  -64.358  50.814  1
452524  98.105  -64.362  50.763  1
452525  98.131  -64.367  50.714  1
452526  98.158  -64.371  50.665  1
452527  98.184  -64.377  50.618  1
452528  98.221  -64.383  50.570  1
452529  98.266  -64.386  50.522  1
452530  98.310  -64.389  50.475  1
452531  98.355  -64.393  50.427  1
452532  98.401  -64.394  50.379  1
452533  98.450  -64.388  50.332  1
452534  98.499  -64.382  50.286  1
452535  98.548  -64.376  50.241  1
452536  98.597  -64.369  50.196  1
452537  98.646  -64.363  50.151  1
452538  98.695  -64.357  50.107  1
452539  98.741  -64.358  50.063  1
452540  98.786  -64.361  50.020  1
452541  98.832  -64.364  49.975  1
452542  98.878  -64.367  49.931  1
452543  98.925  -64.370  49.886  1
452544  98.972  -64.372  49.840  1
452545  99.009  -64.376  49.795  1
452546  99.047  -64.380  49.751  1
452547  99.084  -64.383  49.707  1
452548  99.121  -64.386  49.663  1
452549  99.158  -64.390  49.619  1
452550  99.196  -64.394  49.577  1
452551  99.233  -64.397  49.536  1
452552  99.270  -64.401  49.495  1
452553  99.307  -64.405  49.454  1
452554  99.345  -64.408  49.413  1
452555  99.382  -64.411  49.374  1
452556  99.410  -64.417  49.334  1
452557  99.438  -64.423  49.296  1
452558  99.509  -64.428  49.256  1
452559  99.580  -64.433  49.216  1
452560  99.652  -64.439  49.179  1
452561  99.723  -64.444  49.141  1
452562  99.794  -64.449  49.103  1
452563  99.865  -64.454  49.065  1
452564  99.932  -64.455  49.028  1
452565  99.995  -64.454  48.990  1
452566  100.058  -64.452  48.954  1
452567  100.121  -64.450  48.918  1
452568  100.184  -64.448  48.882  1
452569  100.240  -64.448  48.846  1
452570  100.279  -64.452  48.810  1
452571  100.315  -64.459  48.774  1
452572  100.350  -64.467  48.739  1
452573  100.385  -64.474  48.705  1
452574  100.421  -64.482  48.670  1
452575  100.457  -64.490  48.635  1
452576  100.493  -64.497  48.601  1
452577  100.528  -64.505  48.565  1
452578  100.564  -64.512  48.531  1
452956  86.849  -62.747  56.079  1
452957  86.877  -62.753  56.066  1
452958  86.905  -62.760  56.052  1
452959  86.933  -62.766  56.038  1
452960  86.962  -62.772  56.025  1
452961  86.990  -62.779  56.013  1
452962  87.018  -62.785  55.999  1
452963  87.046  -62.792  55.985  1
452964  87.074  -62.798  55.970  1
452965  87.102  -62.805  55.954  1
452966  87.130  -62.812  55.939  1
452967  87.158  -62.818  55.924  1
452968  87.186  -62.825  55.909  1
452969  87.214  -62.831  55.893  1
452970  87.258  -62.829  55.877  1
452971  87.307  -62.825  55.862  1
452972  87.356  -62.819  55.847  1
452973  87.405  -62.815  55.833  1
452974  87.454  -62.810  55.821  1
452975  87.502  -62.806  55.812  1
452976  87.551  -62.801  55.801  1
452977  87.601  -62.805  55.792  1
452978  87.651  -62.813  55.780  1
452979  87.702  -62.822  55.765  1
452980  87.753  -62.832  55.748  1
452981  87.803  -62.841  55.731  1
452982  87.854  -62.850  55.715  1
452983  87.904  -62.858  55.701  1
452984  87.955  -62.867  55.689  1
452985  88.005  -62.876  55.675  1
452986  88.056  -62.885  55.662  1
452987  88.106  -62.894  55.647  1
452988  88.156  -62.903  55.631  1
452989  88.207  -62.912  55.613  1
452990  88.258  -62.921  55.594  1
452991  88.308  -62.930  55.576  1
452992  88.358  -62.939  55.556  1
452993  88.409  -62.948  55.536  1
452994  88.460  -62.957  55.515  1
452995  88.510  -62.966  55.493  1
452996  88.560  -62.975  55.475  1
452997  88.611  -62.983  55.457  1
452998  88.657  -62.996  55.439  1
452999  88.700  -63.011  55.422  1
453000  88.742  -63.026  55.408  1
453001  88.785  -63.042  55.396  1
453002  88.827  -63.057  55.386  1
453003  88.870  -63.073  55.379  1
453004  88.912  -63.088  55.373  1
453005  88.955  -63.103  55.369  1
453006  88.997  -63.118  55.368  1
453007  89.040  -63.133  55.367  1
453008  89.083  -63.148  55.365  1
453009  89.125  -63.164  55.366  1
453010  89.168  -63.180  55.367  1
453011  89.210  -63.195  55.367  1
453012  89.253  -63.210  55.366  1
453013  89.296  -63.225  55.364  1
453014  89.346  -63.224  55.365  1
453015  89.403  -63.211  55.368  1
453016  89.458  -63.202  55.373  1
453017  89.505  -63.213  55.383  1
453018  89.551  -63.224  55.396  1
453019  89.597  -63.238  55.407  1
453020  89.642  -63.258  55.414  1
453021  89.687  -63.278  55.415  1
453022  89.734  -63.289  55.410  1
453023  89.780  -63.299  55.399  1
453024  89.828  -63.308  55.384  1
453025  89.874  -63.311  55.368  1
453026  89.919  -63.312  55.352  1
453027  89.964  -63.314  55.335  1
453028  90.010  -63.315  55.319  1
453029  90.055  -63.316  55.300  1
453030  90.101  -63.318  55.287  1
453031  90.146  -63.319  55.279  1
453032  90.191  -63.321  55.274  1
453033  90.237  -63.321  55.274  1
453034  90.283  -63.323  55.281  1
453035  90.304  -63.337  55.294  1
453036  90.317  -63.355  55.311  1
453037  90.330  -63.373  55.326  1
453038  90.344  -63.391  55.332  1
453039  90.388  -63.403  55.330  1
453040  90.438  -63.415  55.326  1
453041  90.487  -63.427  55.320  1
453042  90.537  -63.438  55.311  1
453043  90.595  -63.448  55.296  1
453044  90.653  -63.456  55.272  1
453045  90.712  -63.465  55.242  1
453046  90.770  -63.474  55.205  1
453047  90.829  -63.484  55.158  1
453048  90.888  -63.493  55.106  1
453049  90.946  -63.502  55.054  1
453050  91.005  -63.511  55.005  1
453051  91.054  -63.519  54.960  1
453052  91.101  -63.528  54.920  1
453053  91.149  -63.537  54.885  1
453054  91.195  -63.545  54.853  1
453055  91.243  -63.554  54.825  1
453056  91.290  -63.562  54.802  1
453057  91.337  -63.571  54.782  1
453058  91.384  -63.580  54.766  1
453059  91.431  -63.588  54.753  1
453060  91.478  -63.597  54.742  1
453061  91.525  -63.606  54.734  1
453062  91.573  -63.614  54.726  1
453063  91.619  -63.623  54.721  1
453064  91.667  -63.631  54.716  1
453065  91.714  -63.640  54.711  1
453066  91.761  -63.649  54.708  1
453067  91.804  -63.650  54.705  1
453068  91.847  -63.650  54.705  1
453069  91.890  -63.649  54.706  1
453070  91.933  -63.649  54.706  1
453071  91.976  -63.649  54.705  1
453072  92.019  -63.648  54.702  1
453073  92.062  -63.648  54.697  1
453074  92.105  -63.648  54.690  1
453075  92.148  -63.647  54.682  1
453076  92.195  -63.653  54.675  1
453077  92.241  -63.658  54.668  1
453078  92.288  -63.663  54.662  1
453079  92.335  -63.669  54.657  1
453080  92.363  -63.674  54.653  1
453081  92.382  -63.679  54.649  1
453082  92.422  -63.683  54.644  1
453083  92.476  -63.687  54.640  1
453084  92.529  -63.692  54.636  1
453085  92.579  -63.703  54.631  1
453086  92.629  -63.714  54.629  1
453087  92.678  -63.725  54.626  1
453088  92.738  -63.730  54.624  1
453089  92.805  -63.731  54.624  1
453090  92.852  -63.737  54.623  1
453091  92.891  -63.747  54.623  1
453092  92.930  -63.756  54.622  1
453093  92.969  -63.765  54.621  1
453094  93.007  -63.774  54.620  1
453095  93.046  -63.774  54.618  1
453096  93.084  -63.774  54.617  1
453097  93.123  -63.774  54.614  1
453098  93.161  -63.774  54.610  1
453099  93.203  -63.772  54.606  1
453100  93.248  -63.770  54.601  1
453101  93.291  -63.767  54.596  1
453102  93.325  -63.764  54.589  1
453103  93.357  -63.762  54.579  1
453104  93.389  -63.761  54.567  1
453105  93.415  -63.768  54.554  1
453106  93.440  -63.775  54.540  1
453107  93.466  -63.781  54.523  1
453108  93.492  -63.788  54.503  1
453109  93.517  -63.795  54.481  1
453110  93.543  -63.802  54.456  1
453111  93.574  -63.816  54.430  1
453112  93.607  -63.833  54.402  1
453113  93.640  -63.850  54.375  1
453114  93.673  -63.867  54.346  1
453115  93.706  -63.885  54.315  1
453116  93.740  -63.902  54.284  1
453117  93.782  -63.913  54.255  1
453118  93.827  -63.922  54.226  1
453119  93.872  -63.932  54.198  1
453120  93.902  -63.938  54.169  1
453121  93.931  -63.944  54.144  1
453122  93.963  -63.951  54.119  1
453123  94.018  -63.977  54.095  1
453124  94.069  -63.997  54.072  1
453125  94.112  -64.007  54.050  1
453126  94.154  -64.016  54.030  1
453127  94.197  -64.027  54.009  1
453128  94.240  -64.037  53.989  1
453129  94.282  -64.047  53.970  1
453130  94.325  -64.058  53.952  1
453131  94.371  -64.076  53.936  1
453132  94.417  -64.093  53.921  1
453133  94.456  -64.103  53.906  1
453134  94.480  -64.095  53.892  1
453135  94.526  -64.101  53.875  1
453136  94.576  -64.110  53.858  1
453137  94.626  -64.120  53.840  1
453138  94.675  -64.128  53.821  1
453139  94.722  -64.128  53.802  1
453140  94.770  -64.127  53.782  1
453141  94.817  -64.127  53.761  1
453142  94.864  -64.126  53.740  1
453143  94.916  -64.131  53.720  1
453144  94.970  -64.139  53.700  1
453145  95.024  -64.145  53.680  1
453146  95.078  -64.152  53.660  1
453147  95.133  -64.160  53.641  1
453148  95.187  -64.167  53.621  1
453149  95.241  -64.173  53.601  1
453150  95.295  -64.181  53.581  1
453151  95.349  -64.188  53.562  1
453152  95.404  -64.195  53.544  1
453153  95.458  -64.202  53.527  1
453154  95.502  -64.209  53.508  1
453155  95.546  -64.216  53.488  1
453156  95.590  -64.222  53.463  1
453157  95.634  -64.229  53.436  1
453158  95.678  -64.236  53.410  1
453159  95.718  -64.238  53.383  1
453160  95.745  -64.228  53.357  1
453161  95.771  -64.217  53.331  1
453162  95.804  -64.217  53.304  1
453163  95.837  -64.220  53.279  1
453164  95.872  -64.223  53.256  1
453165  95.905  -64.226  53.231  1
453166  95.939  -64.229  53.203  1
453167  95.973  -64.233  53.173  1
453168  96.008  -64.235  53.140  1
453169  96.049  -64.217  53.104  1
453170  96.092  -64.199  53.073  1
453171  96.136  -64.191  53.046  1
453172  96.182  -64.183  53.023  1
453173  96.227  -64.176  53.003  1
453174  96.276  -64.179  52.983  1
453175  96.327  -64.188  52.961  1
453176  96.379  -64.197  52.937  1
453177  96.431  -64.207  52.910  1
453178  96.482  -64.216  52.881  1
453179  96.519  -64.220  52.850  1
453180  96.553  -64.221  52.816  1
453181  96.587  -64.223  52.781  1
453182  96.620  -64.226  52.746  1
453183  96.654  -64.227  52.710  1
453184  96.689  -64.231  52.673  1
453185  96.727  -64.236  52.631  1
453186  96.763  -64.240  52.586  1
453187  96.801  -64.245  52.537  1
453188  96.838  -64.250  52.487  1
453189  96.875  -64.255  52.438  1
453190  96.912  -64.259  52.389  1
453191  96.951  -64.263  52.341  1
453192  96.992  -64.267  52.294  1
453193  97.031  -64.270  52.251  1
453194  97.071  -64.274  52.212  1
453195  97.111  -64.279  52.173  1
453196  97.151  -64.283  52.131  1
453197  97.191  -64.286  52.087  1
453198  97.231  -64.290  52.039  1
453199  97.270  -64.294  51.991  1
453200  97.311  -64.298  51.943  1
453201  97.349  -64.299  51.897  1
453202  97.377  -64.289  51.851  1
453203  97.406  -64.277  51.807  1
453204  97.435  -64.284  51.766  1
453205  97.463  -64.291  51.724  1
453206  97.491  -64.298  51.680  1
453207  97.519  -64.305  51.635  1
453208  97.548  -64.312  51.588  1
453209  97.576  -64.319  51.542  1
453210  97.604  -64.327  51.494  1
453211  97.641  -64.327  51.446  1
453212  97.682  -64.322  51.399  1
453213  97.723  -64.318  51.353  1
453214  97.764  -64.314  51.307  1
453215  97.804  -64.310  51.261  1
453216  97.845  -64.306  51.214  1
453217  97.887  -64.298  51.166  1
453218  97.920  -64.298  51.117  1
453219  97.946  -64.303  51.067  1
453220  97.972  -64.308  51.016  1
453221  97.999  -64.312  50.964  1
453222  98.025  -64.317  50.912  1
453223  98.052  -64.321  50.859  1
453224  98.078  -64.326  50.807  1
453225  98.104  -64.330  50.755  1
453226  98.131  -64.336  50.705  1
453227  98.157  -64.340  50.656  1
453228  98.189  -64.342  50.607  1
453229  98.227  -64.337  50.559  1
453230  98.270  -64.336  50.511  1
453231  98.314  -64.339  50.463  1
453232  98.359  -64.343  50.415  1
453233  98.406  -64.342  50.367  1
453234  98.454  -64.336  50.320  1
453235  98.504  -64.330  50.273  1
453236  98.553  -64.323  50.227  1
453237  98.601  -64.317  50.182  1
453238  98.647  -64.320  50.137  1
453239  98.693  -64.323  50.092  1
453240  98.738  -64.326  50.049  1
453241  98.784  -64.329  50.005  1
453242  98.830  -64.332  49.960  1
453243  98.876  -64.334  49.916  1
453244  98.923  -64.336  49.871  1
453245  98.970  -64.339  49.825  1
453246  99.007  -64.342  49.779  1
453247  99.044  -64.346  49.734  1
453248  99.081  -64.350  49.691  1
453249  99.119  -64.354  49.647  1
453250  99.156  -64.357  49.603  1
453251  99.193  -64.361  49.561  1
453252  99.230  -64.364  49.519  1
453253  99.268  -64.368  49.478  1
453254  99.305  -64.372  49.437  1
453255  99.343  -64.375  49.397  1
453256  99.365  -64.381  49.358  1
453257  99.385  -64.387  49.319  1
453258  99.456  -64.392  49.280  1
453259  99.528  -64.398  49.241  1
453260  99.599  -64.403  49.202  1
453261  99.670  -64.408  49.164  1
453262  99.742  -64.413  49.127  1
453263  99.812  -64.418  49.089  1
453264  99.877  -64.418  49.051  1
453265  99.940  -64.417  49.014  1
453266  100.003  -64.414  48.976  1
453267  100.066  -64.413  48.940  1
453268  100.129  -64.411  48.904  1
453269  100.192  -64.409  48.869  1
453270  100.238  -64.411  48.834  1
453271  100.279  -64.415  48.797  1
453272  100.315  -64.423  48.762  1
453273  100.351  -64.430  48.728  1
453274  100.387  -64.438  48.694  1
453275  100.422  -64.446  48.660  1
453276  100.458  -64.452  48.626  1
453277  100.494  -64.460  48.592  1
453278  100.529  -64.468  48.558  1
453279  100.565  -64.475  48.524  1
453657  86.853  -62.704  56.091  1
453658  86.881  -62.710  56.078  1
453659  86.909  -62.717  56.064  1
453660  86.937  -62.723  56.051  1
453661  86.966  -62.730  56.038  1
453662  86.994  -62.737  56.026  1
453663  87.022  -62.743  56.012  1
453664  87.050  -62.750  55.998  1
453665  87.078  -62.756  55.983  1
453666  87.106  -62.763  55.966  1
453667  87.134  -62.769  55.950  1
453668  87.162  -62.775  55.935  1
453669  87.190  -62.782  55.919  1
453670  87.235  -62.779  55.903  1
453671  87.284  -62.775  55.886  1
453672  87.333  -62.770  55.870  1
453673  87.382  -62.765  55.854  1
453674  87.431  -62.760  55.840  1
453675  87.480  -62.756  55.826  1
453676  87.529  -62.751  55.815  1
453677  87.578  -62.747  55.804  1
453678  87.627  -62.743  55.793  1
453679  87.677  -62.752  55.780  1
453680  87.727  -62.760  55.765  1
453681  87.778  -62.769  55.750  1
453682  87.829  -62.778  55.735  1
453683  87.879  -62.788  55.722  1
453684  87.930  -62.797  55.711  1
453685  87.980  -62.805  55.702  1
453686  88.031  -62.814  55.689  1
453687  88.081  -62.823  55.675  1
453688  88.132  -62.832  55.661  1
453689  88.182  -62.841  55.644  1
453690  88.233  -62.850  55.626  1
453691  88.283  -62.859  55.606  1
453692  88.334  -62.868  55.587  1
453693  88.384  -62.877  55.567  1
453694  88.434  -62.886  55.547  1
453695  88.485  -62.894  55.525  1
453696  88.535  -62.904  55.504  1
453697  88.577  -62.919  55.484  1
453698  88.620  -62.935  55.466  1
453699  88.662  -62.951  55.447  1
453700  88.705  -62.966  55.430  1
453701  88.747  -62.981  55.415  1
453702  88.790  -62.996  55.402  1
453703  88.832  -63.011  55.391  1
453704  88.875  -63.026  55.383  1
453705  88.917  -63.042  55.377  1
453706  88.960  -63.057  55.373  1
453707  89.002  -63.073  55.370  1
453708  89.045  -63.088  55.368  1
453709  89.088  -63.103  55.367  1
453710  89.130  -63.118  55.368  1
453711  89.173  -63.134  55.367  1
453712  89.215  -63.149  55.367  1
453713  89.258  -63.164  55.366  1
453714  89.301  -63.180  55.363  1
453715  89.356  -63.169  55.361  1
453716  89.412  -63.156  55.362  1
453717  89.467  -63.147  55.366  1
453718  89.514  -63.158  55.373  1
453719  89.560  -63.170  55.385  1
453720  89.605  -63.190  55.395  1
453721  89.650  -63.210  55.402  1
453722  89.695  -63.230  55.404  1
453723  89.742  -63.242  55.399  1
453724  89.789  -63.251  55.391  1
453725  89.836  -63.260  55.378  1
453726  89.883  -63.269  55.364  1
453727  89.929  -63.272  55.349  1
453728  89.974  -63.274  55.335  1
453729  90.020  -63.275  55.317  1
453730  90.065  -63.277  55.297  1
453731  90.110  -63.277  55.282  1
453732  90.156  -63.279  55.271  1
453733  90.201  -63.280  55.264  1
453734  90.247  -63.282  55.262  1
453735  90.290  -63.284  55.266  1
453736  90.303  -63.302  55.276  1
453737  90.317  -63.321  55.290  1
453738  90.330  -63.338  55.303  1
453739  90.343  -63.356  55.307  1
453740  90.383  -63.370  55.307  1
453741  90.433  -63.381  55.306  1
453742  90.482  -63.393  55.302  1
453743  90.539  -63.402  55.290  1
453744  90.598  -63.412  55.274  1
453745  90.656  -63.421  55.250  1
453746  90.715  -63.430  55.219  1
453747  90.773  -63.439  55.181  1
453748  90.832  -63.447  55.135  1
453749  90.891  -63.456  55.086  1
453750  90.950  -63.465  55.038  1
453751  91.008  -63.474  54.993  1
453752  91.067  -63.484  54.953  1
453753  91.115  -63.492  54.915  1
453754  91.162  -63.501  54.881  1
453755  91.210  -63.509  54.851  1
453756  91.256  -63.518  54.825  1
453757  91.304  -63.527  54.802  1
453758  91.351  -63.535  54.784  1
453759  91.398  -63.544  54.769  1
453760  91.445  -63.553  54.757  1
453761  91.492  -63.562  54.746  1
453762  91.539  -63.570  54.738  1
453763  91.586  -63.578  54.731  1
453764  91.634  -63.587  54.726  1
453765  91.680  -63.596  54.721  1
453766  91.726  -63.602  54.717  1
453767  91.770  -63.601  54.715  1
453768  91.812  -63.601  54.712  1
453769  91.855  -63.601  54.714  1
453770  91.898  -63.600  54.716  1
453771  91.941  -63.600  54.717  1
453772  91.984  -63.600  54.716  1
453773  92.027  -63.600  54.710  1
453774  92.070  -63.600  54.705  1
453775  92.113  -63.600  54.698  1
453776  92.157  -63.601  54.690  1
453777  92.204  -63.606  54.682  1
453778  92.250  -63.612  54.675  1
453779  92.297  -63.617  54.668  1
453780  92.344  -63.622  54.663  1
453781  92.375  -63.628  54.659  1
453782  92.402  -63.633  54.655  1
453783  92.455  -63.636  54.650  1
453784  92.509  -63.640  54.645  1
453785  92.563  -63.643  54.641  1
453786  92.616  -63.648  54.637  1
453787  92.665  -63.659  54.634  1
453788  92.717  -63.669  54.631  1
453789  92.784  -63.670  54.630  1
453790  92.823  -63.679  54.628  1
453791  92.861  -63.688  54.627  1
453792  92.900  -63.697  54.627  1
453793  92.939  -63.706  54.626  1
453794  92.978  -63.715  54.625  1
453795  93.016  -63.721  54.623  1
453796  93.055  -63.721  54.621  1
453797  93.093  -63.721  54.618  1
453798  93.132  -63.721  54.614  1
453799  93.170  -63.721  54.609  1
453800  93.209  -63.721  54.604  1
453801  93.254  -63.718  54.599  1
453802  93.295  -63.715  54.591  1
453803  93.329  -63.712  54.582  1
453804  93.362  -63.709  54.571  1
453805  93.395  -63.706  54.558  1
453806  93.424  -63.709  54.545  1
453807  93.450  -63.715  54.529  1
453808  93.476  -63.722  54.511  1
453809  93.501  -63.729  54.491  1
453810  93.527  -63.736  54.469  1
453811  93.553  -63.743  54.445  1
453812  93.585  -63.759  54.418  1
453813  93.619  -63.777  54.391  1
453814  93.652  -63.794  54.362  1
453815  93.685  -63.811  54.333  1
453816  93.718  -63.828  54.302  1
453817  93.751  -63.846  54.272  1
453818  93.784  -63.863  54.241  1
453819  93.824  -63.876  54.210  1
453820  93.865  -63.885  54.180  1
453821  93.894  -63.891  54.150  1
453822  93.946  -63.913  54.122  1
453823  93.988  -63.922  54.096  1
453824  94.031  -63.932  54.071  1
453825  94.073  -63.943  54.049  1
453826  94.116  -63.953  54.028  1
453827  94.158  -63.963  54.007  1
453828  94.201  -63.973  53.987  1
453829  94.244  -63.983  53.966  1
453830  94.286  -63.993  53.947  1
453831  94.330  -64.005  53.929  1
453832  94.376  -64.023  53.918  1
453833  94.422  -64.040  53.905  1
453834  94.468  -64.057  53.893  1
453835  94.509  -64.070  53.880  1
453836  94.540  -64.066  53.864  1
453837  94.590  -64.076  53.848  1
453838  94.639  -64.085  53.830  1
453839  94.687  -64.086  53.811  1
453840  94.734  -64.085  53.791  1
453841  94.781  -64.085  53.771  1
453842  94.829  -64.085  53.750  1
453843  94.876  -64.084  53.729  1
453844  94.926  -64.087  53.709  1
453845  94.980  -64.094  53.689  1
453846  95.035  -64.101  53.669  1
453847  95.089  -64.108  53.650  1
453848  95.143  -64.115  53.631  1
453849  95.197  -64.123  53.610  1
453850  95.251  -64.129  53.590  1
453851  95.306  -64.136  53.570  1
453852  95.359  -64.144  53.551  1
453853  95.411  -64.151  53.532  1
453854  95.456  -64.157  53.514  1
453855  95.499  -64.164  53.495  1
453856  95.543  -64.170  53.474  1
453857  95.588  -64.177  53.450  1
453858  95.631  -64.184  53.424  1
453859  95.675  -64.191  53.397  1
453860  95.713  -64.192  53.370  1
453861  95.740  -64.181  53.344  1
453862  95.767  -64.171  53.318  1
453863  95.796  -64.165  53.292  1
453864  95.830  -64.168  53.268  1
453865  95.864  -64.171  53.246  1
453866  95.898  -64.174  53.222  1
453867  95.932  -64.177  53.196  1
453868  95.966  -64.180  53.167  1
453869  96.008  -64.163  53.136  1
453870  96.049  -64.145  53.101  1
453871  96.093  -64.132  53.069  1
453872  96.138  -64.125  53.041  1
453873  96.183  -64.117  53.018  1
453874  96.234  -64.123  52.998  1
453875  96.285  -64.132  52.979  1
453876  96.336  -64.141  52.958  1
453877  96.388  -64.151  52.935  1
453878  96.439  -64.160  52.910  1
453879  96.491  -64.169  52.881  1
453880  96.530  -64.173  52.849  1
453881  96.564  -64.176  52.814  1
453882  96.598  -64.177  52.778  1
453883  96.631  -64.179  52.741  1
453884  96.665  -64.182  52.702  1
453885  96.701  -64.186  52.662  1
453886  96.738  -64.190  52.618  1
453887  96.776  -64.195  52.572  1
453888  96.812  -64.199  52.523  1
453889  96.850  -64.204  52.474  1
453890  96.887  -64.209  52.426  1
453891  96.924  -64.214  52.378  1
453892  96.961  -64.218  52.331  1
453893  96.998  -64.223  52.285  1
453894  97.037  -64.227  52.242  1
453895  97.077  -64.231  52.201  1
453896  97.117  -64.235  52.162  1
453897  97.157  -64.239  52.121  1
453898  97.196  -64.242  52.077  1
453899  97.236  -64.246  52.029  1
453900  97.277  -64.250  51.981  1
453901  97.316  -64.254  51.933  1
453902  97.356  -64.258  51.888  1
453903  97.385  -64.247  51.844  1
453904  97.414  -64.240  51.802  1
453905  97.442  -64.248  51.761  1
453906  97.470  -64.255  51.719  1
453907  97.498  -64.261  51.675  1
453908  97.527  -64.269  51.630  1
453909  97.555  -64.276  51.585  1
453910  97.583  -64.283  51.538  1
453911  97.611  -64.290  51.490  1
453912  97.641  -64.296  51.442  1
453913  97.682  -64.292  51.395  1
453914  97.723  -64.288  51.349  1
453915  97.764  -64.283  51.303  1
453916  97.805  -64.280  51.257  1
453917  97.846  -64.274  51.210  1
453918  97.888  -64.266  51.161  1
453919  97.919  -64.267  51.112  1
453920  97.945  -64.271  51.062  1
453921  97.972  -64.276  51.011  1
453922  97.998  -64.280  50.958  1
453923  98.025  -64.286  50.905  1
453924  98.051  -64.290  50.852  1
453925  98.078  -64.295  50.799  1
453926  98.104  -64.299  50.747  1
453927  98.131  -64.304  50.696  1
453928  98.164  -64.305  50.647  1
453929  98.200  -64.306  50.596  1
453930  98.237  -64.301  50.548  1
453931  98.277  -64.292  50.500  1
453932  98.318  -64.289  50.452  1
453933  98.363  -64.293  50.404  1
453934  98.411  -64.289  50.356  1
453935  98.459  -64.283  50.308  1
453936  98.508  -64.279  50.261  1
453937  98.554  -64.282  50.214  1
453938  98.599  -64.285  50.168  1
453939  98.645  -64.288  50.123  1
453940  98.691  -64.290  50.079  1
453941  98.736  -64.293  50.034  1
453942  98.782  -64.296  49.990  1
453943  98.829  -64.299  49.945  1
453944  98.875  -64.302  49.902  1
453945  98.922  -64.304  49.856  1
453946  98.967  -64.306  49.810  1
453947  99.004  -64.310  49.764  1
453948  99.042  -64.314  49.719  1
453949  99.079  -64.317  49.675  1
453950  99.116  -64.320  49.632  1
453951  99.153  -64.324  49.588  1
453952  99.191  -64.328  49.545  1
453953  99.228  -64.332  49.503  1
453954  99.266  -64.335  49.462  1
453955  99.300  -64.339  49.422  1
453956  99.320  -64.345  49.382  1
453957  99.339  -64.352  49.343  1
453958  99.404  -64.357  49.305  1
453959  99.475  -64.362  49.265  1
453960  99.546  -64.367  49.226  1
453961  99.618  -64.373  49.188  1
453962  99.689  -64.377  49.150  1
453963  99.760  -64.383  49.113  1
453964  99.823  -64.381  49.075  1
453965  99.886  -64.380  49.037  1
453966  99.949  -64.378  48.999  1
453967  100.012  -64.376  48.962  1
453968  100.075  -64.374  48.927  1
453969  100.138  -64.372  48.891  1
453970  100.201  -64.371  48.856  1
453971  100.243  -64.372  48.821  1
453972  100.280  -64.379  48.785  1
453973  100.316  -64.386  48.750  1
453974  100.352  -64.393  48.717  1
453975  100.388  -64.401  48.684  1
453976  100.423  -64.408  48.651  1
453977  100.459  -64.416  48.616  1
453978  100.494  -64.424  48.583  1
453979  100.530  -64.431  48.550  1
454357  86.793  -62.675  56.115  1
454358  86.836  -62.674  56.102  1
454359  86.878  -62.672  56.089  1
454360  86.913  -62.675  56.077  1
454361  86.941  -62.681  56.064  1
454362  86.970  -62.688  56.051  1
454363  86.998  -62.694  56.039  1
454364  87.025  -62.700  56.025  1
454365  87.054  -62.707  56.010  1
454366  87.082  -62.713  55.994  1
454367  87.110  -62.720  55.979  1
454368  87.138  -62.726  55.963  1
454369  87.166  -62.733  55.947  1
454370  87.213  -62.729  55.931  1
454371  87.262  -62.725  55.914  1
454372  87.311  -62.720  55.896  1
454373  87.360  -62.716  55.878  1
454374  87.409  -62.710  55.862  1
454375  87.458  -62.706  55.846  1
454376  87.506  -62.701  55.831  1
454377  87.555  -62.697  55.818  1
454378  87.604  -62.692  55.806  1
454379  87.653  -62.687  55.793  1
454380  87.703  -62.690  55.779  1
454381  87.753  -62.699  55.765  1
454382  87.804  -62.707  55.752  1
454383  87.854  -62.716  55.740  1
454384  87.905  -62.725  55.730  1
454385  87.955  -62.735  55.722  1
454386  88.006  -62.744  55.716  1
454387  88.056  -62.752  55.705  1
454388  88.107  -62.761  55.693  1
454389  88.157  -62.770  55.678  1
454390  88.208  -62.779  55.661  1
454391  88.258  -62.788  55.640  1
454392  88.309  -62.797  55.620  1
454393  88.359  -62.806  55.600  1
454394  88.410  -62.815  55.579  1
454395  88.454  -62.829  55.558  1
454396  88.497  -62.844  55.536  1
454397  88.539  -62.859  55.514  1
454398  88.582  -62.874  55.494  1
454399  88.624  -62.889  55.474  1
454400  88.667  -62.905  55.456  1
454401  88.709  -62.920  55.438  1
454402  88.752  -62.935  55.422  1
454403  88.794  -62.951  55.408  1
454404  88.837  -62.966  55.395  1
454405  88.880  -62.981  55.386  1
454406  88.922  -62.997  55.380  1
454407  88.965  -63.012  55.376  1
454408  89.008  -63.027  55.372  1
454409  89.050  -63.042  55.370  1
454410  89.093  -63.057  55.368  1
454411  89.135  -63.073  55.368  1
454412  89.178  -63.088  55.368  1
454413  89.220  -63.104  55.367  1
454414  89.263  -63.119  55.364  1
454415  89.309  -63.126  55.360  1
454416  89.366  -63.114  55.357  1
454417  89.422  -63.101  55.356  1
454418  89.477  -63.092  55.358  1
454419  89.524  -63.103  55.362  1
454420  89.569  -63.122  55.372  1
454421  89.614  -63.142  55.383  1
454422  89.659  -63.162  55.390  1
454423  89.703  -63.183  55.391  1
454424  89.750  -63.193  55.388  1
454425  89.797  -63.203  55.382  1
454426  89.844  -63.212  55.371  1
454427  89.891  -63.221  55.359  1
454428  89.938  -63.230  55.346  1
454429  89.984  -63.233  55.334  1
454430  90.029  -63.235  55.315  1
454431  90.075  -63.236  55.294  1
454432  90.120  -63.238  55.276  1
454433  90.166  -63.239  55.263  1
454434  90.211  -63.240  55.254  1
454435  90.256  -63.242  55.250  1
454436  90.289  -63.250  55.250  1
454437  90.303  -63.267  55.256  1
454438  90.316  -63.286  55.265  1
454439  90.329  -63.304  55.274  1
454440  90.343  -63.321  55.278  1
454441  90.378  -63.336  55.280  1
454442  90.428  -63.347  55.280  1
454443  90.483  -63.357  55.274  1
454444  90.542  -63.366  55.263  1
454445  90.601  -63.375  55.246  1
454446  90.659  -63.384  55.224  1
454447  90.718  -63.393  55.195  1
454448  90.777  -63.402  55.159  1
454449  90.835  -63.412  55.114  1
454450  90.894  -63.421  55.068  1
454451  90.953  -63.430  55.024  1
454452  91.011  -63.438  54.983  1
454453  91.070  -63.447  54.945  1
454454  91.129  -63.456  54.909  1
454455  91.176  -63.465  54.877  1
454456  91.223  -63.474  54.848  1
454457  91.271  -63.482  54.824  1
454458  91.317  -63.491  54.804  1
454459  91.365  -63.499  54.788  1
454460  91.412  -63.509  54.773  1
454461  91.459  -63.517  54.761  1
454462  91.506  -63.525  54.751  1
454463  91.553  -63.534  54.743  1
454464  91.600  -63.543  54.736  1
454465  91.647  -63.551  54.731  1
454466  91.692  -63.553  54.727  1
454467  91.734  -63.553  54.724  1
454468  91.777  -63.553  54.721  1
454469  91.820  -63.553  54.720  1
454470  91.863  -63.553  54.723  1
454471  91.906  -63.553  54.725  1
454472  91.949  -63.552  54.726  1
454473  91.992  -63.552  54.725  1
454474  92.035  -63.552  54.718  1
454475  92.078  -63.551  54.711  1
454476  92.121  -63.551  54.704  1
454477  92.166  -63.555  54.696  1
454478  92.213  -63.560  54.687  1
454479  92.260  -63.565  54.680  1
454480  92.306  -63.571  54.674  1
454481  92.353  -63.576  54.669  1
454482  92.388  -63.581  54.665  1
454483  92.435  -63.585  54.661  1
454484  92.488  -63.589  54.656  1
454485  92.542  -63.593  54.651  1
454486  92.596  -63.596  54.646  1
454487  92.649  -63.600  54.641  1
454488  92.703  -63.604  54.638  1
454489  92.754  -63.612  54.636  1
454490  92.793  -63.621  54.634  1
454491  92.832  -63.630  54.632  1
454492  92.870  -63.639  54.631  1
454493  92.910  -63.648  54.630  1
454494  92.948  -63.658  54.629  1
454495  92.987  -63.667  54.627  1
454496  93.025  -63.668  54.625  1
454497  93.064  -63.668  54.622  1
454498  93.102  -63.668  54.617  1
454499  93.141  -63.668  54.612  1
454500  93.179  -63.668  54.607  1
454501  93.217  -63.668  54.601  1
454502  93.261  -63.665  54.594  1
454503  93.300  -63.663  54.585  1
454504  93.333  -63.660  54.574  1
454505  93.366  -63.657  54.561  1
454506  93.399  -63.654  54.547  1
454507  93.432  -63.652  54.531  1
454508  93.460  -63.656  54.514  1
454509  93.485  -63.663  54.496  1
454510  93.511  -63.670  54.475  1
454511  93.537  -63.677  54.454  1
454512  93.564  -63.687  54.429  1
454513  93.597  -63.703  54.403  1
454514  93.630  -63.721  54.376  1
454515  93.663  -63.737  54.347  1
454516  93.697  -63.755  54.318  1
454517  93.730  -63.772  54.288  1
454518  93.763  -63.789  54.257  1
454519  93.796  -63.806  54.226  1
454520  93.829  -63.824  54.195  1
454521  93.866  -63.839  54.164  1
454522  93.908  -63.848  54.134  1
454523  93.951  -63.858  54.104  1
454524  93.993  -63.869  54.076  1
454525  94.036  -63.878  54.051  1
454526  94.078  -63.888  54.028  1
454527  94.121  -63.899  54.006  1
454528  94.163  -63.909  53.986  1
454529  94.206  -63.919  53.966  1
454530  94.248  -63.929  53.947  1
454531  94.291  -63.939  53.928  1
454532  94.335  -63.952  53.913  1
454533  94.381  -63.969  53.903  1
454534  94.426  -63.987  53.893  1
454535  94.472  -64.004  53.882  1
454536  94.518  -64.022  53.870  1
454537  94.561  -64.036  53.857  1
454538  94.603  -64.041  53.841  1
454539  94.651  -64.044  53.823  1
454540  94.699  -64.044  53.803  1
454541  94.746  -64.043  53.783  1
454542  94.793  -64.043  53.762  1
454543  94.841  -64.042  53.741  1
454544  94.888  -64.042  53.720  1
454545  94.936  -64.042  53.699  1
454546  94.990  -64.050  53.680  1
454547  95.045  -64.057  53.660  1
454548  95.099  -64.064  53.642  1
454549  95.153  -64.071  53.623  1
454550  95.207  -64.078  53.601  1
454551  95.261  -64.085  53.581  1
454552  95.316  -64.092  53.561  1
454553  95.365  -64.099  53.542  1
454554  95.409  -64.106  53.522  1
454555  95.453  -64.113  53.503  1
454556  95.496  -64.120  53.483  1
454557  95.541  -64.126  53.461  1
454558  95.585  -64.132  53.438  1
454559  95.628  -64.139  53.412  1
454560  95.673  -64.146  53.386  1
454561  95.709  -64.145  53.359  1
454562  95.736  -64.135  53.332  1
454563  95.763  -64.124  53.306  1
454564  95.790  -64.114  53.280  1
454565  95.823  -64.116  53.256  1
454566  95.856  -64.119  53.234  1
454567  95.890  -64.122  53.212  1
454568  95.924  -64.125  53.188  1
454569  95.965  -64.110  53.160  1
454570  96.008  -64.092  53.130  1
454571  96.050  -64.074  53.096  1
454572  96.095  -64.066  53.063  1
454573  96.140  -64.058  53.035  1
454574  96.191  -64.067  53.011  1
454575  96.242  -64.076  52.991  1
454576  96.294  -64.085  52.974  1
454577  96.345  -64.095  52.953  1
454578  96.397  -64.104  52.930  1
454579  96.448  -64.113  52.905  1
454580  96.500  -64.122  52.876  1
454581  96.541  -64.127  52.842  1
454582  96.575  -64.129  52.806  1
454583  96.609  -64.132  52.768  1
454584  96.643  -64.134  52.730  1
454585  96.676  -64.135  52.690  1
454586  96.713  -64.140  52.650  1
454587  96.750  -64.145  52.605  1
454588  96.787  -64.149  52.558  1
454589  96.824  -64.154  52.510  1
454590  96.861  -64.159  52.461  1
454591  96.898  -64.164  52.413  1
454592  96.936  -64.168  52.366  1
454593  96.972  -64.173  52.319  1
454594  97.010  -64.178  52.275  1
454595  97.047  -64.182  52.233  1
454596  97.084  -64.187  52.192  1
454597  97.122  -64.192  52.151  1
454598  97.162  -64.195  52.110  1
454599  97.202  -64.199  52.065  1
454600  97.242  -64.203  52.017  1
454601  97.282  -64.207  51.969  1
454602  97.322  -64.211  51.923  1
454603  97.362  -64.214  51.879  1
454604  97.392  -64.206  51.837  1
454605  97.421  -64.204  51.797  1
454606  97.449  -64.211  51.756  1
454607  97.477  -64.218  51.714  1
454608  97.506  -64.225  51.670  1
454609  97.534  -64.232  51.626  1
454610  97.562  -64.239  51.580  1
454611  97.590  -64.246  51.534  1
454612  97.619  -64.253  51.487  1
454613  97.647  -64.261  51.439  1
454614  97.682  -64.261  51.391  1
454615  97.723  -64.258  51.345  1
454616  97.764  -64.253  51.299  1
454617  97.805  -64.249  51.252  1
454618  97.847  -64.242  51.205  1
454619  97.889  -64.233  51.157  1
454620  97.919  -64.235  51.109  1
454621  97.945  -64.240  51.059  1
454622  97.971  -64.245  51.006  1
454623  97.998  -64.249  50.953  1
454624  98.024  -64.254  50.898  1
454625  98.051  -64.258  50.845  1
454626  98.077  -64.263  50.792  1
454627  98.104  -64.267  50.740  1
454628  98.139  -64.269  50.689  1
454629  98.174  -64.270  50.638  1
454630  98.210  -64.270  50.587  1
454631  98.248  -64.265  50.538  1
454632  98.287  -64.256  50.489  1
454633  98.326  -64.248  50.441  1
454634  98.367  -64.243  50.394  1
454635  98.414  -64.241  50.346  1
454636  98.460  -64.243  50.298  1
454637  98.506  -64.246  50.250  1
454638  98.552  -64.249  50.202  1
454639  98.597  -64.252  50.155  1
454640  98.643  -64.255  50.111  1
454641  98.689  -64.258  50.066  1
454642  98.734  -64.261  50.021  1
454643  98.780  -64.264  49.976  1
454644  98.827  -64.266  49.931  1
454645  98.874  -64.268  49.888  1
454646  98.921  -64.270  49.842  1
454647  98.964  -64.273  49.796  1
454648  99.002  -64.277  49.750  1
454649  99.039  -64.280  49.706  1
454650  99.076  -64.284  49.662  1
454651  99.114  -64.288  49.618  1
454652  99.151  -64.292  49.574  1
454653  99.189  -64.295  49.531  1
454654  99.226  -64.298  49.488  1
454655  99.256  -64.303  49.447  1
454656  99.275  -64.309  49.407  1
454657  99.294  -64.316  49.366  1
454658  99.351  -64.321  49.327  1
454659  99.422  -64.327  49.290  1
454660  99.494  -64.332  49.251  1
454661  99.565  -64.337  49.211  1
454662  99.636  -64.342  49.173  1
454663  99.706  -64.346  49.135  1
454664  99.769  -64.344  49.098  1
454665  99.832  -64.342  49.060  1
454666  99.895  -64.341  49.023  1
454667  99.958  -64.339  48.985  1
454668  100.020  -64.337  48.948  1
454669  100.083  -64.335  48.913  1
454670  100.146  -64.333  48.878  1
454671  100.206  -64.332  48.843  1
454672  100.246  -64.334  48.808  1
454673  100.281  -64.342  48.773  1
454674  100.317  -64.349  48.739  1
454675  100.353  -64.357  48.706  1
454676  100.388  -64.364  48.674  1
454677  100.424  -64.372  48.641  1
455058  86.773  -62.647  56.126  1
455059  86.815  -62.644  56.112  1
455060  86.858  -62.643  56.100  1
455061  86.901  -62.641  56.088  1
455062  86.944  -62.639  56.076  1
455063  86.974  -62.645  56.064  1
455064  87.001  -62.652  56.051  1
455065  87.029  -62.658  56.037  1
455066  87.058  -62.665  56.022  1
455067  87.086  -62.671  56.006  1
455068  87.114  -62.678  55.991  1
455069  87.142  -62.684  55.976  1
455070  87.191  -62.679  55.960  1
455071  87.239  -62.675  55.942  1
455072  87.288  -62.670  55.924  1
455073  87.337  -62.666  55.906  1
455074  87.386  -62.661  55.888  1
455075  87.435  -62.656  55.870  1
455076  87.484  -62.651  55.854  1
455077  87.533  -62.647  55.837  1
455078  87.582  -62.642  55.821  1
455079  87.631  -62.637  55.806  1
455080  87.680  -62.632  55.793  1
455081  87.728  -62.628  55.780  1
455082  87.779  -62.637  55.766  1
455083  87.829  -62.646  55.755  1
455084  87.880  -62.654  55.746  1
455085  87.930  -62.663  55.738  1
455086  87.981  -62.672  55.732  1
455087  88.031  -62.681  55.728  1
455088  88.082  -62.691  55.721  1
455089  88.132  -62.699  55.710  1
455090  88.183  -62.708  55.696  1
455091  88.234  -62.717  55.678  1
455092  88.284  -62.726  55.655  1
455093  88.332  -62.737  55.634  1
455094  88.374  -62.753  55.612  1
455095  88.417  -62.768  55.589  1
455096  88.459  -62.783  55.568  1
455097  88.502  -62.798  55.545  1
455098  88.544  -62.813  55.523  1
455099  88.587  -62.829  55.502  1
455100  88.629  -62.844  55.482  1
455101  88.672  -62.860  55.463  1
455102  88.714  -62.875  55.444  1
455103  88.757  -62.890  55.428  1
455104  88.800  -62.905  55.414  1
455105  88.842  -62.920  55.401  1
455106  88.885  -62.935  55.390  1
455107  88.927  -62.951  55.383  1
455108  88.970  -62.967  55.378  1
455109  89.013  -62.982  55.374  1
455110  89.055  -62.997  55.371  1
455111  89.098  -63.012  55.368  1
455112  89.140  -63.027  55.368  1
455113  89.183  -63.042  55.368  1
455114  89.225  -63.058  55.366  1
455115  89.268  -63.073  55.363  1
455116  89.319  -63.071  55.357  1
455117  89.375  -63.059  55.353  1
455118  89.431  -63.046  55.350  1
455119  89.487  -63.036  55.349  1
455120  89.532  -63.054  55.352  1
455121  89.577  -63.074  55.358  1
455122  89.622  -63.095  55.368  1
455123  89.667  -63.114  55.375  1
455124  89.711  -63.135  55.378  1
455125  89.758  -63.145  55.376  1
455126  89.805  -63.155  55.371  1
455127  89.852  -63.164  55.362  1
455128  89.899  -63.173  55.351  1
455129  89.946  -63.183  55.341  1
455130  89.993  -63.192  55.329  1
455131  90.039  -63.195  55.312  1
455132  90.085  -63.196  55.290  1
455133  90.130  -63.198  55.271  1
455134  90.175  -63.199  55.255  1
455135  90.221  -63.200  55.245  1
455136  90.266  -63.202  55.238  1
455137  90.289  -63.215  55.235  1
455138  90.302  -63.233  55.235  1
455139  90.315  -63.251  55.239  1
455140  90.329  -63.269  55.244  1
455141  90.342  -63.287  55.247  1
455142  90.373  -63.302  55.251  1
455143  90.428  -63.312  55.251  1
455144  90.486  -63.321  55.245  1
455145  90.545  -63.330  55.234  1
455146  90.604  -63.339  55.219  1
455147  90.662  -63.348  55.198  1
455148  90.721  -63.357  55.170  1
455149  90.780  -63.366  55.135  1
455150  90.838  -63.375  55.092  1
455151  90.897  -63.384  55.049  1
455152  90.956  -63.393  55.009  1
455153  91.014  -63.402  54.972  1
455154  91.073  -63.412  54.937  1
455155  91.132  -63.421  54.904  1
455156  91.190  -63.430  54.874  1
455157  91.237  -63.438  54.848  1
455158  91.284  -63.446  54.826  1
455159  91.331  -63.455  54.806  1
455160  91.378  -63.464  54.792  1
455161  91.426  -63.472  54.778  1
455162  91.472  -63.481  54.767  1
455163  91.520  -63.490  54.757  1
455164  91.567  -63.499  54.749  1
455165  91.613  -63.506  54.743  1
455166  91.656  -63.506  54.737  1
455167  91.699  -63.505  54.733  1
455168  91.742  -63.505  54.731  1
455169  91.785  -63.505  54.728  1
455170  91.828  -63.504  54.729  1
455171  91.871  -63.504  54.732  1
455172  91.914  -63.504  54.735  1
455173  91.957  -63.504  54.735  1
455174  92.000  -63.503  54.733  1
455175  92.043  -63.503  54.726  1
455176  92.086  -63.503  54.718  1
455177  92.129  -63.503  54.710  1
455178  92.176  -63.509  54.702  1
455179  92.222  -63.514  54.692  1
455180  92.269  -63.519  54.685  1
455181  92.316  -63.524  54.680  1
455182  92.362  -63.530  54.675  1
455183  92.410  -63.535  54.670  1
455184  92.461  -63.539  54.666  1
455185  92.513  -63.543  54.660  1
455186  92.564  -63.546  54.656  1
455187  92.616  -63.551  54.651  1
455188  92.667  -63.555  54.647  1
455189  92.718  -63.559  54.643  1
455190  92.762  -63.563  54.640  1
455191  92.802  -63.571  54.638  1
455192  92.841  -63.581  54.636  1
455193  92.880  -63.590  54.633  1
455194  92.919  -63.600  54.632  1
455195  92.957  -63.609  54.630  1
455196  92.996  -63.614  54.628  1
455197  93.035  -63.614  54.625  1
455198  93.073  -63.615  54.621  1
455199  93.112  -63.615  54.615  1
455200  93.150  -63.615  54.610  1
455201  93.188  -63.615  54.603  1
455202  93.226  -63.615  54.595  1
455203  93.268  -63.614  54.587  1
455204  93.304  -63.611  54.576  1
455205  93.337  -63.608  54.563  1
455206  93.370  -63.606  54.549  1
455207  93.404  -63.603  54.532  1
455208  93.437  -63.600  54.514  1
455209  93.469  -63.597  54.495  1
455210  93.495  -63.604  54.476  1
455211  93.520  -63.611  54.456  1
455212  93.546  -63.618  54.435  1
455213  93.576  -63.630  54.410  1
455214  93.609  -63.647  54.385  1
455215  93.642  -63.665  54.359  1
455216  93.675  -63.681  54.331  1
455217  93.708  -63.699  54.302  1
455218  93.742  -63.716  54.272  1
455219  93.775  -63.733  54.241  1
455220  93.820  -63.768  54.210  1
455221  93.852  -63.788  54.179  1
455222  93.916  -63.797  54.147  1
455223  93.928  -63.807  54.116  1
455224  93.968  -63.815  54.086  1
455225  94.007  -63.822  54.057  1
455226  94.047  -63.831  54.030  1
455227  94.087  -63.838  54.008  1
455228  94.127  -63.846  53.986  1
455229  94.168  -63.855  53.965  1
455230  94.210  -63.865  53.945  1
455231  94.253  -63.875  53.927  1
455232  94.295  -63.885  53.911  1
455233  94.339  -63.899  53.899  1
455234  94.385  -63.916  53.890  1
455235  94.431  -63.934  53.881  1
455236  94.477  -63.951  53.872  1
455237  94.523  -63.969  53.862  1
455238  94.569  -63.988  53.849  1
455239  94.616  -64.002  53.834  1
455240  94.664  -64.001  53.816  1
455241  94.711  -64.001  53.797  1
455242  94.758  -64.001  53.775  1
455243  94.806  -64.001  53.754  1
455244  94.853  -64.000  53.733  1
455245  94.900  -64.000  53.712  1
455246  94.947  -63.999  53.692  1
455247  95.001  -64.005  53.671  1
455248  95.055  -64.013  53.653  1
455249  95.109  -64.020  53.634  1
455250  95.163  -64.027  53.615  1
455251  95.217  -64.034  53.595  1
455252  95.272  -64.041  53.574  1
455253  95.318  -64.048  53.554  1
455254  95.362  -64.054  53.535  1
455255  95.406  -64.061  53.516  1
455256  95.450  -64.068  53.496  1
455257  95.494  -64.074  53.475  1
455258  95.538  -64.081  53.451  1
455259  95.582  -64.088  53.426  1
455260  95.626  -64.095  53.401  1
455261  95.670  -64.101  53.376  1
455262  95.705  -64.099  53.351  1
455263  95.732  -64.088  53.322  1
455264  95.758  -64.078  53.295  1
455265  95.785  -64.068  53.269  1
455266  95.815  -64.063  53.243  1
455267  95.849  -64.067  53.222  1
455268  95.883  -64.070  53.201  1
455269  95.923  -64.056  53.178  1
455270  95.965  -64.038  53.151  1
455271  96.008  -64.020  53.121  1
455272  96.051  -64.007  53.089  1
455273  96.097  -64.001  53.057  1
455274  96.148  -64.010  53.027  1
455275  96.200  -64.020  53.003  1
455276  96.251  -64.029  52.983  1
455277  96.303  -64.038  52.966  1
455278  96.354  -64.048  52.944  1
455279  96.405  -64.057  52.921  1
455280  96.457  -64.066  52.895  1
455281  96.509  -64.076  52.865  1
455282  96.552  -64.082  52.832  1
455283  96.586  -64.084  52.794  1
455284  96.620  -64.085  52.755  1
455285  96.654  -64.088  52.715  1
455286  96.687  -64.090  52.675  1
455287  96.725  -64.095  52.635  1
455288  96.761  -64.099  52.590  1
455289  96.799  -64.104  52.543  1
455290  96.836  -64.109  52.495  1
455291  96.873  -64.114  52.446  1
455292  96.910  -64.118  52.398  1
455293  96.947  -64.123  52.352  1
455294  96.984  -64.128  52.307  1
455295  97.021  -64.132  52.264  1
455296  97.058  -64.137  52.223  1
455297  97.096  -64.142  52.182  1
455298  97.133  -64.147  52.141  1
455299  97.170  -64.151  52.098  1
455300  97.208  -64.156  52.053  1
455301  97.248  -64.160  52.005  1
455302  97.288  -64.164  51.958  1
455303  97.327  -64.167  51.914  1
455304  97.368  -64.171  51.872  1
455305  97.399  -64.164  51.832  1
455306  97.428  -64.167  51.794  1
455307  97.456  -64.174  51.753  1
455308  97.485  -64.182  51.710  1
455309  97.513  -64.189  51.666  1
455310  97.541  -64.195  51.621  1
455311  97.570  -64.203  51.576  1
455312  97.598  -64.210  51.530  1
455313  97.626  -64.217  51.483  1
455314  97.654  -64.224  51.435  1
455315  97.683  -64.231  51.387  1
455316  97.724  -64.227  51.340  1
455317  97.764  -64.223  51.295  1
455318  97.806  -64.217  51.248  1
455319  97.848  -64.209  51.201  1
455320  97.889  -64.201  51.152  1
455321  97.919  -64.204  51.104  1
455322  97.945  -64.208  51.053  1
455323  97.971  -64.213  51.001  1
455324  97.998  -64.217  50.946  1
455325  98.024  -64.222  50.891  1
455326  98.051  -64.227  50.837  1
455327  98.079  -64.231  50.783  1
455328  98.114  -64.232  50.731  1
455329  98.149  -64.233  50.680  1
455330  98.185  -64.233  50.628  1
455331  98.220  -64.234  50.578  1
455332  98.258  -64.229  50.528  1
455333  98.297  -64.220  50.479  1
455334  98.336  -64.211  50.430  1
455335  98.374  -64.205  50.383  1
455336  98.412  -64.208  50.335  1
455337  98.458  -64.211  50.287  1
455338  98.504  -64.214  50.239  1
455339  98.550  -64.217  50.191  1
455340  98.595  -64.220  50.144  1
455341  98.641  -64.222  50.098  1
455342  98.687  -64.225  50.053  1
455343  98.732  -64.228  50.008  1
455344  98.779  -64.230  49.963  1
455345  98.826  -64.233  49.918  1
455346  98.873  -64.235  49.874  1
455347  98.920  -64.238  49.829  1
455348  98.962  -64.241  49.784  1
455349  98.999  -64.244  49.738  1
455350  99.037  -64.248  49.694  1
455351  99.074  -64.251  49.650  1
455352  99.112  -64.255  49.604  1
455353  99.149  -64.258  49.559  1
455354  99.186  -64.262  49.515  1
455355  99.211  -64.267  49.473  1
455356  99.230  -64.273  49.432  1
455357  99.250  -64.280  49.391  1
455358  99.298  -64.286  49.352  1
455359  99.369  -64.291  49.313  1
455360  99.441  -64.296  49.274  1
455361  99.512  -64.302  49.235  1
455362  99.583  -64.306  49.196  1
455363  99.651  -64.309  49.158  1
455364  99.714  -64.308  49.121  1
455365  99.777  -64.305  49.083  1
455366  99.840  -64.304  49.046  1
455367  99.903  -64.302  49.009  1
455368  99.966  -64.300  48.972  1
455369  100.029  -64.298  48.935  1
455370  100.092  -64.296  48.900  1
455371  100.155  -64.295  48.865  1
455372  100.205  -64.295  48.831  1
455373  100.247  -64.298  48.796  1
455374  100.282  -64.305  48.762  1
455759  86.753  -62.618  56.135  1
455760  86.796  -62.616  56.122  1
455761  86.839  -62.614  56.111  1
455762  86.881  -62.612  56.099  1
455763  86.924  -62.610  56.087  1
455764  86.967  -62.609  56.075  1
455765  87.005  -62.609  56.063  1
455766  87.034  -62.616  56.050  1
455767  87.062  -62.622  56.035  1
455768  87.090  -62.628  56.020  1
455769  87.119  -62.634  56.004  1
455770  87.168  -62.630  55.988  1
455771  87.217  -62.625  55.972  1
455772  87.266  -62.620  55.954  1
455773  87.315  -62.616  55.935  1
455774  87.364  -62.611  55.917  1
455775  87.413  -62.606  55.898  1
455776  87.462  -62.601  55.880  1
455777  87.510  -62.597  55.862  1
455778  87.559  -62.592  55.844  1
455779  87.608  -62.587  55.826  1
455780  87.657  -62.583  55.811  1
455781  87.706  -62.578  55.797  1
455782  87.755  -62.573  55.784  1
455783  87.804  -62.575  55.772  1
455784  87.855  -62.584  55.762  1
455785  87.905  -62.593  55.754  1
455786  87.956  -62.601  55.747  1
455787  88.006  -62.610  55.742  1
455788  88.057  -62.619  55.739  1
455789  88.107  -62.628  55.735  1
455790  88.158  -62.637  55.727  1
455791  88.208  -62.646  55.714  1
455792  88.252  -62.661  55.695  1
455793  88.294  -62.676  55.670  1
455794  88.337  -62.691  55.647  1
455795  88.379  -62.706  55.623  1
455796  88.421  -62.722  55.600  1
455797  88.464  -62.738  55.577  1
455798  88.506  -62.753  55.554  1
455799  88.549  -62.768  55.531  1
455800  88.592  -62.783  55.509  1
455801  88.634  -62.798  55.489  1
455802  88.677  -62.814  55.470  1
455803  88.719  -62.829  55.450  1
455804  88.762  -62.844  55.433  1
455805  88.805  -62.860  55.418  1
455806  88.847  -62.875  55.404  1
455807  88.890  -62.890  55.394  1
455808  88.932  -62.905  55.386  1
455809  88.975  -62.921  55.380  1
455810  89.017  -62.936  55.375  1
455811  89.060  -62.951  55.371  1
455812  89.102  -62.967  55.368  1
455813  89.145  -62.982  55.367  1
455814  89.187  -62.997  55.366  1
455815  89.230  -63.012  55.364  1
455816  89.272  -63.028  55.361  1
455817  89.328  -63.016  55.353  1
455818  89.385  -63.004  55.348  1
455819  89.438  -63.001  55.344  1
455820  89.490  -63.001  55.341  1
455821  89.540  -63.006  55.341  1
455822  89.585  -63.026  55.345  1
455823  89.630  -63.046  55.353  1
455824  89.675  -63.067  55.360  1
455825  89.720  -63.087  55.364  1
455826  89.766  -63.098  55.364  1
455827  89.813  -63.107  55.359  1
455828  89.861  -63.116  55.351  1
455829  89.907  -63.125  55.343  1
455830  89.955  -63.135  55.334  1
455831  90.002  -63.144  55.323  1
455832  90.049  -63.153  55.306  1
455833  90.095  -63.156  55.285  1
455834  90.140  -63.158  55.264  1
455835  90.185  -63.159  55.247  1
455836  90.231  -63.161  55.234  1
455837  90.274  -63.163  55.226  1
455838  90.288  -63.180  55.220  1
455839  90.301  -63.198  55.216  1
455840  90.315  -63.217  55.215  1
455841  90.328  -63.234  55.215  1
455842  90.342  -63.252  55.217  1
455843  90.373  -63.267  55.219  1
455844  90.431  -63.276  55.219  1
455845  90.489  -63.285  55.214  1
455846  90.548  -63.294  55.205  1
455847  90.607  -63.303  55.193  1
455848  90.665  -63.312  55.173  1
455849  90.724  -63.321  55.144  1
455850  90.783  -63.330  55.109  1
455851  90.841  -63.339  55.069  1
455852  90.900  -63.348  55.031  1
455853  90.959  -63.357  54.994  1
455854  91.017  -63.366  54.960  1
455855  91.076  -63.375  54.929  1
455856  91.135  -63.384  54.899  1
455857  91.193  -63.393  54.872  1
455858  91.251  -63.402  54.848  1
455859  91.298  -63.411  54.828  1
455860  91.345  -63.419  54.810  1
455861  91.392  -63.428  54.797  1
455862  91.439  -63.437  54.785  1
455863  91.487  -63.446  54.773  1
455864  91.533  -63.454  54.763  1
455865  91.578  -63.457  54.756  1
455866  91.622  -63.457  54.750  1
455867  91.664  -63.457  54.744  1
455868  91.707  -63.457  54.741  1
455869  91.750  -63.456  54.739  1
455870  91.793  -63.456  54.736  1
455871  91.836  -63.456  54.737  1
455872  91.879  -63.455  54.739  1
455873  91.922  -63.455  54.742  1
455874  91.965  -63.455  54.744  1
455875  92.008  -63.455  54.743  1
455876  92.051  -63.455  54.737  1
455877  92.094  -63.455  54.728  1
455878  92.139  -63.457  54.718  1
455879  92.185  -63.462  54.708  1
455880  92.232  -63.468  54.698  1
455881  92.279  -63.473  54.691  1
455882  92.325  -63.479  54.685  1
455883  92.371  -63.485  54.680  1
455884  92.417  -63.490  54.675  1
455885  92.466  -63.496  54.669  1
455886  92.517  -63.499  54.664  1
455887  92.568  -63.503  54.660  1
455888  92.620  -63.507  54.655  1
455889  92.671  -63.511  54.651  1
455890  92.721  -63.515  54.647  1
455891  92.764  -63.521  54.643  1
455892  92.808  -63.525  54.641  1
455893  92.850  -63.532  54.639  1
455894  92.889  -63.541  54.636  1
455895  92.928  -63.550  54.634  1
455896  92.967  -63.559  54.630  1
455897  93.005  -63.561  54.627  1
455898  93.044  -63.561  54.623  1
455899  93.082  -63.562  54.617  1
455900  93.121  -63.562  54.611  1
455901  93.159  -63.562  54.604  1
455902  93.197  -63.562  54.596  1
455903  93.235  -63.562  54.586  1
455904  93.274  -63.562  54.576  1
455905  93.308  -63.559  54.563  1
455906  93.342  -63.556  54.549  1
455907  93.375  -63.553  54.532  1
455908  93.408  -63.550  54.513  1
455909  93.441  -63.547  54.493  1
455910  93.474  -63.545  54.474  1
455911  93.504  -63.546  54.454  1
455912  93.530  -63.553  54.434  1
455913  93.556  -63.559  54.413  1
455914  93.587  -63.574  54.390  1
455915  93.621  -63.591  54.364  1
455916  93.654  -63.609  54.339  1
455917  93.687  -63.625  54.312  1
455918  93.720  -63.643  54.284  1
455919  93.767  -63.681  54.256  1
455920  93.814  -63.718  54.224  1
455921  93.843  -63.734  54.192  1
455922  93.871  -63.750  54.160  1
455923  93.943  -63.757  54.127  1
455924  93.979  -63.765  54.097  1
455925  93.990  -63.775  54.066  1
455926  94.030  -63.782  54.037  1
455927  94.069  -63.791  54.010  1
455928  94.109  -63.798  53.987  1
455929  94.149  -63.806  53.965  1
455930  94.189  -63.814  53.945  1
455931  94.228  -63.822  53.925  1
455932  94.268  -63.830  53.909  1
455933  94.308  -63.838  53.895  1
455934  94.351  -63.854  53.886  1
455935  94.399  -63.874  53.878  1
455936  94.447  -63.894  53.870  1
455937  94.494  -63.913  53.862  1
455938  94.542  -63.933  53.853  1
455939  94.582  -63.949  53.840  1
455940  94.619  -63.958  53.826  1
455941  94.671  -63.958  53.809  1
455942  94.722  -63.959  53.789  1
455943  94.770  -63.959  53.769  1
455944  94.817  -63.958  53.747  1
455945  94.864  -63.957  53.726  1
455946  94.912  -63.957  53.705  1
455947  94.959  -63.957  53.685  1
455948  95.011  -63.961  53.665  1
455949  95.065  -63.968  53.646  1
455950  95.119  -63.976  53.627  1
455951  95.174  -63.982  53.608  1
455952  95.228  -63.990  53.588  1
455953  95.271  -63.996  53.568  1
455954  95.315  -64.003  53.550  1
455955  95.359  -64.010  53.532  1
455956  95.403  -64.016  53.513  1
455957  95.447  -64.023  53.494  1
455958  95.491  -64.029  53.471  1
455959  95.535  -64.036  53.447  1
455960  95.579  -64.043  53.422  1
455961  95.623  -64.050  53.396  1
455962  95.667  -64.057  53.371  1
455963  95.700  -64.053  53.344  1
455964  95.727  -64.042  53.315  1
455965  95.754  -64.032  53.286  1
455966  95.780  -64.021  53.257  1
455967  95.808  -64.012  53.230  1
455968  95.841  -64.015  53.207  1
455969  95.881  -64.003  53.186  1
455970  95.923  -63.985  53.163  1
455971  95.965  -63.966  53.137  1
455972  96.008  -63.949  53.108  1
455973  96.054  -63.945  53.077  1
455974  96.106  -63.954  53.045  1
455975  96.157  -63.963  53.016  1
455976  96.208  -63.973  52.991  1
455977  96.260  -63.982  52.971  1
455978  96.312  -63.991  52.952  1
455979  96.363  -64.001  52.929  1
455980  96.414  -64.010  52.904  1
455981  96.466  -64.020  52.878  1
455982  96.518  -64.029  52.848  1
455983  96.564  -64.035  52.814  1
455984  96.597  -64.038  52.776  1
455985  96.631  -64.040  52.736  1
455986  96.665  -64.041  52.695  1
455987  96.699  -64.045  52.655  1
455988  96.736  -64.049  52.615  1
455989  96.773  -64.054  52.572  1
455990  96.810  -64.058  52.526  1
455991  96.848  -64.063  52.478  1
455992  96.885  -64.068  52.429  1
455993  96.922  -64.073  52.382  1
455994  96.959  -64.077  52.337  1
455995  96.996  -64.082  52.293  1
455996  97.033  -64.087  52.252  1
455997  97.070  -64.092  52.212  1
455998  97.107  -64.096  52.171  1
455999  97.144  -64.101  52.129  1
456000  97.181  -64.106  52.086  1
456001  97.219  -64.110  52.042  1
456002  97.256  -64.115  51.994  1
456003  97.293  -64.120  51.947  1
456004  97.333  -64.124  51.905  1
456005  97.373  -64.128  51.866  1
456006  97.406  -64.123  51.829  1
456007  97.435  -64.131  51.791  1
456008  97.463  -64.138  51.751  1
456009  97.492  -64.145  51.708  1
456010  97.520  -64.152  51.663  1
456011  97.548  -64.159  51.618  1
456012  97.577  -64.166  51.572  1
456013  97.605  -64.173  51.526  1
456014  97.633  -64.180  51.479  1
456015  97.662  -64.187  51.431  1
456016  97.690  -64.195  51.383  1
456017  97.724  -64.197  51.337  1
456018  97.764  -64.192  51.290  1
456019  97.806  -64.185  51.244  1
456020  97.849  -64.177  51.196  1
456021  97.890  -64.169  51.147  1
456022  97.918  -64.172  51.098  1
456023  97.945  -64.177  51.047  1
456024  97.971  -64.182  50.994  1
456025  97.998  -64.186  50.939  1
456026  98.024  -64.191  50.884  1
456027  98.054  -64.194  50.829  1
456028  98.089  -64.195  50.774  1
456029  98.125  -64.195  50.722  1
456030  98.160  -64.197  50.670  1
456031  98.195  -64.198  50.618  1
456032  98.231  -64.198  50.568  1
456033  98.269  -64.193  50.518  1
456034  98.307  -64.184  50.468  1
456035  98.347  -64.176  50.419  1
456036  98.382  -64.173  50.371  1
456037  98.417  -64.176  50.324  1
456038  98.456  -64.178  50.276  1
456039  98.502  -64.181  50.228  1
456040  98.548  -64.184  50.180  1
456041  98.593  -64.187  50.133  1
456042  98.639  -64.189  50.086  1
456043  98.685  -64.192  50.040  1
456044  98.731  -64.195  49.995  1
456045  98.778  -64.198  49.950  1
456046  98.825  -64.200  49.905  1
456047  98.872  -64.202  49.861  1
456048  98.919  -64.204  49.817  1
456049  98.960  -64.208  49.772  1
456050  98.997  -64.211  49.726  1
456051  99.034  -64.215  49.682  1
456052  99.072  -64.218  49.637  1
456053  99.109  -64.222  49.590  1
456054  99.146  -64.226  49.543  1
456055  99.166  -64.232  49.500  1
456056  99.186  -64.238  49.458  1
456057  99.205  -64.244  49.417  1
456058  99.245  -64.250  49.376  1
456059  99.317  -64.255  49.337  1
456060  99.388  -64.261  49.298  1
456061  99.460  -64.265  49.259  1
456062  99.531  -64.270  49.220  1
456063  99.597  -64.272  49.181  1
456064  99.660  -64.270  49.144  1
456065  99.723  -64.268  49.107  1
456066  99.786  -64.267  49.070  1
456067  99.849  -64.265  49.032  1
456068  99.912  -64.263  48.996  1
456069  99.975  -64.261  48.959  1
456070  100.037  -64.259  48.922  1
456071  100.101  -64.258  48.888  1
456072  100.163  -64.256  48.854  1
456073  100.203  -64.258  48.820  1
456459  86.690  -62.590  56.158  1
456460  86.733  -62.589  56.144  1
456461  86.776  -62.587  56.131  1
456462  86.818  -62.585  56.120  1
456463  86.861  -62.584  56.109  1
456464  86.904  -62.581  56.097  1
456465  86.947  -62.580  56.086  1
456466  86.989  -62.578  56.074  1
456467  87.032  -62.576  56.061  1
456468  87.066  -62.580  56.047  1
456469  87.097  -62.584  56.033  1
456470  87.146  -62.580  56.018  1
456471  87.195  -62.575  56.002  1
456472  87.244  -62.570  55.984  1
456473  87.292  -62.565  55.966  1
456474  87.341  -62.561  55.947  1
456475  87.390  -62.556  55.928  1
456476  87.439  -62.552  55.909  1
456477  87.488  -62.547  55.889  1
456478  87.537  -62.542  55.870  1
456479  87.585  -62.537  55.852  1
456480  87.635  -62.533  55.834  1
456481  87.684  -62.528  55.817  1
456482  87.732  -62.523  55.802  1
456483  87.781  -62.518  55.789  1
456484  87.830  -62.514  55.778  1
456485  87.881  -62.522  55.770  1
456486  87.931  -62.531  55.763  1
456487  87.981  -62.540  55.758  1
456488  88.032  -62.548  55.754  1
456489  88.082  -62.557  55.752  1
456490  88.129  -62.570  55.748  1
456491  88.171  -62.585  55.741  1
456492  88.214  -62.600  55.728  1
456493  88.256  -62.616  55.708  1
456494  88.299  -62.631  55.683  1
456495  88.341  -62.646  55.660  1
456496  88.384  -62.661  55.636  1
456497  88.426  -62.677  55.609  1
456498  88.469  -62.692  55.585  1
456499  88.511  -62.707  55.563  1
456500  88.554  -62.722  55.539  1
456501  88.597  -62.738  55.516  1
456502  88.639  -62.753  55.496  1
456503  88.682  -62.768  55.476  1
456504  88.725  -62.784  55.457  1
456505  88.767  -62.799  55.439  1
456506  88.810  -62.814  55.423  1
456507  88.852  -62.829  55.408  1
456508  88.895  -62.844  55.397  1
456509  88.937  -62.860  55.388  1
456510  88.980  -62.876  55.381  1
456511  89.022  -62.891  55.376  1
456512  89.065  -62.906  55.371  1
456513  89.107  -62.921  55.368  1
456514  89.150  -62.936  55.366  1
456515  89.192  -62.951  55.363  1
456516  89.235  -62.967  55.361  1
456517  89.280  -62.979  55.358  1
456518  89.332  -62.979  55.350  1
456519  89.384  -62.979  55.344  1
456520  89.436  -62.980  55.338  1
456521  89.488  -62.981  55.333  1
456522  89.540  -62.982  55.331  1
456523  89.592  -62.982  55.332  1
456524  89.638  -62.998  55.338  1
456525  89.683  -63.019  55.344  1
456526  89.728  -63.039  55.349  1
456527  89.774  -63.050  55.350  1
456528  89.821  -63.059  55.347  1
456529  89.869  -63.068  55.341  1
456530  89.915  -63.077  55.334  1
456531  89.963  -63.086  55.326  1
456532  90.010  -63.096  55.315  1
456533  90.057  -63.105  55.299  1
456534  90.104  -63.114  55.279  1
456535  90.150  -63.117  55.258  1
456536  90.195  -63.119  55.239  1
456537  90.241  -63.120  55.225  1
456538  90.274  -63.128  55.215  1
456539  90.287  -63.146  55.207  1
456540  90.301  -63.164  55.200  1
456541  90.314  -63.182  55.196  1
456542  90.335  -63.197  55.192  1
456543  90.365  -63.208  55.191  1
456544  90.395  -63.220  55.190  1
456545  90.447  -63.230  55.188  1
456546  90.503  -63.241  55.185  1
456547  90.559  -63.252  55.177  1
456548  90.616  -63.263  55.162  1
456549  90.672  -63.274  55.141  1
456550  90.728  -63.284  55.114  1
456551  90.786  -63.294  55.081  1
456552  90.845  -63.303  55.046  1
456553  90.903  -63.312  55.013  1
456554  90.962  -63.321  54.981  1
456555  91.020  -63.330  54.951  1
456556  91.079  -63.339  54.921  1
456557  91.138  -63.348  54.894  1
456558  91.196  -63.357  54.870  1
456559  91.255  -63.366  54.849  1
456560  91.312  -63.375  54.832  1
456561  91.359  -63.383  54.815  1
456562  91.406  -63.393  54.802  1
456563  91.453  -63.401  54.791  1
456564  91.500  -63.409  54.781  1
456565  91.543  -63.409  54.771  1
456566  91.586  -63.409  54.764  1
456567  91.629  -63.408  54.757  1
456568  91.672  -63.408  54.752  1
456569  91.715  -63.408  54.749  1
456570  91.758  -63.408  54.747  1
456571  91.801  -63.408  54.745  1
456572  91.844  -63.408  54.745  1
456573  91.887  -63.407  54.749  1
456574  91.930  -63.407  54.753  1
456575  91.973  -63.407  54.756  1
456576  92.016  -63.407  54.755  1
456577  92.059  -63.406  54.750  1
456578  92.102  -63.406  54.741  1
456579  92.148  -63.411  54.729  1
456580  92.195  -63.416  54.717  1
456581  92.241  -63.422  54.706  1
456582  92.287  -63.427  54.697  1
456583  92.333  -63.433  54.690  1
456584  92.379  -63.440  54.685  1
456585  92.425  -63.446  54.679  1
456586  92.471  -63.452  54.673  1
456587  92.521  -63.455  54.668  1
456588  92.573  -63.460  54.664  1
456589  92.624  -63.464  54.659  1
456590  92.675  -63.468  54.653  1
456591  92.723  -63.472  54.649  1
456592  92.767  -63.477  54.646  1
456593  92.810  -63.483  54.644  1
456594  92.854  -63.487  54.641  1
456595  92.897  -63.493  54.638  1
456596  92.937  -63.501  54.635  1
456597  92.976  -63.508  54.630  1
456598  93.014  -63.508  54.625  1
456599  93.053  -63.508  54.620  1
456600  93.091  -63.508  54.612  1
456601  93.130  -63.509  54.605  1
456602  93.169  -63.515  54.596  1
456603  93.208  -63.519  54.586  1
456604  93.248  -63.524  54.575  1
456605  93.288  -63.526  54.563  1
456606  93.323  -63.516  54.549  1
456607  93.350  -63.509  54.533  1
456608  93.379  -63.501  54.514  1
456609  93.412  -63.498  54.493  1
456610  93.445  -63.496  54.472  1
456611  93.478  -63.493  54.452  1
456612  93.511  -63.490  54.432  1
456613  93.540  -63.493  54.413  1
456614  93.566  -63.501  54.392  1
456615  93.600  -63.518  54.368  1
456616  93.632  -63.535  54.344  1
456617  93.668  -63.556  54.318  1
456618  93.714  -63.593  54.292  1
456619  93.761  -63.631  54.265  1
456620  93.805  -63.665  54.236  1
456621  93.833  -63.680  54.204  1
456622  93.862  -63.696  54.171  1
456623  93.890  -63.712  54.139  1
456624  93.971  -63.717  54.105  1
456625  94.053  -63.722  54.074  1
456626  94.036  -63.733  54.044  1
456627  94.051  -63.742  54.016  1
456628  94.091  -63.750  53.989  1
456629  94.131  -63.758  53.966  1
456630  94.171  -63.766  53.945  1
456631  94.210  -63.774  53.925  1
456632  94.250  -63.781  53.907  1
456633  94.290  -63.790  53.893  1
456634  94.323  -63.800  53.882  1
456635  94.370  -63.819  53.874  1
456636  94.418  -63.839  53.865  1
456637  94.466  -63.859  53.858  1
456638  94.513  -63.878  53.850  1
456639  94.553  -63.894  53.841  1
456640  94.585  -63.906  53.831  1
456641  94.623  -63.914  53.817  1
456642  94.674  -63.915  53.800  1
456643  94.725  -63.915  53.782  1
456644  94.777  -63.916  53.762  1
456645  94.829  -63.916  53.741  1
456646  94.877  -63.916  53.720  1
456647  94.924  -63.915  53.699  1
456648  94.971  -63.914  53.679  1
456649  95.021  -63.917  53.659  1
456650  95.075  -63.924  53.639  1
456651  95.129  -63.931  53.620  1
456652  95.181  -63.938  53.601  1
456653  95.225  -63.944  53.582  1
456654  95.268  -63.951  53.563  1
456655  95.313  -63.958  53.547  1
456656  95.356  -63.965  53.529  1
456657  95.400  -63.972  53.511  1
456658  95.444  -63.978  53.492  1
456659  95.488  -63.985  53.469  1
456660  95.532  -63.991  53.444  1
456661  95.576  -63.998  53.419  1
456662  95.620  -64.005  53.393  1
456663  95.664  -64.011  53.367  1
456664  95.696  -64.007  53.339  1
456665  95.723  -63.996  53.309  1
456666  95.749  -63.985  53.278  1
456667  95.776  -63.975  53.247  1
456668  95.803  -63.965  53.219  1
456669  95.839  -63.949  53.194  1
456670  95.881  -63.931  53.170  1
456671  95.923  -63.913  53.146  1
456672  95.965  -63.894  53.120  1
456673  96.012  -63.888  53.092  1
456674  96.063  -63.898  53.062  1
456675  96.114  -63.907  53.031  1
456676  96.166  -63.916  53.002  1
456677  96.218  -63.926  52.976  1
456678  96.269  -63.935  52.953  1
456679  96.320  -63.944  52.931  1
456680  96.372  -63.954  52.907  1
456681  96.424  -63.963  52.880  1
456682  96.475  -63.973  52.852  1
456683  96.526  -63.982  52.823  1
456684  96.575  -63.990  52.790  1
456685  96.608  -63.991  52.753  1
456686  96.642  -63.994  52.713  1
456687  96.676  -63.996  52.672  1
456688  96.711  -63.999  52.632  1
456689  96.748  -64.004  52.592  1
456690  96.785  -64.008  52.550  1
456691  96.822  -64.013  52.506  1
456692  96.859  -64.018  52.459  1
456693  96.896  -64.023  52.412  1
456694  96.934  -64.027  52.366  1
456695  96.970  -64.032  52.323  1
456696  97.008  -64.037  52.281  1
456697  97.045  -64.041  52.241  1
456698  97.082  -64.046  52.201  1
456699  97.119  -64.051  52.158  1
456700  97.156  -64.056  52.116  1
456701  97.193  -64.060  52.073  1
456702  97.230  -64.065  52.029  1
456703  97.267  -64.070  51.981  1
456704  97.304  -64.075  51.938  1
456705  97.342  -64.079  51.898  1
456706  97.379  -64.084  51.861  1
456707  97.414  -64.087  51.825  1
456708  97.442  -64.095  51.789  1
456709  97.470  -64.101  51.749  1
456710  97.499  -64.108  51.707  1
456711  97.527  -64.116  51.663  1
456712  97.556  -64.123  51.617  1
456713  97.584  -64.129  51.571  1
456714  97.612  -64.137  51.524  1
456715  97.641  -64.144  51.476  1
456716  97.669  -64.151  51.428  1
456717  97.697  -64.158  51.380  1
456718  97.725  -64.165  51.332  1
456719  97.766  -64.161  51.284  1
456720  97.807  -64.153  51.237  1
456721  97.849  -64.145  51.189  1
456722  97.891  -64.136  51.140  1
456723  97.918  -64.141  51.091  1
456724  97.944  -64.145  51.040  1
456725  97.971  -64.150  50.987  1
456726  97.997  -64.154  50.931  1
456727  98.028  -64.157  50.875  1
456728  98.064  -64.158  50.820  1
456729  98.099  -64.159  50.765  1
456730  98.135  -64.160  50.712  1
456731  98.170  -64.161  50.660  1
456732  98.206  -64.161  50.608  1
456733  98.241  -64.162  50.558  1
456734  98.279  -64.157  50.507  1
456735  98.318  -64.148  50.457  1
456736  98.357  -64.139  50.408  1
456737  98.391  -64.142  50.360  1
456738  98.425  -64.144  50.312  1
456739  98.459  -64.146  50.265  1
456740  98.500  -64.148  50.217  1
456741  98.545  -64.151  50.170  1
456742  98.591  -64.154  50.122  1
456743  98.637  -64.157  50.076  1
456744  98.683  -64.160  50.029  1
456745  98.730  -64.162  49.983  1
456746  98.777  -64.164  49.938  1
456747  98.823  -64.167  49.893  1
456748  98.870  -64.169  49.848  1
456749  98.917  -64.171  49.804  1
456750  98.957  -64.175  49.760  1
456751  98.995  -64.179  49.714  1
456752  99.032  -64.182  49.668  1
456753  99.069  -64.186  49.622  1
456754  99.102  -64.190  49.575  1
456755  99.122  -64.196  49.529  1
456756  99.141  -64.202  49.486  1
456757  99.160  -64.208  49.443  1
456758  99.193  -64.214  49.402  1
456759  99.264  -64.220  49.362  1
456760  99.335  -64.225  49.322  1
456761  99.407  -64.229  49.282  1
456762  99.478  -64.235  49.244  1
456763  99.543  -64.235  49.206  1
456764  99.606  -64.233  49.168  1
456765  99.668  -64.232  49.130  1
456766  99.731  -64.229  49.093  1
456767  99.794  -64.228  49.057  1
456768  99.857  -64.226  49.020  1
456769  99.920  -64.224  48.983  1
456770  99.983  -64.223  48.947  1
456771  100.046  -64.220  48.910  1
456772  100.109  -64.219  48.876  1
456773  100.172  -64.217  48.843  1
457160  86.690  -62.551  56.167  1
457161  86.732  -62.550  56.153  1
457162  86.775  -62.548  56.140  1
457163  86.817  -62.546  56.129  1
457164  86.860  -62.544  56.118  1
457165  86.902  -62.543  56.107  1
457166  86.944  -62.541  56.096  1
457167  86.987  -62.540  56.084  1
457168  87.029  -62.538  56.072  1
457169  87.072  -62.537  56.059  1
457170  87.115  -62.535  56.047  1
457171  87.165  -62.530  56.033  1
457172  87.215  -62.525  56.016  1
457173  87.266  -62.518  55.998  1
457174  87.316  -62.513  55.980  1
457175  87.366  -62.507  55.961  1
457176  87.417  -62.502  55.940  1
457177  87.466  -62.497  55.920  1
457178  87.514  -62.492  55.901  1
457179  87.563  -62.487  55.881  1
457180  87.612  -62.483  55.861  1
457181  87.661  -62.478  55.841  1
457182  87.710  -62.474  55.824  1
457183  87.759  -62.468  55.809  1
457184  87.808  -62.464  55.795  1
457185  87.856  -62.459  55.785  1
457186  87.906  -62.459  55.778  1
457187  87.957  -62.468  55.773  1
457188  88.006  -62.478  55.769  1
457189  88.049  -62.493  55.766  1
457190  88.091  -62.509  55.764  1
457191  88.134  -62.524  55.760  1
457192  88.176  -62.540  55.753  1
457193  88.219  -62.555  55.741  1
457194  88.261  -62.570  55.722  1
457195  88.304  -62.585  55.695  1
457196  88.346  -62.600  55.671  1
457197  88.389  -62.616  55.646  1
457198  88.431  -62.631  55.619  1
457199  88.474  -62.647  55.592  1
457200  88.517  -62.662  55.569  1
457201  88.560  -62.676  55.545  1
457202  88.604  -62.691  55.523  1
457203  88.646  -62.706  55.503  1
457204  88.690  -62.722  55.483  1
457205  88.733  -62.737  55.464  1
457206  88.776  -62.752  55.445  1
457207  88.819  -62.767  55.427  1
457208  88.862  -62.782  55.414  1
457209  88.905  -62.797  55.400  1
457210  88.949  -62.813  55.389  1
457211  88.992  -62.828  55.382  1
457212  89.035  -62.843  55.376  1
457213  89.078  -62.857  55.371  1
457214  89.121  -62.873  55.367  1
457215  89.164  -62.888  55.363  1
457216  89.207  -62.903  55.360  1
457217  89.251  -62.915  55.357  1
457218  89.295  -62.924  55.354  1
457219  89.339  -62.932  55.347  1
457220  89.388  -62.941  55.339  1
457221  89.438  -62.949  55.332  1
457222  89.487  -62.958  55.326  1
457223  89.538  -62.962  55.322  1
457224  89.590  -62.963  55.321  1
457225  89.641  -62.963  55.324  1
457226  89.691  -62.971  55.328  1
457227  89.736  -62.991  55.332  1
457228  89.782  -63.001  55.334  1
457229  89.830  -63.010  55.332  1
457230  89.877  -63.020  55.328  1
457231  89.924  -63.029  55.323  1
457232  89.971  -63.039  55.317  1
457233  90.018  -63.048  55.306  1
457234  90.065  -63.057  55.291  1
457235  90.112  -63.067  55.273  1
457236  90.159  -63.076  55.253  1
457237  90.205  -63.079  55.233  1
457238  90.250  -63.080  55.217  1
457239  90.273  -63.093  55.204  1
457240  90.287  -63.111  55.194  1
457241  90.305  -63.127  55.187  1
457242  90.335  -63.139  55.178  1
457243  90.365  -63.150  55.173  1
457244  90.395  -63.161  55.169  1
457245  90.425  -63.173  55.164  1
457246  90.465  -63.184  55.160  1
457247  90.522  -63.195  55.156  1
457248  90.578  -63.205  55.147  1
457249  90.634  -63.216  55.131  1
457250  90.690  -63.227  55.110  1
457251  90.746  -63.237  55.086  1
457252  90.803  -63.248  55.057  1
457253  90.859  -63.258  55.027  1
457254  90.915  -63.270  54.998  1
457255  90.971  -63.280  54.970  1
457256  91.028  -63.291  54.943  1
457257  91.084  -63.302  54.916  1
457258  91.141  -63.312  54.892  1
457259  91.199  -63.321  54.870  1
457260  91.258  -63.330  54.851  1
457261  91.316  -63.339  54.835  1
457262  91.373  -63.348  54.822  1
457263  91.420  -63.357  54.810  1
457264  91.465  -63.361  54.799  1
457265  91.508  -63.361  54.789  1
457266  91.551  -63.361  54.780  1
457267  91.594  -63.361  54.773  1
457268  91.637  -63.361  54.767  1
457269  91.680  -63.360  54.760  1
457270  91.723  -63.360  54.756  1
457271  91.766  -63.360  54.753  1
457272  91.809  -63.359  54.752  1
457273  91.852  -63.359  54.754  1
457274  91.895  -63.359  54.759  1
457275  91.938  -63.358  54.765  1
457276  91.981  -63.358  54.769  1
457277  92.024  -63.358  54.769  1
457278  92.067  -63.358  54.763  1
457279  92.110  -63.359  54.754  1
457280  92.157  -63.365  54.743  1
457281  92.203  -63.371  54.728  1
457282  92.249  -63.377  54.715  1
457283  92.295  -63.383  54.704  1
457284  92.341  -63.389  54.695  1
457285  92.387  -63.395  54.688  1
457286  92.433  -63.401  54.682  1
457287  92.479  -63.406  54.676  1
457288  92.526  -63.412  54.671  1
457289  92.577  -63.416  54.667  1
457290  92.629  -63.420  54.661  1
457291  92.680  -63.424  54.655  1
457292  92.725  -63.429  54.649  1
457293  92.769  -63.434  54.646  1
457294  92.812  -63.440  54.642  1
457295  92.856  -63.445  54.639  1
457296  92.900  -63.449  54.637  1
457297  92.943  -63.455  54.632  1
457298  92.986  -63.463  54.627  1
457299  93.026  -63.469  54.621  1
457300  93.065  -63.474  54.614  1
457301  93.105  -63.478  54.606  1
457302  93.144  -63.483  54.597  1
457303  93.183  -63.488  54.585  1
457304  93.222  -63.493  54.573  1
457305  93.262  -63.497  54.560  1
457306  93.303  -63.494  54.548  1
457307  93.346  -63.484  54.532  1
457308  93.374  -63.475  54.515  1
457309  93.402  -63.468  54.494  1
457310  93.429  -63.459  54.471  1
457311  93.458  -63.451  54.450  1
457312  93.485  -63.443  54.429  1
457313  93.516  -63.437  54.410  1
457314  93.549  -63.435  54.391  1
457315  93.578  -63.445  54.371  1
457316  93.616  -63.468  54.347  1
457317  93.662  -63.506  54.323  1
457318  93.708  -63.543  54.297  1
457319  93.755  -63.580  54.271  1
457320  93.795  -63.610  54.244  1
457321  93.824  -63.626  54.214  1
457322  93.852  -63.641  54.183  1
457323  93.881  -63.657  54.150  1
457324  93.909  -63.673  54.117  1
457325  93.998  -63.678  54.084  1
457326  94.087  -63.681  54.052  1
457327  94.109  -63.690  54.023  1
457328  94.092  -63.701  53.995  1
457329  94.113  -63.710  53.969  1
457330  94.153  -63.718  53.946  1
457331  94.193  -63.726  53.925  1
457332  94.232  -63.734  53.907  1
457333  94.272  -63.741  53.892  1
457334  94.305  -63.751  53.879  1
457335  94.342  -63.765  53.870  1
457336  94.390  -63.784  53.861  1
457337  94.437  -63.804  53.853  1
457338  94.485  -63.824  53.846  1
457339  94.524  -63.839  53.840  1
457340  94.556  -63.850  53.832  1
457341  94.589  -63.862  53.822  1
457342  94.626  -63.870  53.809  1
457343  94.678  -63.871  53.792  1
457344  94.729  -63.871  53.774  1
457345  94.781  -63.872  53.755  1
457346  94.832  -63.872  53.735  1
457347  94.884  -63.872  53.714  1
457348  94.935  -63.872  53.694  1
457349  94.983  -63.872  53.674  1
457350  95.031  -63.872  53.653  1
457351  95.086  -63.880  53.633  1
457352  95.134  -63.887  53.614  1
457353  95.178  -63.894  53.595  1
457354  95.222  -63.900  53.577  1
457355  95.266  -63.907  53.558  1
457356  95.310  -63.913  53.542  1
457357  95.353  -63.920  53.525  1
457358  95.398  -63.927  53.508  1
457359  95.442  -63.933  53.488  1
457360  95.485  -63.940  53.466  1
457361  95.529  -63.947  53.441  1
457362  95.573  -63.954  53.417  1
457363  95.617  -63.960  53.392  1
457364  95.661  -63.966  53.364  1
457365  95.692  -63.960  53.336  1
457366  95.719  -63.950  53.304  1
457367  95.745  -63.939  53.271  1
457368  95.772  -63.929  53.238  1
457369  95.806  -63.922  53.209  1
457370  95.848  -63.913  53.181  1
457371  95.889  -63.889  53.154  1
457372  95.930  -63.866  53.129  1
457373  95.970  -63.841  53.103  1
457374  96.021  -63.842  53.074  1
457375  96.072  -63.851  53.045  1
457376  96.123  -63.860  53.015  1
457377  96.175  -63.869  52.986  1
457378  96.226  -63.879  52.958  1
457379  96.278  -63.888  52.933  1
457380  96.329  -63.897  52.908  1
457381  96.381  -63.907  52.881  1
457382  96.432  -63.916  52.853  1
457383  96.484  -63.925  52.824  1
457384  96.535  -63.935  52.795  1
457385  96.586  -63.944  52.763  1
457386  96.619  -63.946  52.728  1
457387  96.653  -63.948  52.689  1
457388  96.687  -63.950  52.648  1
457389  96.723  -63.954  52.609  1
457390  96.759  -63.958  52.569  1
457391  96.797  -63.963  52.527  1
457392  96.834  -63.968  52.484  1
457393  96.871  -63.973  52.440  1
457394  96.908  -63.977  52.395  1
457395  96.945  -63.982  52.351  1
457396  96.982  -63.987  52.309  1
457397  97.019  -63.991  52.269  1
457398  97.056  -63.996  52.229  1
457399  97.094  -64.001  52.189  1
457400  97.131  -64.006  52.146  1
457401  97.168  -64.010  52.103  1
457402  97.205  -64.015  52.060  1
457403  97.242  -64.020  52.016  1
457404  97.279  -64.025  51.970  1
457405  97.316  -64.029  51.929  1
457406  97.353  -64.034  51.892  1
457407  97.387  -64.043  51.857  1
457408  97.414  -64.056  51.822  1
457409  97.442  -64.063  51.786  1
457410  97.471  -64.070  51.747  1
457411  97.500  -64.076  51.705  1
457412  97.528  -64.083  51.662  1
457413  97.557  -64.090  51.617  1
457414  97.585  -64.098  51.571  1
457415  97.614  -64.104  51.523  1
457416  97.643  -64.111  51.475  1
457417  97.671  -64.118  51.426  1
457418  97.700  -64.125  51.377  1
457419  97.728  -64.132  51.328  1
457420  97.766  -64.129  51.279  1
457421  97.808  -64.120  51.231  1
457422  97.850  -64.112  51.183  1
457423  97.891  -64.104  51.133  1
457424  97.918  -64.109  51.083  1
457425  97.944  -64.114  51.032  1
457426  97.970  -64.119  50.979  1
457427  98.004  -64.120  50.924  1
457428  98.039  -64.121  50.867  1
457429  98.074  -64.122  50.811  1
457430  98.109  -64.123  50.756  1
457431  98.145  -64.123  50.702  1
457432  98.180  -64.125  50.650  1
457433  98.216  -64.126  50.598  1
457434  98.251  -64.126  50.547  1
457435  98.289  -64.120  50.496  1
457436  98.329  -64.112  50.446  1
457437  98.365  -64.107  50.397  1
457438  98.400  -64.110  50.349  1
457439  98.434  -64.112  50.301  1
457440  98.467  -64.114  50.254  1
457441  98.502  -64.116  50.207  1
457442  98.543  -64.119  50.159  1
457443  98.589  -64.121  50.112  1
457444  98.635  -64.124  50.065  1
457445  98.682  -64.126  50.019  1
457446  98.729  -64.129  49.972  1
457447  98.776  -64.131  49.926  1
457448  98.822  -64.134  49.881  1
457449  98.869  -64.136  49.835  1
457450  98.916  -64.139  49.790  1
457451  98.955  -64.142  49.745  1
457452  98.992  -64.145  49.699  1
457453  99.029  -64.149  49.652  1
457454  99.057  -64.154  49.606  1
457455  99.077  -64.161  49.559  1
457456  99.096  -64.167  49.514  1
457457  99.116  -64.173  49.471  1
457458  99.140  -64.179  49.428  1
457459  99.211  -64.184  49.387  1
457460  99.283  -64.189  49.347  1
457461  99.354  -64.194  49.307  1
457462  99.425  -64.199  49.268  1
457463  99.489  -64.198  49.229  1
457464  99.552  -64.196  49.192  1
457465  99.615  -64.195  49.154  1
457466  99.678  -64.192  49.116  1
457467  99.740  -64.191  49.080  1
457468  99.803  -64.189  49.043  1
457469  99.866  -64.187  49.007  1
457470  99.929  -64.186  48.971  1
457471  99.992  -64.183  48.934  1
457472  100.055  -64.182  48.898  1
457473  100.118  -64.180  48.865  1
457861  86.707  -62.503  56.174  1
457862  86.749  -62.500  56.161  1
457863  86.791  -62.499  56.149  1
457864  86.834  -62.497  56.138  1
457865  86.876  -62.496  56.127  1
457866  86.919  -62.494  56.116  1
457867  86.961  -62.493  56.106  1
457868  87.003  -62.491  56.095  1
457869  87.046  -62.490  56.083  1
457870  87.088  -62.488  56.072  1
457871  87.125  -62.490  56.060  1
457872  87.173  -62.487  56.047  1
457873  87.221  -62.483  56.032  1
457874  87.271  -62.478  56.014  1
457875  87.321  -62.472  55.995  1
457876  87.371  -62.467  55.975  1
457877  87.422  -62.461  55.954  1
457878  87.472  -62.456  55.932  1
457879  87.522  -62.449  55.912  1
457880  87.573  -62.444  55.891  1
457881  87.623  -62.438  55.871  1
457882  87.674  -62.433  55.851  1
457883  87.724  -62.427  55.833  1
457884  87.774  -62.421  55.816  1
457885  87.825  -62.415  55.802  1
457886  87.875  -62.410  55.793  1
457887  87.925  -62.404  55.786  1
457888  87.972  -62.416  55.781  1
457889  88.015  -62.431  55.777  1
457890  88.058  -62.446  55.775  1
457891  88.102  -62.462  55.773  1
457892  88.144  -62.477  55.770  1
457893  88.188  -62.492  55.763  1
457894  88.231  -62.507  55.752  1
457895  88.274  -62.522  55.734  1
457896  88.317  -62.537  55.707  1
457897  88.360  -62.553  55.681  1
457898  88.403  -62.567  55.655  1
457899  88.447  -62.582  55.628  1
457900  88.490  -62.597  55.600  1
457901  88.533  -62.612  55.574  1
457902  88.576  -62.628  55.550  1
457903  88.619  -62.643  55.528  1
457904  88.663  -62.658  55.509  1
457905  88.705  -62.673  55.489  1
457906  88.749  -62.688  55.469  1
457907  88.792  -62.703  55.450  1
457908  88.835  -62.719  55.432  1
457909  88.878  -62.733  55.417  1
457910  88.921  -62.748  55.403  1
457911  88.964  -62.763  55.392  1
457912  89.008  -62.778  55.383  1
457913  89.051  -62.794  55.376  1
457914  89.094  -62.809  55.370  1
457915  89.137  -62.824  55.365  1
457916  89.180  -62.839  55.361  1
457917  89.224  -62.851  55.357  1
457918  89.267  -62.860  55.353  1
457919  89.311  -62.868  55.349  1
457920  89.355  -62.876  55.342  1
457921  89.399  -62.885  55.334  1
457922  89.448  -62.894  55.327  1
457923  89.497  -62.902  55.320  1
457924  89.546  -62.910  55.315  1
457925  89.596  -62.919  55.311  1
457926  89.645  -62.928  55.311  1
457927  89.694  -62.936  55.313  1
457928  89.743  -62.945  55.317  1
457929  89.791  -62.954  55.319  1
457930  89.838  -62.963  55.319  1
457931  89.885  -62.972  55.316  1
457932  89.932  -62.982  55.312  1
457933  89.979  -62.991  55.307  1
457934  90.026  -63.000  55.298  1
457935  90.073  -63.009  55.286  1
457936  90.120  -63.018  55.270  1
457937  90.167  -63.028  55.251  1
457938  90.215  -63.037  55.230  1
457939  90.259  -63.041  55.211  1
457940  90.276  -63.057  55.197  1
457941  90.306  -63.069  55.185  1
457942  90.336  -63.080  55.174  1
457943  90.366  -63.092  55.165  1
457944  90.396  -63.103  55.156  1
457945  90.426  -63.114  55.149  1
457946  90.456  -63.126  55.142  1
457947  90.485  -63.137  55.136  1
457948  90.540  -63.148  55.130  1
457949  90.596  -63.158  55.118  1
457950  90.652  -63.169  55.101  1
457951  90.709  -63.180  55.080  1
457952  90.764  -63.191  55.059  1
457953  90.821  -63.202  55.036  1
457954  90.877  -63.212  55.011  1
457955  90.933  -63.223  54.985  1
457956  90.990  -63.233  54.960  1
457957  91.046  -63.244  54.936  1
457958  91.102  -63.255  54.912  1
457959  91.158  -63.265  54.890  1
457960  91.215  -63.277  54.871  1
457961  91.271  -63.287  54.855  1
457962  91.327  -63.298  54.840  1
457963  91.383  -63.308  54.829  1
457964  91.439  -63.315  54.819  1
457965  91.483  -63.315  54.807  1
457966  91.527  -63.315  54.797  1
457967  91.572  -63.314  54.787  1
457968  91.616  -63.314  54.780  1
457969  91.660  -63.314  54.773  1
457970  91.704  -63.314  54.766  1
457971  91.748  -63.314  54.761  1
457972  91.792  -63.314  54.758  1
457973  91.837  -63.314  54.757  1
457974  91.881  -63.314  54.759  1
457975  91.925  -63.314  54.766  1
457976  91.969  -63.314  54.775  1
457977  92.013  -63.314  54.781  1
457978  92.058  -63.314  54.781  1
457979  92.093  -63.317  54.777  1
457980  92.127  -63.320  54.769  1
457981  92.164  -63.323  54.757  1
457982  92.211  -63.327  54.743  1
457983  92.257  -63.332  54.727  1
457984  92.303  -63.338  54.713  1
457985  92.349  -63.343  54.701  1
457986  92.395  -63.349  54.692  1
457987  92.441  -63.355  54.684  1
457988  92.487  -63.361  54.678  1
457989  92.533  -63.368  54.673  1
457990  92.581  -63.373  54.669  1
457991  92.633  -63.377  54.663  1
457992  92.684  -63.380  54.656  1
457993  92.727  -63.386  54.650  1
457994  92.771  -63.391  54.645  1
457995  92.814  -63.396  54.640  1
457996  92.858  -63.402  54.636  1
457997  92.902  -63.409  54.633  1
457998  92.946  -63.417  54.628  1
457999  92.990  -63.425  54.621  1
458000  93.031  -63.432  54.614  1
458001  93.073  -63.440  54.606  1
458002  93.115  -63.447  54.597  1
458003  93.156  -63.455  54.585  1
458004  93.198  -63.461  54.571  1
458005  93.237  -63.466  54.557  1
458006  93.276  -63.471  54.542  1
458007  93.319  -63.462  54.527  1
458008  93.362  -63.452  54.511  1
458009  93.397  -63.443  54.493  1
458010  93.425  -63.434  54.472  1
458011  93.453  -63.426  54.449  1
458012  93.481  -63.418  54.428  1
458013  93.509  -63.410  54.408  1
458014  93.537  -63.402  54.388  1
458015  93.561  -63.397  54.370  1
458016  93.602  -63.418  54.350  1
458017  93.656  -63.455  54.326  1
458018  93.702  -63.493  54.302  1
458019  93.749  -63.530  54.275  1
458020  93.786  -63.556  54.248  1
458021  93.815  -63.571  54.222  1
458022  93.843  -63.587  54.192  1
458023  93.871  -63.603  54.162  1
458024  93.900  -63.618  54.129  1
458025  93.936  -63.633  54.095  1
458026  94.025  -63.637  54.061  1
458027  94.114  -63.641  54.031  1
458028  94.183  -63.647  54.002  1
458029  94.166  -63.658  53.975  1
458030  94.148  -63.669  53.949  1
458031  94.175  -63.678  53.926  1
458032  94.214  -63.686  53.906  1
458033  94.254  -63.694  53.891  1
458034  94.288  -63.703  53.878  1
458035  94.318  -63.712  53.867  1
458036  94.362  -63.730  53.857  1
458037  94.410  -63.750  53.848  1
458038  94.457  -63.770  53.841  1
458039  94.495  -63.784  53.834  1
458040  94.527  -63.796  53.828  1
458041  94.559  -63.807  53.822  1
458042  94.591  -63.819  53.812  1
458043  94.629  -63.826  53.799  1
458044  94.681  -63.827  53.784  1
458045  94.733  -63.827  53.767  1
458046  94.784  -63.828  53.748  1
458047  94.836  -63.828  53.729  1
458048  94.887  -63.828  53.709  1
458049  94.939  -63.828  53.688  1
458050  94.990  -63.829  53.667  1
458051  95.042  -63.829  53.647  1
458052  95.087  -63.835  53.627  1
458053  95.131  -63.842  53.607  1
458054  95.175  -63.848  53.589  1
458055  95.219  -63.855  53.570  1
458056  95.263  -63.862  53.552  1
458057  95.307  -63.869  53.535  1
458058  95.351  -63.875  53.519  1
458059  95.395  -63.882  53.502  1
458060  95.439  -63.888  53.484  1
458061  95.483  -63.895  53.462  1
458062  95.527  -63.902  53.440  1
458063  95.570  -63.909  53.416  1
458064  95.614  -63.915  53.390  1
458065  95.659  -63.922  53.363  1
458066  95.687  -63.913  53.334  1
458067  95.714  -63.904  53.301  1
458068  95.741  -63.893  53.266  1
458069  95.770  -63.884  53.232  1
458070  95.815  -63.883  53.199  1
458071  95.859  -63.880  53.169  1
458072  95.899  -63.856  53.140  1
458073  95.940  -63.832  53.112  1
458074  95.981  -63.810  53.084  1
458075  96.031  -63.805  53.056  1
458076  96.081  -63.804  53.026  1
458077  96.132  -63.813  52.996  1
458078  96.184  -63.823  52.967  1
458079  96.235  -63.832  52.938  1
458080  96.287  -63.841  52.910  1
458081  96.338  -63.851  52.882  1
458082  96.390  -63.860  52.852  1
458083  96.441  -63.869  52.822  1
458084  96.493  -63.878  52.793  1
458085  96.544  -63.888  52.763  1
458086  96.596  -63.897  52.733  1
458087  96.631  -63.900  52.700  1
458088  96.664  -63.902  52.664  1
458089  96.698  -63.904  52.626  1
458090  96.734  -63.908  52.586  1
458091  96.771  -63.913  52.547  1
458092  96.808  -63.917  52.505  1
458093  96.846  -63.922  52.462  1
458094  96.883  -63.927  52.419  1
458095  96.920  -63.932  52.378  1
458096  96.957  -63.936  52.336  1
458097  96.994  -63.941  52.296  1
458098  97.031  -63.946  52.257  1
458099  97.068  -63.951  52.217  1
458100  97.105  -63.955  52.176  1
458101  97.143  -63.960  52.134  1
458102  97.179  -63.965  52.091  1
458103  97.217  -63.969  52.047  1
458104  97.254  -63.974  52.003  1
458105  97.291  -63.979  51.960  1
458106  97.326  -63.986  51.922  1
458107  97.357  -63.999  51.887  1
458108  97.388  -64.011  51.854  1
458109  97.412  -64.026  51.819  1
458110  97.439  -64.034  51.783  1
458111  97.468  -64.041  51.745  1
458112  97.496  -64.048  51.703  1
458113  97.525  -64.054  51.660  1
458114  97.554  -64.061  51.617  1
458115  97.582  -64.068  51.571  1
458116  97.611  -64.075  51.524  1
458117  97.639  -64.082  51.475  1
458118  97.668  -64.089  51.425  1
458119  97.697  -64.096  51.375  1
458120  97.732  -64.095  51.324  1
458121  97.770  -64.092  51.275  1
458122  97.809  -64.088  51.226  1
458123  97.851  -64.079  51.177  1
458124  97.891  -64.073  51.125  1
458125  97.917  -64.078  51.074  1
458126  97.944  -64.082  51.023  1
458127  97.979  -64.083  50.971  1
458128  98.014  -64.085  50.916  1
458129  98.049  -64.085  50.860  1
458130  98.085  -64.086  50.802  1
458131  98.120  -64.087  50.747  1
458132  98.155  -64.088  50.693  1
458133  98.191  -64.088  50.640  1
458134  98.226  -64.089  50.588  1
458135  98.262  -64.090  50.537  1
458136  98.299  -64.085  50.485  1
458137  98.339  -64.076  50.435  1
458138  98.374  -64.076  50.386  1
458139  98.408  -64.078  50.338  1
458140  98.442  -64.079  50.289  1
458141  98.476  -64.082  50.243  1
458142  98.510  -64.084  50.196  1
458143  98.545  -64.086  50.148  1
458144  98.587  -64.088  50.101  1
458145  98.634  -64.091  50.055  1
458146  98.680  -64.094  50.009  1
458147  98.727  -64.096  49.963  1
458148  98.774  -64.098  49.916  1
458149  98.821  -64.101  49.870  1
458150  98.868  -64.103  49.825  1
458151  98.915  -64.105  49.779  1
458152  98.952  -64.109  49.732  1
458153  98.990  -64.113  49.686  1
458154  99.012  -64.118  49.638  1
458155  99.032  -64.124  49.591  1
458156  99.051  -64.130  49.545  1
458157  99.071  -64.137  49.500  1
458158  99.090  -64.143  49.457  1
458159  99.159  -64.148  49.414  1
458160  99.230  -64.154  49.373  1
458161  99.301  -64.158  49.333  1
458162  99.371  -64.163  49.293  1
458163  99.434  -64.161  49.253  1
458164  99.497  -64.159  49.214  1
458165  99.560  -64.157  49.177  1
458166  99.623  -64.156  49.140  1
458167  99.686  -64.154  49.103  1
458168  99.749  -64.152  49.066  1
458169  99.812  -64.150  49.030  1
458170  99.875  -64.148  48.993  1
458171  99.938  -64.147  48.958  1
458562  86.723  -62.453  56.180  1
458563  86.765  -62.452  56.168  1
458564  86.808  -62.450  56.156  1
458565  86.850  -62.449  56.145  1
458566  86.893  -62.447  56.135  1
458567  86.935  -62.446  56.124  1
458568  86.978  -62.444  56.114  1
458569  87.020  -62.443  56.104  1
458570  87.062  -62.440  56.093  1
458571  87.103  -62.440  56.083  1
458572  87.140  -62.442  56.073  1
458573  87.183  -62.441  56.061  1
458574  87.230  -62.437  56.047  1
458575  87.279  -62.434  56.031  1
458576  87.327  -62.431  56.011  1
458577  87.376  -62.427  55.989  1
458578  87.427  -62.421  55.967  1
458579  87.477  -62.415  55.945  1
458580  87.528  -62.409  55.923  1
458581  87.578  -62.404  55.901  1
458582  87.628  -62.398  55.881  1
458583  87.679  -62.393  55.861  1
458584  87.729  -62.387  55.842  1
458585  87.779  -62.381  55.825  1
458586  87.830  -62.375  55.811  1
458587  87.880  -62.370  55.801  1
458588  87.930  -62.364  55.793  1
458589  87.980  -62.366  55.787  1
458590  88.029  -62.382  55.784  1
458591  88.074  -62.398  55.781  1
458592  88.117  -62.413  55.780  1
458593  88.160  -62.428  55.777  1
458594  88.203  -62.443  55.772  1
458595  88.247  -62.458  55.762  1
458596  88.290  -62.473  55.744  1
458597  88.333  -62.488  55.719  1
458598  88.376  -62.503  55.691  1
458599  88.419  -62.518  55.663  1
458600  88.462  -62.534  55.636  1
458601  88.505  -62.549  55.607  1
458602  88.549  -62.564  55.579  1
458603  88.592  -62.579  55.554  1
458604  88.635  -62.594  55.531  1
458605  88.678  -62.609  55.513  1
458606  88.721  -62.624  55.493  1
458607  88.764  -62.639  55.473  1
458608  88.808  -62.654  55.454  1
458609  88.851  -62.669  55.436  1
458610  88.894  -62.684  55.420  1
458611  88.937  -62.700  55.406  1
458612  88.980  -62.715  55.394  1
458613  89.023  -62.730  55.384  1
458614  89.066  -62.745  55.376  1
458615  89.110  -62.760  55.369  1
458616  89.153  -62.775  55.363  1
458617  89.196  -62.787  55.358  1
458618  89.240  -62.795  55.353  1
458619  89.284  -62.804  55.349  1
458620  89.328  -62.812  55.344  1
458621  89.372  -62.820  55.337  1
458622  89.415  -62.829  55.329  1
458623  89.459  -62.838  55.321  1
458624  89.507  -62.846  55.314  1
458625  89.556  -62.854  55.307  1
458626  89.605  -62.863  55.302  1
458627  89.655  -62.872  55.299  1
458628  89.704  -62.880  55.300  1
458629  89.753  -62.888  55.304  1
458630  89.801  -62.898  55.306  1
458631  89.847  -62.908  55.306  1
458632  89.894  -62.917  55.304  1
458633  89.942  -62.927  55.300  1
458634  89.988  -62.937  55.297  1
458635  90.035  -62.946  55.289  1
458636  90.083  -62.956  55.280  1
458637  90.129  -62.966  55.266  1
458638  90.176  -62.976  55.249  1
458639  90.224  -62.985  55.228  1
458640  90.272  -63.000  55.208  1
458641  90.306  -63.010  55.191  1
458642  90.336  -63.022  55.176  1
458643  90.366  -63.033  55.164  1
458644  90.396  -63.045  55.153  1
458645  90.426  -63.056  55.143  1
458646  90.456  -63.067  55.134  1
458647  90.486  -63.079  55.126  1
458648  90.516  -63.090  55.117  1
458649  90.558  -63.101  55.108  1
458650  90.614  -63.111  55.095  1
458651  90.670  -63.123  55.079  1
458652  90.727  -63.133  55.061  1
458653  90.783  -63.144  55.042  1
458654  90.839  -63.155  55.020  1
458655  90.895  -63.165  54.999  1
458656  90.952  -63.176  54.976  1
458657  91.008  -63.186  54.953  1
458658  91.064  -63.197  54.931  1
458659  91.120  -63.208  54.910  1
458660  91.176  -63.219  54.891  1
458661  91.233  -63.230  54.873  1
458662  91.289  -63.240  54.859  1
458663  91.345  -63.251  54.846  1
458664  91.399  -63.262  54.836  1
458665  91.455  -63.269  54.826  1
458666  91.515  -63.271  54.815  1
458667  91.568  -63.273  54.803  1
458668  91.612  -63.273  54.793  1
458669  91.656  -63.273  54.785  1
458670  91.700  -63.273  54.778  1
458671  91.744  -63.273  54.772  1
458672  91.789  -63.273  54.767  1
458673  91.832  -63.273  54.764  1
458674  91.877  -63.273  54.762  1
458675  91.921  -63.273  54.765  1
458676  91.965  -63.273  54.773  1
458677  92.009  -63.273  54.784  1
458678  92.047  -63.274  54.792  1
458679  92.080  -63.277  54.794  1
458680  92.114  -63.280  54.791  1
458681  92.148  -63.282  54.783  1
458682  92.181  -63.285  54.770  1
458683  92.218  -63.288  54.756  1
458684  92.264  -63.292  54.740  1
458685  92.310  -63.296  54.724  1
458686  92.357  -63.301  54.710  1
458687  92.403  -63.305  54.697  1
458688  92.449  -63.311  54.688  1
458689  92.496  -63.317  54.681  1
458690  92.542  -63.322  54.676  1
458691  92.588  -63.328  54.671  1
458692  92.637  -63.333  54.665  1
458693  92.686  -63.337  54.658  1
458694  92.730  -63.343  54.651  1
458695  92.773  -63.348  54.644  1
458696  92.817  -63.355  54.638  1
458697  92.862  -63.364  54.631  1
458698  92.906  -63.371  54.626  1
458699  92.950  -63.379  54.620  1
458700  92.994  -63.387  54.614  1
458701  93.036  -63.394  54.606  1
458702  93.077  -63.402  54.596  1
458703  93.119  -63.409  54.584  1
458704  93.160  -63.416  54.570  1
458705  93.202  -63.424  54.555  1
458706  93.244  -63.431  54.539  1
458707  93.285  -63.436  54.523  1
458708  93.335  -63.431  54.506  1
458709  93.378  -63.420  54.489  1
458710  93.421  -63.409  54.469  1
458711  93.448  -63.402  54.449  1
458712  93.477  -63.393  54.427  1
458713  93.504  -63.385  54.406  1
458714  93.532  -63.377  54.386  1
458715  93.549  -63.382  54.367  1
458716  93.565  -63.386  54.348  1
458717  93.592  -63.406  54.328  1
458718  93.666  -63.443  54.305  1
458719  93.742  -63.479  54.280  1
458720  93.777  -63.502  54.253  1
458721  93.805  -63.518  54.226  1
458722  93.834  -63.533  54.199  1
458723  93.862  -63.549  54.170  1
458724  93.891  -63.565  54.138  1
458725  93.919  -63.581  54.105  1
458726  93.963  -63.593  54.071  1
458727  94.052  -63.597  54.039  1
458728  94.141  -63.601  54.009  1
458729  94.231  -63.606  53.981  1
458730  94.239  -63.615  53.955  1
458731  94.222  -63.626  53.931  1
458732  94.205  -63.637  53.910  1
458733  94.236  -63.646  53.894  1
458734  94.271  -63.655  53.879  1
458735  94.301  -63.665  53.867  1
458736  94.334  -63.676  53.857  1
458737  94.382  -63.696  53.846  1
458738  94.429  -63.715  53.836  1
458739  94.466  -63.729  53.828  1
458740  94.498  -63.741  53.822  1
458741  94.530  -63.752  53.816  1
458742  94.562  -63.763  53.811  1
458743  94.594  -63.775  53.800  1
458744  94.633  -63.782  53.788  1
458745  94.685  -63.783  53.775  1
458746  94.736  -63.783  53.759  1
458747  94.787  -63.784  53.741  1
458748  94.839  -63.784  53.723  1
458749  94.891  -63.784  53.703  1
458750  94.943  -63.784  53.682  1
458751  94.994  -63.785  53.661  1
458752  95.052  -63.786  53.640  1
458753  95.091  -63.791  53.620  1
458754  95.131  -63.797  53.600  1
458755  95.172  -63.803  53.581  1
458756  95.216  -63.810  53.562  1
458757  95.260  -63.817  53.544  1
458758  95.304  -63.824  53.527  1
458759  95.348  -63.831  53.511  1
458760  95.392  -63.837  53.495  1
458761  95.436  -63.844  53.478  1
458762  95.480  -63.850  53.457  1
458763  95.524  -63.857  53.436  1
458764  95.568  -63.864  53.413  1
458765  95.612  -63.870  53.388  1
458766  95.656  -63.877  53.361  1
458767  95.683  -63.867  53.332  1
458768  95.709  -63.857  53.297  1
458769  95.736  -63.847  53.263  1
458770  95.779  -63.845  53.228  1
458771  95.824  -63.844  53.192  1
458772  95.868  -63.843  53.159  1
458773  95.909  -63.823  53.128  1
458774  95.950  -63.800  53.097  1
458775  95.992  -63.779  53.067  1
458776  96.042  -63.774  53.036  1
458777  96.091  -63.769  53.006  1
458778  96.141  -63.767  52.976  1
458779  96.193  -63.776  52.947  1
458780  96.244  -63.785  52.917  1
458781  96.296  -63.794  52.887  1
458782  96.347  -63.804  52.856  1
458783  96.398  -63.813  52.825  1
458784  96.450  -63.822  52.793  1
458785  96.502  -63.832  52.763  1
458786  96.553  -63.841  52.732  1
458787  96.604  -63.850  52.702  1
458788  96.642  -63.854  52.670  1
458789  96.676  -63.856  52.636  1
458790  96.709  -63.858  52.600  1
458791  96.746  -63.863  52.563  1
458792  96.783  -63.867  52.524  1
458793  96.820  -63.872  52.484  1
458794  96.857  -63.877  52.442  1
458795  96.894  -63.882  52.400  1
458796  96.932  -63.886  52.360  1
458797  96.968  -63.891  52.321  1
458798  97.006  -63.896  52.283  1
458799  97.043  -63.900  52.245  1
458800  97.080  -63.905  52.206  1
458801  97.117  -63.910  52.165  1
458802  97.154  -63.915  52.122  1
458803  97.191  -63.919  52.079  1
458804  97.228  -63.924  52.037  1
458805  97.265  -63.929  51.994  1
458806  97.296  -63.941  51.954  1
458807  97.328  -63.954  51.917  1
458808  97.359  -63.966  51.883  1
458809  97.387  -63.980  51.850  1
458810  97.410  -63.994  51.816  1
458811  97.436  -64.005  51.780  1
458812  97.464  -64.012  51.741  1
458813  97.493  -64.019  51.701  1
458814  97.522  -64.026  51.659  1
458815  97.550  -64.032  51.616  1
458816  97.579  -64.039  51.571  1
458817  97.607  -64.046  51.524  1
458818  97.636  -64.053  51.475  1
458819  97.665  -64.060  51.424  1
458820  97.699  -64.061  51.374  1
458821  97.737  -64.058  51.322  1
458822  97.775  -64.055  51.272  1
458823  97.813  -64.051  51.222  1
458824  97.852  -64.047  51.171  1
458825  97.890  -64.041  51.119  1
458826  97.918  -64.046  51.068  1
458827  97.953  -64.047  51.017  1
458828  97.989  -64.048  50.965  1
458829  98.024  -64.048  50.911  1
458830  98.060  -64.049  50.855  1
458831  98.095  -64.050  50.797  1
458832  98.131  -64.051  50.740  1
458833  98.166  -64.051  50.686  1
458834  98.201  -64.053  50.633  1
458835  98.236  -64.054  50.579  1
458836  98.272  -64.054  50.527  1
458837  98.310  -64.048  50.475  1
458838  98.348  -64.041  50.424  1
458839  98.382  -64.044  50.374  1
458840  98.417  -64.045  50.325  1
458841  98.450  -64.048  50.277  1
458842  98.485  -64.050  50.231  1
458843  98.519  -64.052  50.184  1
458844  98.551  -64.054  50.138  1
458845  98.577  -64.057  50.091  1
458846  98.628  -64.059  50.046  1
458847  98.678  -64.060  50.001  1
458848  98.726  -64.063  49.955  1
458849  98.773  -64.065  49.909  1
458850  98.820  -64.067  49.863  1
458851  98.867  -64.070  49.818  1
458852  98.913  -64.073  49.771  1
458853  98.948  -64.076  49.723  1
458854  98.968  -64.082  49.674  1
458855  98.987  -64.088  49.626  1
458856  99.006  -64.095  49.578  1
458857  99.026  -64.101  49.532  1
458858  99.045  -64.107  49.488  1
458859  99.106  -64.113  49.444  1
458860  99.177  -64.117  49.401  1
458861  99.249  -64.123  49.359  1
458862  99.317  -64.126  49.319  1
458863  99.380  -64.124  49.279  1
458864  99.443  -64.123  49.239  1
458865  99.506  -64.120  49.200  1
458866  99.569  -64.119  49.163  1
458867  99.632  -64.117  49.126  1
458868  99.695  -64.115  49.090  1
458869  99.758  -64.113  49.053  1
459263  86.739  -62.405  56.186  1
459264  86.782  -62.403  56.174  1
459265  86.824  -62.402  56.162  1
459266  86.867  -62.400  56.151  1
459267  86.909  -62.399  56.141  1
459268  86.951  -62.397  56.131  1
459269  86.994  -62.396  56.121  1
459270  87.036  -62.393  56.112  1
459271  87.079  -62.392  56.102  1
459272  87.118  -62.392  56.093  1
459273  87.155  -62.394  56.084  1
459274  87.192  -62.396  56.074  1
459275  87.240  -62.393  56.062  1
459276  87.288  -62.389  56.046  1
459277  87.337  -62.386  56.028  1
459278  87.385  -62.382  56.006  1
459279  87.433  -62.379  55.983  1
459280  87.482  -62.375  55.959  1
459281  87.533  -62.369  55.936  1
459282  87.583  -62.364  55.913  1
459283  87.633  -62.358  55.892  1
459284  87.684  -62.352  55.871  1
459285  87.734  -62.346  55.852  1
459286  87.784  -62.341  55.834  1
459287  87.835  -62.335  55.820  1
459288  87.885  -62.329  55.809  1
459289  87.935  -62.324  55.799  1
459290  87.986  -62.318  55.792  1
459291  88.035  -62.331  55.788  1
459292  88.083  -62.347  55.785  1
459293  88.132  -62.364  55.785  1
459294  88.176  -62.379  55.784  1
459295  88.219  -62.394  55.780  1
459296  88.262  -62.409  55.771  1
459297  88.306  -62.424  55.753  1
459298  88.349  -62.440  55.728  1
459299  88.392  -62.455  55.700  1
459300  88.435  -62.470  55.672  1
459301  88.478  -62.485  55.644  1
459302  88.521  -62.500  55.612  1
459303  88.564  -62.515  55.583  1
459304  88.608  -62.530  55.557  1
459305  88.650  -62.545  55.533  1
459306  88.694  -62.560  55.515  1
459307  88.737  -62.575  55.495  1
459308  88.780  -62.590  55.475  1
459309  88.823  -62.606  55.456  1
459310  88.867  -62.621  55.438  1
459311  88.909  -62.636  55.422  1
459312  88.953  -62.651  55.409  1
459313  88.996  -62.666  55.397  1
459314  89.039  -62.681  55.385  1
459315  89.082  -62.696  55.377  1
459316  89.125  -62.711  55.368  1
459317  89.169  -62.722  55.361  1
459318  89.213  -62.731  55.355  1
459319  89.257  -62.739  55.350  1
459320  89.301  -62.747  55.344  1
459321  89.344  -62.756  55.340  1
459322  89.388  -62.765  55.333  1
459323  89.432  -62.773  55.324  1
459324  89.476  -62.782  55.316  1
459325  89.520  -62.790  55.307  1
459326  89.566  -62.798  55.300  1
459327  89.615  -62.807  55.293  1
459328  89.665  -62.816  55.289  1
459329  89.714  -62.824  55.287  1
459330  89.763  -62.833  55.288  1
459331  89.811  -62.842  55.290  1
459332  89.858  -62.852  55.291  1
459333  89.904  -62.862  55.290  1
459334  89.951  -62.871  55.287  1
459335  89.999  -62.881  55.285  1
459336  90.045  -62.891  55.280  1
459337  90.092  -62.900  55.272  1
459338  90.140  -62.911  55.261  1
459339  90.188  -62.925  55.246  1
459340  90.236  -62.938  55.227  1
459341  90.285  -62.953  55.205  1
459342  90.329  -62.964  55.185  1
459343  90.367  -62.975  55.169  1
459344  90.397  -62.986  55.155  1
459345  90.427  -62.998  55.142  1
459346  90.457  -63.009  55.131  1
459347  90.486  -63.020  55.121  1
459348  90.517  -63.032  55.111  1
459349  90.546  -63.043  55.101  1
459350  90.577  -63.054  55.089  1
459351  90.633  -63.065  55.076  1
459352  90.688  -63.076  55.061  1
459353  90.745  -63.086  55.045  1
459354  90.801  -63.097  55.027  1
459355  90.857  -63.108  55.008  1
459356  90.913  -63.118  54.989  1
459357  90.970  -63.129  54.969  1
459358  91.026  -63.140  54.949  1
459359  91.082  -63.151  54.929  1
459360  91.139  -63.161  54.911  1
459361  91.194  -63.172  54.893  1
459362  91.251  -63.183  54.877  1
459363  91.307  -63.193  54.863  1
459364  91.362  -63.205  54.851  1
459365  91.415  -63.216  54.842  1
459366  91.470  -63.224  54.832  1
459367  91.530  -63.226  54.821  1
459368  91.589  -63.228  54.809  1
459369  91.649  -63.230  54.799  1
459370  91.697  -63.230  54.791  1
459371  91.740  -63.230  54.784  1
459372  91.785  -63.230  54.778  1
459373  91.829  -63.230  54.774  1
459374  91.873  -63.230  54.769  1
459375  91.917  -63.230  54.768  1
459376  91.961  -63.230  54.771  1
459377  92.000  -63.232  54.779  1
459378  92.034  -63.234  54.792  1
459379  92.068  -63.237  54.803  1
459380  92.101  -63.239  54.807  1
459381  92.135  -63.242  54.805  1
459382  92.169  -63.245  54.796  1
459383  92.203  -63.247  54.784  1
459384  92.236  -63.250  54.770  1
459385  92.272  -63.252  54.754  1
459386  92.318  -63.257  54.736  1
459387  92.364  -63.261  54.719  1
459388  92.411  -63.266  54.704  1
459389  92.457  -63.270  54.692  1
459390  92.503  -63.274  54.683  1
459391  92.550  -63.279  54.676  1
459392  92.596  -63.283  54.671  1
459393  92.642  -63.289  54.666  1
459394  92.689  -63.294  54.659  1
459395  92.732  -63.302  54.651  1
459396  92.777  -63.310  54.643  1
459397  92.821  -63.318  54.634  1
459398  92.865  -63.325  54.625  1
459399  92.909  -63.333  54.618  1
459400  92.953  -63.341  54.610  1
459401  92.998  -63.349  54.601  1
459402  93.040  -63.356  54.592  1
459403  93.081  -63.364  54.581  1
459404  93.123  -63.371  54.567  1
459405  93.165  -63.378  54.552  1
459406  93.206  -63.386  54.536  1
459407  93.243  -63.392  54.519  1
459408  93.289  -63.392  54.502  1
459409  93.340  -63.389  54.484  1
459410  93.391  -63.385  54.465  1
459411  93.437  -63.378  54.445  1
459412  93.472  -63.368  54.425  1
459413  93.500  -63.361  54.404  1
459414  93.519  -63.361  54.384  1
459415  93.536  -63.366  54.365  1
459416  93.552  -63.371  54.346  1
459417  93.568  -63.376  54.326  1
459418  93.597  -63.398  54.306  1
459419  93.654  -63.430  54.283  1
459420  93.727  -63.461  54.258  1
459421  93.763  -63.475  54.231  1
459422  93.797  -63.496  54.204  1
459423  93.845  -63.499  54.176  1
459424  93.882  -63.510  54.146  1
459425  93.910  -63.526  54.114  1
459426  93.938  -63.542  54.080  1
459427  93.990  -63.553  54.048  1
459428  94.079  -63.557  54.017  1
459429  94.169  -63.561  53.988  1
459430  94.258  -63.565  53.962  1
459431  94.313  -63.571  53.938  1
459432  94.295  -63.583  53.916  1
459433  94.278  -63.594  53.898  1
459434  94.254  -63.606  53.883  1
459435  94.284  -63.616  53.869  1
459436  94.314  -63.626  53.858  1
459437  94.353  -63.641  53.847  1
459438  94.401  -63.661  53.836  1
459439  94.437  -63.675  53.825  1
459440  94.469  -63.686  53.817  1
459441  94.501  -63.697  53.810  1
459442  94.533  -63.709  53.803  1
459443  94.565  -63.720  53.797  1
459444  94.597  -63.731  53.788  1
459445  94.636  -63.738  53.777  1
459446  94.688  -63.739  53.764  1
459447  94.740  -63.739  53.750  1
459448  94.791  -63.740  53.735  1
459449  94.843  -63.740  53.717  1
459450  94.894  -63.741  53.697  1
459451  94.946  -63.741  53.676  1
459452  95.001  -63.741  53.655  1
459453  95.062  -63.743  53.635  1
459454  95.101  -63.747  53.613  1
459455  95.139  -63.753  53.592  1
459456  95.179  -63.759  53.573  1
459457  95.218  -63.766  53.554  1
459458  95.257  -63.772  53.536  1
459459  95.301  -63.779  53.518  1
459460  95.345  -63.785  53.501  1
459461  95.389  -63.792  53.485  1
459462  95.433  -63.799  53.470  1
459463  95.477  -63.806  53.449  1
459464  95.521  -63.813  53.429  1
459465  95.565  -63.819  53.408  1
459466  95.609  -63.825  53.385  1
459467  95.652  -63.831  53.359  1
459468  95.679  -63.821  53.329  1
459469  95.705  -63.810  53.295  1
459470  95.744  -63.806  53.260  1
459471  95.789  -63.806  53.225  1
459472  95.833  -63.805  53.187  1
459473  95.877  -63.804  53.150  1
459474  95.919  -63.791  53.117  1
459475  95.960  -63.766  53.083  1
459476  96.004  -63.748  53.049  1
459477  96.053  -63.744  53.016  1
459478  96.102  -63.738  52.986  1
459479  96.152  -63.733  52.956  1
459480  96.201  -63.729  52.925  1
459481  96.253  -63.738  52.895  1
459482  96.305  -63.748  52.864  1
459483  96.356  -63.757  52.831  1
459484  96.407  -63.766  52.798  1
459485  96.459  -63.775  52.766  1
459486  96.510  -63.785  52.733  1
459487  96.562  -63.794  52.702  1
459488  96.613  -63.803  52.671  1
459489  96.653  -63.808  52.639  1
459490  96.687  -63.810  52.607  1
459491  96.721  -63.813  52.573  1
459492  96.758  -63.817  52.537  1
459493  96.795  -63.822  52.500  1
459494  96.832  -63.826  52.460  1
459495  96.869  -63.831  52.420  1
459496  96.906  -63.836  52.380  1
459497  96.943  -63.841  52.342  1
459498  96.980  -63.845  52.305  1
459499  97.017  -63.850  52.268  1
459500  97.054  -63.855  52.231  1
459501  97.092  -63.860  52.192  1
459502  97.129  -63.865  52.152  1
459503  97.166  -63.869  52.110  1
459504  97.203  -63.874  52.068  1
459505  97.236  -63.885  52.027  1
459506  97.267  -63.897  51.986  1
459507  97.298  -63.910  51.948  1
459508  97.329  -63.922  51.912  1
459509  97.361  -63.935  51.878  1
459510  97.386  -63.948  51.845  1
459511  97.408  -63.963  51.812  1
459512  97.433  -63.976  51.776  1
459513  97.461  -63.983  51.738  1
459514  97.490  -63.990  51.698  1
459515  97.518  -63.997  51.656  1
459516  97.547  -64.004  51.614  1
459517  97.576  -64.010  51.569  1
459518  97.604  -64.017  51.522  1
459519  97.633  -64.024  51.473  1
459520  97.665  -64.027  51.422  1
459521  97.703  -64.024  51.371  1
459522  97.741  -64.021  51.318  1
459523  97.779  -64.017  51.266  1
459524  97.817  -64.014  51.215  1
459525  97.856  -64.011  51.163  1
459526  97.893  -64.009  51.110  1
459527  97.928  -64.010  51.059  1
459528  97.964  -64.010  51.008  1
459529  97.999  -64.011  50.957  1
459530  98.034  -64.013  50.904  1
459531  98.070  -64.013  50.849  1
459532  98.105  -64.014  50.791  1
459533  98.141  -64.015  50.734  1
459534  98.176  -64.016  50.679  1
459535  98.212  -64.016  50.625  1
459536  98.247  -64.017  50.570  1
459537  98.282  -64.018  50.517  1
459538  98.320  -64.013  50.464  1
459539  98.357  -64.010  50.413  1
459540  98.391  -64.011  50.363  1
459541  98.425  -64.013  50.313  1
459542  98.459  -64.016  50.266  1
459543  98.493  -64.018  50.219  1
459544  98.518  -64.020  50.173  1
459545  98.544  -64.023  50.128  1
459546  98.570  -64.026  50.082  1
459547  98.609  -64.028  50.038  1
459548  98.659  -64.030  49.993  1
459549  98.710  -64.032  49.949  1
459550  98.761  -64.034  49.904  1
459551  98.811  -64.035  49.858  1
459552  98.861  -64.038  49.814  1
459553  98.904  -64.041  49.766  1
459554  98.923  -64.047  49.717  1
459555  98.942  -64.053  49.665  1
459556  98.961  -64.059  49.614  1
459557  98.981  -64.065  49.566  1
459558  99.000  -64.071  49.520  1
459559  99.053  -64.077  49.475  1
459560  99.125  -64.082  49.431  1
459561  99.196  -64.087  49.388  1
459562  99.263  -64.088  49.347  1
459563  99.326  -64.087  49.306  1
459564  99.389  -64.085  49.266  1
459565  99.451  -64.083  49.227  1
459566  99.514  -64.082  49.188  1
459567  99.577  -64.079  49.151  1
459964  86.756  -62.356  56.191  1
459965  86.798  -62.355  56.179  1
459966  86.841  -62.353  56.167  1
459967  86.883  -62.352  56.156  1
459968  86.926  -62.350  56.146  1
459969  86.968  -62.348  56.137  1
459970  87.010  -62.346  56.128  1
459971  87.053  -62.345  56.119  1
459972  87.095  -62.343  56.110  1
459973  87.133  -62.344  56.101  1
459974  87.170  -62.346  56.093  1
459975  87.207  -62.348  56.085  1
459976  87.250  -62.347  56.075  1
459977  87.298  -62.343  56.061  1
459978  87.346  -62.340  56.044  1
459979  87.395  -62.337  56.022  1
459980  87.442  -62.333  55.998  1
459981  87.491  -62.330  55.974  1
459982  87.539  -62.327  55.949  1
459983  87.587  -62.323  55.926  1
459984  87.638  -62.318  55.904  1
459985  87.689  -62.312  55.883  1
459986  87.739  -62.306  55.862  1
459987  87.789  -62.300  55.844  1
459988  87.840  -62.295  55.829  1
459989  87.890  -62.289  55.817  1
459990  87.940  -62.283  55.806  1
459991  87.991  -62.277  55.796  1
459992  88.041  -62.280  55.791  1
459993  88.089  -62.296  55.788  1
459994  88.138  -62.313  55.788  1
459995  88.187  -62.329  55.789  1
459996  88.235  -62.346  55.787  1
459997  88.278  -62.361  55.778  1
459998  88.321  -62.376  55.760  1
459999  88.364  -62.390  55.735  1
460000  88.408  -62.406  55.708  1
460001  88.451  -62.421  55.680  1
460002  88.494  -62.436  55.649  1
460003  88.537  -62.451  55.615  1
460004  88.580  -62.466  55.585  1
460005  88.623  -62.481  55.558  1
460006  88.667  -62.496  55.534  1
460007  88.709  -62.512  55.516  1
460008  88.753  -62.527  55.496  1
460009  88.796  -62.542  55.477  1
460010  88.839  -62.556  55.458  1
460011  88.882  -62.572  55.440  1
460012  88.925  -62.587  55.425  1
460013  88.968  -62.602  55.411  1
460014  89.012  -62.617  55.397  1
460015  89.055  -62.632  55.385  1
460016  89.098  -62.647  55.375  1
460017  89.141  -62.658  55.367  1
460018  89.185  -62.666  55.360  1
460019  89.229  -62.675  55.353  1
460020  89.273  -62.683  55.347  1
460021  89.317  -62.691  55.339  1
460022  89.361  -62.700  55.336  1
460023  89.405  -62.709  55.328  1
460024  89.449  -62.717  55.319  1
460025  89.492  -62.725  55.310  1
460026  89.536  -62.734  55.301  1
460027  89.580  -62.743  55.293  1
460028  89.625  -62.751  55.285  1
460029  89.675  -62.760  55.279  1
460030  89.724  -62.768  55.275  1
460031  89.773  -62.777  55.273  1
460032  89.820  -62.786  55.274  1
460033  89.868  -62.796  55.275  1
460034  89.914  -62.806  55.274  1
460035  89.961  -62.815  55.273  1
460036  90.008  -62.825  55.271  1
460037  90.056  -62.836  55.268  1
460038  90.104  -62.850  55.262  1
460039  90.152  -62.864  55.253  1
460040  90.200  -62.878  55.240  1
460041  90.249  -62.892  55.223  1
460042  90.297  -62.906  55.203  1
460043  90.344  -62.919  55.184  1
460044  90.387  -62.929  55.166  1
460045  90.427  -62.939  55.150  1
460046  90.457  -62.951  55.135  1
460047  90.487  -62.962  55.123  1
460048  90.517  -62.973  55.112  1
460049  90.547  -62.985  55.099  1
460050  90.577  -62.996  55.087  1
460051  90.607  -63.007  55.075  1
460052  90.651  -63.018  55.062  1
460053  90.707  -63.029  55.048  1
460054  90.763  -63.039  55.032  1
460055  90.819  -63.051  55.016  1
460056  90.876  -63.061  54.998  1
460057  90.932  -63.072  54.981  1
460058  90.988  -63.083  54.964  1
460059  91.044  -63.093  54.946  1
460060  91.100  -63.104  54.929  1
460061  91.157  -63.114  54.912  1
460062  91.213  -63.125  54.896  1
460063  91.269  -63.136  54.881  1
460064  91.324  -63.147  54.868  1
460065  91.377  -63.158  54.857  1
460066  91.430  -63.170  54.848  1
460067  91.486  -63.177  54.837  1
460068  91.545  -63.180  54.826  1
460069  91.604  -63.182  54.814  1
460070  91.664  -63.184  54.803  1
460071  91.723  -63.186  54.796  1
460072  91.781  -63.189  54.790  1
460073  91.825  -63.189  54.785  1
460074  91.869  -63.189  54.781  1
460075  91.914  -63.189  54.776  1
460076  91.954  -63.189  54.774  1
460077  91.988  -63.192  54.776  1
460078  92.021  -63.195  54.784  1
460079  92.055  -63.197  54.798  1
460080  92.089  -63.199  54.810  1
460081  92.123  -63.202  54.816  1
460082  92.156  -63.205  54.815  1
460083  92.190  -63.208  54.808  1
460084  92.224  -63.210  54.798  1
460085  92.258  -63.212  54.785  1
460086  92.291  -63.215  54.768  1
460087  92.325  -63.217  54.749  1
460088  92.371  -63.222  54.730  1
460089  92.418  -63.227  54.713  1
460090  92.464  -63.231  54.698  1
460091  92.510  -63.235  54.686  1
460092  92.557  -63.239  54.677  1
460093  92.603  -63.244  54.670  1
460094  92.649  -63.249  54.664  1
460095  92.691  -63.257  54.657  1
460096  92.735  -63.264  54.648  1
460097  92.780  -63.271  54.639  1
460098  92.825  -63.280  54.630  1
460099  92.868  -63.287  54.619  1
460100  92.913  -63.295  54.610  1
460101  92.957  -63.303  54.600  1
460102  93.001  -63.311  54.588  1
460103  93.044  -63.318  54.576  1
460104  93.086  -63.326  54.563  1
460105  93.127  -63.333  54.548  1
460106  93.166  -63.339  54.532  1
460107  93.204  -63.346  54.515  1
460108  93.242  -63.352  54.496  1
460109  93.292  -63.348  54.478  1
460110  93.343  -63.345  54.459  1
460111  93.394  -63.341  54.438  1
460112  93.445  -63.338  54.418  1
460113  93.490  -63.339  54.399  1
460114  93.507  -63.346  54.380  1
460115  93.523  -63.351  54.360  1
460116  93.540  -63.355  54.342  1
460117  93.556  -63.360  54.323  1
460118  93.572  -63.365  54.304  1
460119  93.604  -63.390  54.285  1
460120  93.642  -63.417  54.261  1
460121  93.706  -63.430  54.236  1
460122  93.744  -63.440  54.209  1
460123  93.774  -63.466  54.181  1
460124  93.804  -63.492  54.154  1
460125  93.842  -63.509  54.121  1
460126  93.890  -63.512  54.088  1
460127  93.939  -63.514  54.057  1
460128  94.010  -63.515  54.025  1
460129  94.107  -63.517  53.995  1
460130  94.196  -63.521  53.969  1
460131  94.285  -63.525  53.945  1
460132  94.374  -63.530  53.923  1
460133  94.369  -63.540  53.904  1
460134  94.338  -63.553  53.888  1
460135  94.305  -63.566  53.873  1
460136  94.297  -63.578  53.861  1
460137  94.327  -63.587  53.849  1
460138  94.373  -63.606  53.837  1
460139  94.408  -63.619  53.827  1
460140  94.439  -63.631  53.816  1
460141  94.472  -63.642  53.807  1
460142  94.504  -63.653  53.799  1
460143  94.536  -63.665  53.791  1
460144  94.568  -63.676  53.785  1
460145  94.600  -63.687  53.776  1
460146  94.640  -63.694  53.765  1
460147  94.691  -63.695  53.753  1
460148  94.743  -63.695  53.739  1
460149  94.794  -63.696  53.726  1
460150  94.846  -63.696  53.709  1
460151  94.898  -63.697  53.690  1
460152  94.950  -63.697  53.669  1
460153  95.013  -63.698  53.649  1
460154  95.072  -63.700  53.629  1
460155  95.110  -63.704  53.606  1
460156  95.148  -63.709  53.585  1
460157  95.187  -63.714  53.564  1
460158  95.227  -63.721  53.544  1
460159  95.266  -63.728  53.525  1
460160  95.305  -63.734  53.507  1
460161  95.345  -63.741  53.490  1
460162  95.386  -63.747  53.473  1
460163  95.430  -63.754  53.457  1
460164  95.474  -63.761  53.439  1
460165  95.518  -63.768  53.420  1
460166  95.562  -63.774  53.399  1
460167  95.606  -63.781  53.377  1
460168  95.648  -63.785  53.351  1
460169  95.674  -63.775  53.322  1
460170  95.709  -63.769  53.290  1
460171  95.754  -63.768  53.256  1
460172  95.798  -63.767  53.220  1
460173  95.842  -63.766  53.181  1
460174  95.887  -63.765  53.142  1
460175  95.930  -63.757  53.105  1
460176  95.970  -63.734  53.069  1
460177  96.015  -63.717  53.033  1
460178  96.064  -63.712  52.998  1
460179  96.113  -63.707  52.965  1
460180  96.163  -63.702  52.934  1
460181  96.213  -63.697  52.903  1
460182  96.262  -63.692  52.872  1
460183  96.313  -63.701  52.839  1
460184  96.365  -63.710  52.806  1
460185  96.416  -63.719  52.773  1
460186  96.468  -63.729  52.739  1
460187  96.519  -63.738  52.706  1
460188  96.571  -63.747  52.673  1
460189  96.622  -63.756  52.641  1
460190  96.664  -63.763  52.608  1
460191  96.698  -63.764  52.576  1
460192  96.732  -63.767  52.543  1
460193  96.769  -63.772  52.508  1
460194  96.806  -63.776  52.474  1
460195  96.843  -63.781  52.435  1
460196  96.881  -63.786  52.396  1
460197  96.918  -63.791  52.359  1
460198  96.955  -63.795  52.322  1
460199  96.992  -63.800  52.286  1
460200  97.029  -63.805  52.251  1
460201  97.066  -63.810  52.215  1
460202  97.103  -63.814  52.177  1
460203  97.141  -63.819  52.139  1
460204  97.175  -63.828  52.098  1
460205  97.206  -63.840  52.057  1
460206  97.237  -63.853  52.017  1
460207  97.268  -63.865  51.978  1
460208  97.300  -63.877  51.941  1
460209  97.331  -63.890  51.906  1
460210  97.362  -63.903  51.872  1
460211  97.384  -63.917  51.839  1
460212  97.407  -63.932  51.806  1
460213  97.430  -63.946  51.772  1
460214  97.458  -63.954  51.734  1
460215  97.487  -63.961  51.694  1
460216  97.515  -63.968  51.652  1
460217  97.544  -63.975  51.610  1
460218  97.572  -63.982  51.565  1
460219  97.601  -63.988  51.519  1
460220  97.632  -63.993  51.469  1
460221  97.669  -63.990  51.418  1
460222  97.708  -63.987  51.366  1
460223  97.746  -63.984  51.312  1
460224  97.784  -63.980  51.259  1
460225  97.822  -63.977  51.206  1
460226  97.861  -63.975  51.153  1
460227  97.900  -63.973  51.100  1
460228  97.935  -63.975  51.048  1
460229  97.971  -63.975  50.998  1
460230  98.009  -63.976  50.948  1
460231  98.045  -63.976  50.895  1
460232  98.080  -63.977  50.840  1
460233  98.115  -63.978  50.784  1
460234  98.151  -63.979  50.726  1
460235  98.186  -63.979  50.670  1
460236  98.222  -63.981  50.615  1
460237  98.257  -63.982  50.559  1
460238  98.293  -63.982  50.506  1
460239  98.331  -63.976  50.453  1
460240  98.365  -63.977  50.402  1
460241  98.400  -63.979  50.352  1
460242  98.433  -63.982  50.302  1
460243  98.460  -63.984  50.255  1
460244  98.486  -63.987  50.209  1
460245  98.512  -63.990  50.164  1
460246  98.537  -63.992  50.118  1
460247  98.563  -63.995  50.075  1
460248  98.591  -63.998  50.031  1
460249  98.641  -64.000  49.987  1
460250  98.692  -64.001  49.943  1
460251  98.742  -64.004  49.899  1
460252  98.792  -64.005  49.854  1
460253  98.843  -64.007  49.809  1
460254  98.878  -64.011  49.760  1
460255  98.898  -64.017  49.709  1
460256  98.917  -64.023  49.655  1
460257  98.936  -64.029  49.602  1
460258  98.955  -64.035  49.554  1
460259  99.000  -64.041  49.507  1
460260  99.072  -64.046  49.462  1
460261  99.143  -64.051  49.418  1
460262  99.208  -64.052  49.375  1
460263  99.271  -64.050  49.334  1
460264  99.334  -64.048  49.294  1
460265  99.397  -64.046  49.254  1
460266  99.460  -64.045  49.215  1
460267  99.523  -64.043  49.177  1
460664  86.730  -62.309  56.207  1
460665  86.773  -62.308  56.195  1
460666  86.815  -62.306  56.182  1
460667  86.857  -62.305  56.171  1
460668  86.900  -62.303  56.160  1
460669  86.942  -62.301  56.150  1
460670  86.985  -62.299  56.141  1
460671  87.027  -62.298  56.132  1
460672  87.069  -62.296  56.123  1
460673  87.112  -62.295  56.115  1
460674  87.149  -62.296  56.106  1
460675  87.186  -62.298  56.100  1
460676  87.222  -62.300  56.094  1
460677  87.259  -62.302  56.086  1
460678  87.307  -62.299  56.073  1
460679  87.356  -62.295  56.058  1
460680  87.404  -62.292  56.037  1
460681  87.452  -62.288  56.013  1
460682  87.500  -62.285  55.989  1
460683  87.549  -62.281  55.963  1
460684  87.597  -62.278  55.939  1
460685  87.645  -62.275  55.916  1
460686  87.693  -62.271  55.894  1
460687  87.744  -62.266  55.874  1
460688  87.794  -62.260  55.854  1
460689  87.844  -62.255  55.838  1
460690  87.895  -62.249  55.825  1
460691  87.945  -62.243  55.813  1
460692  87.996  -62.237  55.802  1
460693  88.046  -62.232  55.794  1
460694  88.095  -62.245  55.790  1
460695  88.144  -62.261  55.788  1
460696  88.193  -62.278  55.788  1
460697  88.241  -62.294  55.786  1
460698  88.290  -62.311  55.778  1
460699  88.337  -62.327  55.761  1
460700  88.380  -62.342  55.739  1
460701  88.423  -62.357  55.713  1
460702  88.467  -62.372  55.683  1
460703  88.509  -62.387  55.650  1
460704  88.553  -62.402  55.615  1
460705  88.596  -62.418  55.585  1
460706  88.639  -62.432  55.558  1
460707  88.682  -62.447  55.536  1
460708  88.725  -62.462  55.516  1
460709  88.768  -62.478  55.497  1
460710  88.812  -62.493  55.478  1
460711  88.855  -62.508  55.460  1
460712  88.898  -62.523  55.443  1
460713  88.941  -62.538  55.427  1
460714  88.984  -62.553  55.413  1
460715  89.027  -62.569  55.399  1
460716  89.070  -62.584  55.386  1
460717  89.114  -62.594  55.375  1
460718  89.158  -62.602  55.365  1
460719  89.202  -62.610  55.357  1
460720  89.246  -62.619  55.350  1
460721  89.290  -62.627  55.343  1
460722  89.333  -62.636  55.334  1
460723  89.377  -62.644  55.330  1
460724  89.421  -62.653  55.322  1
460725  89.465  -62.661  55.313  1
460726  89.509  -62.669  55.304  1
460727  89.553  -62.678  55.295  1
460728  89.597  -62.687  55.286  1
460729  89.640  -62.695  55.277  1
460730  89.685  -62.703  55.270  1
460731  89.734  -62.713  55.264  1
460732  89.783  -62.721  55.259  1
460733  89.830  -62.731  55.258  1
460734  89.877  -62.740  55.258  1
460735  89.924  -62.750  55.259  1
460736  89.972  -62.761  55.258  1
460737  90.020  -62.775  55.257  1
460738  90.069  -62.789  55.255  1
460739  90.116  -62.804  55.251  1
460740  90.165  -62.817  55.243  1
460741  90.213  -62.831  55.232  1
460742  90.261  -62.845  55.217  1
460743  90.310  -62.859  55.199  1
460744  90.358  -62.873  55.182  1
460745  90.401  -62.884  55.165  1
460746  90.444  -62.894  55.150  1
460747  90.486  -62.904  55.134  1
460748  90.518  -62.915  55.119  1
460749  90.547  -62.926  55.105  1
460750  90.578  -62.938  55.091  1
460751  90.607  -62.949  55.078  1
460752  90.638  -62.960  55.065  1
460753  90.669  -62.971  55.052  1
460754  90.725  -62.982  55.038  1
460755  90.781  -62.993  55.023  1
460756  90.837  -63.004  55.008  1
460757  90.894  -63.014  54.992  1
460758  90.950  -63.025  54.977  1
460759  91.006  -63.035  54.961  1
460760  91.063  -63.046  54.945  1
460761  91.118  -63.057  54.929  1
460762  91.175  -63.068  54.914  1
460763  91.231  -63.079  54.900  1
460764  91.286  -63.089  54.887  1
460765  91.339  -63.101  54.874  1
460766  91.392  -63.112  54.864  1
460767  91.445  -63.123  54.854  1
460768  91.501  -63.132  54.842  1
460769  91.560  -63.134  54.831  1
460770  91.619  -63.136  54.819  1
460771  91.679  -63.139  54.807  1
460772  91.738  -63.141  54.800  1
460773  91.797  -63.143  54.795  1
460774  91.857  -63.145  54.791  1
460775  91.908  -63.147  54.787  1
460776  91.942  -63.149  54.782  1
460777  91.975  -63.152  54.781  1
460778  92.009  -63.155  54.782  1
460779  92.042  -63.157  54.790  1
460780  92.076  -63.160  54.804  1
460781  92.110  -63.162  54.818  1
460782  92.144  -63.164  54.825  1
460783  92.177  -63.167  54.826  1
460784  92.211  -63.170  54.822  1
460785  92.245  -63.173  54.814  1
460786  92.279  -63.175  54.802  1
460787  92.312  -63.177  54.785  1
460788  92.346  -63.180  54.766  1
460789  92.379  -63.183  54.745  1
460790  92.425  -63.187  54.725  1
460791  92.472  -63.192  54.705  1
460792  92.518  -63.195  54.689  1
460793  92.564  -63.200  54.677  1
460794  92.611  -63.205  54.667  1
460795  92.657  -63.209  54.659  1
460796  92.693  -63.221  54.651  1
460797  92.735  -63.230  54.642  1
460798  92.781  -63.236  54.633  1
460799  92.826  -63.243  54.623  1
460800  92.871  -63.250  54.613  1
460801  92.916  -63.258  54.602  1
460802  92.960  -63.264  54.589  1
460803  93.004  -63.273  54.575  1
460804  93.048  -63.280  54.560  1
460805  93.089  -63.288  54.543  1
460806  93.127  -63.294  54.528  1
460807  93.164  -63.300  54.510  1
460808  93.202  -63.306  54.492  1
460809  93.246  -63.308  54.472  1
460810  93.296  -63.305  54.452  1
460811  93.347  -63.301  54.433  1
460812  93.396  -63.299  54.412  1
460813  93.442  -63.297  54.392  1
460814  93.481  -63.304  54.374  1
460815  93.505  -63.324  54.355  1
460816  93.527  -63.339  54.336  1
460817  93.543  -63.344  54.318  1
460818  93.560  -63.349  54.301  1
460819  93.577  -63.355  54.283  1
460820  93.609  -63.381  54.264  1
460821  93.641  -63.408  54.240  1
460822  93.686  -63.398  54.214  1
460823  93.724  -63.406  54.187  1
460824  93.755  -63.432  54.158  1
460825  93.785  -63.458  54.128  1
460826  93.826  -63.477  54.097  1
460827  93.879  -63.465  54.066  1
460828  93.937  -63.462  54.035  1
460829  93.993  -63.481  54.006  1
460830  94.048  -63.500  53.978  1
460831  94.139  -63.506  53.954  1
460832  94.243  -63.506  53.932  1
460833  94.347  -63.506  53.913  1
460834  94.366  -63.510  53.895  1
460835  94.376  -63.515  53.880  1
460836  94.356  -63.526  53.865  1
460837  94.324  -63.539  53.852  1
460838  94.345  -63.552  53.841  1
460839  94.379  -63.565  53.829  1
460840  94.410  -63.576  53.818  1
460841  94.442  -63.587  53.807  1
460842  94.475  -63.599  53.797  1
460843  94.506  -63.610  53.789  1
460844  94.539  -63.622  53.781  1
460845  94.571  -63.633  53.775  1
460846  94.603  -63.644  53.764  1
460847  94.643  -63.650  53.753  1
460848  94.695  -63.651  53.741  1
460849  94.747  -63.651  53.728  1
460850  94.798  -63.652  53.715  1
460851  94.849  -63.652  53.700  1
460852  94.901  -63.653  53.682  1
460853  94.961  -63.653  53.662  1
460854  95.024  -63.655  53.643  1
460855  95.082  -63.657  53.622  1
460856  95.120  -63.661  53.599  1
460857  95.158  -63.665  53.576  1
460858  95.196  -63.670  53.555  1
460859  95.235  -63.676  53.533  1
460860  95.274  -63.683  53.514  1
460861  95.314  -63.689  53.495  1
460862  95.353  -63.696  53.477  1
460863  95.393  -63.703  53.459  1
460864  95.432  -63.709  53.443  1
460865  95.471  -63.716  53.426  1
460866  95.516  -63.722  53.407  1
460867  95.559  -63.729  53.387  1
460868  95.603  -63.736  53.366  1
460869  95.643  -63.739  53.340  1
460870  95.674  -63.731  53.313  1
460871  95.719  -63.730  53.283  1
460872  95.763  -63.728  53.250  1
460873  95.807  -63.728  53.213  1
460874  95.851  -63.727  53.174  1
460875  95.896  -63.726  53.134  1
460876  95.940  -63.725  53.094  1
460877  95.980  -63.700  53.055  1
460878  96.026  -63.686  53.016  1
460879  96.075  -63.681  52.980  1
460880  96.124  -63.676  52.944  1
460881  96.174  -63.671  52.911  1
460882  96.224  -63.666  52.879  1
460883  96.273  -63.661  52.847  1
460884  96.322  -63.656  52.814  1
460885  96.374  -63.663  52.779  1
460886  96.425  -63.673  52.745  1
460887  96.476  -63.682  52.711  1
460888  96.528  -63.691  52.676  1
460889  96.580  -63.700  52.641  1
460890  96.631  -63.710  52.607  1
460891  96.675  -63.716  52.574  1
460892  96.709  -63.719  52.542  1
460893  96.744  -63.722  52.509  1
460894  96.781  -63.726  52.474  1
460895  96.818  -63.731  52.441  1
460896  96.855  -63.736  52.406  1
460897  96.892  -63.741  52.370  1
460898  96.930  -63.745  52.335  1
460899  96.966  -63.750  52.300  1
460900  97.004  -63.755  52.265  1
460901  97.041  -63.759  52.230  1
460902  97.078  -63.764  52.195  1
460903  97.114  -63.770  52.158  1
460904  97.145  -63.783  52.122  1
460905  97.176  -63.795  52.084  1
460906  97.208  -63.808  52.045  1
460907  97.239  -63.820  52.007  1
460908  97.270  -63.833  51.970  1
460909  97.301  -63.845  51.932  1
460910  97.332  -63.858  51.897  1
460911  97.360  -63.871  51.864  1
460912  97.383  -63.885  51.830  1
460913  97.406  -63.900  51.797  1
460914  97.429  -63.915  51.764  1
460915  97.455  -63.925  51.728  1
460916  97.484  -63.932  51.688  1
460917  97.512  -63.939  51.646  1
460918  97.540  -63.946  51.604  1
460919  97.569  -63.953  51.559  1
460920  97.598  -63.960  51.511  1
460921  97.636  -63.956  51.461  1
460922  97.674  -63.953  51.409  1
460923  97.712  -63.950  51.356  1
460924  97.750  -63.946  51.302  1
460925  97.789  -63.944  51.248  1
460926  97.828  -63.941  51.194  1
460927  97.868  -63.940  51.140  1
460928  97.907  -63.938  51.087  1
460929  97.942  -63.938  51.035  1
460930  97.977  -63.940  50.986  1
460931  98.012  -63.941  50.935  1
460932  98.050  -63.941  50.883  1
460933  98.087  -63.942  50.828  1
460934  98.124  -63.942  50.771  1
460935  98.161  -63.943  50.714  1
460936  98.197  -63.944  50.657  1
460937  98.232  -63.944  50.602  1
460938  98.268  -63.945  50.547  1
460939  98.303  -63.946  50.494  1
460940  98.340  -63.943  50.442  1
460941  98.374  -63.945  50.391  1
460942  98.403  -63.948  50.341  1
460943  98.428  -63.951  50.293  1
460944  98.454  -63.954  50.247  1
460945  98.480  -63.956  50.202  1
460946  98.505  -63.959  50.156  1
460947  98.531  -63.961  50.111  1
460948  98.557  -63.964  50.067  1
460949  98.582  -63.966  50.024  1
460950  98.623  -63.969  49.982  1
460951  98.673  -63.971  49.939  1
460952  98.723  -63.973  49.895  1
460953  98.774  -63.975  49.851  1
460954  98.824  -63.976  49.802  1
460955  98.853  -63.982  49.751  1
460956  98.872  -63.988  49.697  1
460957  98.891  -63.994  49.642  1
460958  98.911  -64.000  49.590  1
460959  98.948  -64.006  49.541  1
460960  99.019  -64.010  49.495  1
460961  99.090  -64.016  49.450  1
460962  99.154  -64.015  49.405  1
460963  99.217  -64.013  49.363  1
460964  99.280  -64.011  49.321  1
460965  99.343  -64.010  49.282  1
460966  99.406  -64.007  49.242  1
460967  99.469  -64.006  49.204  1
460968  99.532  -64.004  49.166  1
461366  86.789  -62.259  56.197  1
461367  86.832  -62.258  56.185  1
461368  86.874  -62.255  56.174  1
461369  86.916  -62.254  56.163  1
461370  86.958  -62.252  56.153  1
461371  87.001  -62.251  56.144  1
461372  87.044  -62.249  56.135  1
461373  87.086  -62.248  56.127  1
461374  87.127  -62.247  56.119  1
461375  87.164  -62.249  56.111  1
461376  87.201  -62.250  56.105  1
461377  87.237  -62.252  56.099  1
461378  87.274  -62.254  56.092  1
461379  87.317  -62.253  56.082  1
461380  87.365  -62.249  56.067  1
461381  87.413  -62.246  56.048  1
461382  87.462  -62.243  56.025  1
461383  87.510  -62.239  56.001  1
461384  87.558  -62.236  55.975  1
461385  87.607  -62.233  55.950  1
461386  87.654  -62.230  55.928  1
461387  87.703  -62.226  55.906  1
461388  87.751  -62.223  55.885  1
461389  87.799  -62.219  55.865  1
461390  87.849  -62.214  55.848  1
461391  87.900  -62.208  55.833  1
461392  87.950  -62.203  55.819  1
461393  88.000  -62.197  55.808  1
461394  88.051  -62.192  55.798  1
461395  88.101  -62.194  55.791  1
461396  88.149  -62.211  55.787  1
461397  88.198  -62.227  55.785  1
461398  88.247  -62.243  55.782  1
461399  88.296  -62.260  55.772  1
461400  88.344  -62.276  55.757  1
461401  88.393  -62.293  55.737  1
461402  88.439  -62.308  55.711  1
461403  88.482  -62.323  55.680  1
461404  88.525  -62.338  55.645  1
461405  88.568  -62.353  55.612  1
461406  88.612  -62.368  55.582  1
461407  88.654  -62.384  55.557  1
461408  88.698  -62.399  55.535  1
461409  88.741  -62.414  55.515  1
461410  88.784  -62.429  55.497  1
461411  88.827  -62.444  55.480  1
461412  88.871  -62.459  55.463  1
461413  88.914  -62.474  55.444  1
461414  88.957  -62.489  55.429  1
461415  89.000  -62.504  55.415  1
461416  89.043  -62.519  55.401  1
461417  89.087  -62.529  55.388  1
461418  89.131  -62.537  55.375  1
461419  89.175  -62.546  55.364  1
461420  89.218  -62.554  55.354  1
461421  89.262  -62.563  55.346  1
461422  89.306  -62.572  55.339  1
461423  89.350  -62.580  55.329  1
461424  89.394  -62.588  55.324  1
461425  89.438  -62.597  55.316  1
461426  89.481  -62.606  55.307  1
461427  89.525  -62.614  55.297  1
461428  89.569  -62.622  55.288  1
461429  89.613  -62.631  55.279  1
461430  89.657  -62.639  55.270  1
461431  89.701  -62.647  55.262  1
461432  89.745  -62.656  55.255  1
461433  89.793  -62.665  55.250  1
461434  89.840  -62.675  55.247  1
461435  89.888  -62.687  55.246  1
461436  89.936  -62.700  55.245  1
461437  89.984  -62.714  55.245  1
461438  90.033  -62.728  55.244  1
461439  90.081  -62.742  55.242  1
461440  90.129  -62.757  55.238  1
461441  90.177  -62.770  55.232  1
461442  90.226  -62.785  55.222  1
461443  90.274  -62.798  55.210  1
461444  90.322  -62.812  55.195  1
461445  90.370  -62.826  55.180  1
461446  90.416  -62.838  55.166  1
461447  90.459  -62.848  55.152  1
461448  90.502  -62.858  55.135  1
461449  90.544  -62.868  55.118  1
461450  90.578  -62.879  55.102  1
461451  90.608  -62.890  55.086  1
461452  90.638  -62.901  55.072  1
461453  90.668  -62.913  55.057  1
461454  90.698  -62.924  55.044  1
461455  90.743  -62.935  55.030  1
461456  90.800  -62.946  55.016  1
461457  90.856  -62.957  55.002  1
461458  90.912  -62.967  54.988  1
461459  90.968  -62.978  54.974  1
461460  91.024  -62.989  54.960  1
461461  91.081  -63.000  54.947  1
461462  91.137  -63.010  54.933  1
461463  91.193  -63.021  54.919  1
461464  91.248  -63.032  54.907  1
461465  91.301  -63.043  54.895  1
461466  91.355  -63.054  54.883  1
461467  91.407  -63.066  54.873  1
461468  91.461  -63.078  54.862  1
461469  91.516  -63.086  54.850  1
461470  91.575  -63.088  54.837  1
461471  91.635  -63.090  54.824  1
461472  91.694  -63.092  54.813  1
461473  91.753  -63.095  54.804  1
461474  91.812  -63.097  54.798  1
461475  91.870  -63.101  54.795  1
461476  91.913  -63.110  54.792  1
461477  91.952  -63.110  54.788  1
461478  91.994  -63.113  54.787  1
461479  92.029  -63.117  54.789  1
461480  92.064  -63.120  54.797  1
461481  92.097  -63.122  54.812  1
461482  92.131  -63.125  54.826  1
461483  92.165  -63.127  54.835  1
461484  92.199  -63.130  54.838  1
461485  92.232  -63.133  54.837  1
461486  92.266  -63.135  54.831  1
461487  92.300  -63.138  54.820  1
461488  92.333  -63.140  54.803  1
461489  92.367  -63.142  54.783  1
461490  92.401  -63.145  54.761  1
461491  92.434  -63.148  54.738  1
461492  92.479  -63.152  54.715  1
461493  92.525  -63.156  54.694  1
461494  92.571  -63.161  54.676  1
461495  92.618  -63.165  54.663  1
461496  92.664  -63.170  54.652  1
461497  92.698  -63.183  54.643  1
461498  92.735  -63.195  54.633  1
461499  92.781  -63.202  54.623  1
461500  92.826  -63.208  54.613  1
461501  92.871  -63.215  54.602  1
461502  92.916  -63.223  54.590  1
461503  92.961  -63.230  54.576  1
461504  93.006  -63.236  54.561  1
461505  93.059  -63.239  54.543  1
461506  93.088  -63.248  54.525  1
461507  93.125  -63.254  54.506  1
461508  93.163  -63.260  54.486  1
461509  93.200  -63.266  54.466  1
461510  93.249  -63.264  54.445  1
461511  93.298  -63.261  54.425  1
461512  93.345  -63.260  54.406  1
461513  93.392  -63.258  54.386  1
461514  93.438  -63.256  54.367  1
461515  93.472  -63.268  54.348  1
461516  93.497  -63.289  54.331  1
461517  93.521  -63.310  54.312  1
461518  93.546  -63.331  54.294  1
461519  93.563  -63.338  54.278  1
461520  93.582  -63.347  54.262  1
461521  93.614  -63.371  54.242  1
461522  93.642  -63.368  54.219  1
461523  93.669  -63.364  54.193  1
461524  93.704  -63.372  54.165  1
461525  93.745  -63.392  54.134  1
461526  93.786  -63.412  54.104  1
461527  93.825  -63.418  54.074  1
461528  93.878  -63.404  54.044  1
461529  93.934  -63.423  54.016  1
461530  93.989  -63.442  53.989  1
461531  94.045  -63.462  53.963  1
461532  94.101  -63.480  53.942  1
461533  94.164  -63.497  53.922  1
461534  94.229  -63.499  53.904  1
461535  94.239  -63.504  53.888  1
461536  94.256  -63.507  53.873  1
461537  94.285  -63.506  53.859  1
461538  94.314  -63.505  53.847  1
461539  94.349  -63.510  53.836  1
461540  94.381  -63.521  53.824  1
461541  94.413  -63.532  53.813  1
461542  94.445  -63.543  53.802  1
461543  94.477  -63.555  53.791  1
461544  94.509  -63.566  53.782  1
461545  94.542  -63.578  53.772  1
461546  94.573  -63.589  53.765  1
461547  94.606  -63.600  53.754  1
461548  94.647  -63.606  53.742  1
461549  94.698  -63.607  53.729  1
461550  94.750  -63.607  53.715  1
461551  94.802  -63.608  53.702  1
461552  94.853  -63.608  53.688  1
461553  94.910  -63.609  53.671  1
461554  94.973  -63.610  53.652  1
461555  95.036  -63.612  53.633  1
461556  95.091  -63.614  53.611  1
461557  95.129  -63.618  53.588  1
461558  95.167  -63.622  53.566  1
461559  95.205  -63.627  53.543  1
461560  95.244  -63.631  53.521  1
461561  95.283  -63.638  53.500  1
461562  95.322  -63.644  53.481  1
461563  95.361  -63.651  53.462  1
461564  95.401  -63.658  53.443  1
461565  95.441  -63.665  53.426  1
461566  95.480  -63.672  53.408  1
461567  95.519  -63.678  53.391  1
461568  95.559  -63.684  53.372  1
461569  95.601  -63.691  53.351  1
461570  95.639  -63.693  53.328  1
461571  95.683  -63.691  53.302  1
461572  95.728  -63.690  53.274  1
461573  95.772  -63.690  53.242  1
461574  95.816  -63.689  53.206  1
461575  95.861  -63.688  53.167  1
461576  95.905  -63.687  53.125  1
461577  95.949  -63.686  53.084  1
461578  95.991  -63.668  53.042  1
461579  96.037  -63.655  53.000  1
461580  96.086  -63.650  52.961  1
461581  96.135  -63.645  52.923  1
461582  96.185  -63.640  52.887  1
461583  96.235  -63.635  52.854  1
461584  96.284  -63.630  52.821  1
461585  96.333  -63.625  52.788  1
461586  96.383  -63.620  52.752  1
461587  96.434  -63.626  52.716  1
461588  96.485  -63.635  52.680  1
461589  96.537  -63.644  52.644  1
461590  96.589  -63.654  52.608  1
461591  96.640  -63.663  52.573  1
461592  96.686  -63.670  52.539  1
461593  96.720  -63.672  52.507  1
461594  96.756  -63.676  52.474  1
461595  96.793  -63.681  52.441  1
461596  96.830  -63.685  52.408  1
461597  96.867  -63.690  52.375  1
461598  96.904  -63.695  52.341  1
461599  96.941  -63.700  52.308  1
461600  96.978  -63.704  52.274  1
461601  97.015  -63.709  52.240  1
461602  97.052  -63.714  52.206  1
461603  97.084  -63.726  52.171  1
461604  97.115  -63.738  52.136  1
461605  97.147  -63.750  52.101  1
461606  97.178  -63.763  52.066  1
461607  97.209  -63.775  52.030  1
461608  97.240  -63.788  51.994  1
461609  97.272  -63.800  51.958  1
461610  97.303  -63.813  51.921  1
461611  97.334  -63.825  51.887  1
461612  97.359  -63.840  51.853  1
461613  97.382  -63.854  51.820  1
461614  97.404  -63.869  51.788  1
461615  97.427  -63.883  51.755  1
461616  97.451  -63.896  51.719  1
461617  97.480  -63.903  51.679  1
461618  97.509  -63.910  51.637  1
461619  97.537  -63.917  51.593  1
461620  97.566  -63.924  51.548  1
461621  97.602  -63.922  51.499  1
461622  97.641  -63.919  51.449  1
461623  97.679  -63.916  51.397  1
461624  97.717  -63.913  51.344  1
461625  97.756  -63.910  51.290  1
461626  97.796  -63.909  51.236  1
461627  97.835  -63.907  51.181  1
461628  97.874  -63.904  51.127  1
461629  97.914  -63.902  51.072  1
461630  97.949  -63.903  51.021  1
461631  97.984  -63.904  50.971  1
461632  98.018  -63.905  50.920  1
461633  98.053  -63.907  50.867  1
461634  98.090  -63.907  50.813  1
461635  98.128  -63.907  50.757  1
461636  98.165  -63.908  50.700  1
461637  98.202  -63.909  50.645  1
461638  98.239  -63.909  50.591  1
461639  98.277  -63.910  50.538  1
461640  98.313  -63.910  50.485  1
461641  98.344  -63.912  50.433  1
461642  98.370  -63.914  50.382  1
461643  98.395  -63.917  50.333  1
461644  98.421  -63.919  50.284  1
461645  98.447  -63.922  50.238  1
461646  98.473  -63.925  50.193  1
461647  98.498  -63.928  50.147  1
461648  98.524  -63.930  50.102  1
461649  98.550  -63.933  50.059  1
461650  98.575  -63.935  50.016  1
461651  98.604  -63.938  49.974  1
461652  98.654  -63.940  49.932  1
461653  98.705  -63.942  49.888  1
461654  98.755  -63.944  49.842  1
461655  98.805  -63.946  49.792  1
461656  98.828  -63.951  49.738  1
461657  98.847  -63.958  49.683  1
461658  98.866  -63.964  49.628  1
461659  98.895  -63.970  49.577  1
461660  98.966  -63.975  49.529  1
461661  99.037  -63.979  49.483  1
461662  99.099  -63.978  49.438  1
461663  99.162  -63.976  49.394  1
461664  99.225  -63.974  49.352  1
461665  99.288  -63.973  49.310  1
461666  99.351  -63.970  49.271  1
461667  99.414  -63.969  49.232  1
461668  99.477  -63.967  49.193  1
462067  86.805  -62.211  56.201  1
462068  86.848  -62.208  56.189  1
462069  86.890  -62.207  56.177  1
462070  86.933  -62.205  56.166  1
462071  86.975  -62.204  56.155  1
462072  87.017  -62.202  56.147  1
462073  87.060  -62.201  56.138  1
462074  87.103  -62.199  56.129  1
462075  87.142  -62.199  56.122  1
462076  87.179  -62.201  56.115  1
462077  87.216  -62.202  56.108  1
462078  87.253  -62.204  56.102  1
462079  87.289  -62.206  56.096  1
462080  87.326  -62.208  56.087  1
462081  87.374  -62.205  56.074  1
462082  87.423  -62.201  56.057  1
462083  87.471  -62.198  56.036  1
462084  87.519  -62.194  56.013  1
462085  87.568  -62.191  55.988  1
462086  87.616  -62.187  55.963  1
462087  87.664  -62.184  55.939  1
462088  87.712  -62.181  55.916  1
462089  87.761  -62.177  55.895  1
462090  87.809  -62.174  55.875  1
462091  87.857  -62.171  55.857  1
462092  87.905  -62.167  55.841  1
462093  87.955  -62.162  55.827  1
462094  88.005  -62.157  55.814  1
462095  88.056  -62.151  55.802  1
462096  88.106  -62.145  55.792  1
462097  88.155  -62.159  55.785  1
462098  88.204  -62.176  55.780  1
462099  88.253  -62.192  55.773  1
462100  88.302  -62.208  55.764  1
462101  88.350  -62.225  55.751  1
462102  88.399  -62.241  55.732  1
462103  88.448  -62.258  55.708  1
462104  88.496  -62.274  55.677  1
462105  88.541  -62.290  55.642  1
462106  88.584  -62.305  55.609  1
462107  88.627  -62.320  55.580  1
462108  88.671  -62.335  55.555  1
462109  88.713  -62.350  55.534  1
462110  88.757  -62.365  55.515  1
462111  88.800  -62.380  55.498  1
462112  88.843  -62.395  55.481  1
462113  88.886  -62.410  55.464  1
462114  88.929  -62.425  55.447  1
462115  88.972  -62.440  55.431  1
462116  89.016  -62.456  55.416  1
462117  89.059  -62.465  55.402  1
462118  89.103  -62.473  55.389  1
462119  89.147  -62.481  55.375  1
462120  89.191  -62.490  55.362  1
462121  89.235  -62.499  55.352  1
462122  89.279  -62.507  55.344  1
462123  89.323  -62.515  55.334  1
462124  89.367  -62.524  55.325  1
462125  89.410  -62.532  55.318  1
462126  89.454  -62.541  55.311  1
462127  89.498  -62.550  55.302  1
462128  89.542  -62.558  55.291  1
462129  89.586  -62.566  55.282  1
462130  89.629  -62.575  55.273  1
462131  89.674  -62.584  55.264  1
462132  89.718  -62.592  55.256  1
462133  89.760  -62.601  55.249  1
462134  89.803  -62.612  55.243  1
462135  89.852  -62.625  55.238  1
462136  89.900  -62.640  55.235  1
462137  89.949  -62.653  55.232  1
462138  89.997  -62.668  55.232  1
462139  90.045  -62.681  55.231  1
462140  90.094  -62.696  55.229  1
462141  90.142  -62.710  55.225  1
462142  90.190  -62.723  55.220  1
462143  90.238  -62.738  55.212  1
462144  90.287  -62.751  55.202  1
462145  90.334  -62.766  55.191  1
462146  90.383  -62.779  55.180  1
462147  90.431  -62.793  55.169  1
462148  90.474  -62.803  55.156  1
462149  90.516  -62.813  55.140  1
462150  90.559  -62.822  55.122  1
462151  90.602  -62.832  55.103  1
462152  90.639  -62.843  55.085  1
462153  90.668  -62.854  55.067  1
462154  90.698  -62.866  55.052  1
462155  90.728  -62.877  55.038  1
462156  90.761  -62.888  55.024  1
462157  90.818  -62.899  55.011  1
462158  90.874  -62.910  54.997  1
462159  90.930  -62.921  54.986  1
462160  90.987  -62.932  54.973  1
462161  91.042  -62.942  54.960  1
462162  91.099  -62.953  54.949  1
462163  91.155  -62.963  54.937  1
462164  91.211  -62.974  54.926  1
462165  91.263  -62.986  54.915  1
462166  91.317  -62.998  54.904  1
462167  91.370  -63.009  54.892  1
462168  91.423  -63.020  54.882  1
462169  91.476  -63.032  54.870  1
462170  91.531  -63.040  54.857  1
462171  91.590  -63.042  54.842  1
462172  91.650  -63.045  54.828  1
462173  91.709  -63.047  54.816  1
462174  91.769  -63.049  54.806  1
462175  91.826  -63.052  54.800  1
462176  91.872  -63.063  54.796  1
462177  91.917  -63.074  54.794  1
462178  91.951  -63.070  54.792  1
462179  91.991  -63.072  54.791  1
462180  92.033  -63.075  54.795  1
462181  92.076  -63.079  54.805  1
462182  92.114  -63.082  54.822  1
462183  92.149  -63.086  54.837  1
462184  92.185  -63.089  54.848  1
462185  92.220  -63.092  54.853  1
462186  92.253  -63.095  54.854  1
462187  92.287  -63.098  54.849  1
462188  92.320  -63.100  54.838  1
462189  92.354  -63.103  54.821  1
462190  92.388  -63.105  54.799  1
462191  92.422  -63.108  54.776  1
462192  92.455  -63.111  54.750  1
462193  92.489  -63.113  54.725  1
462194  92.532  -63.117  54.699  1
462195  92.579  -63.121  54.677  1
462196  92.625  -63.126  54.659  1
462197  92.670  -63.131  54.645  1
462198  92.704  -63.144  54.633  1
462199  92.738  -63.158  54.622  1
462200  92.781  -63.167  54.612  1
462201  92.826  -63.173  54.601  1
462202  92.871  -63.180  54.587  1
462203  92.916  -63.187  54.574  1
462204  92.961  -63.195  54.560  1
462205  93.012  -63.198  54.543  1
462206  93.080  -63.193  54.525  1
462207  93.122  -63.198  54.506  1
462208  93.147  -63.208  54.485  1
462209  93.171  -63.217  54.463  1
462210  93.200  -63.224  54.440  1
462211  93.247  -63.223  54.418  1
462212  93.294  -63.221  54.398  1
462213  93.341  -63.220  54.379  1
462214  93.388  -63.218  54.359  1
462215  93.434  -63.216  54.340  1
462216  93.464  -63.233  54.322  1
462217  93.488  -63.253  54.304  1
462218  93.512  -63.274  54.286  1
462219  93.537  -63.296  54.270  1
462220  93.562  -63.316  54.254  1
462221  93.587  -63.330  54.237  1
462222  93.617  -63.330  54.217  1
462223  93.647  -63.329  54.194  1
462224  93.677  -63.328  54.168  1
462225  93.709  -63.331  54.141  1
462226  93.747  -63.346  54.112  1
462227  93.789  -63.365  54.082  1
462228  93.824  -63.357  54.053  1
462229  93.875  -63.365  54.025  1
462230  93.931  -63.383  53.998  1
462231  93.987  -63.399  53.974  1
462232  94.044  -63.416  53.951  1
462233  94.101  -63.433  53.932  1
462234  94.157  -63.450  53.914  1
462235  94.191  -63.465  53.898  1
462236  94.220  -63.465  53.882  1
462237  94.249  -63.463  53.868  1
462238  94.278  -63.462  53.856  1
462239  94.312  -63.466  53.844  1
462240  94.347  -63.472  53.832  1
462241  94.383  -63.478  53.821  1
462242  94.416  -63.488  53.810  1
462243  94.449  -63.499  53.799  1
462244  94.480  -63.511  53.788  1
462245  94.512  -63.522  53.776  1
462246  94.544  -63.534  53.766  1
462247  94.576  -63.545  53.756  1
462248  94.609  -63.556  53.744  1
462249  94.650  -63.562  53.732  1
462250  94.702  -63.563  53.718  1
462251  94.753  -63.563  53.704  1
462252  94.805  -63.564  53.689  1
462253  94.859  -63.565  53.674  1
462254  94.922  -63.566  53.657  1
462255  94.984  -63.567  53.638  1
462256  95.047  -63.568  53.618  1
462257  95.101  -63.571  53.597  1
462258  95.139  -63.575  53.575  1
462259  95.177  -63.580  53.552  1
462260  95.215  -63.584  53.529  1
462261  95.253  -63.588  53.506  1
462262  95.291  -63.593  53.484  1
462263  95.331  -63.600  53.463  1
462264  95.370  -63.606  53.443  1
462265  95.410  -63.613  53.424  1
462266  95.449  -63.620  53.405  1
462267  95.488  -63.626  53.387  1
462268  95.528  -63.633  53.368  1
462269  95.567  -63.640  53.349  1
462270  95.607  -63.647  53.329  1
462271  95.646  -63.648  53.308  1
462272  95.692  -63.651  53.284  1
462273  95.737  -63.652  53.256  1
462274  95.781  -63.650  53.226  1
462275  95.825  -63.650  53.193  1
462276  95.870  -63.649  53.156  1
462277  95.914  -63.648  53.115  1
462278  95.959  -63.647  53.073  1
462279  96.001  -63.634  53.029  1
462280  96.048  -63.625  52.985  1
462281  96.097  -63.619  52.943  1
462282  96.147  -63.614  52.902  1
462283  96.196  -63.609  52.863  1
462284  96.246  -63.604  52.827  1
462285  96.295  -63.599  52.793  1
462286  96.344  -63.594  52.758  1
462287  96.394  -63.589  52.723  1
462288  96.444  -63.584  52.686  1
462289  96.495  -63.588  52.648  1
462290  96.546  -63.598  52.610  1
462291  96.597  -63.607  52.574  1
462292  96.649  -63.616  52.538  1
462293  96.697  -63.625  52.504  1
462294  96.731  -63.627  52.471  1
462295  96.767  -63.631  52.439  1
462296  96.805  -63.635  52.407  1
462297  96.841  -63.640  52.376  1
462298  96.879  -63.645  52.343  1
462299  96.916  -63.650  52.310  1
462300  96.953  -63.654  52.279  1
462301  96.990  -63.659  52.246  1
462302  97.023  -63.669  52.213  1
462303  97.054  -63.681  52.179  1
462304  97.086  -63.694  52.145  1
462305  97.117  -63.706  52.111  1
462306  97.148  -63.719  52.078  1
462307  97.179  -63.731  52.045  1
462308  97.211  -63.744  52.012  1
462309  97.242  -63.756  51.978  1
462310  97.274  -63.769  51.944  1
462311  97.305  -63.781  51.908  1
462312  97.334  -63.794  51.874  1
462313  97.357  -63.808  51.841  1
462314  97.380  -63.822  51.809  1
462315  97.403  -63.838  51.777  1
462316  97.426  -63.852  51.744  1
462317  97.449  -63.866  51.708  1
462318  97.477  -63.874  51.668  1
462319  97.505  -63.881  51.626  1
462320  97.534  -63.888  51.581  1
462321  97.569  -63.888  51.535  1
462322  97.607  -63.885  51.486  1
462323  97.645  -63.882  51.436  1
462324  97.684  -63.879  51.384  1
462325  97.724  -63.878  51.332  1
462326  97.763  -63.875  51.277  1
462327  97.803  -63.873  51.223  1
462328  97.842  -63.871  51.168  1
462329  97.881  -63.869  51.113  1
462330  97.921  -63.867  51.058  1
462331  97.956  -63.867  51.006  1
462332  97.991  -63.869  50.955  1
462333  98.025  -63.869  50.904  1
462334  98.060  -63.871  50.852  1
462335  98.095  -63.872  50.798  1
462336  98.131  -63.872  50.744  1
462337  98.168  -63.873  50.688  1
462338  98.206  -63.874  50.634  1
462339  98.242  -63.875  50.581  1
462340  98.276  -63.878  50.530  1
462341  98.309  -63.882  50.478  1
462342  98.340  -63.885  50.425  1
462343  98.364  -63.885  50.374  1
462344  98.389  -63.886  50.324  1
462345  98.415  -63.888  50.275  1
462346  98.440  -63.891  50.228  1
462347  98.466  -63.894  50.183  1
462348  98.492  -63.897  50.137  1
462349  98.517  -63.900  50.091  1
462350  98.543  -63.902  50.048  1
462351  98.569  -63.905  50.006  1
462352  98.594  -63.907  49.964  1
462353  98.636  -63.910  49.921  1
462354  98.686  -63.911  49.877  1
462355  98.736  -63.913  49.831  1
462356  98.783  -63.916  49.779  1
462357  98.802  -63.922  49.723  1
462358  98.821  -63.928  49.668  1
462359  98.842  -63.934  49.614  1
462360  98.914  -63.939  49.564  1
462361  98.982  -63.943  49.517  1
462362  99.045  -63.941  49.471  1
462363  99.108  -63.939  49.427  1
462364  99.171  -63.937  49.383  1
462365  99.234  -63.935  49.341  1
462366  99.297  -63.934  49.299  1
462367  99.360  -63.932  49.260  1
462368  99.423  -63.930  49.221  1
462369  99.486  -63.928  49.183  1
462769  86.864  -62.160  56.192  1
462770  86.907  -62.158  56.179  1
462771  86.949  -62.157  56.168  1
462772  86.992  -62.155  56.158  1
462773  87.034  -62.154  56.148  1
462774  87.076  -62.152  56.139  1
462775  87.119  -62.151  56.131  1
462776  87.158  -62.151  56.123  1
462777  87.194  -62.153  56.116  1
462778  87.231  -62.155  56.108  1
462779  87.268  -62.156  56.101  1
462780  87.304  -62.158  56.094  1
462781  87.341  -62.160  56.088  1
462782  87.384  -62.159  56.077  1
462783  87.432  -62.155  56.063  1
462784  87.481  -62.152  56.046  1
462785  87.529  -62.149  56.024  1
462786  87.577  -62.145  56.001  1
462787  87.625  -62.142  55.975  1
462788  87.674  -62.139  55.950  1
462789  87.722  -62.136  55.926  1
462790  87.770  -62.132  55.904  1
462791  87.819  -62.129  55.883  1
462792  87.867  -62.125  55.865  1
462793  87.915  -62.122  55.848  1
462794  87.963  -62.119  55.833  1
462795  88.011  -62.115  55.819  1
462796  88.061  -62.111  55.806  1
462797  88.111  -62.105  55.796  1
462798  88.161  -62.108  55.787  1
462799  88.210  -62.124  55.778  1
462800  88.258  -62.141  55.769  1
462801  88.307  -62.158  55.759  1
462802  88.356  -62.174  55.746  1
462803  88.405  -62.190  55.729  1
462804  88.454  -62.207  55.706  1
462805  88.502  -62.223  55.676  1
462806  88.551  -62.239  55.642  1
462807  88.600  -62.255  55.608  1
462808  88.643  -62.271  55.578  1
462809  88.686  -62.286  55.553  1
462810  88.730  -62.301  55.533  1
462811  88.772  -62.316  55.515  1
462812  88.816  -62.331  55.499  1
462813  88.859  -62.346  55.482  1
462814  88.902  -62.362  55.465  1
462815  88.945  -62.377  55.448  1
462816  88.988  -62.392  55.432  1
462817  89.032  -62.400  55.417  1
462818  89.076  -62.409  55.403  1
462819  89.120  -62.417  55.389  1
462820  89.164  -62.425  55.375  1
462821  89.207  -62.434  55.362  1
462822  89.251  -62.443  55.351  1
462823  89.295  -62.451  55.340  1
462824  89.339  -62.459  55.330  1
462825  89.383  -62.468  55.320  1
462826  89.427  -62.477  55.313  1
462827  89.471  -62.485  55.305  1
462828  89.515  -62.493  55.296  1
462829  89.557  -62.503  55.286  1
462830  89.600  -62.512  55.277  1
462831  89.643  -62.522  55.267  1
462832  89.685  -62.531  55.259  1
462833  89.728  -62.541  55.251  1
462834  89.770  -62.550  55.244  1
462835  89.814  -62.563  55.238  1
462836  89.863  -62.580  55.231  1
462837  89.913  -62.593  55.225  1
462838  89.961  -62.606  55.221  1
462839  90.010  -62.621  55.220  1
462840  90.058  -62.634  55.218  1
462841  90.106  -62.649  55.216  1
462842  90.154  -62.663  55.213  1
462843  90.202  -62.677  55.209  1
462844  90.251  -62.691  55.204  1
462845  90.299  -62.704  55.196  1
462846  90.347  -62.719  55.190  1
462847  90.395  -62.732  55.183  1
462848  90.444  -62.747  55.174  1
462849  90.488  -62.758  55.162  1
462850  90.531  -62.768  55.146  1
462851  90.574  -62.778  55.127  1
462852  90.616  -62.788  55.107  1
462853  90.659  -62.797  55.086  1
462854  90.699  -62.807  55.066  1
462855  90.729  -62.819  55.049  1
462856  90.759  -62.830  55.034  1
462857  90.789  -62.841  55.020  1
462858  90.836  -62.853  55.008  1
462859  90.892  -62.863  54.995  1
462860  90.948  -62.874  54.984  1
462861  91.005  -62.885  54.972  1
462862  91.061  -62.895  54.961  1
462863  91.117  -62.906  54.952  1
462864  91.173  -62.917  54.941  1
462865  91.226  -62.929  54.932  1
462866  91.279  -62.940  54.923  1
462867  91.332  -62.951  54.913  1
462868  91.385  -62.963  54.901  1
462869  91.438  -62.974  54.890  1
462870  91.492  -62.985  54.877  1
462871  91.546  -62.994  54.862  1
462872  91.606  -62.996  54.846  1
462873  91.665  -62.998  54.831  1
462874  91.724  -63.001  54.818  1
462875  91.784  -63.003  54.809  1
462876  91.828  -63.014  54.802  1
462877  91.874  -63.025  54.797  1
462878  91.919  -63.036  54.795  1
462879  91.955  -63.036  54.795  1
462880  91.990  -63.032  54.796  1
462881  92.030  -63.034  54.802  1
462882  92.073  -63.037  54.813  1
462883  92.116  -63.041  54.831  1
462884  92.158  -63.045  54.847  1
462885  92.198  -63.048  54.859  1
462886  92.234  -63.051  54.866  1
462887  92.270  -63.055  54.868  1
462888  92.305  -63.059  54.863  1
462889  92.341  -63.063  54.851  1
462890  92.375  -63.065  54.834  1
462891  92.409  -63.068  54.813  1
462892  92.443  -63.070  54.788  1
462893  92.477  -63.073  54.762  1
462894  92.510  -63.076  54.734  1
462895  92.544  -63.078  54.706  1
462896  92.586  -63.082  54.680  1
462897  92.632  -63.086  54.657  1
462898  92.676  -63.092  54.638  1
462899  92.710  -63.106  54.623  1
462900  92.744  -63.120  54.609  1
462901  92.781  -63.132  54.597  1
462902  92.826  -63.139  54.585  1
462903  92.871  -63.145  54.570  1
462904  92.916  -63.152  54.556  1
462905  92.966  -63.157  54.541  1
462906  93.034  -63.152  54.523  1
462907  93.083  -63.158  54.505  1
462908  93.118  -63.167  54.486  1
462909  93.142  -63.177  54.464  1
462910  93.166  -63.188  54.440  1
462911  93.211  -63.185  54.416  1
462912  93.243  -63.183  54.393  1
462913  93.290  -63.181  54.373  1
462914  93.337  -63.180  54.353  1
462915  93.383  -63.177  54.334  1
462916  93.430  -63.176  54.316  1
462917  93.455  -63.197  54.298  1
462918  93.479  -63.217  54.279  1
462919  93.504  -63.239  54.262  1
462920  93.529  -63.260  54.245  1
462921  93.555  -63.279  54.228  1
462922  93.594  -63.290  54.210  1
462923  93.631  -63.299  54.190  1
462924  93.661  -63.299  54.166  1
462925  93.691  -63.298  54.141  1
462926  93.721  -63.297  54.115  1
462927  93.758  -63.310  54.088  1
462928  93.796  -63.324  54.061  1
462929  93.833  -63.313  54.035  1
462930  93.878  -63.308  54.009  1
462931  93.934  -63.326  53.985  1
462932  93.991  -63.343  53.962  1
462933  94.047  -63.359  53.943  1
462934  94.104  -63.376  53.925  1
462935  94.151  -63.402  53.909  1
462936  94.184  -63.422  53.893  1
462937  94.213  -63.421  53.879  1
462938  94.242  -63.420  53.865  1
462939  94.274  -63.423  53.854  1
462940  94.310  -63.429  53.843  1
462941  94.346  -63.435  53.831  1
462942  94.382  -63.441  53.821  1
462943  94.418  -63.447  53.810  1
462944  94.451  -63.456  53.798  1
462945  94.483  -63.468  53.786  1
462946  94.516  -63.479  53.774  1
462947  94.547  -63.490  53.761  1
462948  94.579  -63.502  53.749  1
462949  94.611  -63.513  53.735  1
462950  94.653  -63.518  53.721  1
462951  94.705  -63.519  53.708  1
462952  94.757  -63.519  53.693  1
462953  94.809  -63.520  53.676  1
462954  94.871  -63.521  53.659  1
462955  94.933  -63.523  53.642  1
462956  94.996  -63.524  53.622  1
462957  95.059  -63.525  53.602  1
462958  95.110  -63.528  53.581  1
462959  95.148  -63.533  53.558  1
462960  95.186  -63.537  53.535  1
462961  95.225  -63.541  53.512  1
462962  95.262  -63.545  53.489  1
462963  95.301  -63.549  53.466  1
462964  95.339  -63.555  53.444  1
462965  95.379  -63.562  53.424  1
462966  95.418  -63.568  53.404  1
462967  95.458  -63.575  53.384  1
462968  95.497  -63.581  53.364  1
462969  95.536  -63.588  53.344  1
462970  95.576  -63.595  53.324  1
462971  95.609  -63.595  53.305  1
462972  95.650  -63.596  53.284  1
462973  95.696  -63.600  53.262  1
462974  95.742  -63.603  53.235  1
462975  95.788  -63.606  53.205  1
462976  95.834  -63.609  53.173  1
462977  95.879  -63.610  53.139  1
462978  95.923  -63.609  53.101  1
462979  95.968  -63.608  53.061  1
462980  96.011  -63.602  53.017  1
462981  96.059  -63.593  52.972  1
462982  96.108  -63.588  52.926  1
462983  96.158  -63.583  52.883  1
462984  96.207  -63.578  52.841  1
462985  96.257  -63.573  52.802  1
462986  96.306  -63.568  52.764  1
462987  96.356  -63.563  52.728  1
462988  96.405  -63.558  52.691  1
462989  96.455  -63.553  52.653  1
462990  96.504  -63.548  52.615  1
462991  96.555  -63.551  52.576  1
462992  96.606  -63.560  52.539  1
462993  96.658  -63.569  52.502  1
462994  96.709  -63.578  52.468  1
462995  96.742  -63.581  52.435  1
462996  96.779  -63.585  52.404  1
462997  96.816  -63.590  52.372  1
462998  96.853  -63.595  52.341  1
462999  96.890  -63.600  52.309  1
463000  96.928  -63.604  52.278  1
463001  96.962  -63.612  52.245  1
463002  96.994  -63.624  52.213  1
463003  97.025  -63.637  52.181  1
463004  97.056  -63.649  52.148  1
463005  97.087  -63.662  52.114  1
463006  97.119  -63.674  52.081  1
463007  97.150  -63.687  52.049  1
463008  97.181  -63.699  52.018  1
463009  97.213  -63.712  51.988  1
463010  97.244  -63.724  51.958  1
463011  97.275  -63.736  51.926  1
463012  97.306  -63.749  51.891  1
463013  97.333  -63.763  51.859  1
463014  97.356  -63.777  51.827  1
463015  97.379  -63.791  51.795  1
463016  97.402  -63.806  51.763  1
463017  97.425  -63.820  51.729  1
463018  97.447  -63.835  51.693  1
463019  97.473  -63.845  51.654  1
463020  97.502  -63.852  51.611  1
463021  97.535  -63.854  51.566  1
463022  97.574  -63.850  51.521  1
463023  97.613  -63.848  51.472  1
463024  97.652  -63.847  51.422  1
463025  97.691  -63.844  51.371  1
463026  97.731  -63.842  51.319  1
463027  97.770  -63.840  51.266  1
463028  97.809  -63.838  51.211  1
463029  97.849  -63.836  51.155  1
463030  97.888  -63.834  51.099  1
463031  97.927  -63.831  51.044  1
463032  97.963  -63.831  50.989  1
463033  97.998  -63.833  50.938  1
463034  98.033  -63.834  50.888  1
463035  98.067  -63.835  50.837  1
463036  98.102  -63.836  50.786  1
463037  98.137  -63.838  50.734  1
463038  98.168  -63.842  50.679  1
463039  98.201  -63.846  50.625  1
463040  98.234  -63.849  50.573  1
463041  98.268  -63.853  50.522  1
463042  98.301  -63.857  50.470  1
463043  98.335  -63.860  50.417  1
463044  98.362  -63.861  50.366  1
463045  98.385  -63.860  50.316  1
463046  98.409  -63.860  50.265  1
463047  98.434  -63.860  50.217  1
463048  98.459  -63.863  50.170  1
463049  98.485  -63.866  50.124  1
463050  98.511  -63.869  50.079  1
463051  98.536  -63.871  50.034  1
463052  98.562  -63.874  49.992  1
463053  98.588  -63.876  49.948  1
463054  98.617  -63.879  49.906  1
463055  98.667  -63.881  49.863  1
463056  98.718  -63.883  49.817  1
463057  98.757  -63.886  49.763  1
463058  98.777  -63.892  49.707  1
463059  98.796  -63.898  49.652  1
463060  98.861  -63.904  49.600  1
463061  98.928  -63.906  49.551  1
463062  98.991  -63.904  49.504  1
463063  99.054  -63.902  49.459  1
463064  99.117  -63.900  49.415  1
463065  99.180  -63.898  49.372  1
463066  99.242  -63.897  49.330  1
463067  99.305  -63.894  49.289  1
463068  99.368  -63.893  49.249  1
463069  99.431  -63.891  49.211  1
463470  86.881  -62.111  56.194  1
463471  86.923  -62.110  56.182  1
463472  86.966  -62.108  56.171  1
463473  87.008  -62.107  56.160  1
463474  87.051  -62.105  56.149  1
463475  87.093  -62.103  56.140  1
463476  87.135  -62.102  56.132  1
463477  87.173  -62.103  56.124  1
463478  87.210  -62.105  56.115  1
463479  87.247  -62.107  56.107  1
463480  87.283  -62.108  56.099  1
463481  87.320  -62.110  56.092  1
463482  87.356  -62.112  56.086  1
463483  87.394  -62.114  56.078  1
463484  87.442  -62.111  56.067  1
463485  87.490  -62.107  56.053  1
463486  87.539  -62.104  56.033  1
463487  87.586  -62.100  56.011  1
463488  87.635  -62.097  55.986  1
463489  87.683  -62.093  55.960  1
463490  87.731  -62.090  55.935  1
463491  87.780  -62.087  55.911  1
463492  87.828  -62.083  55.890  1
463493  87.876  -62.080  55.871  1
463494  87.924  -62.077  55.853  1
463495  87.973  -62.073  55.838  1
463496  88.021  -62.070  55.823  1
463497  88.069  -62.067  55.810  1
463498  88.118  -62.064  55.800  1
463499  88.167  -62.059  55.789  1
463500  88.215  -62.073  55.779  1
463501  88.264  -62.090  55.767  1
463502  88.313  -62.106  55.755  1
463503  88.361  -62.123  55.741  1
463504  88.410  -62.139  55.723  1
463505  88.459  -62.155  55.699  1
463506  88.508  -62.172  55.668  1
463507  88.557  -62.188  55.634  1
463508  88.606  -62.205  55.603  1
463509  88.654  -62.221  55.574  1
463510  88.702  -62.237  55.551  1
463511  88.745  -62.252  55.532  1
463512  88.788  -62.268  55.515  1
463513  88.831  -62.283  55.499  1
463514  88.875  -62.298  55.482  1
463515  88.918  -62.312  55.466  1
463516  88.961  -62.327  55.449  1
463517  89.005  -62.336  55.433  1
463518  89.049  -62.344  55.418  1
463519  89.093  -62.352  55.403  1
463520  89.136  -62.361  55.389  1
463521  89.180  -62.370  55.374  1
463522  89.224  -62.378  55.361  1
463523  89.268  -62.387  55.349  1
463524  89.312  -62.395  55.337  1
463525  89.355  -62.404  55.326  1
463526  89.397  -62.414  55.316  1
463527  89.440  -62.424  55.309  1
463528  89.482  -62.433  55.301  1
463529  89.525  -62.443  55.291  1
463530  89.567  -62.452  55.281  1
463531  89.610  -62.462  55.272  1
463532  89.653  -62.471  55.264  1
463533  89.695  -62.481  55.256  1
463534  89.738  -62.490  55.249  1
463535  89.780  -62.500  55.242  1
463536  89.824  -62.515  55.235  1
463537  89.871  -62.534  55.229  1
463538  89.922  -62.547  55.223  1
463539  89.974  -62.560  55.217  1
463540  90.022  -62.574  55.213  1
463541  90.071  -62.587  55.207  1
463542  90.118  -62.602  55.203  1
463543  90.167  -62.616  55.201  1
463544  90.215  -62.630  55.198  1
463545  90.263  -62.644  55.195  1
463546  90.312  -62.658  55.194  1
463547  90.360  -62.672  55.192  1
463548  90.408  -62.685  55.188  1
463549  90.456  -62.700  55.180  1
463550  90.504  -62.713  55.167  1
463551  90.546  -62.722  55.150  1
463552  90.589  -62.732  55.132  1
463553  90.632  -62.742  55.110  1
463554  90.674  -62.752  55.086  1
463555  90.717  -62.762  55.064  1
463556  90.759  -62.772  55.046  1
463557  90.789  -62.783  55.030  1
463558  90.819  -62.794  55.017  1
463559  90.854  -62.806  55.005  1
463560  90.910  -62.816  54.993  1
463561  90.966  -62.827  54.983  1
463562  91.023  -62.838  54.973  1
463563  91.079  -62.849  54.963  1
463564  91.135  -62.860  54.954  1
463565  91.188  -62.871  54.945  1
463566  91.241  -62.882  54.937  1
463567  91.294  -62.894  54.929  1
463568  91.348  -62.905  54.921  1
463569  91.400  -62.916  54.909  1
463570  91.454  -62.928  54.896  1
463571  91.507  -62.939  54.883  1
463572  91.562  -62.948  54.867  1
463573  91.621  -62.951  54.849  1
463574  91.680  -62.953  54.834  1
463575  91.739  -62.955  54.822  1
463576  91.786  -62.966  54.812  1
463577  91.830  -62.976  54.804  1
463578  91.876  -62.988  54.799  1
463579  91.921  -62.998  54.796  1
463580  91.959  -63.001  54.797  1
463581  91.994  -62.997  54.801  1
463582  92.027  -62.992  54.808  1
463583  92.070  -62.996  54.820  1
463584  92.112  -62.999  54.838  1
463585  92.155  -63.003  54.856  1
463586  92.198  -63.007  54.868  1
463587  92.240  -63.010  54.876  1
463588  92.283  -63.014  54.879  1
463589  92.318  -63.017  54.875  1
463590  92.354  -63.021  54.862  1
463591  92.390  -63.024  54.844  1
463592  92.426  -63.028  54.822  1
463593  92.461  -63.032  54.795  1
463594  92.497  -63.035  54.767  1
463595  92.531  -63.039  54.738  1
463596  92.565  -63.041  54.709  1
463597  92.599  -63.043  54.682  1
463598  92.640  -63.047  54.656  1
463599  92.683  -63.054  54.634  1
463600  92.716  -63.067  54.615  1
463601  92.751  -63.081  54.596  1
463602  92.784  -63.095  54.579  1
463603  92.826  -63.104  54.564  1
463604  92.871  -63.111  54.548  1
463605  92.920  -63.116  54.533  1
463606  92.980  -63.115  54.517  1
463607  93.029  -63.122  54.499  1
463608  93.078  -63.129  54.481  1
463609  93.113  -63.137  54.460  1
463610  93.137  -63.148  54.438  1
463611  93.174  -63.148  54.415  1
463612  93.221  -63.142  54.392  1
463613  93.238  -63.142  54.371  1
463614  93.285  -63.141  54.349  1
463615  93.332  -63.139  54.330  1
463616  93.379  -63.137  54.311  1
463617  93.421  -63.140  54.293  1
463618  93.446  -63.161  54.275  1
463619  93.471  -63.182  54.256  1
463620  93.495  -63.203  54.238  1
463621  93.520  -63.224  54.220  1
463622  93.559  -63.235  54.202  1
463623  93.597  -63.245  54.183  1
463624  93.636  -63.257  54.163  1
463625  93.675  -63.267  54.140  1
463626  93.705  -63.267  54.116  1
463627  93.735  -63.267  54.091  1
463628  93.770  -63.274  54.066  1
463629  93.807  -63.286  54.042  1
463630  93.847  -63.277  54.018  1
463631  93.892  -63.272  53.995  1
463632  93.937  -63.268  53.974  1
463633  93.994  -63.286  53.953  1
463634  94.050  -63.302  53.935  1
463635  94.107  -63.319  53.919  1
463636  94.144  -63.355  53.903  1
463637  94.177  -63.379  53.888  1
463638  94.206  -63.377  53.875  1
463639  94.237  -63.380  53.863  1
463640  94.273  -63.386  53.852  1
463641  94.309  -63.392  53.842  1
463642  94.345  -63.398  53.831  1
463643  94.381  -63.403  53.821  1
463644  94.416  -63.409  53.810  1
463645  94.452  -63.415  53.798  1
463646  94.486  -63.424  53.786  1
463647  94.518  -63.435  53.773  1
463648  94.550  -63.446  53.759  1
463649  94.582  -63.458  53.744  1
463650  94.614  -63.469  53.730  1
463651  94.657  -63.474  53.715  1
463652  94.709  -63.475  53.699  1
463653  94.760  -63.475  53.683  1
463654  94.820  -63.477  53.665  1
463655  94.882  -63.478  53.646  1
463656  94.945  -63.480  53.627  1
463657  95.007  -63.481  53.605  1
463658  95.070  -63.483  53.583  1
463659  95.120  -63.485  53.561  1
463660  95.158  -63.490  53.538  1
463661  95.196  -63.494  53.515  1
463662  95.234  -63.498  53.492  1
463663  95.272  -63.502  53.469  1
463664  95.310  -63.506  53.446  1
463665  95.348  -63.511  53.425  1
463666  95.387  -63.517  53.403  1
463667  95.426  -63.524  53.381  1
463668  95.466  -63.531  53.362  1
463669  95.506  -63.537  53.340  1
463670  95.545  -63.543  53.319  1
463671  95.580  -63.545  53.298  1
463672  95.611  -63.543  53.278  1
463673  95.654  -63.544  53.256  1
463674  95.700  -63.548  53.234  1
463675  95.746  -63.551  53.209  1
463676  95.792  -63.554  53.180  1
463677  95.838  -63.557  53.149  1
463678  95.884  -63.560  53.118  1
463679  95.930  -63.563  53.083  1
463680  95.976  -63.566  53.046  1
463681  96.021  -63.568  53.004  1
463682  96.070  -63.562  52.958  1
463683  96.119  -63.557  52.910  1
463684  96.169  -63.552  52.865  1
463685  96.219  -63.547  52.820  1
463686  96.268  -63.542  52.777  1
463687  96.317  -63.537  52.736  1
463688  96.367  -63.532  52.697  1
463689  96.416  -63.527  52.658  1
463690  96.466  -63.522  52.619  1
463691  96.515  -63.517  52.581  1
463692  96.565  -63.512  52.542  1
463693  96.615  -63.513  52.504  1
463694  96.667  -63.523  52.466  1
463695  96.718  -63.532  52.432  1
463696  96.754  -63.535  52.400  1
463697  96.791  -63.540  52.370  1
463698  96.828  -63.544  52.339  1
463699  96.865  -63.549  52.308  1
463700  96.901  -63.555  52.277  1
463701  96.933  -63.567  52.245  1
463702  96.964  -63.580  52.213  1
463703  96.996  -63.592  52.181  1
463704  97.027  -63.605  52.148  1
463705  97.058  -63.617  52.115  1
463706  97.089  -63.629  52.082  1
463707  97.120  -63.642  52.049  1
463708  97.152  -63.654  52.017  1
463709  97.183  -63.667  51.987  1
463710  97.214  -63.679  51.959  1
463711  97.245  -63.692  51.931  1
463712  97.277  -63.704  51.902  1
463713  97.308  -63.716  51.870  1
463714  97.332  -63.731  51.839  1
463715  97.355  -63.745  51.808  1
463716  97.377  -63.760  51.776  1
463717  97.400  -63.775  51.744  1
463718  97.423  -63.789  51.710  1
463719  97.446  -63.803  51.675  1
463720  97.470  -63.816  51.636  1
463721  97.502  -63.820  51.594  1
463722  97.541  -63.817  51.550  1
463723  97.580  -63.816  51.504  1
463724  97.619  -63.813  51.456  1
463725  97.659  -63.811  51.406  1
463726  97.698  -63.809  51.355  1
463727  97.737  -63.807  51.304  1
463728  97.777  -63.805  51.252  1
463729  97.816  -63.803  51.196  1
463730  97.855  -63.800  51.140  1
463731  97.894  -63.798  51.084  1
463732  97.934  -63.797  51.028  1
463733  97.971  -63.796  50.975  1
463734  98.005  -63.797  50.923  1
463735  98.040  -63.798  50.871  1
463736  98.075  -63.800  50.821  1
463737  98.109  -63.800  50.770  1
463738  98.144  -63.802  50.718  1
463739  98.174  -63.806  50.665  1
463740  98.194  -63.820  50.613  1
463741  98.227  -63.823  50.562  1
463742  98.261  -63.827  50.513  1
463743  98.294  -63.831  50.462  1
463744  98.327  -63.835  50.411  1
463745  98.360  -63.838  50.359  1
463746  98.384  -63.837  50.308  1
463747  98.408  -63.836  50.257  1
463748  98.431  -63.836  50.208  1
463749  98.454  -63.835  50.160  1
463750  98.479  -63.835  50.113  1
463751  98.504  -63.838  50.066  1
463752  98.530  -63.840  50.020  1
463753  98.556  -63.843  49.976  1
463754  98.581  -63.845  49.931  1
463755  98.607  -63.848  49.888  1
463756  98.649  -63.850  49.844  1
463757  98.700  -63.852  49.797  1
463758  98.732  -63.857  49.743  1
463759  98.751  -63.863  49.689  1
463760  98.808  -63.868  49.636  1
463761  98.873  -63.869  49.586  1
463762  98.936  -63.866  49.537  1
463763  98.999  -63.865  49.492  1
463764  99.062  -63.863  49.447  1
463765  99.125  -63.861  49.404  1
463766  99.188  -63.860  49.361  1
463767  99.251  -63.857  49.319  1
463768  99.314  -63.856  49.278  1
463769  99.377  -63.854  49.239  1
463770  99.440  -63.852  49.201  1
464172  86.940  -62.061  56.185  1
464173  86.982  -62.060  56.173  1
464174  87.024  -62.058  56.161  1
464175  87.067  -62.056  56.150  1
464176  87.110  -62.055  56.141  1
464177  87.151  -62.053  56.132  1
464178  87.188  -62.055  56.124  1
464179  87.225  -62.057  56.115  1
464180  87.262  -62.059  56.105  1
464181  87.298  -62.061  56.097  1
464182  87.335  -62.062  56.090  1
464183  87.371  -62.064  56.083  1
464184  87.408  -62.066  56.077  1
464185  87.451  -62.065  56.069  1
464186  87.500  -62.061  56.056  1
464187  87.548  -62.058  56.038  1
464188  87.596  -62.055  56.018  1
464189  87.644  -62.051  55.993  1
464190  87.693  -62.048  55.968  1
464191  87.741  -62.045  55.943  1
464192  87.789  -62.042  55.919  1
464193  87.837  -62.038  55.897  1
464194  87.886  -62.035  55.877  1
464195  87.934  -62.031  55.858  1
464196  87.982  -62.028  55.841  1
464197  88.031  -62.025  55.826  1
464198  88.079  -62.021  55.814  1
464199  88.127  -62.018  55.803  1
464200  88.175  -62.014  55.792  1
464201  88.229  -62.024  55.781  1
464202  88.277  -62.040  55.766  1
464203  88.324  -62.056  55.752  1
464204  88.370  -62.072  55.736  1
464205  88.418  -62.088  55.716  1
464206  88.465  -62.105  55.690  1
464207  88.514  -62.120  55.658  1
464208  88.562  -62.137  55.626  1
464209  88.611  -62.153  55.597  1
464210  88.660  -62.170  55.571  1
464211  88.709  -62.186  55.549  1
464212  88.757  -62.202  55.531  1
464213  88.804  -62.218  55.515  1
464214  88.847  -62.233  55.500  1
464215  88.890  -62.249  55.483  1
464216  88.933  -62.263  55.467  1
464217  88.977  -62.271  55.450  1
464218  89.021  -62.280  55.434  1
464219  89.065  -62.288  55.419  1
464220  89.109  -62.297  55.404  1
464221  89.152  -62.306  55.390  1
464222  89.194  -62.315  55.375  1
464223  89.237  -62.325  55.360  1
464224  89.279  -62.335  55.346  1
464225  89.322  -62.344  55.334  1
464226  89.365  -62.354  55.323  1
464227  89.407  -62.363  55.312  1
464228  89.450  -62.373  55.304  1
464229  89.492  -62.383  55.296  1
464230  89.535  -62.392  55.287  1
464231  89.578  -62.402  55.277  1
464232  89.620  -62.412  55.269  1
464233  89.663  -62.421  55.261  1
464234  89.705  -62.431  55.254  1
464235  89.748  -62.440  55.250  1
464236  89.791  -62.449  55.244  1
464237  89.835  -62.466  55.236  1
464238  89.880  -62.487  55.230  1
464239  89.930  -62.502  55.225  1
464240  89.982  -62.515  55.218  1
464241  90.034  -62.528  55.211  1
464242  90.083  -62.541  55.203  1
464243  90.131  -62.555  55.197  1
464244  90.179  -62.569  55.192  1
464245  90.228  -62.583  55.189  1
464246  90.276  -62.597  55.189  1
464247  90.324  -62.611  55.192  1
464248  90.372  -62.625  55.193  1
464249  90.421  -62.639  55.191  1
464250  90.469  -62.653  55.184  1
464251  90.517  -62.666  55.171  1
464252  90.561  -62.677  55.154  1
464253  90.603  -62.688  55.134  1
464254  90.646  -62.697  55.111  1
464255  90.689  -62.707  55.084  1
464256  90.731  -62.717  55.061  1
464257  90.774  -62.727  55.043  1
464258  90.817  -62.737  55.027  1
464259  90.850  -62.747  55.014  1
464260  90.880  -62.759  55.002  1
464261  90.929  -62.769  54.991  1
464262  90.985  -62.781  54.982  1
464263  91.041  -62.791  54.973  1
464264  91.097  -62.802  54.964  1
464265  91.150  -62.813  54.955  1
464266  91.204  -62.825  54.948  1
464267  91.256  -62.836  54.941  1
464268  91.310  -62.847  54.935  1
464269  91.363  -62.859  54.927  1
464270  91.416  -62.870  54.916  1
464271  91.469  -62.882  54.901  1
464272  91.522  -62.893  54.887  1
464273  91.577  -62.902  54.870  1
464274  91.636  -62.904  54.852  1
464275  91.696  -62.907  54.837  1
464276  91.742  -62.916  54.824  1
464277  91.788  -62.928  54.814  1
464278  91.832  -62.938  54.806  1
464279  91.877  -62.950  54.800  1
464280  91.923  -62.961  54.798  1
464281  91.964  -62.967  54.800  1
464282  91.998  -62.962  54.805  1
464283  92.031  -62.958  54.813  1
464284  92.067  -62.954  54.825  1
464285  92.109  -62.958  54.843  1
464286  92.152  -62.961  54.862  1
464287  92.194  -62.965  54.877  1
464288  92.237  -62.969  54.885  1
464289  92.280  -62.972  54.887  1
464290  92.322  -62.976  54.882  1
464291  92.365  -62.979  54.870  1
464292  92.403  -62.983  54.851  1
464293  92.439  -62.986  54.826  1
464294  92.475  -62.990  54.798  1
464295  92.510  -62.994  54.769  1
464296  92.546  -62.998  54.739  1
464297  92.581  -63.001  54.710  1
464298  92.617  -63.004  54.681  1
464299  92.653  -63.008  54.654  1
464300  92.689  -63.016  54.631  1
464301  92.722  -63.029  54.607  1
464302  92.756  -63.042  54.584  1
464303  92.790  -63.056  54.563  1
464304  92.826  -63.069  54.543  1
464305  92.873  -63.074  54.525  1
464306  92.926  -63.079  54.509  1
464307  92.976  -63.086  54.491  1
464308  93.024  -63.092  54.473  1
464309  93.073  -63.098  54.454  1
464310  93.108  -63.108  54.433  1
464311  93.134  -63.117  54.411  1
464312  93.184  -63.107  54.390  1
464313  93.232  -63.100  54.369  1
464314  93.249  -63.104  54.349  1
464315  93.281  -63.101  54.328  1
464316  93.328  -63.098  54.309  1
464317  93.375  -63.097  54.290  1
464318  93.413  -63.104  54.272  1
464319  93.437  -63.126  54.254  1
464320  93.462  -63.146  54.235  1
464321  93.486  -63.167  54.217  1
464322  93.523  -63.180  54.198  1
464323  93.562  -63.190  54.179  1
464324  93.601  -63.202  54.159  1
464325  93.640  -63.212  54.139  1
464326  93.678  -63.224  54.116  1
464327  93.717  -63.234  54.094  1
464328  93.750  -63.236  54.071  1
464329  93.781  -63.239  54.048  1
464330  93.818  -63.246  54.025  1
464331  93.861  -63.240  54.004  1
464332  93.906  -63.236  53.983  1
464333  93.951  -63.231  53.964  1
464334  93.997  -63.228  53.945  1
464335  94.054  -63.245  53.928  1
464336  94.102  -63.270  53.912  1
464337  94.136  -63.308  53.897  1
464338  94.170  -63.336  53.883  1
464339  94.200  -63.336  53.871  1
464340  94.236  -63.342  53.860  1
464341  94.272  -63.348  53.850  1
464342  94.308  -63.354  53.840  1
464343  94.343  -63.360  53.830  1
464344  94.379  -63.366  53.820  1
464345  94.415  -63.372  53.809  1
464346  94.451  -63.378  53.798  1
464347  94.486  -63.384  53.785  1
464348  94.521  -63.392  53.772  1
464349  94.553  -63.403  53.757  1
464350  94.585  -63.415  53.741  1
464351  94.617  -63.426  53.724  1
464352  94.661  -63.430  53.708  1
464353  94.712  -63.431  53.690  1
464354  94.768  -63.432  53.673  1
464355  94.831  -63.433  53.654  1
464356  94.894  -63.435  53.634  1
464357  94.957  -63.437  53.612  1
464358  95.019  -63.438  53.589  1
464359  95.082  -63.440  53.566  1
464360  95.129  -63.443  53.542  1
464361  95.167  -63.446  53.518  1
464362  95.205  -63.451  53.494  1
464363  95.244  -63.455  53.470  1
464364  95.281  -63.459  53.446  1
464365  95.320  -63.464  53.424  1
464366  95.357  -63.468  53.401  1
464367  95.396  -63.472  53.379  1
464368  95.435  -63.479  53.357  1
464369  95.475  -63.485  53.337  1
464370  95.514  -63.492  53.315  1
464371  95.550  -63.495  53.293  1
464372  95.581  -63.492  53.271  1
464373  95.612  -63.490  53.248  1
464374  95.658  -63.493  53.225  1
464375  95.704  -63.496  53.201  1
464376  95.750  -63.499  53.176  1
464377  95.796  -63.502  53.148  1
464378  95.842  -63.506  53.119  1
464379  95.888  -63.509  53.090  1
464380  95.934  -63.512  53.058  1
464381  95.980  -63.517  53.023  1
464382  96.027  -63.523  52.985  1
464383  96.063  -63.528  52.943  1
464384  96.134  -63.525  52.895  1
464385  96.177  -63.524  52.847  1
464386  96.224  -63.519  52.800  1
464387  96.279  -63.511  52.753  1
464388  96.328  -63.506  52.708  1
464389  96.378  -63.501  52.665  1
464390  96.428  -63.496  52.625  1
464391  96.477  -63.491  52.585  1
464392  96.526  -63.486  52.545  1
464393  96.576  -63.480  52.506  1
464394  96.625  -63.476  52.469  1
464395  96.675  -63.476  52.431  1
464396  96.727  -63.485  52.396  1
464397  96.765  -63.490  52.365  1
464398  96.803  -63.494  52.337  1
464399  96.839  -63.499  52.308  1
464400  96.872  -63.510  52.277  1
464401  96.903  -63.522  52.245  1
464402  96.935  -63.535  52.213  1
464403  96.966  -63.547  52.181  1
464404  96.997  -63.560  52.149  1
464405  97.028  -63.572  52.115  1
464406  97.060  -63.585  52.081  1
464407  97.091  -63.597  52.047  1
464408  97.122  -63.609  52.014  1
464409  97.153  -63.622  51.983  1
464410  97.184  -63.634  51.955  1
464411  97.216  -63.647  51.927  1
464412  97.247  -63.659  51.900  1
464413  97.278  -63.672  51.874  1
464414  97.307  -63.685  51.845  1
464415  97.330  -63.700  51.816  1
464416  97.353  -63.714  51.785  1
464417  97.376  -63.728  51.752  1
464418  97.399  -63.743  51.720  1
464419  97.422  -63.758  51.688  1
464420  97.445  -63.772  51.653  1
464421  97.469  -63.784  51.615  1
464422  97.508  -63.784  51.574  1
464423  97.547  -63.782  51.530  1
464424  97.587  -63.780  51.485  1
464425  97.626  -63.778  51.437  1
464426  97.665  -63.776  51.388  1
464427  97.705  -63.774  51.337  1
464428  97.744  -63.772  51.287  1
464429  97.783  -63.769  51.235  1
464430  97.822  -63.767  51.180  1
464431  97.862  -63.766  51.124  1
464432  97.901  -63.763  51.067  1
464433  97.940  -63.761  51.012  1
464434  97.978  -63.760  50.961  1
464435  98.013  -63.761  50.908  1
464436  98.047  -63.763  50.856  1
464437  98.082  -63.763  50.804  1
464438  98.117  -63.765  50.754  1
464439  98.154  -63.764  50.702  1
464440  98.185  -63.768  50.650  1
464441  98.204  -63.781  50.599  1
464442  98.223  -63.796  50.549  1
464443  98.253  -63.801  50.501  1
464444  98.287  -63.805  50.452  1
464445  98.320  -63.809  50.401  1
464446  98.354  -63.813  50.350  1
464447  98.382  -63.814  50.299  1
464448  98.406  -63.813  50.248  1
464449  98.429  -63.813  50.198  1
464450  98.453  -63.812  50.148  1
464451  98.477  -63.811  50.100  1
464452  98.500  -63.810  50.053  1
464453  98.523  -63.810  50.006  1
464454  98.549  -63.812  49.960  1
464455  98.574  -63.815  49.915  1
464456  98.600  -63.817  49.870  1
464457  98.631  -63.819  49.825  1
464458  98.681  -63.822  49.778  1
464459  98.706  -63.827  49.724  1
464460  98.755  -63.832  49.671  1
464461  98.819  -63.831  49.621  1
464462  98.882  -63.830  49.572  1
464463  98.945  -63.828  49.524  1
464464  99.008  -63.826  49.480  1
464465  99.071  -63.824  49.436  1
464466  99.134  -63.822  49.392  1
464467  99.197  -63.821  49.350  1
464468  99.260  -63.819  49.309  1
464469  99.323  -63.817  49.268  1
464470  99.385  -63.815  49.229  1
464471  99.448  -63.813  49.191  1
464873  86.956  -62.013  56.186  1
464874  86.999  -62.011  56.173  1
464875  87.041  -62.009  56.161  1
464876  87.083  -62.008  56.150  1
464877  87.126  -62.006  56.140  1
464878  87.167  -62.005  56.131  1
464879  87.203  -62.008  56.122  1
464880  87.240  -62.009  56.112  1
464881  87.277  -62.011  56.103  1
464882  87.314  -62.013  56.095  1
464883  87.350  -62.014  56.087  1
464884  87.387  -62.016  56.081  1
464885  87.424  -62.018  56.075  1
464886  87.461  -62.020  56.067  1
464887  87.509  -62.016  56.056  1
464888  87.557  -62.013  56.040  1
464889  87.606  -62.010  56.022  1
464890  87.654  -62.006  55.999  1
464891  87.702  -62.003  55.974  1
464892  87.751  -61.999  55.949  1
464893  87.798  -61.996  55.926  1
464894  87.847  -61.992  55.904  1
464895  87.895  -61.989  55.884  1
464896  87.943  -61.986  55.864  1
464897  87.992  -61.983  55.847  1
464898  88.040  -61.979  55.831  1
464899  88.088  -61.976  55.817  1
464900  88.136  -61.973  55.805  1
464901  88.185  -61.969  55.793  1
464902  88.246  -61.977  55.782  1
464903  88.294  -61.992  55.766  1
464904  88.342  -62.008  55.750  1
464905  88.390  -62.023  55.731  1
464906  88.436  -62.039  55.709  1
464907  88.484  -62.056  55.679  1
464908  88.531  -62.072  55.647  1
464909  88.578  -62.088  55.617  1
464910  88.625  -62.104  55.591  1
464911  88.672  -62.120  55.568  1
464912  88.719  -62.136  55.548  1
464913  88.766  -62.152  55.532  1
464914  88.813  -62.168  55.517  1
464915  88.860  -62.184  55.501  1
464916  88.906  -62.199  55.485  1
464917  88.949  -62.208  55.468  1
464918  88.992  -62.218  55.451  1
464919  89.034  -62.227  55.435  1
464920  89.077  -62.236  55.419  1
464921  89.119  -62.246  55.404  1
464922  89.162  -62.255  55.389  1
464923  89.204  -62.265  55.374  1
464924  89.247  -62.274  55.358  1
464925  89.290  -62.284  55.344  1
464926  89.332  -62.294  55.332  1
464927  89.375  -62.303  55.320  1
464928  89.417  -62.313  55.309  1
464929  89.460  -62.322  55.300  1
464930  89.502  -62.332  55.292  1
464931  89.545  -62.342  55.283  1
464932  89.588  -62.351  55.273  1
464933  89.630  -62.361  55.266  1
464934  89.673  -62.371  55.260  1
464935  89.716  -62.380  55.256  1
464936  89.758  -62.390  55.254  1
464937  89.801  -62.399  55.250  1
464938  89.845  -62.418  55.241  1
464939  89.890  -62.439  55.234  1
464940  89.938  -62.457  55.229  1
464941  89.990  -62.470  55.222  1
464942  90.042  -62.482  55.214  1
464943  90.094  -62.495  55.204  1
464944  90.144  -62.508  55.195  1
464945  90.192  -62.522  55.187  1
464946  90.240  -62.536  55.182  1
464947  90.289  -62.550  55.183  1
464948  90.336  -62.564  55.187  1
464949  90.385  -62.578  55.191  1
464950  90.433  -62.592  55.190  1
464951  90.481  -62.606  55.184  1
464952  90.530  -62.620  55.171  1
464953  90.576  -62.632  55.154  1
464954  90.618  -62.642  55.132  1
464955  90.661  -62.652  55.106  1
464956  90.704  -62.662  55.078  1
464957  90.746  -62.672  55.057  1
464958  90.789  -62.681  55.040  1
464959  90.831  -62.691  55.025  1
464960  90.874  -62.701  55.013  1
464961  90.910  -62.712  55.001  1
464962  90.947  -62.723  54.991  1
464963  91.003  -62.734  54.981  1
464964  91.059  -62.744  54.972  1
464965  91.112  -62.756  54.964  1
464966  91.166  -62.767  54.957  1
464967  91.219  -62.778  54.951  1
464968  91.272  -62.790  54.945  1
464969  91.325  -62.801  54.939  1
464970  91.378  -62.813  54.931  1
464971  91.431  -62.824  54.920  1
464972  91.485  -62.835  54.905  1
464973  91.537  -62.847  54.890  1
464974  91.592  -62.857  54.874  1
464975  91.651  -62.859  54.856  1
464976  91.700  -62.868  54.841  1
464977  91.744  -62.879  54.827  1
464978  91.789  -62.890  54.816  1
464979  91.835  -62.901  54.808  1
464980  91.879  -62.912  54.802  1
464981  91.925  -62.923  54.800  1
464982  91.968  -62.932  54.802  1
464983  92.002  -62.927  54.807  1
464984  92.035  -62.923  54.817  1
464985  92.070  -62.919  54.829  1
464986  92.106  -62.916  54.846  1
464987  92.148  -62.920  54.864  1
464988  92.191  -62.924  54.878  1
464989  92.233  -62.927  54.887  1
464990  92.276  -62.931  54.888  1
464991  92.319  -62.935  54.882  1
464992  92.361  -62.938  54.869  1
464993  92.404  -62.941  54.849  1
464994  92.446  -62.945  54.824  1
464995  92.488  -62.948  54.795  1
464996  92.523  -62.952  54.767  1
464997  92.559  -62.956  54.736  1
464998  92.594  -62.960  54.707  1
464999  92.630  -62.963  54.679  1
465000  92.666  -62.967  54.650  1
465001  92.701  -62.974  54.626  1
465002  92.733  -62.988  54.600  1
465003  92.767  -63.002  54.574  1
465004  92.799  -63.017  54.548  1
465005  92.831  -63.029  54.525  1
465006  92.873  -63.042  54.503  1
465007  92.922  -63.048  54.485  1
465008  92.971  -63.055  54.466  1
465009  93.019  -63.062  54.446  1
465010  93.068  -63.069  54.426  1
465011  93.103  -63.078  54.406  1
465012  93.144  -63.075  54.386  1
465013  93.194  -63.066  54.366  1
465014  93.243  -63.057  54.346  1
465015  93.278  -63.067  54.327  1
465016  93.277  -63.061  54.308  1
465017  93.324  -63.058  54.290  1
465018  93.371  -63.057  54.271  1
465019  93.404  -63.069  54.253  1
465020  93.429  -63.090  54.235  1
465021  93.453  -63.111  54.217  1
465022  93.489  -63.124  54.198  1
465023  93.528  -63.135  54.180  1
465024  93.566  -63.146  54.160  1
465025  93.605  -63.157  54.140  1
465026  93.643  -63.168  54.120  1
465027  93.682  -63.179  54.099  1
465028  93.720  -63.189  54.078  1
465029  93.759  -63.201  54.057  1
465030  93.793  -63.206  54.035  1
465031  93.831  -63.208  54.014  1
465032  93.876  -63.204  53.994  1
465033  93.921  -63.198  53.975  1
465034  93.966  -63.194  53.957  1
465035  94.010  -63.189  53.938  1
465036  94.057  -63.188  53.922  1
465037  94.095  -63.224  53.907  1
465038  94.129  -63.261  53.893  1
465039  94.163  -63.292  53.879  1
465040  94.198  -63.299  53.867  1
465041  94.235  -63.305  53.857  1
465042  94.270  -63.311  53.848  1
465043  94.306  -63.317  53.838  1
465044  94.342  -63.323  53.828  1
465045  94.378  -63.329  53.819  1
465046  94.413  -63.335  53.808  1
465047  94.449  -63.341  53.797  1
465048  94.485  -63.347  53.784  1
465049  94.521  -63.353  53.770  1
465050  94.556  -63.359  53.754  1
465051  94.588  -63.371  53.737  1
465052  94.620  -63.382  53.718  1
465053  94.664  -63.386  53.700  1
465054  94.717  -63.387  53.681  1
465055  94.780  -63.389  53.662  1
465056  94.843  -63.390  53.642  1
465057  94.905  -63.392  53.621  1
465058  94.968  -63.393  53.598  1
465059  95.031  -63.395  53.574  1
465060  95.094  -63.396  53.549  1
465061  95.139  -63.399  53.523  1
465062  95.177  -63.404  53.498  1
465063  95.215  -63.408  53.473  1
465064  95.253  -63.412  53.448  1
465065  95.291  -63.416  53.423  1
465066  95.329  -63.421  53.400  1
465067  95.367  -63.424  53.377  1
465068  95.405  -63.429  53.354  1
465069  95.444  -63.434  53.333  1
465070  95.483  -63.440  53.311  1
465071  95.520  -63.444  53.289  1
465072  95.551  -63.442  53.266  1
465073  95.582  -63.440  53.243  1
465074  95.616  -63.438  53.219  1
465075  95.662  -63.441  53.194  1
465076  95.708  -63.444  53.169  1
465077  95.754  -63.447  53.142  1
465078  95.800  -63.450  53.114  1
465079  95.846  -63.453  53.086  1
465080  95.892  -63.458  53.057  1
465081  95.939  -63.465  53.028  1
465082  95.985  -63.471  52.996  1
465083  96.031  -63.477  52.961  1
465084  96.067  -63.479  52.920  1
465085  96.105  -63.487  52.875  1
465086  96.160  -63.491  52.827  1
465087  96.241  -63.484  52.779  1
465088  96.294  -63.480  52.730  1
465089  96.335  -63.479  52.683  1
465090  96.377  -63.477  52.637  1
465091  96.424  -63.474  52.594  1
465092  96.478  -63.465  52.552  1
465093  96.533  -63.458  52.511  1
465094  96.587  -63.449  52.471  1
465095  96.637  -63.445  52.433  1
465096  96.686  -63.440  52.396  1
465097  96.736  -63.438  52.363  1
465098  96.777  -63.444  52.333  1
465099  96.811  -63.453  52.306  1
465100  96.842  -63.465  52.278  1
465101  96.874  -63.478  52.246  1
465102  96.905  -63.490  52.213  1
465103  96.936  -63.502  52.181  1
465104  96.967  -63.515  52.149  1
465105  96.999  -63.528  52.116  1
465106  97.030  -63.540  52.082  1
465107  97.061  -63.553  52.048  1
465108  97.092  -63.565  52.014  1
465109  97.123  -63.578  51.981  1
465110  97.155  -63.590  51.949  1
465111  97.186  -63.603  51.920  1
465112  97.217  -63.615  51.892  1
465113  97.248  -63.628  51.865  1
465114  97.280  -63.640  51.840  1
465115  97.306  -63.653  51.814  1
465116  97.329  -63.668  51.785  1
465117  97.352  -63.683  51.753  1
465118  97.375  -63.697  51.721  1
465119  97.397  -63.712  51.688  1
465120  97.421  -63.723  51.659  1
465121  97.443  -63.734  51.625  1
465122  97.479  -63.731  51.589  1
465123  97.508  -63.737  51.550  1
465124  97.554  -63.747  51.507  1
465125  97.593  -63.745  51.462  1
465126  97.633  -63.743  51.415  1
465127  97.672  -63.741  51.365  1
465128  97.711  -63.738  51.315  1
465129  97.750  -63.736  51.265  1
465130  97.790  -63.734  51.214  1
465131  97.829  -63.732  51.160  1
465132  97.868  -63.730  51.106  1
465133  97.908  -63.728  51.052  1
465134  97.947  -63.725  50.998  1
465135  97.985  -63.724  50.946  1
465136  98.020  -63.725  50.894  1
465137  98.055  -63.727  50.841  1
465138  98.089  -63.728  50.788  1
465139  98.124  -63.729  50.736  1
465140  98.164  -63.726  50.684  1
465141  98.197  -63.729  50.633  1
465142  98.215  -63.744  50.584  1
465143  98.234  -63.757  50.534  1
465144  98.252  -63.771  50.484  1
465145  98.279  -63.779  50.436  1
465146  98.312  -63.783  50.388  1
465147  98.346  -63.787  50.339  1
465148  98.379  -63.790  50.288  1
465149  98.404  -63.790  50.236  1
465150  98.427  -63.789  50.185  1
465151  98.451  -63.788  50.135  1
465152  98.475  -63.788  50.086  1
465153  98.498  -63.788  50.038  1
465154  98.522  -63.787  49.992  1
465155  98.545  -63.786  49.946  1
465156  98.569  -63.785  49.900  1
465157  98.593  -63.786  49.853  1
465158  98.619  -63.789  49.805  1
465159  98.661  -63.791  49.758  1
465160  98.702  -63.797  49.705  1
465161  98.765  -63.794  49.654  1
465162  98.828  -63.793  49.605  1
465163  98.890  -63.791  49.558  1
465164  98.953  -63.789  49.512  1
465165  99.016  -63.788  49.468  1
465166  99.079  -63.785  49.424  1
465167  99.142  -63.784  49.381  1
465168  99.205  -63.781  49.339  1
465169  99.268  -63.780  49.299  1
465170  99.331  -63.778  49.258  1
465171  99.394  -63.776  49.219  1
465575  87.015  -61.962  56.173  1
465576  87.058  -61.961  56.161  1
465577  87.100  -61.959  56.149  1
465578  87.142  -61.957  56.139  1
465579  87.182  -61.957  56.129  1
465580  87.219  -61.959  56.119  1
465581  87.256  -61.961  56.110  1
465582  87.292  -61.963  56.101  1
465583  87.329  -61.965  56.092  1
465584  87.365  -61.967  56.085  1
465585  87.402  -61.968  56.077  1
465586  87.439  -61.970  56.070  1
465587  87.476  -61.972  56.061  1
465588  87.518  -61.971  56.051  1
465589  87.567  -61.967  56.038  1
465590  87.615  -61.964  56.022  1
465591  87.663  -61.961  56.002  1
465592  87.712  -61.957  55.978  1
465593  87.760  -61.954  55.955  1
465594  87.808  -61.951  55.932  1
465595  87.856  -61.948  55.911  1
465596  87.905  -61.944  55.891  1
465597  87.953  -61.941  55.871  1
465598  88.001  -61.937  55.853  1
465599  88.049  -61.934  55.837  1
465600  88.098  -61.931  55.821  1
465601  88.146  -61.927  55.806  1
465602  88.194  -61.924  55.793  1
465603  88.261  -61.930  55.782  1
465604  88.311  -61.945  55.765  1
465605  88.359  -61.961  55.748  1
465606  88.407  -61.976  55.728  1
465607  88.456  -61.991  55.705  1
465608  88.503  -62.007  55.674  1
465609  88.550  -62.023  55.643  1
465610  88.597  -62.039  55.615  1
465611  88.644  -62.055  55.591  1
465612  88.691  -62.071  55.571  1
465613  88.738  -62.087  55.553  1
465614  88.785  -62.104  55.538  1
465615  88.832  -62.120  55.521  1
465616  88.876  -62.137  55.505  1
465617  88.919  -62.151  55.488  1
465618  88.959  -62.157  55.468  1
465619  89.001  -62.167  55.453  1
465620  89.044  -62.177  55.436  1
465621  89.087  -62.186  55.420  1
465622  89.129  -62.196  55.404  1
465623  89.172  -62.205  55.388  1
465624  89.214  -62.214  55.373  1
465625  89.257  -62.224  55.357  1
465626  89.300  -62.233  55.341  1
465627  89.342  -62.243  55.329  1
465628  89.385  -62.253  55.317  1
465629  89.427  -62.262  55.305  1
465630  89.470  -62.272  55.296  1
465631  89.513  -62.282  55.288  1
465632  89.555  -62.291  55.278  1
465633  89.598  -62.301  55.270  1
465634  89.640  -62.310  55.264  1
465635  89.683  -62.320  55.258  1
465636  89.725  -62.330  55.255  1
465637  89.768  -62.339  55.256  1
465638  89.810  -62.349  55.254  1
465639  89.856  -62.369  55.248  1
465640  89.901  -62.390  55.243  1
465641  89.946  -62.412  55.237  1
465642  89.998  -62.424  55.232  1
465643  90.050  -62.437  55.222  1
465644  90.102  -62.449  55.210  1
465645  90.154  -62.462  55.198  1
465646  90.204  -62.475  55.187  1
465647  90.253  -62.489  55.177  1
465648  90.301  -62.503  55.177  1
465649  90.349  -62.517  55.181  1
465650  90.397  -62.531  55.185  1
465651  90.446  -62.545  55.185  1
465652  90.494  -62.559  55.180  1
465653  90.542  -62.573  55.169  1
465654  90.590  -62.587  55.150  1
465655  90.633  -62.597  55.126  1
465656  90.676  -62.606  55.099  1
465657  90.719  -62.616  55.072  1
465658  90.761  -62.626  55.053  1
465659  90.804  -62.636  55.037  1
465660  90.847  -62.646  55.023  1
465661  90.889  -62.656  55.012  1
465662  90.932  -62.666  55.001  1
465663  90.970  -62.676  54.991  1
465664  91.021  -62.687  54.983  1
465665  91.075  -62.698  54.974  1
465666  91.128  -62.710  54.967  1
465667  91.181  -62.721  54.960  1
465668  91.234  -62.732  54.954  1
465669  91.287  -62.744  54.949  1
465670  91.341  -62.755  54.944  1
465671  91.393  -62.766  54.938  1
465672  91.447  -62.778  54.926  1
465673  91.500  -62.790  54.911  1
465674  91.553  -62.801  54.895  1
465675  91.607  -62.811  54.879  1
465676  91.656  -62.819  54.862  1
465677  91.701  -62.830  54.845  1
465678  91.746  -62.841  54.831  1
465679  91.791  -62.852  54.819  1
465680  91.837  -62.863  54.810  1
465681  91.881  -62.875  54.804  1
465682  91.927  -62.885  54.801  1
465683  91.971  -62.897  54.803  1
465684  92.006  -62.893  54.809  1
465685  92.040  -62.888  54.819  1
465686  92.074  -62.884  54.832  1
465687  92.107  -62.880  54.847  1
465688  92.145  -62.879  54.863  1
465689  92.188  -62.882  54.877  1
465690  92.230  -62.886  54.885  1
465691  92.273  -62.889  54.886  1
465692  92.315  -62.893  54.878  1
465693  92.358  -62.897  54.863  1
465694  92.401  -62.900  54.842  1
465695  92.443  -62.904  54.816  1
465696  92.486  -62.907  54.788  1
465697  92.528  -62.910  54.759  1
465698  92.571  -62.914  54.728  1
465699  92.607  -62.918  54.698  1
465700  92.643  -62.921  54.670  1
465701  92.679  -62.925  54.641  1
465702  92.714  -62.933  54.614  1
465703  92.746  -62.947  54.587  1
465704  92.780  -62.960  54.560  1
465705  92.807  -62.973  54.534  1
465706  92.836  -62.984  54.509  1
465707  92.881  -62.996  54.486  1
465708  92.925  -63.008  54.464  1
465709  92.970  -63.020  54.443  1
465710  93.014  -63.032  54.422  1
465711  93.064  -63.039  54.402  1
465712  93.105  -63.043  54.383  1
465713  93.155  -63.033  54.364  1
465714  93.205  -63.024  54.345  1
465715  93.254  -63.016  54.327  1
465716  93.292  -63.026  54.308  1
465717  93.279  -63.020  54.290  1
465718  93.320  -63.018  54.271  1
465719  93.366  -63.017  54.254  1
465720  93.396  -63.033  54.236  1
465721  93.420  -63.054  54.218  1
465722  93.453  -63.069  54.200  1
465723  93.492  -63.079  54.181  1
465724  93.531  -63.091  54.163  1
465725  93.569  -63.101  54.144  1
465726  93.608  -63.113  54.124  1
465727  93.647  -63.123  54.105  1
465728  93.686  -63.135  54.086  1
465729  93.724  -63.145  54.065  1
465730  93.763  -63.156  54.045  1
465731  93.801  -63.168  54.026  1
465732  93.846  -63.179  54.006  1
465733  93.892  -63.177  53.987  1
465734  93.937  -63.177  53.969  1
465735  93.982  -63.175  53.952  1
465736  94.028  -63.173  53.934  1
465737  94.073  -63.172  53.918  1
465738  94.111  -63.199  53.904  1
465739  94.146  -63.238  53.890  1
465740  94.180  -63.257  53.877  1
465741  94.212  -63.263  53.865  1
465742  94.245  -63.268  53.855  1
465743  94.277  -63.274  53.845  1
465744  94.310  -63.280  53.836  1
465745  94.342  -63.286  53.826  1
465746  94.376  -63.291  53.817  1
465747  94.412  -63.297  53.806  1
465748  94.448  -63.303  53.794  1
465749  94.483  -63.309  53.780  1
465750  94.519  -63.315  53.765  1
465751  94.555  -63.321  53.748  1
465752  94.591  -63.327  53.730  1
465753  94.623  -63.339  53.711  1
465754  94.668  -63.343  53.690  1
465755  94.729  -63.344  53.670  1
465756  94.791  -63.346  53.649  1
465757  94.854  -63.347  53.628  1
465758  94.917  -63.349  53.606  1
465759  94.980  -63.350  53.583  1
465760  95.042  -63.352  53.558  1
465761  95.105  -63.353  53.532  1
465762  95.148  -63.357  53.506  1
465763  95.186  -63.361  53.479  1
465764  95.225  -63.365  53.453  1
465765  95.262  -63.369  53.427  1
465766  95.301  -63.374  53.400  1
465767  95.339  -63.377  53.376  1
465768  95.377  -63.382  53.352  1
465769  95.415  -63.386  53.329  1
465770  95.453  -63.390  53.307  1
465771  95.490  -63.394  53.284  1
465772  95.521  -63.392  53.261  1
465773  95.552  -63.389  53.238  1
465774  95.584  -63.386  53.214  1
465775  95.620  -63.386  53.189  1
465776  95.666  -63.390  53.162  1
465777  95.712  -63.393  53.136  1
465778  95.758  -63.396  53.108  1
465779  95.804  -63.399  53.079  1
465780  95.850  -63.406  53.051  1
465781  95.897  -63.412  53.023  1
465782  95.944  -63.419  52.995  1
465783  95.990  -63.426  52.965  1
465784  96.035  -63.432  52.932  1
465785  96.068  -63.436  52.894  1
465786  96.110  -63.433  52.852  1
465787  96.146  -63.446  52.806  1
465788  96.184  -63.458  52.758  1
465789  96.265  -63.450  52.708  1
465790  96.346  -63.443  52.659  1
465791  96.410  -63.438  52.611  1
465792  96.452  -63.437  52.566  1
465793  96.494  -63.435  52.521  1
465794  96.536  -63.433  52.478  1
465795  96.578  -63.431  52.438  1
465796  96.623  -63.428  52.399  1
465797  96.678  -63.420  52.362  1
465798  96.733  -63.412  52.330  1
465799  96.784  -63.410  52.301  1
465800  96.814  -63.422  52.275  1
465801  96.845  -63.433  52.247  1
465802  96.875  -63.446  52.215  1
465803  96.906  -63.459  52.182  1
465804  96.938  -63.471  52.149  1
465805  96.969  -63.483  52.117  1
465806  97.000  -63.496  52.084  1
465807  97.031  -63.508  52.050  1
465808  97.063  -63.521  52.016  1
465809  97.094  -63.533  51.982  1
465810  97.125  -63.546  51.948  1
465811  97.156  -63.558  51.916  1
465812  97.187  -63.571  51.886  1
465813  97.219  -63.583  51.857  1
465814  97.250  -63.595  51.830  1
465815  97.282  -63.608  51.803  1
465816  97.305  -63.622  51.777  1
465817  97.327  -63.637  51.748  1
465818  97.351  -63.650  51.717  1
465819  97.373  -63.661  51.685  1
465820  97.396  -63.672  51.653  1
465821  97.419  -63.683  51.624  1
465822  97.442  -63.694  51.593  1
465823  97.489  -63.680  51.559  1
465824  97.517  -63.684  51.522  1
465825  97.551  -63.693  51.481  1
465826  97.599  -63.708  51.437  1
465827  97.639  -63.707  51.390  1
465828  97.678  -63.705  51.341  1
465829  97.718  -63.703  51.291  1
465830  97.757  -63.701  51.241  1
465831  97.796  -63.699  51.191  1
465832  97.836  -63.697  51.140  1
465833  97.875  -63.694  51.087  1
465834  97.914  -63.693  51.035  1
465835  97.953  -63.690  50.982  1
465836  97.993  -63.688  50.930  1
465837  98.027  -63.690  50.877  1
465838  98.062  -63.690  50.824  1
465839  98.096  -63.692  50.771  1
465840  98.132  -63.693  50.718  1
465841  98.174  -63.688  50.666  1
465842  98.208  -63.691  50.615  1
465843  98.226  -63.705  50.564  1
465844  98.244  -63.719  50.514  1
465845  98.263  -63.733  50.464  1
465846  98.282  -63.747  50.417  1
465847  98.305  -63.757  50.368  1
465848  98.339  -63.761  50.320  1
465849  98.372  -63.765  50.271  1
465850  98.402  -63.766  50.222  1
465851  98.425  -63.766  50.173  1
465852  98.449  -63.766  50.124  1
465853  98.473  -63.765  50.075  1
465854  98.496  -63.764  50.027  1
465855  98.520  -63.763  49.980  1
465856  98.544  -63.763  49.933  1
465857  98.567  -63.762  49.885  1
465858  98.590  -63.761  49.836  1
465859  98.614  -63.761  49.786  1
465860  98.648  -63.759  49.739  1
465861  98.711  -63.757  49.687  1
465862  98.774  -63.756  49.638  1
465863  98.837  -63.754  49.591  1
465864  98.900  -63.752  49.544  1
465865  98.962  -63.750  49.499  1
465866  99.025  -63.748  49.456  1
465867  99.088  -63.747  49.413  1
465868  99.151  -63.745  49.370  1
465869  99.214  -63.743  49.328  1
465870  99.277  -63.741  49.289  1
465871  99.340  -63.739  49.249  1
465872  99.403  -63.737  49.211  1
466276  87.032  -61.914  56.173  1
466277  87.074  -61.912  56.160  1
466278  87.117  -61.910  56.148  1
466279  87.159  -61.909  56.138  1
466280  87.197  -61.910  56.128  1
466281  87.234  -61.911  56.118  1
466282  87.271  -61.914  56.108  1
466283  87.307  -61.915  56.099  1
466284  87.344  -61.917  56.089  1
466285  87.380  -61.919  56.082  1
466286  87.417  -61.920  56.074  1
466287  87.454  -61.923  56.065  1
466288  87.491  -61.924  56.056  1
466289  87.528  -61.926  56.045  1
466290  87.576  -61.922  56.033  1
466291  87.625  -61.919  56.019  1
466292  87.673  -61.916  56.001  1
466293  87.721  -61.912  55.980  1
466294  87.769  -61.909  55.957  1
466295  87.818  -61.905  55.935  1
466296  87.866  -61.902  55.915  1
466297  87.914  -61.898  55.897  1
466298  87.963  -61.895  55.879  1
466299  88.010  -61.892  55.861  1
466300  88.059  -61.888  55.844  1
466301  88.107  -61.885  55.826  1
466302  88.155  -61.882  55.809  1
466303  88.205  -61.879  55.794  1
466304  88.272  -61.885  55.779  1
466305  88.328  -61.898  55.764  1
466306  88.376  -61.914  55.746  1
466307  88.424  -61.929  55.726  1
466308  88.472  -61.944  55.701  1
466309  88.521  -61.959  55.670  1
466310  88.569  -61.975  55.640  1
466311  88.616  -61.991  55.614  1
466312  88.663  -62.007  55.593  1
466313  88.710  -62.023  55.576  1
466314  88.757  -62.039  55.560  1
466315  88.802  -62.056  55.545  1
466316  88.846  -62.073  55.528  1
466317  88.892  -62.096  55.509  1
466318  88.933  -62.108  55.490  1
466319  88.971  -62.110  55.470  1
466320  89.012  -62.116  55.452  1
466321  89.054  -62.126  55.434  1
466322  89.097  -62.136  55.417  1
466323  89.139  -62.145  55.401  1
466324  89.182  -62.155  55.386  1
466325  89.225  -62.164  55.371  1
466326  89.267  -62.174  55.356  1
466327  89.310  -62.183  55.341  1
466328  89.352  -62.192  55.325  1
466329  89.395  -62.202  55.314  1
466330  89.437  -62.212  55.302  1
466331  89.480  -62.221  55.292  1
466332  89.523  -62.231  55.285  1
466333  89.565  -62.241  55.274  1
466334  89.608  -62.250  55.267  1
466335  89.650  -62.260  55.261  1
466336  89.693  -62.269  55.256  1
466337  89.735  -62.279  55.255  1
466338  89.778  -62.289  55.256  1
466339  89.821  -62.299  55.256  1
466340  89.866  -62.321  55.254  1
466341  89.911  -62.342  55.250  1
466342  89.957  -62.363  55.245  1
466343  90.006  -62.380  55.240  1
466344  90.058  -62.392  55.231  1
466345  90.110  -62.405  55.219  1
466346  90.162  -62.417  55.204  1
466347  90.214  -62.430  55.189  1
466348  90.265  -62.442  55.176  1
466349  90.314  -62.456  55.171  1
466350  90.362  -62.470  55.171  1
466351  90.410  -62.484  55.173  1
466352  90.458  -62.498  55.174  1
466353  90.507  -62.512  55.172  1
466354  90.554  -62.526  55.159  1
466355  90.603  -62.540  55.140  1
466356  90.648  -62.552  55.116  1
466357  90.690  -62.562  55.089  1
466358  90.733  -62.572  55.066  1
466359  90.776  -62.581  55.049  1
466360  90.818  -62.591  55.034  1
466361  90.861  -62.601  55.021  1
466362  90.904  -62.611  55.011  1
466363  90.946  -62.621  55.002  1
466364  90.989  -62.631  54.993  1
466365  91.034  -62.641  54.985  1
466366  91.088  -62.652  54.977  1
466367  91.141  -62.663  54.970  1
466368  91.193  -62.675  54.964  1
466369  91.247  -62.686  54.958  1
466370  91.300  -62.697  54.953  1
466371  91.353  -62.709  54.949  1
466372  91.406  -62.720  54.944  1
466373  91.459  -62.732  54.932  1
466374  91.512  -62.743  54.916  1
466375  91.565  -62.754  54.900  1
466376  91.613  -62.769  54.884  1
466377  91.658  -62.782  54.867  1
466378  91.703  -62.793  54.851  1
466379  91.748  -62.804  54.837  1
466380  91.793  -62.815  54.824  1
466381  91.839  -62.825  54.814  1
466382  91.883  -62.837  54.807  1
466383  91.929  -62.847  54.803  1
466384  91.974  -62.859  54.804  1
466385  92.010  -62.858  54.809  1
466386  92.044  -62.854  54.818  1
466387  92.078  -62.849  54.831  1
466388  92.111  -62.845  54.843  1
466389  92.146  -62.841  54.858  1
466390  92.184  -62.841  54.872  1
466391  92.227  -62.844  54.880  1
466392  92.270  -62.848  54.880  1
466393  92.312  -62.851  54.869  1
466394  92.355  -62.855  54.852  1
466395  92.398  -62.859  54.831  1
466396  92.440  -62.862  54.805  1
466397  92.483  -62.866  54.776  1
466398  92.525  -62.869  54.747  1
466399  92.568  -62.873  54.717  1
466400  92.611  -62.876  54.687  1
466401  92.653  -62.880  54.657  1
466402  92.692  -62.883  54.628  1
466403  92.727  -62.891  54.600  1
466404  92.756  -62.904  54.573  1
466405  92.783  -62.915  54.546  1
466406  92.810  -62.926  54.519  1
466407  92.844  -62.938  54.493  1
466408  92.889  -62.951  54.468  1
466409  92.933  -62.963  54.445  1
466410  92.978  -62.975  54.423  1
466411  93.022  -62.987  54.402  1
466412  93.066  -62.998  54.383  1
466413  93.111  -62.995  54.364  1
466414  93.161  -62.987  54.345  1
466415  93.212  -62.979  54.327  1
466416  93.263  -62.973  54.310  1
466417  93.303  -62.984  54.291  1
466418  93.309  -62.985  54.274  1
466419  93.315  -62.978  54.256  1
466420  93.362  -62.977  54.238  1
466421  93.387  -62.998  54.220  1
466422  93.419  -63.014  54.204  1
466423  93.457  -63.024  54.186  1
466424  93.496  -63.035  54.168  1
466425  93.535  -63.046  54.149  1
466426  93.573  -63.057  54.131  1
466427  93.612  -63.068  54.113  1
466428  93.650  -63.079  54.095  1
466429  93.690  -63.092  54.076  1
466430  93.730  -63.105  54.057  1
466431  93.770  -63.119  54.038  1
466432  93.810  -63.132  54.020  1
466433  93.857  -63.136  54.001  1
466434  93.906  -63.149  53.984  1
466435  93.955  -63.165  53.966  1
466436  94.001  -63.167  53.948  1
466437  94.046  -63.167  53.931  1
466438  94.091  -63.165  53.916  1
466439  94.133  -63.180  53.901  1
466440  94.168  -63.216  53.888  1
466441  94.200  -63.222  53.876  1
466442  94.232  -63.227  53.864  1
466443  94.265  -63.233  53.853  1
466444  94.298  -63.239  53.843  1
466445  94.331  -63.245  53.833  1
466446  94.363  -63.250  53.824  1
466447  94.396  -63.256  53.815  1
466448  94.428  -63.261  53.803  1
466449  94.461  -63.267  53.790  1
466450  94.493  -63.273  53.775  1
466451  94.526  -63.279  53.759  1
466452  94.559  -63.284  53.741  1
466453  94.591  -63.290  53.722  1
466454  94.625  -63.296  53.702  1
466455  94.678  -63.299  53.680  1
466456  94.741  -63.301  53.657  1
466457  94.803  -63.302  53.635  1
466458  94.866  -63.304  53.613  1
466459  94.928  -63.305  53.591  1
466460  94.992  -63.309  53.567  1
466461  95.056  -63.314  53.541  1
466462  95.120  -63.321  53.515  1
466463  95.156  -63.315  53.488  1
466464  95.193  -63.320  53.461  1
466465  95.231  -63.325  53.435  1
466466  95.267  -63.330  53.408  1
466467  95.305  -63.336  53.380  1
466468  95.341  -63.340  53.354  1
466469  95.379  -63.346  53.328  1
466470  95.415  -63.351  53.304  1
466471  95.453  -63.355  53.280  1
466472  95.500  -63.326  53.257  1
466473  95.523  -63.339  53.232  1
466474  95.554  -63.336  53.209  1
466475  95.585  -63.334  53.184  1
466476  95.624  -63.334  53.158  1
466477  95.670  -63.337  53.130  1
466478  95.716  -63.341  53.103  1
466479  95.763  -63.348  53.074  1
466480  95.809  -63.354  53.045  1
466481  95.856  -63.361  53.018  1
466482  95.902  -63.368  52.989  1
466483  95.949  -63.374  52.959  1
466484  95.996  -63.380  52.930  1
466485  96.039  -63.386  52.899  1
466486  96.073  -63.390  52.865  1
466487  96.111  -63.390  52.826  1
466488  96.151  -63.392  52.784  1
466489  96.187  -63.405  52.738  1
466490  96.223  -63.417  52.688  1
466491  96.291  -63.416  52.636  1
466492  96.372  -63.408  52.586  1
466493  96.453  -63.402  52.539  1
466494  96.527  -63.395  52.492  1
466495  96.569  -63.393  52.447  1
466496  96.611  -63.392  52.407  1
466497  96.653  -63.390  52.368  1
466498  96.695  -63.389  52.331  1
466499  96.763  -63.386  52.297  1
466500  96.795  -63.385  52.268  1
466501  96.823  -63.394  52.243  1
466502  96.854  -63.406  52.216  1
466503  96.884  -63.418  52.185  1
466504  96.915  -63.430  52.151  1
466505  96.945  -63.442  52.117  1
466506  96.976  -63.454  52.084  1
466507  97.006  -63.466  52.053  1
466508  97.037  -63.478  52.019  1
466509  97.067  -63.490  51.984  1
466510  97.097  -63.502  51.950  1
466511  97.128  -63.514  51.915  1
466512  97.158  -63.526  51.883  1
466513  97.189  -63.538  51.852  1
466514  97.221  -63.551  51.823  1
466515  97.252  -63.563  51.795  1
466516  97.281  -63.576  51.766  1
466517  97.303  -63.588  51.738  1
466518  97.326  -63.599  51.709  1
466519  97.349  -63.610  51.679  1
466520  97.372  -63.621  51.648  1
466521  97.394  -63.631  51.617  1
466522  97.418  -63.642  51.587  1
466523  97.449  -63.644  51.558  1
466524  97.499  -63.628  51.527  1
466525  97.527  -63.633  51.492  1
466526  97.554  -63.637  51.453  1
466527  97.593  -63.649  51.411  1
466528  97.641  -63.663  51.365  1
466529  97.685  -63.670  51.317  1
466530  97.724  -63.668  51.268  1
466531  97.764  -63.665  51.219  1
466532  97.803  -63.663  51.170  1
466533  97.842  -63.662  51.120  1
466534  97.881  -63.659  51.069  1
466535  97.921  -63.657  51.017  1
466536  97.960  -63.655  50.966  1
466537  97.999  -63.653  50.913  1
466538  98.034  -63.654  50.860  1
466539  98.069  -63.655  50.807  1
466540  98.103  -63.656  50.754  1
466541  98.142  -63.655  50.700  1
466542  98.184  -63.651  50.648  1
466543  98.219  -63.653  50.596  1
466544  98.237  -63.666  50.545  1
466545  98.255  -63.681  50.494  1
466546  98.274  -63.694  50.445  1
466547  98.293  -63.708  50.396  1
466548  98.311  -63.722  50.348  1
466549  98.331  -63.735  50.301  1
466550  98.365  -63.739  50.254  1
466551  98.398  -63.742  50.207  1
466552  98.424  -63.743  50.159  1
466553  98.447  -63.742  50.111  1
466554  98.471  -63.741  50.062  1
466555  98.494  -63.741  50.014  1
466556  98.518  -63.740  49.965  1
466557  98.541  -63.739  49.917  1
466558  98.565  -63.739  49.867  1
466559  98.589  -63.738  49.817  1
466560  98.615  -63.725  49.767  1
466561  98.656  -63.721  49.719  1
466562  98.719  -63.719  49.669  1
466563  98.782  -63.717  49.622  1
466564  98.845  -63.715  49.575  1
466565  98.908  -63.713  49.530  1
466566  98.971  -63.712  49.485  1
466567  99.034  -63.709  49.443  1
466568  99.097  -63.708  49.401  1
466569  99.160  -63.706  49.359  1
466570  99.223  -63.704  49.318  1
466571  99.286  -63.703  49.279  1
466572  99.349  -63.700  49.241  1
466977  87.048  -61.865  56.172  1
466978  87.090  -61.863  56.159  1
466979  87.133  -61.862  56.147  1
466980  87.176  -61.860  56.136  1
466981  87.212  -61.862  56.126  1
466982  87.249  -61.863  56.115  1
466983  87.286  -61.865  56.105  1
466984  87.323  -61.867  56.095  1
466985  87.359  -61.869  56.086  1
466986  87.396  -61.871  56.079  1
466987  87.433  -61.873  56.070  1
466988  87.469  -61.874  56.060  1
466989  87.506  -61.876  56.051  1
466990  87.543  -61.878  56.039  1
466991  87.586  -61.877  56.028  1
466992  87.634  -61.873  56.015  1
466993  87.682  -61.870  55.999  1
466994  87.730  -61.867  55.980  1
466995  87.779  -61.863  55.958  1
466996  87.827  -61.860  55.938  1
466997  87.875  -61.857  55.919  1
466998  87.924  -61.854  55.902  1
466999  87.972  -61.850  55.885  1
467000  88.020  -61.847  55.868  1
467001  88.068  -61.843  55.850  1
467002  88.117  -61.840  55.832  1
467003  88.165  -61.837  55.814  1
467004  88.216  -61.835  55.797  1
467005  88.283  -61.841  55.780  1
467006  88.344  -61.851  55.763  1
467007  88.393  -61.866  55.743  1
467008  88.441  -61.881  55.721  1
467009  88.489  -61.897  55.696  1
467010  88.537  -61.912  55.665  1
467011  88.586  -61.927  55.638  1
467012  88.634  -61.942  55.616  1
467013  88.682  -61.958  55.599  1
467014  88.727  -61.975  55.584  1
467015  88.771  -61.992  55.570  1
467016  88.816  -62.010  55.555  1
467017  88.860  -62.027  55.536  1
467018  88.909  -62.058  55.515  1
467019  88.949  -62.065  55.493  1
467020  88.986  -62.067  55.471  1
467021  89.023  -62.068  55.451  1
467022  89.064  -62.076  55.432  1
467023  89.107  -62.085  55.415  1
467024  89.150  -62.095  55.399  1
467025  89.192  -62.104  55.383  1
467026  89.235  -62.114  55.368  1
467027  89.277  -62.123  55.353  1
467028  89.320  -62.133  55.338  1
467029  89.362  -62.142  55.322  1
467030  89.405  -62.152  55.310  1
467031  89.447  -62.161  55.298  1
467032  89.490  -62.171  55.288  1
467033  89.532  -62.180  55.281  1
467034  89.575  -62.190  55.271  1
467035  89.617  -62.200  55.264  1
467036  89.660  -62.209  55.258  1
467037  89.702  -62.219  55.254  1
467038  89.745  -62.229  55.253  1
467039  89.788  -62.238  55.255  1
467040  89.831  -62.251  55.257  1
467041  89.877  -62.272  55.258  1
467042  89.922  -62.293  55.256  1
467043  89.967  -62.315  55.253  1
467044  90.014  -62.334  55.248  1
467045  90.065  -62.347  55.240  1
467046  90.117  -62.359  55.227  1
467047  90.169  -62.372  55.211  1
467048  90.221  -62.384  55.194  1
467049  90.273  -62.397  55.178  1
467050  90.325  -62.410  55.168  1
467051  90.374  -62.423  55.163  1
467052  90.423  -62.437  55.162  1
467053  90.471  -62.451  55.163  1
467054  90.519  -62.465  55.159  1
467055  90.567  -62.479  55.146  1
467056  90.615  -62.493  55.126  1
467057  90.663  -62.506  55.102  1
467058  90.706  -62.516  55.079  1
467059  90.748  -62.526  55.060  1
467060  90.791  -62.536  55.045  1
467061  90.833  -62.546  55.033  1
467062  90.876  -62.556  55.022  1
467063  90.919  -62.565  55.012  1
467064  90.961  -62.575  55.005  1
467065  91.003  -62.585  54.998  1
467066  91.044  -62.594  54.989  1
467067  91.096  -62.606  54.980  1
467068  91.149  -62.617  54.973  1
467069  91.202  -62.628  54.968  1
467070  91.255  -62.640  54.962  1
467071  91.308  -62.651  54.957  1
467072  91.361  -62.663  54.953  1
467073  91.415  -62.674  54.949  1
467074  91.467  -62.685  54.937  1
467075  91.520  -62.697  54.921  1
467076  91.571  -62.710  54.905  1
467077  91.616  -62.725  54.889  1
467078  91.660  -62.742  54.873  1
467079  91.705  -62.755  54.858  1
467080  91.750  -62.766  54.843  1
467081  91.795  -62.777  54.830  1
467082  91.841  -62.788  54.819  1
467083  91.885  -62.799  54.810  1
467084  91.931  -62.810  54.806  1
467085  91.976  -62.821  54.805  1
467086  92.014  -62.823  54.808  1
467087  92.048  -62.819  54.816  1
467088  92.082  -62.815  54.828  1
467089  92.116  -62.810  54.839  1
467090  92.150  -62.806  54.850  1
467091  92.183  -62.802  54.860  1
467092  92.224  -62.803  54.866  1
467093  92.267  -62.807  54.865  1
467094  92.309  -62.810  54.855  1
467095  92.352  -62.813  54.837  1
467096  92.394  -62.817  54.816  1
467097  92.437  -62.821  54.790  1
467098  92.480  -62.824  54.761  1
467099  92.522  -62.828  54.731  1
467100  92.565  -62.832  54.700  1
467101  92.607  -62.835  54.670  1
467102  92.650  -62.838  54.640  1
467103  92.692  -62.842  54.612  1
467104  92.732  -62.847  54.585  1
467105  92.759  -62.858  54.558  1
467106  92.786  -62.869  54.530  1
467107  92.813  -62.881  54.503  1
467108  92.852  -62.892  54.476  1
467109  92.897  -62.905  54.451  1
467110  92.941  -62.917  54.428  1
467111  92.986  -62.929  54.406  1
467112  93.029  -62.940  54.385  1
467113  93.071  -62.939  54.365  1
467114  93.112  -62.939  54.347  1
467115  93.160  -62.932  54.328  1
467116  93.211  -62.924  54.310  1
467117  93.261  -62.924  54.293  1
467118  93.310  -62.940  54.276  1
467119  93.339  -62.948  54.258  1
467120  93.311  -62.938  54.241  1
467121  93.353  -62.941  54.223  1
467122  93.383  -62.958  54.207  1
467123  93.422  -62.969  54.191  1
467124  93.461  -62.980  54.174  1
467125  93.499  -62.991  54.157  1
467126  93.539  -63.004  54.140  1
467127  93.579  -63.017  54.123  1
467128  93.619  -63.030  54.106  1
467129  93.659  -63.043  54.089  1
467130  93.699  -63.056  54.071  1
467131  93.739  -63.070  54.052  1
467132  93.778  -63.082  54.034  1
467133  93.818  -63.095  54.016  1
467134  93.866  -63.099  53.998  1
467135  93.917  -63.103  53.980  1
467136  93.966  -63.119  53.962  1
467137  94.015  -63.135  53.945  1
467138  94.063  -63.150  53.927  1
467139  94.111  -63.158  53.912  1
467140  94.154  -63.161  53.899  1
467141  94.188  -63.181  53.886  1
467142  94.221  -63.186  53.874  1
467143  94.253  -63.192  53.863  1
467144  94.286  -63.198  53.852  1
467145  94.319  -63.204  53.840  1
467146  94.351  -63.209  53.830  1
467147  94.384  -63.214  53.820  1
467148  94.416  -63.219  53.812  1
467149  94.449  -63.224  53.799  1
467150  94.481  -63.227  53.785  1
467151  94.513  -63.232  53.770  1
467152  94.546  -63.236  53.752  1
467153  94.578  -63.240  53.732  1
467154  94.610  -63.245  53.713  1
467155  94.638  -63.257  53.692  1
467156  94.674  -63.258  53.669  1
467157  94.714  -63.255  53.645  1
467158  94.773  -63.261  53.622  1
467159  94.839  -63.270  53.599  1
467160  94.905  -63.280  53.575  1
467161  94.971  -63.290  53.551  1
467162  95.037  -63.300  53.525  1
467163  95.103  -63.310  53.499  1
467164  95.146  -63.286  53.471  1
467165  95.178  -63.270  53.444  1
467166  95.216  -63.277  53.418  1
467167  95.254  -63.285  53.391  1
467168  95.293  -63.292  53.362  1
467169  95.331  -63.299  53.334  1
467170  95.369  -63.305  53.306  1
467171  95.408  -63.316  53.280  1
467172  95.468  -63.279  53.254  1
467173  95.518  -63.244  53.230  1
467174  95.539  -63.259  53.204  1
467175  95.560  -63.275  53.180  1
467176  95.586  -63.281  53.154  1
467177  95.628  -63.283  53.127  1
467178  95.675  -63.289  53.099  1
467179  95.721  -63.296  53.070  1
467180  95.768  -63.302  53.041  1
467181  95.814  -63.308  53.011  1
467182  95.861  -63.315  52.982  1
467183  95.908  -63.322  52.953  1
467184  95.954  -63.329  52.924  1
467185  96.001  -63.335  52.895  1
467186  96.043  -63.341  52.866  1
467187  96.077  -63.345  52.833  1
467188  96.113  -63.346  52.797  1
467189  96.154  -63.343  52.758  1
467190  96.192  -63.350  52.714  1
467191  96.228  -63.363  52.665  1
467192  96.264  -63.376  52.613  1
467193  96.316  -63.382  52.562  1
467194  96.397  -63.375  52.513  1
467195  96.478  -63.368  52.466  1
467196  96.559  -63.360  52.420  1
467197  96.640  -63.353  52.378  1
467198  96.686  -63.351  52.338  1
467199  96.732  -63.355  52.300  1
467200  96.788  -63.361  52.266  1
467201  96.810  -63.363  52.237  1
467202  96.833  -63.367  52.210  1
467203  96.863  -63.378  52.185  1
467204  96.894  -63.390  52.154  1
467205  96.924  -63.402  52.121  1
467206  96.954  -63.415  52.087  1
467207  96.985  -63.427  52.053  1
467208  97.015  -63.439  52.021  1
467209  97.046  -63.450  51.988  1
467210  97.076  -63.462  51.954  1
467211  97.107  -63.474  51.919  1
467212  97.137  -63.487  51.884  1
467213  97.168  -63.499  51.851  1
467214  97.198  -63.510  51.820  1
467215  97.229  -63.522  51.790  1
467216  97.253  -63.531  51.761  1
467217  97.279  -63.537  51.732  1
467218  97.302  -63.548  51.701  1
467219  97.324  -63.559  51.671  1
467220  97.348  -63.569  51.641  1
467221  97.370  -63.581  51.610  1
467222  97.393  -63.591  51.579  1
467223  97.416  -63.602  51.549  1
467224  97.459  -63.593  51.521  1
467225  97.509  -63.577  51.492  1
467226  97.537  -63.581  51.460  1
467227  97.564  -63.586  51.425  1
467228  97.590  -63.591  51.383  1
467229  97.636  -63.605  51.338  1
467230  97.683  -63.619  51.292  1
467231  97.731  -63.632  51.245  1
467232  97.770  -63.631  51.199  1
467233  97.809  -63.628  51.150  1
467234  97.849  -63.626  51.101  1
467235  97.888  -63.624  51.050  1
467236  97.927  -63.622  50.998  1
467237  97.966  -63.620  50.947  1
467238  98.006  -63.618  50.895  1
467239  98.041  -63.618  50.842  1
467240  98.076  -63.619  50.790  1
467241  98.111  -63.621  50.736  1
467242  98.152  -63.617  50.682  1
467243  98.195  -63.613  50.629  1
467244  98.230  -63.614  50.577  1
467245  98.248  -63.628  50.526  1
467246  98.267  -63.642  50.476  1
467247  98.285  -63.656  50.426  1
467248  98.304  -63.670  50.376  1
467249  98.322  -63.684  50.328  1
467250  98.341  -63.697  50.283  1
467251  98.359  -63.712  50.238  1
467252  98.390  -63.716  50.193  1
467253  98.422  -63.719  50.145  1
467254  98.445  -63.719  50.096  1
467255  98.469  -63.718  50.048  1
467256  98.493  -63.717  49.999  1
467257  98.516  -63.717  49.949  1
467258  98.539  -63.716  49.898  1
467259  98.565  -63.706  49.847  1
467260  98.591  -63.694  49.797  1
467261  98.617  -63.681  49.747  1
467262  98.665  -63.681  49.698  1
467263  98.728  -63.680  49.651  1
467264  98.791  -63.678  49.605  1
467265  98.854  -63.676  49.560  1
467266  98.917  -63.675  49.516  1
467267  98.980  -63.672  49.472  1
467268  99.043  -63.671  49.430  1
467269  99.106  -63.669  49.389  1
467270  99.168  -63.667  49.349  1
467271  99.231  -63.665  49.308  1
467272  99.294  -63.663  49.269  1
467273  99.357  -63.662  49.232  1
467678  87.065  -61.816  56.171  1
467679  87.107  -61.815  56.158  1
467680  87.149  -61.813  56.146  1
467681  87.191  -61.812  56.135  1
467682  87.228  -61.813  56.124  1
467683  87.264  -61.816  56.113  1
467684  87.301  -61.817  56.103  1
467685  87.338  -61.820  56.093  1
467686  87.374  -61.821  56.083  1
467687  87.411  -61.823  56.075  1
467688  87.448  -61.825  56.066  1
467689  87.485  -61.826  56.056  1
467690  87.521  -61.829  56.048  1
467691  87.558  -61.830  56.037  1
467692  87.596  -61.832  56.024  1
467693  87.643  -61.828  56.012  1
467694  87.692  -61.825  55.998  1
467695  87.740  -61.822  55.980  1
467696  87.788  -61.818  55.959  1
467697  87.837  -61.815  55.940  1
467698  87.885  -61.811  55.922  1
467699  87.933  -61.808  55.905  1
467700  87.981  -61.804  55.889  1
467701  88.030  -61.801  55.874  1
467702  88.078  -61.798  55.856  1
467703  88.126  -61.794  55.838  1
467704  88.175  -61.791  55.820  1
467705  88.227  -61.790  55.802  1
467706  88.294  -61.797  55.783  1
467707  88.361  -61.804  55.763  1
467708  88.409  -61.819  55.742  1
467709  88.458  -61.834  55.719  1
467710  88.506  -61.849  55.694  1
467711  88.554  -61.865  55.664  1
467712  88.603  -61.880  55.639  1
467713  88.651  -61.895  55.620  1
467714  88.698  -61.911  55.605  1
467715  88.741  -61.929  55.592  1
467716  88.785  -61.947  55.580  1
467717  88.830  -61.964  55.565  1
467718  88.876  -61.988  55.546  1
467719  88.926  -62.020  55.522  1
467720  88.963  -62.023  55.496  1
467721  89.000  -62.024  55.471  1
467722  89.038  -62.026  55.449  1
467723  89.075  -62.027  55.430  1
467724  89.117  -62.035  55.412  1
467725  89.159  -62.044  55.396  1
467726  89.202  -62.054  55.381  1
467727  89.244  -62.063  55.365  1
467728  89.287  -62.073  55.350  1
467729  89.330  -62.083  55.335  1
467730  89.372  -62.092  55.319  1
467731  89.415  -62.102  55.307  1
467732  89.457  -62.111  55.295  1
467733  89.500  -62.120  55.285  1
467734  89.542  -62.130  55.277  1
467735  89.585  -62.139  55.267  1
467736  89.627  -62.149  55.260  1
467737  89.670  -62.159  55.254  1
467738  89.712  -62.168  55.251  1
467739  89.755  -62.178  55.250  1
467740  89.798  -62.188  55.255  1
467741  89.841  -62.202  55.259  1
467742  89.887  -62.224  55.261  1
467743  89.932  -62.245  55.261  1
467744  89.977  -62.266  55.261  1
467745  90.023  -62.287  55.257  1
467746  90.074  -62.302  55.248  1
467747  90.125  -62.315  55.235  1
467748  90.177  -62.327  55.218  1
467749  90.229  -62.340  55.200  1
467750  90.281  -62.352  55.183  1
467751  90.333  -62.365  55.168  1
467752  90.385  -62.377  55.158  1
467753  90.435  -62.390  55.153  1
467754  90.483  -62.404  55.151  1
467755  90.532  -62.418  55.144  1
467756  90.580  -62.432  55.131  1
467757  90.628  -62.446  55.111  1
467758  90.676  -62.460  55.089  1
467759  90.720  -62.471  55.070  1
467760  90.763  -62.481  55.055  1
467761  90.805  -62.490  55.043  1
467762  90.848  -62.500  55.032  1
467763  90.891  -62.510  55.023  1
467764  90.933  -62.520  55.015  1
467765  90.976  -62.530  55.011  1
467766  91.017  -62.540  55.004  1
467767  91.057  -62.549  54.995  1
467768  91.105  -62.559  54.986  1
467769  91.158  -62.571  54.980  1
467770  91.211  -62.582  54.977  1
467771  91.264  -62.594  54.971  1
467772  91.317  -62.605  54.966  1
467773  91.370  -62.616  54.961  1
467774  91.423  -62.628  54.953  1
467775  91.474  -62.640  54.942  1
467776  91.525  -62.652  54.927  1
467777  91.576  -62.665  54.911  1
467778  91.619  -62.681  54.895  1
467779  91.663  -62.699  54.882  1
467780  91.707  -62.716  54.867  1
467781  91.752  -62.728  54.852  1
467782  91.797  -62.739  54.838  1
467783  91.843  -62.750  54.826  1
467784  91.887  -62.761  54.815  1
467785  91.932  -62.772  54.809  1
467786  91.978  -62.783  54.806  1
467787  92.018  -62.788  54.808  1
467788  92.052  -62.784  54.814  1
467789  92.086  -62.780  54.825  1
467790  92.120  -62.775  54.834  1
467791  92.154  -62.772  54.841  1
467792  92.188  -62.767  54.848  1
467793  92.222  -62.763  54.852  1
467794  92.263  -62.765  54.849  1
467795  92.306  -62.769  54.839  1
467796  92.348  -62.772  54.821  1
467797  92.391  -62.775  54.799  1
467798  92.433  -62.779  54.774  1
467799  92.476  -62.783  54.745  1
467800  92.519  -62.786  54.713  1
467801  92.561  -62.790  54.682  1
467802  92.604  -62.794  54.651  1
467803  92.646  -62.797  54.621  1
467804  92.689  -62.800  54.594  1
467805  92.733  -62.802  54.567  1
467806  92.763  -62.812  54.541  1
467807  92.790  -62.823  54.515  1
467808  92.816  -62.835  54.489  1
467809  92.860  -62.847  54.463  1
467810  92.905  -62.859  54.437  1
467811  92.949  -62.872  54.414  1
467812  92.993  -62.881  54.392  1
467813  93.034  -62.880  54.371  1
467814  93.075  -62.880  54.351  1
467815  93.116  -62.879  54.332  1
467816  93.159  -62.878  54.313  1
467817  93.210  -62.869  54.295  1
467818  93.260  -62.875  54.278  1
467819  93.309  -62.891  54.261  1
467820  93.335  -62.900  54.244  1
467821  93.340  -62.901  54.227  1
467822  93.349  -62.903  54.211  1
467823  93.388  -62.915  54.195  1
467824  93.428  -62.928  54.181  1
467825  93.468  -62.941  54.165  1
467826  93.507  -62.954  54.149  1
467827  93.548  -62.967  54.133  1
467828  93.587  -62.981  54.117  1
467829  93.627  -62.994  54.101  1
467830  93.667  -63.007  54.084  1
467831  93.707  -63.020  54.067  1
467832  93.747  -63.033  54.049  1
467833  93.787  -63.046  54.030  1
467834  93.827  -63.060  54.012  1
467835  93.876  -63.062  53.995  1
467836  93.927  -63.061  53.976  1
467837  93.977  -63.072  53.958  1
467838  94.026  -63.088  53.942  1
467839  94.074  -63.104  53.925  1
467840  94.123  -63.120  53.910  1
467841  94.173  -63.138  53.896  1
467842  94.208  -63.140  53.884  1
467843  94.241  -63.145  53.873  1
467844  94.273  -63.148  53.862  1
467845  94.305  -63.153  53.850  1
467846  94.338  -63.158  53.839  1
467847  94.370  -63.161  53.828  1
467848  94.402  -63.166  53.818  1
467849  94.435  -63.170  53.806  1
467850  94.467  -63.174  53.792  1
467851  94.499  -63.179  53.777  1
467852  94.532  -63.183  53.761  1
467853  94.564  -63.187  53.743  1
467854  94.597  -63.192  53.723  1
467855  94.624  -63.205  53.703  1
467856  94.649  -63.220  53.682  1
467857  94.686  -63.220  53.658  1
467858  94.726  -63.217  53.635  1
467859  94.766  -63.214  53.610  1
467860  94.807  -63.211  53.586  1
467861  94.859  -63.214  53.562  1
467862  94.925  -63.224  53.537  1
467863  94.991  -63.233  53.511  1
467864  95.057  -63.243  53.484  1
467865  95.116  -63.246  53.456  1
467866  95.167  -63.238  53.429  1
467867  95.198  -63.226  53.402  1
467868  95.237  -63.233  53.376  1
467869  95.275  -63.239  53.345  1
467870  95.315  -63.256  53.316  1
467871  95.359  -63.289  53.287  1
467872  95.405  -63.314  53.258  1
467873  95.478  -63.222  53.230  1
467874  95.536  -63.163  53.205  1
467875  95.551  -63.187  53.177  1
467876  95.565  -63.212  53.150  1
467877  95.580  -63.237  53.123  1
467878  95.625  -63.243  53.095  1
467879  95.679  -63.244  53.067  1
467880  95.727  -63.250  53.038  1
467881  95.773  -63.257  53.007  1
467882  95.820  -63.264  52.976  1
467883  95.866  -63.270  52.946  1
467884  95.913  -63.277  52.916  1
467885  95.960  -63.283  52.887  1
467886  96.006  -63.289  52.859  1
467887  96.047  -63.296  52.830  1
467888  96.081  -63.299  52.799  1
467889  96.114  -63.303  52.765  1
467890  96.156  -63.299  52.727  1
467891  96.197  -63.296  52.685  1
467892  96.233  -63.309  52.639  1
467893  96.269  -63.322  52.588  1
467894  96.306  -63.335  52.537  1
467895  96.342  -63.348  52.487  1
467896  96.422  -63.341  52.440  1
467897  96.503  -63.333  52.394  1
467898  96.584  -63.326  52.350  1
467899  96.679  -63.317  52.309  1
467900  96.712  -63.330  52.270  1
467901  96.801  -63.339  52.235  1
467902  96.824  -63.342  52.205  1
467903  96.846  -63.343  52.178  1
467904  96.872  -63.351  52.153  1
467905  96.903  -63.363  52.124  1
467906  96.933  -63.375  52.092  1
467907  96.964  -63.386  52.058  1
467908  96.994  -63.399  52.023  1
467909  97.025  -63.411  51.991  1
467910  97.055  -63.423  51.958  1
467911  97.085  -63.435  51.924  1
467912  97.116  -63.447  51.890  1
467913  97.146  -63.459  51.855  1
467914  97.177  -63.471  51.821  1
467915  97.201  -63.480  51.790  1
467916  97.223  -63.486  51.759  1
467917  97.256  -63.492  51.729  1
467918  97.283  -63.498  51.698  1
467919  97.300  -63.508  51.666  1
467920  97.323  -63.518  51.635  1
467921  97.346  -63.529  51.604  1
467922  97.369  -63.540  51.573  1
467923  97.392  -63.550  51.543  1
467924  97.420  -63.556  51.514  1
467925  97.469  -63.540  51.486  1
467926  97.519  -63.524  51.456  1
467927  97.547  -63.529  51.426  1
467928  97.574  -63.534  51.393  1
467929  97.600  -63.540  51.353  1
467930  97.630  -63.546  51.310  1
467931  97.678  -63.560  51.266  1
467932  97.726  -63.575  51.221  1
467933  97.774  -63.590  51.175  1
467934  97.816  -63.593  51.126  1
467935  97.855  -63.591  51.078  1
467936  97.894  -63.589  51.028  1
467937  97.934  -63.587  50.978  1
467938  97.973  -63.584  50.927  1
467939  98.012  -63.582  50.875  1
467940  98.049  -63.582  50.823  1
467941  98.083  -63.584  50.770  1
467942  98.120  -63.584  50.715  1
467943  98.162  -63.580  50.661  1
467944  98.205  -63.575  50.607  1
467945  98.241  -63.576  50.555  1
467946  98.260  -63.590  50.503  1
467947  98.278  -63.603  50.452  1
467948  98.296  -63.618  50.403  1
467949  98.315  -63.631  50.355  1
467950  98.334  -63.645  50.309  1
467951  98.352  -63.659  50.264  1
467952  98.370  -63.673  50.219  1
467953  98.389  -63.687  50.174  1
467954  98.417  -63.694  50.127  1
467955  98.443  -63.695  50.078  1
467956  98.467  -63.694  50.029  1
467957  98.491  -63.694  49.979  1
467958  98.515  -63.688  49.927  1
467959  98.541  -63.675  49.877  1
467960  98.567  -63.663  49.825  1
467961  98.593  -63.650  49.775  1
467962  98.624  -63.644  49.726  1
467963  98.673  -63.643  49.678  1
467964  98.736  -63.641  49.633  1
467965  98.799  -63.639  49.588  1
467966  98.862  -63.637  49.543  1
467967  98.925  -63.635  49.501  1
467968  98.988  -63.634  49.458  1
467969  99.051  -63.632  49.417  1
467970  99.114  -63.630  49.377  1
467971  99.177  -63.628  49.337  1
467972  99.240  -63.626  49.298  1
467973  99.303  -63.625  49.260  1
468379  87.081  -61.768  56.171  1
468380  87.124  -61.766  56.158  1
468381  87.166  -61.764  56.145  1
468382  87.206  -61.764  56.133  1
468383  87.243  -61.766  56.123  1
468384  87.280  -61.768  56.112  1
468385  87.317  -61.769  56.101  1
468386  87.353  -61.771  56.090  1
468387  87.390  -61.773  56.081  1
468388  87.426  -61.775  56.071  1
468389  87.463  -61.777  56.062  1
468390  87.500  -61.779  56.053  1
468391  87.537  -61.780  56.045  1
468392  87.573  -61.782  56.034  1
468393  87.610  -61.784  56.022  1
468394  87.653  -61.783  56.010  1
468395  87.701  -61.779  55.997  1
468396  87.750  -61.776  55.980  1
468397  87.798  -61.773  55.959  1
468398  87.846  -61.769  55.940  1
468399  87.894  -61.766  55.922  1
468400  87.942  -61.763  55.907  1
468401  87.991  -61.760  55.893  1
468402  88.039  -61.756  55.877  1
468403  88.087  -61.753  55.861  1
468404  88.136  -61.749  55.845  1
468405  88.184  -61.746  55.828  1
468406  88.238  -61.745  55.808  1
468407  88.306  -61.752  55.787  1
468408  88.373  -61.758  55.765  1
468409  88.426  -61.771  55.742  1
468410  88.474  -61.787  55.718  1
468411  88.523  -61.802  55.693  1
468412  88.571  -61.817  55.664  1
468413  88.619  -61.832  55.640  1
468414  88.668  -61.848  55.622  1
468415  88.713  -61.865  55.609  1
468416  88.756  -61.882  55.598  1
468417  88.800  -61.901  55.588  1
468418  88.843  -61.918  55.574  1
468419  88.893  -61.950  55.554  1
468420  88.941  -61.978  55.529  1
468421  88.978  -61.979  55.499  1
468422  89.016  -61.981  55.472  1
468423  89.053  -61.983  55.448  1
468424  89.091  -61.984  55.428  1
468425  89.128  -61.986  55.409  1
468426  89.169  -61.994  55.393  1
468427  89.212  -62.003  55.377  1
468428  89.254  -62.013  55.361  1
468429  89.297  -62.022  55.346  1
468430  89.339  -62.032  55.332  1
468431  89.382  -62.042  55.318  1
468432  89.424  -62.051  55.306  1
468433  89.467  -62.061  55.293  1
468434  89.510  -62.070  55.282  1
468435  89.552  -62.080  55.272  1
468436  89.595  -62.089  55.263  1
468437  89.637  -62.098  55.256  1
468438  89.680  -62.108  55.250  1
468439  89.723  -62.118  55.247  1
468440  89.765  -62.127  55.247  1
468441  89.808  -62.137  55.253  1
468442  89.852  -62.154  55.259  1
468443  89.897  -62.175  55.263  1
468444  89.943  -62.196  55.265  1
468445  89.988  -62.218  55.267  1
468446  90.033  -62.239  55.264  1
468447  90.082  -62.257  55.257  1
468448  90.133  -62.269  55.244  1
468449  90.185  -62.282  55.227  1
468450  90.237  -62.294  55.210  1
468451  90.289  -62.307  55.190  1
468452  90.341  -62.320  55.173  1
468453  90.393  -62.332  55.159  1
468454  90.445  -62.345  55.148  1
468455  90.496  -62.358  55.139  1
468456  90.544  -62.371  55.129  1
468457  90.592  -62.385  55.114  1
468458  90.641  -62.399  55.095  1
468459  90.689  -62.413  55.077  1
468460  90.735  -62.426  55.062  1
468461  90.778  -62.436  55.050  1
468462  90.820  -62.446  55.041  1
468463  90.863  -62.456  55.034  1
468464  90.905  -62.465  55.026  1
468465  90.948  -62.475  55.019  1
468466  90.990  -62.484  55.017  1
468467  91.030  -62.493  55.010  1
468468  91.071  -62.503  55.001  1
468469  91.113  -62.512  54.993  1
468470  91.167  -62.524  54.989  1
468471  91.220  -62.535  54.987  1
468472  91.273  -62.547  54.983  1
468473  91.325  -62.558  54.978  1
468474  91.378  -62.570  54.972  1
468475  91.429  -62.582  54.960  1
468476  91.480  -62.594  54.947  1
468477  91.531  -62.606  54.932  1
468478  91.579  -62.621  54.918  1
468479  91.623  -62.638  54.904  1
468480  91.666  -62.656  54.893  1
468481  91.710  -62.673  54.880  1
468482  91.754  -62.691  54.865  1
468483  91.799  -62.701  54.849  1
468484  91.844  -62.713  54.834  1
468485  91.889  -62.724  54.821  1
468486  91.934  -62.735  54.813  1
468487  91.980  -62.746  54.807  1
468488  92.022  -62.753  54.807  1
468489  92.056  -62.750  54.814  1
468490  92.090  -62.745  54.822  1
468491  92.124  -62.741  54.828  1
468492  92.158  -62.737  54.833  1
468493  92.192  -62.732  54.836  1
468494  92.226  -62.728  54.838  1
468495  92.260  -62.724  54.833  1
468496  92.302  -62.727  54.821  1
468497  92.345  -62.731  54.804  1
468498  92.387  -62.735  54.782  1
468499  92.430  -62.738  54.756  1
468500  92.473  -62.741  54.726  1
468501  92.515  -62.745  54.695  1
468502  92.558  -62.748  54.664  1
468503  92.600  -62.752  54.633  1
468504  92.643  -62.756  54.603  1
468505  92.687  -62.758  54.577  1
468506  92.730  -62.760  54.552  1
468507  92.766  -62.766  54.526  1
468508  92.793  -62.778  54.501  1
468509  92.824  -62.789  54.476  1
468510  92.868  -62.801  54.450  1
468511  92.913  -62.813  54.425  1
468512  92.956  -62.822  54.401  1
468513  92.997  -62.822  54.380  1
468514  93.038  -62.821  54.359  1
468515  93.079  -62.821  54.339  1
468516  93.120  -62.820  54.320  1
468517  93.161  -62.820  54.302  1
468518  93.209  -62.814  54.284  1
468519  93.259  -62.826  54.267  1
468520  93.274  -62.832  54.250  1
468521  93.290  -62.841  54.234  1
468522  93.320  -62.860  54.217  1
468523  93.349  -62.860  54.202  1
468524  93.396  -62.879  54.188  1
468525  93.436  -62.892  54.173  1
468526  93.476  -62.905  54.159  1
468527  93.516  -62.918  54.144  1
468528  93.556  -62.932  54.128  1
468529  93.595  -62.945  54.112  1
468530  93.636  -62.957  54.098  1
468531  93.676  -62.971  54.080  1
468532  93.715  -62.984  54.063  1
468533  93.755  -62.997  54.046  1
468534  93.795  -63.010  54.027  1
468535  93.835  -63.023  54.009  1
468536  93.885  -63.024  53.991  1
468537  93.937  -63.024  53.974  1
468538  93.988  -63.025  53.956  1
468539  94.037  -63.041  53.938  1
468540  94.085  -63.057  53.922  1
468541  94.134  -63.073  53.907  1
468542  94.189  -63.098  53.893  1
468543  94.226  -63.092  53.881  1
468544  94.259  -63.095  53.871  1
468545  94.291  -63.100  53.861  1
468546  94.324  -63.104  53.848  1
468547  94.356  -63.108  53.837  1
468548  94.389  -63.113  53.826  1
468549  94.421  -63.117  53.814  1
468550  94.454  -63.121  53.800  1
468551  94.486  -63.126  53.785  1
468552  94.518  -63.130  53.769  1
468553  94.551  -63.135  53.753  1
468554  94.583  -63.139  53.734  1
468555  94.609  -63.153  53.714  1
468556  94.635  -63.168  53.694  1
468557  94.661  -63.184  53.672  1
468558  94.698  -63.183  53.649  1
468559  94.738  -63.180  53.625  1
468560  94.778  -63.177  53.599  1
468561  94.818  -63.173  53.574  1
468562  94.858  -63.170  53.550  1
468563  94.899  -63.166  53.524  1
468564  94.946  -63.167  53.496  1
468565  95.012  -63.177  53.470  1
468566  95.074  -63.183  53.442  1
468567  95.127  -63.180  53.415  1
468568  95.180  -63.177  53.389  1
468569  95.222  -63.195  53.362  1
468570  95.268  -63.221  53.331  1
468571  95.314  -63.242  53.301  1
468572  95.360  -63.262  53.270  1
468573  95.407  -63.280  53.240  1
468574  95.476  -63.198  53.211  1
468575  95.529  -63.143  53.182  1
468576  95.538  -63.166  53.152  1
468577  95.548  -63.189  53.122  1
468578  95.559  -63.212  53.093  1
468579  95.605  -63.218  53.063  1
468580  95.659  -63.219  53.034  1
468581  95.713  -63.220  53.004  1
468582  95.767  -63.220  52.973  1
468583  95.821  -63.221  52.942  1
468584  95.872  -63.225  52.910  1
468585  95.918  -63.231  52.879  1
468586  95.965  -63.238  52.849  1
468587  96.012  -63.245  52.820  1
468588  96.051  -63.250  52.790  1
468589  96.085  -63.254  52.759  1
468590  96.118  -63.258  52.726  1
468591  96.157  -63.257  52.689  1
468592  96.198  -63.253  52.649  1
468593  96.238  -63.255  52.605  1
468594  96.274  -63.267  52.559  1
468595  96.311  -63.280  52.510  1
468596  96.347  -63.293  52.461  1
468597  96.383  -63.306  52.414  1
468598  96.469  -63.302  52.368  1
468599  96.592  -63.286  52.322  1
468600  96.643  -63.292  52.281  1
468601  96.721  -63.304  52.241  1
468602  96.810  -63.314  52.205  1
468603  96.836  -63.319  52.174  1
468604  96.860  -63.322  52.146  1
468605  96.882  -63.324  52.120  1
468606  96.912  -63.335  52.093  1
468607  96.942  -63.347  52.062  1
468608  96.973  -63.359  52.029  1
468609  97.003  -63.371  51.994  1
468610  97.034  -63.383  51.962  1
468611  97.064  -63.395  51.929  1
468612  97.095  -63.407  51.895  1
468613  97.125  -63.419  51.861  1
468614  97.151  -63.429  51.826  1
468615  97.171  -63.435  51.792  1
468616  97.192  -63.442  51.761  1
468617  97.226  -63.447  51.729  1
468618  97.259  -63.453  51.697  1
468619  97.288  -63.459  51.665  1
468620  97.299  -63.467  51.632  1
468621  97.322  -63.478  51.600  1
468622  97.345  -63.489  51.569  1
468623  97.367  -63.499  51.538  1
468624  97.390  -63.510  51.508  1
468625  97.430  -63.505  51.480  1
468626  97.479  -63.489  51.451  1
468627  97.529  -63.473  51.422  1
468628  97.557  -63.477  51.391  1
468629  97.584  -63.482  51.360  1
468630  97.610  -63.487  51.322  1
468631  97.638  -63.493  51.282  1
468632  97.672  -63.501  51.240  1
468633  97.720  -63.516  51.196  1
468634  97.768  -63.531  51.150  1
468635  97.816  -63.546  51.101  1
468636  97.862  -63.556  51.053  1
468637  97.901  -63.553  51.004  1
468638  97.940  -63.551  50.955  1
468639  97.980  -63.549  50.904  1
468640  98.019  -63.547  50.853  1
468641  98.056  -63.546  50.800  1
468642  98.091  -63.548  50.746  1
468643  98.130  -63.546  50.690  1
468644  98.172  -63.542  50.635  1
468645  98.215  -63.537  50.582  1
468646  98.252  -63.537  50.530  1
468647  98.271  -63.551  50.479  1
468648  98.289  -63.565  50.428  1
468649  98.307  -63.579  50.378  1
468650  98.326  -63.593  50.332  1
468651  98.345  -63.606  50.287  1
468652  98.363  -63.621  50.243  1
468653  98.381  -63.634  50.198  1
468654  98.400  -63.648  50.152  1
468655  98.419  -63.662  50.105  1
468656  98.442  -63.672  50.058  1
468657  98.465  -63.669  50.008  1
468658  98.492  -63.657  49.958  1
468659  98.518  -63.644  49.905  1
468660  98.544  -63.632  49.854  1
468661  98.570  -63.619  49.802  1
468662  98.596  -63.607  49.752  1
468663  98.630  -63.607  49.704  1
468664  98.682  -63.604  49.658  1
468665  98.745  -63.602  49.614  1
468666  98.808  -63.600  49.570  1
468667  98.871  -63.599  49.527  1
468668  98.934  -63.596  49.486  1
468669  98.997  -63.595  49.444  1
468670  99.060  -63.593  49.404  1
468671  99.123  -63.591  49.364  1
468672  99.186  -63.590  49.326  1
468673  99.249  -63.587  49.288  1
469080  87.097  -61.719  56.170  1
469081  87.140  -61.717  56.156  1
469082  87.183  -61.716  56.142  1
469083  87.221  -61.716  56.131  1
469084  87.258  -61.718  56.120  1
469085  87.295  -61.720  56.109  1
469086  87.332  -61.722  56.098  1
469087  87.368  -61.723  56.088  1
469088  87.405  -61.726  56.077  1
469089  87.441  -61.727  56.068  1
469090  87.478  -61.729  56.059  1
469091  87.515  -61.731  56.051  1
469092  87.552  -61.732  56.043  1
469093  87.588  -61.735  56.032  1
469094  87.625  -61.736  56.020  1
469095  87.662  -61.738  56.007  1
469096  87.711  -61.734  55.995  1
469097  87.759  -61.731  55.978  1
469098  87.808  -61.728  55.958  1
469099  87.855  -61.724  55.939  1
469100  87.904  -61.721  55.922  1
469101  87.952  -61.717  55.907  1
469102  88.000  -61.714  55.892  1
469103  88.049  -61.710  55.878  1
469104  88.097  -61.707  55.863  1
469105  88.145  -61.704  55.848  1
469106  88.193  -61.700  55.832  1
469107  88.249  -61.701  55.813  1
469108  88.317  -61.707  55.791  1
469109  88.384  -61.713  55.767  1
469110  88.442  -61.724  55.742  1
469111  88.491  -61.739  55.717  1
469112  88.539  -61.755  55.690  1
469113  88.588  -61.770  55.662  1
469114  88.636  -61.785  55.641  1
469115  88.684  -61.801  55.625  1
469116  88.729  -61.818  55.612  1
469117  88.772  -61.836  55.603  1
469118  88.815  -61.854  55.594  1
469119  88.860  -61.879  55.580  1
469120  88.910  -61.912  55.560  1
469121  88.955  -61.935  55.534  1
469122  88.993  -61.936  55.501  1
469123  89.030  -61.938  55.472  1
469124  89.068  -61.940  55.446  1
469125  89.105  -61.942  55.425  1
469126  89.142  -61.943  55.405  1
469127  89.180  -61.945  55.389  1
469128  89.222  -61.953  55.373  1
469129  89.264  -61.962  55.357  1
469130  89.307  -61.972  55.342  1
469131  89.349  -61.982  55.327  1
469132  89.392  -61.991  55.313  1
469133  89.435  -62.001  55.301  1
469134  89.477  -62.010  55.289  1
469135  89.520  -62.020  55.278  1
469136  89.562  -62.029  55.267  1
469137  89.605  -62.039  55.259  1
469138  89.648  -62.048  55.252  1
469139  89.690  -62.058  55.246  1
469140  89.733  -62.067  55.243  1
469141  89.775  -62.077  55.244  1
469142  89.818  -62.086  55.250  1
469143  89.863  -62.105  55.258  1
469144  89.908  -62.127  55.264  1
469145  89.953  -62.148  55.268  1
469146  89.999  -62.169  55.269  1
469147  90.044  -62.190  55.268  1
469148  90.089  -62.211  55.263  1
469149  90.141  -62.224  55.251  1
469150  90.193  -62.236  55.235  1
469151  90.245  -62.249  55.218  1
469152  90.297  -62.262  55.197  1
469153  90.349  -62.274  55.179  1
469154  90.401  -62.287  55.162  1
469155  90.453  -62.299  55.145  1
469156  90.505  -62.312  55.132  1
469157  90.556  -62.324  55.117  1
469158  90.605  -62.339  55.101  1
469159  90.653  -62.352  55.084  1
469160  90.701  -62.366  55.069  1
469161  90.750  -62.381  55.057  1
469162  90.793  -62.390  55.048  1
469163  90.835  -62.400  55.042  1
469164  90.878  -62.410  55.037  1
469165  90.921  -62.420  55.031  1
469166  90.962  -62.430  55.025  1
469167  91.003  -62.439  55.023  1
469168  91.043  -62.448  55.015  1
469169  91.084  -62.457  55.007  1
469170  91.125  -62.467  55.001  1
469171  91.175  -62.478  55.000  1
469172  91.228  -62.489  54.998  1
469173  91.281  -62.500  54.995  1
469174  91.333  -62.512  54.992  1
469175  91.384  -62.525  54.984  1
469176  91.435  -62.537  54.969  1
469177  91.486  -62.549  54.952  1
469178  91.537  -62.561  54.938  1
469179  91.582  -62.578  54.926  1
469180  91.626  -62.595  54.914  1
469181  91.669  -62.612  54.906  1
469182  91.713  -62.630  54.897  1
469183  91.757  -62.647  54.882  1
469184  91.801  -62.664  54.864  1
469185  91.846  -62.675  54.845  1
469186  91.891  -62.686  54.829  1
469187  91.936  -62.697  54.817  1
469188  91.982  -62.708  54.809  1
469189  92.026  -62.719  54.806  1
469190  92.060  -62.715  54.809  1
469191  92.094  -62.710  54.815  1
469192  92.128  -62.706  54.820  1
469193  92.162  -62.702  54.822  1
469194  92.196  -62.697  54.823  1
469195  92.230  -62.694  54.822  1
469196  92.264  -62.689  54.816  1
469197  92.299  -62.686  54.803  1
469198  92.342  -62.690  54.785  1
469199  92.384  -62.693  54.763  1
469200  92.427  -62.697  54.736  1
469201  92.470  -62.700  54.707  1
469202  92.512  -62.703  54.676  1
469203  92.555  -62.707  54.645  1
469204  92.597  -62.711  54.615  1
469205  92.640  -62.714  54.587  1
469206  92.684  -62.716  54.562  1
469207  92.727  -62.717  54.539  1
469208  92.769  -62.720  54.515  1
469209  92.796  -62.732  54.490  1
469210  92.832  -62.744  54.465  1
469211  92.876  -62.756  54.439  1
469212  92.919  -62.763  54.414  1
469213  92.960  -62.763  54.391  1
469214  93.001  -62.763  54.369  1
469215  93.043  -62.762  54.349  1
469216  93.083  -62.762  54.329  1
469217  93.125  -62.761  54.310  1
469218  93.165  -62.761  54.293  1
469219  93.208  -62.761  54.275  1
469220  93.235  -62.779  54.258  1
469221  93.266  -62.799  54.241  1
469222  93.295  -62.819  54.225  1
469223  93.325  -62.832  54.210  1
469224  93.347  -62.817  54.196  1
469225  93.390  -62.831  54.182  1
469226  93.437  -62.850  54.167  1
469227  93.484  -62.869  54.153  1
469228  93.524  -62.882  54.139  1
469229  93.564  -62.895  54.124  1
469230  93.604  -62.908  54.107  1
469231  93.644  -62.922  54.093  1
469232  93.684  -62.935  54.077  1
469233  93.724  -62.948  54.060  1
469234  93.764  -62.961  54.042  1
469235  93.803  -62.974  54.024  1
469236  93.843  -62.987  54.006  1
469237  93.895  -62.987  53.988  1
469238  93.946  -62.987  53.970  1
469239  93.998  -62.987  53.953  1
469240  94.048  -62.994  53.936  1
469241  94.097  -63.010  53.919  1
469242  94.151  -63.037  53.904  1
469243  94.205  -63.057  53.891  1
469244  94.246  -63.042  53.879  1
469245  94.278  -63.047  53.868  1
469246  94.310  -63.051  53.858  1
469247  94.342  -63.055  53.845  1
469248  94.375  -63.060  53.834  1
469249  94.407  -63.064  53.822  1
469250  94.439  -63.068  53.808  1
469251  94.472  -63.073  53.794  1
469252  94.504  -63.077  53.779  1
469253  94.537  -63.082  53.762  1
469254  94.569  -63.086  53.745  1
469255  94.595  -63.101  53.726  1
469256  94.620  -63.117  53.706  1
469257  94.646  -63.133  53.685  1
469258  94.672  -63.148  53.663  1
469259  94.710  -63.146  53.640  1
469260  94.750  -63.142  53.615  1
469261  94.790  -63.139  53.589  1
469262  94.830  -63.136  53.563  1
469263  94.871  -63.133  53.537  1
469264  94.910  -63.129  53.511  1
469265  94.951  -63.125  53.482  1
469266  94.990  -63.122  53.456  1
469267  95.032  -63.120  53.429  1
469268  95.102  -63.128  53.403  1
469269  95.173  -63.139  53.377  1
469270  95.240  -63.151  53.349  1
469271  95.295  -63.160  53.318  1
469272  95.338  -63.148  53.286  1
469273  95.382  -63.138  53.255  1
469274  95.426  -63.142  53.223  1
469275  95.473  -63.164  53.192  1
469276  95.524  -63.126  53.160  1
469277  95.533  -63.148  53.127  1
469278  95.558  -63.176  53.095  1
469279  95.575  -63.194  53.064  1
469280  95.608  -63.180  53.033  1
469281  95.658  -63.173  53.003  1
469282  95.709  -63.177  52.972  1
469283  95.760  -63.181  52.940  1
469284  95.811  -63.186  52.907  1
469285  95.862  -63.189  52.875  1
469286  95.912  -63.194  52.842  1
469287  95.964  -63.198  52.811  1
469288  96.017  -63.199  52.780  1
469289  96.056  -63.204  52.751  1
469290  96.095  -63.205  52.719  1
469291  96.127  -63.211  52.685  1
469292  96.150  -63.224  52.649  1
469293  96.195  -63.216  52.611  1
469294  96.240  -63.208  52.570  1
469295  96.285  -63.214  52.528  1
469296  96.330  -63.227  52.482  1
469297  96.376  -63.240  52.434  1
469298  96.422  -63.254  52.387  1
469299  96.486  -63.260  52.342  1
469300  96.575  -63.253  52.296  1
469301  96.653  -63.265  52.254  1
469302  96.732  -63.278  52.214  1
469303  96.819  -63.289  52.177  1
469304  96.846  -63.294  52.144  1
469305  96.872  -63.299  52.115  1
469306  96.896  -63.302  52.088  1
469307  96.921  -63.308  52.062  1
469308  96.952  -63.320  52.033  1
469309  96.982  -63.332  52.001  1
469310  97.012  -63.343  51.968  1
469311  97.043  -63.355  51.934  1
469312  97.073  -63.368  51.900  1
469313  97.100  -63.377  51.867  1
469314  97.120  -63.384  51.833  1
469315  97.140  -63.391  51.798  1
469316  97.162  -63.398  51.764  1
469317  97.195  -63.403  51.732  1
469318  97.229  -63.408  51.699  1
469319  97.262  -63.415  51.666  1
469320  97.294  -63.421  51.633  1
469321  97.302  -63.428  51.600  1
469322  97.320  -63.437  51.567  1
469323  97.343  -63.448  51.536  1
469324  97.366  -63.459  51.505  1
469325  97.389  -63.469  51.477  1
469326  97.439  -63.453  51.447  1
469327  97.489  -63.437  51.417  1
469328  97.539  -63.421  51.387  1
469329  97.567  -63.425  51.356  1
469330  97.594  -63.430  51.325  1
469331  97.620  -63.436  51.290  1
469332  97.648  -63.441  51.253  1
469333  97.674  -63.446  51.212  1
469334  97.715  -63.457  51.168  1
469335  97.762  -63.472  51.123  1
469336  97.811  -63.487  51.074  1
469337  97.859  -63.502  51.027  1
469338  97.907  -63.516  50.979  1
469339  97.947  -63.516  50.930  1
469340  97.987  -63.514  50.880  1
469341  98.026  -63.512  50.829  1
469342  98.064  -63.511  50.774  1
469343  98.098  -63.512  50.717  1
469344  98.140  -63.509  50.660  1
469345  98.182  -63.504  50.605  1
469346  98.225  -63.499  50.553  1
469347  98.263  -63.499  50.502  1
469348  98.281  -63.512  50.451  1
469349  98.300  -63.527  50.401  1
469350  98.318  -63.540  50.353  1
469351  98.337  -63.554  50.308  1
469352  98.356  -63.568  50.264  1
469353  98.374  -63.582  50.219  1
469354  98.392  -63.596  50.174  1
469355  98.411  -63.610  50.127  1
469356  98.427  -63.624  50.081  1
469357  98.442  -63.638  50.033  1
469358  98.468  -63.625  49.984  1
469359  98.494  -63.613  49.934  1
469360  98.520  -63.600  49.883  1
469361  98.546  -63.588  49.830  1
469362  98.572  -63.575  49.779  1
469363  98.599  -63.565  49.729  1
469364  98.636  -63.570  49.682  1
469365  98.691  -63.565  49.638  1
469366  98.754  -63.563  49.595  1
469367  98.816  -63.562  49.553  1
469368  98.879  -63.559  49.511  1
469369  98.942  -63.558  49.470  1
469370  99.005  -63.556  49.429  1
469371  99.068  -63.554  49.390  1
469372  99.131  -63.553  49.352  1
469373  99.194  -63.550  49.314  1
469374  99.257  -63.549  49.276  1
469782  87.156  -61.669  56.154  1
469783  87.199  -61.667  56.140  1
469784  87.236  -61.669  56.129  1
469785  87.273  -61.670  56.117  1
469786  87.310  -61.672  56.106  1
469787  87.347  -61.674  56.095  1
469788  87.383  -61.675  56.085  1
469789  87.420  -61.677  56.074  1
469790  87.457  -61.679  56.064  1
469791  87.494  -61.681  56.055  1
469792  87.530  -61.683  56.047  1
469793  87.567  -61.685  56.039  1
469794  87.604  -61.686  56.028  1
469795  87.640  -61.688  56.015  1
469796  87.677  -61.690  56.003  1
469797  87.720  -61.689  55.990  1
469798  87.769  -61.685  55.974  1
469799  87.817  -61.682  55.954  1
469800  87.865  -61.678  55.937  1
469801  87.913  -61.675  55.921  1
469802  87.962  -61.672  55.905  1
469803  88.010  -61.669  55.890  1
469804  88.058  -61.666  55.877  1
469805  88.107  -61.662  55.864  1
469806  88.154  -61.659  55.850  1
469807  88.203  -61.655  55.835  1
469808  88.260  -61.657  55.816  1
469809  88.328  -61.663  55.794  1
469810  88.395  -61.669  55.768  1
469811  88.460  -61.677  55.741  1
469812  88.508  -61.692  55.715  1
469813  88.556  -61.707  55.689  1
469814  88.605  -61.723  55.661  1
469815  88.652  -61.738  55.638  1
469816  88.701  -61.754  55.622  1
469817  88.744  -61.772  55.610  1
469818  88.787  -61.789  55.603  1
469819  88.831  -61.810  55.594  1
469820  88.877  -61.841  55.580  1
469821  88.926  -61.874  55.560  1
469822  88.970  -61.892  55.535  1
469823  89.008  -61.894  55.502  1
469824  89.045  -61.895  55.471  1
469825  89.083  -61.897  55.443  1
469826  89.120  -61.898  55.421  1
469827  89.158  -61.900  55.400  1
469828  89.195  -61.901  55.383  1
469829  89.233  -61.903  55.368  1
469830  89.274  -61.912  55.352  1
469831  89.317  -61.921  55.336  1
469832  89.359  -61.931  55.321  1
469833  89.402  -61.941  55.307  1
469834  89.445  -61.950  55.295  1
469835  89.487  -61.960  55.284  1
469836  89.530  -61.969  55.273  1
469837  89.573  -61.979  55.263  1
469838  89.615  -61.989  55.254  1
469839  89.658  -61.998  55.247  1
469840  89.700  -62.008  55.241  1
469841  89.743  -62.017  55.237  1
469842  89.785  -62.026  55.237  1
469843  89.828  -62.036  55.242  1
469844  89.873  -62.057  55.250  1
469845  89.918  -62.078  55.257  1
469846  89.964  -62.099  55.262  1
469847  90.009  -62.120  55.265  1
469848  90.054  -62.142  55.266  1
469849  90.100  -62.163  55.262  1
469850  90.149  -62.179  55.254  1
469851  90.201  -62.192  55.242  1
469852  90.253  -62.204  55.223  1
469853  90.305  -62.217  55.203  1
469854  90.357  -62.230  55.185  1
469855  90.408  -62.242  55.166  1
469856  90.460  -62.255  55.145  1
469857  90.512  -62.267  55.127  1
469858  90.565  -62.280  55.108  1
469859  90.616  -62.292  55.091  1
469860  90.666  -62.305  55.075  1
469861  90.714  -62.320  55.063  1
469862  90.762  -62.333  55.054  1
469863  90.807  -62.345  55.047  1
469864  90.850  -62.355  55.043  1
469865  90.892  -62.365  55.040  1
469866  90.935  -62.374  55.036  1
469867  90.976  -62.384  55.030  1
469868  91.017  -62.393  55.026  1
469869  91.057  -62.402  55.019  1
469870  91.098  -62.412  55.013  1
469871  91.138  -62.421  55.010  1
469872  91.184  -62.431  55.011  1
469873  91.237  -62.443  55.009  1
469874  91.288  -62.455  55.007  1
469875  91.338  -62.467  55.002  1
469876  91.390  -62.479  54.993  1
469877  91.441  -62.491  54.977  1
469878  91.492  -62.503  54.960  1
469879  91.540  -62.517  54.947  1
469880  91.585  -62.534  54.937  1
469881  91.629  -62.552  54.928  1
469882  91.672  -62.569  54.922  1
469883  91.716  -62.586  54.917  1
469884  91.760  -62.603  54.903  1
469885  91.804  -62.621  54.882  1
469886  91.848  -62.637  54.858  1
469887  91.893  -62.648  54.838  1
469888  91.938  -62.659  54.822  1
469889  91.984  -62.670  54.811  1
469890  92.028  -62.681  54.805  1
469891  92.065  -62.680  54.803  1
469892  92.098  -62.675  54.807  1
469893  92.132  -62.672  54.810  1
469894  92.166  -62.667  54.810  1
469895  92.200  -62.663  54.809  1
469896  92.234  -62.659  54.805  1
469897  92.268  -62.654  54.797  1
469898  92.302  -62.650  54.784  1
469899  92.339  -62.648  54.765  1
469900  92.381  -62.652  54.743  1
469901  92.424  -62.655  54.717  1
469902  92.466  -62.659  54.687  1
469903  92.509  -62.663  54.658  1
469904  92.552  -62.666  54.629  1
469905  92.594  -62.669  54.600  1
469906  92.638  -62.672  54.574  1
469907  92.681  -62.673  54.551  1
469908  92.725  -62.675  54.528  1
469909  92.769  -62.677  54.505  1
469910  92.799  -62.686  54.481  1
469911  92.840  -62.698  54.455  1
469912  92.882  -62.704  54.428  1
469913  92.924  -62.703  54.404  1
469914  92.965  -62.703  54.382  1
469915  93.006  -62.703  54.361  1
469916  93.047  -62.703  54.341  1
469917  93.089  -62.706  54.323  1
469918  93.133  -62.711  54.304  1
469919  93.176  -62.716  54.286  1
469920  93.212  -62.735  54.269  1
469921  93.241  -62.757  54.252  1
469922  93.271  -62.776  54.235  1
469923  93.301  -62.796  54.219  1
469924  93.327  -62.797  54.204  1
469925  93.349  -62.782  54.191  1
469926  93.383  -62.782  54.176  1
469927  93.431  -62.802  54.163  1
469928  93.479  -62.822  54.149  1
469929  93.526  -62.841  54.134  1
469930  93.572  -62.859  54.119  1
469931  93.613  -62.873  54.103  1
469932  93.652  -62.885  54.088  1
469933  93.692  -62.898  54.073  1
469934  93.732  -62.912  54.055  1
469935  93.772  -62.925  54.038  1
469936  93.812  -62.938  54.020  1
469937  93.852  -62.950  54.002  1
469938  93.904  -62.950  53.984  1
469939  93.956  -62.950  53.966  1
469940  94.007  -62.950  53.949  1
469941  94.059  -62.949  53.933  1
469942  94.112  -62.972  53.916  1
469943  94.168  -63.001  53.902  1
469944  94.220  -63.015  53.888  1
469945  94.264  -62.994  53.876  1
469946  94.296  -62.998  53.864  1
469947  94.329  -63.002  53.852  1
469948  94.361  -63.007  53.840  1
469949  94.394  -63.011  53.828  1
469950  94.426  -63.016  53.815  1
469951  94.459  -63.020  53.801  1
469952  94.491  -63.024  53.787  1
469953  94.523  -63.029  53.770  1
469954  94.555  -63.034  53.754  1
469955  94.580  -63.049  53.736  1
469956  94.606  -63.065  53.717  1
469957  94.631  -63.080  53.695  1
469958  94.657  -63.096  53.674  1
469959  94.683  -63.111  53.652  1
469960  94.722  -63.108  53.628  1
469961  94.762  -63.105  53.603  1
469962  94.802  -63.101  53.577  1
469963  94.842  -63.098  53.550  1
469964  94.882  -63.095  53.523  1
469965  94.922  -63.092  53.497  1
469966  94.963  -63.088  53.469  1
469967  95.002  -63.085  53.442  1
469968  95.046  -63.094  53.417  1
469969  95.102  -63.095  53.393  1
469970  95.173  -63.106  53.368  1
469971  95.244  -63.116  53.338  1
469972  95.306  -63.131  53.307  1
469973  95.365  -63.148  53.273  1
469974  95.414  -63.148  53.240  1
469975  95.458  -63.137  53.207  1
469976  95.501  -63.126  53.173  1
469977  95.545  -63.116  53.139  1
469978  95.570  -63.144  53.104  1
469979  95.597  -63.171  53.070  1
469980  95.590  -63.163  53.037  1
469981  95.621  -63.149  53.004  1
469982  95.671  -63.140  52.973  1
469983  95.721  -63.132  52.941  1
469984  95.771  -63.123  52.907  1
469985  95.822  -63.126  52.873  1
469986  95.873  -63.130  52.840  1
469987  95.923  -63.135  52.806  1
469988  95.974  -63.139  52.773  1
469989  96.025  -63.142  52.742  1
469990  96.074  -63.151  52.711  1
469991  96.113  -63.153  52.678  1
469992  96.133  -63.167  52.645  1
469993  96.155  -63.182  52.609  1
469994  96.185  -63.187  52.573  1
469995  96.271  -63.228  52.535  1
469996  96.315  -63.180  52.497  1
469997  96.363  -63.181  52.453  1
469998  96.412  -63.192  52.406  1
469999  96.462  -63.203  52.360  1
470000  96.511  -63.214  52.315  1
470001  96.586  -63.227  52.271  1
470002  96.664  -63.239  52.228  1
470003  96.742  -63.252  52.188  1
470004  96.828  -63.264  52.150  1
470005  96.855  -63.268  52.115  1
470006  96.881  -63.274  52.085  1
470007  96.908  -63.279  52.058  1
470008  96.932  -63.283  52.032  1
470009  96.961  -63.292  52.004  1
470010  96.991  -63.304  51.974  1
470011  97.022  -63.316  51.942  1
470012  97.049  -63.327  51.907  1
470013  97.070  -63.333  51.874  1
470014  97.090  -63.340  51.841  1
470015  97.109  -63.346  51.807  1
470016  97.132  -63.353  51.773  1
470017  97.165  -63.359  51.738  1
470018  97.198  -63.365  51.704  1
470019  97.232  -63.370  51.670  1
470020  97.265  -63.376  51.636  1
470021  97.298  -63.381  51.602  1
470022  97.308  -63.389  51.569  1
470023  97.319  -63.397  51.536  1
470024  97.342  -63.408  51.504  1
470025  97.364  -63.418  51.474  1
470026  97.399  -63.417  51.444  1
470027  97.449  -63.401  51.414  1
470028  97.499  -63.386  51.383  1
470029  97.549  -63.370  51.352  1
470030  97.577  -63.374  51.320  1
470031  97.604  -63.379  51.288  1
470032  97.631  -63.383  51.254  1
470033  97.658  -63.389  51.219  1
470034  97.684  -63.394  51.180  1
470035  97.711  -63.399  51.138  1
470036  97.757  -63.413  51.093  1
470037  97.805  -63.427  51.046  1
470038  97.853  -63.443  50.998  1
470039  97.901  -63.457  50.950  1
470040  97.949  -63.472  50.901  1
470041  97.993  -63.479  50.848  1
470042  98.032  -63.477  50.795  1
470043  98.071  -63.475  50.740  1
470044  98.107  -63.474  50.683  1
470045  98.150  -63.471  50.626  1
470046  98.193  -63.466  50.571  1
470047  98.235  -63.462  50.518  1
470048  98.274  -63.460  50.466  1
470049  98.292  -63.474  50.415  1
470050  98.311  -63.488  50.366  1
470051  98.329  -63.502  50.321  1
470052  98.348  -63.516  50.274  1
470053  98.367  -63.530  50.230  1
470054  98.385  -63.543  50.185  1
470055  98.398  -63.559  50.141  1
470056  98.409  -63.574  50.096  1
470057  98.420  -63.588  50.049  1
470058  98.444  -63.594  50.000  1
470059  98.471  -63.582  49.950  1
470060  98.496  -63.569  49.900  1
470061  98.522  -63.557  49.850  1
470062  98.549  -63.544  49.801  1
470063  98.574  -63.532  49.753  1
470064  98.605  -63.528  49.706  1
470065  98.642  -63.532  49.661  1
470066  98.699  -63.526  49.619  1
470067  98.762  -63.524  49.576  1
470068  98.825  -63.523  49.534  1
470069  98.888  -63.521  49.494  1
470070  98.951  -63.519  49.455  1
470071  99.014  -63.517  49.415  1
470072  99.077  -63.515  49.376  1
470073  99.140  -63.514  49.339  1
470074  99.203  -63.512  49.302  1
470483  87.173  -61.620  56.151  1
470484  87.215  -61.619  56.137  1
470485  87.252  -61.620  56.126  1
470486  87.289  -61.622  56.114  1
470487  87.325  -61.624  56.102  1
470488  87.362  -61.626  56.092  1
470489  87.399  -61.628  56.081  1
470490  87.435  -61.629  56.070  1
470491  87.472  -61.632  56.060  1
470492  87.509  -61.633  56.050  1
470493  87.546  -61.635  56.042  1
470494  87.582  -61.637  56.033  1
470495  87.619  -61.638  56.022  1
470496  87.655  -61.641  56.009  1
470497  87.692  -61.642  55.996  1
470498  87.730  -61.644  55.984  1
470499  87.778  -61.640  55.968  1
470500  87.826  -61.637  55.950  1
470501  87.874  -61.634  55.932  1
470502  87.923  -61.630  55.915  1
470503  87.971  -61.627  55.899  1
470504  88.020  -61.623  55.885  1
470505  88.068  -61.620  55.873  1
470506  88.116  -61.616  55.861  1
470507  88.164  -61.613  55.849  1
470508  88.212  -61.610  55.836  1
470509  88.271  -61.612  55.819  1
470510  88.338  -61.618  55.796  1
470511  88.406  -61.625  55.769  1
470512  88.473  -61.631  55.740  1
470513  88.525  -61.645  55.713  1
470514  88.573  -61.660  55.686  1
470515  88.621  -61.675  55.658  1
470516  88.670  -61.691  55.634  1
470517  88.716  -61.707  55.618  1
470518  88.759  -61.725  55.607  1
470519  88.803  -61.743  55.600  1
470520  88.848  -61.772  55.590  1
470521  88.894  -61.804  55.577  1
470522  88.943  -61.836  55.557  1
470523  88.985  -61.849  55.533  1
470524  89.023  -61.851  55.502  1
470525  89.060  -61.852  55.471  1
470526  89.097  -61.854  55.442  1
470527  89.135  -61.855  55.417  1
470528  89.172  -61.857  55.396  1
470529  89.210  -61.859  55.378  1
470530  89.247  -61.860  55.361  1
470531  89.285  -61.862  55.345  1
470532  89.327  -61.871  55.330  1
470533  89.370  -61.880  55.314  1
470534  89.412  -61.890  55.301  1
470535  89.455  -61.900  55.289  1
470536  89.497  -61.909  55.278  1
470537  89.540  -61.919  55.267  1
470538  89.582  -61.929  55.258  1
470539  89.625  -61.938  55.249  1
470540  89.667  -61.948  55.242  1
470541  89.710  -61.957  55.236  1
470542  89.753  -61.967  55.232  1
470543  89.795  -61.976  55.230  1
470544  89.838  -61.987  55.233  1
470545  89.883  -62.008  55.240  1
470546  89.929  -62.029  55.246  1
470547  89.974  -62.051  55.252  1
470548  90.019  -62.072  55.255  1
470549  90.065  -62.093  55.258  1
470550  90.110  -62.114  55.257  1
470551  90.157  -62.134  55.253  1
470552  90.209  -62.146  55.243  1
470553  90.261  -62.159  55.227  1
470554  90.313  -62.172  55.208  1
470555  90.365  -62.184  55.190  1
470556  90.416  -62.197  55.171  1
470557  90.468  -62.209  55.149  1
470558  90.520  -62.222  55.125  1
470559  90.572  -62.234  55.103  1
470560  90.624  -62.247  55.085  1
470561  90.676  -62.260  55.070  1
470562  90.727  -62.273  55.059  1
470563  90.775  -62.287  55.052  1
470564  90.822  -62.300  55.048  1
470565  90.865  -62.310  55.046  1
470566  90.907  -62.320  55.045  1
470567  90.949  -62.329  55.041  1
470568  90.990  -62.339  55.035  1
470569  91.030  -62.348  55.029  1
470570  91.071  -62.357  55.023  1
470571  91.111  -62.366  55.019  1
470572  91.152  -62.375  55.018  1
470573  91.192  -62.385  55.020  1
470574  91.242  -62.397  55.018  1
470575  91.293  -62.409  55.015  1
470576  91.345  -62.421  55.009  1
470577  91.395  -62.434  54.998  1
470578  91.446  -62.446  54.983  1
470579  91.498  -62.458  54.969  1
470580  91.543  -62.474  54.957  1
470581  91.587  -62.491  54.948  1
470582  91.632  -62.508  54.944  1
470583  91.675  -62.525  54.939  1
470584  91.719  -62.543  54.936  1
470585  91.763  -62.560  54.924  1
470586  91.807  -62.578  54.903  1
470587  91.851  -62.595  54.876  1
470588  91.895  -62.610  54.850  1
470589  91.940  -62.622  54.830  1
470590  91.986  -62.633  54.814  1
470591  92.030  -62.644  54.803  1
470592  92.069  -62.645  54.798  1
470593  92.102  -62.641  54.798  1
470594  92.136  -62.637  54.798  1
470595  92.170  -62.632  54.797  1
470596  92.204  -62.628  54.793  1
470597  92.238  -62.624  54.788  1
470598  92.272  -62.619  54.778  1
470599  92.306  -62.616  54.763  1
470600  92.340  -62.611  54.744  1
470601  92.378  -62.610  54.722  1
470602  92.420  -62.614  54.697  1
470603  92.463  -62.617  54.669  1
470604  92.506  -62.621  54.641  1
470605  92.548  -62.625  54.614  1
470606  92.591  -62.627  54.587  1
470607  92.635  -62.629  54.561  1
470608  92.678  -62.631  54.539  1
470609  92.722  -62.632  54.517  1
470610  92.766  -62.634  54.494  1
470611  92.803  -62.640  54.470  1
470612  92.846  -62.645  54.445  1
470613  92.887  -62.645  54.419  1
470614  92.930  -62.649  54.396  1
470615  92.973  -62.653  54.375  1
470616  93.016  -62.658  54.355  1
470617  93.060  -62.663  54.336  1
470618  93.103  -62.668  54.319  1
470619  93.146  -62.672  54.301  1
470620  93.190  -62.677  54.283  1
470621  93.219  -62.709  54.267  1
470622  93.247  -62.735  54.251  1
470623  93.277  -62.754  54.234  1
470624  93.307  -62.774  54.219  1
470625  93.330  -62.761  54.204  1
470626  93.352  -62.746  54.189  1
470627  93.377  -62.734  54.174  1
470628  93.425  -62.753  54.160  1
470629  93.473  -62.773  54.145  1
470630  93.520  -62.793  54.130  1
470631  93.568  -62.812  54.114  1
470632  93.615  -62.832  54.099  1
470633  93.660  -62.849  54.083  1
470634  93.701  -62.863  54.067  1
470635  93.741  -62.876  54.050  1
470636  93.780  -62.888  54.032  1
470637  93.820  -62.902  54.016  1
470638  93.862  -62.913  53.998  1
470639  93.913  -62.913  53.980  1
470640  93.965  -62.913  53.963  1
470641  94.016  -62.912  53.946  1
470642  94.073  -62.920  53.929  1
470643  94.129  -62.935  53.913  1
470644  94.184  -62.964  53.898  1
470645  94.236  -62.973  53.884  1
470646  94.281  -62.948  53.871  1
470647  94.315  -62.950  53.858  1
470648  94.347  -62.954  53.846  1
470649  94.380  -62.958  53.833  1
470650  94.412  -62.963  53.821  1
470651  94.445  -62.967  53.808  1
470652  94.477  -62.971  53.793  1
470653  94.509  -62.976  53.778  1
470654  94.541  -62.982  53.761  1
470655  94.566  -62.998  53.743  1
470656  94.592  -63.013  53.725  1
470657  94.617  -63.029  53.705  1
470658  94.642  -63.044  53.683  1
470659  94.668  -63.060  53.662  1
470660  94.694  -63.074  53.639  1
470661  94.734  -63.071  53.614  1
470662  94.774  -63.067  53.589  1
470663  94.814  -63.064  53.563  1
470664  94.854  -63.061  53.536  1
470665  94.894  -63.057  53.509  1
470666  94.934  -63.054  53.481  1
470667  94.974  -63.051  53.454  1
470668  95.011  -63.067  53.428  1
470669  95.062  -63.070  53.404  1
470670  95.115  -63.070  53.380  1
470671  95.173  -63.073  53.356  1
470672  95.244  -63.083  53.326  1
470673  95.313  -63.095  53.293  1
470674  95.372  -63.111  53.259  1
470675  95.431  -63.129  53.223  1
470676  95.489  -63.146  53.188  1
470677  95.534  -63.136  53.153  1
470678  95.578  -63.125  53.118  1
470679  95.609  -63.139  53.081  1
470680  95.628  -63.159  53.046  1
470681  95.605  -63.133  53.012  1
470682  95.633  -63.118  52.977  1
470683  95.683  -63.109  52.943  1
470684  95.734  -63.100  52.911  1
470685  95.783  -63.092  52.877  1
470686  95.834  -63.082  52.841  1
470687  95.884  -63.073  52.806  1
470688  95.935  -63.076  52.772  1
470689  95.985  -63.079  52.739  1
470690  96.036  -63.084  52.706  1
470691  96.092  -63.098  52.674  1
470692  96.119  -63.108  52.640  1
470693  96.140  -63.123  52.606  1
470694  96.161  -63.138  52.572  1
470695  96.183  -63.155  52.537  1
470696  96.302  -63.235  52.501  1
470697  96.346  -63.187  52.464  1
470698  96.390  -63.139  52.422  1
470699  96.439  -63.148  52.376  1
470700  96.488  -63.160  52.331  1
470701  96.538  -63.172  52.287  1
470702  96.594  -63.187  52.245  1
470703  96.674  -63.209  52.202  1
470704  96.753  -63.226  52.162  1
470705  96.834  -63.238  52.124  1
470706  96.864  -63.243  52.087  1
470707  96.890  -63.249  52.056  1
470708  96.917  -63.254  52.029  1
470709  96.944  -63.259  52.004  1
470710  96.970  -63.264  51.977  1
470711  96.999  -63.276  51.948  1
470712  97.019  -63.283  51.916  1
470713  97.039  -63.289  51.882  1
470714  97.059  -63.296  51.849  1
470715  97.079  -63.302  51.816  1
470716  97.101  -63.309  51.783  1
470717  97.135  -63.314  51.749  1
470718  97.168  -63.321  51.714  1
470719  97.201  -63.326  51.679  1
470720  97.235  -63.331  51.643  1
470721  97.268  -63.337  51.608  1
470722  97.301  -63.343  51.574  1
470723  97.313  -63.350  51.539  1
470724  97.322  -63.358  51.506  1
470725  97.340  -63.368  51.474  1
470726  97.363  -63.378  51.442  1
470727  97.409  -63.365  51.411  1
470728  97.459  -63.349  51.380  1
470729  97.509  -63.333  51.349  1
470730  97.559  -63.318  51.317  1
470731  97.587  -63.322  51.283  1
470732  97.614  -63.327  51.250  1
470733  97.641  -63.332  51.217  1
470734  97.668  -63.337  51.182  1
470735  97.695  -63.343  51.145  1
470736  97.721  -63.347  51.105  1
470737  97.751  -63.354  51.061  1
470738  97.799  -63.368  51.015  1
470739  97.847  -63.383  50.967  1
470740  97.895  -63.398  50.918  1
470741  97.943  -63.413  50.868  1
470742  97.992  -63.427  50.815  1
470743  98.039  -63.441  50.760  1
470744  98.078  -63.440  50.706  1
470745  98.118  -63.437  50.649  1
470746  98.160  -63.433  50.592  1
470747  98.203  -63.428  50.536  1
470748  98.245  -63.424  50.482  1
470749  98.285  -63.422  50.429  1
470750  98.303  -63.436  50.378  1
470751  98.322  -63.449  50.330  1
470752  98.341  -63.464  50.284  1
470753  98.358  -63.477  50.237  1
470754  98.368  -63.493  50.191  1
470755  98.379  -63.508  50.147  1
470756  98.390  -63.523  50.103  1
470757  98.402  -63.538  50.059  1
470758  98.421  -63.553  50.012  1
470759  98.447  -63.551  49.964  1
470760  98.473  -63.538  49.916  1
470761  98.499  -63.526  49.868  1
470762  98.525  -63.513  49.820  1
470763  98.551  -63.501  49.774  1
470764  98.577  -63.488  49.728  1
470765  98.612  -63.490  49.684  1
470766  98.648  -63.491  49.640  1
470767  98.708  -63.487  49.599  1
470768  98.771  -63.486  49.557  1
470769  98.834  -63.484  49.517  1
470770  98.897  -63.482  49.478  1
470771  98.959  -63.480  49.440  1
470772  99.022  -63.478  49.400  1
470773  99.085  -63.477  49.363  1
470774  99.148  -63.474  49.326  1
471185  87.230  -61.571  56.134  1
471186  87.267  -61.572  56.123  1
471187  87.304  -61.575  56.111  1
471188  87.341  -61.576  56.099  1
471189  87.377  -61.578  56.088  1
471190  87.414  -61.580  56.076  1
471191  87.450  -61.581  56.065  1
471192  87.487  -61.583  56.055  1
471193  87.524  -61.585  56.045  1
471194  87.561  -61.587  56.036  1
471195  87.598  -61.589  56.026  1
471196  87.634  -61.591  56.014  1
471197  87.671  -61.592  56.001  1
471198  87.707  -61.594  55.988  1
471199  87.744  -61.596  55.976  1
471200  87.787  -61.595  55.962  1
471201  87.836  -61.591  55.945  1
471202  87.884  -61.588  55.927  1
471203  87.932  -61.584  55.909  1
471204  87.981  -61.581  55.892  1
471205  88.029  -61.578  55.878  1
471206  88.077  -61.575  55.866  1
471207  88.125  -61.572  55.855  1
471208  88.174  -61.568  55.844  1
471209  88.222  -61.565  55.833  1
471210  88.282  -61.567  55.816  1
471211  88.349  -61.574  55.794  1
471212  88.417  -61.580  55.768  1
471213  88.484  -61.586  55.739  1
471214  88.541  -61.597  55.708  1
471215  88.590  -61.613  55.680  1
471216  88.638  -61.628  55.652  1
471217  88.686  -61.644  55.629  1
471218  88.732  -61.660  55.613  1
471219  88.775  -61.678  55.603  1
471220  88.819  -61.701  55.595  1
471221  88.865  -61.733  55.586  1
471222  88.911  -61.766  55.573  1
471223  88.960  -61.798  55.554  1
471224  89.000  -61.806  55.530  1
471225  89.037  -61.807  55.501  1
471226  89.074  -61.809  55.470  1
471227  89.112  -61.811  55.441  1
471228  89.150  -61.813  55.414  1
471229  89.187  -61.814  55.392  1
471230  89.225  -61.816  55.373  1
471231  89.262  -61.817  55.355  1
471232  89.300  -61.819  55.339  1
471233  89.337  -61.820  55.323  1
471234  89.380  -61.830  55.308  1
471235  89.422  -61.839  55.295  1
471236  89.465  -61.849  55.283  1
471237  89.507  -61.859  55.271  1
471238  89.550  -61.868  55.260  1
471239  89.592  -61.878  55.251  1
471240  89.635  -61.888  55.244  1
471241  89.677  -61.897  55.237  1
471242  89.720  -61.907  55.230  1
471243  89.762  -61.916  55.225  1
471244  89.805  -61.926  55.224  1
471245  89.848  -61.939  55.224  1
471246  89.894  -61.960  55.228  1
471247  89.939  -61.981  55.233  1
471248  89.984  -62.002  55.240  1
471249  90.030  -62.023  55.243  1
471250  90.075  -62.045  55.248  1
471251  90.120  -62.066  55.250  1
471252  90.166  -62.088  55.249  1
471253  90.217  -62.102  55.243  1
471254  90.268  -62.114  55.230  1
471255  90.321  -62.127  55.213  1
471256  90.373  -62.139  55.195  1
471257  90.425  -62.152  55.174  1
471258  90.476  -62.164  55.150  1
471259  90.528  -62.177  55.123  1
471260  90.580  -62.189  55.100  1
471261  90.632  -62.202  55.082  1
471262  90.684  -62.214  55.068  1
471263  90.736  -62.227  55.058  1
471264  90.787  -62.239  55.053  1
471265  90.835  -62.254  55.053  1
471266  90.880  -62.265  55.054  1
471267  90.922  -62.274  55.053  1
471268  90.962  -62.283  55.048  1
471269  91.003  -62.293  55.042  1
471270  91.043  -62.302  55.035  1
471271  91.082  -62.314  55.028  1
471272  91.119  -62.326  55.025  1
471273  91.157  -62.337  55.026  1
471274  91.204  -62.342  55.028  1
471275  91.248  -62.352  55.026  1
471276  91.299  -62.364  55.021  1
471277  91.350  -62.376  55.013  1
471278  91.401  -62.388  55.002  1
471279  91.452  -62.400  54.990  1
471280  91.503  -62.413  54.979  1
471281  91.546  -62.431  54.968  1
471282  91.590  -62.447  54.961  1
471283  91.635  -62.465  54.960  1
471284  91.678  -62.482  54.957  1
471285  91.722  -62.500  54.954  1
471286  91.766  -62.517  54.944  1
471287  91.810  -62.534  54.923  1
471288  91.854  -62.551  54.894  1
471289  91.898  -62.569  54.862  1
471290  91.942  -62.584  54.837  1
471291  91.987  -62.595  54.817  1
471292  92.032  -62.606  54.802  1
471293  92.073  -62.610  54.792  1
471294  92.106  -62.606  54.787  1
471295  92.141  -62.602  54.785  1
471296  92.174  -62.597  54.782  1
471297  92.208  -62.594  54.777  1
471298  92.242  -62.589  54.769  1
471299  92.276  -62.584  54.758  1
471300  92.310  -62.581  54.743  1
471301  92.344  -62.576  54.724  1
471302  92.378  -62.572  54.703  1
471303  92.417  -62.572  54.678  1
471304  92.460  -62.576  54.651  1
471305  92.502  -62.579  54.625  1
471306  92.545  -62.583  54.599  1
471307  92.588  -62.585  54.573  1
471308  92.632  -62.587  54.547  1
471309  92.676  -62.588  54.526  1
471310  92.719  -62.590  54.504  1
471311  92.763  -62.593  54.482  1
471312  92.806  -62.597  54.458  1
471313  92.857  -62.600  54.434  1
471314  92.900  -62.606  54.411  1
471315  92.943  -62.610  54.389  1
471316  92.987  -62.615  54.369  1
471317  93.030  -62.619  54.351  1
471318  93.073  -62.625  54.334  1
471319  93.117  -62.629  54.317  1
471320  93.160  -62.634  54.300  1
471321  93.200  -62.644  54.284  1
471322  93.226  -62.682  54.269  1
471323  93.253  -62.713  54.254  1
471324  93.283  -62.732  54.237  1
471325  93.311  -62.741  54.221  1
471326  93.333  -62.725  54.206  1
471327  93.355  -62.710  54.190  1
471328  93.377  -62.694  54.174  1
471329  93.419  -62.705  54.158  1
471330  93.466  -62.725  54.143  1
471331  93.514  -62.744  54.127  1
471332  93.561  -62.764  54.112  1
471333  93.609  -62.783  54.096  1
471334  93.656  -62.803  54.081  1
471335  93.704  -62.822  54.064  1
471336  93.749  -62.839  54.047  1
471337  93.789  -62.853  54.029  1
471338  93.829  -62.866  54.013  1
471339  93.871  -62.876  53.994  1
471340  93.923  -62.876  53.977  1
471341  93.976  -62.877  53.960  1
471342  94.032  -62.885  53.943  1
471343  94.088  -62.894  53.926  1
471344  94.145  -62.901  53.910  1
471345  94.201  -62.928  53.894  1
471346  94.251  -62.931  53.879  1
471347  94.297  -62.907  53.865  1
471348  94.334  -62.901  53.851  1
471349  94.366  -62.905  53.838  1
471350  94.399  -62.910  53.825  1
471351  94.431  -62.913  53.812  1
471352  94.464  -62.918  53.799  1
471353  94.496  -62.923  53.784  1
471354  94.526  -62.930  53.767  1
471355  94.552  -62.946  53.750  1
471356  94.577  -62.961  53.732  1
471357  94.603  -62.977  53.712  1
471358  94.628  -62.992  53.690  1
471359  94.653  -63.008  53.670  1
471360  94.679  -63.023  53.649  1
471361  94.706  -63.037  53.625  1
471362  94.746  -63.034  53.599  1
471363  94.786  -63.030  53.573  1
471364  94.826  -63.026  53.548  1
471365  94.866  -63.023  53.521  1
471366  94.906  -63.020  53.494  1
471367  94.947  -63.017  53.466  1
471368  94.983  -63.033  53.438  1
471369  95.025  -63.045  53.413  1
471370  95.077  -63.045  53.389  1
471371  95.130  -63.045  53.366  1
471372  95.183  -63.045  53.342  1
471373  95.245  -63.051  53.312  1
471374  95.316  -63.061  53.278  1
471375  95.379  -63.075  53.243  1
471376  95.438  -63.092  53.207  1
471377  95.497  -63.109  53.170  1
471378  95.555  -63.126  53.134  1
471379  95.610  -63.135  53.097  1
471380  95.648  -63.136  53.059  1
471381  95.643  -63.129  53.022  1
471382  95.619  -63.101  52.987  1
471383  95.646  -63.087  52.951  1
471384  95.696  -63.078  52.915  1
471385  95.746  -63.069  52.882  1
471386  95.797  -63.061  52.848  1
471387  95.846  -63.051  52.812  1
471388  95.897  -63.042  52.776  1
471389  95.947  -63.033  52.741  1
471390  95.997  -63.024  52.708  1
471391  96.047  -63.025  52.675  1
471392  96.109  -63.056  52.642  1
471393  96.152  -63.101  52.607  1
471394  96.194  -63.146  52.574  1
471395  96.236  -63.191  52.539  1
471396  96.279  -63.236  52.504  1
471397  96.331  -63.236  52.470  1
471398  96.377  -63.194  52.434  1
471399  96.421  -63.146  52.393  1
471400  96.466  -63.105  52.350  1
471401  96.515  -63.117  52.306  1
471402  96.564  -63.129  52.262  1
471403  96.612  -63.142  52.219  1
471404  96.684  -63.162  52.178  1
471405  96.773  -63.186  52.137  1
471406  96.835  -63.205  52.098  1
471407  96.869  -63.213  52.062  1
471408  96.895  -63.217  52.030  1
471409  96.921  -63.222  52.002  1
471410  96.947  -63.226  51.976  1
471411  96.973  -63.230  51.950  1
471412  96.989  -63.238  51.922  1
471413  97.009  -63.245  51.892  1
471414  97.028  -63.252  51.859  1
471415  97.048  -63.258  51.826  1
471416  97.071  -63.264  51.794  1
471417  97.104  -63.270  51.761  1
471418  97.138  -63.276  51.728  1
471419  97.171  -63.281  51.693  1
471420  97.204  -63.287  51.657  1
471421  97.237  -63.292  51.620  1
471422  97.271  -63.299  51.583  1
471423  97.304  -63.304  51.548  1
471424  97.318  -63.311  51.512  1
471425  97.327  -63.319  51.478  1
471426  97.338  -63.327  51.445  1
471427  97.370  -63.330  51.412  1
471428  97.420  -63.314  51.379  1
471429  97.469  -63.298  51.347  1
471430  97.519  -63.282  51.315  1
471431  97.569  -63.266  51.282  1
471432  97.597  -63.270  51.248  1
471433  97.624  -63.275  51.213  1
471434  97.651  -63.280  51.179  1
471435  97.678  -63.286  51.144  1
471436  97.705  -63.290  51.107  1
471437  97.731  -63.296  51.068  1
471438  97.758  -63.301  51.026  1
471439  97.793  -63.310  50.980  1
471440  97.842  -63.324  50.931  1
471441  97.889  -63.339  50.881  1
471442  97.938  -63.354  50.831  1
471443  97.986  -63.369  50.780  1
471444  98.034  -63.383  50.727  1
471445  98.082  -63.397  50.673  1
471446  98.127  -63.398  50.616  1
471447  98.170  -63.395  50.558  1
471448  98.213  -63.390  50.501  1
471449  98.255  -63.386  50.447  1
471450  98.296  -63.383  50.394  1
471451  98.314  -63.397  50.342  1
471452  98.328  -63.412  50.291  1
471453  98.339  -63.427  50.242  1
471454  98.350  -63.442  50.196  1
471455  98.361  -63.457  50.150  1
471456  98.372  -63.472  50.105  1
471457  98.383  -63.487  50.060  1
471458  98.399  -63.502  50.017  1
471459  98.423  -63.518  49.973  1
471460  98.449  -63.507  49.927  1
471461  98.475  -63.494  49.881  1
471462  98.501  -63.482  49.836  1
471463  98.527  -63.470  49.792  1
471464  98.553  -63.457  49.748  1
471465  98.582  -63.449  49.704  1
471466  98.618  -63.453  49.661  1
471467  98.653  -63.450  49.619  1
471468  98.716  -63.449  49.579  1
471469  98.779  -63.447  49.540  1
471470  98.842  -63.445  49.500  1
471471  98.905  -63.443  49.462  1
471472  98.968  -63.441  49.424  1
471473  99.031  -63.440  49.386  1
471474  99.094  -63.438  49.350  1
471475  99.157  -63.436  49.315  1
471886  87.246  -61.523  56.131  1
471887  87.282  -61.525  56.119  1
471888  87.319  -61.526  56.107  1
471889  87.356  -61.528  56.096  1
471890  87.393  -61.530  56.084  1
471891  87.429  -61.532  56.072  1
471892  87.466  -61.534  56.061  1
471893  87.502  -61.535  56.051  1
471894  87.539  -61.538  56.040  1
471895  87.576  -61.539  56.030  1
471896  87.613  -61.541  56.019  1
471897  87.649  -61.543  56.006  1
471898  87.686  -61.544  55.993  1
471899  87.723  -61.547  55.980  1
471900  87.760  -61.548  55.967  1
471901  87.797  -61.550  55.954  1
471902  87.845  -61.546  55.938  1
471903  87.894  -61.543  55.920  1
471904  87.942  -61.540  55.902  1
471905  87.990  -61.536  55.885  1
471906  88.038  -61.533  55.870  1
471907  88.086  -61.529  55.858  1
471908  88.135  -61.526  55.847  1
471909  88.183  -61.522  55.837  1
471910  88.232  -61.519  55.826  1
471911  88.293  -61.523  55.810  1
471912  88.360  -61.529  55.789  1
471913  88.428  -61.535  55.765  1
471914  88.495  -61.542  55.735  1
471915  88.558  -61.550  55.703  1
471916  88.606  -61.566  55.673  1
471917  88.654  -61.581  55.645  1
471918  88.703  -61.597  55.622  1
471919  88.747  -61.614  55.605  1
471920  88.790  -61.632  55.596  1
471921  88.836  -61.663  55.589  1
471922  88.882  -61.695  55.581  1
471923  88.928  -61.728  55.570  1
471924  88.977  -61.760  55.552  1
471925  89.015  -61.763  55.528  1
471926  89.052  -61.765  55.499  1
471927  89.090  -61.766  55.469  1
471928  89.127  -61.768  55.439  1
471929  89.165  -61.769  55.412  1
471930  89.202  -61.771  55.388  1
471931  89.239  -61.773  55.368  1
471932  89.277  -61.774  55.349  1
471933  89.314  -61.776  55.331  1
471934  89.352  -61.778  55.316  1
471935  89.389  -61.779  55.301  1
471936  89.432  -61.789  55.287  1
471937  89.474  -61.799  55.275  1
471938  89.517  -61.808  55.264  1
471939  89.560  -61.818  55.254  1
471940  89.602  -61.827  55.245  1
471941  89.645  -61.837  55.238  1
471942  89.687  -61.847  55.232  1
471943  89.730  -61.856  55.226  1
471944  89.772  -61.866  55.221  1
471945  89.815  -61.875  55.219  1
471946  89.859  -61.890  55.217  1
471947  89.904  -61.911  55.218  1
471948  89.950  -61.932  55.222  1
471949  89.995  -61.954  55.229  1
471950  90.040  -61.975  55.232  1
471951  90.086  -61.996  55.237  1
471952  90.131  -62.018  55.242  1
471953  90.176  -62.039  55.244  1
471954  90.225  -62.057  55.243  1
471955  90.276  -62.069  55.234  1
471956  90.328  -62.082  55.218  1
471957  90.380  -62.094  55.198  1
471958  90.432  -62.107  55.176  1
471959  90.484  -62.119  55.151  1
471960  90.536  -62.132  55.122  1
471961  90.588  -62.144  55.098  1
471962  90.640  -62.157  55.079  1
471963  90.692  -62.170  55.066  1
471964  90.744  -62.182  55.057  1
471965  90.796  -62.195  55.054  1
471966  90.848  -62.207  55.057  1
471967  90.894  -62.220  55.060  1
471968  90.935  -62.229  55.060  1
471969  90.974  -62.239  55.057  1
471970  91.011  -62.252  55.051  1
471971  91.048  -62.264  55.045  1
471972  91.085  -62.276  55.038  1
471973  91.122  -62.288  55.033  1
471974  91.170  -62.293  55.032  1
471975  91.216  -62.299  55.033  1
471976  91.259  -62.308  55.029  1
471977  91.305  -62.318  55.024  1
471978  91.356  -62.330  55.017  1
471979  91.407  -62.343  55.012  1
471980  91.458  -62.355  55.007  1
471981  91.506  -62.370  54.997  1
471982  91.549  -62.387  54.984  1
471983  91.593  -62.404  54.975  1
471984  91.638  -62.421  54.979  1
471985  91.681  -62.439  54.976  1
471986  91.725  -62.456  54.971  1
471987  91.769  -62.474  54.960  1
471988  91.813  -62.490  54.942  1
471989  91.857  -62.508  54.911  1
471990  91.901  -62.525  54.874  1
471991  91.945  -62.543  54.844  1
471992  91.989  -62.557  54.820  1
471993  92.034  -62.569  54.801  1
471994  92.077  -62.575  54.786  1
471995  92.110  -62.572  54.779  1
471996  92.145  -62.567  54.773  1
471997  92.178  -62.562  54.768  1
471998  92.213  -62.559  54.762  1
471999  92.246  -62.554  54.753  1
472000  92.280  -62.550  54.740  1
472001  92.314  -62.546  54.724  1
472002  92.348  -62.541  54.706  1
472003  92.382  -62.537  54.685  1
472004  92.416  -62.533  54.661  1
472005  92.456  -62.534  54.635  1
472006  92.499  -62.538  54.609  1
472007  92.542  -62.540  54.583  1
472008  92.586  -62.543  54.557  1
472009  92.629  -62.544  54.532  1
472010  92.672  -62.547  54.509  1
472011  92.715  -62.553  54.488  1
472012  92.758  -62.558  54.466  1
472013  92.800  -62.562  54.443  1
472014  92.851  -62.566  54.421  1
472015  92.905  -62.569  54.400  1
472016  92.957  -62.572  54.381  1
472017  93.000  -62.576  54.364  1
472018  93.044  -62.581  54.348  1
472019  93.087  -62.586  54.333  1
472020  93.130  -62.590  54.318  1
472021  93.174  -62.595  54.303  1
472022  93.207  -62.618  54.289  1
472023  93.233  -62.656  54.274  1
472024  93.259  -62.691  54.259  1
472025  93.289  -62.710  54.244  1
472026  93.313  -62.706  54.227  1
472027  93.336  -62.690  54.210  1
472028  93.358  -62.675  54.193  1
472029  93.380  -62.659  54.175  1
472030  93.412  -62.657  54.159  1
472031  93.460  -62.677  54.142  1
472032  93.507  -62.696  54.127  1
472033  93.555  -62.716  54.111  1
472034  93.603  -62.735  54.095  1
472035  93.650  -62.755  54.080  1
472036  93.698  -62.774  54.063  1
472037  93.746  -62.794  54.045  1
472038  93.793  -62.813  54.027  1
472039  93.837  -62.829  54.011  1
472040  93.880  -62.838  53.992  1
472041  93.935  -62.843  53.975  1
472042  93.992  -62.851  53.958  1
472043  94.048  -62.859  53.941  1
472044  94.105  -62.867  53.924  1
472045  94.161  -62.876  53.907  1
472046  94.217  -62.891  53.891  1
472047  94.267  -62.889  53.875  1
472048  94.313  -62.864  53.859  1
472049  94.352  -62.852  53.845  1
472050  94.385  -62.857  53.831  1
472051  94.417  -62.860  53.817  1
472052  94.450  -62.865  53.803  1
472053  94.482  -62.869  53.789  1
472054  94.511  -62.879  53.773  1
472055  94.537  -62.894  53.756  1
472056  94.563  -62.910  53.738  1
472057  94.588  -62.925  53.718  1
472058  94.614  -62.941  53.698  1
472059  94.639  -62.956  53.677  1
472060  94.665  -62.972  53.655  1
472061  94.690  -62.987  53.633  1
472062  94.718  -63.000  53.609  1
472063  94.758  -62.996  53.584  1
472064  94.798  -62.993  53.559  1
472065  94.838  -62.989  53.533  1
472066  94.878  -62.986  53.506  1
472067  94.918  -62.982  53.478  1
472068  94.955  -63.000  53.450  1
472069  94.991  -63.017  53.421  1
472070  95.040  -63.022  53.396  1
472071  95.093  -63.022  53.373  1
472072  95.146  -63.022  53.350  1
472073  95.199  -63.022  53.325  1
472074  95.252  -63.021  53.295  1
472075  95.316  -63.028  53.261  1
472076  95.387  -63.038  53.226  1
472077  95.445  -63.055  53.189  1
472078  95.504  -63.073  53.153  1
472079  95.563  -63.089  53.115  1
472080  95.621  -63.107  53.076  1
472081  95.677  -63.122  53.037  1
472082  95.663  -63.098  52.999  1
472083  95.634  -63.071  52.963  1
472084  95.659  -63.056  52.926  1
472085  95.708  -63.044  52.890  1
472086  95.757  -63.031  52.855  1
472087  95.806  -63.019  52.820  1
472088  95.854  -63.007  52.784  1
472089  95.903  -62.994  52.748  1
472090  95.952  -62.982  52.713  1
472091  96.001  -62.969  52.679  1
472092  96.051  -62.967  52.646  1
472093  96.106  -62.999  52.612  1
472094  96.148  -63.044  52.579  1
472095  96.190  -63.089  52.545  1
472096  96.237  -63.130  52.510  1
472097  96.293  -63.164  52.474  1
472098  96.329  -63.170  52.440  1
472099  96.390  -63.151  52.405  1
472100  96.445  -63.132  52.365  1
472101  96.497  -63.105  52.325  1
472102  96.542  -63.073  52.282  1
472103  96.591  -63.086  52.238  1
472104  96.671  -63.108  52.195  1
472105  96.731  -63.127  52.154  1
472106  96.774  -63.140  52.113  1
472107  96.811  -63.151  52.074  1
472108  96.849  -63.161  52.038  1
472109  96.886  -63.172  52.005  1
472110  96.919  -63.181  51.976  1
472111  96.945  -63.186  51.950  1
472112  96.970  -63.190  51.923  1
472113  96.997  -63.194  51.895  1
472114  96.998  -63.207  51.866  1
472115  97.018  -63.214  51.834  1
472116  97.040  -63.220  51.802  1
472117  97.074  -63.226  51.771  1
472118  97.107  -63.232  51.739  1
472119  97.140  -63.237  51.706  1
472120  97.174  -63.242  51.672  1
472121  97.207  -63.249  51.637  1
472122  97.240  -63.254  51.600  1
472123  97.274  -63.260  51.562  1
472124  97.307  -63.265  51.526  1
472125  97.323  -63.273  51.489  1
472126  97.332  -63.280  51.453  1
472127  97.342  -63.287  51.419  1
472128  97.380  -63.278  51.385  1
472129  97.430  -63.262  51.350  1
472130  97.479  -63.246  51.317  1
472131  97.529  -63.230  51.283  1
472132  97.579  -63.214  51.249  1
472133  97.607  -63.218  51.214  1
472134  97.634  -63.224  51.179  1
472135  97.661  -63.228  51.143  1
472136  97.688  -63.233  51.107  1
472137  97.715  -63.239  51.069  1
472138  97.741  -63.244  51.029  1
472139  97.769  -63.249  50.986  1
472140  97.795  -63.254  50.939  1
472141  97.836  -63.265  50.891  1
472142  97.884  -63.280  50.842  1
472143  97.932  -63.295  50.792  1
472144  97.980  -63.310  50.741  1
472145  98.028  -63.324  50.688  1
472146  98.074  -63.325  50.635  1
472147  98.119  -63.326  50.579  1
472148  98.164  -63.327  50.522  1
472149  98.210  -63.328  50.465  1
472150  98.257  -63.332  50.411  1
472151  98.299  -63.346  50.358  1
472152  98.310  -63.361  50.307  1
472153  98.321  -63.376  50.258  1
472154  98.332  -63.391  50.210  1
472155  98.343  -63.406  50.164  1
472156  98.354  -63.421  50.119  1
472157  98.364  -63.437  50.075  1
472158  98.376  -63.452  50.030  1
472159  98.401  -63.467  49.987  1
472160  98.425  -63.476  49.942  1
472161  98.451  -63.463  49.898  1
472162  98.478  -63.451  49.854  1
472163  98.503  -63.438  49.810  1
472164  98.529  -63.426  49.767  1
472165  98.556  -63.413  49.725  1
472166  98.588  -63.412  49.683  1
472167  98.624  -63.416  49.641  1
472168  98.662  -63.412  49.601  1
472169  98.725  -63.410  49.561  1
472170  98.788  -63.408  49.523  1
472171  98.851  -63.406  49.485  1
472172  98.914  -63.404  49.447  1
472173  98.977  -63.402  49.410  1
472174  99.040  -63.401  49.373  1
472175  99.102  -63.399  49.338  1
472588  87.298  -61.477  56.114  1
472589  87.334  -61.478  56.103  1
472590  87.371  -61.481  56.092  1
472591  87.408  -61.482  56.080  1
472592  87.444  -61.484  56.068  1
472593  87.481  -61.486  56.057  1
472594  87.518  -61.487  56.046  1
472595  87.555  -61.490  56.035  1
472596  87.591  -61.491  56.024  1
472597  87.628  -61.493  56.012  1
472598  87.664  -61.495  55.999  1
472599  87.701  -61.497  55.985  1
472600  87.738  -61.498  55.972  1
472601  87.775  -61.500  55.959  1
472602  87.812  -61.502  55.945  1
472603  87.855  -61.501  55.930  1
472604  87.903  -61.497  55.913  1
472605  87.952  -61.494  55.895  1
472606  87.999  -61.491  55.877  1
472607  88.048  -61.487  55.861  1
472608  88.096  -61.484  55.848  1
472609  88.144  -61.481  55.836  1
472610  88.193  -61.478  55.826  1
472611  88.241  -61.474  55.816  1
472612  88.304  -61.478  55.801  1
472613  88.371  -61.484  55.783  1
472614  88.439  -61.491  55.759  1
472615  88.506  -61.497  55.730  1
472616  88.574  -61.503  55.697  1
472617  88.623  -61.519  55.665  1
472618  88.672  -61.534  55.636  1
472619  88.719  -61.550  55.613  1
472620  88.762  -61.567  55.596  1
472621  88.807  -61.593  55.587  1
472622  88.853  -61.625  55.581  1
472623  88.900  -61.657  55.574  1
472624  88.946  -61.690  55.564  1
472625  88.992  -61.719  55.548  1
472626  89.029  -61.720  55.523  1
472627  89.067  -61.722  55.496  1
472628  89.104  -61.723  55.466  1
472629  89.142  -61.725  55.437  1
472630  89.179  -61.726  55.410  1
472631  89.216  -61.729  55.385  1
472632  89.254  -61.730  55.363  1
472633  89.292  -61.732  55.342  1
472634  89.329  -61.733  55.324  1
472635  89.367  -61.735  55.307  1
472636  89.404  -61.736  55.292  1
472637  89.442  -61.738  55.279  1
472638  89.484  -61.748  55.268  1
472639  89.527  -61.758  55.257  1
472640  89.569  -61.767  55.247  1
472641  89.612  -61.777  55.239  1
472642  89.655  -61.786  55.232  1
472643  89.697  -61.796  55.226  1
472644  89.740  -61.806  55.221  1
472645  89.782  -61.815  55.217  1
472646  89.825  -61.825  55.215  1
472647  89.869  -61.841  55.212  1
472648  89.915  -61.863  55.211  1
472649  89.960  -61.884  55.213  1
472650  90.006  -61.905  55.218  1
472651  90.051  -61.926  55.223  1
472652  90.096  -61.948  55.228  1
472653  90.142  -61.970  55.233  1
472654  90.187  -61.991  55.236  1
472655  90.233  -62.011  55.237  1
472656  90.285  -62.024  55.231  1
472657  90.336  -62.036  55.219  1
472658  90.388  -62.049  55.201  1
472659  90.440  -62.061  55.178  1
472660  90.492  -62.074  55.151  1
472661  90.544  -62.086  55.121  1
472662  90.596  -62.099  55.096  1
472663  90.648  -62.112  55.076  1
472664  90.699  -62.124  55.063  1
472665  90.751  -62.137  55.055  1
472666  90.803  -62.149  55.055  1
472667  90.856  -62.162  55.060  1
472668  90.903  -62.177  55.065  1
472669  90.941  -62.190  55.067  1
472670  90.978  -62.202  55.065  1
472671  91.015  -62.214  55.061  1
472672  91.052  -62.227  55.057  1
472673  91.089  -62.239  55.052  1
472674  91.133  -62.246  55.045  1
472675  91.183  -62.248  55.039  1
472676  91.228  -62.255  55.037  1
472677  91.271  -62.265  55.033  1
472678  91.314  -62.274  55.028  1
472679  91.362  -62.285  55.026  1
472680  91.413  -62.297  55.028  1
472681  91.464  -62.309  55.026  1
472682  91.509  -62.326  55.013  1
472683  91.553  -62.343  54.997  1
472684  91.596  -62.361  54.989  1
472685  91.641  -62.378  54.995  1
472686  91.684  -62.396  54.995  1
472687  91.728  -62.412  54.987  1
472688  91.772  -62.430  54.975  1
472689  91.816  -62.447  54.956  1
472690  91.860  -62.465  54.926  1
472691  91.904  -62.482  54.886  1
472692  91.948  -62.500  54.851  1
472693  91.992  -62.516  54.823  1
472694  92.036  -62.531  54.801  1
472695  92.081  -62.541  54.784  1
472696  92.115  -62.537  54.773  1
472697  92.149  -62.532  54.764  1
472698  92.182  -62.528  54.757  1
472699  92.217  -62.524  54.750  1
472700  92.250  -62.519  54.739  1
472701  92.284  -62.515  54.725  1
472702  92.318  -62.511  54.707  1
472703  92.352  -62.506  54.688  1
472704  92.386  -62.503  54.667  1
472705  92.420  -62.498  54.643  1
472706  92.454  -62.493  54.617  1
472707  92.496  -62.496  54.591  1
472708  92.540  -62.499  54.565  1
472709  92.582  -62.503  54.539  1
472710  92.625  -62.508  54.515  1
472711  92.667  -62.512  54.492  1
472712  92.710  -62.518  54.470  1
472713  92.753  -62.523  54.449  1
472714  92.795  -62.528  54.428  1
472715  92.842  -62.532  54.408  1
472716  92.896  -62.534  54.390  1
472717  92.949  -62.537  54.376  1
472718  93.003  -62.540  54.363  1
472719  93.057  -62.543  54.351  1
472720  93.100  -62.547  54.340  1
472721  93.144  -62.552  54.328  1
472722  93.187  -62.556  54.316  1
472723  93.214  -62.591  54.303  1
472724  93.240  -62.629  54.288  1
472725  93.265  -62.666  54.271  1
472726  93.294  -62.685  54.254  1
472727  93.317  -62.669  54.235  1
472728  93.339  -62.654  54.217  1
472729  93.361  -62.639  54.199  1
472730  93.383  -62.623  54.180  1
472731  93.406  -62.609  54.163  1
472732  93.453  -62.628  54.146  1
472733  93.501  -62.648  54.130  1
472734  93.549  -62.667  54.113  1
472735  93.596  -62.687  54.098  1
472736  93.644  -62.706  54.081  1
472737  93.692  -62.726  54.064  1
472738  93.739  -62.745  54.046  1
472739  93.787  -62.765  54.027  1
472740  93.843  -62.788  54.010  1
472741  93.893  -62.806  53.992  1
472742  93.950  -62.815  53.974  1
472743  94.007  -62.824  53.957  1
472744  94.064  -62.832  53.940  1
472745  94.121  -62.841  53.923  1
472746  94.177  -62.849  53.905  1
472747  94.234  -62.857  53.888  1
472748  94.282  -62.847  53.872  1
472749  94.328  -62.822  53.855  1
472750  94.371  -62.804  53.840  1
472751  94.404  -62.808  53.825  1
472752  94.436  -62.812  53.809  1
472753  94.468  -62.816  53.793  1
472754  94.497  -62.826  53.779  1
472755  94.523  -62.842  53.763  1
472756  94.548  -62.857  53.745  1
472757  94.574  -62.873  53.726  1
472758  94.599  -62.888  53.705  1
472759  94.625  -62.904  53.684  1
472760  94.650  -62.919  53.663  1
472761  94.676  -62.935  53.641  1
472762  94.701  -62.951  53.618  1
472763  94.730  -62.962  53.594  1
472764  94.770  -62.959  53.569  1
472765  94.810  -62.955  53.543  1
472766  94.850  -62.952  53.517  1
472767  94.890  -62.948  53.490  1
472768  94.927  -62.966  53.462  1
472769  94.964  -62.983  53.433  1
472770  95.003  -62.998  53.403  1
472771  95.056  -62.998  53.376  1
472772  95.109  -62.998  53.352  1
472773  95.162  -62.998  53.328  1
472774  95.214  -62.998  53.302  1
472775  95.267  -62.998  53.273  1
472776  95.320  -62.998  53.239  1
472777  95.387  -63.005  53.204  1
472778  95.453  -63.019  53.168  1
472779  95.512  -63.035  53.131  1
472780  95.570  -63.053  53.093  1
472781  95.629  -63.070  53.056  1
472782  95.673  -63.076  53.018  1
472783  95.694  -63.061  52.980  1
472784  95.697  -63.043  52.942  1
472785  95.670  -63.016  52.905  1
472786  95.716  -62.997  52.868  1
472787  95.763  -62.978  52.832  1
472788  95.809  -62.959  52.795  1
472789  95.855  -62.940  52.758  1
472790  95.902  -62.923  52.722  1
472791  95.951  -62.910  52.688  1
472792  96.000  -62.898  52.653  1
472793  96.051  -62.909  52.620  1
472794  96.103  -62.942  52.588  1
472795  96.145  -62.987  52.555  1
472796  96.195  -63.026  52.520  1
472797  96.251  -63.059  52.484  1
472798  96.300  -63.089  52.448  1
472799  96.325  -63.097  52.413  1
472800  96.394  -63.085  52.378  1
472801  96.449  -63.066  52.339  1
472802  96.504  -63.047  52.300  1
472803  96.558  -63.029  52.260  1
472804  96.618  -63.048  52.216  1
472805  96.675  -63.065  52.171  1
472806  96.713  -63.076  52.131  1
472807  96.750  -63.086  52.090  1
472808  96.788  -63.097  52.052  1
472809  96.825  -63.108  52.016  1
472810  96.862  -63.118  51.982  1
472811  96.899  -63.128  51.952  1
472812  96.937  -63.139  51.924  1
472813  96.968  -63.150  51.896  1
472814  96.994  -63.154  51.867  1
472815  97.001  -63.165  51.839  1
472816  97.010  -63.176  51.808  1
472817  97.043  -63.182  51.778  1
472818  97.077  -63.187  51.747  1
472819  97.110  -63.193  51.716  1
472820  97.143  -63.198  51.684  1
472821  97.177  -63.204  51.650  1
472822  97.210  -63.210  51.616  1
472823  97.243  -63.215  51.580  1
472824  97.277  -63.221  51.543  1
472825  97.310  -63.227  51.506  1
472826  97.329  -63.233  51.468  1
472827  97.338  -63.241  51.431  1
472828  97.366  -63.253  51.395  1
472829  97.409  -63.245  51.359  1
472830  97.450  -63.220  51.323  1
472831  97.491  -63.195  51.288  1
472832  97.539  -63.179  51.253  1
472833  97.589  -63.163  51.217  1
472834  97.617  -63.167  51.182  1
472835  97.644  -63.171  51.144  1
472836  97.671  -63.177  51.107  1
472837  97.698  -63.182  51.070  1
472838  97.725  -63.187  51.031  1
472839  97.751  -63.192  50.990  1
472840  97.779  -63.197  50.946  1
472841  97.805  -63.202  50.900  1
472842  97.832  -63.208  50.853  1
472843  97.878  -63.221  50.804  1
472844  97.926  -63.236  50.754  1
472845  97.974  -63.251  50.703  1
472846  98.020  -63.252  50.650  1
472847  98.065  -63.253  50.597  1
472848  98.111  -63.254  50.542  1
472849  98.164  -63.267  50.486  1
472850  98.217  -63.281  50.431  1
472851  98.271  -63.296  50.377  1
472852  98.291  -63.311  50.325  1
472853  98.302  -63.326  50.276  1
472854  98.313  -63.340  50.227  1
472855  98.324  -63.355  50.180  1
472856  98.335  -63.371  50.135  1
472857  98.346  -63.386  50.091  1
472858  98.357  -63.401  50.047  1
472859  98.378  -63.416  50.003  1
472860  98.403  -63.432  49.960  1
472861  98.428  -63.432  49.915  1
472862  98.454  -63.420  49.872  1
472863  98.480  -63.407  49.829  1
472864  98.506  -63.395  49.787  1
472865  98.532  -63.382  49.745  1
472866  98.558  -63.370  49.704  1
472867  98.594  -63.374  49.664  1
472868  98.631  -63.378  49.624  1
472869  98.670  -63.373  49.584  1
472870  98.733  -63.371  49.544  1
472871  98.796  -63.369  49.507  1
472872  98.859  -63.368  49.470  1
472873  98.922  -63.365  49.433  1
472874  98.985  -63.364  49.397  1
472875  99.048  -63.361  49.361  1
473290  87.350  -61.431  56.099  1
473291  87.387  -61.432  56.087  1
473292  87.423  -61.434  56.076  1
473293  87.460  -61.436  56.064  1
473294  87.496  -61.438  56.053  1
473295  87.533  -61.440  56.041  1
473296  87.570  -61.441  56.030  1
473297  87.607  -61.443  56.018  1
473298  87.643  -61.445  56.005  1
473299  87.680  -61.447  55.992  1
473300  87.716  -61.449  55.979  1
473301  87.753  -61.450  55.965  1
473302  87.790  -61.453  55.951  1
473303  87.827  -61.454  55.937  1
473304  87.864  -61.456  55.921  1
473305  87.913  -61.452  55.905  1
473306  87.961  -61.449  55.888  1
473307  88.009  -61.445  55.869  1
473308  88.057  -61.442  55.852  1
473309  88.106  -61.439  55.838  1
473310  88.154  -61.435  55.824  1
473311  88.202  -61.432  55.812  1
473312  88.250  -61.428  55.802  1
473313  88.315  -61.434  55.790  1
473314  88.383  -61.440  55.773  1
473315  88.450  -61.447  55.751  1
473316  88.518  -61.453  55.724  1
473317  88.585  -61.459  55.691  1
473318  88.640  -61.472  55.656  1
473319  88.688  -61.487  55.626  1
473320  88.735  -61.503  55.602  1
473321  88.778  -61.522  55.586  1
473322  88.824  -61.555  55.576  1
473323  88.871  -61.588  55.571  1
473324  88.917  -61.619  55.565  1
473325  88.963  -61.652  55.556  1
473326  89.006  -61.675  55.541  1
473327  89.044  -61.677  55.518  1
473328  89.082  -61.678  55.492  1
473329  89.119  -61.680  55.464  1
473330  89.157  -61.682  55.436  1
473331  89.194  -61.684  55.408  1
473332  89.232  -61.685  55.382  1
473333  89.269  -61.687  55.358  1
473334  89.307  -61.688  55.335  1
473335  89.344  -61.690  55.316  1
473336  89.382  -61.691  55.298  1
473337  89.419  -61.694  55.283  1
473338  89.456  -61.695  55.270  1
473339  89.494  -61.697  55.259  1
473340  89.537  -61.707  55.249  1
473341  89.580  -61.717  55.239  1
473342  89.622  -61.726  55.233  1
473343  89.665  -61.736  55.225  1
473344  89.707  -61.745  55.219  1
473345  89.750  -61.755  55.215  1
473346  89.793  -61.765  55.212  1
473347  89.835  -61.774  55.211  1
473348  89.880  -61.793  55.209  1
473349  89.925  -61.814  55.207  1
473350  89.970  -61.835  55.206  1
473351  90.016  -61.857  55.209  1
473352  90.061  -61.878  55.214  1
473353  90.107  -61.900  55.218  1
473354  90.152  -61.921  55.222  1
473355  90.197  -61.942  55.227  1
473356  90.243  -61.964  55.229  1
473357  90.292  -61.979  55.226  1
473358  90.344  -61.992  55.216  1
473359  90.396  -62.004  55.200  1
473360  90.448  -62.017  55.177  1
473361  90.500  -62.029  55.149  1
473362  90.552  -62.042  55.118  1
473363  90.604  -62.055  55.093  1
473364  90.656  -62.067  55.074  1
473365  90.708  -62.080  55.061  1
473366  90.759  -62.092  55.054  1
473367  90.812  -62.106  55.053  1
473368  90.865  -62.120  55.058  1
473369  90.908  -62.137  55.064  1
473370  90.945  -62.153  55.070  1
473371  90.982  -62.165  55.073  1
473372  91.019  -62.177  55.074  1
473373  91.056  -62.189  55.074  1
473374  91.096  -62.199  55.070  1
473375  91.146  -62.202  55.061  1
473376  91.196  -62.204  55.047  1
473377  91.239  -62.212  55.040  1
473378  91.283  -62.222  55.036  1
473379  91.325  -62.231  55.035  1
473380  91.369  -62.240  55.038  1
473381  91.419  -62.252  55.048  1
473382  91.468  -62.265  55.043  1
473383  91.512  -62.283  55.027  1
473384  91.556  -62.300  55.010  1
473385  91.599  -62.318  55.001  1
473386  91.643  -62.335  55.008  1
473387  91.687  -62.352  55.009  1
473388  91.731  -62.369  55.002  1
473389  91.775  -62.387  54.988  1
473390  91.819  -62.404  54.968  1
473391  91.863  -62.421  54.936  1
473392  91.907  -62.439  54.895  1
473393  91.951  -62.456  54.858  1
473394  91.995  -62.473  54.827  1
473395  92.038  -62.490  54.802  1
473396  92.083  -62.504  54.783  1
473397  92.119  -62.502  54.770  1
473398  92.153  -62.497  54.758  1
473399  92.187  -62.493  54.747  1
473400  92.221  -62.489  54.735  1
473401  92.254  -62.485  54.723  1
473402  92.289  -62.481  54.706  1
473403  92.322  -62.476  54.687  1
473404  92.356  -62.472  54.666  1
473405  92.390  -62.468  54.643  1
473406  92.424  -62.460  54.619  1
473407  92.458  -62.453  54.593  1
473408  92.499  -62.458  54.568  1
473409  92.542  -62.462  54.543  1
473410  92.584  -62.468  54.518  1
473411  92.628  -62.473  54.494  1
473412  92.670  -62.478  54.472  1
473413  92.713  -62.483  54.452  1
473414  92.756  -62.488  54.432  1
473415  92.799  -62.493  54.413  1
473416  92.840  -62.498  54.396  1
473417  92.893  -62.501  54.383  1
473418  92.944  -62.503  54.372  1
473419  92.997  -62.506  54.364  1
473420  93.049  -62.509  54.358  1
473421  93.102  -62.511  54.350  1
473422  93.156  -62.514  54.341  1
473423  93.196  -62.527  54.330  1
473424  93.221  -62.565  54.317  1
473425  93.247  -62.602  54.301  1
473426  93.272  -62.640  54.284  1
473427  93.297  -62.650  54.265  1
473428  93.319  -62.634  54.245  1
473429  93.341  -62.619  54.225  1
473430  93.363  -62.603  54.205  1
473431  93.386  -62.587  54.186  1
473432  93.408  -62.572  54.170  1
473433  93.447  -62.580  54.154  1
473434  93.495  -62.600  54.138  1
473435  93.543  -62.619  54.122  1
473436  93.590  -62.638  54.106  1
473437  93.641  -62.659  54.089  1
473438  93.699  -62.684  54.072  1
473439  93.757  -62.708  54.053  1
473440  93.815  -62.732  54.034  1
473441  93.855  -62.757  54.015  1
473442  93.905  -62.771  53.996  1
473443  93.962  -62.780  53.978  1
473444  94.019  -62.789  53.960  1
473445  94.076  -62.798  53.942  1
473446  94.133  -62.807  53.924  1
473447  94.190  -62.816  53.905  1
473448  94.246  -62.823  53.887  1
473449  94.297  -62.805  53.870  1
473450  94.344  -62.781  53.853  1
473451  94.389  -62.756  53.837  1
473452  94.422  -62.759  53.820  1
473453  94.455  -62.763  53.802  1
473454  94.483  -62.775  53.785  1
473455  94.508  -62.791  53.768  1
473456  94.534  -62.806  53.753  1
473457  94.559  -62.822  53.735  1
473458  94.585  -62.837  53.715  1
473459  94.610  -62.853  53.693  1
473460  94.636  -62.868  53.671  1
473461  94.662  -62.884  53.650  1
473462  94.687  -62.899  53.627  1
473463  94.712  -62.915  53.603  1
473464  94.742  -62.925  53.579  1
473465  94.782  -62.921  53.554  1
473466  94.822  -62.918  53.527  1
473467  94.862  -62.915  53.501  1
473468  94.899  -62.932  53.473  1
473469  94.935  -62.949  53.444  1
473470  94.972  -62.967  53.414  1
473471  95.019  -62.973  53.383  1
473472  95.071  -62.973  53.354  1
473473  95.124  -62.973  53.328  1
473474  95.177  -62.973  53.303  1
473475  95.230  -62.973  53.276  1
473476  95.283  -62.973  53.247  1
473477  95.336  -62.973  53.214  1
473478  95.389  -62.973  53.180  1
473479  95.459  -62.982  53.144  1
473480  95.519  -62.999  53.108  1
473481  95.578  -63.017  53.071  1
473482  95.636  -63.033  53.034  1
473483  95.669  -63.029  52.997  1
473484  95.690  -63.015  52.959  1
473485  95.710  -63.001  52.921  1
473486  95.732  -62.988  52.884  1
473487  95.731  -62.963  52.848  1
473488  95.777  -62.945  52.811  1
473489  95.823  -62.926  52.774  1
473490  95.870  -62.907  52.736  1
473491  95.915  -62.888  52.699  1
473492  95.960  -62.873  52.664  1
473493  96.005  -62.857  52.630  1
473494  96.052  -62.851  52.596  1
473495  96.100  -62.885  52.563  1
473496  96.154  -62.920  52.530  1
473497  96.209  -62.954  52.495  1
473498  96.264  -62.988  52.459  1
473499  96.307  -63.011  52.422  1
473500  96.331  -63.020  52.386  1
473501  96.385  -63.017  52.350  1
473502  96.453  -63.000  52.313  1
473503  96.508  -62.981  52.274  1
473504  96.566  -62.986  52.233  1
473505  96.614  -63.001  52.191  1
473506  96.651  -63.011  52.148  1
473507  96.688  -63.022  52.108  1
473508  96.726  -63.032  52.069  1
473509  96.763  -63.043  52.031  1
473510  96.801  -63.054  51.995  1
473511  96.838  -63.064  51.961  1
473512  96.875  -63.074  51.930  1
473513  96.912  -63.085  51.900  1
473514  96.950  -63.095  51.870  1
473515  96.987  -63.106  51.841  1
473516  97.018  -63.117  51.812  1
473517  97.033  -63.128  51.782  1
473518  97.058  -63.137  51.752  1
473519  97.084  -63.147  51.722  1
473520  97.113  -63.155  51.690  1
473521  97.146  -63.160  51.660  1
473522  97.180  -63.165  51.628  1
473523  97.213  -63.171  51.595  1
473524  97.246  -63.177  51.560  1
473525  97.280  -63.183  51.525  1
473526  97.313  -63.188  51.488  1
473527  97.334  -63.195  51.450  1
473528  97.353  -63.205  51.411  1
473529  97.399  -63.220  51.372  1
473530  97.444  -63.218  51.334  1
473531  97.485  -63.193  51.297  1
473532  97.525  -63.168  51.260  1
473533  97.566  -63.143  51.223  1
473534  97.600  -63.120  51.187  1
473535  97.626  -63.120  51.149  1
473536  97.653  -63.122  51.110  1
473537  97.681  -63.125  51.071  1
473538  97.708  -63.130  51.032  1
473539  97.735  -63.135  50.993  1
473540  97.761  -63.140  50.952  1
473541  97.789  -63.145  50.906  1
473542  97.815  -63.151  50.862  1
473543  97.842  -63.155  50.816  1
473544  97.872  -63.162  50.769  1
473545  97.921  -63.177  50.718  1
473546  97.966  -63.179  50.666  1
473547  98.017  -63.189  50.613  1
473548  98.071  -63.203  50.559  1
473549  98.124  -63.217  50.505  1
473550  98.177  -63.231  50.450  1
473551  98.231  -63.245  50.397  1
473552  98.273  -63.260  50.345  1
473553  98.284  -63.275  50.295  1
473554  98.295  -63.290  50.247  1
473555  98.306  -63.305  50.200  1
473556  98.317  -63.320  50.154  1
473557  98.327  -63.335  50.109  1
473558  98.339  -63.350  50.065  1
473559  98.356  -63.365  50.022  1
473560  98.380  -63.381  49.978  1
473561  98.404  -63.396  49.935  1
473562  98.430  -63.389  49.891  1
473563  98.456  -63.376  49.849  1
473564  98.482  -63.364  49.808  1
473565  98.508  -63.351  49.766  1
473566  98.534  -63.339  49.725  1
473567  98.564  -63.333  49.684  1
473568  98.600  -63.336  49.646  1
473569  98.637  -63.341  49.607  1
473570  98.679  -63.334  49.568  1
473571  98.742  -63.332  49.529  1
473572  98.805  -63.330  49.493  1
473573  98.868  -63.328  49.456  1
473574  98.931  -63.327  49.420  1
473575  98.994  -63.325  49.385  1
473991  87.365  -61.383  56.095  1
473992  87.402  -61.384  56.083  1
473993  87.438  -61.387  56.071  1
473994  87.475  -61.388  56.060  1
473995  87.511  -61.390  56.048  1
473996  87.548  -61.392  56.036  1
473997  87.585  -61.393  56.025  1
473998  87.622  -61.396  56.012  1
473999  87.658  -61.397  56.000  1
474000  87.695  -61.399  55.986  1
474001  87.732  -61.401  55.972  1
474002  87.768  -61.403  55.957  1
474003  87.805  -61.404  55.943  1
474004  87.842  -61.406  55.927  1
474005  87.879  -61.408  55.912  1
474006  87.922  -61.407  55.896  1
474007  87.970  -61.403  55.879  1
474008  88.019  -61.400  55.860  1
474009  88.067  -61.396  55.843  1
474010  88.115  -61.393  55.827  1
474011  88.164  -61.390  55.812  1
474012  88.211  -61.387  55.798  1
474013  88.260  -61.384  55.787  1
474014  88.326  -61.389  55.775  1
474015  88.394  -61.396  55.760  1
474016  88.461  -61.402  55.740  1
474017  88.528  -61.408  55.715  1
474018  88.596  -61.415  55.683  1
474019  88.657  -61.424  55.648  1
474020  88.705  -61.439  55.615  1
474021  88.750  -61.456  55.590  1
474022  88.795  -61.484  55.571  1
474023  88.841  -61.517  55.562  1
474024  88.888  -61.549  55.556  1
474025  88.933  -61.581  55.550  1
474026  88.978  -61.606  55.543  1
474027  89.022  -61.627  55.531  1
474028  89.062  -61.638  55.512  1
474029  89.098  -61.637  55.489  1
474030  89.134  -61.638  55.463  1
474031  89.171  -61.639  55.436  1
474032  89.209  -61.641  55.406  1
474033  89.246  -61.642  55.379  1
474034  89.284  -61.644  55.353  1
474035  89.321  -61.646  55.329  1
474036  89.359  -61.647  55.308  1
474037  89.396  -61.649  55.289  1
474038  89.434  -61.650  55.274  1
474039  89.471  -61.652  55.261  1
474040  89.509  -61.653  55.250  1
474041  89.547  -61.657  55.240  1
474042  89.590  -61.666  55.231  1
474043  89.632  -61.676  55.225  1
474044  89.675  -61.685  55.218  1
474045  89.718  -61.695  55.213  1
474046  89.760  -61.705  55.210  1
474047  89.803  -61.714  55.209  1
474048  89.845  -61.724  55.211  1
474049  89.890  -61.744  55.210  1
474050  89.936  -61.766  55.208  1
474051  89.981  -61.787  55.204  1
474052  90.026  -61.808  55.201  1
474053  90.072  -61.829  55.202  1
474054  90.117  -61.851  55.206  1
474055  90.162  -61.873  55.210  1
474056  90.207  -61.894  55.215  1
474057  90.253  -61.915  55.219  1
474058  90.300  -61.934  55.217  1
474059  90.352  -61.946  55.210  1
474060  90.404  -61.959  55.196  1
474061  90.456  -61.971  55.173  1
474062  90.508  -61.984  55.146  1
474063  90.559  -61.997  55.114  1
474064  90.612  -62.009  55.089  1
474065  90.664  -62.022  55.070  1
474066  90.716  -62.035  55.058  1
474067  90.769  -62.050  55.052  1
474068  90.822  -62.065  55.051  1
474069  90.875  -62.080  55.056  1
474070  90.912  -62.096  55.064  1
474071  90.949  -62.114  55.072  1
474072  90.986  -62.127  55.079  1
474073  91.023  -62.139  55.084  1
474074  91.060  -62.152  55.087  1
474075  91.109  -62.155  55.085  1
474076  91.159  -62.157  55.076  1
474077  91.208  -62.160  55.060  1
474078  91.251  -62.169  55.050  1
474079  91.294  -62.179  55.047  1
474080  91.338  -62.188  55.050  1
474081  91.380  -62.197  55.057  1
474082  91.424  -62.207  55.063  1
474083  91.470  -62.222  55.056  1
474084  91.515  -62.239  55.038  1
474085  91.559  -62.257  55.020  1
474086  91.602  -62.274  55.013  1
474087  91.646  -62.291  55.017  1
474088  91.690  -62.308  55.020  1
474089  91.734  -62.326  55.014  1
474090  91.778  -62.343  55.000  1
474091  91.822  -62.361  54.976  1
474092  91.866  -62.378  54.942  1
474093  91.910  -62.395  54.902  1
474094  91.954  -62.412  54.864  1
474095  91.998  -62.430  54.830  1
474096  92.041  -62.447  54.803  1
474097  92.086  -62.465  54.782  1
474098  92.123  -62.467  54.767  1
474099  92.157  -62.459  54.752  1
474100  92.191  -62.451  54.736  1
474101  92.225  -62.442  54.721  1
474102  92.260  -62.434  54.705  1
474103  92.293  -62.425  54.686  1
474104  92.328  -62.417  54.665  1
474105  92.362  -62.409  54.643  1
474106  92.393  -62.406  54.620  1
474107  92.423  -62.409  54.596  1
474108  92.462  -62.414  54.572  1
474109  92.511  -62.421  54.549  1
474110  92.559  -62.428  54.526  1
474111  92.602  -62.433  54.503  1
474112  92.645  -62.438  54.482  1
474113  92.688  -62.443  54.462  1
474114  92.730  -62.448  54.443  1
474115  92.774  -62.453  54.425  1
474116  92.816  -62.459  54.407  1
474117  92.850  -62.465  54.391  1
474118  92.902  -62.468  54.380  1
474119  92.954  -62.470  54.374  1
474120  93.006  -62.473  54.370  1
474121  93.058  -62.475  54.369  1
474122  93.111  -62.478  54.363  1
474123  93.159  -62.483  54.355  1
474124  93.199  -62.494  54.344  1
474125  93.225  -62.531  54.331  1
474126  93.251  -62.569  54.316  1
474127  93.276  -62.607  54.298  1
474128  93.299  -62.607  54.277  1
474129  93.322  -62.593  54.256  1
474130  93.344  -62.579  54.234  1
474131  93.366  -62.565  54.212  1
474132  93.389  -62.551  54.193  1
474133  93.411  -62.537  54.178  1
474134  93.441  -62.532  54.163  1
474135  93.497  -62.555  54.148  1
474136  93.555  -62.579  54.133  1
474137  93.613  -62.603  54.118  1
474138  93.671  -62.628  54.101  1
474139  93.729  -62.652  54.082  1
474140  93.787  -62.676  54.063  1
474141  93.826  -62.700  54.043  1
474142  93.863  -62.725  54.022  1
474143  93.916  -62.737  54.003  1
474144  93.974  -62.746  53.984  1
474145  94.031  -62.755  53.965  1
474146  94.087  -62.764  53.946  1
474147  94.144  -62.773  53.927  1
474148  94.201  -62.782  53.907  1
474149  94.254  -62.772  53.888  1
474150  94.306  -62.753  53.870  1
474151  94.357  -62.736  53.852  1
474152  94.405  -62.714  53.834  1
474153  94.441  -62.710  53.814  1
474154  94.468  -62.723  53.794  1
474155  94.494  -62.738  53.775  1
474156  94.520  -62.754  53.756  1
474157  94.545  -62.769  53.738  1
474158  94.570  -62.785  53.720  1
474159  94.596  -62.800  53.700  1
474160  94.621  -62.816  53.678  1
474161  94.647  -62.832  53.656  1
474162  94.673  -62.847  53.634  1
474163  94.698  -62.863  53.610  1
474164  94.723  -62.879  53.586  1
474165  94.754  -62.888  53.561  1
474166  94.794  -62.884  53.535  1
474167  94.834  -62.881  53.508  1
474168  94.871  -62.898  53.481  1
474169  94.907  -62.916  53.452  1
474170  94.944  -62.933  53.422  1
474171  94.981  -62.949  53.392  1
474172  95.034  -62.949  53.359  1
474173  95.087  -62.949  53.330  1
474174  95.140  -62.949  53.302  1
474175  95.193  -62.949  53.275  1
474176  95.246  -62.949  53.248  1
474177  95.299  -62.949  53.219  1
474178  95.352  -62.949  53.186  1
474179  95.405  -62.949  53.152  1
474180  95.459  -62.950  53.117  1
474181  95.526  -62.962  53.082  1
474182  95.585  -62.979  53.047  1
474183  95.643  -62.997  53.011  1
474184  95.664  -62.983  52.975  1
474185  95.685  -62.969  52.938  1
474186  95.706  -62.955  52.901  1
474187  95.727  -62.941  52.865  1
474188  95.748  -62.929  52.828  1
474189  95.790  -62.915  52.791  1
474190  95.835  -62.899  52.754  1
474191  95.880  -62.883  52.715  1
474192  95.924  -62.867  52.677  1
474193  95.969  -62.851  52.642  1
474194  96.014  -62.835  52.607  1
474195  96.059  -62.820  52.573  1
474196  96.112  -62.819  52.539  1
474197  96.167  -62.849  52.506  1
474198  96.222  -62.883  52.470  1
474199  96.277  -62.916  52.434  1
474200  96.313  -62.934  52.397  1
474201  96.338  -62.943  52.361  1
474202  96.372  -62.948  52.324  1
474203  96.453  -62.933  52.287  1
474204  96.514  -62.925  52.249  1
474205  96.552  -62.936  52.208  1
474206  96.590  -62.947  52.167  1
474207  96.627  -62.957  52.126  1
474208  96.664  -62.968  52.087  1
474209  96.702  -62.979  52.049  1
474210  96.739  -62.989  52.011  1
474211  96.777  -63.000  51.975  1
474212  96.816  -63.013  51.941  1
474213  96.855  -63.025  51.909  1
474214  96.894  -63.037  51.877  1
474215  96.933  -63.049  51.847  1
474216  96.972  -63.062  51.817  1
474217  97.011  -63.074  51.787  1
474218  97.043  -63.092  51.757  1
474219  97.075  -63.096  51.727  1
474220  97.105  -63.101  51.697  1
474221  97.136  -63.105  51.666  1
474222  97.167  -63.110  51.636  1
474223  97.197  -63.119  51.605  1
474224  97.226  -63.128  51.572  1
474225  97.251  -63.137  51.539  1
474226  97.283  -63.144  51.506  1
474227  97.316  -63.149  51.471  1
474228  97.339  -63.156  51.434  1
474229  97.386  -63.172  51.394  1
474230  97.434  -63.189  51.353  1
474231  97.478  -63.191  51.313  1
474232  97.519  -63.166  51.274  1
474233  97.560  -63.141  51.235  1
474234  97.597  -63.117  51.197  1
474235  97.604  -63.100  51.159  1
474236  97.626  -63.097  51.121  1
474237  97.654  -63.099  51.080  1
474238  97.681  -63.101  51.038  1
474239  97.709  -63.104  50.997  1
474240  97.737  -63.106  50.955  1
474241  97.765  -63.108  50.913  1
474242  97.793  -63.111  50.869  1
474243  97.820  -63.113  50.825  1
474244  97.848  -63.116  50.780  1
474245  97.876  -63.117  50.733  1
474246  97.924  -63.124  50.684  1
474247  97.977  -63.138  50.632  1
474248  98.031  -63.152  50.578  1
474249  98.084  -63.167  50.525  1
474250  98.138  -63.181  50.472  1
474251  98.192  -63.195  50.419  1
474252  98.245  -63.209  50.368  1
474253  98.266  -63.224  50.318  1
474254  98.277  -63.239  50.270  1
474255  98.287  -63.254  50.223  1
474256  98.298  -63.269  50.176  1
474257  98.309  -63.284  50.130  1
474258  98.320  -63.299  50.087  1
474259  98.334  -63.314  50.044  1
474260  98.358  -63.330  50.000  1
474261  98.382  -63.346  49.957  1
474262  98.407  -63.357  49.915  1
474263  98.432  -63.345  49.872  1
474264  98.458  -63.332  49.830  1
474265  98.485  -63.320  49.789  1
474266  98.510  -63.307  49.748  1
474267  98.536  -63.295  49.708  1
474268  98.570  -63.295  49.668  1
474269  98.606  -63.299  49.629  1
474270  98.643  -63.304  49.592  1
474271  98.688  -63.295  49.554  1
474272  98.750  -63.293  49.517  1
474273  98.813  -63.292  49.481  1
474274  98.876  -63.289  49.445  1
474275  98.939  -63.288  49.410  1
474276  99.002  -63.286  49.375  1
474692  87.380  -61.335  56.089  1
474693  87.417  -61.337  56.078  1
474694  87.454  -61.338  56.066  1
474695  87.490  -61.340  56.055  1
474696  87.527  -61.342  56.043  1
474697  87.563  -61.344  56.030  1
474698  87.600  -61.346  56.019  1
474699  87.637  -61.347  56.007  1
474700  87.674  -61.349  55.994  1
474701  87.710  -61.351  55.980  1
474702  87.747  -61.353  55.965  1
474703  87.784  -61.355  55.950  1
474704  87.821  -61.356  55.935  1
474705  87.857  -61.359  55.920  1
474706  87.894  -61.360  55.904  1
474707  87.931  -61.362  55.888  1
474708  87.980  -61.358  55.870  1
474709  88.028  -61.355  55.851  1
474710  88.076  -61.351  55.834  1
474711  88.125  -61.348  55.817  1
474712  88.173  -61.345  55.801  1
474713  88.221  -61.341  55.785  1
474714  88.270  -61.338  55.771  1
474715  88.337  -61.344  55.759  1
474716  88.405  -61.351  55.744  1
474717  88.472  -61.357  55.725  1
474718  88.539  -61.364  55.701  1
474719  88.607  -61.370  55.672  1
474720  88.673  -61.377  55.638  1
474721  88.721  -61.392  55.604  1
474722  88.766  -61.415  55.577  1
474723  88.812  -61.447  55.556  1
474724  88.858  -61.479  55.544  1
474725  88.903  -61.505  55.536  1
474726  88.948  -61.531  55.530  1
474727  88.992  -61.556  55.522  1
474728  89.036  -61.574  55.510  1
474729  89.079  -61.592  55.492  1
474730  89.119  -61.603  55.471  1
474731  89.154  -61.601  55.448  1
474732  89.189  -61.600  55.425  1
474733  89.224  -61.598  55.399  1
474734  89.261  -61.600  55.372  1
474735  89.299  -61.601  55.346  1
474736  89.336  -61.603  55.322  1
474737  89.374  -61.604  55.300  1
474738  89.411  -61.606  55.280  1
474739  89.449  -61.607  55.265  1
474740  89.486  -61.609  55.252  1
474741  89.524  -61.611  55.240  1
474742  89.561  -61.613  55.230  1
474743  89.600  -61.616  55.222  1
474744  89.642  -61.625  55.216  1
474745  89.685  -61.635  55.211  1
474746  89.727  -61.644  55.207  1
474747  89.770  -61.654  55.204  1
474748  89.812  -61.664  55.204  1
474749  89.856  -61.675  55.208  1
474750  89.901  -61.696  55.211  1
474751  89.946  -61.717  55.210  1
474752  89.991  -61.738  55.206  1
474753  90.037  -61.760  55.200  1
474754  90.082  -61.781  55.198  1
474755  90.127  -61.803  55.197  1
474756  90.173  -61.824  55.198  1
474757  90.218  -61.845  55.201  1
474758  90.263  -61.867  55.204  1
474759  90.309  -61.888  55.204  1
474760  90.360  -61.901  55.198  1
474761  90.412  -61.914  55.186  1
474762  90.464  -61.926  55.165  1
474763  90.516  -61.939  55.138  1
474764  90.568  -61.951  55.108  1
474765  90.620  -61.964  55.083  1
474766  90.673  -61.979  55.066  1
474767  90.726  -61.994  55.054  1
474768  90.779  -62.009  55.050  1
474769  90.831  -62.023  55.050  1
474770  90.880  -62.039  55.055  1
474771  90.917  -62.056  55.063  1
474772  90.953  -62.073  55.073  1
474773  90.990  -62.090  55.084  1
474774  91.027  -62.102  55.092  1
474775  91.072  -62.108  55.097  1
474776  91.122  -62.110  55.097  1
474777  91.172  -62.112  55.089  1
474778  91.220  -62.117  55.072  1
474779  91.263  -62.126  55.061  1
474780  91.306  -62.136  55.058  1
474781  91.349  -62.145  55.063  1
474782  91.392  -62.154  55.071  1
474783  91.435  -62.164  55.073  1
474784  91.477  -62.177  55.062  1
474785  91.521  -62.193  55.044  1
474786  91.566  -62.211  55.029  1
474787  91.609  -62.228  55.027  1
474788  91.654  -62.246  55.030  1
474789  91.698  -62.262  55.029  1
474790  91.742  -62.280  55.021  1
474791  91.786  -62.297  55.005  1
474792  91.830  -62.315  54.980  1
474793  91.874  -62.332  54.945  1
474794  91.918  -62.349  54.905  1
474795  91.962  -62.366  54.866  1
474796  92.006  -62.384  54.832  1
474797  92.047  -62.401  54.804  1
474798  92.085  -62.420  54.779  1
474799  92.120  -62.418  54.760  1
474800  92.156  -62.406  54.744  1
474801  92.193  -62.392  54.726  1
474802  92.229  -62.377  54.707  1
474803  92.265  -62.365  54.688  1
474804  92.299  -62.357  54.668  1
474805  92.329  -62.359  54.645  1
474806  92.358  -62.362  54.622  1
474807  92.387  -62.365  54.599  1
474808  92.425  -62.370  54.576  1
474809  92.474  -62.377  54.555  1
474810  92.523  -62.384  54.534  1
474811  92.572  -62.392  54.513  1
474812  92.619  -62.399  54.492  1
474813  92.662  -62.403  54.474  1
474814  92.705  -62.409  54.456  1
474815  92.747  -62.414  54.438  1
474816  92.791  -62.418  54.420  1
474817  92.823  -62.426  54.402  1
474818  92.860  -62.432  54.389  1
474819  92.912  -62.434  54.380  1
474820  92.964  -62.437  54.376  1
474821  93.016  -62.440  54.375  1
474822  93.068  -62.442  54.375  1
474823  93.114  -62.449  54.370  1
474824  93.154  -62.461  54.362  1
474825  93.194  -62.472  54.350  1
474826  93.227  -62.496  54.337  1
474827  93.253  -62.534  54.321  1
474828  93.278  -62.572  54.304  1
474829  93.300  -62.560  54.284  1
474830  93.323  -62.547  54.262  1
474831  93.345  -62.532  54.240  1
474832  93.367  -62.518  54.219  1
474833  93.390  -62.504  54.203  1
474834  93.426  -62.498  54.188  1
474835  93.469  -62.499  54.174  1
474836  93.527  -62.523  54.160  1
474837  93.585  -62.547  54.147  1
474838  93.643  -62.572  54.132  1
474839  93.701  -62.596  54.114  1
474840  93.759  -62.620  54.095  1
474841  93.797  -62.644  54.076  1
474842  93.834  -62.669  54.055  1
474843  93.871  -62.693  54.034  1
474844  93.928  -62.702  54.014  1
474845  93.985  -62.711  53.994  1
474846  94.042  -62.720  53.973  1
474847  94.099  -62.729  53.953  1
474848  94.156  -62.738  53.931  1
474849  94.211  -62.738  53.910  1
474850  94.262  -62.720  53.890  1
474851  94.314  -62.703  53.870  1
474852  94.365  -62.684  53.850  1
474853  94.416  -62.666  53.830  1
474854  94.454  -62.667  53.808  1
474855  94.479  -62.685  53.786  1
474856  94.505  -62.702  53.764  1
474857  94.531  -62.718  53.743  1
474858  94.556  -62.733  53.723  1
474859  94.581  -62.749  53.704  1
474860  94.607  -62.764  53.683  1
474861  94.632  -62.780  53.661  1
474862  94.658  -62.795  53.637  1
474863  94.683  -62.811  53.613  1
474864  94.709  -62.826  53.589  1
474865  94.735  -62.842  53.564  1
474866  94.766  -62.850  53.538  1
474867  94.806  -62.847  53.511  1
474868  94.842  -62.864  53.483  1
474869  94.879  -62.882  53.455  1
474870  94.916  -62.899  53.426  1
474871  94.953  -62.916  53.395  1
474872  94.997  -62.925  53.365  1
474873  95.050  -62.925  53.333  1
474874  95.103  -62.925  53.302  1
474875  95.156  -62.925  53.272  1
474876  95.209  -62.925  53.244  1
474877  95.262  -62.925  53.217  1
474878  95.315  -62.925  53.189  1
474879  95.368  -62.925  53.157  1
474880  95.420  -62.925  53.124  1
474881  95.473  -62.925  53.090  1
474882  95.530  -62.927  53.055  1
474883  95.592  -62.943  53.020  1
474884  95.639  -62.951  52.987  1
474885  95.660  -62.937  52.952  1
474886  95.681  -62.923  52.916  1
474887  95.703  -62.912  52.880  1
474888  95.731  -62.910  52.845  1
474889  95.759  -62.908  52.808  1
474890  95.801  -62.895  52.771  1
474891  95.846  -62.879  52.733  1
474892  95.891  -62.863  52.695  1
474893  95.936  -62.847  52.659  1
474894  95.980  -62.832  52.622  1
474895  96.025  -62.816  52.586  1
474896  96.078  -62.814  52.551  1
474897  96.130  -62.813  52.517  1
474898  96.183  -62.813  52.481  1
474899  96.236  -62.812  52.446  1
474900  96.291  -62.845  52.410  1
474901  96.319  -62.857  52.373  1
474902  96.344  -62.866  52.337  1
474903  96.369  -62.874  52.300  1
474904  96.452  -62.879  52.262  1
474905  96.508  -62.890  52.224  1
474906  96.546  -62.903  52.185  1
474907  96.585  -62.915  52.144  1
474908  96.624  -62.927  52.105  1
474909  96.663  -62.939  52.067  1
474910  96.702  -62.952  52.029  1
474911  96.741  -62.964  51.992  1
474912  96.780  -62.976  51.956  1
474913  96.819  -62.988  51.921  1
474914  96.858  -63.001  51.888  1
474915  96.897  -63.014  51.856  1
474916  96.936  -63.026  51.824  1
474917  96.972  -63.040  51.793  1
474918  97.005  -63.057  51.763  1
474919  97.038  -63.076  51.733  1
474920  97.070  -63.092  51.703  1
474921  97.101  -63.097  51.672  1
474922  97.132  -63.101  51.642  1
474923  97.163  -63.106  51.612  1
474924  97.193  -63.111  51.581  1
474925  97.225  -63.115  51.549  1
474926  97.255  -63.120  51.517  1
474927  97.286  -63.124  51.485  1
474928  97.320  -63.128  51.451  1
474929  97.372  -63.128  51.415  1
474930  97.420  -63.140  51.375  1
474931  97.467  -63.156  51.334  1
474932  97.513  -63.164  51.293  1
474933  97.554  -63.139  51.252  1
474934  97.594  -63.114  51.211  1
474935  97.601  -63.097  51.172  1
474936  97.608  -63.080  51.133  1
474937  97.626  -63.073  51.093  1
474938  97.654  -63.076  51.051  1
474939  97.681  -63.079  51.007  1
474940  97.710  -63.081  50.964  1
474941  97.737  -63.083  50.921  1
474942  97.765  -63.086  50.878  1
474943  97.793  -63.088  50.834  1
474944  97.820  -63.090  50.790  1
474945  97.851  -63.086  50.745  1
474946  97.884  -63.074  50.698  1
474947  97.938  -63.088  50.650  1
474948  97.991  -63.102  50.599  1
474949  98.044  -63.117  50.546  1
474950  98.098  -63.130  50.494  1
474951  98.152  -63.145  50.443  1
474952  98.206  -63.159  50.391  1
474953  98.247  -63.173  50.342  1
474954  98.258  -63.189  50.294  1
474955  98.269  -63.204  50.247  1
474956  98.280  -63.218  50.201  1
474957  98.291  -63.233  50.155  1
474958  98.302  -63.249  50.110  1
474959  98.313  -63.264  50.067  1
474960  98.336  -63.279  50.024  1
474961  98.360  -63.295  49.982  1
474962  98.384  -63.311  49.939  1
474963  98.409  -63.314  49.896  1
474964  98.435  -63.301  49.854  1
474965  98.461  -63.289  49.813  1
474966  98.487  -63.276  49.772  1
474967  98.513  -63.264  49.732  1
474968  98.540  -63.253  49.693  1
474969  98.576  -63.258  49.654  1
474970  98.613  -63.262  49.616  1
474971  98.649  -63.266  49.579  1
474972  98.696  -63.256  49.542  1
474973  98.759  -63.255  49.506  1
474974  98.822  -63.252  49.470  1
474975  98.885  -63.251  49.435  1
474976  98.948  -63.249  49.400  1
475394  87.432  -61.289  56.071  1
475395  87.469  -61.290  56.061  1
475396  87.505  -61.293  56.049  1
475397  87.542  -61.294  56.037  1
475398  87.579  -61.296  56.024  1
475399  87.616  -61.298  56.012  1
475400  87.652  -61.299  56.000  1
475401  87.689  -61.302  55.987  1
475402  87.725  -61.303  55.973  1
475403  87.762  -61.305  55.958  1
475404  87.799  -61.307  55.942  1
475405  87.836  -61.309  55.928  1
475406  87.872  -61.310  55.912  1
475407  87.909  -61.312  55.896  1
475408  87.945  -61.314  55.879  1
475409  87.989  -61.313  55.861  1
475410  88.038  -61.309  55.842  1
475411  88.086  -61.306  55.824  1
475412  88.134  -61.302  55.807  1
475413  88.182  -61.299  55.789  1
475414  88.231  -61.296  55.771  1
475415  88.281  -61.293  55.755  1
475416  88.348  -61.300  55.739  1
475417  88.415  -61.306  55.722  1
475418  88.483  -61.312  55.704  1
475419  88.550  -61.319  55.683  1
475420  88.618  -61.325  55.657  1
475421  88.685  -61.332  55.625  1
475422  88.737  -61.345  55.592  1
475423  88.783  -61.376  55.563  1
475424  88.828  -61.403  55.540  1
475425  88.873  -61.429  55.524  1
475426  88.917  -61.454  55.514  1
475427  88.962  -61.480  55.506  1
475428  89.006  -61.503  55.498  1
475429  89.049  -61.521  55.486  1
475430  89.092  -61.539  55.468  1
475431  89.135  -61.557  55.449  1
475432  89.175  -61.567  55.429  1
475433  89.210  -61.566  55.408  1
475434  89.245  -61.563  55.383  1
475435  89.280  -61.562  55.359  1
475436  89.315  -61.560  55.335  1
475437  89.351  -61.559  55.312  1
475438  89.388  -61.561  55.290  1
475439  89.426  -61.563  55.271  1
475440  89.463  -61.565  55.255  1
475441  89.501  -61.566  55.242  1
475442  89.538  -61.568  55.231  1
475443  89.576  -61.569  55.222  1
475444  89.613  -61.571  55.213  1
475445  89.652  -61.575  55.207  1
475446  89.695  -61.584  55.203  1
475447  89.737  -61.594  55.200  1
475448  89.780  -61.603  55.198  1
475449  89.822  -61.613  55.198  1
475450  89.866  -61.626  55.204  1
475451  89.911  -61.647  55.209  1
475452  89.957  -61.669  55.212  1
475453  90.002  -61.690  55.210  1
475454  90.047  -61.711  55.203  1
475455  90.093  -61.733  55.197  1
475456  90.138  -61.754  55.192  1
475457  90.183  -61.776  55.189  1
475458  90.229  -61.797  55.191  1
475459  90.274  -61.818  55.192  1
475460  90.319  -61.839  55.191  1
475461  90.368  -61.856  55.185  1
475462  90.420  -61.869  55.172  1
475463  90.472  -61.881  55.152  1
475464  90.524  -61.894  55.127  1
475465  90.577  -61.908  55.099  1
475466  90.629  -61.923  55.076  1
475467  90.682  -61.938  55.061  1
475468  90.735  -61.953  55.050  1
475469  90.788  -61.967  55.046  1
475470  90.841  -61.983  55.046  1
475471  90.885  -61.998  55.051  1
475472  90.921  -62.016  55.060  1
475473  90.957  -62.033  55.072  1
475474  90.994  -62.050  55.085  1
475475  91.035  -62.061  55.096  1
475476  91.085  -62.064  55.103  1
475477  91.135  -62.066  55.104  1
475478  91.185  -62.067  55.099  1
475479  91.232  -62.073  55.081  1
475480  91.275  -62.083  55.071  1
475481  91.318  -62.092  55.070  1
475482  91.361  -62.102  55.076  1
475483  91.403  -62.111  55.083  1
475484  91.445  -62.120  55.079  1
475485  91.487  -62.130  55.066  1
475486  91.530  -62.147  55.049  1
475487  91.575  -62.164  55.038  1
475488  91.618  -62.181  55.041  1
475489  91.663  -62.199  55.041  1
475490  91.707  -62.216  55.036  1
475491  91.750  -62.233  55.024  1
475492  91.795  -62.250  55.006  1
475493  91.839  -62.268  54.981  1
475494  91.883  -62.285  54.946  1
475495  91.927  -62.302  54.907  1
475496  91.968  -62.320  54.869  1
475497  92.006  -62.338  54.833  1
475498  92.044  -62.356  54.803  1
475499  92.081  -62.369  54.778  1
475500  92.116  -62.365  54.756  1
475501  92.150  -62.362  54.736  1
475502  92.186  -62.352  54.717  1
475503  92.223  -62.337  54.696  1
475504  92.260  -62.323  54.675  1
475505  92.293  -62.316  54.653  1
475506  92.322  -62.319  54.631  1
475507  92.351  -62.321  54.608  1
475508  92.388  -62.327  54.586  1
475509  92.437  -62.333  54.564  1
475510  92.486  -62.341  54.544  1
475511  92.535  -62.348  54.525  1
475512  92.584  -62.355  54.505  1
475513  92.633  -62.362  54.487  1
475514  92.679  -62.369  54.470  1
475515  92.722  -62.374  54.454  1
475516  92.765  -62.379  54.437  1
475517  92.808  -62.384  54.419  1
475518  92.826  -62.394  54.400  1
475519  92.869  -62.399  54.387  1
475520  92.922  -62.401  54.381  1
475521  92.974  -62.404  54.377  1
475522  93.026  -62.406  54.377  1
475523  93.068  -62.416  54.377  1
475524  93.108  -62.428  54.372  1
475525  93.148  -62.438  54.363  1
475526  93.189  -62.449  54.351  1
475527  93.228  -62.461  54.337  1
475528  93.255  -62.498  54.322  1
475529  93.279  -62.528  54.304  1
475530  93.302  -62.514  54.285  1
475531  93.324  -62.500  54.264  1
475532  93.347  -62.486  54.243  1
475533  93.377  -62.476  54.224  1
475534  93.417  -62.472  54.210  1
475535  93.458  -62.468  54.196  1
475536  93.499  -62.467  54.182  1
475537  93.557  -62.491  54.170  1
475538  93.615  -62.515  54.157  1
475539  93.673  -62.540  54.142  1
475540  93.731  -62.564  54.125  1
475541  93.768  -62.588  54.109  1
475542  93.805  -62.612  54.092  1
475543  93.843  -62.637  54.074  1
475544  93.883  -62.659  54.055  1
475545  93.940  -62.668  54.036  1
475546  93.997  -62.677  54.014  1
475547  94.054  -62.686  53.991  1
475548  94.111  -62.695  53.967  1
475549  94.168  -62.704  53.942  1
475550  94.219  -62.687  53.917  1
475551  94.271  -62.669  53.893  1
475552  94.322  -62.651  53.869  1
475553  94.373  -62.633  53.846  1
475554  94.418  -62.633  53.824  1
475555  94.468  -62.639  53.800  1
475556  94.517  -62.646  53.777  1
475557  94.518  -62.646  53.753  1
475558  94.543  -62.665  53.729  1
475559  94.568  -62.684  53.709  1
475560  94.594  -62.702  53.687  1
475561  94.619  -62.721  53.664  1
475562  94.644  -62.739  53.640  1
475563  94.669  -62.758  53.616  1
475564  94.694  -62.775  53.590  1
475565  94.720  -62.791  53.565  1
475566  94.746  -62.806  53.539  1
475567  94.778  -62.813  53.512  1
475568  94.814  -62.831  53.484  1
475569  94.851  -62.848  53.455  1
475570  94.888  -62.865  53.426  1
475571  94.924  -62.882  53.396  1
475572  94.961  -62.900  53.366  1
475573  95.013  -62.901  53.335  1
475574  95.066  -62.901  53.304  1
475575  95.119  -62.901  53.273  1
475576  95.172  -62.901  53.243  1
475577  95.225  -62.901  53.215  1
475578  95.277  -62.901  53.187  1
475579  95.330  -62.901  53.160  1
475580  95.383  -62.901  53.130  1
475581  95.436  -62.901  53.097  1
475582  95.489  -62.901  53.063  1
475583  95.542  -62.901  53.028  1
475584  95.599  -62.906  52.995  1
475585  95.634  -62.904  52.962  1
475586  95.658  -62.895  52.928  1
475587  95.686  -62.894  52.893  1
475588  95.714  -62.892  52.858  1
475589  95.742  -62.890  52.823  1
475590  95.770  -62.888  52.786  1
475591  95.812  -62.875  52.749  1
475592  95.857  -62.859  52.712  1
475593  95.902  -62.843  52.675  1
475594  95.947  -62.827  52.639  1
475595  95.991  -62.811  52.602  1
475596  96.044  -62.810  52.565  1
475597  96.096  -62.809  52.529  1
475598  96.149  -62.808  52.494  1
475599  96.201  -62.807  52.458  1
475600  96.254  -62.807  52.423  1
475601  96.300  -62.797  52.387  1
475602  96.324  -62.813  52.350  1
475603  96.349  -62.829  52.313  1
475604  96.376  -62.844  52.277  1
475605  96.471  -62.854  52.240  1
475606  96.510  -62.866  52.202  1
475607  96.549  -62.879  52.164  1
475608  96.588  -62.891  52.125  1
475609  96.627  -62.904  52.086  1
475610  96.666  -62.916  52.048  1
475611  96.705  -62.928  52.010  1
475612  96.744  -62.940  51.972  1
475613  96.783  -62.953  51.936  1
475614  96.822  -62.965  51.901  1
475615  96.861  -62.977  51.868  1
475616  96.899  -62.989  51.836  1
475617  96.934  -63.006  51.804  1
475618  96.966  -63.023  51.772  1
475619  96.999  -63.042  51.742  1
475620  97.032  -63.059  51.711  1
475621  97.065  -63.077  51.680  1
475622  97.097  -63.093  51.649  1
475623  97.128  -63.098  51.618  1
475624  97.159  -63.102  51.587  1
475625  97.189  -63.107  51.557  1
475626  97.220  -63.111  51.525  1
475627  97.251  -63.116  51.493  1
475628  97.298  -63.117  51.460  1
475629  97.349  -63.117  51.427  1
475630  97.400  -63.117  51.391  1
475631  97.452  -63.117  51.353  1
475632  97.501  -63.123  51.313  1
475633  97.548  -63.136  51.272  1
475634  97.588  -63.111  51.230  1
475635  97.598  -63.094  51.188  1
475636  97.605  -63.077  51.148  1
475637  97.611  -63.061  51.107  1
475638  97.626  -63.051  51.065  1
475639  97.654  -63.053  51.022  1
475640  97.682  -63.055  50.978  1
475641  97.710  -63.057  50.934  1
475642  97.737  -63.061  50.890  1
475643  97.765  -63.063  50.845  1
475644  97.793  -63.065  50.801  1
475645  97.826  -63.054  50.758  1
475646  97.859  -63.042  50.712  1
475647  97.898  -63.038  50.664  1
475648  97.951  -63.051  50.616  1
475649  98.005  -63.066  50.567  1
475650  98.059  -63.080  50.516  1
475651  98.112  -63.095  50.466  1
475652  98.166  -63.109  50.417  1
475653  98.220  -63.123  50.367  1
475654  98.240  -63.138  50.319  1
475655  98.250  -63.153  50.273  1
475656  98.262  -63.167  50.227  1
475657  98.273  -63.183  50.181  1
475658  98.283  -63.198  50.136  1
475659  98.294  -63.213  50.092  1
475660  98.313  -63.228  50.049  1
475661  98.337  -63.244  50.007  1
475662  98.361  -63.259  49.965  1
475663  98.385  -63.275  49.922  1
475664  98.411  -63.270  49.879  1
475665  98.437  -63.258  49.839  1
475666  98.463  -63.245  49.797  1
475667  98.489  -63.233  49.757  1
475668  98.515  -63.220  49.718  1
475669  98.547  -63.216  49.679  1
475670  98.583  -63.220  49.641  1
475671  98.619  -63.224  49.604  1
475672  98.655  -63.228  49.567  1
475673  98.705  -63.217  49.531  1
475674  98.768  -63.216  49.495  1
475675  98.831  -63.214  49.461  1
475676  98.894  -63.212  49.426  1
476096  87.484  -61.243  56.054  1
476097  87.520  -61.244  56.042  1
476098  87.557  -61.246  56.030  1
476099  87.594  -61.248  56.017  1
476100  87.631  -61.250  56.005  1
476101  87.668  -61.252  55.993  1
476102  87.704  -61.253  55.980  1
476103  87.741  -61.255  55.965  1
476104  87.777  -61.257  55.951  1
476105  87.814  -61.259  55.934  1
476106  87.851  -61.261  55.920  1
476107  87.888  -61.262  55.905  1
476108  87.924  -61.265  55.888  1
476109  87.961  -61.266  55.870  1
476110  87.999  -61.268  55.853  1
476111  88.047  -61.264  55.834  1
476112  88.095  -61.261  55.815  1
476113  88.143  -61.257  55.797  1
476114  88.192  -61.254  55.778  1
476115  88.240  -61.251  55.759  1
476116  88.292  -61.249  55.740  1
476117  88.359  -61.255  55.721  1
476118  88.426  -61.262  55.702  1
476119  88.494  -61.268  55.682  1
476120  88.561  -61.274  55.661  1
476121  88.629  -61.281  55.636  1
476122  88.696  -61.287  55.607  1
476123  88.753  -61.302  55.575  1
476124  88.798  -61.328  55.547  1
476125  88.842  -61.353  55.523  1
476126  88.887  -61.378  55.504  1
476127  88.931  -61.404  55.490  1
476128  88.976  -61.430  55.480  1
476129  89.020  -61.450  55.472  1
476130  89.063  -61.468  55.458  1
476131  89.106  -61.486  55.441  1
476132  89.149  -61.504  55.423  1
476133  89.192  -61.522  55.405  1
476134  89.232  -61.531  55.384  1
476135  89.266  -61.529  55.361  1
476136  89.302  -61.528  55.340  1
476137  89.337  -61.526  55.319  1
476138  89.372  -61.525  55.300  1
476139  89.407  -61.523  55.281  1
476140  89.442  -61.522  55.261  1
476141  89.478  -61.522  55.245  1
476142  89.516  -61.523  55.232  1
476143  89.553  -61.525  55.220  1
476144  89.591  -61.526  55.212  1
476145  89.628  -61.528  55.204  1
476146  89.666  -61.530  55.198  1
476147  89.704  -61.534  55.194  1
476148  89.747  -61.544  55.191  1
476149  89.790  -61.553  55.189  1
476150  89.832  -61.563  55.190  1
476151  89.876  -61.578  55.194  1
476152  89.921  -61.599  55.200  1
476153  89.967  -61.620  55.208  1
476154  90.012  -61.641  55.211  1
476155  90.057  -61.663  55.208  1
476156  90.103  -61.685  55.202  1
476157  90.149  -61.706  55.194  1
476158  90.194  -61.727  55.186  1
476159  90.239  -61.748  55.184  1
476160  90.285  -61.769  55.183  1
476161  90.330  -61.791  55.179  1
476162  90.376  -61.811  55.170  1
476163  90.428  -61.823  55.156  1
476164  90.480  -61.838  55.138  1
476165  90.533  -61.852  55.114  1
476166  90.586  -61.867  55.089  1
476167  90.639  -61.882  55.069  1
476168  90.692  -61.897  55.056  1
476169  90.745  -61.912  55.046  1
476170  90.798  -61.926  55.043  1
476171  90.851  -61.942  55.043  1
476172  90.889  -61.958  55.049  1
476173  90.926  -61.975  55.058  1
476174  90.962  -61.992  55.070  1
476175  91.002  -62.006  55.083  1
476176  91.050  -62.013  55.096  1
476177  91.098  -62.019  55.105  1
476178  91.148  -62.021  55.108  1
476179  91.198  -62.023  55.104  1
476180  91.243  -62.030  55.085  1
476181  91.287  -62.039  55.076  1
476182  91.329  -62.049  55.075  1
476183  91.371  -62.058  55.081  1
476184  91.413  -62.068  55.087  1
476185  91.455  -62.078  55.080  1
476186  91.497  -62.087  55.065  1
476187  91.539  -62.100  55.053  1
476188  91.583  -62.117  55.048  1
476189  91.628  -62.134  55.053  1
476190  91.671  -62.152  55.051  1
476191  91.716  -62.169  55.040  1
476192  91.759  -62.186  55.023  1
476193  91.804  -62.203  55.001  1
476194  91.848  -62.221  54.978  1
476195  91.889  -62.238  54.945  1
476196  91.927  -62.257  54.907  1
476197  91.964  -62.275  54.870  1
476198  92.002  -62.293  54.834  1
476199  92.040  -62.312  54.804  1
476200  92.076  -62.317  54.778  1
476201  92.111  -62.314  54.754  1
476202  92.146  -62.311  54.731  1
476203  92.180  -62.308  54.711  1
476204  92.216  -62.297  54.690  1
476205  92.253  -62.283  54.667  1
476206  92.287  -62.275  54.645  1
476207  92.316  -62.278  54.622  1
476208  92.351  -62.283  54.600  1
476209  92.400  -62.290  54.579  1
476210  92.449  -62.297  54.558  1
476211  92.498  -62.304  54.538  1
476212  92.547  -62.312  54.520  1
476213  92.596  -62.318  54.503  1
476214  92.645  -62.326  54.488  1
476215  92.694  -62.333  54.472  1
476216  92.739  -62.339  54.457  1
476217  92.782  -62.344  54.440  1
476218  92.813  -62.352  54.419  1
476219  92.829  -62.362  54.398  1
476220  92.879  -62.365  54.386  1
476221  92.931  -62.368  54.380  1
476222  92.983  -62.371  54.377  1
476223  93.023  -62.383  54.375  1
476224  93.063  -62.393  54.374  1
476225  93.103  -62.405  54.367  1
476226  93.143  -62.416  54.359  1
476227  93.183  -62.428  54.347  1
476228  93.223  -62.439  54.332  1
476229  93.257  -62.462  54.317  1
476230  93.281  -62.481  54.300  1
476231  93.303  -62.467  54.281  1
476232  93.328  -62.454  54.261  1
476233  93.368  -62.450  54.243  1
476234  93.409  -62.446  54.227  1
476235  93.449  -62.443  54.214  1
476236  93.489  -62.440  54.202  1
476237  93.530  -62.436  54.191  1
476238  93.587  -62.459  54.180  1
476239  93.645  -62.484  54.168  1
476240  93.702  -62.508  54.154  1
476241  93.739  -62.532  54.139  1
476242  93.776  -62.556  54.125  1
476243  93.814  -62.581  54.112  1
476244  93.851  -62.605  54.098  1
476245  93.895  -62.624  54.082  1
476246  93.952  -62.633  54.063  1
476247  94.009  -62.642  54.040  1
476248  94.066  -62.651  54.014  1
476249  94.123  -62.660  53.988  1
476250  94.176  -62.653  53.960  1
476251  94.227  -62.635  53.932  1
476252  94.279  -62.618  53.903  1
476253  94.330  -62.600  53.876  1
476254  94.376  -62.599  53.849  1
476255  94.420  -62.603  53.823  1
476256  94.469  -62.609  53.796  1
476257  94.523  -62.617  53.769  1
476258  94.577  -62.625  53.742  1
476259  94.580  -62.625  53.717  1
476260  94.581  -62.625  53.693  1
476261  94.607  -62.644  53.668  1
476262  94.632  -62.663  53.642  1
476263  94.657  -62.681  53.617  1
476264  94.682  -62.700  53.592  1
476265  94.707  -62.719  53.566  1
476266  94.733  -62.738  53.539  1
476267  94.772  -62.765  53.511  1
476268  94.802  -62.805  53.482  1
476269  94.829  -62.819  53.452  1
476270  94.859  -62.832  53.423  1
476271  94.896  -62.849  53.393  1
476272  94.933  -62.866  53.362  1
476273  94.976  -62.877  53.332  1
476274  95.029  -62.877  53.303  1
476275  95.082  -62.877  53.273  1
476276  95.134  -62.877  53.243  1
476277  95.187  -62.877  53.214  1
476278  95.240  -62.877  53.187  1
476279  95.293  -62.877  53.161  1
476280  95.346  -62.877  53.134  1
476281  95.398  -62.876  53.103  1
476282  95.449  -62.876  53.071  1
476283  95.499  -62.875  53.037  1
476284  95.549  -62.873  53.002  1
476285  95.600  -62.873  52.970  1
476286  95.641  -62.877  52.937  1
476287  95.669  -62.876  52.903  1
476288  95.697  -62.873  52.869  1
476289  95.725  -62.872  52.835  1
476290  95.753  -62.870  52.800  1
476291  95.781  -62.869  52.764  1
476292  95.823  -62.855  52.727  1
476293  95.868  -62.839  52.691  1
476294  95.913  -62.823  52.655  1
476295  95.958  -62.807  52.618  1
476296  96.010  -62.804  52.582  1
476297  96.062  -62.804  52.545  1
476298  96.115  -62.803  52.508  1
476299  96.167  -62.802  52.473  1
476300  96.213  -62.791  52.438  1
476301  96.256  -62.775  52.402  1
476302  96.304  -62.774  52.366  1
476303  96.329  -62.790  52.330  1
476304  96.354  -62.806  52.292  1
476305  96.400  -62.819  52.256  1
476306  96.474  -62.830  52.219  1
476307  96.513  -62.842  52.182  1
476308  96.552  -62.855  52.144  1
476309  96.591  -62.867  52.106  1
476310  96.630  -62.879  52.067  1
476311  96.669  -62.891  52.029  1
476312  96.708  -62.904  51.992  1
476313  96.746  -62.916  51.954  1
476314  96.786  -62.929  51.918  1
476315  96.824  -62.941  51.883  1
476316  96.862  -62.954  51.849  1
476317  96.895  -62.972  51.816  1
476318  96.928  -62.990  51.784  1
476319  96.960  -63.007  51.752  1
476320  96.993  -63.025  51.721  1
476321  97.026  -63.043  51.690  1
476322  97.058  -63.061  51.659  1
476323  97.091  -63.078  51.628  1
476324  97.123  -63.094  51.597  1
476325  97.154  -63.098  51.566  1
476326  97.185  -63.103  51.534  1
476327  97.223  -63.106  51.503  1
476328  97.275  -63.106  51.470  1
476329  97.326  -63.105  51.437  1
476330  97.377  -63.105  51.403  1
476331  97.429  -63.105  51.367  1
476332  97.480  -63.105  51.330  1
476333  97.531  -63.105  51.291  1
476334  97.582  -63.108  51.251  1
476335  97.595  -63.091  51.209  1
476336  97.602  -63.074  51.167  1
476337  97.609  -63.057  51.126  1
476338  97.615  -63.041  51.084  1
476339  97.627  -63.028  51.042  1
476340  97.654  -63.030  50.998  1
476341  97.682  -63.032  50.953  1
476342  97.710  -63.035  50.908  1
476343  97.738  -63.037  50.864  1
476344  97.768  -63.034  50.820  1
476345  97.801  -63.022  50.776  1
476346  97.833  -63.010  50.731  1
476347  97.867  -62.998  50.685  1
476348  97.912  -63.001  50.638  1
476349  97.965  -63.016  50.590  1
476350  98.019  -63.030  50.542  1
476351  98.073  -63.044  50.493  1
476352  98.126  -63.058  50.444  1
476353  98.180  -63.073  50.395  1
476354  98.221  -63.087  50.348  1
476355  98.232  -63.102  50.301  1
476356  98.243  -63.117  50.255  1
476357  98.254  -63.132  50.209  1
476358  98.265  -63.147  50.165  1
476359  98.276  -63.162  50.121  1
476360  98.291  -63.177  50.078  1
476361  98.315  -63.193  50.034  1
476362  98.339  -63.208  49.993  1
476363  98.363  -63.224  49.951  1
476364  98.387  -63.239  49.909  1
476365  98.414  -63.226  49.867  1
476366  98.439  -63.214  49.826  1
476367  98.465  -63.201  49.786  1
476368  98.492  -63.189  49.746  1
476369  98.517  -63.177  49.707  1
476370  98.553  -63.179  49.669  1
476371  98.589  -63.183  49.631  1
476372  98.625  -63.187  49.594  1
476373  98.661  -63.188  49.558  1
476374  98.714  -63.179  49.522  1
476375  98.777  -63.177  49.487  1
476376  98.840  -63.175  49.453  1
476798  87.536  -61.196  56.034  1
476799  87.572  -61.199  56.022  1
476800  87.609  -61.200  56.010  1
476801  87.646  -61.202  55.997  1
476802  87.683  -61.204  55.985  1
476803  87.719  -61.205  55.972  1
476804  87.756  -61.208  55.957  1
476805  87.793  -61.209  55.942  1
476806  87.829  -61.211  55.926  1
476807  87.866  -61.213  55.911  1
476808  87.903  -61.215  55.896  1
476809  87.939  -61.216  55.879  1
476810  87.976  -61.218  55.862  1
476811  88.013  -61.220  55.844  1
476812  88.056  -61.218  55.824  1
476813  88.105  -61.215  55.805  1
476814  88.153  -61.212  55.786  1
476815  88.201  -61.208  55.768  1
476816  88.250  -61.205  55.748  1
476817  88.303  -61.205  55.726  1
476818  88.370  -61.211  55.705  1
476819  88.437  -61.217  55.683  1
476820  88.505  -61.224  55.662  1
476821  88.572  -61.230  55.639  1
476822  88.640  -61.237  55.615  1
476823  88.709  -61.240  55.588  1
476824  88.767  -61.252  55.559  1
476825  88.812  -61.277  55.531  1
476826  88.856  -61.302  55.507  1
476827  88.901  -61.328  55.486  1
476828  88.946  -61.353  55.468  1
476829  88.990  -61.378  55.453  1
476830  89.033  -61.396  55.442  1
476831  89.076  -61.414  55.427  1
476832  89.119  -61.433  55.409  1
476833  89.163  -61.451  55.391  1
476834  89.206  -61.469  55.374  1
476835  89.249  -61.487  55.355  1
476836  89.288  -61.495  55.334  1
476837  89.323  -61.494  55.315  1
476838  89.358  -61.492  55.299  1
476839  89.393  -61.491  55.285  1
476840  89.428  -61.489  55.271  1
476841  89.463  -61.487  55.251  1
476842  89.498  -61.486  55.234  1
476843  89.533  -61.484  55.220  1
476844  89.568  -61.483  55.209  1
476845  89.605  -61.484  55.201  1
476846  89.643  -61.485  55.194  1
476847  89.680  -61.487  55.189  1
476848  89.718  -61.488  55.184  1
476849  89.757  -61.494  55.181  1
476850  89.800  -61.503  55.180  1
476851  89.842  -61.512  55.180  1
476852  89.887  -61.529  55.183  1
476853  89.932  -61.550  55.189  1
476854  89.977  -61.572  55.198  1
476855  90.023  -61.593  55.206  1
476856  90.068  -61.615  55.208  1
476857  90.113  -61.636  55.205  1
476858  90.159  -61.657  55.198  1
476859  90.204  -61.678  55.190  1
476860  90.249  -61.700  55.185  1
476861  90.295  -61.721  55.181  1
476862  90.341  -61.744  55.174  1
476863  90.389  -61.768  55.161  1
476864  90.437  -61.782  55.144  1
476865  90.490  -61.797  55.123  1
476866  90.543  -61.811  55.100  1
476867  90.596  -61.826  55.078  1
476868  90.649  -61.841  55.061  1
476869  90.702  -61.856  55.050  1
476870  90.755  -61.870  55.043  1
476871  90.808  -61.885  55.040  1
476872  90.857  -61.901  55.041  1
476873  90.893  -61.918  55.046  1
476874  90.930  -61.935  55.055  1
476875  90.969  -61.949  55.067  1
476876  91.018  -61.955  55.082  1
476877  91.066  -61.962  55.095  1
476878  91.114  -61.968  55.105  1
476879  91.162  -61.975  55.110  1
476880  91.211  -61.979  55.106  1
476881  91.255  -61.987  55.088  1
476882  91.297  -61.997  55.078  1
476883  91.339  -62.006  55.077  1
476884  91.381  -62.016  55.082  1
476885  91.423  -62.026  55.086  1
476886  91.465  -62.035  55.077  1
476887  91.507  -62.045  55.067  1
476888  91.548  -62.055  55.062  1
476889  91.592  -62.070  55.062  1
476890  91.637  -62.087  55.062  1
476891  91.680  -62.105  55.053  1
476892  91.725  -62.122  55.037  1
476893  91.769  -62.139  55.015  1
476894  91.809  -62.157  54.990  1
476895  91.848  -62.175  54.966  1
476896  91.885  -62.194  54.935  1
476897  91.923  -62.212  54.900  1
476898  91.961  -62.230  54.866  1
476899  91.999  -62.249  54.834  1
476900  92.037  -62.268  54.805  1
476901  92.072  -62.265  54.779  1
476902  92.106  -62.262  54.754  1
476903  92.141  -62.258  54.730  1
476904  92.176  -62.255  54.708  1
476905  92.211  -62.252  54.688  1
476906  92.246  -62.243  54.665  1
476907  92.280  -62.235  54.641  1
476908  92.314  -62.239  54.618  1
476909  92.363  -62.246  54.596  1
476910  92.412  -62.253  54.575  1
476911  92.461  -62.261  54.554  1
476912  92.510  -62.268  54.535  1
476913  92.559  -62.275  54.518  1
476914  92.608  -62.282  54.503  1
476915  92.657  -62.290  54.490  1
476916  92.706  -62.296  54.475  1
476917  92.755  -62.304  54.460  1
476918  92.799  -62.309  54.442  1
476919  92.817  -62.320  54.420  1
476920  92.837  -62.330  54.397  1
476921  92.889  -62.333  54.384  1
476922  92.937  -62.338  54.377  1
476923  92.977  -62.349  54.372  1
476924  93.017  -62.360  54.369  1
476925  93.058  -62.371  54.365  1
476926  93.097  -62.383  54.357  1
476927  93.138  -62.394  54.347  1
476928  93.178  -62.406  54.335  1
476929  93.218  -62.417  54.322  1
476930  93.258  -62.428  54.308  1
476931  93.282  -62.434  54.292  1
476932  93.320  -62.429  54.273  1
476933  93.360  -62.425  54.255  1
476934  93.400  -62.421  54.239  1
476935  93.440  -62.418  54.226  1
476936  93.481  -62.414  54.216  1
476937  93.521  -62.410  54.207  1
476938  93.561  -62.406  54.201  1
476939  93.618  -62.428  54.194  1
476940  93.673  -62.452  54.183  1
476941  93.710  -62.476  54.170  1
476942  93.748  -62.500  54.157  1
476943  93.785  -62.525  54.146  1
476944  93.822  -62.549  54.137  1
476945  93.859  -62.573  54.127  1
476946  93.906  -62.590  54.113  1
476947  93.964  -62.599  54.093  1
476948  94.020  -62.608  54.068  1
476949  94.077  -62.617  54.041  1
476950  94.133  -62.620  54.011  1
476951  94.184  -62.602  53.981  1
476952  94.236  -62.584  53.950  1
476953  94.287  -62.566  53.918  1
476954  94.333  -62.565  53.886  1
476955  94.377  -62.569  53.856  1
476956  94.421  -62.573  53.826  1
476957  94.469  -62.578  53.796  1
476958  94.524  -62.587  53.765  1
476959  94.578  -62.595  53.736  1
476960  94.632  -62.603  53.707  1
476961  94.643  -62.604  53.679  1
476962  94.643  -62.603  53.651  1
476963  94.645  -62.604  53.623  1
476964  94.671  -62.623  53.595  1
476965  94.705  -62.648  53.568  1
476966  94.745  -62.676  53.540  1
476967  94.785  -62.704  53.512  1
476968  94.825  -62.732  53.483  1
476969  94.859  -62.766  53.452  1
476970  94.872  -62.824  53.421  1
476971  94.900  -62.837  53.391  1
476972  94.928  -62.848  53.361  1
476973  94.953  -62.851  53.331  1
476974  94.978  -62.847  53.301  1
476975  95.028  -62.846  53.272  1
476976  95.078  -62.845  53.243  1
476977  95.129  -62.844  53.214  1
476978  95.179  -62.843  53.187  1
476979  95.230  -62.842  53.161  1
476980  95.280  -62.841  53.136  1
476981  95.331  -62.840  53.109  1
476982  95.381  -62.839  53.079  1
476983  95.431  -62.838  53.047  1
476984  95.482  -62.837  53.013  1
476985  95.532  -62.836  52.979  1
476986  95.583  -62.835  52.945  1
476987  95.629  -62.847  52.912  1
476988  95.680  -62.855  52.879  1
476989  95.708  -62.854  52.845  1
476990  95.736  -62.852  52.810  1
476991  95.764  -62.851  52.777  1
476992  95.792  -62.849  52.742  1
476993  95.834  -62.835  52.706  1
476994  95.879  -62.819  52.670  1
476995  95.924  -62.803  52.634  1
476996  95.975  -62.799  52.599  1
476997  96.028  -62.799  52.562  1
476998  96.081  -62.798  52.526  1
476999  96.127  -62.788  52.491  1
477000  96.170  -62.773  52.457  1
477001  96.214  -62.759  52.420  1
477002  96.257  -62.744  52.384  1
477003  96.308  -62.750  52.348  1
477004  96.334  -62.766  52.312  1
477005  96.359  -62.782  52.275  1
477006  96.424  -62.794  52.238  1
477007  96.477  -62.807  52.201  1
477008  96.516  -62.819  52.164  1
477009  96.554  -62.831  52.126  1
477010  96.594  -62.843  52.088  1
477011  96.632  -62.856  52.050  1
477012  96.671  -62.868  52.013  1
477013  96.711  -62.880  51.975  1
477014  96.749  -62.892  51.937  1
477015  96.788  -62.905  51.900  1
477016  96.823  -62.920  51.865  1
477017  96.856  -62.938  51.831  1
477018  96.889  -62.956  51.798  1
477019  96.922  -62.973  51.765  1
477020  96.954  -62.992  51.732  1
477021  96.987  -63.009  51.701  1
477022  97.020  -63.026  51.669  1
477023  97.052  -63.045  51.638  1
477024  97.085  -63.062  51.608  1
477025  97.118  -63.079  51.578  1
477026  97.150  -63.095  51.545  1
477027  97.200  -63.095  51.514  1
477028  97.247  -63.092  51.482  1
477029  97.295  -63.091  51.449  1
477030  97.342  -63.089  51.415  1
477031  97.389  -63.086  51.380  1
477032  97.436  -63.085  51.345  1
477033  97.483  -63.082  51.309  1
477034  97.530  -63.080  51.271  1
477035  97.577  -63.079  51.230  1
477036  97.597  -63.069  51.190  1
477037  97.606  -63.054  51.148  1
477038  97.612  -63.038  51.107  1
477039  97.619  -63.021  51.064  1
477040  97.627  -63.004  51.021  1
477041  97.654  -63.007  50.978  1
477042  97.682  -63.010  50.932  1
477043  97.710  -63.012  50.886  1
477044  97.742  -63.002  50.841  1
477045  97.776  -62.990  50.797  1
477046  97.808  -62.978  50.753  1
477047  97.842  -62.967  50.707  1
477048  97.875  -62.954  50.662  1
477049  97.926  -62.966  50.615  1
477050  97.980  -62.979  50.567  1
477051  98.033  -62.994  50.520  1
477052  98.087  -63.008  50.472  1
477053  98.140  -63.023  50.424  1
477054  98.194  -63.036  50.377  1
477055  98.214  -63.051  50.330  1
477056  98.225  -63.067  50.285  1
477057  98.236  -63.082  50.239  1
477058  98.246  -63.096  50.195  1
477059  98.257  -63.111  50.151  1
477060  98.269  -63.126  50.108  1
477061  98.292  -63.142  50.065  1
477062  98.316  -63.158  50.022  1
477063  98.341  -63.173  49.980  1
477064  98.365  -63.189  49.939  1
477065  98.389  -63.195  49.897  1
477066  98.416  -63.183  49.857  1
477067  98.442  -63.170  49.816  1
477068  98.468  -63.158  49.776  1
477069  98.494  -63.145  49.736  1
477070  98.522  -63.137  49.698  1
477071  98.559  -63.141  49.661  1
477072  98.595  -63.145  49.623  1
477073  98.631  -63.150  49.587  1
477074  98.667  -63.147  49.551  1
477501  87.625  -61.152  56.002  1
477502  87.661  -61.154  55.990  1
477503  87.698  -61.156  55.978  1
477504  87.734  -61.158  55.963  1
477505  87.771  -61.159  55.948  1
477506  87.808  -61.161  55.934  1
477507  87.845  -61.163  55.918  1
477508  87.882  -61.165  55.902  1
477509  87.918  -61.167  55.887  1
477510  87.955  -61.168  55.870  1
477511  87.991  -61.171  55.853  1
477512  88.028  -61.172  55.835  1
477513  88.066  -61.174  55.815  1
477514  88.114  -61.170  55.796  1
477515  88.163  -61.167  55.777  1
477516  88.211  -61.163  55.758  1
477517  88.259  -61.160  55.737  1
477518  88.314  -61.160  55.716  1
477519  88.381  -61.166  55.693  1
477520  88.449  -61.173  55.670  1
477521  88.516  -61.179  55.646  1
477522  88.583  -61.185  55.623  1
477523  88.651  -61.192  55.598  1
477524  88.727  -61.185  55.571  1
477525  88.781  -61.201  55.543  1
477526  88.826  -61.227  55.516  1
477527  88.871  -61.252  55.492  1
477528  88.915  -61.277  55.469  1
477529  88.960  -61.303  55.448  1
477530  89.003  -61.324  55.428  1
477531  89.047  -61.343  55.413  1
477532  89.090  -61.361  55.396  1
477533  89.133  -61.379  55.378  1
477534  89.176  -61.397  55.361  1
477535  89.219  -61.415  55.345  1
477536  89.263  -61.434  55.327  1
477537  89.306  -61.453  55.310  1
477538  89.344  -61.459  55.293  1
477539  89.379  -61.457  55.280  1
477540  89.414  -61.456  55.269  1
477541  89.450  -61.454  55.258  1
477542  89.484  -61.453  55.241  1
477543  89.520  -61.451  55.224  1
477544  89.554  -61.450  55.209  1
477545  89.590  -61.448  55.198  1
477546  89.625  -61.447  55.190  1
477547  89.660  -61.445  55.183  1
477548  89.695  -61.443  55.178  1
477549  89.733  -61.446  55.174  1
477550  89.770  -61.447  55.170  1
477551  89.810  -61.453  55.170  1
477552  89.852  -61.462  55.169  1
477553  89.897  -61.481  55.171  1
477554  89.943  -61.502  55.176  1
477555  89.988  -61.523  55.185  1
477556  90.033  -61.544  55.196  1
477557  90.079  -61.566  55.203  1
477558  90.124  -61.588  55.204  1
477559  90.172  -61.613  55.201  1
477560  90.222  -61.642  55.194  1
477561  90.271  -61.671  55.187  1
477562  90.321  -61.700  55.180  1
477563  90.367  -61.719  55.170  1
477564  90.409  -61.729  55.154  1
477565  90.455  -61.742  55.135  1
477566  90.500  -61.755  55.113  1
477567  90.553  -61.770  55.090  1
477568  90.606  -61.785  55.071  1
477569  90.659  -61.800  55.056  1
477570  90.712  -61.814  55.046  1
477571  90.764  -61.829  55.039  1
477572  90.817  -61.844  55.037  1
477573  90.862  -61.860  55.039  1
477574  90.898  -61.877  55.045  1
477575  90.937  -61.892  55.055  1
477576  90.985  -61.898  55.067  1
477577  91.033  -61.905  55.082  1
477578  91.081  -61.911  55.094  1
477579  91.130  -61.918  55.104  1
477580  91.177  -61.925  55.109  1
477581  91.223  -61.935  55.105  1
477582  91.265  -61.945  55.090  1
477583  91.307  -61.954  55.078  1
477584  91.349  -61.964  55.075  1
477585  91.391  -61.973  55.080  1
477586  91.433  -61.983  55.082  1
477587  91.475  -61.992  55.073  1
477588  91.517  -62.001  55.069  1
477589  91.559  -62.011  55.070  1
477590  91.601  -62.023  55.073  1
477591  91.645  -62.040  55.066  1
477592  91.689  -62.058  55.052  1
477593  91.730  -62.076  55.033  1
477594  91.768  -62.094  55.009  1
477595  91.806  -62.112  54.980  1
477596  91.844  -62.131  54.954  1
477597  91.882  -62.149  54.926  1
477598  91.920  -62.167  54.895  1
477599  91.958  -62.186  54.865  1
477600  91.996  -62.205  54.837  1
477601  92.032  -62.217  54.809  1
477602  92.067  -62.213  54.782  1
477603  92.102  -62.210  54.757  1
477604  92.137  -62.207  54.734  1
477605  92.171  -62.204  54.714  1
477606  92.206  -62.201  54.694  1
477607  92.241  -62.197  54.669  1
477608  92.277  -62.195  54.644  1
477609  92.326  -62.202  54.620  1
477610  92.375  -62.209  54.597  1
477611  92.424  -62.217  54.574  1
477612  92.473  -62.224  54.554  1
477613  92.521  -62.231  54.536  1
477614  92.570  -62.238  54.519  1
477615  92.619  -62.246  54.505  1
477616  92.667  -62.252  54.495  1
477617  92.716  -62.259  54.480  1
477618  92.765  -62.267  54.464  1
477619  92.804  -62.276  54.444  1
477620  92.820  -62.288  54.419  1
477621  92.847  -62.296  54.395  1
477622  92.892  -62.304  54.380  1
477623  92.932  -62.315  54.371  1
477624  92.972  -62.327  54.365  1
477625  93.012  -62.338  54.359  1
477626  93.052  -62.349  54.352  1
477627  93.092  -62.361  54.343  1
477628  93.135  -62.371  54.332  1
477629  93.177  -62.381  54.320  1
477630  93.219  -62.392  54.309  1
477631  93.262  -62.402  54.295  1
477632  93.303  -62.406  54.280  1
477633  93.346  -62.404  54.263  1
477634  93.389  -62.398  54.247  1
477635  93.432  -62.392  54.233  1
477636  93.472  -62.388  54.225  1
477637  93.512  -62.384  54.221  1
477638  93.553  -62.381  54.219  1
477639  93.593  -62.377  54.217  1
477640  93.644  -62.396  54.212  1
477641  93.681  -62.420  54.202  1
477642  93.718  -62.444  54.191  1
477643  93.756  -62.468  54.180  1
477644  93.793  -62.493  54.169  1
477645  93.830  -62.517  54.158  1
477646  93.867  -62.541  54.146  1
477647  93.918  -62.555  54.130  1
477648  93.975  -62.564  54.109  1
477649  94.032  -62.573  54.085  1
477650  94.089  -62.582  54.057  1
477651  94.141  -62.569  54.028  1
477652  94.193  -62.551  53.997  1
477653  94.244  -62.533  53.966  1
477654  94.289  -62.531  53.933  1
477655  94.334  -62.535  53.899  1
477656  94.378  -62.539  53.867  1
477657  94.422  -62.543  53.834  1
477658  94.470  -62.549  53.801  1
477659  94.525  -62.557  53.767  1
477660  94.579  -62.565  53.734  1
477661  94.633  -62.573  53.700  1
477662  94.688  -62.581  53.668  1
477663  94.706  -62.584  53.637  1
477664  94.699  -62.589  53.606  1
477665  94.687  -62.598  53.575  1
477666  94.736  -62.619  53.545  1
477667  94.797  -62.643  53.515  1
477668  94.838  -62.671  53.486  1
477669  94.878  -62.699  53.455  1
477670  94.918  -62.727  53.423  1
477671  94.930  -62.785  53.392  1
477672  94.943  -62.843  53.360  1
477673  94.958  -62.825  53.331  1
477674  94.946  -62.799  53.301  1
477675  94.983  -62.802  53.272  1
477676  95.021  -62.805  53.243  1
477677  95.061  -62.808  53.214  1
477678  95.112  -62.807  53.187  1
477679  95.163  -62.806  53.161  1
477680  95.213  -62.804  53.135  1
477681  95.263  -62.804  53.110  1
477682  95.314  -62.803  53.083  1
477683  95.364  -62.801  53.054  1
477684  95.414  -62.800  53.022  1
477685  95.465  -62.800  52.990  1
477686  95.515  -62.798  52.957  1
477687  95.565  -62.797  52.923  1
477688  95.616  -62.797  52.891  1
477689  95.657  -62.832  52.859  1
477690  95.713  -62.835  52.826  1
477691  95.747  -62.832  52.791  1
477692  95.775  -62.831  52.759  1
477693  95.803  -62.829  52.725  1
477694  95.845  -62.815  52.691  1
477695  95.891  -62.799  52.655  1
477696  95.941  -62.794  52.620  1
477697  95.994  -62.794  52.584  1
477698  96.041  -62.785  52.547  1
477699  96.085  -62.770  52.512  1
477700  96.128  -62.756  52.477  1
477701  96.171  -62.741  52.443  1
477702  96.215  -62.727  52.406  1
477703  96.258  -62.712  52.369  1
477704  96.311  -62.728  52.333  1
477705  96.338  -62.744  52.297  1
477706  96.363  -62.759  52.260  1
477707  96.441  -62.770  52.223  1
477708  96.479  -62.782  52.186  1
477709  96.519  -62.794  52.149  1
477710  96.557  -62.807  52.111  1
477711  96.596  -62.819  52.073  1
477712  96.636  -62.832  52.035  1
477713  96.674  -62.844  51.998  1
477714  96.713  -62.857  51.960  1
477715  96.752  -62.869  51.922  1
477716  96.785  -62.886  51.885  1
477717  96.817  -62.904  51.848  1
477718  96.850  -62.922  51.814  1
477719  96.883  -62.940  51.780  1
477720  96.915  -62.957  51.746  1
477721  96.948  -62.975  51.714  1
477722  96.981  -62.993  51.683  1
477723  97.014  -63.010  51.651  1
477724  97.046  -63.028  51.620  1
477725  97.081  -63.040  51.589  1
477726  97.118  -63.047  51.559  1
477727  97.157  -63.052  51.527  1
477728  97.196  -63.057  51.495  1
477729  97.236  -63.062  51.462  1
477730  97.282  -63.061  51.429  1
477731  97.329  -63.059  51.395  1
477732  97.376  -63.057  51.360  1
477733  97.423  -63.054  51.325  1
477734  97.470  -63.053  51.289  1
477735  97.517  -63.051  51.251  1
477736  97.565  -63.048  51.211  1
477737  97.596  -63.042  51.173  1
477738  97.605  -63.029  51.132  1
477739  97.615  -63.016  51.090  1
477740  97.623  -63.001  51.047  1
477741  97.630  -62.985  51.004  1
477742  97.655  -62.984  50.960  1
477743  97.684  -62.982  50.914  1
477744  97.717  -62.970  50.868  1
477745  97.750  -62.958  50.822  1
477746  97.783  -62.946  50.777  1
477747  97.816  -62.935  50.732  1
477748  97.850  -62.923  50.686  1
477749  97.886  -62.915  50.641  1
477750  97.940  -62.929  50.595  1
477751  97.993  -62.944  50.547  1
477752  98.047  -62.957  50.501  1
477753  98.100  -62.972  50.454  1
477754  98.154  -62.986  50.407  1
477755  98.196  -63.001  50.361  1
477756  98.206  -63.016  50.315  1
477757  98.217  -63.031  50.270  1
477758  98.228  -63.045  50.226  1
477759  98.239  -63.061  50.182  1
477760  98.250  -63.076  50.139  1
477761  98.270  -63.091  50.096  1
477762  98.294  -63.107  50.053  1
477763  98.318  -63.123  50.011  1
477764  98.343  -63.138  49.970  1
477765  98.367  -63.154  49.928  1
477766  98.392  -63.151  49.887  1
477767  98.418  -63.139  49.847  1
477768  98.444  -63.126  49.807  1
478203  87.677  -61.106  55.981  1
478204  87.713  -61.108  55.968  1
478205  87.750  -61.110  55.954  1
478206  87.786  -61.111  55.940  1
478207  87.823  -61.114  55.925  1
478208  87.860  -61.115  55.909  1
478209  87.897  -61.117  55.894  1
478210  87.933  -61.119  55.878  1
478211  87.970  -61.121  55.860  1
478212  88.006  -61.122  55.844  1
478213  88.043  -61.124  55.826  1
478214  88.080  -61.126  55.806  1
478215  88.124  -61.124  55.787  1
478216  88.172  -61.121  55.767  1
478217  88.220  -61.118  55.748  1
478218  88.269  -61.114  55.727  1
478219  88.325  -61.115  55.705  1
478220  88.392  -61.121  55.682  1
478221  88.460  -61.128  55.658  1
478222  88.527  -61.134  55.633  1
478223  88.595  -61.141  55.610  1
478224  88.668  -61.138  55.584  1
478225  88.743  -61.133  55.557  1
478226  88.796  -61.151  55.530  1
478227  88.840  -61.176  55.502  1
478228  88.885  -61.202  55.477  1
478229  88.929  -61.227  55.454  1
478230  88.974  -61.252  55.430  1
478231  89.018  -61.271  55.408  1
478232  89.060  -61.290  55.388  1
478233  89.104  -61.308  55.369  1
478234  89.147  -61.326  55.351  1
478235  89.190  -61.344  55.334  1
478236  89.233  -61.362  55.318  1
478237  89.276  -61.381  55.302  1
478238  89.319  -61.399  55.287  1
478239  89.363  -61.417  55.274  1
478240  89.401  -61.423  55.262  1
478241  89.436  -61.422  55.253  1
478242  89.471  -61.420  55.243  1
478243  89.506  -61.418  55.228  1
478244  89.541  -61.417  55.213  1
478245  89.576  -61.415  55.198  1
478246  89.611  -61.414  55.187  1
478247  89.646  -61.412  55.179  1
478248  89.681  -61.411  55.173  1
478249  89.716  -61.409  55.167  1
478250  89.751  -61.408  55.163  1
478251  89.787  -61.406  55.160  1
478252  89.822  -61.406  55.159  1
478253  89.863  -61.412  55.159  1
478254  89.907  -61.432  55.160  1
478255  89.953  -61.453  55.162  1
478256  90.003  -61.482  55.168  1
478257  90.052  -61.511  55.180  1
478258  90.102  -61.541  55.191  1
478259  90.152  -61.569  55.197  1
478260  90.201  -61.598  55.198  1
478261  90.251  -61.628  55.196  1
478262  90.301  -61.657  55.189  1
478263  90.344  -61.671  55.180  1
478264  90.385  -61.678  55.167  1
478265  90.431  -61.691  55.149  1
478266  90.476  -61.704  55.128  1
478267  90.521  -61.717  55.106  1
478268  90.566  -61.730  55.083  1
478269  90.615  -61.744  55.065  1
478270  90.668  -61.759  55.052  1
478271  90.721  -61.773  55.041  1
478272  90.775  -61.788  55.035  1
478273  90.827  -61.803  55.033  1
478274  90.866  -61.820  55.036  1
478275  90.904  -61.835  55.043  1
478276  90.953  -61.841  55.053  1
478277  91.001  -61.848  55.066  1
478278  91.049  -61.854  55.082  1
478279  91.097  -61.862  55.094  1
478280  91.145  -61.870  55.103  1
478281  91.190  -61.880  55.107  1
478282  91.232  -61.892  55.100  1
478283  91.275  -61.903  55.087  1
478284  91.316  -61.912  55.078  1
478285  91.359  -61.922  55.074  1
478286  91.400  -61.931  55.076  1
478287  91.443  -61.941  55.077  1
478288  91.485  -61.950  55.069  1
478289  91.527  -61.959  55.069  1
478290  91.569  -61.969  55.073  1
478291  91.611  -61.978  55.076  1
478292  91.651  -61.994  55.066  1
478293  91.689  -62.013  55.050  1
478294  91.727  -62.031  55.029  1
478295  91.765  -62.049  55.003  1
478296  91.803  -62.068  54.973  1
478297  91.841  -62.086  54.945  1
478298  91.878  -62.105  54.918  1
478299  91.917  -62.123  54.892  1
478300  91.954  -62.142  54.868  1
478301  91.992  -62.160  54.844  1
478302  92.028  -62.164  54.815  1
478303  92.063  -62.161  54.786  1
478304  92.101  -62.161  54.760  1
478305  92.139  -62.160  54.739  1
478306  92.177  -62.159  54.721  1
478307  92.216  -62.158  54.701  1
478308  92.254  -62.158  54.675  1
478309  92.290  -62.158  54.649  1
478310  92.335  -62.164  54.624  1
478311  92.383  -62.171  54.600  1
478312  92.432  -62.178  54.578  1
478313  92.481  -62.186  54.558  1
478314  92.529  -62.192  54.540  1
478315  92.578  -62.200  54.524  1
478316  92.627  -62.207  54.512  1
478317  92.675  -62.214  54.499  1
478318  92.724  -62.221  54.483  1
478319  92.773  -62.228  54.463  1
478320  92.806  -62.239  54.439  1
478321  92.822  -62.253  54.413  1
478322  92.854  -62.268  54.389  1
478323  92.896  -62.278  54.373  1
478324  92.938  -62.289  54.362  1
478325  92.981  -62.299  54.354  1
478326  93.022  -62.310  54.346  1
478327  93.065  -62.321  54.336  1
478328  93.107  -62.330  54.325  1
478329  93.149  -62.341  54.314  1
478330  93.191  -62.352  54.303  1
478331  93.234  -62.361  54.291  1
478332  93.278  -62.367  54.280  1
478333  93.319  -62.371  54.265  1
478334  93.360  -62.375  54.251  1
478335  93.401  -62.380  54.237  1
478336  93.442  -62.381  54.226  1
478337  93.485  -62.374  54.223  1
478338  93.529  -62.368  54.228  1
478339  93.571  -62.363  54.231  1
478340  93.615  -62.357  54.231  1
478341  93.652  -62.364  54.227  1
478342  93.689  -62.388  54.219  1
478343  93.726  -62.412  54.208  1
478344  93.764  -62.437  54.198  1
478345  93.801  -62.461  54.186  1
478346  93.839  -62.485  54.172  1
478347  93.876  -62.509  54.156  1
478348  93.930  -62.521  54.138  1
478349  93.987  -62.530  54.116  1
478350  94.044  -62.539  54.091  1
478351  94.098  -62.535  54.063  1
478352  94.149  -62.518  54.034  1
478353  94.201  -62.500  54.004  1
478354  94.247  -62.498  53.973  1
478355  94.291  -62.502  53.941  1
478356  94.335  -62.506  53.907  1
478357  94.379  -62.509  53.873  1
478358  94.423  -62.513  53.840  1
478359  94.471  -62.518  53.805  1
478360  94.526  -62.527  53.768  1
478361  94.580  -62.535  53.732  1
478362  94.634  -62.543  53.695  1
478363  94.688  -62.551  53.660  1
478364  94.720  -62.566  53.626  1
478365  94.740  -62.584  53.592  1
478366  94.731  -62.594  53.559  1
478367  94.719  -62.603  53.527  1
478368  94.773  -62.625  53.495  1
478369  94.834  -62.649  53.463  1
478370  94.896  -62.673  53.431  1
478371  94.957  -62.697  53.399  1
478372  94.924  -62.778  53.366  1
478373  94.962  -62.797  53.335  1
478374  94.950  -62.772  53.305  1
478375  94.951  -62.753  53.275  1
478376  94.989  -62.757  53.246  1
478377  95.027  -62.760  53.218  1
478378  95.065  -62.763  53.188  1
478379  95.103  -62.766  53.160  1
478380  95.145  -62.768  53.134  1
478381  95.196  -62.767  53.108  1
478382  95.246  -62.766  53.082  1
478383  95.297  -62.765  53.057  1
478384  95.347  -62.764  53.028  1
478385  95.397  -62.763  52.997  1
478386  95.448  -62.762  52.966  1
478387  95.498  -62.761  52.935  1
478388  95.549  -62.760  52.903  1
478389  95.599  -62.759  52.872  1
478390  95.643  -62.783  52.841  1
478391  95.684  -62.818  52.809  1
478392  95.743  -62.815  52.776  1
478393  95.785  -62.811  52.744  1
478394  95.814  -62.809  52.711  1
478395  95.857  -62.794  52.678  1
478396  95.907  -62.789  52.643  1
478397  95.955  -62.782  52.607  1
478398  95.999  -62.767  52.571  1
478399  96.042  -62.753  52.534  1
478400  96.086  -62.738  52.499  1
478401  96.129  -62.724  52.465  1
478402  96.172  -62.710  52.430  1
478403  96.216  -62.695  52.393  1
478404  96.261  -62.685  52.357  1
478405  96.315  -62.704  52.320  1
478406  96.343  -62.720  52.284  1
478407  96.372  -62.735  52.247  1
478408  96.444  -62.746  52.210  1
478409  96.482  -62.759  52.172  1
478410  96.521  -62.771  52.134  1
478411  96.560  -62.783  52.097  1
478412  96.599  -62.795  52.059  1
478413  96.638  -62.808  52.021  1
478414  96.677  -62.820  51.983  1
478415  96.713  -62.835  51.944  1
478416  96.746  -62.853  51.906  1
478417  96.779  -62.870  51.869  1
478418  96.811  -62.888  51.833  1
478419  96.844  -62.906  51.798  1
478420  96.877  -62.923  51.763  1
478421  96.909  -62.941  51.729  1
478422  96.942  -62.959  51.696  1
478423  96.975  -62.975  51.664  1
478424  97.013  -62.981  51.633  1
478425  97.050  -62.987  51.601  1
478426  97.088  -62.993  51.570  1
478427  97.125  -62.999  51.539  1
478428  97.164  -63.004  51.508  1
478429  97.204  -63.009  51.476  1
478430  97.243  -63.014  51.444  1
478431  97.283  -63.020  51.411  1
478432  97.322  -63.024  51.376  1
478433  97.364  -63.027  51.342  1
478434  97.411  -63.025  51.307  1
478435  97.458  -63.023  51.271  1
478436  97.505  -63.021  51.235  1
478437  97.552  -63.019  51.196  1
478438  97.594  -63.016  51.157  1
478439  97.604  -63.002  51.117  1
478440  97.613  -62.989  51.075  1
478441  97.623  -62.976  51.033  1
478442  97.633  -62.963  50.990  1
478443  97.659  -62.950  50.944  1
478444  97.692  -62.938  50.897  1
478445  97.725  -62.926  50.851  1
478446  97.758  -62.914  50.805  1
478447  97.791  -62.903  50.760  1
478448  97.824  -62.891  50.714  1
478449  97.857  -62.879  50.669  1
478450  97.900  -62.879  50.623  1
478451  97.954  -62.893  50.578  1
478452  98.007  -62.907  50.531  1
478453  98.061  -62.922  50.484  1
478454  98.114  -62.936  50.439  1
478455  98.168  -62.950  50.393  1
478456  98.188  -62.965  50.347  1
478457  98.199  -62.980  50.302  1
478458  98.210  -62.995  50.257  1
478459  98.221  -63.010  50.214  1
478460  98.232  -63.025  50.171  1
478461  98.247  -63.040  50.128  1
478462  98.272  -63.056  50.086  1
478463  98.296  -63.072  50.043  1
478464  98.320  -63.087  50.001  1
478465  98.344  -63.103  49.960  1
478905  87.728  -61.060  55.959  1
478906  87.765  -61.062  55.945  1
478907  87.802  -61.064  55.931  1
478908  87.838  -61.065  55.916  1
478909  87.875  -61.067  55.900  1
478910  87.912  -61.069  55.884  1
478911  87.948  -61.071  55.868  1
478912  87.985  -61.073  55.852  1
478913  88.022  -61.074  55.834  1
478914  88.059  -61.077  55.817  1
478915  88.095  -61.078  55.797  1
478916  88.133  -61.080  55.777  1
478917  88.182  -61.076  55.759  1
478918  88.230  -61.073  55.738  1
478919  88.278  -61.069  55.717  1
478920  88.336  -61.071  55.695  1
478921  88.403  -61.077  55.671  1
478922  88.471  -61.083  55.647  1
478923  88.538  -61.089  55.623  1
478924  88.609  -61.090  55.598  1
478925  88.685  -61.084  55.572  1
478926  88.760  -61.080  55.545  1
478927  88.810  -61.100  55.518  1
478928  88.854  -61.126  55.490  1
478929  88.899  -61.151  55.464  1
478930  88.944  -61.177  55.440  1
478931  88.988  -61.200  55.415  1
478932  89.031  -61.218  55.392  1
478933  89.074  -61.237  55.371  1
478934  89.117  -61.255  55.351  1
478935  89.161  -61.273  55.335  1
478936  89.203  -61.291  55.320  1
478937  89.247  -61.309  55.305  1
478938  89.290  -61.327  55.291  1
478939  89.333  -61.346  55.275  1
478940  89.376  -61.364  55.260  1
478941  89.419  -61.382  55.246  1
478942  89.457  -61.387  55.235  1
478943  89.492  -61.386  55.224  1
478944  89.527  -61.384  55.213  1
478945  89.562  -61.383  55.200  1
478946  89.597  -61.381  55.188  1
478947  89.632  -61.379  55.177  1
478948  89.667  -61.378  55.168  1
478949  89.702  -61.376  55.162  1
478950  89.738  -61.375  55.156  1
478951  89.772  -61.373  55.152  1
478952  89.808  -61.371  55.150  1
478953  89.843  -61.370  55.148  1
478954  89.881  -61.375  55.148  1
478955  89.933  -61.409  55.148  1
478956  89.982  -61.438  55.149  1
478957  90.032  -61.467  55.152  1
478958  90.082  -61.497  55.161  1
478959  90.131  -61.525  55.173  1
478960  90.181  -61.554  55.183  1
478961  90.231  -61.584  55.189  1
478962  90.281  -61.613  55.189  1
478963  90.322  -61.622  55.184  1
478964  90.363  -61.629  55.176  1
478965  90.406  -61.639  55.163  1
478966  90.451  -61.652  55.146  1
478967  90.497  -61.665  55.126  1
478968  90.542  -61.678  55.105  1
478969  90.587  -61.691  55.081  1
478970  90.633  -61.704  55.061  1
478971  90.678  -61.717  55.047  1
478972  90.731  -61.732  55.037  1
478973  90.784  -61.747  55.031  1
478974  90.834  -61.762  55.029  1
478975  90.872  -61.778  55.032  1
478976  90.920  -61.784  55.040  1
478977  90.968  -61.791  55.050  1
478978  91.016  -61.798  55.064  1
478979  91.065  -61.807  55.081  1
478980  91.112  -61.815  55.094  1
478981  91.157  -61.826  55.102  1
478982  91.200  -61.838  55.104  1
478983  91.242  -61.850  55.095  1
478984  91.284  -61.861  55.086  1
478985  91.326  -61.870  55.081  1
478986  91.368  -61.880  55.079  1
478987  91.410  -61.889  55.078  1
478988  91.452  -61.898  55.077  1
478989  91.494  -61.908  55.069  1
478990  91.536  -61.917  55.068  1
478991  91.578  -61.927  55.072  1
478992  91.620  -61.937  55.073  1
478993  91.660  -61.951  55.065  1
478994  91.698  -61.970  55.053  1
478995  91.735  -61.988  55.034  1
478996  91.773  -62.007  55.008  1
478997  91.811  -62.025  54.978  1
478998  91.848  -62.043  54.944  1
478999  91.886  -62.061  54.917  1
479000  91.924  -62.080  54.898  1
479001  91.961  -62.098  54.881  1
479002  92.002  -62.116  54.857  1
479003  92.045  -62.127  54.823  1
479004  92.084  -62.127  54.791  1
479005  92.122  -62.127  54.765  1
479006  92.160  -62.126  54.744  1
479007  92.199  -62.125  54.729  1
479008  92.237  -62.124  54.708  1
479009  92.274  -62.124  54.682  1
479010  92.309  -62.126  54.655  1
479011  92.344  -62.127  54.630  1
479012  92.390  -62.133  54.607  1
479013  92.439  -62.140  54.585  1
479014  92.488  -62.147  54.565  1
479015  92.536  -62.155  54.546  1
479016  92.585  -62.161  54.531  1
479017  92.634  -62.169  54.517  1
479018  92.683  -62.176  54.501  1
479019  92.731  -62.183  54.482  1
479020  92.780  -62.190  54.458  1
479021  92.807  -62.202  54.432  1
479022  92.824  -62.216  54.406  1
479023  92.866  -62.232  54.383  1
479024  92.910  -62.248  54.366  1
479025  92.952  -62.259  54.353  1
479026  92.995  -62.270  54.341  1
479027  93.037  -62.280  54.330  1
479028  93.079  -62.290  54.318  1
479029  93.121  -62.301  54.306  1
479030  93.163  -62.312  54.295  1
479031  93.206  -62.321  54.283  1
479032  93.250  -62.326  54.271  1
479033  93.294  -62.332  54.260  1
479034  93.335  -62.337  54.246  1
479035  93.375  -62.340  54.233  1
479036  93.416  -62.345  54.223  1
479037  93.457  -62.349  54.218  1
479038  93.498  -62.354  54.224  1
479039  93.539  -62.357  54.231  1
479040  93.582  -62.351  54.236  1
479041  93.625  -62.345  54.237  1
479042  93.661  -62.340  54.233  1
479043  93.698  -62.356  54.227  1
479044  93.735  -62.381  54.218  1
479045  93.772  -62.405  54.207  1
479046  93.809  -62.429  54.194  1
479047  93.847  -62.453  54.177  1
479048  93.885  -62.477  54.157  1
479049  93.941  -62.486  54.137  1
479050  93.999  -62.495  54.115  1
479051  94.055  -62.502  54.090  1
479052  94.106  -62.484  54.063  1
479053  94.157  -62.466  54.034  1
479054  94.204  -62.464  54.005  1
479055  94.248  -62.468  53.975  1
479056  94.292  -62.471  53.943  1
479057  94.336  -62.476  53.909  1
479058  94.381  -62.480  53.875  1
479059  94.425  -62.484  53.842  1
479060  94.472  -62.489  53.806  1
479061  94.526  -62.496  53.767  1
479062  94.580  -62.505  53.728  1
479063  94.635  -62.513  53.688  1
479064  94.679  -62.524  53.650  1
479065  94.699  -62.542  53.614  1
479066  94.718  -62.560  53.580  1
479067  94.737  -62.578  53.546  1
479068  94.756  -62.597  53.512  1
479069  94.751  -62.607  53.477  1
479070  94.810  -62.631  53.444  1
479071  94.834  -62.678  53.412  1
479072  94.878  -62.704  53.379  1
479073  94.923  -62.731  53.345  1
479074  94.955  -62.745  53.313  1
479075  94.943  -62.719  53.283  1
479076  94.957  -62.709  53.252  1
479077  94.994  -62.712  53.223  1
479078  95.032  -62.715  53.196  1
479079  95.070  -62.718  53.166  1
479080  95.108  -62.722  53.139  1
479081  95.146  -62.725  53.112  1
479082  95.184  -62.728  53.085  1
479083  95.229  -62.728  53.060  1
479084  95.280  -62.728  53.035  1
479085  95.330  -62.726  53.006  1
479086  95.381  -62.725  52.977  1
479087  95.431  -62.725  52.948  1
479088  95.481  -62.723  52.918  1
479089  95.532  -62.722  52.887  1
479090  95.582  -62.722  52.857  1
479091  95.629  -62.734  52.827  1
479092  95.670  -62.769  52.796  1
479093  95.711  -62.803  52.765  1
479094  95.772  -62.795  52.733  1
479095  95.825  -62.789  52.701  1
479096  95.870  -62.779  52.668  1
479097  95.913  -62.765  52.632  1
479098  95.956  -62.750  52.595  1
479099  96.000  -62.735  52.560  1
479100  96.043  -62.721  52.524  1
479101  96.087  -62.706  52.489  1
479102  96.130  -62.692  52.453  1
479103  96.173  -62.678  52.419  1
479104  96.217  -62.663  52.382  1
479105  96.265  -62.662  52.346  1
479106  96.319  -62.681  52.309  1
479107  96.347  -62.697  52.272  1
479108  96.396  -62.710  52.235  1
479109  96.446  -62.722  52.198  1
479110  96.485  -62.735  52.160  1
479111  96.524  -62.747  52.122  1
479112  96.563  -62.760  52.083  1
479113  96.602  -62.772  52.045  1
479114  96.641  -62.784  52.007  1
479115  96.674  -62.801  51.968  1
479116  96.707  -62.819  51.929  1
479117  96.740  -62.836  51.890  1
479118  96.772  -62.854  51.852  1
479119  96.805  -62.872  51.817  1
479120  96.838  -62.889  51.781  1
479121  96.871  -62.907  51.746  1
479122  96.907  -62.915  51.712  1
479123  96.945  -62.921  51.678  1
479124  96.982  -62.927  51.646  1
479125  97.019  -62.933  51.614  1
479126  97.056  -62.939  51.582  1
479127  97.094  -62.945  51.551  1
479128  97.132  -62.951  51.520  1
479129  97.171  -62.957  51.488  1
479130  97.211  -62.961  51.457  1
479131  97.250  -62.967  51.425  1
479132  97.290  -62.972  51.393  1
479133  97.329  -62.976  51.358  1
479134  97.369  -62.982  51.325  1
479135  97.408  -62.986  51.289  1
479136  97.448  -62.992  51.254  1
479137  97.493  -62.992  51.218  1
479138  97.540  -62.989  51.180  1
479139  97.587  -62.987  51.142  1
479140  97.602  -62.976  51.101  1
479141  97.612  -62.963  51.059  1
479142  97.624  -62.945  51.017  1
479143  97.639  -62.922  50.974  1
479144  97.667  -62.907  50.928  1
479145  97.700  -62.894  50.881  1
479146  97.733  -62.882  50.834  1
479147  97.766  -62.870  50.789  1
479148  97.799  -62.859  50.744  1
479149  97.832  -62.847  50.698  1
479150  97.865  -62.835  50.653  1
479151  97.914  -62.843  50.607  1
479152  97.967  -62.857  50.561  1
479153  98.021  -62.871  50.516  1
479154  98.075  -62.885  50.469  1
479155  98.129  -62.900  50.424  1
479156  98.169  -62.914  50.379  1
479157  98.180  -62.929  50.334  1
479158  98.192  -62.945  50.289  1
479159  98.202  -62.960  50.245  1
479160  98.213  -62.974  50.202  1
479161  98.225  -62.989  50.160  1
479162  98.249  -63.005  50.118  1
479163  98.274  -63.020  50.076  1
479164  98.298  -63.036  50.034  1
479607  87.780  -61.014  55.937  1
479608  87.817  -61.016  55.922  1
479609  87.854  -61.017  55.907  1
479610  87.890  -61.020  55.890  1
479611  87.927  -61.021  55.874  1
479612  87.964  -61.023  55.858  1
479613  88.000  -61.025  55.843  1
479614  88.037  -61.027  55.825  1
479615  88.074  -61.028  55.807  1
479616  88.111  -61.030  55.788  1
479617  88.147  -61.032  55.768  1
479618  88.191  -61.030  55.750  1
479619  88.239  -61.027  55.729  1
479620  88.287  -61.024  55.708  1
479621  88.347  -61.026  55.686  1
479622  88.414  -61.033  55.662  1
479623  88.482  -61.039  55.637  1
479624  88.550  -61.043  55.613  1
479625  88.626  -61.036  55.587  1
479626  88.702  -61.030  55.561  1
479627  88.777  -61.027  55.534  1
479628  88.824  -61.050  55.507  1
479629  88.869  -61.075  55.479  1
479630  88.913  -61.101  55.453  1
479631  88.958  -61.127  55.427  1
479632  89.001  -61.147  55.402  1
479633  89.045  -61.165  55.378  1
479634  89.088  -61.183  55.356  1
479635  89.131  -61.202  55.337  1
479636  89.174  -61.220  55.321  1
479637  89.217  -61.238  55.308  1
479638  89.260  -61.256  55.295  1
479639  89.304  -61.274  55.281  1
479640  89.346  -61.293  55.268  1
479641  89.390  -61.311  55.254  1
479642  89.433  -61.329  55.240  1
479643  89.476  -61.347  55.227  1
479644  89.513  -61.351  55.214  1
479645  89.548  -61.349  55.203  1
479646  89.584  -61.348  55.193  1
479647  89.618  -61.346  55.182  1
479648  89.654  -61.345  55.168  1
479649  89.689  -61.343  55.159  1
479650  89.724  -61.342  55.151  1
479651  89.759  -61.340  55.145  1
479652  89.794  -61.339  55.141  1
479653  89.829  -61.337  55.138  1
479654  89.864  -61.336  55.136  1
479655  89.905  -61.348  55.136  1
479656  89.962  -61.394  55.136  1
479657  90.012  -61.424  55.136  1
479658  90.061  -61.453  55.137  1
479659  90.111  -61.481  55.143  1
479660  90.161  -61.511  55.154  1
479661  90.211  -61.540  55.165  1
479662  90.260  -61.567  55.174  1
479663  90.300  -61.574  55.177  1
479664  90.341  -61.581  55.175  1
479665  90.382  -61.588  55.168  1
479666  90.427  -61.600  55.157  1
479667  90.472  -61.613  55.143  1
479668  90.517  -61.626  55.125  1
479669  90.563  -61.640  55.103  1
479670  90.608  -61.653  55.079  1
479671  90.653  -61.666  55.059  1
479672  90.698  -61.678  55.045  1
479673  90.744  -61.691  55.036  1
479674  90.794  -61.706  55.030  1
479675  90.839  -61.721  55.028  1
479676  90.888  -61.728  55.029  1
479677  90.936  -61.735  55.034  1
479678  90.984  -61.744  55.045  1
479679  91.032  -61.752  55.061  1
479680  91.080  -61.760  55.078  1
479681  91.124  -61.771  55.092  1
479682  91.167  -61.783  55.100  1
479683  91.209  -61.795  55.101  1
479684  91.251  -61.807  55.091  1
479685  91.294  -61.819  55.086  1
479686  91.336  -61.829  55.086  1
479687  91.378  -61.838  55.087  1
479688  91.420  -61.848  55.084  1
479689  91.462  -61.857  55.080  1
479690  91.504  -61.867  55.071  1
479691  91.546  -61.876  55.068  1
479692  91.588  -61.885  55.071  1
479693  91.630  -61.896  55.070  1
479694  91.670  -61.908  55.065  1
479695  91.708  -61.927  55.057  1
479696  91.745  -61.945  55.039  1
479697  91.783  -61.964  55.013  1
479698  91.821  -61.982  54.981  1
479699  91.859  -62.001  54.947  1
479700  91.896  -62.019  54.924  1
479701  91.934  -62.037  54.908  1
479702  91.974  -62.055  54.892  1
479703  92.018  -62.070  54.866  1
479704  92.063  -62.086  54.827  1
479705  92.104  -62.092  54.794  1
479706  92.143  -62.092  54.768  1
479707  92.181  -62.091  54.748  1
479708  92.220  -62.090  54.733  1
479709  92.258  -62.090  54.712  1
479710  92.294  -62.091  54.685  1
479711  92.329  -62.092  54.659  1
479712  92.364  -62.093  54.637  1
479713  92.399  -62.095  54.618  1
479714  92.447  -62.102  54.598  1
479715  92.496  -62.109  54.577  1
479716  92.545  -62.116  54.556  1
479717  92.593  -62.123  54.538  1
479718  92.642  -62.130  54.519  1
479719  92.691  -62.138  54.500  1
479720  92.739  -62.145  54.476  1
479721  92.788  -62.152  54.450  1
479722  92.809  -62.165  54.424  1
479723  92.834  -62.180  54.398  1
479724  92.878  -62.196  54.378  1
479725  92.922  -62.212  54.361  1
479726  92.967  -62.228  54.344  1
479727  93.009  -62.239  54.329  1
479728  93.051  -62.250  54.316  1
479729  93.093  -62.261  54.301  1
479730  93.136  -62.271  54.289  1
479731  93.179  -62.280  54.277  1
479732  93.222  -62.286  54.264  1
479733  93.266  -62.291  54.251  1
479734  93.310  -62.297  54.240  1
479735  93.351  -62.302  54.228  1
479736  93.392  -62.305  54.216  1
479737  93.432  -62.310  54.209  1
479738  93.473  -62.315  54.209  1
479739  93.514  -62.319  54.218  1
479740  93.555  -62.323  54.225  1
479741  93.595  -62.327  54.229  1
479742  93.635  -62.333  54.230  1
479743  93.671  -62.329  54.227  1
479744  93.706  -62.324  54.219  1
479745  93.743  -62.349  54.211  1
479746  93.780  -62.373  54.199  1
479747  93.818  -62.397  54.184  1
479748  93.855  -62.421  54.166  1
479749  93.896  -62.443  54.146  1
479750  93.954  -62.452  54.125  1
479751  94.010  -62.461  54.103  1
479752  94.063  -62.450  54.080  1
479753  94.114  -62.433  54.053  1
479754  94.160  -62.431  54.026  1
479755  94.205  -62.434  53.997  1
479756  94.249  -62.438  53.968  1
479757  94.293  -62.442  53.937  1
479758  94.338  -62.446  53.904  1
479759  94.382  -62.449  53.872  1
479760  94.426  -62.454  53.838  1
479761  94.473  -62.459  53.801  1
479762  94.527  -62.467  53.762  1
479763  94.581  -62.475  53.722  1
479764  94.636  -62.483  53.681  1
479765  94.658  -62.500  53.640  1
479766  94.677  -62.518  53.603  1
479767  94.696  -62.537  53.568  1
479768  94.715  -62.555  53.533  1
479769  94.735  -62.573  53.498  1
479770  94.754  -62.590  53.462  1
479771  94.787  -62.605  53.428  1
479772  94.832  -62.631  53.394  1
479773  94.877  -62.658  53.360  1
479774  94.922  -62.684  53.326  1
479775  94.948  -62.692  53.293  1
479776  94.935  -62.666  53.262  1
479777  94.962  -62.663  53.232  1
479778  95.000  -62.666  53.202  1
479779  95.038  -62.669  53.176  1
479780  95.076  -62.673  53.147  1
479781  95.114  -62.676  53.119  1
479782  95.151  -62.679  53.092  1
479783  95.189  -62.683  53.066  1
479784  95.228  -62.686  53.041  1
479785  95.265  -62.689  53.015  1
479786  95.313  -62.689  52.988  1
479787  95.364  -62.688  52.960  1
479788  95.414  -62.687  52.932  1
479789  95.464  -62.686  52.903  1
479790  95.515  -62.685  52.875  1
479791  95.565  -62.684  52.846  1
479792  95.615  -62.684  52.816  1
479793  95.656  -62.719  52.786  1
479794  95.697  -62.753  52.756  1
479795  95.741  -62.783  52.723  1
479796  95.802  -62.775  52.691  1
479797  95.871  -62.747  52.658  1
479798  95.914  -62.733  52.624  1
479799  95.957  -62.719  52.588  1
479800  96.001  -62.703  52.552  1
479801  96.044  -62.689  52.517  1
479802  96.088  -62.675  52.481  1
479803  96.131  -62.660  52.446  1
479804  96.174  -62.646  52.410  1
479805  96.218  -62.631  52.373  1
479806  96.268  -62.639  52.336  1
479807  96.323  -62.657  52.299  1
479808  96.352  -62.674  52.262  1
479809  96.410  -62.686  52.224  1
479810  96.449  -62.698  52.186  1
479811  96.488  -62.711  52.148  1
479812  96.527  -62.723  52.110  1
479813  96.566  -62.735  52.071  1
479814  96.603  -62.749  52.032  1
479815  96.636  -62.767  51.993  1
479816  96.668  -62.785  51.954  1
479817  96.701  -62.803  51.915  1
479818  96.734  -62.820  51.877  1
479819  96.766  -62.838  51.837  1
479820  96.802  -62.850  51.801  1
479821  96.839  -62.856  51.764  1
479822  96.876  -62.862  51.728  1
479823  96.914  -62.868  51.694  1
479824  96.951  -62.874  51.661  1
479825  96.989  -62.880  51.627  1
479826  97.026  -62.886  51.595  1
479827  97.063  -62.892  51.564  1
479828  97.100  -62.898  51.532  1
479829  97.139  -62.904  51.500  1
479830  97.178  -62.909  51.469  1
479831  97.218  -62.913  51.438  1
479832  97.257  -62.919  51.406  1
479833  97.297  -62.924  51.373  1
479834  97.336  -62.929  51.339  1
479835  97.376  -62.934  51.306  1
479836  97.416  -62.938  51.271  1
479837  97.455  -62.944  51.235  1
479838  97.494  -62.949  51.200  1
479839  97.534  -62.954  51.163  1
479840  97.575  -62.957  51.125  1
479841  97.601  -62.949  51.085  1
479842  97.616  -62.926  51.043  1
479843  97.631  -62.901  51.000  1
479844  97.646  -62.877  50.957  1
479845  97.674  -62.863  50.912  1
479846  97.708  -62.851  50.865  1
479847  97.741  -62.838  50.818  1
479848  97.774  -62.827  50.772  1
479849  97.807  -62.815  50.727  1
479850  97.840  -62.803  50.682  1
479851  97.874  -62.793  50.637  1
479852  97.928  -62.807  50.591  1
479853  97.982  -62.821  50.546  1
479854  98.035  -62.835  50.501  1
479855  98.089  -62.850  50.456  1
479856  98.143  -62.863  50.411  1
479857  98.162  -62.879  50.366  1
479858  98.173  -62.894  50.321  1
479859  98.184  -62.909  50.277  1
479860  98.195  -62.923  50.234  1
479861  98.206  -62.938  50.192  1
479862  98.227  -62.954  50.150  1
479863  98.251  -62.970  50.109  1
480310  87.869  -60.970  55.897  1
480311  87.906  -60.971  55.881  1
480312  87.942  -60.973  55.865  1
480313  87.979  -60.975  55.850  1
480314  88.015  -60.977  55.832  1
480315  88.052  -60.979  55.815  1
480316  88.089  -60.980  55.797  1
480317  88.126  -60.983  55.779  1
480318  88.163  -60.984  55.759  1
480319  88.200  -60.986  55.740  1
480320  88.249  -60.982  55.720  1
480321  88.297  -60.979  55.699  1
480322  88.358  -60.982  55.677  1
480323  88.425  -60.988  55.653  1
480324  88.492  -60.994  55.628  1
480325  88.567  -60.989  55.603  1
480326  88.643  -60.983  55.577  1
480327  88.719  -60.976  55.550  1
480328  88.793  -60.974  55.523  1
480329  88.838  -60.999  55.496  1
480330  88.883  -61.025  55.468  1
480331  88.927  -61.050  55.441  1
480332  88.972  -61.076  55.415  1
480333  89.015  -61.094  55.390  1
480334  89.058  -61.112  55.366  1
480335  89.101  -61.130  55.345  1
480336  89.144  -61.149  55.325  1
480337  89.188  -61.167  55.309  1
480338  89.231  -61.185  55.298  1
480339  89.274  -61.203  55.285  1
480340  89.317  -61.221  55.273  1
480341  89.360  -61.240  55.262  1
480342  89.403  -61.258  55.251  1
480343  89.447  -61.276  55.238  1
480344  89.489  -61.294  55.223  1
480345  89.533  -61.312  55.209  1
480346  89.569  -61.315  55.197  1
480347  89.605  -61.314  55.186  1
480348  89.640  -61.312  55.175  1
480349  89.675  -61.311  55.161  1
480350  89.710  -61.309  55.150  1
480351  89.745  -61.308  55.141  1
480352  89.780  -61.306  55.135  1
480353  89.815  -61.305  55.130  1
480354  89.850  -61.303  55.126  1
480355  89.885  -61.302  55.124  1
480356  89.930  -61.321  55.123  1
480357  89.987  -61.370  55.124  1
480358  90.041  -61.409  55.125  1
480359  90.091  -61.438  55.125  1
480360  90.141  -61.467  55.127  1
480361  90.190  -61.496  55.134  1
480362  90.238  -61.519  55.144  1
480363  90.279  -61.525  55.153  1
480364  90.319  -61.532  55.158  1
480365  90.360  -61.540  55.160  1
480366  90.402  -61.549  55.157  1
480367  90.447  -61.562  55.151  1
480368  90.493  -61.575  55.140  1
480369  90.538  -61.588  55.123  1
480370  90.583  -61.601  55.101  1
480371  90.628  -61.614  55.078  1
480372  90.674  -61.627  55.057  1
480373  90.719  -61.640  55.044  1
480374  90.764  -61.653  55.036  1
480375  90.809  -61.664  55.030  1
480376  90.855  -61.672  55.027  1
480377  90.903  -61.681  55.027  1
480378  90.951  -61.688  55.030  1
480379  91.000  -61.697  55.039  1
480380  91.047  -61.705  55.055  1
480381  91.091  -61.716  55.073  1
480382  91.134  -61.729  55.088  1
480383  91.176  -61.741  55.099  1
480384  91.219  -61.753  55.101  1
480385  91.261  -61.765  55.091  1
480386  91.303  -61.777  55.087  1
480387  91.346  -61.787  55.088  1
480388  91.387  -61.796  55.091  1
480389  91.430  -61.806  55.090  1
480390  91.471  -61.815  55.086  1
480391  91.514  -61.824  55.078  1
480392  91.556  -61.834  55.073  1
480393  91.597  -61.845  55.074  1
480394  91.639  -61.855  55.070  1
480395  91.680  -61.867  55.070  1
480396  91.718  -61.884  55.061  1
480397  91.756  -61.902  55.043  1
480398  91.793  -61.921  55.017  1
480399  91.831  -61.939  54.983  1
480400  91.869  -61.957  54.952  1
480401  91.907  -61.976  54.934  1
480402  91.945  -61.994  54.920  1
480403  91.990  -62.010  54.901  1
480404  92.035  -62.025  54.870  1
480405  92.080  -62.040  54.829  1
480406  92.125  -62.056  54.795  1
480407  92.164  -62.058  54.770  1
480408  92.203  -62.057  54.751  1
480409  92.241  -62.056  54.735  1
480410  92.278  -62.056  54.712  1
480411  92.313  -62.058  54.688  1
480412  92.348  -62.059  54.666  1
480413  92.383  -62.061  54.650  1
480414  92.418  -62.061  54.635  1
480415  92.454  -62.064  54.616  1
480416  92.503  -62.071  54.592  1
480417  92.552  -62.078  54.568  1
480418  92.600  -62.085  54.545  1
480419  92.649  -62.092  54.521  1
480420  92.698  -62.099  54.496  1
480421  92.746  -62.107  54.469  1
480422  92.794  -62.114  54.442  1
480423  92.810  -62.128  54.416  1
480424  92.846  -62.144  54.392  1
480425  92.890  -62.160  54.374  1
480426  92.934  -62.176  54.357  1
480427  92.979  -62.192  54.339  1
480428  93.022  -62.208  54.321  1
480429  93.066  -62.221  54.306  1
480430  93.108  -62.231  54.288  1
480431  93.151  -62.239  54.273  1
480432  93.195  -62.245  54.260  1
480433  93.238  -62.251  54.247  1
480434  93.282  -62.257  54.234  1
480435  93.326  -62.262  54.221  1
480436  93.366  -62.267  54.210  1
480437  93.407  -62.271  54.200  1
480438  93.448  -62.275  54.195  1
480439  93.489  -62.280  54.197  1
480440  93.530  -62.283  54.206  1
480441  93.567  -62.287  54.212  1
480442  93.604  -62.293  54.215  1
480443  93.641  -62.305  54.215  1
480444  93.680  -62.316  54.212  1
480445  93.715  -62.312  54.204  1
480446  93.752  -62.317  54.195  1
480447  93.789  -62.341  54.182  1
480448  93.826  -62.365  54.167  1
480449  93.863  -62.390  54.149  1
480450  93.908  -62.408  54.129  1
480451  93.965  -62.417  54.110  1
480452  94.020  -62.417  54.090  1
480453  94.071  -62.399  54.068  1
480454  94.118  -62.396  54.044  1
480455  94.162  -62.400  54.019  1
480456  94.206  -62.404  53.992  1
480457  94.250  -62.409  53.963  1
480458  94.294  -62.412  53.932  1
480459  94.339  -62.416  53.899  1
480460  94.383  -62.420  53.865  1
480461  94.427  -62.424  53.830  1
480462  94.473  -62.428  53.792  1
480463  94.528  -62.437  53.753  1
480464  94.582  -62.445  53.713  1
480465  94.617  -62.459  53.671  1
480466  94.636  -62.477  53.631  1
480467  94.655  -62.495  53.594  1
480468  94.675  -62.513  53.558  1
480469  94.694  -62.531  53.521  1
480470  94.736  -62.532  53.482  1
480471  94.771  -62.537  53.445  1
480472  94.786  -62.558  53.411  1
480473  94.831  -62.584  53.377  1
480474  94.876  -62.611  53.342  1
480475  94.921  -62.637  53.309  1
480476  94.941  -62.640  53.276  1
480477  94.930  -62.615  53.244  1
480478  94.968  -62.618  53.214  1
480479  95.005  -62.622  53.186  1
480480  95.044  -62.625  53.159  1
480481  95.082  -62.628  53.130  1
480482  95.119  -62.631  53.102  1
480483  95.157  -62.634  53.075  1
480484  95.195  -62.637  53.049  1
480485  95.233  -62.641  53.025  1
480486  95.271  -62.644  52.999  1
480487  95.309  -62.647  52.972  1
480488  95.346  -62.650  52.945  1
480489  95.397  -62.650  52.918  1
480490  95.447  -62.648  52.891  1
480491  95.498  -62.647  52.864  1
480492  95.548  -62.647  52.837  1
480493  95.599  -62.645  52.808  1
480494  95.642  -62.669  52.778  1
480495  95.683  -62.704  52.748  1
480496  95.725  -62.739  52.715  1
480497  95.771  -62.760  52.683  1
480498  95.841  -62.732  52.651  1
480499  95.910  -62.703  52.617  1
480500  95.958  -62.687  52.582  1
480501  96.002  -62.672  52.546  1
480502  96.045  -62.657  52.511  1
480503  96.089  -62.643  52.476  1
480504  96.132  -62.628  52.440  1
480505  96.176  -62.614  52.404  1
480506  96.219  -62.599  52.366  1
480507  96.272  -62.616  52.328  1
480508  96.327  -62.634  52.291  1
480509  96.357  -62.650  52.253  1
480510  96.413  -62.663  52.215  1
480511  96.452  -62.675  52.177  1
480512  96.490  -62.687  52.138  1
480513  96.530  -62.699  52.099  1
480514  96.564  -62.716  52.059  1
480515  96.597  -62.733  52.019  1
480516  96.629  -62.750  51.980  1
480517  96.662  -62.769  51.940  1
480518  96.696  -62.784  51.901  1
480519  96.733  -62.790  51.862  1
480520  96.771  -62.796  51.822  1
480521  96.808  -62.802  51.784  1
480522  96.846  -62.808  51.747  1
480523  96.883  -62.814  51.711  1
480524  96.920  -62.820  51.677  1
480525  96.957  -62.826  51.642  1
480526  96.995  -62.832  51.609  1
480527  97.032  -62.838  51.576  1
480528  97.070  -62.844  51.545  1
480529  97.107  -62.851  51.513  1
480530  97.146  -62.856  51.481  1
480531  97.186  -62.861  51.449  1
480532  97.225  -62.866  51.418  1
480533  97.264  -62.871  51.385  1
480534  97.304  -62.876  51.352  1
480535  97.344  -62.881  51.319  1
480536  97.383  -62.886  51.285  1
480537  97.423  -62.891  51.250  1
480538  97.462  -62.896  51.214  1
480539  97.502  -62.901  51.179  1
480540  97.541  -62.906  51.143  1
480541  97.577  -62.912  51.105  1
480542  97.608  -62.905  51.065  1
480543  97.624  -62.881  51.024  1
480544  97.638  -62.857  50.982  1
480545  97.653  -62.833  50.940  1
480546  97.682  -62.819  50.895  1
480547  97.716  -62.807  50.849  1
480548  97.749  -62.795  50.803  1
480549  97.782  -62.783  50.757  1
480550  97.815  -62.771  50.712  1
480551  97.848  -62.759  50.667  1
480552  97.888  -62.757  50.622  1
480553  97.942  -62.771  50.577  1
480554  97.996  -62.785  50.532  1
480555  98.049  -62.799  50.487  1
480556  98.103  -62.813  50.442  1
480557  98.144  -62.828  50.398  1
480558  98.155  -62.843  50.354  1
480559  98.165  -62.858  50.310  1
480560  98.176  -62.873  50.266  1
480561  98.187  -62.888  50.224  1
480562  98.205  -62.904  50.182  1
480563  98.229  -62.919  50.141  1
481011  87.884  -60.922  55.887  1
481012  87.921  -60.923  55.871  1
481013  87.958  -60.926  55.855  1
481014  87.994  -60.927  55.839  1
481015  88.031  -60.929  55.823  1
481016  88.067  -60.931  55.806  1
481017  88.104  -60.933  55.788  1
481018  88.141  -60.934  55.769  1
481019  88.178  -60.936  55.750  1
481020  88.214  -60.938  55.731  1
481021  88.258  -60.936  55.712  1
481022  88.307  -60.933  55.690  1
481023  88.369  -60.937  55.667  1
481024  88.436  -60.943  55.643  1
481025  88.509  -60.942  55.619  1
481026  88.585  -60.936  55.593  1
481027  88.661  -60.929  55.567  1
481028  88.737  -60.923  55.540  1
481029  88.808  -60.923  55.513  1
481030  88.852  -60.949  55.485  1
481031  88.897  -60.974  55.457  1
481032  88.942  -61.000  55.431  1
481033  88.985  -61.022  55.405  1
481034  89.029  -61.040  55.379  1
481035  89.072  -61.058  55.355  1
481036  89.115  -61.077  55.333  1
481037  89.158  -61.095  55.313  1
481038  89.201  -61.114  55.297  1
481039  89.244  -61.132  55.284  1
481040  89.287  -61.150  55.274  1
481041  89.331  -61.168  55.264  1
481042  89.374  -61.187  55.256  1
481043  89.417  -61.205  55.248  1
481044  89.460  -61.223  55.237  1
481045  89.503  -61.241  55.224  1
481046  89.546  -61.259  55.210  1
481047  89.590  -61.277  55.194  1
481048  89.626  -61.279  55.181  1
481049  89.661  -61.277  55.169  1
481050  89.696  -61.276  55.155  1
481051  89.731  -61.274  55.143  1
481052  89.766  -61.273  55.132  1
481053  89.801  -61.271  55.125  1
481054  89.836  -61.270  55.119  1
481055  89.872  -61.268  55.114  1
481056  89.906  -61.267  55.112  1
481057  89.954  -61.293  55.111  1
481058  90.012  -61.343  55.111  1
481059  90.071  -61.393  55.112  1
481060  90.120  -61.423  55.112  1
481061  90.170  -61.453  55.113  1
481062  90.216  -61.470  55.116  1
481063  90.256  -61.477  55.121  1
481064  90.297  -61.484  55.128  1
481065  90.337  -61.491  55.135  1
481066  90.378  -61.498  55.141  1
481067  90.423  -61.510  55.142  1
481068  90.468  -61.523  55.140  1
481069  90.513  -61.536  55.132  1
481070  90.558  -61.550  55.117  1
481071  90.604  -61.563  55.097  1
481072  90.649  -61.575  55.074  1
481073  90.694  -61.588  55.055  1
481074  90.739  -61.600  55.043  1
481075  90.782  -61.609  55.038  1
481076  90.825  -61.617  55.032  1
481077  90.871  -61.625  55.028  1
481078  90.919  -61.634  55.025  1
481079  90.967  -61.642  55.027  1
481080  91.015  -61.650  55.034  1
481081  91.059  -61.661  55.049  1
481082  91.101  -61.674  55.067  1
481083  91.143  -61.686  55.084  1
481084  91.186  -61.698  55.097  1
481085  91.228  -61.710  55.101  1
481086  91.271  -61.722  55.092  1
481087  91.313  -61.735  55.087  1
481088  91.355  -61.745  55.087  1
481089  91.397  -61.754  55.091  1
481090  91.439  -61.763  55.093  1
481091  91.481  -61.773  55.090  1
481092  91.523  -61.782  55.083  1
481093  91.565  -61.793  55.079  1
481094  91.606  -61.804  55.079  1
481095  91.648  -61.815  55.073  1
481096  91.689  -61.826  55.070  1
481097  91.728  -61.841  55.061  1
481098  91.766  -61.860  55.043  1
481099  91.804  -61.878  55.017  1
481100  91.842  -61.897  54.987  1
481101  91.879  -61.915  54.959  1
481102  91.917  -61.933  54.943  1
481103  91.962  -61.948  54.928  1
481104  92.007  -61.964  54.907  1
481105  92.052  -61.979  54.871  1
481106  92.096  -61.995  54.830  1
481107  92.141  -62.011  54.797  1
481108  92.185  -62.023  54.772  1
481109  92.223  -62.023  54.753  1
481110  92.262  -62.022  54.736  1
481111  92.297  -62.023  54.712  1
481112  92.333  -62.024  54.690  1
481113  92.367  -62.026  54.674  1
481114  92.403  -62.027  54.664  1
481115  92.437  -62.028  54.653  1
481116  92.473  -62.029  54.633  1
481117  92.511  -62.033  54.608  1
481118  92.560  -62.040  54.581  1
481119  92.609  -62.047  54.556  1
481120  92.657  -62.054  54.527  1
481121  92.706  -62.061  54.497  1
481122  92.755  -62.068  54.467  1
481123  92.795  -62.077  54.438  1
481124  92.814  -62.092  54.411  1
481125  92.859  -62.108  54.387  1
481126  92.903  -62.123  54.369  1
481127  92.947  -62.139  54.351  1
481128  92.991  -62.156  54.333  1
481129  93.035  -62.172  54.313  1
481130  93.079  -62.188  54.295  1
481131  93.123  -62.199  54.278  1
481132  93.167  -62.205  54.262  1
481133  93.211  -62.210  54.247  1
481134  93.255  -62.216  54.233  1
481135  93.298  -62.222  54.219  1
481136  93.341  -62.227  54.206  1
481137  93.382  -62.232  54.194  1
481138  93.423  -62.236  54.186  1
481139  93.464  -62.240  54.181  1
481140  93.501  -62.243  54.181  1
481141  93.535  -62.244  54.186  1
481142  93.572  -62.253  54.188  1
481143  93.610  -62.265  54.190  1
481144  93.648  -62.276  54.189  1
481145  93.687  -62.287  54.186  1
481146  93.724  -62.299  54.178  1
481147  93.761  -62.296  54.169  1
481148  93.797  -62.309  54.157  1
481149  93.834  -62.333  54.142  1
481150  93.871  -62.358  54.125  1
481151  93.920  -62.374  54.109  1
481152  93.977  -62.383  54.093  1
481153  94.028  -62.366  54.075  1
481154  94.075  -62.363  54.055  1
481155  94.119  -62.367  54.034  1
481156  94.163  -62.371  54.012  1
481157  94.207  -62.374  53.986  1
481158  94.252  -62.378  53.958  1
481159  94.296  -62.382  53.927  1
481160  94.340  -62.387  53.893  1
481161  94.384  -62.390  53.858  1
481162  94.428  -62.394  53.821  1
481163  94.474  -62.399  53.782  1
481164  94.529  -62.407  53.743  1
481165  94.576  -62.417  53.703  1
481166  94.596  -62.435  53.661  1
481167  94.615  -62.453  53.621  1
481168  94.634  -62.471  53.583  1
481169  94.672  -62.475  53.546  1
481170  94.722  -62.469  53.507  1
481171  94.762  -62.472  53.468  1
481172  94.778  -62.493  53.430  1
481173  94.793  -62.512  53.394  1
481174  94.830  -62.537  53.360  1
481175  94.876  -62.564  53.327  1
481176  94.920  -62.590  53.293  1
481177  94.933  -62.587  53.260  1
481178  94.935  -62.569  53.228  1
481179  94.973  -62.573  53.199  1
481180  95.011  -62.576  53.170  1
481181  95.049  -62.579  53.143  1
481182  95.087  -62.583  53.116  1
481183  95.125  -62.586  53.089  1
481184  95.163  -62.589  53.063  1
481185  95.200  -62.592  53.038  1
481186  95.239  -62.596  53.013  1
481187  95.276  -62.599  52.987  1
481188  95.314  -62.602  52.962  1
481189  95.352  -62.606  52.936  1
481190  95.390  -62.609  52.910  1
481191  95.430  -62.611  52.885  1
481192  95.481  -62.610  52.858  1
481193  95.531  -62.609  52.830  1
481194  95.582  -62.608  52.802  1
481195  95.628  -62.620  52.772  1
481196  95.670  -62.655  52.741  1
481197  95.710  -62.690  52.710  1
481198  95.777  -62.716  52.678  1
481199  95.822  -62.710  52.645  1
481200  95.880  -62.688  52.613  1
481201  95.949  -62.660  52.579  1
481202  96.003  -62.640  52.543  1
481203  96.046  -62.625  52.508  1
481204  96.090  -62.611  52.473  1
481205  96.133  -62.597  52.437  1
481206  96.177  -62.582  52.401  1
481207  96.222  -62.574  52.362  1
481208  96.276  -62.592  52.323  1
481209  96.331  -62.611  52.284  1
481210  96.368  -62.627  52.246  1
481211  96.415  -62.638  52.208  1
481212  96.455  -62.650  52.170  1
481213  96.493  -62.664  52.130  1
481214  96.525  -62.681  52.089  1
481215  96.558  -62.699  52.048  1
481216  96.591  -62.717  52.007  1
481217  96.628  -62.724  51.967  1
481218  96.665  -62.730  51.927  1
481219  96.702  -62.736  51.887  1
481220  96.740  -62.743  51.847  1
481221  96.777  -62.749  51.807  1
481222  96.814  -62.755  51.768  1
481223  96.852  -62.761  51.731  1
481224  96.889  -62.767  51.695  1
481225  96.927  -62.773  51.659  1
481226  96.964  -62.779  51.625  1
481227  97.001  -62.785  51.591  1
481228  97.038  -62.791  51.559  1
481229  97.076  -62.797  51.526  1
481230  97.114  -62.803  51.494  1
481231  97.154  -62.808  51.462  1
481232  97.193  -62.813  51.431  1
481233  97.232  -62.818  51.398  1
481234  97.272  -62.823  51.365  1
481235  97.311  -62.828  51.332  1
481236  97.351  -62.833  51.300  1
481237  97.390  -62.838  51.265  1
481238  97.430  -62.843  51.230  1
481239  97.469  -62.848  51.195  1
481240  97.509  -62.853  51.159  1
481241  97.544  -62.860  51.123  1
481242  97.572  -62.869  51.085  1
481243  97.616  -62.861  51.045  1
481244  97.631  -62.837  51.005  1
481245  97.646  -62.813  50.964  1
481246  97.660  -62.789  50.922  1
481247  97.690  -62.775  50.877  1
481248  97.724  -62.763  50.833  1
481249  97.756  -62.751  50.788  1
481250  97.790  -62.739  50.743  1
481251  97.823  -62.727  50.698  1
481252  97.856  -62.716  50.654  1
481253  97.902  -62.720  50.609  1
481254  97.956  -62.735  50.564  1
481255  98.010  -62.749  50.519  1
481256  98.063  -62.763  50.474  1
481257  98.117  -62.777  50.430  1
481258  98.136  -62.792  50.387  1
481259  98.147  -62.807  50.344  1
481260  98.158  -62.822  50.300  1
481261  98.169  -62.837  50.257  1
481262  98.182  -62.852  50.214  1
481712  87.899  -60.874  55.878  1
481713  87.936  -60.876  55.862  1
481714  87.973  -60.877  55.845  1
481715  88.009  -60.879  55.830  1
481716  88.046  -60.881  55.814  1
481717  88.083  -60.883  55.796  1
481718  88.120  -60.885  55.778  1
481719  88.156  -60.886  55.760  1
481720  88.193  -60.889  55.741  1
481721  88.229  -60.890  55.721  1
481722  88.268  -60.892  55.702  1
481723  88.316  -60.888  55.681  1
481724  88.380  -60.892  55.659  1
481725  88.450  -60.895  55.635  1
481726  88.526  -60.888  55.610  1
481727  88.602  -60.881  55.584  1
481728  88.678  -60.875  55.558  1
481729  88.753  -60.870  55.531  1
481730  88.822  -60.873  55.504  1
481731  88.867  -60.898  55.475  1
481732  88.911  -60.924  55.447  1
481733  88.956  -60.949  55.421  1
481734  88.999  -60.969  55.395  1
481735  89.042  -60.987  55.369  1
481736  89.086  -61.005  55.345  1
481737  89.128  -61.024  55.322  1
481738  89.172  -61.042  55.302  1
481739  89.215  -61.060  55.284  1
481740  89.258  -61.078  55.270  1
481741  89.301  -61.096  55.261  1
481742  89.344  -61.114  55.254  1
481743  89.387  -61.133  55.249  1
481744  89.430  -61.152  55.244  1
481745  89.474  -61.170  55.237  1
481746  89.517  -61.188  55.225  1
481747  89.560  -61.206  55.211  1
481748  89.603  -61.224  55.195  1
481749  89.647  -61.243  55.179  1
481750  89.682  -61.243  55.163  1
481751  89.718  -61.242  55.149  1
481752  89.753  -61.240  55.136  1
481753  89.788  -61.239  55.125  1
481754  89.823  -61.237  55.116  1
481755  89.858  -61.236  55.108  1
481756  89.893  -61.234  55.104  1
481757  89.928  -61.233  55.100  1
481758  89.979  -61.267  55.098  1
481759  90.037  -61.316  55.098  1
481760  90.095  -61.365  55.098  1
481761  90.150  -61.409  55.099  1
481762  90.193  -61.422  55.099  1
481763  90.234  -61.428  55.100  1
481764  90.274  -61.436  55.102  1
481765  90.315  -61.443  55.106  1
481766  90.356  -61.450  55.114  1
481767  90.398  -61.459  55.122  1
481768  90.444  -61.472  55.127  1
481769  90.489  -61.484  55.127  1
481770  90.534  -61.497  55.123  1
481771  90.580  -61.511  55.110  1
481772  90.625  -61.524  55.092  1
481773  90.669  -61.536  55.072  1
481774  90.712  -61.544  55.054  1
481775  90.755  -61.553  55.044  1
481776  90.798  -61.562  55.040  1
481777  90.840  -61.571  55.035  1
481778  90.886  -61.579  55.030  1
481779  90.935  -61.587  55.027  1
481780  90.982  -61.595  55.026  1
481781  91.026  -61.606  55.030  1
481782  91.068  -61.619  55.042  1
481783  91.110  -61.632  55.059  1
481784  91.153  -61.644  55.078  1
481785  91.195  -61.656  55.094  1
481786  91.238  -61.668  55.100  1
481787  91.280  -61.680  55.094  1
481788  91.322  -61.692  55.088  1
481789  91.365  -61.703  55.085  1
481790  91.406  -61.713  55.089  1
481791  91.449  -61.722  55.093  1
481792  91.491  -61.732  55.092  1
481793  91.532  -61.741  55.088  1
481794  91.574  -61.752  55.085  1
481795  91.615  -61.763  55.084  1
481796  91.657  -61.774  55.077  1
481797  91.699  -61.785  55.070  1
481798  91.739  -61.798  55.058  1
481799  91.776  -61.817  55.042  1
481800  91.814  -61.835  55.021  1
481801  91.852  -61.854  54.995  1
481802  91.889  -61.872  54.968  1
481803  91.933  -61.888  54.952  1
481804  91.979  -61.904  54.936  1
481805  92.023  -61.919  54.911  1
481806  92.068  -61.934  54.873  1
481807  92.113  -61.950  54.831  1
481808  92.158  -61.965  54.797  1
481809  92.203  -61.981  54.772  1
481810  92.244  -61.988  54.755  1
481811  92.282  -61.988  54.737  1
481812  92.317  -61.989  54.713  1
481813  92.352  -61.991  54.695  1
481814  92.387  -61.992  54.685  1
481815  92.422  -61.994  54.679  1
481816  92.457  -61.995  54.668  1
481817  92.492  -61.996  54.648  1
481818  92.526  -61.998  54.623  1
481819  92.567  -62.001  54.597  1
481820  92.616  -62.009  54.572  1
481821  92.664  -62.016  54.540  1
481822  92.713  -62.023  54.505  1
481823  92.762  -62.030  54.470  1
481824  92.797  -62.040  54.438  1
481825  92.827  -62.055  54.409  1
481826  92.871  -62.071  54.384  1
481827  92.915  -62.087  54.364  1
481828  92.959  -62.104  54.345  1
481829  93.003  -62.120  54.326  1
481830  93.047  -62.136  54.305  1
481831  93.086  -62.147  54.286  1
481832  93.131  -62.158  54.269  1
481833  93.179  -62.167  54.252  1
481834  93.227  -62.176  54.236  1
481835  93.271  -62.181  54.222  1
481836  93.314  -62.187  54.207  1
481837  93.357  -62.192  54.194  1
481838  93.398  -62.197  54.182  1
481839  93.435  -62.199  54.174  1
481840  93.469  -62.201  54.168  1
481841  93.503  -62.202  54.164  1
481842  93.541  -62.213  54.163  1
481843  93.579  -62.224  54.163  1
481844  93.617  -62.236  54.161  1
481845  93.655  -62.247  54.157  1
481846  93.693  -62.258  54.152  1
481847  93.731  -62.270  54.144  1
481848  93.769  -62.281  54.135  1
481849  93.805  -62.279  54.125  1
481850  93.843  -62.302  54.113  1
481851  93.880  -62.326  54.103  1
481852  93.931  -62.339  54.092  1
481853  93.985  -62.332  54.078  1
481854  94.032  -62.329  54.062  1
481855  94.076  -62.333  54.043  1
481856  94.120  -62.337  54.023  1
481857  94.165  -62.341  54.004  1
481858  94.209  -62.345  53.980  1
481859  94.253  -62.349  53.952  1
481860  94.297  -62.352  53.921  1
481861  94.341  -62.356  53.887  1
481862  94.386  -62.360  53.849  1
481863  94.430  -62.365  53.812  1
481864  94.475  -62.368  53.773  1
481865  94.530  -62.377  53.733  1
481866  94.555  -62.393  53.691  1
481867  94.574  -62.411  53.650  1
481868  94.608  -62.418  53.609  1
481869  94.659  -62.412  53.571  1
481870  94.709  -62.407  53.533  1
481871  94.753  -62.406  53.492  1
481872  94.769  -62.427  53.454  1
481873  94.784  -62.447  53.415  1
481874  94.800  -62.468  53.379  1
481875  94.829  -62.490  53.345  1
481876  94.875  -62.517  53.312  1
481877  94.919  -62.543  53.278  1
481878  94.926  -62.534  53.246  1
481879  94.941  -62.525  53.215  1
481880  94.979  -62.528  53.185  1
481881  95.017  -62.531  53.157  1
481882  95.055  -62.534  53.132  1
481883  95.093  -62.537  53.105  1
481884  95.130  -62.540  53.079  1
481885  95.168  -62.543  53.055  1
481886  95.206  -62.547  53.030  1
481887  95.244  -62.550  53.005  1
481888  95.282  -62.553  52.980  1
481889  95.320  -62.557  52.955  1
481890  95.357  -62.560  52.930  1
481891  95.396  -62.563  52.905  1
481892  95.433  -62.566  52.880  1
481893  95.471  -62.570  52.854  1
481894  95.514  -62.572  52.827  1
481895  95.564  -62.570  52.799  1
481896  95.615  -62.571  52.769  1
481897  95.656  -62.606  52.738  1
481898  95.716  -62.633  52.706  1
481899  95.791  -62.658  52.674  1
481900  95.839  -62.669  52.642  1
481901  95.881  -62.656  52.610  1
481902  95.923  -62.643  52.577  1
481903  95.988  -62.617  52.542  1
481904  96.047  -62.594  52.508  1
481905  96.091  -62.579  52.473  1
481906  96.134  -62.565  52.438  1
481907  96.178  -62.550  52.401  1
481908  96.226  -62.550  52.364  1
481909  96.281  -62.569  52.326  1
481910  96.335  -62.587  52.288  1
481911  96.380  -62.603  52.248  1
481912  96.418  -62.615  52.209  1
481913  96.454  -62.630  52.169  1
481914  96.486  -62.647  52.126  1
481915  96.522  -62.659  52.083  1
481916  96.559  -62.665  52.040  1
481917  96.597  -62.671  51.998  1
481918  96.634  -62.677  51.957  1
481919  96.671  -62.683  51.916  1
481920  96.709  -62.689  51.875  1
481921  96.746  -62.695  51.835  1
481922  96.784  -62.701  51.794  1
481923  96.821  -62.707  51.755  1
481924  96.858  -62.713  51.717  1
481925  96.895  -62.719  51.680  1
481926  96.933  -62.725  51.644  1
481927  96.970  -62.732  51.609  1
481928  97.008  -62.738  51.575  1
481929  97.045  -62.744  51.541  1
481930  97.082  -62.750  51.509  1
481931  97.121  -62.755  51.477  1
481932  97.161  -62.760  51.445  1
481933  97.200  -62.766  51.413  1
481934  97.240  -62.770  51.380  1
481935  97.279  -62.775  51.347  1
481936  97.318  -62.780  51.315  1
481937  97.358  -62.785  51.281  1
481938  97.397  -62.791  51.246  1
481939  97.437  -62.795  51.212  1
481940  97.476  -62.800  51.176  1
481941  97.510  -62.807  51.139  1
481942  97.538  -62.817  51.103  1
481943  97.567  -62.826  51.064  1
481944  97.623  -62.817  51.025  1
481945  97.638  -62.793  50.985  1
481946  97.653  -62.769  50.944  1
481947  97.668  -62.744  50.904  1
481948  97.699  -62.731  50.860  1
481949  97.731  -62.719  50.817  1
481950  97.764  -62.707  50.774  1
481951  97.798  -62.695  50.730  1
481952  97.830  -62.684  50.686  1
481953  97.864  -62.672  50.642  1
481954  97.916  -62.684  50.597  1
481955  97.970  -62.699  50.552  1
481956  98.023  -62.713  50.508  1
481957  98.077  -62.727  50.464  1
481958  98.118  -62.741  50.420  1
481959  98.129  -62.757  50.378  1
481960  98.140  -62.772  50.334  1
481961  98.151  -62.787  50.291  1
482413  87.915  -60.826  55.868  1
482414  87.952  -60.828  55.852  1
482415  87.988  -60.829  55.836  1
482416  88.025  -60.832  55.821  1
482417  88.061  -60.833  55.804  1
482418  88.098  -60.835  55.787  1
482419  88.135  -60.837  55.769  1
482420  88.172  -60.839  55.750  1
482421  88.208  -60.841  55.731  1
482422  88.245  -60.842  55.712  1
482423  88.281  -60.844  55.692  1
482424  88.326  -60.842  55.672  1
482425  88.391  -60.847  55.651  1
482426  88.467  -60.841  55.626  1
482427  88.543  -60.834  55.601  1
482428  88.619  -60.827  55.575  1
482429  88.695  -60.820  55.549  1
482430  88.770  -60.817  55.522  1
482431  88.836  -60.823  55.493  1
482432  88.881  -60.848  55.466  1
482433  88.925  -60.873  55.438  1
482434  88.970  -60.898  55.411  1
482435  89.013  -60.916  55.384  1
482436  89.056  -60.934  55.358  1
482437  89.099  -60.952  55.334  1
482438  89.142  -60.970  55.311  1
482439  89.185  -60.989  55.290  1
482440  89.229  -61.007  55.271  1
482441  89.271  -61.025  55.258  1
482442  89.315  -61.043  55.248  1
482443  89.358  -61.061  55.242  1
482444  89.401  -61.080  55.240  1
482445  89.444  -61.098  55.238  1
482446  89.487  -61.116  55.234  1
482447  89.531  -61.134  55.225  1
482448  89.574  -61.152  55.212  1
482449  89.617  -61.171  55.196  1
482450  89.660  -61.190  55.178  1
482451  89.703  -61.208  55.162  1
482452  89.739  -61.208  55.146  1
482453  89.774  -61.206  55.131  1
482454  89.809  -61.205  55.118  1
482455  89.844  -61.203  55.108  1
482456  89.879  -61.202  55.099  1
482457  89.914  -61.200  55.094  1
482458  89.949  -61.198  55.090  1
482459  90.004  -61.240  55.087  1
482460  90.061  -61.289  55.085  1
482461  90.119  -61.339  55.084  1
482462  90.170  -61.369  55.086  1
482463  90.212  -61.381  55.087  1
482464  90.252  -61.387  55.087  1
482465  90.293  -61.394  55.087  1
482466  90.334  -61.401  55.089  1
482467  90.374  -61.408  55.094  1
482468  90.419  -61.420  55.103  1
482469  90.464  -61.433  55.111  1
482470  90.510  -61.446  55.114  1
482471  90.555  -61.459  55.112  1
482472  90.600  -61.472  55.102  1
482473  90.643  -61.480  55.086  1
482474  90.685  -61.489  55.069  1
482475  90.728  -61.497  55.053  1
482476  90.771  -61.506  55.045  1
482477  90.814  -61.515  55.043  1
482478  90.857  -61.524  55.039  1
482479  90.902  -61.532  55.035  1
482480  90.950  -61.540  55.030  1
482481  90.993  -61.552  55.026  1
482482  91.035  -61.564  55.027  1
482483  91.078  -61.576  55.036  1
482484  91.120  -61.589  55.052  1
482485  91.162  -61.601  55.072  1
482486  91.205  -61.613  55.089  1
482487  91.247  -61.625  55.098  1
482488  91.290  -61.638  55.097  1
482489  91.332  -61.650  55.091  1
482490  91.374  -61.661  55.085  1
482491  91.416  -61.671  55.085  1
482492  91.458  -61.680  55.090  1
482493  91.500  -61.690  55.091  1
482494  91.542  -61.700  55.091  1
482495  91.583  -61.711  55.091  1
482496  91.625  -61.722  55.090  1
482497  91.666  -61.733  55.082  1
482498  91.708  -61.744  55.068  1
482499  91.749  -61.756  55.055  1
482500  91.787  -61.774  55.043  1
482501  91.824  -61.792  55.027  1
482502  91.862  -61.811  55.004  1
482503  91.905  -61.827  54.978  1
482504  91.950  -61.842  54.960  1
482505  91.995  -61.858  54.942  1
482506  92.040  -61.873  54.913  1
482507  92.085  -61.889  54.873  1
482508  92.130  -61.904  54.832  1
482509  92.174  -61.920  54.799  1
482510  92.220  -61.936  54.775  1
482511  92.265  -61.951  54.757  1
482512  92.301  -61.954  54.737  1
482513  92.336  -61.956  54.715  1
482514  92.371  -61.957  54.701  1
482515  92.406  -61.959  54.694  1
482516  92.441  -61.961  54.688  1
482517  92.476  -61.962  54.677  1
482518  92.511  -61.963  54.658  1
482519  92.546  -61.964  54.638  1
482520  92.581  -61.966  54.616  1
482521  92.624  -61.970  54.593  1
482522  92.672  -61.978  54.559  1
482523  92.721  -61.985  54.520  1
482524  92.770  -61.992  54.480  1
482525  92.798  -62.003  54.442  1
482526  92.839  -62.019  54.411  1
482527  92.883  -62.036  54.383  1
482528  92.927  -62.051  54.359  1
482529  92.971  -62.067  54.338  1
482530  93.013  -62.081  54.317  1
482531  93.053  -62.092  54.296  1
482532  93.092  -62.105  54.277  1
482533  93.137  -62.116  54.260  1
482534  93.183  -62.127  54.243  1
482535  93.231  -62.136  54.227  1
482536  93.280  -62.144  54.213  1
482537  93.329  -62.152  54.198  1
482538  93.368  -62.155  54.186  1
482539  93.403  -62.157  54.173  1
482540  93.437  -62.158  54.163  1
482541  93.472  -62.161  54.155  1
482542  93.510  -62.173  54.148  1
482543  93.548  -62.184  54.142  1
482544  93.586  -62.196  54.138  1
482545  93.624  -62.207  54.134  1
482546  93.662  -62.218  54.127  1
482547  93.700  -62.230  54.120  1
482548  93.738  -62.241  54.112  1
482549  93.776  -62.252  54.104  1
482550  93.815  -62.264  54.096  1
482551  93.851  -62.270  54.090  1
482552  93.888  -62.294  54.087  1
482553  93.942  -62.299  54.079  1
482554  93.989  -62.296  54.067  1
482555  94.033  -62.299  54.052  1
482556  94.077  -62.303  54.034  1
482557  94.121  -62.307  54.015  1
482558  94.166  -62.311  53.996  1
482559  94.210  -62.315  53.972  1
482560  94.254  -62.319  53.944  1
482561  94.298  -62.323  53.912  1
482562  94.342  -62.327  53.878  1
482563  94.387  -62.330  53.839  1
482564  94.431  -62.334  53.800  1
482565  94.476  -62.339  53.760  1
482566  94.514  -62.351  53.718  1
482567  94.545  -62.361  53.677  1
482568  94.595  -62.355  53.636  1
482569  94.646  -62.349  53.596  1
482570  94.696  -62.344  53.557  1
482571  94.745  -62.340  53.519  1
482572  94.760  -62.361  53.480  1
482573  94.775  -62.381  53.441  1
482574  94.790  -62.402  53.404  1
482575  94.806  -62.422  53.368  1
482576  94.829  -62.444  53.334  1
482577  94.874  -62.470  53.300  1
482578  94.919  -62.496  53.266  1
482579  94.918  -62.481  53.234  1
482580  94.947  -62.479  53.204  1
482581  94.984  -62.482  53.175  1
482582  95.022  -62.486  53.149  1
482583  95.060  -62.489  53.124  1
482584  95.098  -62.492  53.099  1
482585  95.136  -62.496  53.074  1
482586  95.174  -62.499  53.050  1
482587  95.211  -62.502  53.025  1
482588  95.250  -62.505  53.001  1
482589  95.287  -62.509  52.976  1
482590  95.325  -62.512  52.951  1
482591  95.363  -62.515  52.927  1
482592  95.401  -62.518  52.903  1
482593  95.439  -62.522  52.878  1
482594  95.477  -62.525  52.852  1
482595  95.515  -62.528  52.826  1
482596  95.552  -62.531  52.798  1
482597  95.598  -62.532  52.768  1
482598  95.647  -62.555  52.738  1
482599  95.734  -62.572  52.706  1
482600  95.804  -62.599  52.673  1
482601  95.856  -62.626  52.641  1
482602  95.898  -62.613  52.609  1
482603  95.941  -62.600  52.575  1
482604  95.983  -62.587  52.541  1
482605  96.027  -62.574  52.507  1
482606  96.092  -62.547  52.473  1
482607  96.135  -62.533  52.439  1
482608  96.179  -62.518  52.402  1
482609  96.230  -62.527  52.365  1
482610  96.284  -62.546  52.328  1
482611  96.338  -62.564  52.290  1
482612  96.382  -62.578  52.250  1
482613  96.416  -62.593  52.210  1
482614  96.454  -62.599  52.168  1
482615  96.491  -62.605  52.124  1
482616  96.528  -62.611  52.079  1
482617  96.566  -62.617  52.034  1
482618  96.603  -62.623  51.990  1
482619  96.641  -62.629  51.948  1
482620  96.678  -62.635  51.906  1
482621  96.715  -62.641  51.865  1
482622  96.752  -62.647  51.823  1
482623  96.790  -62.654  51.782  1
482624  96.827  -62.660  51.743  1
482625  96.865  -62.666  51.705  1
482626  96.902  -62.672  51.667  1
482627  96.939  -62.678  51.631  1
482628  96.976  -62.684  51.595  1
482629  97.014  -62.691  51.561  1
482630  97.051  -62.697  51.527  1
482631  97.089  -62.703  51.494  1
482632  97.129  -62.707  51.462  1
482633  97.168  -62.713  51.429  1
482634  97.208  -62.718  51.397  1
482635  97.247  -62.722  51.365  1
482636  97.286  -62.728  51.332  1
482637  97.326  -62.732  51.299  1
482638  97.365  -62.738  51.265  1
482639  97.404  -62.743  51.230  1
482640  97.444  -62.747  51.195  1
482641  97.477  -62.755  51.160  1
482642  97.505  -62.765  51.123  1
482643  97.533  -62.774  51.086  1
482644  97.565  -62.782  51.048  1
482645  97.631  -62.772  51.009  1
482646  97.645  -62.749  50.970  1
482647  97.660  -62.725  50.929  1
482648  97.675  -62.700  50.889  1
482649  97.706  -62.688  50.847  1
482650  97.739  -62.675  50.804  1
482651  97.773  -62.663  50.761  1
482652  97.805  -62.652  50.718  1
482653  97.839  -62.640  50.674  1
482654  97.877  -62.634  50.631  1
482655  97.930  -62.648  50.587  1
482656  97.984  -62.663  50.543  1
482657  98.037  -62.677  50.499  1
482658  98.091  -62.691  50.455  1
482659  98.110  -62.706  50.413  1
482660  98.121  -62.721  50.370  1
482661  98.132  -62.736  50.327  1
483114  87.930  -60.778  55.858  1
483115  87.967  -60.780  55.841  1
483116  88.003  -60.782  55.825  1
483117  88.040  -60.783  55.809  1
483118  88.076  -60.785  55.793  1
483119  88.113  -60.787  55.777  1
483120  88.150  -60.789  55.759  1
483121  88.187  -60.791  55.740  1
483122  88.223  -60.792  55.722  1
483123  88.260  -60.795  55.702  1
483124  88.297  -60.796  55.683  1
483125  88.335  -60.798  55.663  1
483126  88.409  -60.793  55.641  1
483127  88.485  -60.786  55.618  1
483128  88.561  -60.780  55.593  1
483129  88.637  -60.773  55.567  1
483130  88.713  -60.767  55.540  1
483131  88.786  -60.764  55.513  1
483132  88.850  -60.772  55.484  1
483133  88.895  -60.798  55.457  1
483134  88.940  -60.823  55.429  1
483135  88.983  -60.845  55.401  1
483136  89.026  -60.863  55.374  1
483137  89.069  -60.881  55.348  1
483138  89.113  -60.899  55.324  1
483139  89.156  -60.917  55.301  1
483140  89.199  -60.936  55.280  1
483141  89.242  -60.954  55.261  1
483142  89.285  -60.972  55.246  1
483143  89.328  -60.990  55.236  1
483144  89.372  -61.008  55.231  1
483145  89.415  -61.027  55.229  1
483146  89.458  -61.045  55.229  1
483147  89.501  -61.063  55.228  1
483148  89.544  -61.081  55.221  1
483149  89.587  -61.099  55.211  1
483150  89.630  -61.118  55.196  1
483151  89.674  -61.136  55.179  1
483152  89.717  -61.154  55.162  1
483153  89.760  -61.172  55.144  1
483154  89.795  -61.171  55.127  1
483155  89.830  -61.170  55.113  1
483156  89.865  -61.168  55.100  1
483157  89.900  -61.167  55.091  1
483158  89.936  -61.165  55.085  1
483159  89.970  -61.164  55.080  1
483160  90.028  -61.212  55.076  1
483161  90.086  -61.262  55.074  1
483162  90.141  -61.305  55.073  1
483163  90.185  -61.320  55.074  1
483164  90.229  -61.335  55.076  1
483165  90.271  -61.346  55.077  1
483166  90.312  -61.353  55.078  1
483167  90.352  -61.359  55.077  1
483168  90.394  -61.368  55.082  1
483169  90.440  -61.381  55.089  1
483170  90.485  -61.394  55.096  1
483171  90.530  -61.407  55.100  1
483172  90.573  -61.416  55.100  1
483173  90.616  -61.425  55.090  1
483174  90.659  -61.433  55.077  1
483175  90.701  -61.442  55.063  1
483176  90.744  -61.450  55.051  1
483177  90.787  -61.459  55.046  1
483178  90.830  -61.468  55.045  1
483179  90.873  -61.477  55.044  1
483180  90.918  -61.485  55.040  1
483181  90.960  -61.497  55.034  1
483182  91.002  -61.509  55.026  1
483183  91.045  -61.522  55.025  1
483184  91.087  -61.534  55.030  1
483185  91.130  -61.547  55.045  1
483186  91.172  -61.559  55.064  1
483187  91.214  -61.571  55.080  1
483188  91.256  -61.583  55.093  1
483189  91.299  -61.595  55.097  1
483190  91.342  -61.607  55.094  1
483191  91.384  -61.619  55.089  1
483192  91.426  -61.628  55.083  1
483193  91.468  -61.638  55.085  1
483194  91.509  -61.649  55.088  1
483195  91.551  -61.660  55.090  1
483196  91.592  -61.671  55.092  1
483197  91.634  -61.682  55.093  1
483198  91.675  -61.693  55.085  1
483199  91.717  -61.704  55.073  1
483200  91.758  -61.714  55.062  1
483201  91.797  -61.732  55.052  1
483202  91.835  -61.750  55.034  1
483203  91.877  -61.766  55.009  1
483204  91.922  -61.782  54.983  1
483205  91.966  -61.798  54.963  1
483206  92.012  -61.813  54.943  1
483207  92.057  -61.828  54.911  1
483208  92.101  -61.844  54.871  1
483209  92.144  -61.860  54.834  1
483210  92.187  -61.876  54.803  1
483211  92.229  -61.892  54.779  1
483212  92.274  -61.907  54.761  1
483213  92.317  -61.916  54.737  1
483214  92.354  -61.920  54.717  1
483215  92.390  -61.923  54.707  1
483216  92.426  -61.926  54.701  1
483217  92.460  -61.927  54.695  1
483218  92.496  -61.929  54.685  1
483219  92.530  -61.930  54.670  1
483220  92.565  -61.931  54.654  1
483221  92.600  -61.932  54.636  1
483222  92.635  -61.934  54.612  1
483223  92.680  -61.939  54.578  1
483224  92.728  -61.947  54.536  1
483225  92.777  -61.954  54.491  1
483226  92.807  -61.967  54.449  1
483227  92.851  -61.983  54.414  1
483228  92.895  -61.999  54.384  1
483229  92.939  -62.014  54.358  1
483230  92.979  -62.026  54.335  1
483231  93.018  -62.038  54.313  1
483232  93.058  -62.050  54.293  1
483233  93.098  -62.061  54.274  1
483234  93.144  -62.073  54.257  1
483235  93.190  -62.084  54.241  1
483236  93.235  -62.095  54.226  1
483237  93.284  -62.104  54.211  1
483238  93.333  -62.111  54.197  1
483239  93.370  -62.114  54.183  1
483240  93.405  -62.116  54.170  1
483241  93.440  -62.121  54.157  1
483242  93.479  -62.133  54.145  1
483243  93.516  -62.144  54.135  1
483244  93.555  -62.155  54.126  1
483245  93.593  -62.167  54.118  1
483246  93.631  -62.178  54.110  1
483247  93.669  -62.189  54.102  1
483248  93.707  -62.201  54.093  1
483249  93.745  -62.212  54.084  1
483250  93.783  -62.224  54.076  1
483251  93.821  -62.236  54.072  1
483252  93.859  -62.247  54.072  1
483253  93.898  -62.261  54.075  1
483254  93.945  -62.261  54.068  1
483255  93.990  -62.265  54.056  1
483256  94.034  -62.269  54.042  1
483257  94.078  -62.274  54.024  1
483258  94.123  -62.277  54.006  1
483259  94.167  -62.281  53.986  1
483260  94.211  -62.285  53.962  1
483261  94.255  -62.289  53.933  1
483262  94.299  -62.293  53.901  1
483263  94.344  -62.297  53.866  1
483264  94.389  -62.300  53.827  1
483265  94.435  -62.302  53.787  1
483266  94.481  -62.303  53.745  1
483267  94.532  -62.298  53.703  1
483268  94.582  -62.293  53.662  1
483269  94.632  -62.287  53.621  1
483270  94.683  -62.281  53.581  1
483271  94.734  -62.276  53.543  1
483272  94.751  -62.295  53.505  1
483273  94.766  -62.315  53.467  1
483274  94.782  -62.336  53.430  1
483275  94.797  -62.356  53.394  1
483276  94.813  -62.377  53.359  1
483277  94.828  -62.397  53.324  1
483278  94.873  -62.424  53.291  1
483279  94.918  -62.450  53.258  1
483280  94.914  -62.431  53.226  1
483281  94.952  -62.434  53.196  1
483282  94.990  -62.437  53.168  1
483283  95.028  -62.440  53.144  1
483284  95.066  -62.443  53.120  1
483285  95.104  -62.447  53.096  1
483286  95.141  -62.450  53.071  1
483287  95.179  -62.453  53.047  1
483288  95.217  -62.457  53.022  1
483289  95.255  -62.460  52.998  1
483290  95.293  -62.463  52.975  1
483291  95.331  -62.466  52.951  1
483292  95.369  -62.470  52.928  1
483293  95.407  -62.473  52.905  1
483294  95.445  -62.476  52.880  1
483295  95.482  -62.480  52.855  1
483296  95.520  -62.483  52.830  1
483297  95.558  -62.486  52.802  1
483298  95.598  -62.490  52.771  1
483299  95.655  -62.503  52.741  1
483300  95.738  -62.518  52.709  1
483301  95.818  -62.540  52.676  1
483302  95.872  -62.578  52.643  1
483303  95.915  -62.571  52.610  1
483304  95.958  -62.558  52.575  1
483305  96.000  -62.545  52.540  1
483306  96.042  -62.532  52.506  1
483307  96.085  -62.519  52.473  1
483308  96.135  -62.502  52.438  1
483309  96.180  -62.486  52.403  1
483310  96.234  -62.503  52.365  1
483311  96.288  -62.521  52.327  1
483312  96.340  -62.528  52.289  1
483313  96.385  -62.540  52.250  1
483314  96.423  -62.546  52.210  1
483315  96.460  -62.552  52.167  1
483316  96.498  -62.558  52.122  1
483317  96.535  -62.564  52.076  1
483318  96.572  -62.570  52.029  1
483319  96.609  -62.576  51.983  1
483320  96.647  -62.582  51.940  1
483321  96.684  -62.588  51.897  1
483322  96.722  -62.594  51.855  1
483323  96.759  -62.600  51.812  1
483324  96.796  -62.606  51.771  1
483325  96.833  -62.612  51.731  1
483326  96.871  -62.619  51.692  1
483327  96.908  -62.625  51.655  1
483328  96.946  -62.631  51.618  1
483329  96.983  -62.637  51.582  1
483330  97.020  -62.643  51.548  1
483331  97.058  -62.649  51.513  1
483332  97.096  -62.655  51.480  1
483333  97.136  -62.659  51.448  1
483334  97.175  -62.665  51.415  1
483335  97.215  -62.669  51.382  1
483336  97.254  -62.675  51.350  1
483337  97.294  -62.680  51.317  1
483338  97.333  -62.684  51.284  1
483339  97.372  -62.690  51.250  1
483340  97.412  -62.694  51.215  1
483341  97.443  -62.703  51.179  1
483342  97.471  -62.713  51.144  1
483343  97.499  -62.722  51.108  1
483344  97.527  -62.732  51.071  1
483345  97.567  -62.735  51.033  1
483346  97.634  -62.727  50.994  1
483347  97.653  -62.704  50.955  1
483348  97.668  -62.681  50.915  1
483349  97.682  -62.656  50.876  1
483350  97.714  -62.644  50.834  1
483351  97.747  -62.631  50.792  1
483352  97.780  -62.619  50.749  1
483353  97.813  -62.608  50.707  1
483354  97.847  -62.596  50.664  1
483355  97.890  -62.598  50.621  1
483356  97.944  -62.612  50.577  1
483357  97.998  -62.626  50.534  1
483358  98.052  -62.641  50.490  1
483359  98.092  -62.655  50.447  1
483360  98.103  -62.670  50.405  1
483361  98.114  -62.685  50.362  1
483362  98.125  -62.700  50.320  1
483815  87.945  -60.730  55.848  1
483816  87.982  -60.732  55.831  1
483817  88.019  -60.734  55.814  1
483818  88.055  -60.735  55.798  1
483819  88.092  -60.738  55.782  1
483820  88.129  -60.739  55.765  1
483821  88.165  -60.741  55.748  1
483822  88.202  -60.743  55.729  1
483823  88.239  -60.745  55.710  1
483824  88.275  -60.747  55.692  1
483825  88.312  -60.748  55.673  1
483826  88.358  -60.750  55.653  1
483827  88.426  -60.739  55.632  1
483828  88.502  -60.732  55.610  1
483829  88.578  -60.726  55.585  1
483830  88.654  -60.720  55.559  1
483831  88.730  -60.713  55.532  1
483832  88.803  -60.712  55.505  1
483833  88.864  -60.722  55.476  1
483834  88.909  -60.747  55.448  1
483835  88.954  -60.773  55.420  1
483836  88.997  -60.792  55.392  1
483837  89.040  -60.810  55.364  1
483838  89.083  -60.828  55.339  1
483839  89.126  -60.846  55.315  1
483840  89.169  -60.864  55.292  1
483841  89.212  -60.882  55.270  1
483842  89.256  -60.901  55.251  1
483843  89.299  -60.919  55.235  1
483844  89.342  -60.937  55.224  1
483845  89.385  -60.955  55.217  1
483846  89.428  -60.973  55.214  1
483847  89.471  -60.992  55.214  1
483848  89.515  -61.010  55.213  1
483849  89.558  -61.028  55.209  1
483850  89.601  -61.046  55.202  1
483851  89.644  -61.064  55.191  1
483852  89.687  -61.083  55.175  1
483853  89.730  -61.101  55.159  1
483854  89.773  -61.119  55.141  1
483855  89.816  -61.137  55.124  1
483856  89.851  -61.136  55.108  1
483857  89.887  -61.134  55.095  1
483858  89.921  -61.133  55.085  1
483859  89.957  -61.131  55.076  1
483860  89.994  -61.136  55.070  1
483861  90.052  -61.185  55.065  1
483862  90.111  -61.235  55.063  1
483863  90.157  -61.255  55.062  1
483864  90.200  -61.271  55.063  1
483865  90.244  -61.286  55.065  1
483866  90.289  -61.301  55.068  1
483867  90.330  -61.311  55.070  1
483868  90.371  -61.318  55.067  1
483869  90.415  -61.330  55.071  1
483870  90.460  -61.343  55.076  1
483871  90.504  -61.352  55.081  1
483872  90.546  -61.360  55.085  1
483873  90.589  -61.369  55.085  1
483874  90.632  -61.378  55.077  1
483875  90.674  -61.387  55.066  1
483876  90.717  -61.395  55.055  1
483877  90.759  -61.405  55.048  1
483878  90.801  -61.415  55.046  1
483879  90.843  -61.425  55.046  1
483880  90.886  -61.436  55.046  1
483881  90.928  -61.447  55.044  1
483882  90.969  -61.459  55.037  1
483883  91.012  -61.469  55.028  1
483884  91.054  -61.481  55.024  1
483885  91.097  -61.491  55.026  1
483886  91.139  -61.503  55.035  1
483887  91.181  -61.516  55.050  1
483888  91.224  -61.528  55.067  1
483889  91.266  -61.541  55.084  1
483890  91.309  -61.553  55.094  1
483891  91.351  -61.565  55.097  1
483892  91.393  -61.577  55.094  1
483893  91.436  -61.587  55.085  1
483894  91.477  -61.597  55.080  1
483895  91.519  -61.608  55.083  1
483896  91.560  -61.619  55.087  1
483897  91.602  -61.630  55.091  1
483898  91.643  -61.641  55.093  1
483899  91.684  -61.652  55.088  1
483900  91.726  -61.663  55.078  1
483901  91.768  -61.674  55.068  1
483902  91.807  -61.688  55.057  1
483903  91.849  -61.706  55.037  1
483904  91.893  -61.721  55.008  1
483905  91.938  -61.736  54.982  1
483906  91.982  -61.753  54.961  1
483907  92.024  -61.769  54.940  1
483908  92.066  -61.785  54.908  1
483909  92.109  -61.802  54.875  1
483910  92.151  -61.818  54.843  1
483911  92.194  -61.835  54.811  1
483912  92.237  -61.851  54.782  1
483913  92.285  -61.863  54.764  1
483914  92.332  -61.875  54.740  1
483915  92.368  -61.879  54.722  1
483916  92.405  -61.882  54.712  1
483917  92.441  -61.886  54.707  1
483918  92.478  -61.890  54.701  1
483919  92.514  -61.893  54.694  1
483920  92.550  -61.897  54.685  1
483921  92.585  -61.898  54.674  1
483922  92.620  -61.899  54.657  1
483923  92.655  -61.901  54.631  1
483924  92.690  -61.902  54.595  1
483925  92.736  -61.908  54.551  1
483926  92.785  -61.916  54.504  1
483927  92.819  -61.931  54.457  1
483928  92.863  -61.947  54.418  1
483929  92.905  -61.960  54.386  1
483930  92.944  -61.972  54.360  1
483931  92.984  -61.983  54.335  1
483932  93.024  -61.995  54.313  1
483933  93.064  -62.007  54.293  1
483934  93.104  -62.018  54.275  1
483935  93.150  -62.029  54.258  1
483936  93.196  -62.041  54.243  1
483937  93.242  -62.052  54.228  1
483938  93.288  -62.063  54.214  1
483939  93.337  -62.071  54.200  1
483940  93.372  -62.073  54.185  1
483941  93.409  -62.080  54.170  1
483942  93.447  -62.092  54.155  1
483943  93.485  -62.104  54.140  1
483944  93.523  -62.115  54.127  1
483945  93.562  -62.127  54.116  1
483946  93.600  -62.138  54.106  1
483947  93.638  -62.149  54.097  1
483948  93.676  -62.161  54.088  1
483949  93.714  -62.172  54.078  1
483950  93.752  -62.183  54.068  1
483951  93.790  -62.193  54.059  1
483952  93.828  -62.203  54.053  1
483953  93.866  -62.213  54.052  1
483954  93.906  -62.223  54.053  1
483955  93.948  -62.230  54.047  1
483956  94.006  -62.220  54.037  1
483957  94.060  -62.212  54.024  1
483958  94.106  -62.214  54.009  1
483959  94.152  -62.216  53.993  1
483960  94.198  -62.218  53.972  1
483961  94.245  -62.219  53.949  1
483962  94.291  -62.221  53.921  1
483963  94.337  -62.223  53.888  1
483964  94.383  -62.224  53.851  1
483965  94.429  -62.227  53.812  1
483966  94.476  -62.228  53.771  1
483967  94.522  -62.230  53.730  1
483968  94.569  -62.230  53.688  1
483969  94.619  -62.224  53.645  1
483970  94.670  -62.219  53.605  1
483971  94.720  -62.214  53.567  1
483972  94.742  -62.230  53.529  1
483973  94.757  -62.249  53.492  1
483974  94.773  -62.270  53.455  1
483975  94.788  -62.290  53.419  1
483976  94.804  -62.311  53.384  1
483977  94.819  -62.331  53.350  1
483978  94.834  -62.352  53.317  1
483979  94.872  -62.377  53.283  1
483980  94.916  -62.402  53.251  1
483981  94.920  -62.386  53.220  1
483982  94.958  -62.389  53.191  1
483983  94.995  -62.392  53.163  1
483984  95.033  -62.395  53.140  1
483985  95.071  -62.399  53.117  1
483986  95.109  -62.402  53.093  1
483987  95.147  -62.405  53.069  1
483988  95.185  -62.409  53.044  1
483989  95.223  -62.412  53.020  1
483990  95.261  -62.415  52.997  1
483991  95.299  -62.418  52.974  1
483992  95.336  -62.421  52.952  1
483993  95.374  -62.424  52.930  1
483994  95.412  -62.428  52.907  1
483995  95.450  -62.431  52.884  1
483996  95.491  -62.435  52.860  1
483997  95.531  -62.440  52.834  1
483998  95.572  -62.444  52.807  1
483999  95.613  -62.448  52.776  1
484000  95.674  -62.462  52.744  1
484001  95.742  -62.483  52.712  1
484002  95.810  -62.503  52.679  1
484003  95.878  -62.525  52.645  1
484004  95.933  -62.528  52.612  1
484005  95.975  -62.515  52.576  1
484006  96.016  -62.502  52.540  1
484007  96.057  -62.487  52.505  1
484008  96.098  -62.473  52.470  1
484009  96.139  -62.459  52.435  1
484010  96.182  -62.450  52.400  1
484011  96.234  -62.456  52.362  1
484012  96.287  -62.463  52.322  1
484013  96.339  -62.471  52.283  1
484014  96.390  -62.479  52.243  1
484015  96.429  -62.498  52.202  1
484016  96.466  -62.504  52.160  1
484017  96.504  -62.510  52.115  1
484018  96.541  -62.516  52.069  1
484019  96.579  -62.522  52.022  1
484020  96.616  -62.528  51.976  1
484021  96.653  -62.534  51.931  1
484022  96.690  -62.540  51.887  1
484023  96.728  -62.547  51.843  1
484024  96.765  -62.553  51.800  1
484025  96.803  -62.559  51.759  1
484026  96.840  -62.565  51.719  1
484027  96.877  -62.572  51.680  1
484028  96.914  -62.578  51.642  1
484029  96.952  -62.584  51.605  1
484030  96.990  -62.590  51.569  1
484031  97.027  -62.596  51.535  1
484032  97.064  -62.602  51.501  1
484033  97.103  -62.607  51.467  1
484034  97.143  -62.612  51.434  1
484035  97.182  -62.617  51.402  1
484036  97.222  -62.622  51.369  1
484037  97.261  -62.627  51.336  1
484038  97.301  -62.632  51.303  1
484039  97.340  -62.637  51.270  1
484040  97.380  -62.642  51.235  1
484041  97.409  -62.650  51.200  1
484042  97.438  -62.660  51.165  1
484043  97.466  -62.669  51.129  1
484044  97.494  -62.679  51.093  1
484045  97.522  -62.688  51.055  1
484046  97.568  -62.690  51.018  1
484047  97.635  -62.681  50.980  1
484048  97.660  -62.660  50.941  1
484049  97.675  -62.636  50.902  1
484050  97.690  -62.612  50.863  1
484051  97.722  -62.600  50.822  1
484052  97.755  -62.587  50.780  1
484053  97.788  -62.576  50.738  1
484054  97.821  -62.564  50.696  1
484055  97.854  -62.552  50.654  1
484056  97.904  -62.562  50.611  1
484057  97.958  -62.576  50.568  1
484058  98.012  -62.590  50.525  1
484059  98.065  -62.605  50.482  1
484060  98.084  -62.619  50.438  1
484061  98.095  -62.634  50.396  1
484062  98.106  -62.650  50.355  1
484516  87.960  -60.682  55.837  1
484517  87.997  -60.684  55.821  1
484518  88.034  -60.686  55.803  1
484519  88.070  -60.688  55.787  1
484520  88.107  -60.689  55.770  1
484521  88.144  -60.691  55.753  1
484522  88.181  -60.693  55.736  1
484523  88.217  -60.695  55.718  1
484524  88.254  -60.697  55.699  1
484525  88.290  -60.698  55.681  1
484526  88.332  -60.702  55.662  1
484527  88.386  -60.702  55.643  1
484528  88.445  -60.686  55.623  1
484529  88.519  -60.679  55.602  1
484530  88.595  -60.672  55.578  1
484531  88.671  -60.665  55.552  1
484532  88.747  -60.660  55.524  1
484533  88.820  -60.659  55.497  1
484534  88.879  -60.671  55.469  1
484535  88.923  -60.697  55.441  1
484536  88.967  -60.720  55.412  1
484537  89.011  -60.738  55.384  1
484538  89.053  -60.756  55.356  1
484539  89.097  -60.775  55.330  1
484540  89.140  -60.793  55.306  1
484541  89.183  -60.811  55.283  1
484542  89.226  -60.829  55.261  1
484543  89.269  -60.848  55.241  1
484544  89.313  -60.866  55.224  1
484545  89.355  -60.884  55.211  1
484546  89.399  -60.902  55.202  1
484547  89.442  -60.920  55.197  1
484548  89.485  -60.939  55.195  1
484549  89.528  -60.957  55.194  1
484550  89.571  -60.975  55.194  1
484551  89.614  -60.993  55.191  1
484552  89.658  -61.011  55.183  1
484553  89.701  -61.030  55.169  1
484554  89.744  -61.048  55.153  1
484555  89.787  -61.066  55.135  1
484556  89.830  -61.084  55.118  1
484557  89.873  -61.101  55.104  1
484558  89.908  -61.099  55.090  1
484559  89.943  -61.098  55.078  1
484560  89.978  -61.096  55.068  1
484561  90.019  -61.108  55.061  1
484562  90.077  -61.158  55.056  1
484563  90.128  -61.190  55.053  1
484564  90.172  -61.206  55.052  1
484565  90.216  -61.221  55.052  1
484566  90.260  -61.237  55.055  1
484567  90.304  -61.252  55.059  1
484568  90.347  -61.267  55.063  1
484569  90.391  -61.278  55.061  1
484570  90.434  -61.287  55.062  1
484571  90.476  -61.296  55.064  1
484572  90.518  -61.307  55.067  1
484573  90.559  -61.318  55.069  1
484574  90.601  -61.328  55.068  1
484575  90.643  -61.338  55.063  1
484576  90.684  -61.348  55.055  1
484577  90.726  -61.359  55.048  1
484578  90.768  -61.369  55.045  1
484579  90.810  -61.379  55.046  1
484580  90.855  -61.390  55.048  1
484581  90.902  -61.401  55.048  1
484582  90.941  -61.413  55.046  1
484583  90.979  -61.425  55.040  1
484584  91.021  -61.436  55.031  1
484585  91.064  -61.447  55.025  1
484586  91.106  -61.458  55.025  1
484587  91.148  -61.469  55.029  1
484588  91.191  -61.480  55.038  1
484589  91.233  -61.491  55.053  1
484590  91.276  -61.501  55.068  1
484591  91.318  -61.512  55.081  1
484592  91.361  -61.523  55.089  1
484593  91.403  -61.534  55.093  1
484594  91.445  -61.546  55.088  1
484595  91.487  -61.556  55.078  1
484596  91.528  -61.568  55.077  1
484597  91.569  -61.578  55.082  1
484598  91.611  -61.589  55.088  1
484599  91.652  -61.600  55.090  1
484600  91.694  -61.612  55.089  1
484601  91.735  -61.622  55.082  1
484602  91.777  -61.634  55.073  1
484603  91.818  -61.645  55.060  1
484604  91.861  -61.662  55.036  1
484605  91.904  -61.678  55.004  1
484606  91.946  -61.694  54.978  1
484607  91.989  -61.711  54.957  1
484608  92.031  -61.728  54.936  1
484609  92.073  -61.744  54.908  1
484610  92.116  -61.760  54.883  1
484611  92.158  -61.777  54.854  1
484612  92.201  -61.793  54.820  1
484613  92.247  -61.807  54.786  1
484614  92.295  -61.819  54.765  1
484615  92.343  -61.831  54.743  1
484616  92.383  -61.838  54.728  1
484617  92.420  -61.841  54.720  1
484618  92.456  -61.845  54.717  1
484619  92.492  -61.849  54.713  1
484620  92.528  -61.853  54.709  1
484621  92.565  -61.856  54.701  1
484622  92.601  -61.860  54.688  1
484623  92.638  -61.863  54.669  1
484624  92.674  -61.867  54.641  1
484625  92.709  -61.869  54.606  1
484626  92.744  -61.870  54.563  1
484627  92.787  -61.879  54.515  1
484628  92.831  -61.894  54.466  1
484629  92.870  -61.906  54.424  1
484630  92.910  -61.917  54.392  1
484631  92.950  -61.929  54.364  1
484632  92.990  -61.941  54.340  1
484633  93.029  -61.952  54.318  1
484634  93.069  -61.964  54.299  1
484635  93.111  -61.976  54.283  1
484636  93.156  -61.987  54.266  1
484637  93.203  -61.998  54.250  1
484638  93.249  -62.009  54.235  1
484639  93.294  -62.020  54.221  1
484640  93.341  -62.031  54.206  1
484641  93.378  -62.040  54.189  1
484642  93.416  -62.051  54.172  1
484643  93.454  -62.061  54.154  1
484644  93.492  -62.071  54.136  1
484645  93.530  -62.081  54.121  1
484646  93.568  -62.091  54.107  1
484647  93.607  -62.101  54.096  1
484648  93.644  -62.111  54.085  1
484649  93.683  -62.120  54.075  1
484650  93.720  -62.130  54.064  1
484651  93.759  -62.139  54.053  1
484652  93.796  -62.149  54.043  1
484653  93.835  -62.159  54.035  1
484654  93.873  -62.170  54.030  1
484655  93.915  -62.181  54.027  1
484656  93.957  -62.189  54.020  1
484657  94.000  -62.197  54.010  1
484658  94.043  -62.204  53.999  1
484659  94.090  -62.205  53.986  1
484660  94.148  -62.194  53.972  1
484661  94.206  -62.182  53.953  1
484662  94.264  -62.170  53.929  1
484663  94.322  -62.158  53.901  1
484664  94.378  -62.149  53.868  1
484665  94.424  -62.151  53.831  1
484666  94.470  -62.152  53.792  1
484667  94.516  -62.155  53.751  1
484668  94.562  -62.156  53.710  1
484669  94.609  -62.158  53.668  1
484670  94.657  -62.156  53.628  1
484671  94.707  -62.151  53.590  1
484672  94.733  -62.164  53.553  1
484673  94.749  -62.184  53.517  1
484674  94.764  -62.205  53.480  1
484675  94.779  -62.225  53.444  1
484676  94.794  -62.245  53.409  1
484677  94.810  -62.265  53.375  1
484678  94.825  -62.286  53.341  1
484679  94.841  -62.306  53.309  1
484680  94.871  -62.330  53.277  1
484681  94.908  -62.349  53.246  1
484682  94.925  -62.340  53.215  1
484683  94.963  -62.343  53.187  1
484684  95.001  -62.347  53.161  1
484685  95.039  -62.350  53.137  1
484686  95.077  -62.353  53.116  1
484687  95.115  -62.356  53.091  1
484688  95.153  -62.360  53.066  1
484689  95.190  -62.363  53.042  1
484690  95.229  -62.366  53.019  1
484691  95.266  -62.370  52.996  1
484692  95.304  -62.373  52.975  1
484693  95.343  -62.376  52.954  1
484694  95.383  -62.381  52.932  1
484695  95.424  -62.385  52.909  1
484696  95.464  -62.389  52.887  1
484697  95.505  -62.393  52.864  1
484698  95.545  -62.398  52.839  1
484699  95.586  -62.402  52.811  1
484700  95.631  -62.404  52.781  1
484701  95.694  -62.421  52.748  1
484702  95.762  -62.441  52.715  1
484703  95.829  -62.462  52.681  1
484704  95.897  -62.484  52.646  1
484705  95.939  -62.472  52.612  1
484706  95.977  -62.457  52.576  1
484707  96.015  -62.442  52.539  1
484708  96.056  -62.428  52.503  1
484709  96.097  -62.413  52.467  1
484710  96.141  -62.406  52.431  1
484711  96.187  -62.402  52.396  1
484712  96.233  -62.399  52.357  1
484713  96.285  -62.406  52.317  1
484714  96.337  -62.412  52.277  1
484715  96.390  -62.420  52.236  1
484716  96.433  -62.436  52.195  1
484717  96.473  -62.456  52.153  1
484718  96.510  -62.463  52.108  1
484719  96.547  -62.469  52.062  1
484720  96.585  -62.475  52.015  1
484721  96.622  -62.481  51.968  1
484722  96.660  -62.487  51.923  1
484723  96.697  -62.493  51.878  1
484724  96.734  -62.500  51.834  1
484725  96.771  -62.506  51.790  1
484726  96.809  -62.512  51.748  1
484727  96.847  -62.518  51.708  1
484728  96.884  -62.524  51.669  1
484729  96.921  -62.530  51.631  1
484730  96.958  -62.536  51.594  1
484731  96.996  -62.542  51.557  1
484732  97.033  -62.548  51.522  1
484733  97.071  -62.554  51.488  1
484734  97.110  -62.559  51.455  1
484735  97.150  -62.564  51.422  1
484736  97.189  -62.569  51.389  1
484737  97.229  -62.574  51.356  1
484738  97.268  -62.579  51.323  1
484739  97.308  -62.584  51.289  1
484740  97.347  -62.589  51.256  1
484741  97.376  -62.598  51.222  1
484742  97.404  -62.608  51.186  1
484743  97.432  -62.617  51.151  1
484744  97.460  -62.627  51.116  1
484745  97.489  -62.636  51.079  1
484746  97.516  -62.646  51.042  1
484747  97.569  -62.644  51.004  1
484748  97.636  -62.635  50.966  1
484749  97.667  -62.616  50.927  1
484750  97.682  -62.592  50.889  1
484751  97.697  -62.568  50.849  1
484752  97.730  -62.556  50.809  1
484753  97.763  -62.544  50.768  1
484754  97.796  -62.532  50.726  1
484755  97.829  -62.520  50.685  1
484756  97.865  -62.512  50.645  1
484757  97.919  -62.526  50.602  1
484758  97.972  -62.540  50.560  1
484759  98.026  -62.554  50.517  1
484760  98.066  -62.569  50.473  1
484761  98.077  -62.584  50.431  1
484762  98.088  -62.599  50.389  1
484763  98.099  -62.614  50.347  1
484764  98.119  -62.629  50.306  1
485217  87.976  -60.635  55.826  1
485218  88.012  -60.636  55.810  1
485219  88.049  -60.638  55.791  1
485220  88.085  -60.640  55.775  1
485221  88.122  -60.641  55.759  1
485222  88.159  -60.644  55.742  1
485223  88.196  -60.645  55.725  1
485224  88.233  -60.647  55.706  1
485225  88.269  -60.649  55.688  1
485226  88.307  -60.651  55.670  1
485227  88.358  -60.658  55.651  1
485228  88.414  -60.654  55.633  1
485229  88.473  -60.638  55.613  1
485230  88.537  -60.625  55.594  1
485231  88.613  -60.618  55.570  1
485232  88.689  -60.611  55.544  1
485233  88.763  -60.607  55.517  1
485234  88.837  -60.606  55.490  1
485235  88.893  -60.621  55.462  1
485236  88.937  -60.646  55.434  1
485237  88.981  -60.666  55.405  1
485238  89.024  -60.685  55.376  1
485239  89.067  -60.703  55.349  1
485240  89.110  -60.721  55.323  1
485241  89.154  -60.739  55.298  1
485242  89.197  -60.757  55.274  1
485243  89.240  -60.776  55.251  1
485244  89.283  -60.795  55.230  1
485245  89.326  -60.813  55.213  1
485246  89.369  -60.831  55.199  1
485247  89.412  -60.849  55.187  1
485248  89.456  -60.867  55.179  1
485249  89.498  -60.886  55.174  1
485250  89.542  -60.904  55.172  1
485251  89.585  -60.922  55.175  1
485252  89.628  -60.940  55.176  1
485253  89.671  -60.958  55.172  1
485254  89.715  -60.977  55.161  1
485255  89.757  -60.995  55.144  1
485256  89.801  -61.013  55.126  1
485257  89.844  -61.031  55.111  1
485258  89.887  -61.049  55.099  1
485259  89.929  -61.065  55.086  1
485260  89.964  -61.064  55.072  1
485261  90.000  -61.062  55.061  1
485262  90.044  -61.082  55.053  1
485263  90.100  -61.126  55.047  1
485264  90.144  -61.141  55.044  1
485265  90.187  -61.156  55.042  1
485266  90.231  -61.172  55.041  1
485267  90.275  -61.187  55.043  1
485268  90.318  -61.204  55.047  1
485269  90.360  -61.224  55.053  1
485270  90.401  -61.240  55.055  1
485271  90.443  -61.250  55.055  1
485272  90.484  -61.261  55.054  1
485273  90.526  -61.271  55.053  1
485274  90.568  -61.281  55.052  1
485275  90.610  -61.292  55.050  1
485276  90.651  -61.302  55.048  1
485277  90.693  -61.312  55.045  1
485278  90.735  -61.323  55.042  1
485279  90.777  -61.333  55.043  1
485280  90.823  -61.344  55.046  1
485281  90.872  -61.355  55.050  1
485282  90.916  -61.366  55.050  1
485283  90.954  -61.378  55.047  1
485284  90.993  -61.390  55.042  1
485285  91.031  -61.403  55.035  1
485286  91.073  -61.413  55.029  1
485287  91.115  -61.425  55.027  1
485288  91.158  -61.435  55.027  1
485289  91.200  -61.446  55.030  1
485290  91.242  -61.457  55.039  1
485291  91.285  -61.468  55.052  1
485292  91.327  -61.478  55.065  1
485293  91.370  -61.490  55.077  1
485294  91.412  -61.500  55.086  1
485295  91.454  -61.511  55.086  1
485296  91.496  -61.522  55.079  1
485297  91.537  -61.534  55.077  1
485298  91.579  -61.544  55.080  1
485299  91.621  -61.556  55.085  1
485300  91.662  -61.567  55.087  1
485301  91.704  -61.578  55.085  1
485302  91.745  -61.589  55.080  1
485303  91.787  -61.600  55.070  1
485304  91.826  -61.608  55.054  1
485305  91.868  -61.620  55.032  1
485306  91.911  -61.637  54.999  1
485307  91.953  -61.653  54.973  1
485308  91.996  -61.669  54.952  1
485309  92.038  -61.686  54.934  1
485310  92.080  -61.703  54.914  1
485311  92.123  -61.719  54.895  1
485312  92.165  -61.735  54.867  1
485313  92.210  -61.750  54.830  1
485314  92.258  -61.763  54.791  1
485315  92.305  -61.775  54.764  1
485316  92.353  -61.787  54.746  1
485317  92.398  -61.798  54.735  1
485318  92.434  -61.801  54.729  1
485319  92.471  -61.804  54.729  1
485320  92.507  -61.808  54.727  1
485321  92.544  -61.812  54.723  1
485322  92.580  -61.816  54.713  1
485323  92.616  -61.819  54.697  1
485324  92.652  -61.823  54.675  1
485325  92.689  -61.826  54.645  1
485326  92.725  -61.830  54.609  1
485327  92.762  -61.834  54.568  1
485328  92.797  -61.839  54.520  1
485329  92.837  -61.851  54.471  1
485330  92.876  -61.863  54.429  1
485331  92.916  -61.874  54.397  1
485332  92.955  -61.886  54.371  1
485333  92.995  -61.898  54.348  1
485334  93.035  -61.910  54.328  1
485335  93.075  -61.921  54.313  1
485336  93.117  -61.932  54.298  1
485337  93.163  -61.944  54.282  1
485338  93.209  -61.955  54.266  1
485339  93.255  -61.967  54.250  1
485340  93.301  -61.978  54.235  1
485341  93.344  -61.988  54.216  1
485342  93.384  -61.998  54.196  1
485343  93.423  -62.008  54.175  1
485344  93.461  -62.018  54.154  1
485345  93.499  -62.028  54.133  1
485346  93.537  -62.038  54.114  1
485347  93.575  -62.047  54.098  1
485348  93.613  -62.057  54.084  1
485349  93.651  -62.067  54.072  1
485350  93.689  -62.077  54.061  1
485351  93.727  -62.086  54.049  1
485352  93.765  -62.096  54.038  1
485353  93.803  -62.106  54.026  1
485354  93.841  -62.116  54.016  1
485355  93.882  -62.127  54.006  1
485356  93.924  -62.139  53.998  1
485357  93.966  -62.148  53.989  1
485358  94.008  -62.155  53.979  1
485359  94.051  -62.163  53.970  1
485360  94.094  -62.171  53.960  1
485361  94.136  -62.178  53.946  1
485362  94.179  -62.186  53.929  1
485363  94.232  -62.180  53.905  1
485364  94.290  -62.168  53.876  1
485365  94.348  -62.156  53.844  1
485366  94.406  -62.144  53.808  1
485367  94.465  -62.132  53.769  1
485368  94.523  -62.120  53.728  1
485369  94.580  -62.108  53.688  1
485370  94.639  -62.096  53.649  1
485371  94.695  -62.086  53.611  1
485372  94.724  -62.098  53.575  1
485373  94.740  -62.118  53.539  1
485374  94.755  -62.139  53.504  1
485375  94.770  -62.159  53.470  1
485376  94.785  -62.180  53.435  1
485377  94.801  -62.200  53.401  1
485378  94.817  -62.221  53.367  1
485379  94.832  -62.240  53.335  1
485380  94.847  -62.261  53.305  1
485381  94.870  -62.283  53.274  1
485382  94.901  -62.296  53.243  1
485383  94.931  -62.295  53.214  1
485384  94.969  -62.299  53.187  1
485385  95.006  -62.302  53.161  1
485386  95.044  -62.305  53.137  1
485387  95.083  -62.308  53.115  1
485388  95.120  -62.312  53.091  1
485389  95.158  -62.315  53.066  1
485390  95.196  -62.318  53.042  1
485391  95.235  -62.321  53.019  1
485392  95.276  -62.326  52.998  1
485393  95.316  -62.330  52.977  1
485394  95.357  -62.334  52.956  1
485395  95.398  -62.339  52.934  1
485396  95.438  -62.343  52.913  1
485397  95.479  -62.347  52.892  1
485398  95.519  -62.352  52.869  1
485399  95.560  -62.356  52.844  1
485400  95.601  -62.360  52.817  1
485401  95.648  -62.361  52.784  1
485402  95.714  -62.379  52.752  1
485403  95.781  -62.400  52.718  1
485404  95.849  -62.421  52.682  1
485405  95.908  -62.431  52.646  1
485406  95.946  -62.415  52.610  1
485407  95.984  -62.400  52.574  1
485408  96.022  -62.385  52.536  1
485409  96.060  -62.370  52.499  1
485410  96.098  -62.368  52.462  1
485411  96.146  -62.359  52.426  1
485412  96.191  -62.355  52.390  1
485413  96.237  -62.351  52.352  1
485414  96.283  -62.347  52.312  1
485415  96.336  -62.355  52.271  1
485416  96.388  -62.362  52.230  1
485417  96.437  -62.373  52.189  1
485418  96.476  -62.393  52.147  1
485419  96.516  -62.413  52.102  1
485420  96.554  -62.421  52.055  1
485421  96.591  -62.428  52.009  1
485422  96.628  -62.434  51.961  1
485423  96.666  -62.440  51.915  1
485424  96.703  -62.446  51.869  1
485425  96.741  -62.452  51.825  1
485426  96.778  -62.458  51.781  1
485427  96.815  -62.465  51.738  1
485428  96.853  -62.471  51.697  1
485429  96.890  -62.477  51.658  1
485430  96.928  -62.483  51.620  1
485431  96.965  -62.489  51.583  1
485432  97.002  -62.495  51.546  1
485433  97.039  -62.501  51.510  1
485434  97.078  -62.506  51.477  1
485435  97.118  -62.511  51.443  1
485436  97.157  -62.516  51.410  1
485437  97.196  -62.522  51.377  1
485438  97.236  -62.526  51.344  1
485439  97.276  -62.531  51.311  1
485440  97.315  -62.537  51.277  1
485441  97.343  -62.546  51.243  1
485442  97.371  -62.556  51.209  1
485443  97.399  -62.565  51.173  1
485444  97.427  -62.575  51.138  1
485445  97.455  -62.584  51.103  1
485446  97.483  -62.594  51.066  1
485447  97.511  -62.603  51.029  1
485448  97.571  -62.597  50.991  1
485449  97.638  -62.589  50.953  1
485450  97.675  -62.572  50.914  1
485451  97.689  -62.548  50.876  1
485452  97.705  -62.524  50.837  1
485453  97.738  -62.512  50.797  1
485454  97.771  -62.500  50.757  1
485455  97.804  -62.488  50.716  1
485456  97.837  -62.476  50.675  1
485457  97.879  -62.475  50.635  1
485458  97.933  -62.490  50.592  1
485459  97.986  -62.504  50.551  1
485460  98.039  -62.518  50.509  1
485461  98.059  -62.533  50.466  1
485462  98.070  -62.548  50.423  1
485463  98.080  -62.563  50.382  1
485464  98.096  -62.578  50.341  1
485465  98.121  -62.594  50.300  1
485466  98.145  -62.609  50.258  1
485918  87.991  -60.587  55.815  1
485919  88.028  -60.588  55.798  1
485920  88.064  -60.590  55.779  1
485921  88.101  -60.592  55.763  1
485922  88.137  -60.594  55.746  1
485923  88.174  -60.595  55.729  1
485924  88.211  -60.597  55.712  1
485925  88.248  -60.599  55.694  1
485926  88.284  -60.601  55.676  1
485927  88.333  -60.607  55.658  1
485928  88.385  -60.613  55.640  1
485929  88.442  -60.605  55.622  1
485930  88.501  -60.590  55.604  1
485931  88.560  -60.574  55.585  1
485932  88.630  -60.564  55.563  1
485933  88.706  -60.557  55.538  1
485934  88.780  -60.555  55.510  1
485935  88.853  -60.553  55.483  1
485936  88.907  -60.570  55.456  1
485937  88.952  -60.595  55.427  1
485938  88.994  -60.613  55.398  1
485939  89.038  -60.632  55.370  1
485940  89.081  -60.650  55.342  1
485941  89.124  -60.668  55.316  1
485942  89.167  -60.686  55.290  1
485943  89.210  -60.704  55.266  1
485944  89.253  -60.723  55.242  1
485945  89.297  -60.741  55.221  1
485946  89.340  -60.759  55.203  1
485947  89.383  -60.777  55.187  1
485948  89.426  -60.795  55.174  1
485949  89.469  -60.814  55.163  1
485950  89.512  -60.832  55.155  1
485951  89.555  -60.851  55.151  1
485952  89.599  -60.869  55.151  1
485953  89.641  -60.887  55.152  1
485954  89.685  -60.905  55.150  1
485955  89.728  -60.923  55.142  1
485956  89.771  -60.942  55.129  1
485957  89.814  -60.960  55.117  1
485958  89.858  -60.978  55.106  1
485959  89.900  -60.996  55.095  1
485960  89.944  -61.014  55.082  1
485961  89.985  -61.030  55.068  1
485962  90.021  -61.028  55.056  1
485963  90.069  -61.055  55.046  1
485964  90.115  -61.077  55.039  1
485965  90.159  -61.092  55.035  1
485966  90.203  -61.107  55.031  1
485967  90.244  -61.127  55.031  1
485968  90.286  -61.148  55.032  1
485969  90.327  -61.168  55.035  1
485970  90.368  -61.189  55.042  1
485971  90.410  -61.205  55.046  1
485972  90.451  -61.215  55.046  1
485973  90.493  -61.225  55.043  1
485974  90.535  -61.235  55.040  1
485975  90.577  -61.246  55.037  1
485976  90.618  -61.256  55.036  1
485977  90.660  -61.266  55.036  1
485978  90.701  -61.277  55.036  1
485979  90.743  -61.287  55.037  1
485980  90.792  -61.298  55.040  1
485981  90.841  -61.309  55.046  1
485982  90.890  -61.320  55.051  1
485983  90.929  -61.332  55.052  1
485984  90.968  -61.344  55.050  1
485985  91.006  -61.356  55.045  1
485986  91.045  -61.368  55.040  1
485987  91.083  -61.380  55.036  1
485988  91.124  -61.390  55.033  1
485989  91.167  -61.402  55.030  1
485990  91.209  -61.412  55.025  1
485991  91.252  -61.423  55.027  1
485992  91.294  -61.434  55.036  1
485993  91.336  -61.445  55.049  1
485994  91.379  -61.456  55.063  1
485995  91.422  -61.467  55.075  1
485996  91.464  -61.478  55.080  1
485997  91.506  -61.489  55.078  1
485998  91.547  -61.500  55.077  1
485999  91.589  -61.511  55.080  1
486000  91.630  -61.522  55.081  1
486001  91.671  -61.533  55.082  1
486002  91.713  -61.544  55.079  1
486003  91.754  -61.555  55.074  1
486004  91.796  -61.566  55.063  1
486005  91.836  -61.573  55.046  1
486006  91.875  -61.579  55.025  1
486007  91.918  -61.595  54.995  1
486008  91.960  -61.612  54.969  1
486009  92.003  -61.628  54.950  1
486010  92.045  -61.644  54.937  1
486011  92.087  -61.661  54.920  1
486012  92.130  -61.677  54.898  1
486013  92.173  -61.694  54.868  1
486014  92.221  -61.706  54.830  1
486015  92.268  -61.718  54.791  1
486016  92.316  -61.731  54.764  1
486017  92.364  -61.743  54.748  1
486018  92.411  -61.755  54.741  1
486019  92.449  -61.760  54.739  1
486020  92.486  -61.764  54.741  1
486021  92.522  -61.767  54.739  1
486022  92.558  -61.771  54.732  1
486023  92.594  -61.775  54.718  1
486024  92.631  -61.779  54.699  1
486025  92.667  -61.782  54.674  1
486026  92.704  -61.785  54.643  1
486027  92.740  -61.789  54.606  1
486028  92.775  -61.796  54.566  1
486029  92.810  -61.804  54.520  1
486030  92.845  -61.810  54.472  1
486031  92.882  -61.820  54.434  1
486032  92.922  -61.832  54.404  1
486033  92.961  -61.843  54.378  1
486034  93.001  -61.855  54.358  1
486035  93.041  -61.867  54.342  1
486036  93.080  -61.879  54.331  1
486037  93.124  -61.890  54.317  1
486038  93.169  -61.901  54.301  1
486039  93.216  -61.912  54.283  1
486040  93.261  -61.923  54.266  1
486041  93.304  -61.934  54.247  1
486042  93.348  -61.945  54.224  1
486043  93.391  -61.954  54.200  1
486044  93.429  -61.964  54.175  1
486045  93.468  -61.974  54.151  1
486046  93.505  -61.984  54.127  1
486047  93.544  -61.994  54.105  1
486048  93.581  -62.004  54.087  1
486049  93.620  -62.014  54.071  1
486050  93.658  -62.023  54.057  1
486051  93.696  -62.033  54.044  1
486052  93.734  -62.043  54.032  1
486053  93.772  -62.053  54.019  1
486054  93.810  -62.063  54.007  1
486055  93.849  -62.073  53.995  1
486056  93.891  -62.085  53.984  1
486057  93.932  -62.096  53.973  1
486058  93.974  -62.107  53.960  1
486059  94.017  -62.114  53.947  1
486060  94.060  -62.122  53.935  1
486061  94.102  -62.129  53.925  1
486062  94.145  -62.136  53.912  1
486063  94.188  -62.144  53.895  1
486064  94.230  -62.152  53.873  1
486065  94.273  -62.159  53.846  1
486066  94.316  -62.166  53.815  1
486067  94.374  -62.155  53.779  1
486068  94.432  -62.142  53.741  1
486069  94.490  -62.130  53.703  1
486070  94.548  -62.118  53.664  1
486071  94.607  -62.107  53.629  1
486072  94.665  -62.095  53.595  1
486073  94.709  -62.089  53.561  1
486074  94.733  -62.097  53.527  1
486075  94.756  -62.104  53.493  1
486076  94.777  -62.114  53.461  1
486077  94.792  -62.134  53.427  1
486078  94.808  -62.155  53.395  1
486079  94.823  -62.175  53.363  1
486080  94.838  -62.196  53.332  1
486081  94.853  -62.216  53.302  1
486082  94.869  -62.236  53.273  1
486083  94.899  -62.246  53.244  1
486084  94.936  -62.250  53.216  1
486085  94.974  -62.253  53.189  1
486086  95.012  -62.256  53.164  1
486087  95.050  -62.260  53.140  1
486088  95.088  -62.263  53.116  1
486089  95.128  -62.267  53.093  1
486090  95.168  -62.271  53.068  1
486091  95.209  -62.275  53.044  1
486092  95.250  -62.280  53.021  1
486093  95.290  -62.284  53.000  1
486094  95.331  -62.288  52.979  1
486095  95.371  -62.293  52.958  1
486096  95.412  -62.297  52.937  1
486097  95.453  -62.301  52.917  1
486098  95.493  -62.305  52.897  1
486099  95.534  -62.310  52.874  1
486100  95.574  -62.314  52.850  1
486101  95.618  -62.317  52.822  1
486102  95.666  -62.317  52.789  1
486103  95.734  -62.338  52.756  1
486104  95.801  -62.359  52.721  1
486105  95.869  -62.380  52.685  1
486106  95.915  -62.374  52.647  1
486107  95.953  -62.359  52.609  1
486108  95.991  -62.343  52.571  1
486109  96.029  -62.328  52.533  1
486110  96.065  -62.324  52.495  1
486111  96.101  -62.329  52.457  1
486112  96.145  -62.330  52.419  1
486113  96.196  -62.307  52.383  1
486114  96.242  -62.303  52.344  1
486115  96.288  -62.299  52.305  1
486116  96.334  -62.297  52.266  1
486117  96.387  -62.304  52.225  1
486118  96.440  -62.312  52.184  1
486119  96.480  -62.330  52.142  1
486120  96.520  -62.349  52.098  1
486121  96.559  -62.370  52.051  1
486122  96.598  -62.381  52.003  1
486123  96.635  -62.387  51.955  1
486124  96.672  -62.393  51.908  1
486125  96.710  -62.399  51.862  1
486126  96.747  -62.405  51.816  1
486127  96.785  -62.411  51.773  1
486128  96.822  -62.417  51.729  1
486129  96.859  -62.423  51.688  1
486130  96.896  -62.429  51.648  1
486131  96.934  -62.435  51.609  1
486132  96.971  -62.441  51.572  1
486133  97.009  -62.447  51.536  1
486134  97.046  -62.453  51.501  1
486135  97.086  -62.459  51.467  1
486136  97.125  -62.463  51.433  1
486137  97.164  -62.468  51.400  1
486138  97.204  -62.474  51.366  1
486139  97.243  -62.478  51.333  1
486140  97.281  -62.484  51.299  1
486141  97.309  -62.493  51.266  1
486142  97.337  -62.503  51.232  1
486143  97.365  -62.512  51.196  1
486144  97.393  -62.522  51.161  1
486145  97.421  -62.531  51.126  1
486146  97.449  -62.541  51.090  1
486147  97.477  -62.550  51.054  1
486148  97.505  -62.560  51.016  1
486149  97.572  -62.552  50.979  1
486150  97.639  -62.543  50.941  1
486151  97.682  -62.528  50.902  1
486152  97.697  -62.503  50.864  1
486153  97.713  -62.480  50.826  1
486154  97.746  -62.468  50.787  1
486155  97.779  -62.456  50.746  1
486156  97.812  -62.444  50.706  1
486157  97.845  -62.433  50.665  1
486158  97.893  -62.440  50.625  1
486159  97.946  -62.453  50.583  1
486160  98.000  -62.468  50.542  1
486161  98.040  -62.482  50.501  1
486162  98.051  -62.497  50.459  1
486163  98.062  -62.512  50.417  1
486164  98.074  -62.528  50.376  1
486165  98.098  -62.543  50.335  1
486166  98.122  -62.559  50.294  1
486167  98.146  -62.575  50.252  1
486168  98.170  -62.590  50.211  1
486619  88.006  -60.538  55.804  1
486620  88.043  -60.541  55.786  1
486621  88.079  -60.542  55.767  1
486622  88.116  -60.544  55.751  1
486623  88.153  -60.546  55.734  1
486624  88.190  -60.547  55.716  1
486625  88.226  -60.550  55.698  1
486626  88.263  -60.551  55.681  1
486627  88.308  -60.556  55.663  1
486628  88.360  -60.563  55.645  1
486629  88.412  -60.569  55.628  1
486630  88.470  -60.557  55.611  1
486631  88.530  -60.541  55.594  1
486632  88.589  -60.525  55.576  1
486633  88.648  -60.510  55.555  1
486634  88.723  -60.503  55.530  1
486635  88.797  -60.502  55.503  1
486636  88.870  -60.500  55.476  1
486637  88.921  -60.520  55.448  1
486638  88.965  -60.542  55.420  1
486639  89.008  -60.560  55.391  1
486640  89.051  -60.579  55.363  1
486641  89.095  -60.597  55.335  1
486642  89.137  -60.615  55.309  1
486643  89.181  -60.633  55.283  1
486644  89.224  -60.651  55.258  1
486645  89.267  -60.669  55.235  1
486646  89.310  -60.688  55.213  1
486647  89.353  -60.706  55.194  1
486648  89.396  -60.724  55.177  1
486649  89.440  -60.742  55.162  1
486650  89.483  -60.760  55.149  1
486651  89.526  -60.779  55.138  1
486652  89.569  -60.797  55.132  1
486653  89.612  -60.815  55.128  1
486654  89.655  -60.833  55.127  1
486655  89.698  -60.852  55.126  1
486656  89.742  -60.870  55.121  1
486657  89.785  -60.889  55.112  1
486658  89.828  -60.907  55.105  1
486659  89.871  -60.925  55.098  1
486660  89.914  -60.943  55.090  1
486661  89.957  -60.961  55.076  1
486662  90.001  -60.980  55.063  1
486663  90.042  -60.993  55.051  1
486664  90.087  -61.012  55.040  1
486665  90.129  -61.030  55.032  1
486666  90.170  -61.050  55.026  1
486667  90.212  -61.071  55.023  1
486668  90.253  -61.092  55.022  1
486669  90.294  -61.112  55.022  1
486670  90.335  -61.133  55.024  1
486671  90.377  -61.153  55.028  1
486672  90.418  -61.168  55.033  1
486673  90.460  -61.179  55.034  1
486674  90.502  -61.190  55.032  1
486675  90.543  -61.199  55.026  1
486676  90.585  -61.210  55.024  1
486677  90.627  -61.220  55.024  1
486678  90.668  -61.230  55.026  1
486679  90.712  -61.241  55.029  1
486680  90.761  -61.252  55.033  1
486681  90.810  -61.263  55.037  1
486682  90.859  -61.274  55.045  1
486683  90.904  -61.286  55.051  1
486684  90.943  -61.297  55.053  1
486685  90.981  -61.309  55.052  1
486686  91.020  -61.321  55.048  1
486687  91.058  -61.333  55.045  1
486688  91.097  -61.345  55.043  1
486689  91.135  -61.357  55.041  1
486690  91.176  -61.368  55.037  1
486691  91.219  -61.379  55.029  1
486692  91.261  -61.390  55.024  1
486693  91.303  -61.401  55.026  1
486694  91.346  -61.412  55.034  1
486695  91.388  -61.422  55.045  1
486696  91.431  -61.434  55.059  1
486697  91.473  -61.444  55.068  1
486698  91.515  -61.455  55.071  1
486699  91.557  -61.466  55.075  1
486700  91.598  -61.478  55.078  1
486701  91.640  -61.488  55.077  1
486702  91.681  -61.500  55.076  1
486703  91.723  -61.511  55.072  1
486704  91.764  -61.522  55.064  1
486705  91.805  -61.532  55.051  1
486706  91.845  -61.538  55.034  1
486707  91.884  -61.544  55.017  1
486708  91.925  -61.553  54.990  1
486709  91.967  -61.570  54.966  1
486710  92.010  -61.587  54.950  1
486711  92.052  -61.603  54.941  1
486712  92.094  -61.619  54.925  1
486713  92.137  -61.636  54.897  1
486714  92.183  -61.649  54.863  1
486715  92.231  -61.662  54.826  1
486716  92.279  -61.674  54.792  1
486717  92.326  -61.686  54.766  1
486718  92.374  -61.699  54.750  1
486719  92.422  -61.711  54.743  1
486720  92.464  -61.719  54.743  1
486721  92.500  -61.723  54.746  1
486722  92.536  -61.727  54.743  1
486723  92.573  -61.730  54.732  1
486724  92.609  -61.734  54.715  1
486725  92.646  -61.738  54.693  1
486726  92.682  -61.741  54.667  1
486727  92.718  -61.746  54.634  1
486728  92.753  -61.753  54.600  1
486729  92.788  -61.760  54.561  1
486730  92.823  -61.767  54.518  1
486731  92.858  -61.775  54.475  1
486732  92.893  -61.782  54.439  1
486733  92.928  -61.789  54.412  1
486734  92.967  -61.801  54.390  1
486735  93.007  -61.812  54.373  1
486736  93.047  -61.824  54.362  1
486737  93.086  -61.835  54.352  1
486738  93.130  -61.847  54.339  1
486739  93.176  -61.858  54.323  1
486740  93.221  -61.869  54.304  1
486741  93.265  -61.879  54.281  1
486742  93.308  -61.890  54.257  1
486743  93.351  -61.901  54.230  1
486744  93.395  -61.911  54.202  1
486745  93.436  -61.921  54.173  1
486746  93.474  -61.931  54.146  1
486747  93.512  -61.941  54.121  1
486748  93.550  -61.951  54.096  1
486749  93.588  -61.961  54.075  1
486750  93.626  -61.970  54.057  1
486751  93.664  -61.980  54.042  1
486752  93.702  -61.990  54.027  1
486753  93.741  -62.000  54.013  1
486754  93.779  -62.009  53.999  1
486755  93.817  -62.020  53.985  1
486756  93.858  -62.031  53.973  1
486757  93.900  -62.042  53.961  1
486758  93.941  -62.054  53.947  1
486759  93.983  -62.065  53.932  1
486760  94.026  -62.073  53.917  1
486761  94.068  -62.080  53.902  1
486762  94.111  -62.088  53.888  1
486763  94.153  -62.095  53.873  1
486764  94.196  -62.103  53.854  1
486765  94.239  -62.111  53.833  1
486766  94.281  -62.117  53.807  1
486767  94.324  -62.125  53.778  1
486768  94.367  -62.133  53.747  1
486769  94.410  -62.140  53.713  1
486770  94.458  -62.140  53.679  1
486771  94.516  -62.129  53.645  1
486772  94.574  -62.117  53.612  1
486773  94.632  -62.105  53.580  1
486774  94.688  -62.094  53.549  1
486775  94.711  -62.101  53.518  1
486776  94.734  -62.108  53.486  1
486777  94.757  -62.115  53.455  1
486778  94.780  -62.122  53.423  1
486779  94.803  -62.129  53.392  1
486780  94.826  -62.136  53.361  1
486781  94.845  -62.150  53.332  1
486782  94.860  -62.171  53.303  1
486783  94.876  -62.191  53.277  1
486784  94.904  -62.202  53.249  1
486785  94.942  -62.205  53.221  1
486786  94.980  -62.208  53.195  1
486787  95.020  -62.212  53.170  1
486788  95.061  -62.217  53.145  1
486789  95.102  -62.221  53.120  1
486790  95.142  -62.225  53.096  1
486791  95.183  -62.230  53.072  1
486792  95.223  -62.233  53.047  1
486793  95.264  -62.238  53.024  1
486794  95.305  -62.243  53.002  1
486795  95.345  -62.246  52.981  1
486796  95.386  -62.251  52.960  1
486797  95.426  -62.255  52.940  1
486798  95.467  -62.259  52.921  1
486799  95.508  -62.264  52.901  1
486800  95.548  -62.268  52.880  1
486801  95.589  -62.272  52.855  1
486802  95.635  -62.273  52.827  1
486803  95.686  -62.276  52.795  1
486804  95.753  -62.296  52.760  1
486805  95.821  -62.318  52.725  1
486806  95.884  -62.333  52.687  1
486807  95.922  -62.318  52.649  1
486808  95.960  -62.302  52.610  1
486809  95.999  -62.287  52.569  1
486810  96.035  -62.279  52.530  1
486811  96.071  -62.284  52.491  1
486812  96.105  -62.289  52.452  1
486813  96.148  -62.291  52.414  1
486814  96.192  -62.290  52.377  1
486815  96.244  -62.263  52.338  1
486816  96.292  -62.251  52.298  1
486817  96.338  -62.247  52.259  1
486818  96.385  -62.246  52.220  1
486819  96.438  -62.254  52.180  1
486820  96.484  -62.267  52.138  1
486821  96.524  -62.287  52.094  1
486822  96.564  -62.306  52.048  1
486823  96.603  -62.327  52.001  1
486824  96.642  -62.339  51.953  1
486825  96.679  -62.345  51.906  1
486826  96.716  -62.351  51.858  1
486827  96.753  -62.357  51.812  1
486828  96.791  -62.363  51.767  1
486829  96.828  -62.370  51.723  1
486830  96.866  -62.376  51.681  1
486831  96.903  -62.382  51.641  1
486832  96.940  -62.388  51.602  1
486833  96.977  -62.394  51.565  1
486834  97.015  -62.400  51.529  1
486835  97.053  -62.406  51.494  1
486836  97.093  -62.411  51.459  1
486837  97.132  -62.415  51.425  1
486838  97.172  -62.421  51.392  1
486839  97.211  -62.426  51.358  1
486840  97.247  -62.432  51.325  1
486841  97.276  -62.441  51.291  1
486842  97.304  -62.451  51.258  1
486843  97.331  -62.460  51.223  1
486844  97.360  -62.470  51.189  1
486845  97.388  -62.479  51.153  1
486846  97.416  -62.489  51.117  1
486847  97.444  -62.498  51.081  1
486848  97.472  -62.508  51.044  1
486849  97.506  -62.514  51.007  1
486850  97.573  -62.506  50.969  1
486851  97.640  -62.497  50.931  1
486852  97.689  -62.484  50.894  1
486853  97.704  -62.459  50.855  1
486854  97.721  -62.437  50.817  1
486855  97.753  -62.424  50.778  1
486856  97.787  -62.412  50.738  1
486857  97.820  -62.401  50.698  1
486858  97.853  -62.389  50.658  1
486859  97.907  -62.403  50.617  1
486860  97.960  -62.418  50.576  1
486861  98.014  -62.432  50.535  1
486862  98.032  -62.446  50.495  1
486863  98.043  -62.462  50.454  1
486864  98.055  -62.477  50.412  1
486865  98.076  -62.492  50.371  1
486866  98.100  -62.508  50.329  1
486867  98.124  -62.524  50.288  1
486868  98.148  -62.539  50.247  1
486869  98.172  -62.555  50.206  1
486870  98.197  -62.570  50.166  1
487320  88.021  -60.491  55.793  1
487321  88.058  -60.493  55.775  1
487322  88.095  -60.494  55.756  1
487323  88.131  -60.496  55.739  1
487324  88.168  -60.498  55.721  1
487325  88.205  -60.500  55.703  1
487326  88.242  -60.501  55.685  1
487327  88.283  -60.505  55.667  1
487328  88.335  -60.512  55.650  1
487329  88.387  -60.519  55.632  1
487330  88.439  -60.525  55.615  1
487331  88.498  -60.509  55.599  1
487332  88.557  -60.493  55.584  1
487333  88.617  -60.478  55.567  1
487334  88.676  -60.462  55.547  1
487335  88.740  -60.450  55.523  1
487336  88.813  -60.449  55.497  1
487337  88.887  -60.447  55.469  1
487338  88.935  -60.469  55.442  1
487339  88.979  -60.489  55.414  1
487340  89.022  -60.507  55.385  1
487341  89.065  -60.525  55.356  1
487342  89.108  -60.544  55.330  1
487343  89.151  -60.562  55.303  1
487344  89.194  -60.580  55.277  1
487345  89.238  -60.598  55.252  1
487346  89.280  -60.616  55.228  1
487347  89.324  -60.635  55.205  1
487348  89.367  -60.653  55.186  1
487349  89.410  -60.671  55.168  1
487350  89.453  -60.689  55.152  1
487351  89.496  -60.707  55.138  1
487352  89.539  -60.726  55.125  1
487353  89.583  -60.744  55.115  1
487354  89.626  -60.762  55.107  1
487355  89.669  -60.780  55.102  1
487356  89.712  -60.798  55.100  1
487357  89.755  -60.817  55.098  1
487358  89.799  -60.835  55.095  1
487359  89.841  -60.853  55.091  1
487360  89.885  -60.871  55.087  1
487361  89.928  -60.891  55.080  1
487362  89.970  -60.912  55.069  1
487363  90.013  -60.934  55.058  1
487364  90.055  -60.955  55.047  1
487365  90.096  -60.973  55.036  1
487366  90.138  -60.994  55.025  1
487367  90.179  -61.014  55.019  1
487368  90.220  -61.035  55.015  1
487369  90.261  -61.056  55.013  1
487370  90.303  -61.077  55.013  1
487371  90.344  -61.097  55.013  1
487372  90.385  -61.118  55.016  1
487373  90.427  -61.133  55.019  1
487374  90.468  -61.143  55.020  1
487375  90.510  -61.153  55.019  1
487376  90.552  -61.164  55.017  1
487377  90.594  -61.174  55.017  1
487378  90.636  -61.184  55.018  1
487379  90.680  -61.195  55.020  1
487380  90.729  -61.206  55.025  1
487381  90.778  -61.217  55.031  1
487382  90.827  -61.228  55.036  1
487383  90.876  -61.240  55.043  1
487384  90.918  -61.251  55.050  1
487385  90.956  -61.263  55.054  1
487386  90.995  -61.274  55.055  1
487387  91.033  -61.287  55.051  1
487388  91.072  -61.299  55.050  1
487389  91.110  -61.310  55.049  1
487390  91.149  -61.322  55.048  1
487391  91.187  -61.334  55.044  1
487392  91.228  -61.346  55.034  1
487393  91.271  -61.356  55.025  1
487394  91.313  -61.367  55.021  1
487395  91.355  -61.378  55.022  1
487396  91.397  -61.389  55.029  1
487397  91.440  -61.400  55.041  1
487398  91.483  -61.411  55.051  1
487399  91.525  -61.422  55.058  1
487400  91.566  -61.433  55.064  1
487401  91.608  -61.443  55.069  1
487402  91.649  -61.455  55.068  1
487403  91.691  -61.466  55.066  1
487404  91.732  -61.477  55.061  1
487405  91.774  -61.488  55.051  1
487406  91.814  -61.497  55.037  1
487407  91.854  -61.503  55.020  1
487408  91.893  -61.509  55.005  1
487409  91.932  -61.515  54.983  1
487410  91.974  -61.528  54.965  1
487411  92.017  -61.545  54.954  1
487412  92.059  -61.562  54.946  1
487413  92.101  -61.578  54.927  1
487414  92.146  -61.593  54.892  1
487415  92.194  -61.605  54.853  1
487416  92.241  -61.617  54.817  1
487417  92.289  -61.630  54.792  1
487418  92.337  -61.642  54.771  1
487419  92.384  -61.654  54.753  1
487420  92.432  -61.667  54.744  1
487421  92.479  -61.678  54.743  1
487422  92.515  -61.682  54.747  1
487423  92.552  -61.686  54.743  1
487424  92.588  -61.690  54.730  1
487425  92.624  -61.693  54.711  1
487426  92.660  -61.697  54.689  1
487427  92.696  -61.702  54.663  1
487428  92.731  -61.710  54.631  1
487429  92.766  -61.717  54.599  1
487430  92.801  -61.724  54.561  1
487431  92.836  -61.732  54.520  1
487432  92.871  -61.738  54.477  1
487433  92.906  -61.746  54.444  1
487434  92.941  -61.754  54.421  1
487435  92.976  -61.760  54.405  1
487436  93.012  -61.769  54.394  1
487437  93.052  -61.781  54.387  1
487438  93.092  -61.792  54.376  1
487439  93.137  -61.804  54.360  1
487440  93.182  -61.815  54.341  1
487441  93.225  -61.826  54.318  1
487442  93.268  -61.835  54.292  1
487443  93.311  -61.846  54.261  1
487444  93.355  -61.857  54.229  1
487445  93.398  -61.867  54.197  1
487446  93.441  -61.877  54.167  1
487447  93.481  -61.888  54.139  1
487448  93.519  -61.898  54.113  1
487449  93.557  -61.907  54.087  1
487450  93.595  -61.917  54.064  1
487451  93.633  -61.926  54.044  1
487452  93.671  -61.936  54.026  1
487453  93.709  -61.946  54.009  1
487454  93.747  -61.956  53.993  1
487455  93.785  -61.966  53.977  1
487456  93.826  -61.977  53.962  1
487457  93.867  -61.989  53.948  1
487458  93.909  -62.000  53.936  1
487459  93.951  -62.011  53.922  1
487460  93.992  -62.023  53.906  1
487461  94.034  -62.032  53.889  1
487462  94.077  -62.039  53.870  1
487463  94.119  -62.046  53.853  1
487464  94.162  -62.054  53.835  1
487465  94.205  -62.061  53.816  1
487466  94.248  -62.069  53.795  1
487467  94.290  -62.077  53.771  1
487468  94.333  -62.084  53.745  1
487469  94.376  -62.092  53.717  1
487470  94.418  -62.098  53.687  1
487471  94.461  -62.106  53.658  1
487472  94.503  -62.114  53.628  1
487473  94.546  -62.121  53.598  1
487474  94.600  -62.114  53.569  1
487475  94.658  -62.103  53.541  1
487476  94.689  -62.105  53.512  1
487477  94.712  -62.112  53.483  1
487478  94.735  -62.119  53.455  1
487479  94.758  -62.127  53.425  1
487480  94.781  -62.133  53.395  1
487481  94.804  -62.140  53.367  1
487482  94.827  -62.147  53.340  1
487483  94.851  -62.152  53.313  1
487484  94.880  -62.154  53.286  1
487485  94.913  -62.158  53.259  1
487486  94.954  -62.161  53.232  1
487487  94.994  -62.166  53.205  1
487488  95.035  -62.171  53.180  1
487489  95.075  -62.174  53.155  1
487490  95.116  -62.179  53.131  1
487491  95.157  -62.183  53.106  1
487492  95.197  -62.187  53.080  1
487493  95.238  -62.192  53.053  1
487494  95.278  -62.196  53.029  1
487495  95.319  -62.200  53.007  1
487496  95.359  -62.205  52.985  1
487497  95.400  -62.209  52.964  1
487498  95.441  -62.213  52.944  1
487499  95.481  -62.218  52.924  1
487500  95.522  -62.222  52.905  1
487501  95.562  -62.226  52.883  1
487502  95.605  -62.229  52.859  1
487503  95.653  -62.230  52.831  1
487504  95.705  -62.234  52.800  1
487505  95.773  -62.255  52.765  1
487506  95.841  -62.276  52.728  1
487507  95.891  -62.276  52.690  1
487508  95.930  -62.261  52.651  1
487509  95.967  -62.246  52.611  1
487510  96.005  -62.234  52.569  1
487511  96.040  -62.239  52.527  1
487512  96.075  -62.244  52.486  1
487513  96.110  -62.249  52.448  1
487514  96.151  -62.252  52.410  1
487515  96.194  -62.253  52.371  1
487516  96.239  -62.251  52.332  1
487517  96.291  -62.224  52.292  1
487518  96.342  -62.199  52.253  1
487519  96.388  -62.196  52.214  1
487520  96.437  -62.196  52.175  1
487521  96.488  -62.204  52.133  1
487522  96.528  -62.224  52.090  1
487523  96.568  -62.243  52.045  1
487524  96.607  -62.263  51.999  1
487525  96.647  -62.283  51.952  1
487526  96.685  -62.298  51.904  1
487527  96.723  -62.304  51.856  1
487528  96.760  -62.310  51.809  1
487529  96.797  -62.316  51.763  1
487530  96.834  -62.322  51.719  1
487531  96.872  -62.328  51.677  1
487532  96.909  -62.334  51.636  1
487533  96.947  -62.340  51.597  1
487534  96.984  -62.346  51.560  1
487535  97.021  -62.352  51.523  1
487536  97.061  -62.358  51.488  1
487537  97.100  -62.363  51.453  1
487538  97.139  -62.368  51.419  1
487539  97.179  -62.373  51.385  1
487540  97.214  -62.380  51.352  1
487541  97.242  -62.389  51.319  1
487542  97.270  -62.399  51.285  1
487543  97.298  -62.408  51.251  1
487544  97.326  -62.418  51.217  1
487545  97.354  -62.427  51.183  1
487546  97.382  -62.437  51.146  1
487547  97.410  -62.446  51.110  1
487548  97.438  -62.456  51.073  1
487549  97.466  -62.465  51.036  1
487550  97.508  -62.468  50.999  1
487551  97.575  -62.460  50.962  1
487552  97.642  -62.451  50.924  1
487553  97.697  -62.440  50.886  1
487554  97.712  -62.415  50.848  1
487555  97.728  -62.393  50.810  1
487556  97.761  -62.381  50.771  1
487557  97.795  -62.369  50.732  1
487558  97.828  -62.357  50.692  1
487559  97.867  -62.353  50.652  1
487560  97.921  -62.367  50.612  1
487561  97.974  -62.381  50.572  1
487562  98.014  -62.396  50.531  1
487563  98.025  -62.411  50.490  1
487564  98.036  -62.426  50.449  1
487565  98.053  -62.441  50.407  1
487566  98.077  -62.457  50.366  1
487567  98.101  -62.472  50.326  1
487568  98.126  -62.488  50.285  1
487569  98.150  -62.504  50.244  1
487570  98.174  -62.519  50.203  1
487571  98.198  -62.535  50.162  1
488021  88.037  -60.443  55.783  1
488022  88.073  -60.444  55.763  1
488023  88.110  -60.447  55.744  1
488024  88.146  -60.448  55.726  1
488025  88.183  -60.450  55.708  1
488026  88.220  -60.452  55.690  1
488027  88.257  -60.454  55.672  1
488028  88.310  -60.461  55.653  1
488029  88.361  -60.468  55.636  1
488030  88.413  -60.475  55.619  1
488031  88.467  -60.476  55.602  1
488032  88.527  -60.460  55.586  1
488033  88.586  -60.445  55.572  1
488034  88.645  -60.429  55.555  1
488035  88.704  -60.414  55.537  1
488036  88.761  -60.401  55.515  1
488037  88.830  -60.397  55.493  1
488038  88.903  -60.395  55.464  1
488039  88.949  -60.418  55.436  1
488040  88.992  -60.436  55.408  1
488041  89.035  -60.454  55.380  1
488042  89.079  -60.472  55.351  1
488043  89.122  -60.491  55.325  1
488044  89.165  -60.509  55.298  1
488045  89.208  -60.527  55.271  1
488046  89.251  -60.545  55.246  1
488047  89.294  -60.563  55.223  1
488048  89.337  -60.582  55.199  1
488049  89.381  -60.600  55.179  1
488050  89.423  -60.618  55.161  1
488051  89.467  -60.636  55.144  1
488052  89.510  -60.654  55.128  1
488053  89.553  -60.673  55.115  1
488054  89.596  -60.691  55.104  1
488055  89.639  -60.709  55.094  1
488056  89.682  -60.731  55.086  1
488057  89.725  -60.752  55.080  1
488058  89.767  -60.774  55.076  1
488059  89.810  -60.795  55.073  1
488060  89.852  -60.817  55.072  1
488061  89.895  -60.839  55.070  1
488062  89.938  -60.860  55.064  1
488063  89.981  -60.882  55.059  1
488064  90.023  -60.903  55.052  1
488065  90.066  -60.925  55.043  1
488066  90.107  -60.943  55.032  1
488067  90.147  -60.961  55.020  1
488068  90.187  -60.979  55.012  1
488069  90.229  -60.999  55.007  1
488070  90.270  -61.020  55.005  1
488071  90.311  -61.041  55.004  1
488072  90.353  -61.061  55.003  1
488073  90.394  -61.082  55.005  1
488074  90.435  -61.097  55.007  1
488075  90.477  -61.107  55.009  1
488076  90.519  -61.118  55.010  1
488077  90.561  -61.128  55.011  1
488078  90.602  -61.138  55.013  1
488079  90.649  -61.149  55.015  1
488080  90.698  -61.160  55.019  1
488081  90.747  -61.171  55.025  1
488082  90.796  -61.182  55.032  1
488083  90.845  -61.193  55.038  1
488084  90.892  -61.205  55.044  1
488085  90.931  -61.216  55.051  1
488086  90.969  -61.228  55.056  1
488087  91.008  -61.240  55.059  1
488088  91.046  -61.252  55.058  1
488089  91.085  -61.264  55.056  1
488090  91.123  -61.276  55.054  1
488091  91.162  -61.287  55.052  1
488092  91.201  -61.299  55.049  1
488093  91.239  -61.312  55.040  1
488094  91.280  -61.323  55.029  1
488095  91.322  -61.334  55.020  1
488096  91.365  -61.344  55.015  1
488097  91.407  -61.356  55.016  1
488098  91.449  -61.366  55.023  1
488099  91.492  -61.377  55.032  1
488100  91.534  -61.388  55.040  1
488101  91.576  -61.399  55.048  1
488102  91.617  -61.410  55.055  1
488103  91.659  -61.422  55.056  1
488104  91.701  -61.432  55.054  1
488105  91.742  -61.443  55.048  1
488106  91.784  -61.454  55.037  1
488107  91.823  -61.462  55.021  1
488108  91.863  -61.469  55.004  1
488109  91.902  -61.474  54.991  1
488110  91.941  -61.480  54.975  1
488111  91.981  -61.487  54.964  1
488112  92.024  -61.503  54.959  1
488113  92.066  -61.520  54.950  1
488114  92.109  -61.536  54.926  1
488115  92.157  -61.549  54.890  1
488116  92.204  -61.561  54.851  1
488117  92.252  -61.573  54.817  1
488118  92.299  -61.586  54.799  1
488119  92.347  -61.598  54.779  1
488120  92.395  -61.610  54.758  1
488121  92.442  -61.623  54.743  1
488122  92.490  -61.635  54.738  1
488123  92.530  -61.641  54.742  1
488124  92.566  -61.645  54.738  1
488125  92.603  -61.649  54.726  1
488126  92.639  -61.653  54.709  1
488127  92.674  -61.659  54.688  1
488128  92.709  -61.666  54.661  1
488129  92.744  -61.674  54.633  1
488130  92.779  -61.681  54.602  1
488131  92.814  -61.688  54.566  1
488132  92.849  -61.695  54.524  1
488133  92.884  -61.703  54.479  1
488134  92.919  -61.710  54.450  1
488135  92.954  -61.717  54.432  1
488136  92.989  -61.725  54.422  1
488137  93.024  -61.732  54.417  1
488138  93.059  -61.739  54.411  1
488139  93.097  -61.750  54.398  1
488140  93.142  -61.760  54.379  1
488141  93.185  -61.771  54.356  1
488142  93.228  -61.782  54.329  1
488143  93.272  -61.792  54.297  1
488144  93.315  -61.802  54.262  1
488145  93.358  -61.813  54.228  1
488146  93.402  -61.823  54.194  1
488147  93.445  -61.834  54.163  1
488148  93.487  -61.844  54.135  1
488149  93.525  -61.854  54.107  1
488150  93.564  -61.863  54.081  1
488151  93.602  -61.873  54.057  1
488152  93.640  -61.883  54.035  1
488153  93.678  -61.893  54.016  1
488154  93.716  -61.903  53.997  1
488155  93.754  -61.913  53.979  1
488156  93.793  -61.923  53.962  1
488157  93.835  -61.935  53.945  1
488158  93.876  -61.946  53.929  1
488159  93.918  -61.957  53.914  1
488160  93.960  -61.969  53.898  1
488161  94.001  -61.980  53.881  1
488162  94.043  -61.990  53.863  1
488163  94.085  -61.998  53.844  1
488164  94.128  -62.005  53.825  1
488165  94.171  -62.013  53.806  1
488166  94.213  -62.020  53.786  1
488167  94.256  -62.028  53.765  1
488168  94.299  -62.035  53.742  1
488169  94.341  -62.042  53.718  1
488170  94.384  -62.050  53.693  1
488171  94.427  -62.058  53.666  1
488172  94.469  -62.065  53.641  1
488173  94.512  -62.073  53.615  1
488174  94.555  -62.080  53.588  1
488175  94.598  -62.087  53.561  1
488176  94.640  -62.095  53.536  1
488177  94.678  -62.099  53.510  1
488178  94.705  -62.101  53.485  1
488179  94.734  -62.102  53.460  1
488180  94.762  -62.104  53.432  1
488181  94.789  -62.105  53.404  1
488182  94.818  -62.106  53.378  1
488183  94.846  -62.108  53.352  1
488184  94.874  -62.109  53.326  1
488185  94.902  -62.111  53.300  1
488186  94.931  -62.114  53.273  1
488187  94.969  -62.120  53.246  1
488188  95.008  -62.124  53.220  1
488189  95.049  -62.129  53.194  1
488190  95.090  -62.133  53.168  1
488191  95.130  -62.137  53.144  1
488192  95.171  -62.142  53.118  1
488193  95.211  -62.145  53.091  1
488194  95.252  -62.150  53.063  1
488195  95.293  -62.155  53.038  1
488196  95.333  -62.158  53.014  1
488197  95.374  -62.163  52.992  1
488198  95.414  -62.167  52.970  1
488199  95.455  -62.171  52.949  1
488200  95.495  -62.176  52.929  1
488201  95.536  -62.180  52.908  1
488202  95.577  -62.184  52.886  1
488203  95.623  -62.186  52.861  1
488204  95.670  -62.186  52.834  1
488205  95.725  -62.193  52.802  1
488206  95.793  -62.214  52.768  1
488207  95.861  -62.235  52.731  1
488208  95.898  -62.220  52.692  1
488209  95.937  -62.204  52.652  1
488210  95.974  -62.189  52.611  1
488211  96.010  -62.194  52.568  1
488212  96.044  -62.199  52.527  1
488213  96.080  -62.204  52.486  1
488214  96.115  -62.208  52.447  1
488215  96.154  -62.212  52.408  1
488216  96.197  -62.214  52.369  1
488217  96.240  -62.215  52.328  1
488218  96.286  -62.211  52.288  1
488219  96.338  -62.183  52.249  1
488220  96.390  -62.156  52.210  1
488221  96.438  -62.143  52.170  1
488222  96.487  -62.145  52.129  1
488223  96.532  -62.161  52.086  1
488224  96.571  -62.180  52.042  1
488225  96.611  -62.200  51.998  1
488226  96.650  -62.220  51.951  1
488227  96.690  -62.239  51.904  1
488228  96.729  -62.256  51.857  1
488229  96.766  -62.262  51.810  1
488230  96.804  -62.268  51.762  1
488231  96.841  -62.275  51.716  1
488232  96.878  -62.281  51.675  1
488233  96.915  -62.287  51.634  1
488234  96.953  -62.293  51.594  1
488235  96.990  -62.299  51.556  1
488236  97.028  -62.305  51.519  1
488237  97.068  -62.310  51.484  1
488238  97.107  -62.315  51.449  1
488239  97.147  -62.320  51.415  1
488240  97.180  -62.327  51.381  1
488241  97.209  -62.337  51.348  1
488242  97.237  -62.346  51.314  1
488243  97.264  -62.355  51.281  1
488244  97.293  -62.365  51.247  1
488245  97.321  -62.374  51.213  1
488246  97.349  -62.384  51.178  1
488247  97.377  -62.393  51.141  1
488248  97.405  -62.403  51.105  1
488249  97.433  -62.412  51.068  1
488250  97.461  -62.422  51.031  1
488251  97.509  -62.422  50.994  1
488252  97.576  -62.414  50.957  1
488253  97.643  -62.406  50.918  1
488254  97.704  -62.395  50.880  1
488255  97.719  -62.371  50.842  1
488256  97.736  -62.349  50.805  1
488257  97.770  -62.337  50.766  1
488258  97.803  -62.325  50.726  1
488259  97.836  -62.313  50.686  1
488260  97.881  -62.317  50.646  1
488261  97.935  -62.331  50.608  1
488262  97.988  -62.346  50.568  1
488263  98.007  -62.360  50.527  1
488264  98.018  -62.375  50.486  1
488265  98.031  -62.390  50.445  1
488266  98.055  -62.406  50.403  1
488267  98.079  -62.421  50.362  1
488268  98.103  -62.437  50.322  1
488269  98.128  -62.453  50.282  1
488270  98.152  -62.468  50.241  1
488271  98.176  -62.484  50.201  1
488272  98.200  -62.500  50.160  1
488273  98.224  -62.515  50.121  1
488723  88.088  -60.397  55.752  1
488724  88.125  -60.399  55.732  1
488725  88.162  -60.400  55.714  1
488726  88.198  -60.402  55.695  1
488727  88.235  -60.404  55.676  1
488728  88.284  -60.410  55.658  1
488729  88.336  -60.417  55.640  1
488730  88.388  -60.424  55.622  1
488731  88.440  -60.431  55.605  1
488732  88.495  -60.428  55.588  1
488733  88.555  -60.412  55.573  1
488734  88.614  -60.397  55.559  1
488735  88.673  -60.381  55.543  1
488736  88.732  -60.365  55.526  1
488737  88.788  -60.354  55.506  1
488738  88.846  -60.343  55.484  1
488739  88.919  -60.343  55.458  1
488740  88.963  -60.364  55.430  1
488741  89.006  -60.382  55.402  1
488742  89.049  -60.400  55.374  1
488743  89.092  -60.419  55.346  1
488744  89.135  -60.437  55.319  1
488745  89.178  -60.456  55.293  1
488746  89.222  -60.474  55.266  1
488747  89.265  -60.492  55.241  1
488748  89.308  -60.510  55.217  1
488749  89.351  -60.528  55.194  1
488750  89.394  -60.549  55.173  1
488751  89.437  -60.571  55.154  1
488752  89.479  -60.592  55.136  1
488753  89.522  -60.614  55.120  1
488754  89.564  -60.635  55.106  1
488755  89.607  -60.657  55.094  1
488756  89.650  -60.679  55.083  1
488757  89.692  -60.700  55.074  1
488758  89.735  -60.722  55.066  1
488759  89.777  -60.743  55.059  1
488760  89.820  -60.765  55.055  1
488761  89.863  -60.786  55.054  1
488762  89.906  -60.807  55.052  1
488763  89.948  -60.829  55.049  1
488764  89.991  -60.851  55.048  1
488765  90.034  -60.873  55.043  1
488766  90.076  -60.894  55.037  1
488767  90.117  -60.913  55.029  1
488768  90.157  -60.930  55.018  1
488769  90.197  -60.947  55.008  1
488770  90.237  -60.964  55.001  1
488771  90.279  -60.984  54.997  1
488772  90.320  -61.005  54.996  1
488773  90.361  -61.026  54.995  1
488774  90.402  -61.046  54.995  1
488775  90.444  -61.061  54.998  1
488776  90.485  -61.071  55.001  1
488777  90.527  -61.082  55.004  1
488778  90.569  -61.092  55.008  1
488779  90.618  -61.103  55.011  1
488780  90.667  -61.114  55.014  1
488781  90.716  -61.125  55.020  1
488782  90.764  -61.136  55.027  1
488783  90.813  -61.147  55.035  1
488784  90.862  -61.158  55.042  1
488785  90.905  -61.170  55.047  1
488786  90.944  -61.182  55.055  1
488787  90.982  -61.193  55.062  1
488788  91.021  -61.205  55.067  1
488789  91.060  -61.218  55.067  1
488790  91.098  -61.229  55.064  1
488791  91.137  -61.241  55.061  1
488792  91.175  -61.253  55.059  1
488793  91.214  -61.265  55.055  1
488794  91.252  -61.277  55.047  1
488795  91.291  -61.289  55.035  1
488796  91.331  -61.300  55.023  1
488797  91.374  -61.311  55.014  1
488798  91.416  -61.321  55.009  1
488799  91.458  -61.333  55.011  1
488800  91.501  -61.343  55.015  1
488801  91.543  -61.355  55.020  1
488802  91.585  -61.365  55.026  1
488803  91.627  -61.377  55.033  1
488804  91.668  -61.387  55.038  1
488805  91.710  -61.399  55.040  1
488806  91.751  -61.409  55.035  1
488807  91.793  -61.421  55.022  1
488808  91.832  -61.428  55.006  1
488809  91.872  -61.434  54.988  1
488810  91.911  -61.439  54.977  1
488811  91.950  -61.445  54.969  1
488812  91.990  -61.451  54.965  1
488813  92.031  -61.462  54.963  1
488814  92.073  -61.478  54.952  1
488815  92.120  -61.492  54.926  1
488816  92.167  -61.504  54.890  1
488817  92.215  -61.517  54.850  1
488818  92.262  -61.529  54.816  1
488819  92.310  -61.541  54.801  1
488820  92.358  -61.554  54.786  1
488821  92.405  -61.566  54.766  1
488822  92.453  -61.578  54.746  1
488823  92.501  -61.591  54.732  1
488824  92.545  -61.601  54.731  1
488825  92.581  -61.604  54.729  1
488826  92.618  -61.609  54.719  1
488827  92.652  -61.616  54.704  1
488828  92.688  -61.623  54.682  1
488829  92.722  -61.630  54.655  1
488830  92.757  -61.638  54.629  1
488831  92.792  -61.645  54.598  1
488832  92.827  -61.652  54.561  1
488833  92.862  -61.660  54.520  1
488834  92.897  -61.666  54.481  1
488835  92.932  -61.674  54.458  1
488836  92.967  -61.681  54.447  1
488837  93.002  -61.688  54.443  1
488838  93.037  -61.695  54.440  1
488839  93.072  -61.702  54.432  1
488840  93.107  -61.709  54.417  1
488841  93.146  -61.717  54.395  1
488842  93.189  -61.727  54.367  1
488843  93.232  -61.738  54.334  1
488844  93.275  -61.748  54.296  1
488845  93.319  -61.758  54.260  1
488846  93.362  -61.769  54.226  1
488847  93.405  -61.779  54.193  1
488848  93.448  -61.790  54.162  1
488849  93.491  -61.801  54.133  1
488850  93.532  -61.810  54.104  1
488851  93.570  -61.820  54.077  1
488852  93.608  -61.830  54.053  1
488853  93.646  -61.840  54.030  1
488854  93.684  -61.850  54.009  1
488855  93.722  -61.860  53.989  1
488856  93.761  -61.870  53.969  1
488857  93.802  -61.881  53.951  1
488858  93.844  -61.892  53.933  1
488859  93.885  -61.904  53.915  1
488860  93.927  -61.915  53.898  1
488861  93.968  -61.926  53.881  1
488862  94.010  -61.938  53.863  1
488863  94.051  -61.948  53.844  1
488864  94.094  -61.957  53.826  1
488865  94.137  -61.964  53.806  1
488866  94.179  -61.971  53.788  1
488867  94.222  -61.979  53.769  1
488868  94.265  -61.986  53.748  1
488869  94.308  -61.994  53.726  1
488870  94.350  -62.001  53.703  1
488871  94.393  -62.009  53.680  1
488872  94.435  -62.017  53.656  1
488873  94.478  -62.023  53.633  1
488874  94.521  -62.031  53.609  1
488875  94.563  -62.039  53.585  1
488876  94.606  -62.046  53.560  1
488877  94.648  -62.053  53.538  1
488878  94.685  -62.055  53.516  1
488879  94.720  -62.057  53.495  1
488880  94.755  -62.059  53.473  1
488881  94.784  -62.060  53.447  1
488882  94.812  -62.061  53.422  1
488883  94.840  -62.063  53.395  1
488884  94.868  -62.064  53.369  1
488885  94.896  -62.066  53.345  1
488886  94.924  -62.067  53.319  1
488887  94.952  -62.069  53.292  1
488888  94.988  -62.075  53.265  1
488889  95.025  -62.081  53.239  1
488890  95.063  -62.086  53.211  1
488891  95.104  -62.091  53.186  1
488892  95.144  -62.095  53.160  1
488893  95.185  -62.099  53.133  1
488894  95.226  -62.104  53.104  1
488895  95.266  -62.108  53.075  1
488896  95.307  -62.112  53.049  1
488897  95.347  -62.117  53.024  1
488898  95.388  -62.121  53.000  1
488899  95.428  -62.125  52.978  1
488900  95.469  -62.130  52.955  1
488901  95.510  -62.134  52.932  1
488902  95.550  -62.138  52.910  1
488903  95.592  -62.142  52.886  1
488904  95.640  -62.142  52.861  1
488905  95.688  -62.142  52.833  1
488906  95.745  -62.152  52.801  1
488907  95.812  -62.173  52.767  1
488908  95.868  -62.178  52.730  1
488909  95.905  -62.163  52.690  1
488910  95.944  -62.148  52.650  1
488911  95.979  -62.149  52.609  1
488912  96.014  -62.154  52.567  1
488913  96.049  -62.159  52.528  1
488914  96.084  -62.164  52.489  1
488915  96.119  -62.168  52.448  1
488916  96.157  -62.172  52.408  1
488917  96.200  -62.174  52.368  1
488918  96.243  -62.176  52.327  1
488919  96.287  -62.177  52.286  1
488920  96.333  -62.171  52.246  1
488921  96.385  -62.144  52.208  1
488922  96.437  -62.117  52.167  1
488923  96.488  -62.092  52.125  1
488924  96.535  -62.098  52.082  1
488925  96.575  -62.117  52.038  1
488926  96.614  -62.137  51.993  1
488927  96.654  -62.157  51.947  1
488928  96.694  -62.177  51.902  1
488929  96.733  -62.196  51.856  1
488930  96.772  -62.215  51.810  1
488931  96.810  -62.221  51.762  1
488932  96.847  -62.227  51.717  1
488933  96.885  -62.233  51.674  1
488934  96.922  -62.239  51.632  1
488935  96.959  -62.246  51.592  1
488936  96.997  -62.252  51.554  1
488937  97.035  -62.257  51.517  1
488938  97.075  -62.262  51.482  1
488939  97.114  -62.268  51.447  1
488940  97.147  -62.275  51.413  1
488941  97.175  -62.284  51.379  1
488942  97.203  -62.294  51.345  1
488943  97.231  -62.303  51.311  1
488944  97.259  -62.313  51.278  1
488945  97.287  -62.322  51.244  1
488946  97.315  -62.332  51.210  1
488947  97.343  -62.341  51.174  1
488948  97.371  -62.351  51.138  1
488949  97.399  -62.360  51.102  1
488950  97.427  -62.370  51.065  1
488951  97.455  -62.379  51.028  1
488952  97.510  -62.376  50.990  1
488953  97.577  -62.368  50.952  1
488954  97.644  -62.359  50.914  1
488955  97.711  -62.351  50.876  1
488956  97.726  -62.327  50.838  1
488957  97.744  -62.305  50.800  1
488958  97.777  -62.293  50.761  1
488959  97.810  -62.281  50.722  1
488960  97.844  -62.269  50.682  1
488961  97.895  -62.281  50.643  1
488962  97.949  -62.295  50.603  1
488963  97.989  -62.309  50.564  1
488964  97.999  -62.324  50.523  1
488965  98.010  -62.340  50.482  1
488966  98.033  -62.355  50.441  1
488967  98.057  -62.371  50.400  1
488968  98.081  -62.387  50.359  1
488969  98.105  -62.402  50.318  1
488970  98.130  -62.418  50.278  1
488971  98.154  -62.434  50.238  1
488972  98.178  -62.449  50.197  1
488973  98.202  -62.465  50.157  1
488974  98.226  -62.480  50.119  1
489424  88.104  -60.349  55.741  1
489425  88.140  -60.350  55.721  1
489426  88.177  -60.353  55.701  1
489427  88.214  -60.354  55.682  1
489428  88.259  -60.359  55.663  1
489429  88.311  -60.365  55.644  1
489430  88.363  -60.373  55.626  1
489431  88.415  -60.380  55.608  1
489432  88.467  -60.387  55.591  1
489433  88.524  -60.380  55.575  1
489434  88.582  -60.364  55.559  1
489435  88.642  -60.349  55.545  1
489436  88.701  -60.333  55.530  1
489437  88.759  -60.318  55.513  1
489438  88.816  -60.307  55.494  1
489439  88.872  -60.296  55.474  1
489440  88.933  -60.293  55.451  1
489441  88.976  -60.311  55.424  1
489442  89.020  -60.329  55.396  1
489443  89.062  -60.347  55.369  1
489444  89.106  -60.368  55.341  1
489445  89.148  -60.389  55.315  1
489446  89.191  -60.411  55.288  1
489447  89.234  -60.432  55.262  1
489448  89.276  -60.454  55.237  1
489449  89.319  -60.475  55.213  1
489450  89.362  -60.497  55.189  1
489451  89.404  -60.519  55.168  1
489452  89.447  -60.540  55.148  1
489453  89.489  -60.562  55.131  1
489454  89.532  -60.583  55.114  1
489455  89.575  -60.604  55.099  1
489456  89.617  -60.626  55.086  1
489457  89.660  -60.647  55.074  1
489458  89.703  -60.669  55.064  1
489459  89.745  -60.691  55.055  1
489460  89.788  -60.713  55.046  1
489461  89.831  -60.734  55.040  1
489462  89.873  -60.755  55.037  1
489463  89.916  -60.777  55.035  1
489464  89.959  -60.798  55.033  1
489465  90.002  -60.820  55.035  1
489466  90.044  -60.842  55.034  1
489467  90.087  -60.864  55.031  1
489468  90.127  -60.882  55.025  1
489469  90.168  -60.899  55.015  1
489470  90.207  -60.916  55.003  1
489471  90.248  -60.933  54.995  1
489472  90.288  -60.951  54.991  1
489473  90.328  -60.969  54.989  1
489474  90.370  -60.990  54.989  1
489475  90.411  -61.011  54.990  1
489476  90.452  -61.025  54.992  1
489477  90.494  -61.036  54.996  1
489478  90.537  -61.046  55.002  1
489479  90.587  -61.057  55.010  1
489480  90.636  -61.068  55.014  1
489481  90.684  -61.079  55.017  1
489482  90.733  -61.090  55.022  1
489483  90.782  -61.102  55.031  1
489484  90.831  -61.112  55.041  1
489485  90.880  -61.124  55.047  1
489486  90.919  -61.135  55.053  1
489487  90.957  -61.147  55.061  1
489488  90.996  -61.159  55.071  1
489489  91.034  -61.171  55.077  1
489490  91.073  -61.183  55.077  1
489491  91.111  -61.195  55.074  1
489492  91.150  -61.206  55.070  1
489493  91.188  -61.218  55.067  1
489494  91.227  -61.230  55.062  1
489495  91.265  -61.242  55.054  1
489496  91.304  -61.254  55.043  1
489497  91.343  -61.266  55.031  1
489498  91.383  -61.277  55.019  1
489499  91.426  -61.288  55.009  1
489500  91.468  -61.299  55.004  1
489501  91.510  -61.310  55.003  1
489502  91.553  -61.321  55.004  1
489503  91.595  -61.332  55.006  1
489504  91.637  -61.343  55.011  1
489505  91.678  -61.354  55.018  1
489506  91.720  -61.365  55.021  1
489507  91.761  -61.376  55.018  1
489508  91.802  -61.387  55.008  1
489509  91.842  -61.393  54.992  1
489510  91.881  -61.398  54.975  1
489511  91.920  -61.404  54.966  1
489512  91.959  -61.410  54.966  1
489513  91.999  -61.416  54.969  1
489514  92.038  -61.422  54.966  1
489515  92.082  -61.435  54.951  1
489516  92.130  -61.448  54.924  1
489517  92.177  -61.460  54.890  1
489518  92.225  -61.472  54.852  1
489519  92.273  -61.485  54.816  1
489520  92.320  -61.497  54.800  1
489521  92.368  -61.509  54.792  1
489522  92.416  -61.522  54.774  1
489523  92.463  -61.534  54.750  1
489524  92.511  -61.547  54.727  1
489525  92.559  -61.559  54.719  1
489526  92.595  -61.566  54.717  1
489527  92.631  -61.572  54.709  1
489528  92.665  -61.580  54.694  1
489529  92.700  -61.587  54.672  1
489530  92.735  -61.594  54.645  1
489531  92.770  -61.600  54.618  1
489532  92.805  -61.608  54.588  1
489533  92.840  -61.615  54.553  1
489534  92.875  -61.622  54.515  1
489535  92.910  -61.628  54.484  1
489536  92.944  -61.636  54.468  1
489537  92.980  -61.643  54.462  1
489538  93.014  -61.650  54.459  1
489539  93.049  -61.657  54.454  1
489540  93.084  -61.664  54.442  1
489541  93.119  -61.671  54.422  1
489542  93.155  -61.678  54.395  1
489543  93.196  -61.686  54.363  1
489544  93.236  -61.694  54.328  1
489545  93.279  -61.704  54.293  1
489546  93.322  -61.715  54.259  1
489547  93.365  -61.725  54.227  1
489548  93.408  -61.735  54.195  1
489549  93.451  -61.746  54.163  1
489550  93.495  -61.757  54.134  1
489551  93.538  -61.766  54.106  1
489552  93.577  -61.777  54.078  1
489553  93.615  -61.786  54.052  1
489554  93.653  -61.796  54.028  1
489555  93.691  -61.806  54.005  1
489556  93.729  -61.816  53.985  1
489557  93.770  -61.827  53.963  1
489558  93.811  -61.838  53.943  1
489559  93.853  -61.850  53.925  1
489560  93.894  -61.861  53.905  1
489561  93.936  -61.873  53.887  1
489562  93.977  -61.884  53.869  1
489563  94.018  -61.895  53.850  1
489564  94.060  -61.907  53.831  1
489565  94.103  -61.915  53.812  1
489566  94.145  -61.923  53.794  1
489567  94.188  -61.930  53.775  1
489568  94.230  -61.938  53.756  1
489569  94.273  -61.945  53.736  1
489570  94.316  -61.953  53.715  1
489571  94.358  -61.960  53.693  1
489572  94.401  -61.967  53.671  1
489573  94.444  -61.975  53.649  1
489574  94.487  -61.983  53.628  1
489575  94.529  -61.990  53.607  1
489576  94.572  -61.998  53.585  1
489577  94.615  -62.005  53.563  1
489578  94.654  -62.009  53.544  1
489579  94.691  -62.012  53.527  1
489580  94.726  -62.014  53.512  1
489581  94.761  -62.015  53.495  1
489582  94.796  -62.017  53.473  1
489583  94.832  -62.018  53.450  1
489584  94.862  -62.020  53.426  1
489585  94.890  -62.021  53.403  1
489586  94.918  -62.023  53.380  1
489587  94.946  -62.024  53.356  1
489588  94.974  -62.026  53.330  1
489589  95.007  -62.030  53.303  1
489590  95.045  -62.036  53.275  1
489591  95.082  -62.042  53.245  1
489592  95.119  -62.048  53.215  1
489593  95.159  -62.054  53.185  1
489594  95.199  -62.058  53.153  1
489595  95.240  -62.062  53.121  1
489596  95.280  -62.067  53.089  1
489597  95.321  -62.070  53.062  1
489598  95.361  -62.075  53.036  1
489599  95.402  -62.080  53.011  1
489600  95.443  -62.083  52.985  1
489601  95.483  -62.088  52.959  1
489602  95.524  -62.092  52.933  1
489603  95.564  -62.096  52.907  1
489604  95.610  -62.098  52.881  1
489605  95.658  -62.098  52.855  1
489606  95.705  -62.098  52.827  1
489607  95.764  -62.111  52.794  1
489608  95.832  -62.131  52.760  1
489609  95.875  -62.121  52.722  1
489610  95.913  -62.106  52.683  1
489611  95.949  -62.105  52.644  1
489612  95.984  -62.109  52.606  1
489613  96.019  -62.114  52.568  1
489614  96.054  -62.119  52.532  1
489615  96.089  -62.123  52.493  1
489616  96.124  -62.128  52.450  1
489617  96.160  -62.133  52.408  1
489618  96.203  -62.134  52.368  1
489619  96.246  -62.136  52.326  1
489620  96.290  -62.138  52.285  1
489621  96.333  -62.139  52.245  1
489622  96.380  -62.131  52.206  1
489623  96.432  -62.104  52.164  1
489624  96.484  -62.077  52.122  1
489625  96.536  -62.049  52.079  1
489626  96.579  -62.055  52.035  1
489627  96.618  -62.074  51.990  1
489628  96.658  -62.094  51.944  1
489629  96.697  -62.114  51.900  1
489630  96.737  -62.133  51.855  1
489631  96.777  -62.153  51.810  1
489632  96.816  -62.174  51.764  1
489633  96.854  -62.180  51.718  1
489634  96.891  -62.186  51.674  1
489635  96.928  -62.192  51.632  1
489636  96.966  -62.199  51.592  1
489637  97.003  -62.205  51.553  1
489638  97.042  -62.209  51.516  1
489639  97.082  -62.214  51.480  1
489640  97.113  -62.223  51.445  1
489641  97.142  -62.232  51.411  1
489642  97.169  -62.242  51.377  1
489643  97.197  -62.251  51.343  1
489644  97.226  -62.261  51.310  1
489645  97.254  -62.270  51.276  1
489646  97.282  -62.280  51.243  1
489647  97.310  -62.289  51.208  1
489648  97.338  -62.299  51.172  1
489649  97.366  -62.308  51.136  1
489650  97.394  -62.318  51.099  1
489651  97.422  -62.327  51.063  1
489652  97.450  -62.337  51.025  1
489653  97.512  -62.330  50.987  1
489654  97.579  -62.322  50.949  1
489655  97.646  -62.313  50.911  1
489656  97.713  -62.305  50.873  1
489657  97.733  -62.283  50.834  1
489658  97.752  -62.261  50.797  1
489659  97.785  -62.249  50.757  1
489660  97.818  -62.237  50.718  1
489661  97.855  -62.230  50.679  1
489662  97.909  -62.245  50.639  1
489663  97.962  -62.259  50.599  1
489664  97.981  -62.274  50.560  1
489665  97.992  -62.289  50.519  1
489666  98.010  -62.304  50.478  1
489667  98.034  -62.320  50.437  1
489668  98.059  -62.336  50.397  1
489669  98.083  -62.351  50.356  1
489670  98.107  -62.367  50.315  1
489671  98.131  -62.382  50.275  1
489672  98.155  -62.398  50.235  1
489673  98.179  -62.414  50.195  1
489674  98.204  -62.429  50.155  1
489675  98.228  -62.445  50.116  1
490126  88.155  -60.303  55.710  1
490127  88.192  -60.305  55.689  1
490128  88.234  -60.308  55.669  1
490129  88.286  -60.315  55.651  1
490130  88.338  -60.322  55.632  1
490131  88.390  -60.328  55.613  1
490132  88.442  -60.336  55.594  1
490133  88.494  -60.343  55.577  1
490134  88.552  -60.331  55.562  1
490135  88.611  -60.316  55.546  1
490136  88.670  -60.300  55.531  1
490137  88.729  -60.284  55.515  1
490138  88.786  -60.271  55.499  1
490139  88.843  -60.260  55.481  1
490140  88.899  -60.249  55.463  1
490141  88.947  -60.249  55.442  1
490142  88.989  -60.269  55.418  1
490143  89.032  -60.290  55.391  1
490144  89.075  -60.312  55.363  1
490145  89.118  -60.334  55.336  1
490146  89.160  -60.355  55.310  1
490147  89.203  -60.377  55.284  1
490148  89.246  -60.398  55.258  1
490149  89.288  -60.419  55.233  1
490150  89.331  -60.441  55.209  1
490151  89.374  -60.463  55.186  1
490152  89.416  -60.484  55.164  1
490153  89.459  -60.506  55.144  1
490154  89.502  -60.527  55.127  1
490155  89.545  -60.548  55.110  1
490156  89.587  -60.570  55.095  1
490157  89.630  -60.591  55.081  1
490158  89.673  -60.613  55.068  1
490159  89.716  -60.634  55.056  1
490160  89.758  -60.656  55.047  1
490161  89.801  -60.677  55.039  1
490162  89.843  -60.698  55.031  1
490163  89.886  -60.720  55.025  1
490164  89.929  -60.742  55.021  1
490165  89.972  -60.763  55.019  1
490166  90.015  -60.785  55.020  1
490167  90.057  -60.806  55.024  1
490168  90.100  -60.827  55.024  1
490169  90.144  -60.847  55.019  1
490170  90.182  -60.865  55.009  1
490171  90.220  -60.884  54.997  1
490172  90.259  -60.902  54.989  1
490173  90.298  -60.920  54.985  1
490174  90.338  -60.937  54.983  1
490175  90.378  -60.955  54.984  1
490176  90.419  -60.975  54.985  1
490177  90.461  -60.989  54.987  1
490178  90.506  -61.000  54.991  1
490179  90.555  -61.011  54.999  1
490180  90.604  -61.022  55.009  1
490181  90.653  -61.033  55.015  1
490182  90.702  -61.044  55.019  1
490183  90.751  -61.055  55.025  1
490184  90.800  -61.067  55.033  1
490185  90.849  -61.077  55.045  1
490186  90.894  -61.089  55.051  1
490187  90.932  -61.101  55.057  1
490188  90.971  -61.112  55.066  1
490189  91.009  -61.124  55.078  1
490190  91.048  -61.136  55.086  1
490191  91.086  -61.148  55.088  1
490192  91.125  -61.160  55.085  1
490193  91.163  -61.172  55.081  1
490194  91.202  -61.183  55.075  1
490195  91.240  -61.196  55.070  1
490196  91.279  -61.208  55.063  1
490197  91.317  -61.219  55.053  1
490198  91.356  -61.231  55.042  1
490199  91.394  -61.243  55.029  1
490200  91.435  -61.255  55.014  1
490201  91.477  -61.265  55.001  1
490202  91.520  -61.277  54.995  1
490203  91.562  -61.287  54.991  1
490204  91.604  -61.298  54.989  1
490205  91.646  -61.309  54.990  1
490206  91.687  -61.320  54.996  1
490207  91.729  -61.331  54.999  1
490208  91.771  -61.343  54.997  1
490209  91.811  -61.352  54.988  1
490210  91.851  -61.358  54.975  1
490211  91.890  -61.363  54.963  1
490212  91.929  -61.369  54.959  1
490213  91.968  -61.375  54.962  1
490214  92.008  -61.381  54.965  1
490215  92.047  -61.387  54.961  1
490216  92.088  -61.397  54.946  1
490217  92.136  -61.409  54.918  1
490218  92.183  -61.422  54.885  1
490219  92.231  -61.434  54.849  1
490220  92.279  -61.447  54.816  1
490221  92.326  -61.459  54.801  1
490222  92.374  -61.472  54.796  1
490223  92.422  -61.484  54.781  1
490224  92.470  -61.497  54.755  1
490225  92.517  -61.509  54.725  1
490226  92.565  -61.522  54.710  1
490227  92.604  -61.528  54.702  1
490228  92.643  -61.534  54.692  1
490229  92.678  -61.541  54.677  1
490230  92.713  -61.548  54.657  1
490231  92.747  -61.556  54.630  1
490232  92.783  -61.563  54.602  1
490233  92.817  -61.569  54.574  1
490234  92.852  -61.576  54.543  1
490235  92.887  -61.583  54.510  1
490236  92.922  -61.591  54.488  1
490237  92.957  -61.597  54.480  1
490238  92.992  -61.604  54.476  1
490239  93.027  -61.611  54.472  1
490240  93.062  -61.619  54.463  1
490241  93.096  -61.625  54.446  1
490242  93.132  -61.632  54.420  1
490243  93.166  -61.639  54.390  1
490244  93.205  -61.647  54.356  1
490245  93.246  -61.656  54.321  1
490246  93.286  -61.664  54.288  1
490247  93.327  -61.672  54.256  1
490248  93.368  -61.682  54.226  1
490249  93.412  -61.691  54.195  1
490250  93.455  -61.702  54.166  1
490251  93.498  -61.713  54.137  1
490252  93.542  -61.723  54.110  1
490253  93.583  -61.733  54.082  1
490254  93.622  -61.743  54.056  1
490255  93.659  -61.753  54.031  1
490256  93.698  -61.763  54.007  1
490257  93.737  -61.773  53.986  1
490258  93.778  -61.785  53.965  1
490259  93.820  -61.796  53.944  1
490260  93.861  -61.807  53.924  1
490261  93.903  -61.819  53.903  1
490262  93.944  -61.830  53.883  1
490263  93.986  -61.841  53.863  1
490264  94.028  -61.853  53.844  1
490265  94.069  -61.864  53.824  1
490266  94.111  -61.874  53.805  1
490267  94.154  -61.882  53.787  1
490268  94.196  -61.889  53.769  1
490269  94.239  -61.896  53.750  1
490270  94.282  -61.904  53.730  1
490271  94.325  -61.911  53.708  1
490272  94.367  -61.919  53.687  1
490273  94.410  -61.926  53.666  1
490274  94.453  -61.934  53.646  1
490275  94.495  -61.942  53.627  1
490276  94.538  -61.948  53.608  1
490277  94.580  -61.956  53.589  1
490278  94.621  -61.962  53.569  1
490279  94.660  -61.966  53.553  1
490280  94.696  -61.968  53.540  1
490281  94.732  -61.970  53.530  1
490282  94.767  -61.972  53.517  1
490283  94.803  -61.973  53.499  1
490284  94.838  -61.975  53.479  1
490285  94.874  -61.976  53.459  1
490286  94.909  -61.978  53.439  1
490287  94.940  -61.979  53.419  1
490288  94.968  -61.981  53.395  1
490289  94.996  -61.983  53.370  1
490290  95.027  -61.986  53.344  1
490291  95.064  -61.992  53.316  1
490292  95.101  -61.998  53.286  1
490293  95.138  -62.004  53.253  1
490294  95.176  -62.011  53.220  1
490295  95.213  -62.016  53.185  1
490296  95.254  -62.020  53.148  1
490297  95.295  -62.024  53.112  1
490298  95.335  -62.029  53.080  1
490299  95.376  -62.033  53.051  1
490300  95.416  -62.037  53.023  1
490301  95.457  -62.042  52.994  1
490302  95.497  -62.046  52.966  1
490303  95.538  -62.050  52.937  1
490304  95.580  -62.054  52.909  1
490305  95.627  -62.055  52.881  1
490306  95.675  -62.055  52.851  1
490307  95.723  -62.055  52.820  1
490308  95.784  -62.069  52.786  1
490309  95.844  -62.080  52.751  1
490310  95.882  -62.065  52.714  1
490311  95.918  -62.059  52.676  1
490312  95.953  -62.064  52.638  1
490313  95.988  -62.069  52.600  1
490314  96.024  -62.073  52.564  1
490315  96.058  -62.079  52.527  1
490316  96.094  -62.083  52.489  1
490317  96.128  -62.088  52.450  1
490318  96.164  -62.093  52.408  1
490319  96.206  -62.095  52.367  1
490320  96.249  -62.097  52.324  1
490321  96.293  -62.098  52.283  1
490322  96.336  -62.100  52.244  1
490323  96.380  -62.102  52.204  1
490324  96.427  -62.092  52.163  1
490325  96.479  -62.064  52.122  1
490326  96.531  -62.037  52.079  1
490327  96.577  -62.036  52.035  1
490328  96.619  -62.040  51.990  1
490329  96.660  -62.044  51.944  1
490330  96.701  -62.051  51.899  1
490331  96.741  -62.070  51.855  1
490332  96.781  -62.090  51.811  1
490333  96.820  -62.110  51.767  1
490334  96.860  -62.130  51.721  1
490335  96.897  -62.139  51.677  1
490336  96.935  -62.145  51.634  1
490337  96.972  -62.151  51.593  1
490338  97.010  -62.157  51.553  1
490339  97.050  -62.161  51.516  1
490340  97.080  -62.171  51.480  1
490341  97.108  -62.180  51.445  1
490342  97.136  -62.189  51.411  1
490343  97.164  -62.199  51.376  1
490344  97.192  -62.208  51.342  1
490345  97.220  -62.218  51.309  1
490346  97.248  -62.227  51.276  1
490347  97.276  -62.236  51.242  1
490348  97.304  -62.246  51.208  1
490349  97.332  -62.255  51.172  1
490350  97.360  -62.265  51.135  1
490351  97.388  -62.274  51.098  1
490352  97.417  -62.284  51.061  1
490353  97.446  -62.293  51.023  1
490354  97.513  -62.284  50.985  1
490355  97.580  -62.276  50.947  1
490356  97.647  -62.268  50.908  1
490357  97.714  -62.259  50.870  1
490358  97.741  -62.239  50.832  1
490359  97.760  -62.218  50.794  1
490360  97.793  -62.205  50.754  1
490361  97.826  -62.193  50.714  1
490362  97.869  -62.195  50.675  1
490363  97.923  -62.208  50.636  1
490364  97.962  -62.223  50.596  1
490365  97.973  -62.238  50.557  1
490366  97.988  -62.253  50.516  1
490367  98.012  -62.269  50.475  1
490368  98.036  -62.284  50.434  1
490369  98.061  -62.300  50.393  1
490370  98.085  -62.316  50.353  1
490371  98.109  -62.331  50.312  1
490372  98.133  -62.347  50.272  1
490373  98.157  -62.363  50.232  1
490374  98.181  -62.378  50.192  1
490375  98.206  -62.394  50.152  1
490376  98.230  -62.409  50.114  1
490828  88.208  -60.257  55.678  1
490829  88.260  -60.264  55.657  1
490830  88.313  -60.271  55.638  1
490831  88.364  -60.278  55.620  1
490832  88.416  -60.284  55.601  1
490833  88.469  -60.291  55.582  1
490834  88.521  -60.299  55.564  1
490835  88.579  -60.283  55.549  1
490836  88.639  -60.268  55.533  1
490837  88.698  -60.252  55.517  1
490838  88.757  -60.237  55.501  1
490839  88.814  -60.225  55.485  1
490840  88.870  -60.214  55.468  1
490841  88.926  -60.202  55.451  1
490842  88.967  -60.217  55.432  1
490843  89.003  -60.233  55.409  1
490844  89.046  -60.254  55.384  1
490845  89.089  -60.275  55.358  1
490846  89.131  -60.297  55.331  1
490847  89.174  -60.318  55.305  1
490848  89.216  -60.340  55.279  1
490849  89.259  -60.362  55.254  1
490850  89.302  -60.383  55.231  1
490851  89.345  -60.404  55.206  1
490852  89.387  -60.426  55.183  1
490853  89.430  -60.447  55.161  1
490854  89.473  -60.469  55.142  1
490855  89.516  -60.491  55.124  1
490856  89.558  -60.512  55.106  1
490857  89.601  -60.533  55.091  1
490858  89.644  -60.554  55.077  1
490859  89.686  -60.576  55.064  1
490860  89.729  -60.597  55.052  1
490861  89.772  -60.619  55.042  1
490862  89.815  -60.641  55.033  1
490863  89.857  -60.662  55.024  1
490864  89.900  -60.683  55.018  1
490865  89.943  -60.705  55.013  1
490866  89.985  -60.726  55.010  1
490867  90.028  -60.748  55.009  1
490868  90.071  -60.770  55.010  1
490869  90.115  -60.790  55.010  1
490870  90.161  -60.810  55.007  1
490871  90.199  -60.829  55.000  1
490872  90.238  -60.847  54.990  1
490873  90.276  -60.866  54.984  1
490874  90.315  -60.884  54.980  1
490875  90.354  -60.902  54.977  1
490876  90.392  -60.921  54.978  1
490877  90.431  -60.939  54.980  1
490878  90.475  -60.954  54.982  1
490879  90.524  -60.965  54.986  1
490880  90.573  -60.976  54.994  1
490881  90.621  -60.987  55.006  1
490882  90.671  -60.998  55.015  1
490883  90.720  -61.009  55.021  1
490884  90.768  -61.020  55.027  1
490885  90.817  -61.031  55.034  1
490886  90.866  -61.042  55.045  1
490887  90.907  -61.054  55.052  1
490888  90.946  -61.066  55.058  1
490889  90.984  -61.078  55.067  1
490890  91.023  -61.089  55.079  1
490891  91.061  -61.102  55.090  1
490892  91.100  -61.114  55.094  1
490893  91.138  -61.125  55.094  1
490894  91.177  -61.137  55.091  1
490895  91.215  -61.149  55.086  1
490896  91.254  -61.161  55.080  1
490897  91.292  -61.173  55.074  1
490898  91.331  -61.185  55.065  1
490899  91.369  -61.196  55.055  1
490900  91.408  -61.208  55.042  1
490901  91.446  -61.221  55.028  1
490902  91.487  -61.232  55.006  1
490903  91.529  -61.243  54.992  1
490904  91.571  -61.254  54.983  1
490905  91.613  -61.265  54.976  1
490906  91.656  -61.276  54.970  1
490907  91.698  -61.287  54.970  1
490908  91.739  -61.298  54.972  1
490909  91.780  -61.309  54.971  1
490910  91.820  -61.317  54.966  1
490911  91.860  -61.322  54.956  1
490912  91.899  -61.328  54.951  1
490913  91.938  -61.334  54.953  1
490914  91.978  -61.340  54.957  1
490915  92.017  -61.347  54.958  1
490916  92.056  -61.356  54.953  1
490917  92.095  -61.363  54.938  1
490918  92.140  -61.375  54.910  1
490919  92.188  -61.387  54.877  1
490920  92.235  -61.400  54.843  1
490921  92.283  -61.412  54.813  1
490922  92.331  -61.425  54.804  1
490923  92.378  -61.437  54.800  1
490924  92.426  -61.450  54.787  1
490925  92.473  -61.462  54.762  1
490926  92.521  -61.475  54.728  1
490927  92.568  -61.487  54.703  1
490928  92.607  -61.493  54.690  1
490929  92.646  -61.499  54.678  1
490930  92.684  -61.505  54.664  1
490931  92.722  -61.511  54.648  1
490932  92.760  -61.517  54.627  1
490933  92.795  -61.524  54.604  1
490934  92.830  -61.531  54.577  1
490935  92.865  -61.538  54.546  1
490936  92.900  -61.545  54.513  1
490937  92.935  -61.552  54.496  1
490938  92.970  -61.559  54.492  1
490939  93.004  -61.566  54.489  1
490940  93.040  -61.573  54.481  1
490941  93.074  -61.580  54.467  1
490942  93.109  -61.587  54.443  1
490943  93.144  -61.594  54.411  1
490944  93.179  -61.601  54.378  1
490945  93.214  -61.608  54.344  1
490946  93.255  -61.616  54.312  1
490947  93.295  -61.625  54.281  1
490948  93.336  -61.633  54.252  1
490949  93.377  -61.641  54.224  1
490950  93.418  -61.650  54.197  1
490951  93.459  -61.658  54.169  1
490952  93.502  -61.669  54.142  1
490953  93.545  -61.679  54.115  1
490954  93.588  -61.690  54.088  1
490955  93.628  -61.700  54.063  1
490956  93.666  -61.710  54.038  1
490957  93.704  -61.719  54.013  1
490958  93.746  -61.731  53.990  1
490959  93.787  -61.742  53.968  1
490960  93.829  -61.754  53.946  1
490961  93.870  -61.765  53.924  1
490962  93.912  -61.776  53.903  1
490963  93.954  -61.788  53.882  1
490964  93.995  -61.799  53.862  1
490965  94.037  -61.810  53.842  1
490966  94.078  -61.822  53.823  1
490967  94.120  -61.832  53.804  1
490968  94.163  -61.840  53.786  1
490969  94.205  -61.848  53.767  1
490970  94.248  -61.855  53.749  1
490971  94.290  -61.863  53.729  1
490972  94.333  -61.870  53.708  1
490973  94.376  -61.877  53.687  1
490974  94.418  -61.885  53.667  1
490975  94.461  -61.892  53.648  1
490976  94.504  -61.900  53.631  1
490977  94.546  -61.907  53.614  1
490978  94.589  -61.914  53.594  1
490979  94.627  -61.918  53.577  1
490980  94.666  -61.923  53.563  1
490981  94.702  -61.925  53.552  1
490982  94.738  -61.926  53.543  1
490983  94.773  -61.928  53.533  1
490984  94.809  -61.929  53.519  1
490985  94.844  -61.931  53.505  1
490986  94.880  -61.933  53.490  1
490987  94.915  -61.935  53.474  1
490988  94.950  -61.936  53.455  1
490989  94.986  -61.938  53.435  1
490990  95.019  -61.939  53.411  1
490991  95.047  -61.941  53.386  1
490992  95.084  -61.947  53.360  1
490993  95.121  -61.953  53.332  1
490994  95.158  -61.960  53.299  1
490995  95.195  -61.966  53.264  1
490996  95.232  -61.972  53.224  1
490997  95.269  -61.978  53.182  1
490998  95.309  -61.983  53.141  1
490999  95.349  -61.987  53.104  1
491000  95.390  -61.992  53.069  1
491001  95.431  -61.995  53.036  1
491002  95.471  -62.000  53.005  1
491003  95.512  -62.004  52.974  1
491004  95.552  -62.008  52.943  1
491005  95.597  -62.011  52.912  1
491006  95.645  -62.011  52.881  1
491007  95.692  -62.011  52.849  1
491008  95.740  -62.011  52.816  1
491009  95.804  -62.028  52.780  1
491010  95.851  -62.023  52.744  1
491011  95.888  -62.014  52.707  1
491012  95.923  -62.019  52.670  1
491013  95.958  -62.024  52.633  1
491014  95.993  -62.029  52.596  1
491015  96.028  -62.033  52.558  1
491016  96.063  -62.039  52.522  1
491017  96.098  -62.043  52.485  1
491018  96.133  -62.048  52.447  1
491019  96.168  -62.053  52.406  1
491020  96.209  -62.055  52.367  1
491021  96.252  -62.057  52.326  1
491022  96.296  -62.059  52.286  1
491023  96.339  -62.061  52.248  1
491024  96.383  -62.062  52.208  1
491025  96.426  -62.064  52.166  1
491026  96.473  -62.051  52.124  1
491027  96.526  -62.026  52.081  1
491028  96.575  -62.022  52.037  1
491029  96.616  -62.026  51.992  1
491030  96.658  -62.030  51.947  1
491031  96.699  -62.034  51.901  1
491032  96.741  -62.038  51.857  1
491033  96.783  -62.042  51.813  1
491034  96.824  -62.047  51.768  1
491035  96.864  -62.067  51.723  1
491036  96.903  -62.087  51.679  1
491037  96.941  -62.098  51.637  1
491038  96.978  -62.104  51.595  1
491039  97.017  -62.109  51.555  1
491040  97.046  -62.118  51.517  1
491041  97.075  -62.127  51.481  1
491042  97.102  -62.137  51.446  1
491043  97.131  -62.146  51.411  1
491044  97.159  -62.156  51.377  1
491045  97.186  -62.165  51.343  1
491046  97.215  -62.175  51.310  1
491047  97.243  -62.184  51.276  1
491048  97.271  -62.194  51.242  1
491049  97.299  -62.203  51.208  1
491050  97.327  -62.213  51.172  1
491051  97.355  -62.222  51.135  1
491052  97.383  -62.232  51.098  1
491053  97.411  -62.241  51.061  1
491054  97.447  -62.247  51.022  1
491055  97.514  -62.238  50.984  1
491056  97.581  -62.230  50.946  1
491057  97.648  -62.221  50.907  1
491058  97.715  -62.213  50.868  1
491059  97.748  -62.195  50.829  1
491060  97.768  -62.174  50.791  1
491061  97.801  -62.161  50.752  1
491062  97.834  -62.150  50.712  1
491063  97.883  -62.158  50.672  1
491064  97.937  -62.173  50.632  1
491065  97.955  -62.187  50.593  1
491066  97.966  -62.202  50.553  1
491067  97.990  -62.218  50.513  1
491068  98.014  -62.233  50.472  1
491069  98.038  -62.249  50.431  1
491070  98.062  -62.265  50.390  1
491071  98.086  -62.280  50.349  1
491072  98.110  -62.296  50.310  1
491073  98.135  -62.312  50.269  1
491074  98.159  -62.327  50.229  1
491075  98.183  -62.343  50.188  1
491076  98.207  -62.359  50.149  1
491077  98.231  -62.374  50.111  1
491529  88.235  -60.213  55.669  1
491530  88.287  -60.220  55.648  1
491531  88.339  -60.227  55.628  1
491532  88.391  -60.234  55.608  1
491533  88.444  -60.240  55.589  1
491534  88.495  -60.247  55.571  1
491535  88.549  -60.250  55.552  1
491536  88.608  -60.235  55.537  1
491537  88.667  -60.219  55.520  1
491538  88.726  -60.204  55.504  1
491539  88.784  -60.190  55.488  1
491540  88.841  -60.178  55.473  1
491541  88.897  -60.167  55.455  1
491542  88.948  -60.165  55.439  1
491543  88.988  -60.186  55.421  1
491544  89.018  -60.198  55.400  1
491545  89.059  -60.218  55.377  1
491546  89.102  -60.239  55.351  1
491547  89.145  -60.260  55.325  1
491548  89.187  -60.282  55.300  1
491549  89.230  -60.303  55.275  1
491550  89.273  -60.325  55.251  1
491551  89.316  -60.347  55.227  1
491552  89.358  -60.368  55.203  1
491553  89.401  -60.389  55.181  1
491554  89.444  -60.410  55.159  1
491555  89.486  -60.432  55.139  1
491556  89.529  -60.453  55.122  1
491557  89.572  -60.475  55.105  1
491558  89.615  -60.497  55.089  1
491559  89.657  -60.518  55.075  1
491560  89.700  -60.539  55.061  1
491561  89.743  -60.561  55.050  1
491562  89.786  -60.582  55.038  1
491563  89.828  -60.604  55.028  1
491564  89.871  -60.626  55.020  1
491565  89.913  -60.647  55.013  1
491566  89.956  -60.668  55.007  1
491567  89.999  -60.690  55.003  1
491568  90.042  -60.711  55.000  1
491569  90.085  -60.732  54.999  1
491570  90.130  -60.752  54.998  1
491571  90.176  -60.773  54.996  1
491572  90.218  -60.792  54.992  1
491573  90.256  -60.810  54.984  1
491574  90.295  -60.829  54.979  1
491575  90.333  -60.848  54.975  1
491576  90.371  -60.866  54.973  1
491577  90.410  -60.884  54.974  1
491578  90.448  -60.903  54.975  1
491579  90.493  -60.919  54.978  1
491580  90.541  -60.930  54.982  1
491581  90.590  -60.941  54.989  1
491582  90.639  -60.952  54.998  1
491583  90.688  -60.964  55.011  1
491584  90.737  -60.974  55.020  1
491585  90.786  -60.986  55.026  1
491586  90.835  -60.996  55.033  1
491587  90.882  -61.008  55.043  1
491588  90.921  -61.020  55.050  1
491589  90.959  -61.031  55.057  1
491590  90.998  -61.043  55.065  1
491591  91.036  -61.055  55.077  1
491592  91.075  -61.067  55.089  1
491593  91.113  -61.079  55.097  1
491594  91.152  -61.091  55.101  1
491595  91.190  -61.103  55.101  1
491596  91.229  -61.114  55.097  1
491597  91.267  -61.127  55.091  1
491598  91.306  -61.139  55.085  1
491599  91.344  -61.150  55.077  1
491600  91.383  -61.162  55.066  1
491601  91.421  -61.174  55.052  1
491602  91.460  -61.186  55.037  1
491603  91.498  -61.198  55.015  1
491604  91.538  -61.209  54.997  1
491605  91.581  -61.220  54.984  1
491606  91.623  -61.231  54.974  1
491607  91.665  -61.242  54.962  1
491608  91.707  -61.253  54.955  1
491609  91.748  -61.264  54.950  1
491610  91.790  -61.275  54.947  1
491611  91.829  -61.282  54.944  1
491612  91.869  -61.287  54.938  1
491613  91.908  -61.293  54.941  1
491614  91.947  -61.299  54.945  1
491615  91.987  -61.306  54.947  1
491616  92.025  -61.315  54.947  1
491617  92.065  -61.323  54.943  1
491618  92.103  -61.331  54.928  1
491619  92.144  -61.340  54.899  1
491620  92.192  -61.353  54.865  1
491621  92.239  -61.365  54.832  1
491622  92.287  -61.377  54.809  1
491623  92.334  -61.390  54.808  1
491624  92.382  -61.402  54.805  1
491625  92.429  -61.415  54.792  1
491626  92.477  -61.427  54.769  1
491627  92.525  -61.440  54.734  1
491628  92.572  -61.451  54.699  1
491629  92.610  -61.457  54.681  1
491630  92.648  -61.463  54.668  1
491631  92.687  -61.469  54.656  1
491632  92.725  -61.475  54.642  1
491633  92.764  -61.481  54.623  1
491634  92.802  -61.487  54.602  1
491635  92.841  -61.493  54.574  1
491636  92.877  -61.500  54.544  1
491637  92.912  -61.506  54.519  1
491638  92.947  -61.513  54.512  1
491639  92.982  -61.521  54.509  1
491640  93.017  -61.528  54.501  1
491641  93.052  -61.534  54.487  1
491642  93.087  -61.541  54.466  1
491643  93.122  -61.549  54.438  1
491644  93.156  -61.556  54.403  1
491645  93.191  -61.563  54.370  1
491646  93.226  -61.569  54.339  1
491647  93.264  -61.577  54.309  1
491648  93.304  -61.585  54.280  1
491649  93.345  -61.594  54.254  1
491650  93.386  -61.602  54.228  1
491651  93.427  -61.610  54.202  1
491652  93.468  -61.619  54.176  1
491653  93.508  -61.628  54.150  1
491654  93.549  -61.636  54.123  1
491655  93.591  -61.646  54.098  1
491656  93.635  -61.656  54.074  1
491657  93.673  -61.666  54.049  1
491658  93.713  -61.677  54.023  1
491659  93.755  -61.688  53.998  1
491660  93.796  -61.700  53.973  1
491661  93.838  -61.711  53.949  1
491662  93.880  -61.722  53.927  1
491663  93.921  -61.734  53.906  1
491664  93.963  -61.745  53.885  1
491665  94.004  -61.757  53.865  1
491666  94.046  -61.768  53.845  1
491667  94.087  -61.779  53.825  1
491668  94.129  -61.790  53.807  1
491669  94.171  -61.799  53.788  1
491670  94.213  -61.807  53.769  1
491671  94.256  -61.813  53.751  1
491672  94.299  -61.821  53.731  1
491673  94.342  -61.829  53.710  1
491674  94.384  -61.836  53.689  1
491675  94.427  -61.844  53.669  1
491676  94.470  -61.851  53.651  1
491677  94.512  -61.859  53.634  1
491678  94.555  -61.866  53.619  1
491679  94.595  -61.871  53.600  1
491680  94.633  -61.875  53.583  1
491681  94.672  -61.879  53.570  1
491682  94.708  -61.881  53.560  1
491683  94.744  -61.882  53.552  1
491684  94.779  -61.885  53.543  1
491685  94.815  -61.886  53.533  1
491686  94.850  -61.888  53.522  1
491687  94.886  -61.889  53.510  1
491688  94.921  -61.891  53.496  1
491689  94.956  -61.892  53.479  1
491690  94.991  -61.895  53.460  1
491691  95.027  -61.896  53.438  1
491692  95.062  -61.898  53.414  1
491693  95.102  -61.903  53.388  1
491694  95.140  -61.909  53.360  1
491695  95.178  -61.915  53.328  1
491696  95.214  -61.921  53.293  1
491697  95.252  -61.927  53.255  1
491698  95.289  -61.933  53.214  1
491699  95.326  -61.939  53.173  1
491700  95.364  -61.945  53.131  1
491701  95.404  -61.949  53.091  1
491702  95.445  -61.954  53.053  1
491703  95.486  -61.958  53.018  1
491704  95.526  -61.962  52.982  1
491705  95.567  -61.967  52.949  1
491706  95.614  -61.967  52.916  1
491707  95.662  -61.967  52.882  1
491708  95.710  -61.967  52.848  1
491709  95.758  -61.967  52.814  1
491710  95.820  -61.982  52.777  1
491711  95.858  -61.970  52.740  1
491712  95.893  -61.974  52.703  1
491713  95.927  -61.979  52.666  1
491714  95.963  -61.984  52.629  1
491715  95.998  -61.989  52.592  1
491716  96.033  -61.993  52.553  1
491717  96.068  -61.998  52.516  1
491718  96.103  -62.003  52.479  1
491719  96.138  -62.008  52.442  1
491720  96.173  -62.013  52.405  1
491721  96.212  -62.016  52.369  1
491722  96.255  -62.017  52.331  1
491723  96.299  -62.020  52.293  1
491724  96.342  -62.021  52.255  1
491725  96.386  -62.023  52.214  1
491726  96.429  -62.024  52.172  1
491727  96.472  -62.026  52.128  1
491728  96.521  -62.015  52.084  1
491729  96.573  -62.008  52.040  1
491730  96.614  -62.012  51.995  1
491731  96.656  -62.016  51.950  1
491732  96.697  -62.020  51.904  1
491733  96.739  -62.024  51.860  1
491734  96.780  -62.028  51.816  1
491735  96.822  -62.032  51.771  1
491736  96.863  -62.036  51.727  1
491737  96.905  -62.040  51.684  1
491738  96.946  -62.044  51.641  1
491739  96.985  -62.056  51.599  1
491740  97.013  -62.066  51.559  1
491741  97.041  -62.075  51.520  1
491742  97.069  -62.085  51.484  1
491743  97.097  -62.094  51.449  1
491744  97.125  -62.104  51.414  1
491745  97.153  -62.113  51.380  1
491746  97.181  -62.123  51.345  1
491747  97.209  -62.132  51.312  1
491748  97.237  -62.142  51.279  1
491749  97.265  -62.151  51.245  1
491750  97.293  -62.161  51.210  1
491751  97.321  -62.170  51.175  1
491752  97.349  -62.180  51.138  1
491753  97.377  -62.189  51.101  1
491754  97.405  -62.199  51.063  1
491755  97.448  -62.201  51.024  1
491756  97.516  -62.192  50.986  1
491757  97.583  -62.184  50.947  1
491758  97.650  -62.176  50.908  1
491759  97.717  -62.167  50.869  1
491760  97.755  -62.150  50.829  1
491761  97.776  -62.130  50.790  1
491762  97.809  -62.118  50.751  1
491763  97.844  -62.108  50.711  1
491764  97.897  -62.122  50.670  1
491765  97.937  -62.136  50.630  1
491766  97.947  -62.152  50.592  1
491767  97.967  -62.167  50.551  1
491768  97.992  -62.183  50.510  1
491769  98.016  -62.199  50.470  1
491770  98.040  -62.214  50.429  1
491771  98.064  -62.230  50.388  1
491772  98.088  -62.246  50.348  1
491773  98.112  -62.261  50.308  1
491774  98.137  -62.277  50.268  1
491775  98.161  -62.292  50.227  1
491776  98.185  -62.308  50.187  1
491777  98.209  -62.324  50.147  1
492231  88.314  -60.176  55.639  1
492232  88.366  -60.183  55.619  1
492233  88.418  -60.190  55.599  1
492234  88.470  -60.196  55.580  1
492235  88.522  -60.203  55.561  1
492236  88.577  -60.202  55.542  1
492237  88.636  -60.187  55.526  1
492238  88.695  -60.171  55.510  1
492239  88.754  -60.155  55.494  1
492240  88.812  -60.143  55.477  1
492241  88.868  -60.131  55.461  1
492242  88.924  -60.120  55.443  1
492243  88.968  -60.134  55.428  1
492244  89.008  -60.153  55.410  1
492245  89.032  -60.165  55.390  1
492246  89.073  -60.181  55.368  1
492247  89.116  -60.202  55.344  1
492248  89.159  -60.224  55.319  1
492249  89.201  -60.245  55.295  1
492250  89.244  -60.267  55.271  1
492251  89.286  -60.288  55.247  1
492252  89.329  -60.309  55.223  1
492253  89.372  -60.331  55.201  1
492254  89.415  -60.353  55.179  1
492255  89.457  -60.374  55.158  1
492256  89.500  -60.395  55.138  1
492257  89.543  -60.417  55.121  1
492258  89.586  -60.438  55.104  1
492259  89.628  -60.459  55.090  1
492260  89.671  -60.481  55.075  1
492261  89.713  -60.503  55.061  1
492262  89.756  -60.524  55.049  1
492263  89.799  -60.546  55.039  1
492264  89.842  -60.567  55.028  1
492265  89.885  -60.588  55.019  1
492266  89.927  -60.610  55.010  1
492267  89.970  -60.632  55.004  1
492268  90.013  -60.653  55.000  1
492269  90.055  -60.674  54.995  1
492270  90.100  -60.695  54.991  1
492271  90.146  -60.715  54.990  1
492272  90.191  -60.735  54.988  1
492273  90.236  -60.755  54.986  1
492274  90.274  -60.773  54.980  1
492275  90.312  -60.792  54.975  1
492276  90.351  -60.810  54.971  1
492277  90.389  -60.829  54.970  1
492278  90.428  -60.848  54.970  1
492279  90.466  -60.866  54.972  1
492280  90.511  -60.882  54.975  1
492281  90.559  -60.895  54.979  1
492282  90.608  -60.906  54.984  1
492283  90.657  -60.917  54.992  1
492284  90.706  -60.929  55.004  1
492285  90.755  -60.939  55.016  1
492286  90.804  -60.951  55.025  1
492287  90.853  -60.961  55.033  1
492288  90.895  -60.973  55.041  1
492289  90.934  -60.985  55.046  1
492290  90.972  -60.997  55.052  1
492291  91.011  -61.009  55.060  1
492292  91.049  -61.020  55.073  1
492293  91.088  -61.033  55.086  1
492294  91.127  -61.045  55.096  1
492295  91.165  -61.056  55.103  1
492296  91.204  -61.068  55.107  1
492297  91.242  -61.080  55.107  1
492298  91.281  -61.092  55.103  1
492299  91.319  -61.104  55.096  1
492300  91.358  -61.116  55.087  1
492301  91.396  -61.127  55.075  1
492302  91.435  -61.139  55.060  1
492303  91.473  -61.152  55.044  1
492304  91.512  -61.163  55.024  1
492305  91.550  -61.175  55.005  1
492306  91.590  -61.187  54.989  1
492307  91.632  -61.198  54.976  1
492308  91.675  -61.208  54.960  1
492309  91.717  -61.219  54.946  1
492310  91.758  -61.230  54.935  1
492311  91.799  -61.241  54.929  1
492312  91.839  -61.246  54.927  1
492313  91.878  -61.252  54.926  1
492314  91.917  -61.259  54.931  1
492315  91.956  -61.266  54.934  1
492316  91.995  -61.274  54.935  1
492317  92.034  -61.282  54.935  1
492318  92.073  -61.290  54.932  1
492319  92.112  -61.299  54.920  1
492320  92.151  -61.306  54.896  1
492321  92.195  -61.318  54.865  1
492322  92.243  -61.330  54.833  1
492323  92.291  -61.342  54.808  1
492324  92.338  -61.355  54.807  1
492325  92.386  -61.367  54.804  1
492326  92.433  -61.380  54.793  1
492327  92.481  -61.392  54.771  1
492328  92.528  -61.405  54.739  1
492329  92.574  -61.416  54.702  1
492330  92.613  -61.422  54.677  1
492331  92.651  -61.428  54.663  1
492332  92.690  -61.434  54.653  1
492333  92.728  -61.440  54.641  1
492334  92.767  -61.446  54.619  1
492335  92.805  -61.452  54.596  1
492336  92.844  -61.458  54.566  1
492337  92.882  -61.463  54.540  1
492338  92.920  -61.469  54.526  1
492339  92.958  -61.475  54.529  1
492340  92.994  -61.482  54.524  1
492341  93.029  -61.489  54.511  1
492342  93.064  -61.497  54.490  1
492343  93.099  -61.503  54.464  1
492344  93.134  -61.510  54.431  1
492345  93.169  -61.517  54.398  1
492346  93.204  -61.524  54.367  1
492347  93.239  -61.531  54.338  1
492348  93.274  -61.538  54.310  1
492349  93.313  -61.547  54.284  1
492350  93.354  -61.555  54.261  1
492351  93.395  -61.563  54.238  1
492352  93.436  -61.572  54.216  1
492353  93.477  -61.580  54.194  1
492354  93.517  -61.588  54.170  1
492355  93.558  -61.597  54.143  1
492356  93.599  -61.605  54.119  1
492357  93.640  -61.613  54.096  1
492358  93.681  -61.623  54.070  1
492359  93.722  -61.635  54.043  1
492360  93.764  -61.646  54.016  1
492361  93.805  -61.657  53.989  1
492362  93.847  -61.669  53.962  1
492363  93.888  -61.680  53.938  1
492364  93.930  -61.691  53.916  1
492365  93.971  -61.703  53.895  1
492366  94.013  -61.714  53.874  1
492367  94.054  -61.726  53.854  1
492368  94.096  -61.737  53.834  1
492369  94.137  -61.747  53.814  1
492370  94.180  -61.757  53.795  1
492371  94.222  -61.765  53.775  1
492372  94.265  -61.773  53.755  1
492373  94.308  -61.780  53.734  1
492374  94.350  -61.788  53.712  1
492375  94.393  -61.795  53.692  1
492376  94.435  -61.802  53.673  1
492377  94.478  -61.810  53.655  1
492378  94.521  -61.817  53.639  1
492379  94.562  -61.823  53.624  1
492380  94.601  -61.828  53.605  1
492381  94.639  -61.832  53.589  1
492382  94.678  -61.835  53.576  1
492383  94.714  -61.838  53.566  1
492384  94.750  -61.839  53.559  1
492385  94.785  -61.841  53.551  1
492386  94.821  -61.842  53.543  1
492387  94.856  -61.844  53.534  1
492388  94.891  -61.846  53.524  1
492389  94.927  -61.848  53.512  1
492390  94.962  -61.849  53.496  1
492391  94.997  -61.851  53.478  1
492392  95.033  -61.853  53.456  1
492393  95.069  -61.860  53.432  1
492394  95.107  -61.866  53.406  1
492395  95.148  -61.870  53.378  1
492396  95.189  -61.874  53.346  1
492397  95.230  -61.879  53.312  1
492398  95.270  -61.883  53.275  1
492399  95.309  -61.888  53.236  1
492400  95.345  -61.895  53.196  1
492401  95.383  -61.901  53.153  1
492402  95.420  -61.907  53.111  1
492403  95.459  -61.912  53.071  1
492404  95.500  -61.916  53.033  1
492405  95.541  -61.920  52.995  1
492406  95.584  -61.923  52.959  1
492407  95.632  -61.923  52.923  1
492408  95.680  -61.923  52.887  1
492409  95.728  -61.923  52.851  1
492410  95.775  -61.924  52.815  1
492411  95.827  -61.926  52.777  1
492412  95.863  -61.929  52.739  1
492413  95.897  -61.934  52.701  1
492414  95.933  -61.939  52.664  1
492415  95.967  -61.944  52.626  1
492416  96.003  -61.948  52.590  1
492417  96.037  -61.953  52.552  1
492418  96.073  -61.958  52.515  1
492419  96.108  -61.963  52.478  1
492420  96.143  -61.967  52.443  1
492421  96.178  -61.973  52.408  1
492422  96.215  -61.976  52.374  1
492423  96.258  -61.978  52.337  1
492424  96.302  -61.979  52.299  1
492425  96.345  -61.982  52.260  1
492426  96.389  -61.983  52.219  1
492427  96.432  -61.985  52.176  1
492428  96.475  -61.987  52.133  1
492429  96.519  -61.984  52.088  1
492430  96.568  -61.978  52.043  1
492431  96.609  -61.981  51.997  1
492432  96.651  -61.984  51.952  1
492433  96.692  -61.988  51.908  1
492434  96.734  -61.992  51.864  1
492435  96.775  -61.996  51.821  1
492436  96.816  -62.001  51.777  1
492437  96.857  -62.007  51.735  1
492438  96.897  -62.011  51.691  1
492439  96.939  -62.017  51.647  1
492440  96.974  -62.022  51.606  1
492441  97.005  -62.027  51.566  1
492442  97.035  -62.033  51.527  1
492443  97.064  -62.042  51.489  1
492444  97.092  -62.051  51.454  1
492445  97.119  -62.061  51.419  1
492446  97.148  -62.070  51.384  1
492447  97.176  -62.080  51.350  1
492448  97.204  -62.089  51.317  1
492449  97.232  -62.098  51.284  1
492450  97.260  -62.108  51.250  1
492451  97.288  -62.117  51.216  1
492452  97.316  -62.127  51.180  1
492453  97.344  -62.136  51.143  1
492454  97.372  -62.146  51.105  1
492455  97.400  -62.155  51.067  1
492456  97.450  -62.155  51.028  1
492457  97.517  -62.146  50.989  1
492458  97.584  -62.138  50.950  1
492459  97.651  -62.130  50.910  1
492460  97.718  -62.121  50.870  1
492461  97.763  -62.106  50.831  1
492462  97.784  -62.086  50.791  1
492463  97.817  -62.074  50.752  1
492464  97.858  -62.072  50.711  1
492465  97.911  -62.086  50.670  1
492466  97.929  -62.101  50.630  1
492467  97.945  -62.117  50.591  1
492468  97.969  -62.132  50.550  1
492469  97.993  -62.148  50.509  1
492470  98.017  -62.163  50.469  1
492471  98.041  -62.179  50.427  1
492472  98.066  -62.195  50.386  1
492473  98.090  -62.210  50.347  1
492474  98.114  -62.226  50.308  1
492475  98.138  -62.241  50.267  1
492476  98.162  -62.257  50.227  1
492477  98.186  -62.273  50.186  1
492933  88.393  -60.139  55.611  1
492934  88.445  -60.146  55.591  1
492935  88.497  -60.152  55.571  1
492936  88.549  -60.159  55.552  1
492937  88.605  -60.154  55.533  1
492938  88.664  -60.139  55.516  1
492939  88.723  -60.123  55.500  1
492940  88.782  -60.108  55.484  1
492941  88.839  -60.096  55.467  1
492942  88.895  -60.085  55.450  1
492943  88.947  -60.081  55.433  1
492944  88.987  -60.102  55.417  1
492945  89.027  -60.121  55.399  1
492946  89.047  -60.133  55.380  1
492947  89.088  -60.147  55.359  1
492948  89.129  -60.165  55.335  1
492949  89.172  -60.187  55.312  1
492950  89.215  -60.209  55.289  1
492951  89.257  -60.230  55.266  1
492952  89.300  -60.251  55.243  1
492953  89.343  -60.273  55.220  1
492954  89.386  -60.294  55.199  1
492955  89.428  -60.315  55.177  1
492956  89.471  -60.337  55.156  1
492957  89.514  -60.359  55.137  1
492958  89.556  -60.380  55.121  1
492959  89.599  -60.402  55.105  1
492960  89.642  -60.423  55.090  1
492961  89.685  -60.444  55.076  1
492962  89.727  -60.466  55.063  1
492963  89.770  -60.488  55.051  1
492964  89.813  -60.509  55.040  1
492965  89.856  -60.530  55.030  1
492966  89.898  -60.552  55.020  1
492967  89.941  -60.573  55.012  1
492968  89.983  -60.594  55.005  1
492969  90.026  -60.616  54.999  1
492970  90.070  -60.637  54.994  1
492971  90.115  -60.657  54.992  1
492972  90.161  -60.678  54.991  1
492973  90.206  -60.698  54.990  1
492974  90.252  -60.718  54.987  1
492975  90.292  -60.737  54.980  1
492976  90.330  -60.755  54.974  1
492977  90.369  -60.774  54.971  1
492978  90.407  -60.792  54.968  1
492979  90.446  -60.810  54.967  1
492980  90.485  -60.829  54.969  1
492981  90.530  -60.845  54.973  1
492982  90.577  -60.861  54.977  1
492983  90.625  -60.871  54.981  1
492984  90.674  -60.882  54.988  1
492985  90.723  -60.893  54.998  1
492986  90.772  -60.904  55.011  1
492987  90.821  -60.916  55.023  1
492988  90.870  -60.926  55.033  1
492989  90.908  -60.939  55.040  1
492990  90.947  -60.951  55.044  1
492991  90.986  -60.962  55.049  1
492992  91.024  -60.974  55.057  1
492993  91.063  -60.986  55.068  1
492994  91.101  -60.998  55.080  1
492995  91.140  -61.010  55.091  1
492996  91.178  -61.022  55.100  1
492997  91.217  -61.033  55.107  1
492998  91.255  -61.045  55.109  1
492999  91.294  -61.058  55.107  1
493000  91.332  -61.069  55.100  1
493001  91.371  -61.081  55.092  1
493002  91.410  -61.093  55.082  1
493003  91.448  -61.105  55.069  1
493004  91.487  -61.117  55.053  1
493005  91.525  -61.129  55.034  1
493006  91.564  -61.140  55.014  1
493007  91.602  -61.152  54.996  1
493008  91.642  -61.164  54.980  1
493009  91.684  -61.175  54.964  1
493010  91.726  -61.186  54.944  1
493011  91.768  -61.197  54.927  1
493012  91.808  -61.206  54.915  1
493013  91.848  -61.212  54.912  1
493014  91.887  -61.218  54.917  1
493015  91.926  -61.225  54.923  1
493016  91.965  -61.233  54.925  1
493017  92.004  -61.242  54.925  1
493018  92.043  -61.250  54.924  1
493019  92.082  -61.258  54.922  1
493020  92.121  -61.266  54.912  1
493021  92.160  -61.274  54.892  1
493022  92.199  -61.283  54.864  1
493023  92.247  -61.295  54.833  1
493024  92.294  -61.307  54.811  1
493025  92.342  -61.320  54.810  1
493026  92.389  -61.332  54.806  1
493027  92.437  -61.345  54.795  1
493028  92.485  -61.357  54.775  1
493029  92.532  -61.370  54.746  1
493030  92.577  -61.381  54.711  1
493031  92.616  -61.386  54.677  1
493032  92.654  -61.392  54.653  1
493033  92.693  -61.398  54.640  1
493034  92.731  -61.404  54.627  1
493035  92.770  -61.410  54.608  1
493036  92.808  -61.416  54.582  1
493037  92.846  -61.422  54.555  1
493038  92.885  -61.428  54.538  1
493039  92.923  -61.434  54.538  1
493040  92.961  -61.440  54.539  1
493041  93.000  -61.446  54.531  1
493042  93.039  -61.452  54.514  1
493043  93.077  -61.458  54.489  1
493044  93.112  -61.465  54.459  1
493045  93.146  -61.472  54.425  1
493046  93.182  -61.479  54.395  1
493047  93.216  -61.486  54.367  1
493048  93.251  -61.493  54.341  1
493049  93.286  -61.500  54.315  1
493050  93.322  -61.507  54.293  1
493051  93.363  -61.516  54.275  1
493052  93.404  -61.524  54.256  1
493053  93.444  -61.532  54.236  1
493054  93.485  -61.541  54.216  1
493055  93.526  -61.549  54.192  1
493056  93.567  -61.557  54.164  1
493057  93.608  -61.566  54.139  1
493058  93.648  -61.576  54.115  1
493059  93.688  -61.586  54.089  1
493060  93.731  -61.592  54.062  1
493061  93.773  -61.603  54.035  1
493062  93.814  -61.615  54.008  1
493063  93.856  -61.626  53.981  1
493064  93.897  -61.638  53.955  1
493065  93.939  -61.649  53.930  1
493066  93.980  -61.660  53.909  1
493067  94.022  -61.672  53.887  1
493068  94.063  -61.683  53.866  1
493069  94.105  -61.694  53.844  1
493070  94.146  -61.706  53.823  1
493071  94.188  -61.716  53.802  1
493072  94.231  -61.724  53.782  1
493073  94.273  -61.732  53.761  1
493074  94.316  -61.738  53.740  1
493075  94.359  -61.746  53.721  1
493076  94.402  -61.754  53.701  1
493077  94.444  -61.761  53.682  1
493078  94.487  -61.769  53.664  1
493079  94.530  -61.776  53.647  1
493080  94.568  -61.780  53.630  1
493081  94.607  -61.784  53.613  1
493082  94.645  -61.788  53.594  1
493083  94.684  -61.792  53.580  1
493084  94.720  -61.794  53.570  1
493085  94.756  -61.796  53.562  1
493086  94.791  -61.798  53.554  1
493087  94.827  -61.799  53.546  1
493088  94.862  -61.801  53.538  1
493089  94.897  -61.802  53.529  1
493090  94.933  -61.804  53.518  1
493091  94.968  -61.805  53.504  1
493092  95.003  -61.807  53.486  1
493093  95.040  -61.815  53.464  1
493094  95.076  -61.822  53.439  1
493095  95.114  -61.828  53.413  1
493096  95.154  -61.833  53.385  1
493097  95.194  -61.837  53.354  1
493098  95.235  -61.841  53.322  1
493099  95.276  -61.846  53.288  1
493100  95.317  -61.850  53.250  1
493101  95.357  -61.854  53.212  1
493102  95.398  -61.858  53.170  1
493103  95.439  -61.863  53.129  1
493104  95.476  -61.869  53.088  1
493105  95.514  -61.874  53.048  1
493106  95.555  -61.879  53.008  1
493107  95.602  -61.879  52.971  1
493108  95.650  -61.879  52.932  1
493109  95.697  -61.880  52.894  1
493110  95.745  -61.880  52.855  1
493111  95.795  -61.883  52.818  1
493112  95.832  -61.884  52.778  1
493113  95.867  -61.889  52.739  1
493114  95.902  -61.894  52.701  1
493115  95.937  -61.898  52.663  1
493116  95.972  -61.904  52.626  1
493117  96.007  -61.908  52.590  1
493118  96.042  -61.913  52.552  1
493119  96.077  -61.918  52.515  1
493120  96.112  -61.923  52.479  1
493121  96.147  -61.927  52.446  1
493122  96.182  -61.932  52.416  1
493123  96.218  -61.937  52.384  1
493124  96.261  -61.939  52.348  1
493125  96.305  -61.940  52.308  1
493126  96.348  -61.942  52.267  1
493127  96.392  -61.944  52.225  1
493128  96.435  -61.945  52.182  1
493129  96.478  -61.942  52.138  1
493130  96.522  -61.938  52.094  1
493131  96.564  -61.939  52.049  1
493132  96.602  -61.945  52.003  1
493133  96.643  -61.951  51.958  1
493134  96.683  -61.956  51.915  1
493135  96.724  -61.961  51.872  1
493136  96.765  -61.966  51.830  1
493137  96.806  -61.971  51.788  1
493138  96.847  -61.976  51.745  1
493139  96.887  -61.982  51.703  1
493140  96.928  -61.987  51.661  1
493141  96.962  -61.992  51.619  1
493142  96.993  -61.997  51.578  1
493143  97.023  -62.002  51.538  1
493144  97.053  -62.007  51.501  1
493145  97.084  -62.011  51.464  1
493146  97.114  -62.018  51.429  1
493147  97.142  -62.027  51.394  1
493148  97.170  -62.037  51.361  1
493149  97.198  -62.046  51.327  1
493150  97.226  -62.056  51.293  1
493151  97.254  -62.065  51.259  1
493152  97.282  -62.075  51.224  1
493153  97.310  -62.084  51.187  1
493154  97.338  -62.094  51.149  1
493155  97.366  -62.103  51.111  1
493156  97.394  -62.113  51.073  1
493157  97.451  -62.109  51.034  1
493158  97.518  -62.101  50.994  1
493159  97.585  -62.092  50.954  1
493160  97.652  -62.083  50.914  1
493161  97.719  -62.075  50.873  1
493162  97.770  -62.062  50.834  1
493163  97.792  -62.042  50.794  1
493164  97.825  -62.030  50.753  1
493165  97.872  -62.036  50.713  1
493166  97.911  -62.051  50.672  1
493167  97.923  -62.065  50.631  1
493168  97.947  -62.081  50.591  1
493169  97.971  -62.097  50.551  1
493170  97.995  -62.112  50.510  1
493171  98.019  -62.128  50.469  1
493172  98.043  -62.143  50.428  1
493173  98.068  -62.159  50.387  1
493174  98.092  -62.175  50.347  1
493175  98.116  -62.190  50.307  1
493176  98.140  -62.206  50.268  1
493177  98.164  -62.221  50.228  1
493178  98.189  -62.237  50.188  1
493635  88.472  -60.102  55.585  1
493636  88.524  -60.108  55.565  1
493637  88.575  -60.115  55.544  1
493638  88.633  -60.106  55.525  1
493639  88.692  -60.090  55.507  1
493640  88.751  -60.074  55.491  1
493641  88.810  -60.061  55.474  1
493642  88.866  -60.049  55.457  1
493643  88.922  -60.038  55.440  1
493644  88.967  -60.049  55.423  1
493645  89.006  -60.069  55.407  1
493646  89.047  -60.090  55.389  1
493647  89.064  -60.100  55.371  1
493648  89.103  -60.115  55.351  1
493649  89.143  -60.129  55.328  1
493650  89.186  -60.150  55.305  1
493651  89.229  -60.171  55.283  1
493652  89.271  -60.193  55.261  1
493653  89.314  -60.215  55.240  1
493654  89.356  -60.236  55.218  1
493655  89.399  -60.258  55.196  1
493656  89.442  -60.279  55.175  1
493657  89.485  -60.300  55.156  1
493658  89.527  -60.322  55.138  1
493659  89.570  -60.343  55.121  1
493660  89.613  -60.365  55.106  1
493661  89.656  -60.387  55.091  1
493662  89.698  -60.408  55.077  1
493663  89.741  -60.429  55.065  1
493664  89.783  -60.450  55.053  1
493665  89.826  -60.472  55.042  1
493666  89.869  -60.494  55.032  1
493667  89.912  -60.515  55.023  1
493668  89.954  -60.537  55.015  1
493669  89.997  -60.558  55.007  1
493670  90.040  -60.579  55.000  1
493671  90.085  -60.600  54.996  1
493672  90.130  -60.620  54.994  1
493673  90.176  -60.640  54.995  1
493674  90.222  -60.660  54.997  1
493675  90.267  -60.680  54.994  1
493676  90.310  -60.700  54.986  1
493677  90.348  -60.719  54.978  1
493678  90.387  -60.737  54.972  1
493679  90.425  -60.755  54.968  1
493680  90.463  -60.774  54.968  1
493681  90.504  -60.792  54.969  1
493682  90.549  -60.808  54.971  1
493683  90.595  -60.824  54.976  1
493684  90.643  -60.836  54.981  1
493685  90.692  -60.848  54.987  1
493686  90.741  -60.858  54.995  1
493687  90.790  -60.870  55.006  1
493688  90.838  -60.881  55.020  1
493689  90.883  -60.892  55.033  1
493690  90.922  -60.904  55.040  1
493691  90.960  -60.916  55.044  1
493692  90.999  -60.928  55.048  1
493693  91.037  -60.939  55.054  1
493694  91.076  -60.951  55.062  1
493695  91.114  -60.964  55.072  1
493696  91.153  -60.975  55.084  1
493697  91.191  -60.987  55.094  1
493698  91.230  -60.999  55.102  1
493699  91.269  -61.011  55.106  1
493700  91.307  -61.023  55.105  1
493701  91.346  -61.035  55.100  1
493702  91.384  -61.046  55.093  1
493703  91.423  -61.058  55.085  1
493704  91.461  -61.071  55.075  1
493705  91.500  -61.082  55.061  1
493706  91.538  -61.094  55.045  1
493707  91.577  -61.106  55.025  1
493708  91.615  -61.118  55.005  1
493709  91.654  -61.130  54.984  1
493710  91.693  -61.141  54.963  1
493711  91.736  -61.152  54.942  1
493712  91.777  -61.163  54.922  1
493713  91.817  -61.171  54.908  1
493714  91.857  -61.177  54.903  1
493715  91.895  -61.185  54.910  1
493716  91.935  -61.193  54.917  1
493717  91.974  -61.201  54.921  1
493718  92.013  -61.209  54.920  1
493719  92.052  -61.218  54.917  1
493720  92.090  -61.225  54.914  1
493721  92.130  -61.233  54.904  1
493722  92.168  -61.242  54.885  1
493723  92.208  -61.250  54.860  1
493724  92.250  -61.260  54.832  1
493725  92.298  -61.273  54.816  1
493726  92.346  -61.285  54.815  1
493727  92.393  -61.297  54.809  1
493728  92.441  -61.310  54.796  1
493729  92.489  -61.322  54.777  1
493730  92.536  -61.335  54.750  1
493731  92.580  -61.345  54.717  1
493732  92.619  -61.351  54.680  1
493733  92.657  -61.356  54.649  1
493734  92.696  -61.362  54.628  1
493735  92.734  -61.368  54.610  1
493736  92.772  -61.375  54.590  1
493737  92.811  -61.381  54.564  1
493738  92.849  -61.387  54.542  1
493739  92.887  -61.393  54.533  1
493740  92.926  -61.399  54.539  1
493741  92.965  -61.404  54.536  1
493742  93.003  -61.410  54.525  1
493743  93.041  -61.416  54.504  1
493744  93.080  -61.422  54.477  1
493745  93.118  -61.428  54.449  1
493746  93.156  -61.434  54.423  1
493747  93.194  -61.440  54.397  1
493748  93.229  -61.447  54.373  1
493749  93.264  -61.454  54.352  1
493750  93.298  -61.462  54.336  1
493751  93.334  -61.469  54.320  1
493752  93.372  -61.476  54.305  1
493753  93.413  -61.484  54.287  1
493754  93.453  -61.493  54.265  1
493755  93.494  -61.501  54.240  1
493756  93.535  -61.510  54.211  1
493757  93.575  -61.519  54.182  1
493758  93.616  -61.530  54.154  1
493759  93.655  -61.541  54.128  1
493760  93.696  -61.551  54.103  1
493761  93.738  -61.557  54.079  1
493762  93.781  -61.564  54.056  1
493763  93.823  -61.572  54.031  1
493764  93.864  -61.584  54.004  1
493765  93.906  -61.595  53.976  1
493766  93.947  -61.606  53.948  1
493767  93.989  -61.618  53.925  1
493768  94.031  -61.629  53.901  1
493769  94.072  -61.641  53.877  1
493770  94.114  -61.652  53.854  1
493771  94.155  -61.663  53.833  1
493772  94.197  -61.674  53.811  1
493773  94.240  -61.682  53.790  1
493774  94.282  -61.690  53.770  1
493775  94.325  -61.697  53.750  1
493776  94.367  -61.705  53.732  1
493777  94.410  -61.713  53.713  1
493778  94.453  -61.720  53.695  1
493779  94.495  -61.727  53.676  1
493780  94.536  -61.732  53.658  1
493781  94.574  -61.737  53.640  1
493782  94.613  -61.741  53.620  1
493783  94.652  -61.744  53.601  1
493784  94.690  -61.748  53.584  1
493785  94.726  -61.751  53.572  1
493786  94.762  -61.752  53.561  1
493787  94.797  -61.754  53.552  1
493788  94.833  -61.755  53.544  1
493789  94.868  -61.757  53.534  1
493790  94.903  -61.759  53.524  1
493791  94.938  -61.760  53.513  1
493792  94.974  -61.763  53.499  1
493793  95.011  -61.769  53.481  1
493794  95.046  -61.777  53.459  1
493795  95.083  -61.784  53.434  1
493796  95.121  -61.789  53.408  1
493797  95.159  -61.795  53.380  1
493798  95.200  -61.800  53.351  1
493799  95.241  -61.804  53.320  1
493800  95.281  -61.809  53.287  1
493801  95.322  -61.813  53.252  1
493802  95.363  -61.817  53.215  1
493803  95.403  -61.821  53.177  1
493804  95.444  -61.826  53.137  1
493805  95.485  -61.829  53.098  1
493806  95.526  -61.834  53.061  1
493807  95.565  -61.838  53.023  1
493808  95.613  -61.838  52.984  1
493809  95.660  -61.839  52.943  1
493810  95.707  -61.839  52.901  1
493811  95.754  -61.840  52.861  1
493812  95.796  -61.842  52.822  1
493813  95.834  -61.845  52.781  1
493814  95.872  -61.849  52.741  1
493815  95.907  -61.854  52.703  1
493816  95.942  -61.858  52.665  1
493817  95.977  -61.863  52.627  1
493818  96.012  -61.868  52.590  1
493819  96.047  -61.873  52.553  1
493820  96.082  -61.878  52.516  1
493821  96.117  -61.882  52.482  1
493822  96.152  -61.887  52.452  1
493823  96.187  -61.892  52.425  1
493824  96.222  -61.897  52.395  1
493825  96.264  -61.899  52.359  1
493826  96.308  -61.901  52.318  1
493827  96.352  -61.902  52.275  1
493828  96.395  -61.903  52.232  1
493829  96.438  -61.899  52.189  1
493830  96.480  -61.899  52.145  1
493831  96.521  -61.903  52.100  1
493832  96.562  -61.907  52.054  1
493833  96.599  -61.913  52.008  1
493834  96.636  -61.920  51.963  1
493835  96.673  -61.926  51.921  1
493836  96.714  -61.931  51.879  1
493837  96.755  -61.936  51.838  1
493838  96.796  -61.942  51.797  1
493839  96.836  -61.947  51.756  1
493840  96.877  -61.952  51.715  1
493841  96.918  -61.957  51.674  1
493842  96.949  -61.962  51.632  1
493843  96.980  -61.967  51.591  1
493844  97.011  -61.972  51.551  1
493845  97.041  -61.977  51.513  1
493846  97.072  -61.982  51.476  1
493847  97.102  -61.986  51.442  1
493848  97.133  -61.992  51.408  1
493849  97.163  -61.996  51.375  1
493850  97.192  -62.004  51.341  1
493851  97.221  -62.013  51.306  1
493852  97.249  -62.023  51.270  1
493853  97.277  -62.032  51.234  1
493854  97.305  -62.042  51.196  1
493855  97.333  -62.051  51.158  1
493856  97.361  -62.061  51.119  1
493857  97.389  -62.070  51.081  1
493858  97.452  -62.063  51.041  1
493859  97.519  -62.055  51.000  1
493860  97.586  -62.046  50.960  1
493861  97.653  -62.038  50.919  1
493862  97.720  -62.029  50.878  1
493863  97.778  -62.017  50.838  1
493864  97.800  -61.998  50.798  1
493865  97.832  -61.986  50.756  1
493866  97.885  -62.000  50.715  1
493867  97.903  -62.014  50.674  1
493868  97.924  -62.030  50.632  1
493869  97.948  -62.045  50.592  1
493870  97.972  -62.061  50.551  1
493871  97.997  -62.077  50.511  1
493872  98.021  -62.092  50.470  1
493873  98.045  -62.108  50.428  1
493874  98.069  -62.124  50.387  1
493875  98.093  -62.139  50.347  1
493876  98.118  -62.155  50.308  1
493877  98.142  -62.171  50.268  1
493878  98.166  -62.186  50.228  1
494336  88.498  -60.058  55.583  1
494337  88.550  -60.065  55.561  1
494338  88.603  -60.071  55.540  1
494339  88.661  -60.058  55.520  1
494340  88.720  -60.042  55.502  1
494341  88.779  -60.027  55.485  1
494342  88.837  -60.014  55.467  1
494343  88.893  -60.002  55.450  1
494344  88.946  -59.997  55.432  1
494345  88.986  -60.017  55.415  1
494346  89.026  -60.037  55.398  1
494347  89.066  -60.057  55.381  1
494348  89.086  -60.069  55.362  1
494349  89.118  -60.082  55.343  1
494350  89.158  -60.096  55.322  1
494351  89.199  -60.114  55.300  1
494352  89.242  -60.135  55.278  1
494353  89.285  -60.156  55.257  1
494354  89.327  -60.178  55.237  1
494355  89.370  -60.199  55.217  1
494356  89.413  -60.221  55.195  1
494357  89.456  -60.243  55.175  1
494358  89.498  -60.264  55.156  1
494359  89.541  -60.285  55.140  1
494360  89.584  -60.306  55.124  1
494361  89.626  -60.328  55.109  1
494362  89.669  -60.350  55.094  1
494363  89.712  -60.371  55.081  1
494364  89.754  -60.393  55.069  1
494365  89.797  -60.414  55.057  1
494366  89.840  -60.435  55.047  1
494367  89.883  -60.457  55.037  1
494368  89.925  -60.478  55.027  1
494369  89.968  -60.500  55.019  1
494370  90.011  -60.522  55.011  1
494371  90.054  -60.542  55.004  1
494372  90.100  -60.563  54.999  1
494373  90.146  -60.582  54.998  1
494374  90.191  -60.603  55.001  1
494375  90.237  -60.622  55.006  1
494376  90.282  -60.643  55.001  1
494377  90.327  -60.663  54.992  1
494378  90.366  -60.682  54.982  1
494379  90.404  -60.700  54.974  1
494380  90.443  -60.719  54.968  1
494381  90.481  -60.737  54.968  1
494382  90.523  -60.754  54.969  1
494383  90.569  -60.771  54.970  1
494384  90.614  -60.787  54.975  1
494385  90.661  -60.801  54.981  1
494386  90.710  -60.813  54.986  1
494387  90.758  -60.823  54.993  1
494388  90.807  -60.835  55.002  1
494389  90.856  -60.845  55.015  1
494390  90.897  -60.857  55.030  1
494391  90.935  -60.870  55.040  1
494392  90.974  -60.881  55.047  1
494393  91.012  -60.893  55.051  1
494394  91.051  -60.905  55.053  1
494395  91.089  -60.917  55.056  1
494396  91.128  -60.929  55.063  1
494397  91.166  -60.941  55.073  1
494398  91.205  -60.952  55.084  1
494399  91.243  -60.964  55.093  1
494400  91.282  -60.977  55.098  1
494401  91.320  -60.988  55.098  1
494402  91.359  -61.000  55.096  1
494403  91.397  -61.012  55.091  1
494404  91.436  -61.024  55.085  1
494405  91.474  -61.036  55.079  1
494406  91.513  -61.048  55.068  1
494407  91.552  -61.059  55.054  1
494408  91.590  -61.071  55.036  1
494409  91.629  -61.083  55.014  1
494410  91.667  -61.095  54.990  1
494411  91.706  -61.107  54.964  1
494412  91.745  -61.118  54.940  1
494413  91.787  -61.130  54.918  1
494414  91.826  -61.136  54.900  1
494415  91.865  -61.144  54.892  1
494416  91.905  -61.152  54.897  1
494417  91.943  -61.161  54.904  1
494418  91.982  -61.168  54.909  1
494419  92.021  -61.177  54.909  1
494420  92.060  -61.185  54.906  1
494421  92.099  -61.193  54.902  1
494422  92.138  -61.201  54.891  1
494423  92.177  -61.209  54.873  1
494424  92.216  -61.218  54.851  1
494425  92.255  -61.226  54.828  1
494426  92.302  -61.238  54.820  1
494427  92.350  -61.250  54.819  1
494428  92.398  -61.262  54.812  1
494429  92.445  -61.275  54.798  1
494430  92.493  -61.287  54.774  1
494431  92.540  -61.300  54.745  1
494432  92.583  -61.309  54.716  1
494433  92.622  -61.315  54.686  1
494434  92.660  -61.321  54.654  1
494435  92.699  -61.327  54.619  1
494436  92.737  -61.333  54.592  1
494437  92.775  -61.339  54.569  1
494438  92.813  -61.345  54.546  1
494439  92.852  -61.351  54.529  1
494440  92.890  -61.357  54.525  1
494441  92.929  -61.363  54.532  1
494442  92.968  -61.368  54.527  1
494443  93.006  -61.375  54.513  1
494444  93.044  -61.381  54.492  1
494445  93.082  -61.387  54.466  1
494446  93.121  -61.393  54.443  1
494447  93.159  -61.399  54.422  1
494448  93.198  -61.405  54.399  1
494449  93.236  -61.411  54.379  1
494450  93.275  -61.416  54.365  1
494451  93.311  -61.423  54.356  1
494452  93.346  -61.430  54.342  1
494453  93.381  -61.437  54.325  1
494454  93.422  -61.446  54.304  1
494455  93.463  -61.454  54.278  1
494456  93.503  -61.463  54.249  1
494457  93.543  -61.473  54.219  1
494458  93.583  -61.484  54.190  1
494459  93.623  -61.494  54.162  1
494460  93.663  -61.505  54.136  1
494461  93.703  -61.515  54.111  1
494462  93.746  -61.522  54.087  1
494463  93.788  -61.528  54.065  1
494464  93.831  -61.535  54.043  1
494465  93.873  -61.541  54.019  1
494466  93.915  -61.553  53.995  1
494467  93.957  -61.564  53.966  1
494468  93.998  -61.575  53.939  1
494469  94.040  -61.587  53.913  1
494470  94.081  -61.598  53.887  1
494471  94.123  -61.610  53.862  1
494472  94.164  -61.621  53.840  1
494473  94.206  -61.632  53.820  1
494474  94.248  -61.641  53.801  1
494475  94.290  -61.649  53.783  1
494476  94.333  -61.656  53.765  1
494477  94.376  -61.663  53.747  1
494478  94.419  -61.671  53.730  1
494479  94.461  -61.678  53.711  1
494480  94.503  -61.685  53.691  1
494481  94.542  -61.689  53.671  1
494482  94.580  -61.693  53.651  1
494483  94.619  -61.697  53.629  1
494484  94.658  -61.701  53.608  1
494485  94.697  -61.705  53.589  1
494486  94.733  -61.707  53.573  1
494487  94.768  -61.709  53.560  1
494488  94.803  -61.710  53.548  1
494489  94.838  -61.712  53.538  1
494490  94.874  -61.713  53.527  1
494491  94.909  -61.715  53.515  1
494492  94.945  -61.717  53.503  1
494493  94.981  -61.725  53.488  1
494494  95.017  -61.732  53.471  1
494495  95.053  -61.739  53.449  1
494496  95.090  -61.746  53.425  1
494497  95.128  -61.751  53.399  1
494498  95.166  -61.757  53.373  1
494499  95.204  -61.763  53.344  1
494500  95.246  -61.767  53.314  1
494501  95.287  -61.771  53.282  1
494502  95.328  -61.776  53.249  1
494503  95.368  -61.780  53.214  1
494504  95.409  -61.784  53.178  1
494505  95.450  -61.788  53.141  1
494506  95.490  -61.792  53.105  1
494507  95.529  -61.797  53.070  1
494508  95.567  -61.801  53.032  1
494509  95.612  -61.803  52.993  1
494510  95.659  -61.803  52.951  1
494511  95.706  -61.804  52.909  1
494512  95.748  -61.806  52.868  1
494513  95.788  -61.809  52.829  1
494514  95.827  -61.812  52.786  1
494515  95.865  -61.815  52.745  1
494516  95.903  -61.818  52.706  1
494517  95.941  -61.821  52.667  1
494518  95.979  -61.824  52.628  1
494519  96.017  -61.828  52.592  1
494520  96.051  -61.832  52.554  1
494521  96.087  -61.838  52.518  1
494522  96.121  -61.842  52.485  1
494523  96.157  -61.847  52.456  1
494524  96.191  -61.852  52.430  1
494525  96.227  -61.857  52.400  1
494526  96.267  -61.859  52.364  1
494527  96.311  -61.861  52.323  1
494528  96.355  -61.860  52.280  1
494529  96.397  -61.859  52.238  1
494530  96.438  -61.863  52.195  1
494531  96.479  -61.867  52.151  1
494532  96.520  -61.871  52.105  1
494533  96.560  -61.875  52.058  1
494534  96.598  -61.880  52.010  1
494535  96.635  -61.887  51.965  1
494536  96.672  -61.893  51.924  1
494537  96.708  -61.900  51.883  1
494538  96.745  -61.907  51.843  1
494539  96.786  -61.912  51.805  1
494540  96.826  -61.917  51.767  1
494541  96.867  -61.923  51.728  1
494542  96.906  -61.927  51.687  1
494543  96.937  -61.932  51.646  1
494544  96.967  -61.937  51.604  1
494545  96.998  -61.942  51.564  1
494546  97.028  -61.947  51.526  1
494547  97.059  -61.952  51.490  1
494548  97.090  -61.957  51.457  1
494549  97.120  -61.962  51.426  1
494550  97.151  -61.967  51.391  1
494551  97.181  -61.971  51.356  1
494552  97.212  -61.976  51.321  1
494553  97.242  -61.981  51.283  1
494554  97.272  -61.989  51.245  1
494555  97.299  -61.998  51.206  1
494556  97.327  -62.008  51.167  1
494557  97.356  -62.017  51.128  1
494558  97.387  -62.026  51.089  1
494559  97.454  -62.017  51.049  1
494560  97.521  -62.008  51.008  1
494561  97.588  -62.000  50.967  1
494562  97.655  -61.992  50.926  1
494563  97.722  -61.983  50.884  1
494564  97.785  -61.973  50.843  1
494565  97.807  -61.954  50.801  1
494566  97.846  -61.949  50.759  1
494567  97.885  -61.964  50.718  1
494568  97.902  -61.979  50.676  1
494569  97.926  -61.995  50.633  1
494570  97.950  -62.011  50.593  1
494571  97.974  -62.026  50.552  1
494572  97.999  -62.042  50.511  1
494573  98.023  -62.058  50.470  1
494574  98.047  -62.073  50.429  1
494575  98.071  -62.089  50.387  1
494576  98.095  -62.105  50.347  1
494577  98.120  -62.120  50.308  1
494578  98.144  -62.136  50.268  1
494579  98.168  -62.151  50.228  1
495038  88.577  -60.021  55.559  1
495039  88.630  -60.025  55.538  1
495040  88.689  -60.009  55.518  1
495041  88.748  -59.994  55.499  1
495042  88.808  -59.978  55.481  1
495043  88.863  -59.967  55.462  1
495044  88.920  -59.955  55.444  1
495045  88.966  -59.965  55.426  1
495046  89.005  -59.985  55.409  1
495047  89.046  -60.005  55.392  1
495048  89.086  -60.025  55.374  1
495049  89.107  -60.037  55.355  1
495050  89.132  -60.049  55.337  1
495051  89.173  -60.064  55.316  1
495052  89.213  -60.079  55.295  1
495053  89.256  -60.099  55.274  1
495054  89.299  -60.120  55.254  1
495055  89.341  -60.141  55.234  1
495056  89.384  -60.163  55.215  1
495057  89.426  -60.184  55.195  1
495058  89.469  -60.206  55.175  1
495059  89.512  -60.227  55.157  1
495060  89.554  -60.249  55.142  1
495061  89.597  -60.270  55.127  1
495062  89.640  -60.291  55.112  1
495063  89.683  -60.313  55.098  1
495064  89.726  -60.334  55.085  1
495065  89.768  -60.356  55.074  1
495066  89.811  -60.378  55.063  1
495067  89.853  -60.399  55.053  1
495068  89.896  -60.420  55.043  1
495069  89.939  -60.442  55.034  1
495070  89.982  -60.463  55.026  1
495071  90.024  -60.485  55.018  1
495072  90.070  -60.505  55.010  1
495073  90.115  -60.525  55.004  1
495074  90.161  -60.545  55.001  1
495075  90.206  -60.566  55.000  1
495076  90.252  -60.585  55.004  1
495077  90.297  -60.606  55.001  1
495078  90.342  -60.626  54.993  1
495079  90.384  -60.645  54.983  1
495080  90.423  -60.663  54.975  1
495081  90.461  -60.682  54.970  1
495082  90.499  -60.701  54.968  1
495083  90.542  -60.717  54.968  1
495084  90.588  -60.734  54.970  1
495085  90.633  -60.750  54.974  1
495086  90.679  -60.766  54.982  1
495087  90.727  -60.778  54.987  1
495088  90.776  -60.788  54.992  1
495089  90.825  -60.800  55.000  1
495090  90.872  -60.811  55.012  1
495091  90.910  -60.823  55.027  1
495092  90.949  -60.835  55.041  1
495093  90.987  -60.847  55.050  1
495094  91.026  -60.858  55.055  1
495095  91.064  -60.870  55.058  1
495096  91.103  -60.882  55.057  1
495097  91.141  -60.894  55.061  1
495098  91.180  -60.906  55.066  1
495099  91.218  -60.918  55.072  1
495100  91.257  -60.930  55.077  1
495101  91.295  -60.942  55.083  1
495102  91.334  -60.954  55.084  1
495103  91.372  -60.965  55.084  1
495104  91.411  -60.977  55.082  1
495105  91.449  -60.989  55.081  1
495106  91.488  -61.001  55.079  1
495107  91.526  -61.013  55.072  1
495108  91.565  -61.025  55.060  1
495109  91.603  -61.036  55.043  1
495110  91.642  -61.049  55.023  1
495111  91.680  -61.061  54.998  1
495112  91.719  -61.072  54.967  1
495113  91.757  -61.084  54.938  1
495114  91.796  -61.096  54.914  1
495115  91.835  -61.104  54.894  1
495116  91.874  -61.112  54.881  1
495117  91.913  -61.120  54.880  1
495118  91.952  -61.128  54.885  1
495119  91.991  -61.136  54.891  1
495120  92.030  -61.144  54.893  1
495121  92.069  -61.152  54.891  1
495122  92.108  -61.161  54.887  1
495123  92.147  -61.169  54.877  1
495124  92.186  -61.177  54.861  1
495125  92.225  -61.185  54.843  1
495126  92.264  -61.193  54.825  1
495127  92.306  -61.203  54.819  1
495128  92.354  -61.215  54.815  1
495129  92.401  -61.227  54.808  1
495130  92.449  -61.240  54.794  1
495131  92.496  -61.252  54.772  1
495132  92.544  -61.265  54.753  1
495133  92.586  -61.274  54.730  1
495134  92.625  -61.280  54.704  1
495135  92.663  -61.286  54.672  1
495136  92.701  -61.292  54.632  1
495137  92.740  -61.297  54.595  1
495138  92.778  -61.303  54.569  1
495139  92.816  -61.309  54.543  1
495140  92.855  -61.315  54.521  1
495141  92.894  -61.321  54.511  1
495142  92.932  -61.328  54.517  1
495143  92.970  -61.334  54.513  1
495144  93.009  -61.339  54.500  1
495145  93.047  -61.345  54.481  1
495146  93.085  -61.351  54.459  1
495147  93.124  -61.357  54.442  1
495148  93.162  -61.363  54.421  1
495149  93.201  -61.369  54.398  1
495150  93.239  -61.375  54.384  1
495151  93.278  -61.381  54.378  1
495152  93.316  -61.387  54.372  1
495153  93.354  -61.393  54.357  1
495154  93.393  -61.399  54.338  1
495155  93.431  -61.406  54.313  1
495156  93.471  -61.417  54.283  1
495157  93.511  -61.428  54.251  1
495158  93.551  -61.437  54.222  1
495159  93.591  -61.448  54.195  1
495160  93.631  -61.459  54.170  1
495161  93.671  -61.469  54.145  1
495162  93.711  -61.479  54.121  1
495163  93.753  -61.487  54.099  1
495164  93.795  -61.494  54.076  1
495165  93.838  -61.500  54.053  1
495166  93.880  -61.506  54.029  1
495167  93.923  -61.513  54.005  1
495168  93.966  -61.522  53.978  1
495169  94.007  -61.533  53.952  1
495170  94.049  -61.544  53.924  1
495171  94.090  -61.556  53.898  1
495172  94.132  -61.567  53.873  1
495173  94.173  -61.578  53.853  1
495174  94.215  -61.589  53.835  1
495175  94.257  -61.600  53.818  1
495176  94.299  -61.607  53.802  1
495177  94.342  -61.615  53.785  1
495178  94.385  -61.622  53.767  1
495179  94.427  -61.630  53.749  1
495180  94.470  -61.638  53.729  1
495181  94.509  -61.641  53.708  1
495182  94.548  -61.646  53.686  1
495183  94.586  -61.650  53.665  1
495184  94.625  -61.653  53.640  1
495185  94.664  -61.657  53.617  1
495186  94.703  -61.662  53.595  1
495187  94.738  -61.663  53.575  1
495188  94.774  -61.665  53.556  1
495189  94.809  -61.666  53.542  1
495190  94.844  -61.668  53.529  1
495191  94.880  -61.670  53.515  1
495192  94.915  -61.672  53.502  1
495193  94.952  -61.679  53.488  1
495194  94.988  -61.687  53.473  1
495195  95.024  -61.694  53.456  1
495196  95.060  -61.701  53.436  1
495197  95.097  -61.708  53.413  1
495198  95.135  -61.713  53.388  1
495199  95.173  -61.719  53.362  1
495200  95.210  -61.724  53.334  1
495201  95.251  -61.729  53.305  1
495202  95.293  -61.734  53.275  1
495203  95.333  -61.738  53.243  1
495204  95.374  -61.743  53.210  1
495205  95.414  -61.747  53.177  1
495206  95.455  -61.751  53.144  1
495207  95.494  -61.755  53.110  1
495208  95.532  -61.760  53.075  1
495209  95.569  -61.763  53.038  1
495210  95.611  -61.766  53.000  1
495211  95.658  -61.767  52.959  1
495212  95.701  -61.769  52.917  1
495213  95.740  -61.773  52.876  1
495214  95.779  -61.776  52.836  1
495215  95.819  -61.779  52.792  1
495216  95.858  -61.782  52.750  1
495217  95.896  -61.785  52.709  1
495218  95.934  -61.788  52.670  1
495219  95.972  -61.791  52.631  1
495220  96.010  -61.794  52.594  1
495221  96.048  -61.798  52.556  1
495222  96.086  -61.801  52.519  1
495223  96.124  -61.804  52.486  1
495224  96.161  -61.807  52.456  1
495225  96.196  -61.812  52.428  1
495226  96.231  -61.816  52.398  1
495227  96.270  -61.820  52.363  1
495228  96.314  -61.820  52.322  1
495229  96.355  -61.823  52.280  1
495230  96.395  -61.827  52.238  1
495231  96.436  -61.831  52.194  1
495232  96.477  -61.835  52.149  1
495233  96.518  -61.838  52.102  1
495234  96.558  -61.842  52.054  1
495235  96.597  -61.848  52.006  1
495236  96.633  -61.854  51.962  1
495237  96.670  -61.861  51.922  1
495238  96.707  -61.867  51.883  1
495239  96.744  -61.874  51.845  1
495240  96.781  -61.880  51.808  1
495241  96.817  -61.887  51.773  1
495242  96.857  -61.892  51.735  1
495243  96.894  -61.898  51.696  1
495244  96.924  -61.902  51.656  1
495245  96.955  -61.907  51.616  1
495246  96.985  -61.912  51.576  1
495247  97.016  -61.917  51.538  1
495248  97.046  -61.922  51.502  1
495249  97.077  -61.927  51.469  1
495250  97.107  -61.932  51.439  1
495251  97.138  -61.937  51.405  1
495252  97.169  -61.942  51.370  1
495253  97.199  -61.946  51.334  1
495254  97.230  -61.951  51.296  1
495255  97.260  -61.956  51.258  1
495256  97.291  -61.961  51.218  1
495257  97.321  -61.966  51.178  1
495258  97.350  -61.975  51.138  1
495259  97.388  -61.979  51.098  1
495260  97.455  -61.971  51.057  1
495261  97.522  -61.963  51.016  1
495262  97.589  -61.954  50.974  1
495263  97.656  -61.945  50.931  1
495264  97.723  -61.937  50.889  1
495265  97.790  -61.929  50.848  1
495266  97.815  -61.910  50.805  1
495267  97.860  -61.914  50.762  1
495268  97.880  -61.929  50.719  1
495269  97.904  -61.944  50.677  1
495270  97.928  -61.960  50.634  1
495271  97.952  -61.975  50.594  1
495272  97.977  -61.991  50.552  1
495273  98.001  -62.007  50.512  1
495274  98.025  -62.022  50.471  1
495275  98.049  -62.038  50.430  1
495276  98.073  -62.053  50.388  1
495277  98.097  -62.069  50.347  1
495278  98.122  -62.085  50.308  1
495279  98.146  -62.100  50.268  1
495280  98.170  -62.116  50.228  1
495740  88.658  -59.977  55.537  1
495741  88.717  -59.961  55.516  1
495742  88.776  -59.946  55.497  1
495743  88.835  -59.932  55.478  1
495744  88.891  -59.920  55.459  1
495745  88.945  -59.913  55.441  1
495746  88.985  -59.933  55.422  1
495747  89.025  -59.953  55.404  1
495748  89.065  -59.973  55.386  1
495749  89.105  -59.993  55.368  1
495750  89.128  -60.006  55.350  1
495751  89.147  -60.016  55.332  1
495752  89.188  -60.031  55.312  1
495753  89.229  -60.046  55.292  1
495754  89.269  -60.061  55.272  1
495755  89.312  -60.083  55.253  1
495756  89.354  -60.105  55.233  1
495757  89.397  -60.126  55.214  1
495758  89.440  -60.147  55.195  1
495759  89.483  -60.169  55.177  1
495760  89.526  -60.190  55.160  1
495761  89.568  -60.212  55.145  1
495762  89.611  -60.234  55.129  1
495763  89.654  -60.255  55.115  1
495764  89.696  -60.276  55.102  1
495765  89.739  -60.298  55.091  1
495766  89.782  -60.319  55.080  1
495767  89.824  -60.340  55.070  1
495768  89.867  -60.362  55.060  1
495769  89.910  -60.384  55.050  1
495770  89.953  -60.405  55.042  1
495771  89.996  -60.426  55.034  1
495772  90.039  -60.447  55.026  1
495773  90.085  -60.468  55.018  1
495774  90.130  -60.488  55.011  1
495775  90.176  -60.508  55.005  1
495776  90.222  -60.528  55.001  1
495777  90.267  -60.548  55.001  1
495778  90.312  -60.568  54.997  1
495779  90.358  -60.588  54.991  1
495780  90.402  -60.608  54.983  1
495781  90.440  -60.626  54.977  1
495782  90.479  -60.645  54.973  1
495783  90.517  -60.663  54.971  1
495784  90.561  -60.680  54.971  1
495785  90.607  -60.697  54.971  1
495786  90.652  -60.713  54.973  1
495787  90.698  -60.729  54.979  1
495788  90.745  -60.743  54.986  1
495789  90.794  -60.754  54.993  1
495790  90.842  -60.765  55.001  1
495791  90.885  -60.776  55.010  1
495792  90.924  -60.788  55.027  1
495793  90.962  -60.800  55.043  1
495794  91.001  -60.812  55.054  1
495795  91.039  -60.824  55.062  1
495796  91.078  -60.836  55.065  1
495797  91.116  -60.848  55.063  1
495798  91.155  -60.860  55.063  1
495799  91.193  -60.871  55.064  1
495800  91.232  -60.883  55.065  1
495801  91.270  -60.895  55.065  1
495802  91.309  -60.907  55.068  1
495803  91.347  -60.919  55.068  1
495804  91.386  -60.931  55.069  1
495805  91.424  -60.942  55.072  1
495806  91.463  -60.955  55.076  1
495807  91.501  -60.967  55.077  1
495808  91.540  -60.978  55.072  1
495809  91.579  -60.989  55.060  1
495810  91.618  -60.998  55.044  1
495811  91.658  -61.008  55.023  1
495812  91.698  -61.017  55.000  1
495813  91.737  -61.027  54.971  1
495814  91.777  -61.036  54.944  1
495815  91.803  -61.049  54.918  1
495816  91.843  -61.064  54.893  1
495817  91.883  -61.080  54.872  1
495818  91.922  -61.087  54.863  1
495819  91.961  -61.096  54.862  1
495820  92.000  -61.104  54.865  1
495821  92.038  -61.112  54.869  1
495822  92.078  -61.120  54.870  1
495823  92.117  -61.128  54.869  1
495824  92.156  -61.136  54.862  1
495825  92.195  -61.144  54.849  1
495826  92.233  -61.152  54.836  1
495827  92.273  -61.161  54.825  1
495828  92.311  -61.169  54.816  1
495829  92.358  -61.180  54.810  1
495830  92.405  -61.193  54.802  1
495831  92.453  -61.205  54.789  1
495832  92.500  -61.218  54.771  1
495833  92.548  -61.230  54.760  1
495834  92.589  -61.238  54.743  1
495835  92.627  -61.244  54.719  1
495836  92.666  -61.250  54.686  1
495837  92.704  -61.256  54.645  1
495838  92.742  -61.262  54.601  1
495839  92.781  -61.268  54.569  1
495840  92.819  -61.274  54.539  1
495841  92.858  -61.280  54.515  1
495842  92.896  -61.286  54.502  1
495843  92.935  -61.292  54.505  1
495844  92.973  -61.298  54.501  1
495845  93.011  -61.304  54.490  1
495846  93.050  -61.309  54.473  1
495847  93.088  -61.315  54.454  1
495848  93.127  -61.321  54.434  1
495849  93.165  -61.328  54.411  1
495850  93.204  -61.334  54.395  1
495851  93.242  -61.340  54.386  1
495852  93.280  -61.346  54.380  1
495853  93.319  -61.351  54.371  1
495854  93.359  -61.357  54.358  1
495855  93.399  -61.362  54.339  1
495856  93.439  -61.370  54.314  1
495857  93.479  -61.381  54.283  1
495858  93.518  -61.392  54.249  1
495859  93.559  -61.402  54.223  1
495860  93.599  -61.412  54.200  1
495861  93.639  -61.423  54.178  1
495862  93.679  -61.433  54.156  1
495863  93.719  -61.443  54.136  1
495864  93.760  -61.453  54.114  1
495865  93.802  -61.459  54.090  1
495866  93.845  -61.465  54.064  1
495867  93.888  -61.472  54.037  1
495868  93.930  -61.478  54.012  1
495869  93.973  -61.484  53.988  1
495870  94.016  -61.491  53.963  1
495871  94.058  -61.502  53.936  1
495872  94.099  -61.513  53.910  1
495873  94.140  -61.525  53.887  1
495874  94.182  -61.536  53.869  1
495875  94.223  -61.547  53.853  1
495876  94.265  -61.558  53.838  1
495877  94.308  -61.566  53.822  1
495878  94.350  -61.574  53.806  1
495879  94.393  -61.581  53.788  1
495880  94.436  -61.588  53.768  1
495881  94.477  -61.594  53.747  1
495882  94.516  -61.598  53.725  1
495883  94.554  -61.602  53.702  1
495884  94.593  -61.606  53.679  1
495885  94.631  -61.610  53.653  1
495886  94.670  -61.614  53.627  1
495887  94.709  -61.618  53.603  1
495888  94.744  -61.619  53.579  1
495889  94.780  -61.622  53.556  1
495890  94.815  -61.623  53.538  1
495891  94.850  -61.625  53.521  1
495892  94.886  -61.627  53.504  1
495893  94.922  -61.635  53.487  1
495894  94.958  -61.641  53.471  1
495895  94.994  -61.649  53.454  1
495896  95.031  -61.656  53.436  1
495897  95.066  -61.663  53.416  1
495898  95.104  -61.669  53.393  1
495899  95.141  -61.675  53.370  1
495900  95.179  -61.681  53.345  1
495901  95.217  -61.686  53.320  1
495902  95.255  -61.691  53.294  1
495903  95.297  -61.697  53.266  1
495904  95.338  -61.701  53.238  1
495905  95.379  -61.706  53.208  1
495906  95.420  -61.710  53.177  1
495907  95.458  -61.714  53.145  1
495908  95.496  -61.718  53.112  1
495909  95.534  -61.722  53.077  1
495910  95.572  -61.726  53.042  1
495911  95.610  -61.731  53.003  1
495912  95.653  -61.732  52.964  1
495913  95.692  -61.735  52.924  1
495914  95.732  -61.738  52.884  1
495915  95.771  -61.742  52.844  1
495916  95.811  -61.745  52.800  1
495917  95.850  -61.748  52.756  1
495918  95.889  -61.751  52.714  1
495919  95.926  -61.754  52.675  1
495920  95.965  -61.757  52.635  1
495921  96.003  -61.760  52.596  1
495922  96.041  -61.763  52.557  1
495923  96.079  -61.767  52.520  1
495924  96.117  -61.770  52.485  1
495925  96.155  -61.773  52.453  1
495926  96.194  -61.776  52.422  1
495927  96.235  -61.779  52.392  1
495928  96.271  -61.783  52.357  1
495929  96.312  -61.787  52.317  1
495930  96.353  -61.791  52.274  1
495931  96.394  -61.794  52.231  1
495932  96.435  -61.798  52.187  1
495933  96.475  -61.803  52.141  1
495934  96.516  -61.807  52.094  1
495935  96.557  -61.810  52.045  1
495936  96.596  -61.816  51.999  1
495937  96.632  -61.822  51.956  1
495938  96.669  -61.829  51.917  1
495939  96.706  -61.835  51.880  1
495940  96.742  -61.841  51.844  1
495941  96.779  -61.848  51.809  1
495942  96.816  -61.854  51.775  1
495943  96.853  -61.861  51.740  1
495944  96.891  -61.861  51.703  1
495945  96.922  -61.867  51.664  1
495946  96.953  -61.871  51.625  1
495947  96.983  -61.876  51.586  1
495948  97.014  -61.881  51.549  1
495949  97.045  -61.885  51.513  1
495950  97.076  -61.891  51.479  1
495951  97.106  -61.895  51.449  1
495952  97.137  -61.900  51.414  1
495953  97.167  -61.905  51.379  1
495954  97.198  -61.910  51.343  1
495955  97.229  -61.915  51.306  1
495956  97.259  -61.920  51.268  1
495957  97.290  -61.924  51.229  1
495958  97.320  -61.929  51.189  1
495959  97.351  -61.934  51.148  1
495960  97.400  -61.931  51.107  1
495961  97.456  -61.925  51.064  1
495962  97.523  -61.917  51.023  1
495963  97.590  -61.908  50.980  1
495964  97.657  -61.900  50.936  1
495965  97.724  -61.892  50.893  1
495966  97.791  -61.882  50.851  1
495967  97.823  -61.867  50.809  1
495968  97.859  -61.878  50.766  1
495969  97.881  -61.893  50.722  1
495970  97.906  -61.909  50.678  1
495971  97.930  -61.924  50.635  1
495972  97.954  -61.940  50.595  1
495973  97.978  -61.956  50.553  1
495974  98.002  -61.971  50.512  1
495975  98.026  -61.987  50.471  1
495976  98.051  -62.002  50.429  1
495977  98.075  -62.018  50.388  1
495978  98.099  -62.034  50.347  1
495979  98.123  -62.049  50.308  1
495980  98.147  -62.065  50.269  1
495981  98.171  -62.080  50.229  1
496438  88.527  -59.918  55.609  1
496439  88.579  -59.925  55.585  1
496440  88.631  -59.932  55.562  1
496441  88.686  -59.929  55.540  1
496442  88.746  -59.913  55.518  1
496443  88.805  -59.897  55.498  1
496444  88.861  -59.885  55.478  1
496445  88.918  -59.873  55.459  1
496446  88.965  -59.881  55.440  1
496447  89.004  -59.901  55.420  1
496448  89.045  -59.920  55.400  1
496449  89.085  -59.941  55.382  1
496450  89.125  -59.961  55.364  1
496451  89.150  -59.974  55.346  1
496452  89.163  -59.983  55.328  1
496453  89.203  -59.999  55.309  1
496454  89.243  -60.013  55.289  1
496455  89.284  -60.028  55.271  1
496456  89.326  -60.046  55.252  1
496457  89.369  -60.068  55.233  1
496458  89.411  -60.090  55.215  1
496459  89.454  -60.111  55.197  1
496460  89.496  -60.132  55.180  1
496461  89.539  -60.154  55.164  1
496462  89.582  -60.175  55.149  1
496463  89.624  -60.196  55.134  1
496464  89.667  -60.218  55.121  1
496465  89.710  -60.240  55.110  1
496466  89.753  -60.261  55.098  1
496467  89.796  -60.283  55.087  1
496468  89.838  -60.304  55.078  1
496469  89.881  -60.325  55.069  1
496470  89.923  -60.347  55.061  1
496471  89.966  -60.369  55.052  1
496472  90.009  -60.390  55.043  1
496473  90.054  -60.410  55.035  1
496474  90.100  -60.430  55.026  1
496475  90.146  -60.450  55.018  1
496476  90.191  -60.470  55.011  1
496477  90.237  -60.491  55.005  1
496478  90.282  -60.510  54.999  1
496479  90.327  -60.531  54.994  1
496480  90.373  -60.551  54.989  1
496481  90.418  -60.571  54.983  1
496482  90.458  -60.590  54.980  1
496483  90.497  -60.608  54.977  1
496484  90.535  -60.627  54.975  1
496485  90.580  -60.643  54.974  1
496486  90.625  -60.660  54.974  1
496487  90.671  -60.676  54.974  1
496488  90.717  -60.691  54.979  1
496489  90.762  -60.707  54.986  1
496490  90.811  -60.719  54.994  1
496491  90.860  -60.730  55.002  1
496492  90.898  -60.742  55.012  1
496493  90.937  -60.754  55.027  1
496494  90.975  -60.766  55.042  1
496495  91.014  -60.777  55.055  1
496496  91.052  -60.789  55.064  1
496497  91.091  -60.801  55.070  1
496498  91.130  -60.813  55.071  1
496499  91.168  -60.825  55.070  1
496500  91.207  -60.837  55.069  1
496501  91.245  -60.848  55.067  1
496502  91.284  -60.861  55.061  1
496503  91.322  -60.873  55.055  1
496504  91.361  -60.883  55.052  1
496505  91.400  -60.893  55.054  1
496506  91.440  -60.902  55.060  1
496507  91.480  -60.911  55.069  1
496508  91.519  -60.921  55.073  1
496509  91.559  -60.930  55.069  1
496510  91.599  -60.939  55.058  1
496511  91.638  -60.949  55.042  1
496512  91.678  -60.958  55.023  1
496513  91.718  -60.968  55.001  1
496514  91.757  -60.977  54.975  1
496515  91.797  -60.986  54.948  1
496516  91.809  -61.002  54.921  1
496517  91.850  -61.017  54.892  1
496518  91.889  -61.033  54.867  1
496519  91.929  -61.048  54.852  1
496520  91.969  -61.063  54.844  1
496521  92.008  -61.071  54.841  1
496522  92.048  -61.080  54.840  1
496523  92.086  -61.088  54.839  1
496524  92.125  -61.096  54.838  1
496525  92.164  -61.104  54.835  1
496526  92.203  -61.112  54.833  1
496527  92.242  -61.120  54.831  1
496528  92.281  -61.128  54.827  1
496529  92.320  -61.136  54.821  1
496530  92.361  -61.146  54.812  1
496531  92.409  -61.158  54.801  1
496532  92.456  -61.171  54.788  1
496533  92.504  -61.183  54.777  1
496534  92.552  -61.196  54.766  1
496535  92.592  -61.202  54.749  1
496536  92.630  -61.208  54.725  1
496537  92.668  -61.215  54.695  1
496538  92.707  -61.221  54.657  1
496539  92.745  -61.227  54.610  1
496540  92.784  -61.232  54.569  1
496541  92.823  -61.238  54.536  1
496542  92.861  -61.244  54.510  1
496543  92.899  -61.250  54.494  1
496544  92.937  -61.256  54.496  1
496545  92.976  -61.262  54.490  1
496546  93.014  -61.268  54.479  1
496547  93.053  -61.274  54.464  1
496548  93.091  -61.280  54.447  1
496549  93.130  -61.286  54.425  1
496550  93.168  -61.292  54.404  1
496551  93.206  -61.298  54.390  1
496552  93.246  -61.304  54.381  1
496553  93.286  -61.309  54.374  1
496554  93.327  -61.314  54.364  1
496555  93.368  -61.319  54.348  1
496556  93.409  -61.324  54.330  1
496557  93.448  -61.333  54.308  1
496558  93.488  -61.343  54.281  1
496559  93.528  -61.355  54.257  1
496560  93.567  -61.365  54.238  1
496561  93.607  -61.377  54.218  1
496562  93.646  -61.387  54.200  1
496563  93.686  -61.397  54.183  1
496564  93.726  -61.408  54.169  1
496565  93.767  -61.418  54.149  1
496566  93.809  -61.424  54.123  1
496567  93.852  -61.431  54.094  1
496568  93.895  -61.437  54.062  1
496569  93.937  -61.443  54.030  1
496570  93.980  -61.450  54.001  1
496571  94.023  -61.456  53.975  1
496572  94.066  -61.462  53.950  1
496573  94.108  -61.471  53.927  1
496574  94.149  -61.482  53.905  1
496575  94.191  -61.494  53.888  1
496576  94.233  -61.505  53.873  1
496577  94.274  -61.516  53.859  1
496578  94.317  -61.525  53.843  1
496579  94.359  -61.532  53.827  1
496580  94.402  -61.540  53.807  1
496581  94.444  -61.547  53.787  1
496582  94.483  -61.551  53.766  1
496583  94.522  -61.555  53.743  1
496584  94.560  -61.559  53.720  1
496585  94.599  -61.563  53.695  1
496586  94.637  -61.566  53.668  1
496587  94.676  -61.571  53.640  1
496588  94.715  -61.575  53.612  1
496589  94.750  -61.576  53.585  1
496590  94.785  -61.578  53.558  1
496591  94.821  -61.579  53.535  1
496592  94.856  -61.581  53.514  1
496593  94.893  -61.589  53.493  1
496594  94.929  -61.597  53.473  1
496595  94.965  -61.603  53.454  1
496596  95.001  -61.611  53.435  1
496597  95.037  -61.618  53.415  1
496598  95.073  -61.625  53.393  1
496599  95.111  -61.632  53.371  1
496600  95.148  -61.637  53.347  1
496601  95.186  -61.643  53.324  1
496602  95.224  -61.648  53.301  1
496603  95.262  -61.653  53.278  1
496604  95.302  -61.659  53.254  1
496605  95.343  -61.663  53.228  1
496606  95.385  -61.669  53.200  1
496607  95.422  -61.672  53.170  1
496608  95.461  -61.676  53.139  1
496609  95.499  -61.681  53.107  1
496610  95.537  -61.685  53.074  1
496611  95.576  -61.688  53.038  1
496612  95.614  -61.693  53.001  1
496613  95.652  -61.697  52.963  1
496614  95.690  -61.700  52.924  1
496615  95.728  -61.704  52.885  1
496616  95.766  -61.707  52.846  1
496617  95.805  -61.711  52.803  1
496618  95.843  -61.714  52.761  1
496619  95.881  -61.718  52.719  1
496620  95.920  -61.721  52.679  1
496621  95.962  -61.723  52.638  1
496622  96.003  -61.726  52.599  1
496623  96.044  -61.729  52.559  1
496624  96.085  -61.732  52.518  1
496625  96.126  -61.734  52.480  1
496626  96.168  -61.736  52.445  1
496627  96.205  -61.739  52.411  1
496628  96.242  -61.741  52.378  1
496629  96.277  -61.744  52.342  1
496630  96.310  -61.755  52.302  1
496631  96.351  -61.759  52.259  1
496632  96.392  -61.763  52.214  1
496633  96.433  -61.766  52.168  1
496634  96.474  -61.770  52.122  1
496635  96.515  -61.774  52.077  1
496636  96.555  -61.778  52.030  1
496637  96.595  -61.783  51.987  1
496638  96.631  -61.789  51.946  1
496639  96.668  -61.796  51.908  1
496640  96.704  -61.802  51.872  1
496641  96.741  -61.809  51.840  1
496642  96.778  -61.816  51.806  1
496643  96.815  -61.822  51.775  1
496644  96.857  -61.825  51.741  1
496645  96.897  -61.823  51.706  1
496646  96.934  -61.822  51.668  1
496647  96.965  -61.827  51.631  1
496648  96.996  -61.832  51.594  1
496649  97.026  -61.836  51.557  1
496650  97.057  -61.841  51.522  1
496651  97.088  -61.846  51.487  1
496652  97.118  -61.851  51.454  1
496653  97.149  -61.856  51.421  1
496654  97.179  -61.860  51.386  1
496655  97.210  -61.866  51.349  1
496656  97.241  -61.870  51.313  1
496657  97.272  -61.875  51.276  1
496658  97.302  -61.880  51.238  1
496659  97.333  -61.885  51.198  1
496660  97.378  -61.883  51.157  1
496661  97.432  -61.878  51.115  1
496662  97.486  -61.873  51.071  1
496663  97.539  -61.867  51.028  1
496664  97.593  -61.862  50.985  1
496665  97.659  -61.854  50.941  1
496666  97.726  -61.845  50.898  1
496667  97.793  -61.837  50.855  1
496668  97.834  -61.827  50.813  1
496669  97.859  -61.842  50.769  1
496670  97.883  -61.858  50.724  1
496671  97.908  -61.873  50.680  1
496672  97.932  -61.889  50.637  1
496673  97.956  -61.904  50.595  1
496674  97.980  -61.920  50.554  1
496675  98.004  -61.936  50.513  1
496676  98.028  -61.951  50.471  1
496677  98.053  -61.967  50.429  1
496678  98.077  -61.983  50.388  1
496679  98.101  -61.998  50.348  1
496680  98.125  -62.014  50.309  1
496681  98.149  -62.029  50.270  1
496682  98.173  -62.045  50.229  1
497135  88.345  -59.847  55.718  1
497136  88.397  -59.854  55.690  1
497137  88.450  -59.861  55.663  1
497138  88.501  -59.867  55.638  1
497139  88.553  -59.874  55.614  1
497140  88.606  -59.881  55.590  1
497141  88.658  -59.888  55.567  1
497142  88.714  -59.880  55.545  1
497143  88.773  -59.864  55.522  1
497144  88.833  -59.849  55.500  1
497145  88.889  -59.838  55.481  1
497146  88.944  -59.829  55.461  1
497147  88.984  -59.848  55.441  1
497148  89.024  -59.869  55.420  1
497149  89.064  -59.889  55.400  1
497150  89.104  -59.908  55.382  1
497151  89.144  -59.929  55.363  1
497152  89.171  -59.943  55.345  1
497153  89.183  -59.952  55.327  1
497154  89.218  -59.966  55.308  1
497155  89.258  -59.980  55.289  1
497156  89.299  -59.995  55.270  1
497157  89.339  -60.010  55.253  1
497158  89.382  -60.031  55.235  1
497159  89.424  -60.052  55.217  1
497160  89.467  -60.074  55.200  1
497161  89.510  -60.096  55.183  1
497162  89.553  -60.117  55.168  1
497163  89.596  -60.139  55.153  1
497164  89.638  -60.160  55.140  1
497165  89.681  -60.181  55.128  1
497166  89.724  -60.203  55.117  1
497167  89.766  -60.224  55.106  1
497168  89.809  -60.246  55.096  1
497169  89.852  -60.267  55.087  1
497170  89.894  -60.289  55.079  1
497171  89.937  -60.310  55.071  1
497172  89.980  -60.331  55.063  1
497173  90.024  -60.353  55.054  1
497174  90.070  -60.372  55.046  1
497175  90.115  -60.393  55.037  1
497176  90.161  -60.412  55.028  1
497177  90.206  -60.433  55.020  1
497178  90.252  -60.453  55.012  1
497179  90.297  -60.473  55.004  1
497180  90.342  -60.494  54.999  1
497181  90.388  -60.513  54.993  1
497182  90.434  -60.534  54.988  1
497183  90.476  -60.553  54.984  1
497184  90.515  -60.572  54.981  1
497185  90.553  -60.590  54.979  1
497186  90.599  -60.606  54.978  1
497187  90.645  -60.622  54.978  1
497188  90.690  -60.638  54.977  1
497189  90.736  -60.654  54.979  1
497190  90.782  -60.670  54.986  1
497191  90.829  -60.684  54.996  1
497192  90.873  -60.695  55.006  1
497193  90.911  -60.707  55.017  1
497194  90.950  -60.719  55.030  1
497195  90.989  -60.731  55.044  1
497196  91.027  -60.743  55.056  1
497197  91.066  -60.754  55.066  1
497198  91.104  -60.767  55.074  1
497199  91.143  -60.778  55.077  1
497200  91.183  -60.787  55.076  1
497201  91.222  -60.796  55.074  1
497202  91.262  -60.806  55.072  1
497203  91.302  -60.815  55.065  1
497204  91.341  -60.824  55.056  1
497205  91.381  -60.834  55.046  1
497206  91.421  -60.843  55.042  1
497207  91.460  -60.853  55.047  1
497208  91.500  -60.862  55.056  1
497209  91.539  -60.871  55.062  1
497210  91.579  -60.881  55.061  1
497211  91.618  -60.890  55.054  1
497212  91.658  -60.900  55.041  1
497213  91.698  -60.909  55.025  1
497214  91.737  -60.918  55.003  1
497215  91.777  -60.928  54.979  1
497216  91.810  -60.939  54.953  1
497217  91.816  -60.955  54.923  1
497218  91.856  -60.970  54.892  1
497219  91.896  -60.985  54.863  1
497220  91.936  -61.001  54.844  1
497221  91.976  -61.016  54.832  1
497222  92.016  -61.032  54.823  1
497223  92.056  -61.047  54.817  1
497224  92.095  -61.055  54.813  1
497225  92.134  -61.063  54.810  1
497226  92.173  -61.071  54.810  1
497227  92.212  -61.080  54.812  1
497228  92.251  -61.088  54.817  1
497229  92.290  -61.096  54.816  1
497230  92.329  -61.104  54.810  1
497231  92.368  -61.112  54.803  1
497232  92.413  -61.123  54.792  1
497233  92.460  -61.136  54.781  1
497234  92.508  -61.148  54.773  1
497235  92.556  -61.161  54.761  1
497236  92.595  -61.167  54.744  1
497237  92.633  -61.173  54.719  1
497238  92.671  -61.179  54.686  1
497239  92.710  -61.185  54.650  1
497240  92.748  -61.191  54.604  1
497241  92.787  -61.197  54.564  1
497242  92.825  -61.202  54.530  1
497243  92.864  -61.208  54.503  1
497244  92.902  -61.215  54.488  1
497245  92.940  -61.221  54.489  1
497246  92.979  -61.227  54.480  1
497247  93.017  -61.233  54.467  1
497248  93.056  -61.239  54.452  1
497249  93.094  -61.244  54.436  1
497250  93.133  -61.250  54.417  1
497251  93.174  -61.255  54.398  1
497252  93.214  -61.261  54.383  1
497253  93.255  -61.266  54.372  1
497254  93.295  -61.271  54.362  1
497255  93.336  -61.277  54.352  1
497256  93.377  -61.282  54.335  1
497257  93.418  -61.287  54.318  1
497258  93.458  -61.295  54.300  1
497259  93.497  -61.306  54.282  1
497260  93.537  -61.318  54.268  1
497261  93.576  -61.328  54.255  1
497262  93.616  -61.340  54.237  1
497263  93.655  -61.350  54.220  1
497264  93.694  -61.362  54.208  1
497265  93.734  -61.372  54.198  1
497266  93.774  -61.383  54.179  1
497267  93.817  -61.389  54.153  1
497268  93.859  -61.396  54.120  1
497269  93.902  -61.402  54.085  1
497270  93.945  -61.409  54.050  1
497271  93.987  -61.415  54.022  1
497272  94.030  -61.422  53.998  1
497273  94.073  -61.428  53.976  1
497274  94.116  -61.434  53.953  1
497275  94.158  -61.440  53.931  1
497276  94.200  -61.451  53.913  1
497277  94.242  -61.462  53.897  1
497278  94.283  -61.473  53.882  1
497279  94.325  -61.484  53.867  1
497280  94.367  -61.491  53.851  1
497281  94.410  -61.498  53.831  1
497282  94.450  -61.503  53.811  1
497283  94.489  -61.507  53.789  1
497284  94.528  -61.511  53.765  1
497285  94.566  -61.516  53.739  1
497286  94.605  -61.519  53.714  1
497287  94.643  -61.523  53.684  1
497288  94.682  -61.527  53.653  1
497289  94.721  -61.531  53.623  1
497290  94.756  -61.533  53.593  1
497291  94.791  -61.534  53.562  1
497292  94.827  -61.537  53.535  1
497293  94.863  -61.544  53.509  1
497294  94.899  -61.551  53.484  1
497295  94.935  -61.559  53.459  1
497296  94.972  -61.566  53.438  1
497297  95.008  -61.573  53.416  1
497298  95.044  -61.580  53.394  1
497299  95.080  -61.588  53.370  1
497300  95.118  -61.594  53.346  1
497301  95.156  -61.599  53.322  1
497302  95.193  -61.604  53.300  1
497303  95.231  -61.610  53.278  1
497304  95.269  -61.615  53.259  1
497305  95.307  -61.620  53.238  1
497306  95.347  -61.625  53.215  1
497307  95.388  -61.630  53.187  1
497308  95.427  -61.634  53.158  1
497309  95.466  -61.638  53.129  1
497310  95.504  -61.642  53.099  1
497311  95.542  -61.646  53.067  1
497312  95.580  -61.650  53.031  1
497313  95.618  -61.654  52.994  1
497314  95.656  -61.659  52.957  1
497315  95.694  -61.663  52.920  1
497316  95.733  -61.666  52.881  1
497317  95.771  -61.669  52.843  1
497318  95.809  -61.673  52.802  1
497319  95.847  -61.676  52.761  1
497320  95.885  -61.680  52.720  1
497321  95.927  -61.683  52.679  1
497322  95.971  -61.686  52.639  1
497323  96.014  -61.688  52.599  1
497324  96.058  -61.691  52.557  1
497325  96.100  -61.694  52.515  1
497326  96.139  -61.697  52.475  1
497327  96.176  -61.699  52.437  1
497328  96.212  -61.702  52.400  1
497329  96.248  -61.704  52.364  1
497330  96.284  -61.707  52.326  1
497331  96.316  -61.717  52.285  1
497332  96.349  -61.726  52.242  1
497333  96.390  -61.730  52.198  1
497334  96.431  -61.734  52.152  1
497335  96.472  -61.738  52.108  1
497336  96.513  -61.742  52.064  1
497337  96.553  -61.746  52.020  1
497338  96.593  -61.751  51.978  1
497339  96.630  -61.757  51.938  1
497340  96.667  -61.763  51.900  1
497341  96.703  -61.770  51.865  1
497342  96.740  -61.776  51.832  1
497343  96.777  -61.783  51.799  1
497344  96.815  -61.788  51.768  1
497345  96.862  -61.787  51.736  1
497346  96.901  -61.785  51.702  1
497347  96.941  -61.782  51.666  1
497348  96.977  -61.782  51.631  1
497349  97.008  -61.788  51.596  1
497350  97.038  -61.792  51.561  1
497351  97.069  -61.797  51.526  1
497352  97.100  -61.802  51.492  1
497353  97.131  -61.807  51.458  1
497354  97.161  -61.811  51.424  1
497355  97.191  -61.816  51.390  1
497356  97.222  -61.821  51.354  1
497357  97.253  -61.826  51.318  1
497358  97.284  -61.831  51.281  1
497359  97.314  -61.835  51.242  1
497360  97.357  -61.835  51.202  1
497361  97.410  -61.830  51.161  1
497362  97.464  -61.825  51.119  1
497363  97.518  -61.820  51.076  1
497364  97.572  -61.814  51.033  1
497365  97.626  -61.808  50.990  1
497366  97.679  -61.803  50.946  1
497367  97.733  -61.798  50.902  1
497368  97.794  -61.791  50.859  1
497369  97.837  -61.791  50.817  1
497370  97.861  -61.807  50.773  1
497371  97.885  -61.823  50.729  1
497372  97.909  -61.838  50.683  1
497373  97.933  -61.854  50.639  1
497374  97.957  -61.870  50.597  1
497375  97.982  -61.885  50.556  1
497376  98.006  -61.901  50.515  1
497377  98.030  -61.917  50.473  1
497378  98.054  -61.932  50.431  1
497379  98.078  -61.948  50.389  1
497380  98.102  -61.964  50.350  1
497381  98.127  -61.979  50.311  1
497382  98.151  -61.995  50.271  1
497383  98.175  -62.010  50.231  1
497832  88.164  -59.775  55.843  1
497833  88.216  -59.782  55.814  1
497834  88.268  -59.789  55.785  1
497835  88.320  -59.795  55.756  1
497836  88.372  -59.803  55.727  1
497837  88.424  -59.810  55.699  1
497838  88.476  -59.817  55.671  1
497839  88.528  -59.823  55.646  1
497840  88.580  -59.830  55.622  1
497841  88.632  -59.837  55.598  1
497842  88.684  -59.844  55.574  1
497843  88.743  -59.832  55.551  1
497844  88.802  -59.817  55.527  1
497845  88.859  -59.803  55.505  1
497846  88.916  -59.792  55.485  1
497847  88.964  -59.797  55.465  1
497848  89.003  -59.817  55.444  1
497849  89.044  -59.836  55.423  1
497850  89.084  -59.857  55.403  1
497851  89.124  -59.877  55.383  1
497852  89.164  -59.897  55.365  1
497853  89.192  -59.912  55.346  1
497854  89.204  -59.920  55.328  1
497855  89.233  -59.933  55.310  1
497856  89.273  -59.948  55.292  1
497857  89.314  -59.962  55.273  1
497858  89.354  -59.977  55.257  1
497859  89.396  -59.995  55.240  1
497860  89.438  -60.016  55.223  1
497861  89.481  -60.037  55.206  1
497862  89.524  -60.059  55.190  1
497863  89.566  -60.080  55.175  1
497864  89.609  -60.102  55.160  1
497865  89.652  -60.123  55.148  1
497866  89.694  -60.145  55.136  1
497867  89.737  -60.166  55.126  1
497868  89.780  -60.187  55.115  1
497869  89.823  -60.209  55.106  1
497870  89.866  -60.231  55.097  1
497871  89.908  -60.252  55.090  1
497872  89.951  -60.274  55.082  1
497873  89.994  -60.295  55.074  1
497874  90.039  -60.315  55.066  1
497875  90.085  -60.335  55.058  1
497876  90.130  -60.355  55.048  1
497877  90.176  -60.375  55.039  1
497878  90.221  -60.396  55.030  1
497879  90.267  -60.416  55.021  1
497880  90.312  -60.436  55.013  1
497881  90.358  -60.456  55.006  1
497882  90.403  -60.476  55.000  1
497883  90.449  -60.496  54.994  1
497884  90.494  -60.516  54.991  1
497885  90.532  -60.535  54.988  1
497886  90.573  -60.553  54.985  1
497887  90.618  -60.569  54.982  1
497888  90.664  -60.585  54.981  1
497889  90.710  -60.601  54.980  1
497890  90.755  -60.617  54.982  1
497891  90.801  -60.633  54.989  1
497892  90.847  -60.649  55.001  1
497893  90.886  -60.660  55.014  1
497894  90.925  -60.672  55.026  1
497895  90.965  -60.681  55.037  1
497896  91.005  -60.691  55.047  1
497897  91.044  -60.700  55.057  1
497898  91.084  -60.710  55.066  1
497899  91.123  -60.719  55.075  1
497900  91.163  -60.728  55.080  1
497901  91.203  -60.738  55.080  1
497902  91.242  -60.747  55.078  1
497903  91.282  -60.756  55.075  1
497904  91.321  -60.766  55.068  1
497905  91.361  -60.775  55.057  1
497906  91.401  -60.785  55.042  1
497907  91.440  -60.794  55.033  1
497908  91.480  -60.803  55.033  1
497909  91.520  -60.813  55.040  1
497910  91.559  -60.822  55.047  1
497911  91.599  -60.832  55.049  1
497912  91.639  -60.841  55.045  1
497913  91.678  -60.850  55.036  1
497914  91.718  -60.860  55.024  1
497915  91.757  -60.869  55.005  1
497916  91.797  -60.879  54.982  1
497917  91.819  -60.891  54.955  1
497918  91.824  -60.907  54.924  1
497919  91.863  -60.923  54.890  1
497920  91.903  -60.938  54.861  1
497921  91.943  -60.954  54.841  1
497922  91.983  -60.969  54.828  1
497923  92.023  -60.984  54.818  1
497924  92.063  -61.000  54.808  1
497925  92.102  -61.015  54.797  1
497926  92.143  -61.030  54.789  1
497927  92.181  -61.039  54.786  1
497928  92.221  -61.047  54.788  1
497929  92.260  -61.055  54.795  1
497930  92.298  -61.064  54.796  1
497931  92.338  -61.071  54.792  1
497932  92.376  -61.080  54.788  1
497933  92.417  -61.089  54.781  1
497934  92.464  -61.101  54.772  1
497935  92.512  -61.113  54.764  1
497936  92.559  -61.125  54.753  1
497937  92.597  -61.131  54.736  1
497938  92.636  -61.137  54.711  1
497939  92.674  -61.143  54.679  1
497940  92.713  -61.149  54.645  1
497941  92.751  -61.155  54.603  1
497942  92.790  -61.161  54.565  1
497943  92.828  -61.168  54.529  1
497944  92.866  -61.173  54.500  1
497945  92.905  -61.179  54.487  1
497946  92.943  -61.185  54.483  1
497947  92.982  -61.191  54.474  1
497948  93.020  -61.197  54.461  1
497949  93.060  -61.202  54.446  1
497950  93.101  -61.208  54.429  1
497951  93.142  -61.213  54.410  1
497952  93.183  -61.218  54.391  1
497953  93.223  -61.224  54.375  1
497954  93.264  -61.229  54.361  1
497955  93.304  -61.234  54.350  1
497956  93.345  -61.240  54.339  1
497957  93.386  -61.245  54.324  1
497958  93.427  -61.250  54.311  1
497959  93.467  -61.258  54.299  1
497960  93.506  -61.269  54.291  1
497961  93.546  -61.280  54.286  1
497962  93.585  -61.291  54.272  1
497963  93.625  -61.302  54.252  1
497964  93.664  -61.313  54.236  1
497965  93.703  -61.324  54.229  1
497966  93.743  -61.336  54.221  1
497967  93.782  -61.346  54.205  1
497968  93.824  -61.354  54.178  1
497969  93.867  -61.360  54.143  1
497970  93.909  -61.367  54.105  1
497971  93.952  -61.373  54.074  1
497972  93.995  -61.380  54.048  1
497973  94.037  -61.386  54.027  1
497974  94.080  -61.393  54.005  1
497975  94.123  -61.399  53.982  1
497976  94.166  -61.406  53.960  1
497977  94.208  -61.412  53.941  1
497978  94.251  -61.420  53.924  1
497979  94.292  -61.431  53.907  1
497980  94.334  -61.442  53.892  1
497981  94.376  -61.450  53.875  1
497982  94.417  -61.456  53.855  1
497983  94.456  -61.460  53.835  1
497984  94.495  -61.464  53.812  1
497985  94.534  -61.468  53.786  1
497986  94.572  -61.472  53.760  1
497987  94.611  -61.476  53.732  1
497988  94.649  -61.480  53.700  1
497989  94.688  -61.484  53.667  1
497990  94.726  -61.487  53.635  1
497991  94.762  -61.489  53.603  1
497992  94.797  -61.491  53.569  1
497993  94.834  -61.499  53.540  1
497994  94.870  -61.506  53.510  1
497995  94.906  -61.513  53.480  1
497996  94.942  -61.520  53.453  1
497997  94.978  -61.528  53.428  1
497998  95.015  -61.535  53.404  1
497999  95.051  -61.542  53.379  1
498000  95.087  -61.550  53.354  1
498001  95.124  -61.555  53.329  1
498002  95.162  -61.561  53.303  1
498003  95.200  -61.566  53.278  1
498004  95.238  -61.572  53.256  1
498005  95.276  -61.576  53.235  1
498006  95.314  -61.581  53.215  1
498007  95.352  -61.587  53.192  1
498008  95.392  -61.591  53.165  1
498009  95.432  -61.596  53.140  1
498010  95.470  -61.600  53.114  1
498011  95.509  -61.604  53.086  1
498012  95.547  -61.608  53.055  1
498013  95.585  -61.612  53.019  1
498014  95.623  -61.616  52.982  1
498015  95.661  -61.620  52.946  1
498016  95.699  -61.625  52.909  1
498017  95.737  -61.628  52.872  1
498018  95.775  -61.632  52.834  1
498019  95.813  -61.635  52.795  1
498020  95.851  -61.639  52.756  1
498021  95.890  -61.642  52.717  1
498022  95.932  -61.645  52.677  1
498023  95.976  -61.648  52.638  1
498024  96.019  -61.650  52.596  1
498025  96.063  -61.653  52.554  1
498026  96.105  -61.657  52.512  1
498027  96.146  -61.660  52.471  1
498028  96.182  -61.662  52.430  1
498029  96.218  -61.665  52.391  1
498030  96.254  -61.667  52.351  1
498031  96.290  -61.669  52.311  1
498032  96.323  -61.678  52.269  1
498033  96.354  -61.689  52.227  1
498034  96.389  -61.698  52.184  1
498035  96.430  -61.702  52.140  1
498036  96.470  -61.706  52.097  1
498037  96.511  -61.710  52.055  1
498038  96.552  -61.713  52.012  1
498039  96.592  -61.718  51.973  1
498040  96.629  -61.724  51.933  1
498041  96.665  -61.731  51.895  1
498042  96.702  -61.738  51.859  1
498043  96.739  -61.744  51.825  1
498044  96.776  -61.751  51.791  1
498045  96.821  -61.751  51.760  1
498046  96.866  -61.749  51.729  1
498047  96.905  -61.747  51.697  1
498048  96.945  -61.744  51.664  1
498049  96.985  -61.741  51.629  1
498050  97.020  -61.743  51.595  1
498051  97.050  -61.747  51.560  1
498052  97.081  -61.753  51.527  1
498053  97.112  -61.757  51.493  1
498054  97.143  -61.763  51.459  1
498055  97.173  -61.767  51.425  1
498056  97.204  -61.772  51.391  1
498057  97.234  -61.777  51.356  1
498058  97.265  -61.782  51.319  1
498059  97.296  -61.786  51.281  1
498060  97.335  -61.787  51.242  1
498061  97.389  -61.782  51.202  1
498062  97.443  -61.776  51.161  1
498063  97.497  -61.771  51.120  1
498064  97.550  -61.766  51.077  1
498065  97.604  -61.760  51.035  1
498066  97.658  -61.755  50.991  1
498067  97.712  -61.750  50.948  1
498068  97.766  -61.744  50.904  1
498069  97.806  -61.748  50.862  1
498070  97.839  -61.756  50.818  1
498071  97.863  -61.772  50.775  1
498072  97.887  -61.788  50.731  1
498073  97.911  -61.803  50.686  1
498074  97.935  -61.819  50.641  1
498075  97.959  -61.834  50.599  1
498076  97.984  -61.850  50.557  1
498077  98.008  -61.866  50.516  1
498078  98.032  -61.881  50.475  1
498079  98.056  -61.897  50.433  1
498080  98.080  -61.912  50.392  1
498081  98.104  -61.928  50.352  1
498082  98.129  -61.944  50.313  1
498083  98.153  -61.959  50.274  1
498084  98.177  -61.975  50.235  1
498531  88.087  -59.717  55.914  1
498532  88.139  -59.724  55.883  1
498533  88.191  -59.731  55.852  1
498534  88.243  -59.738  55.823  1
498535  88.295  -59.745  55.794  1
498536  88.347  -59.751  55.765  1
498537  88.399  -59.758  55.736  1
498538  88.451  -59.766  55.708  1
498539  88.503  -59.773  55.680  1
498540  88.555  -59.779  55.654  1
498541  88.607  -59.786  55.630  1
498542  88.659  -59.793  55.607  1
498543  88.711  -59.799  55.582  1
498544  88.770  -59.784  55.558  1
498545  88.830  -59.768  55.534  1
498546  88.887  -59.756  55.512  1
498547  88.943  -59.745  55.491  1
498548  88.983  -59.764  55.471  1
498549  89.023  -59.785  55.449  1
498550  89.063  -59.804  55.428  1
498551  89.103  -59.824  55.407  1
498552  89.143  -59.845  55.387  1
498553  89.184  -59.864  55.368  1
498554  89.214  -59.880  55.349  1
498555  89.226  -59.889  55.331  1
498556  89.248  -59.900  55.314  1
498557  89.288  -59.915  55.296  1
498558  89.329  -59.930  55.278  1
498559  89.369  -59.945  55.263  1
498560  89.410  -59.959  55.246  1
498561  89.452  -59.980  55.230  1
498562  89.494  -60.001  55.215  1
498563  89.537  -60.022  55.198  1
498564  89.580  -60.043  55.184  1
498565  89.623  -60.065  55.170  1
498566  89.666  -60.086  55.158  1
498567  89.708  -60.108  55.147  1
498568  89.751  -60.130  55.136  1
498569  89.794  -60.151  55.127  1
498570  89.836  -60.172  55.118  1
498571  89.879  -60.194  55.110  1
498572  89.921  -60.215  55.102  1
498573  89.964  -60.237  55.095  1
498574  90.009  -60.257  55.087  1
498575  90.054  -60.278  55.079  1
498576  90.100  -60.298  55.070  1
498577  90.146  -60.318  55.061  1
498578  90.191  -60.338  55.051  1
498579  90.236  -60.358  55.042  1
498580  90.282  -60.378  55.032  1
498581  90.327  -60.398  55.023  1
498582  90.373  -60.419  55.015  1
498583  90.418  -60.439  55.009  1
498584  90.464  -60.459  55.002  1
498585  90.509  -60.479  54.999  1
498586  90.550  -60.498  54.996  1
498587  90.592  -60.516  54.992  1
498588  90.637  -60.532  54.988  1
498589  90.683  -60.548  54.985  1
498590  90.728  -60.564  54.984  1
498591  90.774  -60.580  54.986  1
498592  90.818  -60.591  54.992  1
498593  90.861  -60.603  55.002  1
498594  90.901  -60.616  55.014  1
498595  90.944  -60.623  55.027  1
498596  90.984  -60.632  55.038  1
498597  91.024  -60.641  55.047  1
498598  91.064  -60.651  55.056  1
498599  91.104  -60.660  55.063  1
498600  91.143  -60.669  55.072  1
498601  91.183  -60.679  55.078  1
498602  91.223  -60.688  55.081  1
498603  91.262  -60.698  55.079  1
498604  91.302  -60.707  55.075  1
498605  91.342  -60.716  55.067  1
498606  91.381  -60.726  55.055  1
498607  91.421  -60.735  55.040  1
498608  91.460  -60.745  55.027  1
498609  91.500  -60.754  55.020  1
498610  91.539  -60.763  55.024  1
498611  91.579  -60.773  55.031  1
498612  91.619  -60.782  55.034  1
498613  91.658  -60.792  55.034  1
498614  91.698  -60.801  55.029  1
498615  91.738  -60.810  55.021  1
498616  91.777  -60.820  55.004  1
498617  91.817  -60.829  54.981  1
498618  91.827  -60.844  54.954  1
498619  91.833  -60.860  54.923  1
498620  91.869  -60.875  54.889  1
498621  91.910  -60.891  54.862  1
498622  91.949  -60.906  54.844  1
498623  91.990  -60.922  54.830  1
498624  92.029  -60.937  54.818  1
498625  92.069  -60.952  54.813  1
498626  92.109  -60.968  54.802  1
498627  92.149  -60.983  54.790  1
498628  92.189  -60.999  54.778  1
498629  92.229  -61.014  54.770  1
498630  92.268  -61.023  54.770  1
498631  92.307  -61.031  54.777  1
498632  92.346  -61.039  54.780  1
498633  92.385  -61.047  54.780  1
498634  92.424  -61.055  54.774  1
498635  92.468  -61.066  54.764  1
498636  92.516  -61.078  54.750  1
498637  92.562  -61.090  54.740  1
498638  92.600  -61.096  54.724  1
498639  92.639  -61.102  54.702  1
498640  92.677  -61.108  54.675  1
498641  92.716  -61.114  54.641  1
498642  92.754  -61.120  54.605  1
498643  92.793  -61.126  54.568  1
498644  92.831  -61.132  54.532  1
498645  92.869  -61.137  54.501  1
498646  92.908  -61.143  54.490  1
498647  92.947  -61.149  54.482  1
498648  92.988  -61.155  54.474  1
498649  93.029  -61.160  54.463  1
498650  93.070  -61.165  54.448  1
498651  93.110  -61.171  54.430  1
498652  93.151  -61.176  54.409  1
498653  93.192  -61.180  54.392  1
498654  93.232  -61.186  54.378  1
498655  93.273  -61.191  54.367  1
498656  93.314  -61.196  54.355  1
498657  93.354  -61.202  54.342  1
498658  93.395  -61.207  54.330  1
498659  93.436  -61.212  54.321  1
498660  93.476  -61.221  54.313  1
498661  93.515  -61.232  54.306  1
498662  93.555  -61.243  54.297  1
498663  93.594  -61.254  54.284  1
498664  93.634  -61.265  54.268  1
498665  93.673  -61.276  54.255  1
498666  93.712  -61.287  54.248  1
498667  93.752  -61.298  54.239  1
498668  93.791  -61.308  54.222  1
498669  93.835  -61.318  54.194  1
498670  93.877  -61.324  54.161  1
498671  93.919  -61.331  54.128  1
498672  93.961  -61.338  54.105  1
498673  94.003  -61.344  54.081  1
498674  94.046  -61.351  54.056  1
498675  94.087  -61.358  54.032  1
498676  94.130  -61.364  54.009  1
498677  94.173  -61.371  53.989  1
498678  94.215  -61.377  53.969  1
498679  94.258  -61.384  53.951  1
498680  94.300  -61.390  53.934  1
498681  94.342  -61.400  53.918  1
498682  94.385  -61.409  53.900  1
498683  94.423  -61.412  53.879  1
498684  94.462  -61.416  53.857  1
498685  94.501  -61.421  53.833  1
498686  94.540  -61.425  53.807  1
498687  94.578  -61.428  53.779  1
498688  94.617  -61.432  53.749  1
498689  94.656  -61.436  53.715  1
498690  94.694  -61.440  53.681  1
498691  94.733  -61.443  53.647  1
498692  94.768  -61.447  53.612  1
498693  94.805  -61.453  53.577  1
498694  94.840  -61.461  53.545  1
498695  94.877  -61.468  53.512  1
498696  94.913  -61.475  53.480  1
498697  94.949  -61.482  53.450  1
498698  94.985  -61.490  53.422  1
498699  95.021  -61.497  53.395  1
498700  95.057  -61.504  53.369  1
498701  95.094  -61.512  53.343  1
498702  95.131  -61.517  53.316  1
498703  95.169  -61.522  53.288  1
498704  95.207  -61.528  53.261  1
498705  95.245  -61.532  53.236  1
498706  95.283  -61.538  53.212  1
498707  95.321  -61.543  53.190  1
498708  95.358  -61.547  53.166  1
498709  95.396  -61.553  53.142  1
498710  95.437  -61.557  53.118  1
498711  95.475  -61.562  53.094  1
498712  95.513  -61.566  53.067  1
498713  95.551  -61.570  53.037  1
498714  95.589  -61.574  53.002  1
498715  95.627  -61.578  52.966  1
498716  95.665  -61.582  52.931  1
498717  95.703  -61.586  52.895  1
498718  95.741  -61.591  52.858  1
498719  95.779  -61.594  52.820  1
498720  95.818  -61.597  52.782  1
498721  95.856  -61.601  52.745  1
498722  95.894  -61.604  52.707  1
498723  95.937  -61.607  52.668  1
498724  95.981  -61.610  52.630  1
498725  96.024  -61.613  52.590  1
498726  96.066  -61.616  52.549  1
498727  96.107  -61.619  52.508  1
498728  96.147  -61.622  52.468  1
498729  96.187  -61.625  52.428  1
498730  96.224  -61.628  52.387  1
498731  96.260  -61.630  52.346  1
498732  96.296  -61.632  52.304  1
498733  96.330  -61.638  52.262  1
498734  96.362  -61.650  52.219  1
498735  96.392  -61.662  52.177  1
498736  96.428  -61.670  52.134  1
498737  96.468  -61.674  52.092  1
498738  96.509  -61.678  52.051  1
498739  96.550  -61.682  52.009  1
498740  96.591  -61.685  51.970  1
498741  96.627  -61.692  51.931  1
498742  96.664  -61.698  51.893  1
498743  96.701  -61.705  51.856  1
498744  96.738  -61.711  51.820  1
498745  96.780  -61.713  51.785  1
498746  96.827  -61.713  51.753  1
498747  96.870  -61.711  51.723  1
498748  96.909  -61.709  51.692  1
498749  96.949  -61.706  51.660  1
498750  96.989  -61.704  51.626  1
498751  97.029  -61.701  51.591  1
498752  97.063  -61.704  51.557  1
498753  97.093  -61.708  51.524  1
498754  97.124  -61.713  51.492  1
498755  97.155  -61.718  51.458  1
498756  97.185  -61.722  51.424  1
498757  97.216  -61.728  51.390  1
498758  97.247  -61.732  51.355  1
498759  97.277  -61.738  51.319  1
498760  97.314  -61.739  51.279  1
498761  97.368  -61.734  51.241  1
498762  97.422  -61.729  51.200  1
498763  97.475  -61.723  51.159  1
498764  97.529  -61.718  51.118  1
498765  97.583  -61.713  51.076  1
498766  97.637  -61.707  51.034  1
498767  97.686  -61.705  50.991  1
498768  97.726  -61.711  50.947  1
498769  97.765  -61.716  50.904  1
498770  97.810  -61.712  50.862  1
498771  97.840  -61.721  50.818  1
498772  97.864  -61.736  50.775  1
498773  97.888  -61.752  50.731  1
498774  97.913  -61.768  50.686  1
498775  97.937  -61.783  50.643  1
498776  97.961  -61.799  50.601  1
498777  97.985  -61.814  50.559  1
498778  98.009  -61.830  50.518  1
498779  98.033  -61.846  50.477  1
498780  98.058  -61.861  50.436  1
498781  98.082  -61.877  50.394  1
498782  98.106  -61.893  50.355  1
498783  98.130  -61.908  50.316  1
498784  98.154  -61.924  50.277  1
498785  98.178  -61.939  50.238  1
499231  88.061  -59.666  55.954  1
499232  88.114  -59.673  55.923  1
499233  88.166  -59.680  55.892  1
499234  88.217  -59.687  55.862  1
499235  88.270  -59.694  55.833  1
499236  88.322  -59.701  55.804  1
499237  88.374  -59.707  55.775  1
499238  88.426  -59.714  55.746  1
499239  88.478  -59.721  55.719  1
499240  88.530  -59.729  55.690  1
499241  88.582  -59.736  55.664  1
499242  88.634  -59.742  55.640  1
499243  88.686  -59.749  55.616  1
499244  88.740  -59.751  55.592  1
499245  88.799  -59.736  55.567  1
499246  88.857  -59.720  55.543  1
499247  88.914  -59.709  55.521  1
499248  88.963  -59.712  55.499  1
499249  89.002  -59.732  55.478  1
499250  89.043  -59.752  55.457  1
499251  89.083  -59.773  55.435  1
499252  89.123  -59.792  55.414  1
499253  89.163  -59.812  55.394  1
499254  89.203  -59.833  55.376  1
499255  89.235  -59.849  55.356  1
499256  89.247  -59.858  55.338  1
499257  89.263  -59.867  55.320  1
499258  89.303  -59.882  55.303  1
499259  89.344  -59.897  55.286  1
499260  89.384  -59.911  55.271  1
499261  89.424  -59.927  55.255  1
499262  89.466  -59.942  55.239  1
499263  89.508  -59.964  55.225  1
499264  89.551  -59.986  55.209  1
499265  89.594  -60.007  55.195  1
499266  89.636  -60.028  55.183  1
499267  89.679  -60.050  55.171  1
499268  89.722  -60.071  55.160  1
499269  89.764  -60.093  55.149  1
499270  89.807  -60.115  55.140  1
499271  89.850  -60.136  55.132  1
499272  89.893  -60.157  55.124  1
499273  89.936  -60.179  55.117  1
499274  89.979  -60.199  55.109  1
499275  90.024  -60.220  55.102  1
499276  90.070  -60.240  55.094  1
499277  90.115  -60.260  55.085  1
499278  90.161  -60.281  55.075  1
499279  90.206  -60.300  55.066  1
499280  90.251  -60.321  55.056  1
499281  90.297  -60.340  55.045  1
499282  90.342  -60.361  55.034  1
499283  90.388  -60.381  55.026  1
499284  90.434  -60.401  55.018  1
499285  90.479  -60.422  55.012  1
499286  90.524  -60.441  55.007  1
499287  90.568  -60.461  55.004  1
499288  90.611  -60.478  55.001  1
499289  90.656  -60.494  54.996  1
499290  90.702  -60.510  54.991  1
499291  90.745  -60.520  54.990  1
499292  90.788  -60.530  54.992  1
499293  90.831  -60.539  54.996  1
499294  90.874  -60.553  55.003  1
499295  90.912  -60.575  55.011  1
499296  90.955  -60.582  55.023  1
499297  90.997  -60.588  55.033  1
499298  91.039  -60.596  55.043  1
499299  91.082  -60.603  55.051  1
499300  91.123  -60.610  55.058  1
499301  91.163  -60.619  55.066  1
499302  91.203  -60.629  55.072  1
499303  91.242  -60.638  55.075  1
499304  91.282  -60.648  55.075  1
499305  91.322  -60.657  55.071  1
499306  91.361  -60.666  55.061  1
499307  91.401  -60.676  55.049  1
499308  91.441  -60.685  55.034  1
499309  91.480  -60.695  55.021  1
499310  91.520  -60.704  55.012  1
499311  91.560  -60.713  55.010  1
499312  91.599  -60.723  55.015  1
499313  91.639  -60.732  55.020  1
499314  91.678  -60.742  55.022  1
499315  91.718  -60.751  55.020  1
499316  91.757  -60.760  55.014  1
499317  91.797  -60.770  54.999  1
499318  91.830  -60.781  54.978  1
499319  91.836  -60.797  54.951  1
499320  91.842  -60.813  54.921  1
499321  91.876  -60.828  54.888  1
499322  91.916  -60.844  54.863  1
499323  91.956  -60.859  54.848  1
499324  91.996  -60.874  54.833  1
499325  92.036  -60.890  54.819  1
499326  92.076  -60.905  54.816  1
499327  92.116  -60.920  54.806  1
499328  92.156  -60.936  54.794  1
499329  92.196  -60.951  54.779  1
499330  92.236  -60.967  54.766  1
499331  92.276  -60.983  54.757  1
499332  92.316  -60.998  54.760  1
499333  92.355  -61.007  54.767  1
499334  92.394  -61.014  54.769  1
499335  92.433  -61.023  54.764  1
499336  92.472  -61.031  54.754  1
499337  92.520  -61.043  54.739  1
499338  92.565  -61.055  54.723  1
499339  92.603  -61.061  54.706  1
499340  92.642  -61.066  54.687  1
499341  92.680  -61.072  54.665  1
499342  92.719  -61.078  54.636  1
499343  92.757  -61.084  54.608  1
499344  92.795  -61.090  54.575  1
499345  92.835  -61.096  54.539  1
499346  92.875  -61.101  54.506  1
499347  92.916  -61.106  54.495  1
499348  92.956  -61.111  54.491  1
499349  92.997  -61.117  54.486  1
499350  93.038  -61.122  54.477  1
499351  93.079  -61.127  54.463  1
499352  93.120  -61.133  54.443  1
499353  93.160  -61.138  54.417  1
499354  93.201  -61.143  54.401  1
499355  93.241  -61.149  54.392  1
499356  93.282  -61.154  54.384  1
499357  93.323  -61.159  54.372  1
499358  93.364  -61.165  54.358  1
499359  93.405  -61.170  54.345  1
499360  93.445  -61.175  54.339  1
499361  93.485  -61.183  54.333  1
499362  93.524  -61.195  54.324  1
499363  93.564  -61.205  54.311  1
499364  93.604  -61.217  54.298  1
499365  93.643  -61.227  54.284  1
499366  93.682  -61.239  54.272  1
499367  93.722  -61.249  54.265  1
499368  93.761  -61.259  54.254  1
499369  93.801  -61.270  54.235  1
499370  93.845  -61.280  54.208  1
499371  93.888  -61.289  54.177  1
499372  93.929  -61.296  54.148  1
499373  93.972  -61.302  54.131  1
499374  94.014  -61.309  54.109  1
499375  94.056  -61.315  54.085  1
499376  94.098  -61.321  54.059  1
499377  94.140  -61.328  54.035  1
499378  94.183  -61.335  54.014  1
499379  94.225  -61.341  53.994  1
499380  94.267  -61.348  53.975  1
499381  94.309  -61.355  53.958  1
499382  94.351  -61.361  53.940  1
499383  94.393  -61.368  53.921  1
499384  94.431  -61.371  53.898  1
499385  94.470  -61.375  53.874  1
499386  94.508  -61.378  53.848  1
499387  94.546  -61.382  53.820  1
499388  94.585  -61.385  53.790  1
499389  94.623  -61.389  53.759  1
499390  94.662  -61.393  53.725  1
499391  94.701  -61.396  53.690  1
499392  94.739  -61.401  53.656  1
499393  94.775  -61.408  53.619  1
499394  94.811  -61.415  53.584  1
499395  94.847  -61.423  53.550  1
499396  94.883  -61.430  53.516  1
499397  94.919  -61.437  53.483  1
499398  94.956  -61.444  53.451  1
499399  94.992  -61.452  53.419  1
499400  95.028  -61.459  53.391  1
499401  95.064  -61.466  53.363  1
499402  95.101  -61.473  53.335  1
499403  95.138  -61.478  53.306  1
499404  95.176  -61.484  53.275  1
499405  95.214  -61.488  53.246  1
499406  95.252  -61.494  53.217  1
499407  95.290  -61.499  53.190  1
499408  95.328  -61.503  53.165  1
499409  95.366  -61.509  53.139  1
499410  95.403  -61.514  53.117  1
499411  95.441  -61.519  53.094  1
499412  95.480  -61.523  53.070  1
499413  95.518  -61.528  53.044  1
499414  95.556  -61.531  53.015  1
499415  95.594  -61.535  52.980  1
499416  95.632  -61.540  52.946  1
499417  95.670  -61.544  52.912  1
499418  95.708  -61.548  52.878  1
499419  95.746  -61.552  52.841  1
499420  95.784  -61.556  52.805  1
499421  95.822  -61.559  52.768  1
499422  95.860  -61.563  52.731  1
499423  95.899  -61.566  52.695  1
499424  95.942  -61.569  52.659  1
499425  95.986  -61.572  52.621  1
499426  96.028  -61.575  52.583  1
499427  96.068  -61.578  52.542  1
499428  96.109  -61.581  52.502  1
499429  96.149  -61.584  52.463  1
499430  96.189  -61.587  52.423  1
499431  96.230  -61.590  52.384  1
499432  96.266  -61.593  52.344  1
499433  96.303  -61.595  52.303  1
499434  96.338  -61.599  52.260  1
499435  96.369  -61.611  52.217  1
499436  96.400  -61.622  52.173  1
499437  96.431  -61.634  52.130  1
499438  96.467  -61.641  52.089  1
499439  96.508  -61.645  52.049  1
499440  96.548  -61.649  52.007  1
499441  96.589  -61.653  51.968  1
499442  96.626  -61.660  51.929  1
499443  96.663  -61.666  51.891  1
499444  96.699  -61.672  51.854  1
499445  96.739  -61.677  51.818  1
499446  96.786  -61.676  51.782  1
499447  96.833  -61.675  51.749  1
499448  96.874  -61.673  51.717  1
499449  96.913  -61.671  51.686  1
499450  96.953  -61.668  51.655  1
499451  96.993  -61.666  51.622  1
499452  97.033  -61.663  51.587  1
499453  97.073  -61.660  51.553  1
499454  97.105  -61.664  51.520  1
499455  97.136  -61.669  51.487  1
499456  97.167  -61.674  51.454  1
499457  97.197  -61.678  51.420  1
499458  97.228  -61.683  51.386  1
499459  97.259  -61.688  51.351  1
499460  97.293  -61.691  51.313  1
499461  97.347  -61.686  51.275  1
499462  97.400  -61.681  51.236  1
499463  97.454  -61.675  51.195  1
499464  97.508  -61.670  51.154  1
499465  97.562  -61.665  51.113  1
499466  97.606  -61.666  51.072  1
499467  97.646  -61.672  51.030  1
499468  97.685  -61.678  50.987  1
499469  97.724  -61.684  50.945  1
499470  97.768  -61.677  50.902  1
499471  97.814  -61.677  50.859  1
499472  97.842  -61.685  50.815  1
499473  97.866  -61.701  50.772  1
499474  97.890  -61.717  50.728  1
499475  97.915  -61.732  50.685  1
499476  97.939  -61.748  50.642  1
499477  97.963  -61.763  50.600  1
499478  97.987  -61.779  50.560  1
499479  98.011  -61.795  50.520  1
499480  98.035  -61.810  50.479  1
499481  98.060  -61.826  50.438  1
499482  98.084  -61.841  50.397  1
499483  98.108  -61.857  50.358  1
499484  98.132  -61.873  50.319  1
499485  98.156  -61.888  50.281  1
499486  98.180  -61.904  50.242  1
499931  88.039  -59.616  55.994  1
499932  88.088  -59.622  55.964  1
499933  88.140  -59.629  55.934  1
499934  88.192  -59.636  55.903  1
499935  88.245  -59.643  55.873  1
499936  88.296  -59.650  55.844  1
499937  88.348  -59.657  55.816  1
499938  88.401  -59.663  55.787  1
499939  88.453  -59.670  55.759  1
499940  88.504  -59.677  55.730  1
499941  88.557  -59.684  55.702  1
499942  88.609  -59.692  55.676  1
499943  88.661  -59.698  55.651  1
499944  88.713  -59.705  55.626  1
499945  88.768  -59.703  55.602  1
499946  88.827  -59.687  55.577  1
499947  88.885  -59.673  55.554  1
499948  88.941  -59.662  55.531  1
499949  88.982  -59.680  55.508  1
499950  89.022  -59.701  55.487  1
499951  89.062  -59.720  55.466  1
499952  89.102  -59.740  55.445  1
499953  89.142  -59.761  55.424  1
499954  89.183  -59.780  55.403  1
499955  89.223  -59.800  55.385  1
499956  89.257  -59.818  55.366  1
499957  89.268  -59.826  55.348  1
499958  89.280  -59.836  55.330  1
499959  89.318  -59.849  55.314  1
499960  89.358  -59.864  55.297  1
499961  89.399  -59.879  55.283  1
499962  89.440  -59.894  55.269  1
499963  89.480  -59.908  55.254  1
499964  89.522  -59.927  55.238  1
499965  89.564  -59.949  55.224  1
499966  89.607  -59.971  55.209  1
499967  89.650  -59.992  55.197  1
499968  89.693  -60.013  55.186  1
499969  89.736  -60.035  55.176  1
499970  89.778  -60.056  55.165  1
499971  89.821  -60.077  55.156  1
499972  89.864  -60.099  55.148  1
499973  89.906  -60.121  55.141  1
499974  89.949  -60.142  55.133  1
499975  89.994  -60.162  55.126  1
499976  90.039  -60.183  55.118  1
499977  90.085  -60.202  55.110  1
499978  90.130  -60.223  55.101  1
499979  90.176  -60.243  55.091  1
499980  90.221  -60.263  55.081  1
499981  90.267  -60.284  55.071  1
499982  90.312  -60.303  55.060  1
499983  90.358  -60.324  55.048  1
499984  90.403  -60.343  55.039  1
499985  90.449  -60.364  55.031  1
499986  90.494  -60.384  55.023  1
499987  90.539  -60.404  55.017  1
499988  90.585  -60.425  55.013  1
499989  90.629  -60.439  55.009  1
499990  90.672  -60.449  55.004  1
499991  90.716  -60.458  55.000  1
499992  90.759  -60.468  55.000  1
499993  90.802  -60.478  55.000  1
499994  90.845  -60.487  55.001  1
499995  90.886  -60.503  55.004  1
499996  90.923  -60.533  55.007  1
499997  90.965  -60.541  55.013  1
499998  91.008  -60.547  55.022  1
499999  91.050  -60.554  55.034  1
500000  91.093  -60.561  55.045  1
500001  91.135  -60.568  55.052  1
500002  91.178  -60.575  55.059  1
500003  91.220  -60.582  55.065  1
500004  91.262  -60.589  55.068  1
500005  91.302  -60.598  55.068  1
500006  91.342  -60.608  55.064  1
500007  91.381  -60.617  55.054  1
500008  91.421  -60.627  55.042  1
500009  91.460  -60.636  55.029  1
500010  91.500  -60.645  55.016  1
500011  91.540  -60.655  55.004  1
500012  91.579  -60.664  54.999  1
500013  91.619  -60.674  55.000  1
500014  91.659  -60.683  55.005  1
500015  91.698  -60.692  55.009  1
500016  91.738  -60.702  55.010  1
500017  91.778  -60.711  55.005  1
500018  91.817  -60.720  54.994  1
500019  91.839  -60.733  54.975  1
500020  91.844  -60.749  54.951  1
500021  91.850  -60.765  54.921  1
500022  91.883  -60.781  54.888  1
500023  91.923  -60.796  54.864  1
500024  91.963  -60.812  54.848  1
500025  92.003  -60.827  54.832  1
500026  92.042  -60.842  54.817  1
500027  92.083  -60.858  54.811  1
500028  92.123  -60.873  54.804  1
500029  92.163  -60.889  54.797  1
500030  92.203  -60.904  54.788  1
500031  92.242  -60.920  54.774  1
500032  92.283  -60.936  54.756  1
500033  92.322  -60.951  54.747  1
500034  92.362  -60.966  54.752  1
500035  92.403  -60.982  54.755  1
500036  92.441  -60.990  54.751  1
500037  92.481  -60.998  54.742  1
500038  92.523  -61.008  54.726  1
500039  92.568  -61.019  54.706  1
500040  92.606  -61.025  54.687  1
500041  92.645  -61.030  54.669  1
500042  92.683  -61.036  54.652  1
500043  92.721  -61.042  54.629  1
500044  92.762  -61.048  54.605  1
500045  92.803  -61.053  54.576  1
500046  92.844  -61.058  54.541  1
500047  92.884  -61.064  54.507  1
500048  92.925  -61.069  54.501  1
500049  92.966  -61.074  54.500  1
500050  93.006  -61.080  54.494  1
500051  93.047  -61.085  54.482  1
500052  93.088  -61.090  54.465  1
500053  93.129  -61.096  54.443  1
500054  93.169  -61.101  54.428  1
500055  93.210  -61.106  54.419  1
500056  93.251  -61.111  54.412  1
500057  93.291  -61.117  54.405  1
500058  93.332  -61.122  54.395  1
500059  93.373  -61.127  54.380  1
500060  93.414  -61.132  54.370  1
500061  93.454  -61.137  54.362  1
500062  93.494  -61.146  54.353  1
500063  93.534  -61.157  54.342  1
500064  93.573  -61.168  54.331  1
500065  93.613  -61.180  54.318  1
500066  93.652  -61.190  54.303  1
500067  93.692  -61.201  54.288  1
500068  93.731  -61.211  54.280  1
500069  93.771  -61.221  54.265  1
500070  93.812  -61.231  54.244  1
500071  93.854  -61.241  54.219  1
500072  93.898  -61.252  54.191  1
500073  93.940  -61.259  54.166  1
500074  93.982  -61.266  54.154  1
500075  94.025  -61.273  54.135  1
500076  94.067  -61.279  54.111  1
500077  94.109  -61.286  54.085  1
500078  94.151  -61.293  54.060  1
500079  94.193  -61.299  54.037  1
500080  94.236  -61.306  54.016  1
500081  94.277  -61.312  53.995  1
500082  94.320  -61.318  53.976  1
500083  94.362  -61.327  53.956  1
500084  94.404  -61.335  53.934  1
500085  94.445  -61.342  53.910  1
500086  94.485  -61.346  53.884  1
500087  94.523  -61.349  53.856  1
500088  94.562  -61.353  53.826  1
500089  94.600  -61.356  53.794  1
500090  94.638  -61.360  53.763  1
500091  94.677  -61.364  53.727  1
500092  94.715  -61.368  53.692  1
500093  94.748  -61.368  53.657  1
500094  94.782  -61.374  53.622  1
500095  94.818  -61.381  53.588  1
500096  94.854  -61.388  53.555  1
500097  94.891  -61.396  53.520  1
500098  94.927  -61.403  53.485  1
500099  94.963  -61.410  53.451  1
500100  94.999  -61.418  53.418  1
500101  95.035  -61.425  53.387  1
500102  95.071  -61.431  53.357  1
500103  95.109  -61.434  53.327  1
500104  95.146  -61.439  53.295  1
500105  95.184  -61.444  53.263  1
500106  95.222  -61.449  53.231  1
500107  95.260  -61.454  53.200  1
500108  95.298  -61.459  53.170  1
500109  95.336  -61.465  53.142  1
500110  95.374  -61.469  53.114  1
500111  95.411  -61.475  53.090  1
500112  95.449  -61.482  53.067  1
500113  95.485  -61.487  53.043  1
500114  95.523  -61.490  53.016  1
500115  95.560  -61.494  52.986  1
500116  95.598  -61.497  52.953  1
500117  95.636  -61.501  52.920  1
500118  95.674  -61.506  52.889  1
500119  95.712  -61.509  52.858  1
500120  95.750  -61.514  52.823  1
500121  95.788  -61.518  52.787  1
500122  95.826  -61.522  52.751  1
500123  95.865  -61.525  52.716  1
500124  95.904  -61.529  52.682  1
500125  95.947  -61.531  52.648  1
500126  95.990  -61.534  52.611  1
500127  96.030  -61.538  52.573  1
500128  96.071  -61.541  52.533  1
500129  96.111  -61.544  52.494  1
500130  96.151  -61.547  52.455  1
500131  96.191  -61.550  52.417  1
500132  96.232  -61.553  52.380  1
500133  96.272  -61.556  52.342  1
500134  96.309  -61.558  52.302  1
500135  96.345  -61.560  52.260  1
500136  96.376  -61.572  52.216  1
500137  96.407  -61.583  52.171  1
500138  96.438  -61.594  52.129  1
500139  96.469  -61.606  52.089  1
500140  96.506  -61.613  52.048  1
500141  96.547  -61.617  52.007  1
500142  96.588  -61.621  51.967  1
500143  96.625  -61.627  51.928  1
500144  96.662  -61.633  51.890  1
500145  96.698  -61.640  51.852  1
500146  96.745  -61.639  51.816  1
500147  96.792  -61.638  51.781  1
500148  96.838  -61.638  51.746  1
500149  96.878  -61.635  51.713  1
500150  96.918  -61.633  51.680  1
500151  96.958  -61.630  51.649  1
500152  96.998  -61.628  51.616  1
500153  97.037  -61.625  51.582  1
500154  97.077  -61.622  51.548  1
500155  97.117  -61.620  51.514  1
500156  97.148  -61.625  51.481  1
500157  97.179  -61.629  51.448  1
500158  97.210  -61.634  51.415  1
500159  97.240  -61.639  51.380  1
500160  97.272  -61.644  51.345  1
500161  97.325  -61.638  51.308  1
500162  97.379  -61.633  51.269  1
500163  97.433  -61.628  51.229  1
500164  97.487  -61.622  51.188  1
500165  97.527  -61.628  51.147  1
500166  97.566  -61.633  51.107  1
500167  97.605  -61.639  51.066  1
500168  97.644  -61.645  51.024  1
500169  97.683  -61.651  50.982  1
500170  97.726  -61.645  50.939  1
500171  97.770  -61.638  50.896  1
500172  97.819  -61.643  50.853  1
500173  97.844  -61.650  50.811  1
500174  97.868  -61.666  50.767  1
500175  97.892  -61.682  50.724  1
500176  97.916  -61.697  50.682  1
500177  97.940  -61.713  50.640  1
500178  97.964  -61.729  50.600  1
500179  97.989  -61.744  50.560  1
500180  98.013  -61.760  50.519  1
500181  98.037  -61.776  50.479  1
500182  98.061  -61.791  50.439  1
500183  98.085  -61.807  50.398  1
500184  98.109  -61.822  50.360  1
500185  98.134  -61.838  50.321  1
500186  98.158  -61.854  50.283  1
500187  98.182  -61.869  50.244  1
500631  88.017  -59.566  56.034  1
500632  88.063  -59.571  56.004  1
500633  88.115  -59.578  55.974  1
500634  88.167  -59.585  55.944  1
500635  88.219  -59.592  55.915  1
500636  88.271  -59.599  55.885  1
500637  88.323  -59.606  55.857  1
500638  88.375  -59.613  55.829  1
500639  88.427  -59.620  55.801  1
500640  88.479  -59.626  55.772  1
500641  88.531  -59.633  55.743  1
500642  88.583  -59.640  55.715  1
500643  88.635  -59.647  55.689  1
500644  88.687  -59.654  55.664  1
500645  88.740  -59.661  55.638  1
500646  88.796  -59.654  55.613  1
500647  88.855  -59.639  55.590  1
500648  88.912  -59.627  55.566  1
500649  88.962  -59.628  55.543  1
500650  89.001  -59.648  55.520  1
500651  89.042  -59.668  55.499  1
500652  89.082  -59.689  55.478  1
500653  89.122  -59.708  55.457  1
500654  89.162  -59.728  55.435  1
500655  89.202  -59.748  55.415  1
500656  89.242  -59.768  55.395  1
500657  89.278  -59.786  55.377  1
500658  89.290  -59.795  55.360  1
500659  89.302  -59.804  55.343  1
500660  89.333  -59.817  55.326  1
500661  89.374  -59.832  55.311  1
500662  89.414  -59.846  55.297  1
500663  89.455  -59.861  55.284  1
500664  89.495  -59.876  55.269  1
500665  89.536  -59.891  55.255  1
500666  89.578  -59.912  55.241  1
500667  89.621  -59.933  55.228  1
500668  89.664  -59.955  55.216  1
500669  89.706  -59.977  55.205  1
500670  89.749  -59.998  55.195  1
500671  89.792  -60.020  55.185  1
500672  89.834  -60.041  55.177  1
500673  89.877  -60.062  55.169  1
500674  89.920  -60.083  55.161  1
500675  89.963  -60.105  55.153  1
500676  90.009  -60.125  55.145  1
500677  90.054  -60.145  55.136  1
500678  90.100  -60.165  55.127  1
500679  90.146  -60.185  55.118  1
500680  90.191  -60.206  55.108  1
500681  90.236  -60.226  55.098  1
500682  90.282  -60.246  55.087  1
500683  90.327  -60.266  55.076  1
500684  90.373  -60.286  55.064  1
500685  90.418  -60.306  55.053  1
500686  90.464  -60.326  55.044  1
500687  90.509  -60.347  55.034  1
500688  90.554  -60.363  55.027  1
500689  90.599  -60.375  55.022  1
500690  90.643  -60.387  55.017  1
500691  90.686  -60.397  55.012  1
500692  90.729  -60.406  55.009  1
500693  90.773  -60.416  55.011  1
500694  90.815  -60.425  55.012  1
500695  90.859  -60.434  55.013  1
500696  90.899  -60.453  55.014  1
500697  90.935  -60.487  55.015  1
500698  90.976  -60.499  55.016  1
500699  91.019  -60.506  55.022  1
500700  91.061  -60.513  55.031  1
500701  91.103  -60.519  55.040  1
500702  91.146  -60.527  55.049  1
500703  91.188  -60.534  55.057  1
500704  91.231  -60.541  55.061  1
500705  91.273  -60.547  55.061  1
500706  91.316  -60.554  55.059  1
500707  91.358  -60.561  55.055  1
500708  91.400  -60.569  55.045  1
500709  91.441  -60.577  55.035  1
500710  91.481  -60.587  55.023  1
500711  91.520  -60.596  55.011  1
500712  91.560  -60.605  54.998  1
500713  91.599  -60.615  54.989  1
500714  91.639  -60.624  54.987  1
500715  91.678  -60.634  54.990  1
500716  91.718  -60.643  54.995  1
500717  91.758  -60.652  54.998  1
500718  91.797  -60.662  54.996  1
500719  91.837  -60.671  54.988  1
500720  91.847  -60.686  54.973  1
500721  91.853  -60.702  54.951  1
500722  91.858  -60.718  54.922  1
500723  91.889  -60.734  54.889  1
500724  91.929  -60.749  54.867  1
500725  91.969  -60.764  54.851  1
500726  92.009  -60.780  54.837  1
500727  92.050  -60.795  54.820  1
500728  92.089  -60.810  54.806  1
500729  92.129  -60.826  54.801  1
500730  92.169  -60.842  54.797  1
500731  92.209  -60.857  54.791  1
500732  92.249  -60.873  54.781  1
500733  92.289  -60.888  54.765  1
500734  92.329  -60.904  54.746  1
500735  92.369  -60.919  54.737  1
500736  92.409  -60.935  54.734  1
500737  92.449  -60.950  54.732  1
500738  92.489  -60.965  54.722  1
500739  92.528  -60.974  54.708  1
500740  92.571  -60.983  54.689  1
500741  92.609  -60.989  54.669  1
500742  92.649  -60.995  54.649  1
500743  92.690  -61.000  54.634  1
500744  92.730  -61.005  54.619  1
500745  92.771  -61.011  54.597  1
500746  92.812  -61.016  54.570  1
500747  92.853  -61.021  54.537  1
500748  92.894  -61.027  54.505  1
500749  92.934  -61.032  54.503  1
500750  92.975  -61.037  54.504  1
500751  93.015  -61.042  54.498  1
500752  93.056  -61.048  54.484  1
500753  93.097  -61.052  54.467  1
500754  93.138  -61.058  54.451  1
500755  93.179  -61.063  54.444  1
500756  93.219  -61.068  54.437  1
500757  93.260  -61.074  54.430  1
500758  93.300  -61.079  54.423  1
500759  93.341  -61.084  54.414  1
500760  93.382  -61.089  54.401  1
500761  93.423  -61.095  54.391  1
500762  93.464  -61.100  54.382  1
500763  93.503  -61.109  54.372  1
500764  93.543  -61.120  54.359  1
500765  93.582  -61.131  54.345  1
500766  93.622  -61.142  54.328  1
500767  93.661  -61.152  54.312  1
500768  93.701  -61.162  54.298  1
500769  93.741  -61.172  54.285  1
500770  93.780  -61.183  54.265  1
500771  93.822  -61.193  54.241  1
500772  93.864  -61.203  54.216  1
500773  93.908  -61.213  54.194  1
500774  93.951  -61.223  54.179  1
500775  93.993  -61.230  54.171  1
500776  94.035  -61.237  54.156  1
500777  94.077  -61.243  54.135  1
500778  94.119  -61.250  54.109  1
500779  94.161  -61.256  54.082  1
500780  94.204  -61.263  54.057  1
500781  94.246  -61.270  54.033  1
500782  94.288  -61.276  54.010  1
500783  94.330  -61.284  53.987  1
500784  94.372  -61.293  53.965  1
500785  94.415  -61.302  53.940  1
500786  94.457  -61.309  53.915  1
500787  94.498  -61.315  53.888  1
500788  94.539  -61.321  53.859  1
500789  94.577  -61.324  53.827  1
500790  94.615  -61.328  53.794  1
500791  94.654  -61.331  53.763  1
500792  94.692  -61.335  53.726  1
500793  94.731  -61.339  53.690  1
500794  94.759  -61.337  53.656  1
500795  94.789  -61.340  53.622  1
500796  94.826  -61.346  53.590  1
500797  94.862  -61.354  53.557  1
500798  94.898  -61.361  53.521  1
500799  94.934  -61.368  53.484  1
500800  94.970  -61.376  53.448  1
500801  95.006  -61.383  53.413  1
500802  95.043  -61.390  53.381  1
500803  95.080  -61.393  53.349  1
500804  95.117  -61.395  53.316  1
500805  95.155  -61.400  53.282  1
500806  95.193  -61.405  53.248  1
500807  95.231  -61.409  53.215  1
500808  95.268  -61.415  53.183  1
500809  95.306  -61.421  53.152  1
500810  95.344  -61.427  53.123  1
500811  95.382  -61.434  53.092  1
500812  95.419  -61.440  53.065  1
500813  95.456  -61.446  53.039  1
500814  95.491  -61.450  53.011  1
500815  95.529  -61.454  52.983  1
500816  95.566  -61.458  52.954  1
500817  95.604  -61.461  52.922  1
500818  95.641  -61.465  52.892  1
500819  95.679  -61.468  52.862  1
500820  95.717  -61.472  52.833  1
500821  95.755  -61.475  52.802  1
500822  95.793  -61.480  52.768  1
500823  95.831  -61.484  52.733  1
500824  95.869  -61.487  52.700  1
500825  95.909  -61.491  52.667  1
500826  95.952  -61.494  52.633  1
500827  95.992  -61.497  52.597  1
500828  96.032  -61.500  52.559  1
500829  96.073  -61.503  52.518  1
500830  96.113  -61.506  52.478  1
500831  96.153  -61.509  52.441  1
500832  96.193  -61.512  52.405  1
500833  96.234  -61.515  52.372  1
500834  96.274  -61.518  52.336  1
500835  96.314  -61.521  52.298  1
500836  96.351  -61.523  52.257  1
500837  96.383  -61.532  52.214  1
500838  96.414  -61.544  52.171  1
500839  96.445  -61.556  52.130  1
500840  96.476  -61.567  52.089  1
500841  96.508  -61.578  52.049  1
500842  96.545  -61.584  52.009  1
500843  96.586  -61.589  51.967  1
500844  96.624  -61.594  51.928  1
500845  96.661  -61.601  51.889  1
500846  96.704  -61.603  51.851  1
500847  96.751  -61.602  51.814  1
500848  96.798  -61.601  51.780  1
500849  96.842  -61.600  51.745  1
500850  96.882  -61.597  51.711  1
500851  96.922  -61.595  51.676  1
500852  96.962  -61.592  51.642  1
500853  97.002  -61.590  51.610  1
500854  97.041  -61.588  51.577  1
500855  97.081  -61.584  51.542  1
500856  97.121  -61.582  51.508  1
500857  97.161  -61.580  51.473  1
500858  97.191  -61.585  51.441  1
500859  97.222  -61.590  51.408  1
500860  97.252  -61.594  51.373  1
500861  97.304  -61.591  51.338  1
500862  97.358  -61.585  51.301  1
500863  97.407  -61.583  51.261  1
500864  97.447  -61.588  51.220  1
500865  97.486  -61.594  51.179  1
500866  97.525  -61.600  51.139  1
500867  97.565  -61.606  51.099  1
500868  97.603  -61.613  51.060  1
500869  97.643  -61.619  51.018  1
500870  97.685  -61.613  50.975  1
500871  97.729  -61.606  50.932  1
500872  97.775  -61.604  50.890  1
500873  97.823  -61.609  50.847  1
500874  97.847  -61.616  50.805  1
500875  97.870  -61.631  50.762  1
500876  97.894  -61.646  50.720  1
500877  97.918  -61.662  50.679  1
500878  97.942  -61.678  50.639  1
500879  97.966  -61.693  50.599  1
500880  97.991  -61.709  50.559  1
500881  98.015  -61.725  50.519  1
500882  98.039  -61.740  50.480  1
500883  98.063  -61.756  50.440  1
500884  98.087  -61.771  50.399  1
500885  98.111  -61.787  50.361  1
500886  98.136  -61.803  50.323  1
500887  98.160  -61.818  50.285  1
500888  98.184  -61.834  50.247  1
501331  87.996  -59.516  56.071  1
501332  88.038  -59.520  56.042  1
501333  88.090  -59.527  56.013  1
501334  88.142  -59.534  55.985  1
501335  88.194  -59.541  55.956  1
501336  88.246  -59.547  55.928  1
501337  88.298  -59.555  55.898  1
501338  88.350  -59.562  55.871  1
501339  88.402  -59.569  55.843  1
501340  88.454  -59.576  55.814  1
501341  88.506  -59.582  55.786  1
501342  88.558  -59.589  55.757  1
501343  88.610  -59.596  55.729  1
501344  88.662  -59.603  55.702  1
501345  88.714  -59.610  55.677  1
501346  88.766  -59.617  55.651  1
501347  88.824  -59.607  55.626  1
501348  88.883  -59.591  55.602  1
501349  88.939  -59.580  55.578  1
501350  88.981  -59.596  55.555  1
501351  89.021  -59.616  55.533  1
501352  89.061  -59.636  55.512  1
501353  89.101  -59.656  55.491  1
501354  89.141  -59.676  55.470  1
501355  89.182  -59.696  55.449  1
501356  89.222  -59.716  55.429  1
501357  89.262  -59.736  55.410  1
501358  89.300  -59.755  55.392  1
501359  89.311  -59.764  55.375  1
501360  89.323  -59.773  55.358  1
501361  89.348  -59.784  55.343  1
501362  89.389  -59.798  55.327  1
501363  89.429  -59.814  55.313  1
501364  89.469  -59.828  55.300  1
501365  89.510  -59.843  55.286  1
501366  89.550  -59.858  55.273  1
501367  89.592  -59.876  55.260  1
501368  89.634  -59.897  55.248  1
501369  89.677  -59.918  55.237  1
501370  89.720  -59.939  55.227  1
501371  89.763  -59.961  55.217  1
501372  89.805  -59.983  55.208  1
501373  89.848  -60.004  55.200  1
501374  89.891  -60.026  55.193  1
501375  89.934  -60.047  55.184  1
501376  89.978  -60.068  55.176  1
501377  90.024  -60.087  55.168  1
501378  90.070  -60.108  55.159  1
501379  90.115  -60.128  55.150  1
501380  90.161  -60.148  55.140  1
501381  90.206  -60.168  55.129  1
501382  90.251  -60.188  55.118  1
501383  90.297  -60.209  55.106  1
501384  90.342  -60.228  55.094  1
501385  90.388  -60.249  55.082  1
501386  90.434  -60.269  55.069  1
501387  90.478  -60.285  55.058  1
501388  90.523  -60.297  55.047  1
501389  90.567  -60.309  55.038  1
501390  90.611  -60.322  55.031  1
501391  90.656  -60.334  55.026  1
501392  90.699  -60.344  55.020  1
501393  90.743  -60.353  55.017  1
501394  90.786  -60.363  55.021  1
501395  90.829  -60.372  55.023  1
501396  90.872  -60.382  55.025  1
501397  90.912  -60.403  55.027  1
501398  90.948  -60.437  55.026  1
501399  90.987  -60.457  55.024  1
501400  91.029  -60.464  55.026  1
501401  91.072  -60.472  55.032  1
501402  91.114  -60.478  55.040  1
501403  91.157  -60.485  55.048  1
501404  91.199  -60.492  55.054  1
501405  91.242  -60.499  55.058  1
501406  91.284  -60.506  55.058  1
501407  91.326  -60.513  55.055  1
501408  91.369  -60.520  55.048  1
501409  91.412  -60.527  55.038  1
501410  91.454  -60.534  55.028  1
501411  91.496  -60.541  55.018  1
501412  91.538  -60.547  55.007  1
501413  91.580  -60.556  54.996  1
501414  91.619  -60.566  54.985  1
501415  91.659  -60.575  54.977  1
501416  91.699  -60.584  54.976  1
501417  91.738  -60.594  54.981  1
501418  91.778  -60.603  54.986  1
501419  91.817  -60.613  54.987  1
501420  91.850  -60.623  54.982  1
501421  91.855  -60.639  54.970  1
501422  91.861  -60.655  54.950  1
501423  91.867  -60.671  54.922  1
501424  91.896  -60.686  54.890  1
501425  91.936  -60.702  54.868  1
501426  91.976  -60.717  54.854  1
501427  92.016  -60.732  54.842  1
501428  92.056  -60.748  54.825  1
501429  92.096  -60.763  54.805  1
501430  92.136  -60.779  54.799  1
501431  92.176  -60.795  54.796  1
501432  92.216  -60.810  54.792  1
501433  92.256  -60.826  54.786  1
501434  92.296  -60.841  54.774  1
501435  92.336  -60.856  54.753  1
501436  92.376  -60.872  54.733  1
501437  92.416  -60.887  54.719  1
501438  92.456  -60.903  54.711  1
501439  92.496  -60.918  54.706  1
501440  92.534  -60.935  54.691  1
501441  92.576  -60.945  54.674  1
501442  92.617  -60.951  54.654  1
501443  92.658  -60.956  54.633  1
501444  92.699  -60.962  54.614  1
501445  92.740  -60.967  54.600  1
501446  92.780  -60.973  54.579  1
501447  92.821  -60.978  54.550  1
501448  92.862  -60.983  54.520  1
501449  92.903  -60.989  54.495  1
501450  92.943  -60.994  54.500  1
501451  92.984  -60.999  54.500  1
501452  93.025  -61.005  54.493  1
501453  93.065  -61.010  54.481  1
501454  93.106  -61.015  54.472  1
501455  93.147  -61.020  54.470  1
501456  93.188  -61.026  54.464  1
501457  93.228  -61.031  54.456  1
501458  93.269  -61.036  54.447  1
501459  93.310  -61.042  54.439  1
501460  93.350  -61.047  54.430  1
501461  93.391  -61.052  54.417  1
501462  93.432  -61.058  54.408  1
501463  93.473  -61.063  54.398  1
501464  93.512  -61.071  54.386  1
501465  93.552  -61.083  54.371  1
501466  93.591  -61.093  54.353  1
501467  93.631  -61.103  54.334  1
501468  93.671  -61.114  54.317  1
501469  93.710  -61.124  54.301  1
501470  93.750  -61.134  54.283  1
501471  93.789  -61.144  54.259  1
501472  93.831  -61.154  54.235  1
501473  93.874  -61.165  54.215  1
501474  93.917  -61.174  54.201  1
501475  93.961  -61.185  54.194  1
501476  94.003  -61.194  54.187  1
501477  94.046  -61.201  54.175  1
501478  94.088  -61.208  54.155  1
501479  94.130  -61.214  54.130  1
501480  94.172  -61.221  54.104  1
501481  94.214  -61.227  54.079  1
501482  94.257  -61.233  54.051  1
501483  94.298  -61.242  54.022  1
501484  94.341  -61.250  53.994  1
501485  94.384  -61.259  53.966  1
501486  94.426  -61.268  53.939  1
501487  94.468  -61.276  53.912  1
501488  94.509  -61.282  53.884  1
501489  94.551  -61.289  53.855  1
501490  94.592  -61.296  53.825  1
501491  94.631  -61.299  53.794  1
501492  94.669  -61.302  53.761  1
501493  94.707  -61.306  53.723  1
501494  94.744  -61.309  53.687  1
501495  94.770  -61.307  53.653  1
501496  94.797  -61.306  53.621  1
501497  94.833  -61.312  53.588  1
501498  94.869  -61.319  53.554  1
501499  94.905  -61.327  53.516  1
501500  94.942  -61.334  53.478  1
501501  94.978  -61.341  53.441  1
501502  95.014  -61.349  53.406  1
501503  95.051  -61.351  53.372  1
501504  95.089  -61.354  53.338  1
501505  95.126  -61.356  53.304  1
501506  95.164  -61.360  53.268  1
501507  95.201  -61.365  53.233  1
501508  95.239  -61.372  53.200  1
501509  95.276  -61.378  53.167  1
501510  95.314  -61.385  53.136  1
501511  95.352  -61.392  53.106  1
501512  95.389  -61.398  53.074  1
501513  95.427  -61.405  53.043  1
501514  95.463  -61.409  53.013  1
501515  95.498  -61.414  52.983  1
501516  95.534  -61.418  52.954  1
501517  95.572  -61.422  52.925  1
501518  95.610  -61.425  52.894  1
501519  95.647  -61.428  52.865  1
501520  95.685  -61.432  52.836  1
501521  95.723  -61.435  52.807  1
501522  95.760  -61.439  52.779  1
501523  95.798  -61.443  52.748  1
501524  95.835  -61.446  52.715  1
501525  95.873  -61.450  52.683  1
501526  95.913  -61.453  52.651  1
501527  95.953  -61.456  52.616  1
501528  95.994  -61.459  52.579  1
501529  96.034  -61.462  52.539  1
501530  96.075  -61.465  52.499  1
501531  96.115  -61.468  52.459  1
501532  96.155  -61.471  52.422  1
501533  96.195  -61.474  52.389  1
501534  96.236  -61.477  52.357  1
501535  96.276  -61.480  52.324  1
501536  96.316  -61.483  52.288  1
501537  96.357  -61.486  52.249  1
501538  96.391  -61.493  52.208  1
501539  96.421  -61.505  52.166  1
501540  96.453  -61.516  52.126  1
501541  96.484  -61.528  52.087  1
501542  96.515  -61.539  52.047  1
501543  96.546  -61.550  52.008  1
501544  96.584  -61.556  51.969  1
501545  96.623  -61.562  51.930  1
501546  96.663  -61.566  51.891  1
501547  96.710  -61.565  51.852  1
501548  96.757  -61.564  51.814  1
501549  96.804  -61.563  51.779  1
501550  96.847  -61.562  51.743  1
501551  96.886  -61.559  51.708  1
501552  96.926  -61.557  51.673  1
501553  96.966  -61.554  51.637  1
501554  97.006  -61.552  51.603  1
501555  97.045  -61.550  51.568  1
501556  97.085  -61.547  51.533  1
501557  97.125  -61.544  51.499  1
501558  97.165  -61.542  51.466  1
501559  97.204  -61.541  51.434  1
501560  97.234  -61.545  51.400  1
501561  97.283  -61.542  51.364  1
501562  97.327  -61.544  51.327  1
501563  97.367  -61.550  51.289  1
501564  97.406  -61.556  51.249  1
501565  97.445  -61.562  51.207  1
501566  97.485  -61.568  51.167  1
501567  97.524  -61.574  51.128  1
501568  97.563  -61.580  51.089  1
501569  97.602  -61.585  51.051  1
501570  97.644  -61.581  51.010  1
501571  97.687  -61.574  50.968  1
501572  97.731  -61.566  50.925  1
501573  97.779  -61.569  50.882  1
501574  97.828  -61.575  50.840  1
501575  97.851  -61.581  50.799  1
501576  97.871  -61.595  50.758  1
501577  97.895  -61.611  50.717  1
501578  97.920  -61.627  50.677  1
501579  97.944  -61.642  50.636  1
501580  97.968  -61.658  50.597  1
501581  97.992  -61.673  50.558  1
501582  98.016  -61.689  50.519  1
501583  98.040  -61.705  50.480  1
501584  98.065  -61.720  50.441  1
501585  98.089  -61.736  50.401  1
501586  98.113  -61.751  50.363  1
501587  98.137  -61.767  50.325  1
501588  98.161  -61.783  50.288  1
502032  88.012  -59.469  56.079  1
502033  88.065  -59.476  56.051  1
502034  88.117  -59.483  56.023  1
502035  88.169  -59.490  55.995  1
502036  88.221  -59.497  55.968  1
502037  88.273  -59.504  55.940  1
502038  88.325  -59.510  55.911  1
502039  88.377  -59.518  55.884  1
502040  88.429  -59.525  55.857  1
502041  88.481  -59.532  55.830  1
502042  88.533  -59.538  55.801  1
502043  88.585  -59.545  55.773  1
502044  88.637  -59.552  55.744  1
502045  88.689  -59.559  55.716  1
502046  88.741  -59.566  55.690  1
502047  88.793  -59.573  55.664  1
502048  88.852  -59.558  55.639  1
502049  88.910  -59.544  55.614  1
502050  88.961  -59.544  55.591  1
502051  89.000  -59.564  55.568  1
502052  89.041  -59.584  55.546  1
502053  89.081  -59.604  55.526  1
502054  89.121  -59.624  55.505  1
502055  89.161  -59.644  55.485  1
502056  89.201  -59.664  55.465  1
502057  89.241  -59.684  55.445  1
502058  89.281  -59.704  55.426  1
502059  89.321  -59.723  55.408  1
502060  89.333  -59.732  55.392  1
502061  89.344  -59.741  55.376  1
502062  89.363  -59.751  55.361  1
502063  89.403  -59.766  55.346  1
502064  89.444  -59.781  55.333  1
502065  89.484  -59.795  55.321  1
502066  89.525  -59.811  55.308  1
502067  89.565  -59.825  55.296  1
502068  89.606  -59.840  55.283  1
502069  89.648  -59.860  55.272  1
502070  89.691  -59.882  55.261  1
502071  89.734  -59.903  55.252  1
502072  89.776  -59.924  55.243  1
502073  89.819  -59.946  55.234  1
502074  89.862  -59.967  55.226  1
502075  89.904  -59.989  55.219  1
502076  89.948  -60.010  55.211  1
502077  89.993  -60.030  55.202  1
502078  90.039  -60.050  55.193  1
502079  90.085  -60.071  55.184  1
502080  90.130  -60.090  55.175  1
502081  90.176  -60.111  55.164  1
502082  90.221  -60.130  55.153  1
502083  90.266  -60.151  55.140  1
502084  90.312  -60.171  55.127  1
502085  90.358  -60.191  55.114  1
502086  90.402  -60.207  55.100  1
502087  90.447  -60.219  55.087  1
502088  90.491  -60.231  55.073  1
502089  90.535  -60.243  55.062  1
502090  90.580  -60.256  55.051  1
502091  90.624  -60.267  55.042  1
502092  90.669  -60.279  55.035  1
502093  90.713  -60.291  55.030  1
502094  90.756  -60.301  55.025  1
502095  90.799  -60.310  55.026  1
502096  90.842  -60.320  55.029  1
502097  90.886  -60.330  55.034  1
502098  90.925  -60.354  55.038  1
502099  90.961  -60.387  55.039  1
502100  90.998  -60.416  55.036  1
502101  91.040  -60.423  55.035  1
502102  91.083  -60.430  55.037  1
502103  91.125  -60.437  55.044  1
502104  91.167  -60.444  55.049  1
502105  91.210  -60.450  55.052  1
502106  91.252  -60.458  55.055  1
502107  91.295  -60.465  55.055  1
502108  91.337  -60.472  55.052  1
502109  91.380  -60.478  55.045  1
502110  91.422  -60.485  55.036  1
502111  91.464  -60.492  55.027  1
502112  91.507  -60.499  55.017  1
502113  91.549  -60.506  55.006  1
502114  91.592  -60.513  54.996  1
502115  91.634  -60.520  54.982  1
502116  91.677  -60.527  54.970  1
502117  91.718  -60.535  54.964  1
502118  91.758  -60.544  54.965  1
502119  91.798  -60.553  54.971  1
502120  91.837  -60.563  54.974  1
502121  91.858  -60.576  54.971  1
502122  91.864  -60.591  54.962  1
502123  91.869  -60.607  54.946  1
502124  91.875  -60.623  54.922  1
502125  91.903  -60.639  54.891  1
502126  91.943  -60.654  54.868  1
502127  91.983  -60.670  54.854  1
502128  92.023  -60.685  54.843  1
502129  92.063  -60.701  54.829  1
502130  92.102  -60.716  54.810  1
502131  92.143  -60.732  54.797  1
502132  92.182  -60.748  54.793  1
502133  92.223  -60.763  54.791  1
502134  92.263  -60.778  54.787  1
502135  92.302  -60.794  54.780  1
502136  92.343  -60.809  54.762  1
502137  92.382  -60.825  54.736  1
502138  92.423  -60.840  54.711  1
502139  92.458  -60.858  54.694  1
502140  92.493  -60.877  54.688  1
502141  92.536  -60.889  54.674  1
502142  92.581  -60.898  54.659  1
502143  92.624  -60.905  54.641  1
502144  92.664  -60.911  54.621  1
502145  92.705  -60.917  54.600  1
502146  92.746  -60.923  54.582  1
502147  92.787  -60.929  54.559  1
502148  92.828  -60.935  54.532  1
502149  92.869  -60.940  54.505  1
502150  92.910  -60.946  54.489  1
502151  92.951  -60.952  54.497  1
502152  92.992  -60.958  54.499  1
502153  93.032  -60.964  54.495  1
502154  93.074  -60.970  54.489  1
502155  93.115  -60.976  54.485  1
502156  93.155  -60.981  54.479  1
502157  93.196  -60.987  54.472  1
502158  93.237  -60.993  54.466  1
502159  93.278  -60.998  54.459  1
502160  93.319  -61.004  54.449  1
502161  93.360  -61.009  54.436  1
502162  93.400  -61.014  54.424  1
502163  93.441  -61.020  54.415  1
502164  93.482  -61.025  54.405  1
502165  93.521  -61.034  54.390  1
502166  93.561  -61.045  54.372  1
502167  93.601  -61.055  54.353  1
502168  93.640  -61.064  54.334  1
502169  93.680  -61.075  54.316  1
502170  93.720  -61.085  54.297  1
502171  93.759  -61.096  54.273  1
502172  93.799  -61.105  54.248  1
502173  93.841  -61.116  54.227  1
502174  93.884  -61.126  54.215  1
502175  93.927  -61.136  54.210  1
502176  93.970  -61.146  54.207  1
502177  94.013  -61.156  54.201  1
502178  94.056  -61.165  54.190  1
502179  94.098  -61.171  54.172  1
502180  94.140  -61.178  54.149  1
502181  94.183  -61.185  54.124  1
502182  94.225  -61.191  54.097  1
502183  94.267  -61.199  54.067  1
502184  94.310  -61.208  54.035  1
502185  94.352  -61.217  54.002  1
502186  94.394  -61.226  53.969  1
502187  94.436  -61.235  53.939  1
502188  94.479  -61.243  53.908  1
502189  94.520  -61.249  53.879  1
502190  94.561  -61.255  53.850  1
502191  94.603  -61.262  53.823  1
502192  94.644  -61.269  53.793  1
502193  94.684  -61.274  53.758  1
502194  94.723  -61.277  53.721  1
502195  94.755  -61.278  53.684  1
502196  94.782  -61.276  53.649  1
502197  94.809  -61.274  53.615  1
502198  94.840  -61.277  53.579  1
502199  94.877  -61.285  53.544  1
502200  94.913  -61.293  53.506  1
502201  94.949  -61.299  53.468  1
502202  94.985  -61.307  53.431  1
502203  95.022  -61.309  53.396  1
502204  95.060  -61.312  53.361  1
502205  95.097  -61.315  53.327  1
502206  95.134  -61.318  53.292  1
502207  95.171  -61.324  53.255  1
502208  95.209  -61.330  53.220  1
502209  95.247  -61.337  53.186  1
502210  95.284  -61.343  53.153  1
502211  95.322  -61.349  53.122  1
502212  95.359  -61.356  53.091  1
502213  95.397  -61.363  53.058  1
502214  95.434  -61.368  53.026  1
502215  95.469  -61.373  52.994  1
502216  95.505  -61.378  52.964  1
502217  95.540  -61.382  52.933  1
502218  95.578  -61.386  52.903  1
502219  95.615  -61.389  52.871  1
502220  95.653  -61.393  52.841  1
502221  95.691  -61.396  52.810  1
502222  95.728  -61.400  52.781  1
502223  95.766  -61.403  52.753  1
502224  95.804  -61.406  52.726  1
502225  95.841  -61.410  52.696  1
502226  95.879  -61.414  52.665  1
502227  95.917  -61.418  52.631  1
502228  95.957  -61.421  52.596  1
502229  95.997  -61.424  52.557  1
502230  96.038  -61.427  52.517  1
502231  96.078  -61.430  52.476  1
502232  96.118  -61.432  52.437  1
502233  96.159  -61.435  52.401  1
502234  96.199  -61.438  52.369  1
502235  96.239  -61.441  52.338  1
502236  96.279  -61.444  52.306  1
502237  96.320  -61.447  52.274  1
502238  96.360  -61.450  52.238  1
502239  96.400  -61.453  52.199  1
502240  96.431  -61.463  52.159  1
502241  96.461  -61.476  52.120  1
502242  96.491  -61.488  52.081  1
502243  96.522  -61.500  52.043  1
502244  96.553  -61.512  52.005  1
502245  96.584  -61.523  51.968  1
502246  96.622  -61.529  51.930  1
502247  96.669  -61.528  51.891  1
502248  96.716  -61.528  51.853  1
502249  96.762  -61.527  51.816  1
502250  96.810  -61.526  51.780  1
502251  96.851  -61.524  51.744  1
502252  96.890  -61.522  51.708  1
502253  96.930  -61.519  51.672  1
502254  96.970  -61.516  51.636  1
502255  97.010  -61.514  51.600  1
502256  97.049  -61.512  51.564  1
502257  97.089  -61.509  51.528  1
502258  97.129  -61.506  51.493  1
502259  97.169  -61.505  51.460  1
502260  97.208  -61.503  51.427  1
502261  97.247  -61.505  51.392  1
502262  97.287  -61.511  51.355  1
502263  97.326  -61.517  51.317  1
502264  97.365  -61.523  51.278  1
502265  97.404  -61.529  51.237  1
502266  97.444  -61.535  51.196  1
502267  97.483  -61.541  51.155  1
502268  97.522  -61.547  51.116  1
502269  97.562  -61.553  51.078  1
502270  97.603  -61.550  51.039  1
502271  97.647  -61.542  50.999  1
502272  97.690  -61.534  50.958  1
502273  97.735  -61.531  50.917  1
502274  97.784  -61.535  50.875  1
502275  97.832  -61.540  50.835  1
502276  97.855  -61.547  50.795  1
502277  97.873  -61.560  50.755  1
502278  97.897  -61.575  50.715  1
502279  97.922  -61.591  50.675  1
502280  97.946  -61.607  50.635  1
502281  97.970  -61.622  50.596  1
502282  97.994  -61.638  50.558  1
502283  98.018  -61.653  50.520  1
502284  98.042  -61.669  50.481  1
502285  98.067  -61.685  50.442  1
502286  98.091  -61.700  50.403  1
502287  98.115  -61.716  50.367  1
502288  98.139  -61.732  50.330  1
502733  88.039  -59.425  56.086  1
502734  88.092  -59.432  56.060  1
502735  88.143  -59.439  56.033  1
502736  88.195  -59.446  56.006  1
502737  88.248  -59.453  55.979  1
502738  88.299  -59.460  55.951  1
502739  88.351  -59.466  55.925  1
502740  88.404  -59.473  55.898  1
502741  88.456  -59.481  55.872  1
502742  88.507  -59.488  55.846  1
502743  88.560  -59.494  55.817  1
502744  88.612  -59.501  55.789  1
502745  88.664  -59.508  55.759  1
502746  88.716  -59.515  55.731  1
502747  88.768  -59.522  55.704  1
502748  88.821  -59.526  55.678  1
502749  88.880  -59.510  55.653  1
502750  88.937  -59.498  55.629  1
502751  88.980  -59.512  55.605  1
502752  89.020  -59.532  55.583  1
502753  89.060  -59.552  55.562  1
502754  89.100  -59.572  55.541  1
502755  89.140  -59.591  55.521  1
502756  89.181  -59.612  55.501  1
502757  89.221  -59.632  55.482  1
502758  89.261  -59.652  55.462  1
502759  89.301  -59.672  55.444  1
502760  89.341  -59.692  55.427  1
502761  89.354  -59.701  55.410  1
502762  89.366  -59.710  55.396  1
502763  89.378  -59.719  55.381  1
502764  89.418  -59.733  55.368  1
502765  89.459  -59.748  55.356  1
502766  89.499  -59.763  55.345  1
502767  89.540  -59.777  55.334  1
502768  89.581  -59.792  55.323  1
502769  89.621  -59.807  55.311  1
502770  89.662  -59.823  55.300  1
502771  89.704  -59.845  55.290  1
502772  89.747  -59.867  55.281  1
502773  89.790  -59.888  55.273  1
502774  89.833  -59.909  55.264  1
502775  89.875  -59.931  55.257  1
502776  89.918  -59.952  55.249  1
502777  89.963  -59.973  55.241  1
502778  90.009  -59.992  55.232  1
502779  90.054  -60.013  55.222  1
502780  90.100  -60.033  55.213  1
502781  90.145  -60.053  55.202  1
502782  90.191  -60.073  55.190  1
502783  90.236  -60.093  55.178  1
502784  90.282  -60.114  55.165  1
502785  90.327  -60.129  55.150  1
502786  90.371  -60.141  55.136  1
502787  90.415  -60.153  55.121  1
502788  90.460  -60.165  55.105  1
502789  90.504  -60.177  55.091  1
502790  90.548  -60.190  55.077  1
502791  90.593  -60.201  55.064  1
502792  90.637  -60.213  55.054  1
502793  90.681  -60.225  55.046  1
502794  90.726  -60.237  55.038  1
502795  90.770  -60.249  55.033  1
502796  90.813  -60.258  55.032  1
502797  90.856  -60.268  55.033  1
502798  90.899  -60.277  55.037  1
502799  90.937  -60.304  55.041  1
502800  90.973  -60.337  55.042  1
502801  91.010  -60.370  55.041  1
502802  91.051  -60.381  55.039  1
502803  91.093  -60.388  55.039  1
502804  91.136  -60.395  55.042  1
502805  91.178  -60.403  55.044  1
502806  91.221  -60.409  55.047  1
502807  91.263  -60.416  55.049  1
502808  91.306  -60.423  55.049  1
502809  91.348  -60.430  55.048  1
502810  91.390  -60.437  55.045  1
502811  91.433  -60.444  55.038  1
502812  91.475  -60.451  55.030  1
502813  91.518  -60.458  55.019  1
502814  91.560  -60.465  55.007  1
502815  91.602  -60.472  54.995  1
502816  91.645  -60.478  54.980  1
502817  91.687  -60.485  54.965  1
502818  91.730  -60.493  54.953  1
502819  91.773  -60.500  54.949  1
502820  91.815  -60.506  54.956  1
502821  91.857  -60.513  54.960  1
502822  91.866  -60.528  54.958  1
502823  91.872  -60.544  54.950  1
502824  91.878  -60.560  54.936  1
502825  91.883  -60.576  54.915  1
502826  91.910  -60.592  54.887  1
502827  91.949  -60.607  54.863  1
502828  91.990  -60.622  54.847  1
502829  92.029  -60.638  54.837  1
502830  92.069  -60.654  54.826  1
502831  92.109  -60.669  54.810  1
502832  92.149  -60.685  54.795  1
502833  92.189  -60.700  54.786  1
502834  92.229  -60.716  54.782  1
502835  92.269  -60.731  54.780  1
502836  92.309  -60.746  54.774  1
502837  92.348  -60.763  54.762  1
502838  92.382  -60.782  54.742  1
502839  92.418  -60.801  54.719  1
502840  92.453  -60.820  54.693  1
502841  92.496  -60.832  54.669  1
502842  92.541  -60.841  54.656  1
502843  92.585  -60.851  54.644  1
502844  92.630  -60.860  54.629  1
502845  92.671  -60.866  54.611  1
502846  92.712  -60.872  54.590  1
502847  92.753  -60.878  54.567  1
502848  92.794  -60.883  54.541  1
502849  92.835  -60.889  54.515  1
502850  92.875  -60.895  54.493  1
502851  92.916  -60.901  54.486  1
502852  92.957  -60.907  54.495  1
502853  92.998  -60.913  54.498  1
502854  93.039  -60.919  54.498  1
502855  93.080  -60.924  54.496  1
502856  93.121  -60.930  54.493  1
502857  93.162  -60.936  54.484  1
502858  93.203  -60.942  54.474  1
502859  93.243  -60.948  54.466  1
502860  93.285  -60.954  54.457  1
502861  93.326  -60.960  54.447  1
502862  93.366  -60.965  54.435  1
502863  93.407  -60.971  54.423  1
502864  93.448  -60.977  54.414  1
502865  93.489  -60.983  54.403  1
502866  93.531  -60.995  54.389  1
502867  93.571  -61.006  54.370  1
502868  93.610  -61.016  54.347  1
502869  93.650  -61.027  54.326  1
502870  93.690  -61.036  54.307  1
502871  93.729  -61.047  54.287  1
502872  93.769  -61.057  54.265  1
502873  93.808  -61.067  54.244  1
502874  93.851  -61.077  54.226  1
502875  93.894  -61.087  54.216  1
502876  93.937  -61.098  54.214  1
502877  93.980  -61.108  54.212  1
502878  94.024  -61.118  54.208  1
502879  94.066  -61.128  54.199  1
502880  94.109  -61.136  54.185  1
502881  94.151  -61.143  54.165  1
502882  94.193  -61.149  54.140  1
502883  94.236  -61.156  54.111  1
502884  94.278  -61.165  54.080  1
502885  94.320  -61.174  54.047  1
502886  94.362  -61.183  54.012  1
502887  94.405  -61.193  53.975  1
502888  94.448  -61.202  53.941  1
502889  94.489  -61.209  53.906  1
502890  94.531  -61.216  53.874  1
502891  94.572  -61.223  53.846  1
502892  94.614  -61.229  53.819  1
502893  94.655  -61.236  53.789  1
502894  94.697  -61.243  53.754  1
502895  94.738  -61.249  53.717  1
502896  94.766  -61.247  53.679  1
502897  94.793  -61.246  53.643  1
502898  94.820  -61.244  53.609  1
502899  94.848  -61.243  53.571  1
502900  94.884  -61.251  53.535  1
502901  94.920  -61.258  53.498  1
502902  94.956  -61.265  53.460  1
502903  94.993  -61.268  53.424  1
502904  95.031  -61.271  53.387  1
502905  95.067  -61.274  53.351  1
502906  95.104  -61.279  53.317  1
502907  95.140  -61.283  53.282  1
502908  95.178  -61.288  53.245  1
502909  95.217  -61.294  53.211  1
502910  95.254  -61.301  53.177  1
502911  95.292  -61.308  53.144  1
502912  95.330  -61.314  53.113  1
502913  95.368  -61.321  53.081  1
502914  95.405  -61.328  53.048  1
502915  95.441  -61.332  53.015  1
502916  95.476  -61.337  52.983  1
502917  95.512  -61.341  52.951  1
502918  95.547  -61.346  52.920  1
502919  95.584  -61.349  52.889  1
502920  95.621  -61.353  52.857  1
502921  95.659  -61.357  52.825  1
502922  95.696  -61.360  52.794  1
502923  95.734  -61.364  52.763  1
502924  95.772  -61.367  52.734  1
502925  95.810  -61.371  52.706  1
502926  95.847  -61.375  52.675  1
502927  95.884  -61.380  52.642  1
502928  95.922  -61.384  52.606  1
502929  95.962  -61.387  52.569  1
502930  96.003  -61.390  52.530  1
502931  96.043  -61.393  52.492  1
502932  96.083  -61.395  52.453  1
502933  96.123  -61.398  52.415  1
502934  96.164  -61.401  52.379  1
502935  96.204  -61.404  52.345  1
502936  96.244  -61.407  52.314  1
502937  96.285  -61.410  52.284  1
502938  96.325  -61.414  52.254  1
502939  96.365  -61.418  52.222  1
502940  96.409  -61.416  52.186  1
502941  96.445  -61.420  52.148  1
502942  96.477  -61.428  52.110  1
502943  96.508  -61.440  52.072  1
502944  96.538  -61.453  52.034  1
502945  96.568  -61.465  51.998  1
502946  96.597  -61.478  51.964  1
502947  96.629  -61.489  51.929  1
502948  96.676  -61.488  51.892  1
502949  96.723  -61.488  51.854  1
502950  96.770  -61.487  51.819  1
502951  96.814  -61.488  51.783  1
502952  96.852  -61.493  51.747  1
502953  96.891  -61.491  51.710  1
502954  96.931  -61.490  51.674  1
502955  96.970  -61.488  51.637  1
502956  97.010  -61.487  51.602  1
502957  97.049  -61.485  51.564  1
502958  97.088  -61.484  51.526  1
502959  97.127  -61.482  51.490  1
502960  97.167  -61.481  51.454  1
502961  97.207  -61.479  51.421  1
502962  97.246  -61.478  51.384  1
502963  97.285  -61.484  51.346  1
502964  97.324  -61.491  51.307  1
502965  97.364  -61.497  51.267  1
502966  97.403  -61.502  51.226  1
502967  97.442  -61.508  51.185  1
502968  97.481  -61.514  51.145  1
502969  97.521  -61.520  51.106  1
502970  97.562  -61.518  51.067  1
502971  97.605  -61.510  51.029  1
502972  97.649  -61.502  50.990  1
502973  97.692  -61.494  50.950  1
502974  97.739  -61.497  50.910  1
502975  97.788  -61.501  50.870  1
502976  97.837  -61.506  50.831  1
502977  97.860  -61.512  50.793  1
502978  97.875  -61.525  50.754  1
502979  97.899  -61.541  50.714  1
502980  97.924  -61.556  50.674  1
502981  97.948  -61.572  50.635  1
502982  97.972  -61.588  50.596  1
502983  97.996  -61.603  50.559  1
502984  98.020  -61.619  50.521  1
502985  98.044  -61.635  50.483  1
502986  98.069  -61.650  50.445  1
502987  98.093  -61.666  50.406  1
502988  98.117  -61.681  50.370  1
503434  88.066  -59.381  56.092  1
503435  88.118  -59.388  56.067  1
503436  88.170  -59.395  56.042  1
503437  88.222  -59.402  56.016  1
503438  88.274  -59.409  55.991  1
503439  88.326  -59.416  55.964  1
503440  88.379  -59.422  55.938  1
503441  88.430  -59.429  55.913  1
503442  88.482  -59.436  55.887  1
503443  88.534  -59.444  55.861  1
503444  88.587  -59.450  55.833  1
503445  88.638  -59.457  55.804  1
503446  88.690  -59.464  55.775  1
503447  88.743  -59.471  55.746  1
503448  88.794  -59.478  55.718  1
503449  88.849  -59.477  55.692  1
503450  88.908  -59.463  55.667  1
503451  88.960  -59.460  55.643  1
503452  88.999  -59.480  55.621  1
503453  89.040  -59.500  55.599  1
503454  89.080  -59.519  55.578  1
503455  89.120  -59.540  55.558  1
503456  89.160  -59.560  55.537  1
503457  89.200  -59.580  55.518  1
503458  89.240  -59.600  55.499  1
503459  89.280  -59.620  55.480  1
503460  89.320  -59.640  55.463  1
503461  89.361  -59.660  55.447  1
503462  89.376  -59.670  55.432  1
503463  89.387  -59.679  55.418  1
503464  89.399  -59.687  55.404  1
503465  89.434  -59.701  55.392  1
503466  89.474  -59.715  55.381  1
503467  89.515  -59.730  55.372  1
503468  89.555  -59.745  55.363  1
503469  89.595  -59.760  55.353  1
503470  89.636  -59.774  55.342  1
503471  89.676  -59.789  55.331  1
503472  89.718  -59.808  55.322  1
503473  89.761  -59.830  55.313  1
503474  89.804  -59.851  55.306  1
503475  89.846  -59.873  55.298  1
503476  89.889  -59.894  55.292  1
503477  89.933  -59.915  55.284  1
503478  89.978  -59.935  55.277  1
503479  90.024  -59.955  55.268  1
503480  90.070  -59.975  55.258  1
503481  90.115  -59.996  55.248  1
503482  90.161  -60.016  55.236  1
503483  90.206  -60.036  55.224  1
503484  90.251  -60.051  55.210  1
503485  90.295  -60.063  55.194  1
503486  90.339  -60.075  55.178  1
503487  90.384  -60.087  55.161  1
503488  90.428  -60.099  55.143  1
503489  90.472  -60.112  55.126  1
503490  90.517  -60.123  55.110  1
503491  90.561  -60.135  55.094  1
503492  90.605  -60.147  55.080  1
503493  90.650  -60.159  55.068  1
503494  90.694  -60.171  55.057  1
503495  90.739  -60.184  55.047  1
503496  90.783  -60.195  55.041  1
503497  90.826  -60.206  55.037  1
503498  90.870  -60.215  55.037  1
503499  90.913  -60.224  55.039  1
503500  90.950  -60.254  55.043  1
503501  90.986  -60.287  55.043  1
503502  91.022  -60.321  55.042  1
503503  91.062  -60.340  55.040  1
503504  91.104  -60.347  55.039  1
503505  91.147  -60.354  55.040  1
503506  91.189  -60.361  55.042  1
503507  91.231  -60.368  55.045  1
503508  91.274  -60.375  55.047  1
503509  91.316  -60.381  55.047  1
503510  91.359  -60.388  55.045  1
503511  91.401  -60.396  55.043  1
503512  91.444  -60.403  55.039  1
503513  91.486  -60.409  55.033  1
503514  91.528  -60.416  55.023  1
503515  91.571  -60.423  55.009  1
503516  91.613  -60.430  54.993  1
503517  91.656  -60.437  54.976  1
503518  91.698  -60.444  54.959  1
503519  91.741  -60.451  54.944  1
503520  91.783  -60.458  54.936  1
503521  91.820  -60.466  54.941  1
503522  91.847  -60.474  54.944  1
503523  91.873  -60.482  54.941  1
503524  91.880  -60.497  54.934  1
503525  91.886  -60.513  54.921  1
503526  91.892  -60.529  54.903  1
503527  91.916  -60.544  54.878  1
503528  91.956  -60.560  54.852  1
503529  91.996  -60.575  54.835  1
503530  92.036  -60.591  54.827  1
503531  92.076  -60.607  54.819  1
503532  92.116  -60.622  54.807  1
503533  92.156  -60.638  54.792  1
503534  92.196  -60.653  54.781  1
503535  92.236  -60.668  54.775  1
503536  92.272  -60.686  54.774  1
503537  92.307  -60.706  54.771  1
503538  92.342  -60.725  54.762  1
503539  92.377  -60.744  54.745  1
503540  92.412  -60.763  54.721  1
503541  92.455  -60.774  54.691  1
503542  92.500  -60.784  54.662  1
503543  92.545  -60.794  54.644  1
503544  92.589  -60.803  54.627  1
503545  92.634  -60.813  54.611  1
503546  92.677  -60.821  54.594  1
503547  92.718  -60.826  54.577  1
503548  92.759  -60.832  54.556  1
503549  92.800  -60.839  54.533  1
503550  92.841  -60.844  54.508  1
503551  92.882  -60.850  54.485  1
503552  92.923  -60.856  54.484  1
503553  92.964  -60.862  54.491  1
503554  93.005  -60.867  54.498  1
503555  93.046  -60.873  54.503  1
503556  93.086  -60.879  54.502  1
503557  93.128  -60.885  54.495  1
503558  93.168  -60.891  54.484  1
503559  93.209  -60.897  54.472  1
503560  93.250  -60.903  54.459  1
503561  93.291  -60.908  54.448  1
503562  93.332  -60.914  54.440  1
503563  93.373  -60.920  54.428  1
503564  93.414  -60.926  54.417  1
503565  93.455  -60.932  54.407  1
503566  93.496  -60.943  54.397  1
503567  93.539  -60.955  54.384  1
503568  93.580  -60.967  54.365  1
503569  93.620  -60.978  54.342  1
503570  93.659  -60.988  54.321  1
503571  93.699  -60.998  54.300  1
503572  93.739  -61.008  54.279  1
503573  93.778  -61.019  54.260  1
503574  93.818  -61.029  54.241  1
503575  93.861  -61.039  54.224  1
503576  93.904  -61.049  54.215  1
503577  93.947  -61.059  54.214  1
503578  93.990  -61.069  54.211  1
503579  94.033  -61.080  54.208  1
503580  94.076  -61.089  54.201  1
503581  94.119  -61.099  54.189  1
503582  94.161  -61.107  54.172  1
503583  94.204  -61.114  54.149  1
503584  94.246  -61.123  54.120  1
503585  94.288  -61.132  54.089  1
503586  94.331  -61.141  54.056  1
503587  94.373  -61.150  54.022  1
503588  94.416  -61.158  53.986  1
503589  94.458  -61.168  53.951  1
503590  94.500  -61.177  53.911  1
503591  94.542  -61.183  53.874  1
503592  94.583  -61.190  53.842  1
503593  94.625  -61.196  53.811  1
503594  94.667  -61.202  53.781  1
503595  94.707  -61.209  53.746  1
503596  94.745  -61.216  53.709  1
503597  94.776  -61.217  53.672  1
503598  94.804  -61.215  53.635  1
503599  94.831  -61.213  53.601  1
503600  94.857  -61.212  53.566  1
503601  94.891  -61.216  53.531  1
503602  94.927  -61.224  53.494  1
503603  94.965  -61.227  53.455  1
503604  95.001  -61.230  53.418  1
503605  95.038  -61.234  53.380  1
503606  95.074  -61.239  53.343  1
503607  95.110  -61.243  53.309  1
503608  95.147  -61.248  53.275  1
503609  95.185  -61.253  53.238  1
503610  95.225  -61.259  53.204  1
503611  95.262  -61.265  53.170  1
503612  95.300  -61.272  53.138  1
503613  95.337  -61.279  53.107  1
503614  95.375  -61.285  53.075  1
503615  95.412  -61.291  53.042  1
503616  95.448  -61.296  53.009  1
503617  95.483  -61.300  52.976  1
503618  95.519  -61.305  52.944  1
503619  95.554  -61.309  52.912  1
503620  95.590  -61.314  52.881  1
503621  95.627  -61.318  52.849  1
503622  95.665  -61.321  52.815  1
503623  95.702  -61.324  52.782  1
503624  95.740  -61.328  52.750  1
503625  95.777  -61.331  52.719  1
503626  95.815  -61.336  52.689  1
503627  95.852  -61.340  52.657  1
503628  95.889  -61.345  52.623  1
503629  95.927  -61.349  52.587  1
503630  95.967  -61.353  52.548  1
503631  96.008  -61.355  52.511  1
503632  96.048  -61.358  52.475  1
503633  96.088  -61.361  52.438  1
503634  96.128  -61.364  52.400  1
503635  96.169  -61.367  52.364  1
503636  96.209  -61.370  52.330  1
503637  96.249  -61.374  52.297  1
503638  96.290  -61.378  52.266  1
503639  96.330  -61.381  52.235  1
503640  96.370  -61.385  52.202  1
503641  96.415  -61.381  52.168  1
503642  96.458  -61.380  52.132  1
503643  96.490  -61.388  52.096  1
503644  96.522  -61.396  52.061  1
503645  96.554  -61.405  52.027  1
503646  96.585  -61.417  51.992  1
503647  96.614  -61.430  51.957  1
503648  96.644  -61.443  51.922  1
503649  96.685  -61.447  51.887  1
503650  96.732  -61.446  51.851  1
503651  96.779  -61.445  51.817  1
503652  96.816  -61.451  51.782  1
503653  96.854  -61.457  51.747  1
503654  96.891  -61.463  51.711  1
503655  96.929  -61.465  51.675  1
503656  96.968  -61.464  51.639  1
503657  97.008  -61.462  51.604  1
503658  97.047  -61.461  51.566  1
503659  97.087  -61.459  51.527  1
503660  97.126  -61.458  51.489  1
503661  97.166  -61.456  51.450  1
503662  97.205  -61.454  51.412  1
503663  97.244  -61.452  51.375  1
503664  97.284  -61.457  51.337  1
503665  97.323  -61.463  51.298  1
503666  97.362  -61.469  51.259  1
503667  97.401  -61.475  51.218  1
503668  97.441  -61.481  51.177  1
503669  97.480  -61.487  51.138  1
503670  97.521  -61.486  51.099  1
503671  97.565  -61.478  51.061  1
503672  97.608  -61.470  51.023  1
503673  97.651  -61.462  50.986  1
503674  97.696  -61.457  50.946  1
503675  97.744  -61.462  50.906  1
503676  97.793  -61.467  50.868  1
503677  97.842  -61.472  50.831  1
503678  97.864  -61.478  50.792  1
503679  97.877  -61.490  50.753  1
503680  97.901  -61.505  50.714  1
503681  97.925  -61.521  50.675  1
503682  97.949  -61.537  50.636  1
503683  97.973  -61.552  50.598  1
503684  97.998  -61.568  50.561  1
503685  98.022  -61.583  50.523  1
503686  98.046  -61.599  50.485  1
503687  98.070  -61.615  50.449  1
504135  88.093  -59.337  56.098  1
504136  88.145  -59.344  56.074  1
504137  88.197  -59.351  56.049  1
504138  88.249  -59.358  56.025  1
504139  88.301  -59.365  56.001  1
504140  88.353  -59.372  55.977  1
504141  88.405  -59.378  55.951  1
504142  88.457  -59.385  55.925  1
504143  88.509  -59.392  55.901  1
504144  88.561  -59.399  55.875  1
504145  88.613  -59.406  55.848  1
504146  88.665  -59.413  55.819  1
504147  88.717  -59.420  55.789  1
504148  88.769  -59.427  55.760  1
504149  88.821  -59.434  55.733  1
504150  88.877  -59.429  55.706  1
504151  88.934  -59.416  55.681  1
504152  88.979  -59.428  55.658  1
504153  89.019  -59.447  55.637  1
504154  89.059  -59.468  55.615  1
504155  89.099  -59.488  55.594  1
504156  89.139  -59.507  55.574  1
504157  89.180  -59.528  55.554  1
504158  89.219  -59.547  55.535  1
504159  89.260  -59.568  55.517  1
504160  89.300  -59.588  55.500  1
504161  89.340  -59.607  55.485  1
504162  89.380  -59.628  55.471  1
504163  89.397  -59.638  55.458  1
504164  89.409  -59.647  55.446  1
504165  89.420  -59.656  55.434  1
504166  89.449  -59.668  55.423  1
504167  89.489  -59.682  55.414  1
504168  89.529  -59.698  55.407  1
504169  89.570  -59.712  55.400  1
504170  89.610  -59.727  55.391  1
504171  89.651  -59.742  55.379  1
504172  89.691  -59.757  55.368  1
504173  89.732  -59.772  55.358  1
504174  89.774  -59.793  55.349  1
504175  89.817  -59.814  55.342  1
504176  89.860  -59.836  55.336  1
504177  89.903  -59.858  55.330  1
504178  89.948  -59.877  55.323  1
504179  89.993  -59.898  55.315  1
504180  90.039  -59.917  55.308  1
504181  90.085  -59.938  55.300  1
504182  90.130  -59.958  55.290  1
504183  90.175  -59.973  55.277  1
504184  90.219  -59.985  55.262  1
504185  90.263  -59.997  55.246  1
504186  90.308  -60.009  55.227  1
504187  90.352  -60.021  55.209  1
504188  90.397  -60.033  55.190  1
504189  90.441  -60.045  55.170  1
504190  90.485  -60.057  55.150  1
504191  90.530  -60.069  55.131  1
504192  90.574  -60.081  55.112  1
504193  90.618  -60.093  55.095  1
504194  90.663  -60.105  55.081  1
504195  90.707  -60.117  55.069  1
504196  90.751  -60.129  55.057  1
504197  90.796  -60.141  55.047  1
504198  90.840  -60.153  55.041  1
504199  90.883  -60.163  55.038  1
504200  90.927  -60.172  55.040  1
504201  90.963  -60.205  55.042  1
504202  90.999  -60.237  55.041  1
504203  91.035  -60.271  55.039  1
504204  91.073  -60.299  55.037  1
504205  91.115  -60.306  55.036  1
504206  91.157  -60.312  55.037  1
504207  91.200  -60.319  55.040  1
504208  91.242  -60.326  55.043  1
504209  91.285  -60.333  55.045  1
504210  91.327  -60.340  55.044  1
504211  91.370  -60.347  55.040  1
504212  91.412  -60.354  55.038  1
504213  91.454  -60.361  55.036  1
504214  91.497  -60.368  55.031  1
504215  91.539  -60.375  55.023  1
504216  91.582  -60.382  55.009  1
504217  91.624  -60.389  54.992  1
504218  91.666  -60.396  54.974  1
504219  91.709  -60.403  54.955  1
504220  91.751  -60.409  54.936  1
504221  91.781  -60.418  54.922  1
504222  91.808  -60.426  54.919  1
504223  91.834  -60.434  54.918  1
504224  91.860  -60.443  54.915  1
504225  91.886  -60.451  54.907  1
504226  91.894  -60.466  54.894  1
504227  91.900  -60.481  54.877  1
504228  91.923  -60.497  54.855  1
504229  91.963  -60.513  54.834  1
504230  92.003  -60.528  54.818  1
504231  92.042  -60.544  54.811  1
504232  92.083  -60.559  54.807  1
504233  92.123  -60.575  54.800  1
504234  92.161  -60.591  54.790  1
504235  92.196  -60.610  54.779  1
504236  92.231  -60.629  54.770  1
504237  92.266  -60.648  54.770  1
504238  92.301  -60.667  54.768  1
504239  92.337  -60.686  54.761  1
504240  92.371  -60.705  54.745  1
504241  92.414  -60.717  54.721  1
504242  92.459  -60.727  54.690  1
504243  92.504  -60.736  54.658  1
504244  92.549  -60.746  54.636  1
504245  92.593  -60.756  54.618  1
504246  92.638  -60.765  54.601  1
504247  92.684  -60.775  54.586  1
504248  92.725  -60.782  54.570  1
504249  92.766  -60.787  54.551  1
504250  92.807  -60.793  54.527  1
504251  92.848  -60.799  54.500  1
504252  92.888  -60.805  54.478  1
504253  92.929  -60.810  54.482  1
504254  92.971  -60.817  54.489  1
504255  93.011  -60.823  54.498  1
504256  93.052  -60.828  54.504  1
504257  93.093  -60.834  54.505  1
504258  93.134  -60.840  54.503  1
504259  93.175  -60.846  54.497  1
504260  93.216  -60.851  54.485  1
504261  93.257  -60.857  54.471  1
504262  93.298  -60.864  54.457  1
504263  93.339  -60.869  54.440  1
504264  93.379  -60.875  54.419  1
504265  93.420  -60.881  54.404  1
504266  93.462  -60.890  54.394  1
504267  93.504  -60.902  54.386  1
504268  93.546  -60.915  54.375  1
504269  93.587  -60.927  54.357  1
504270  93.629  -60.939  54.339  1
504271  93.669  -60.949  54.319  1
504272  93.708  -60.960  54.297  1
504273  93.748  -60.970  54.272  1
504274  93.787  -60.980  54.256  1
504275  93.828  -60.990  54.238  1
504276  93.871  -61.001  54.222  1
504277  93.914  -61.011  54.213  1
504278  93.957  -61.020  54.211  1
504279  94.000  -61.031  54.206  1
504280  94.043  -61.041  54.203  1
504281  94.086  -61.051  54.197  1
504282  94.129  -61.061  54.188  1
504283  94.172  -61.071  54.174  1
504284  94.214  -61.080  54.153  1
504285  94.257  -61.089  54.126  1
504286  94.299  -61.099  54.095  1
504287  94.342  -61.107  54.062  1
504288  94.384  -61.116  54.029  1
504289  94.426  -61.125  53.995  1
504290  94.469  -61.134  53.960  1
504291  94.511  -61.143  53.919  1
504292  94.553  -61.150  53.880  1
504293  94.595  -61.156  53.843  1
504294  94.636  -61.163  53.807  1
504295  94.675  -61.170  53.772  1
504296  94.712  -61.177  53.736  1
504297  94.750  -61.183  53.700  1
504298  94.783  -61.187  53.665  1
504299  94.812  -61.184  53.631  1
504300  94.840  -61.183  53.600  1
504301  94.868  -61.181  53.567  1
504302  94.899  -61.182  53.532  1
504303  94.935  -61.186  53.493  1
504304  94.972  -61.190  53.452  1
504305  95.008  -61.195  53.412  1
504306  95.044  -61.199  53.374  1
504307  95.080  -61.204  53.338  1
504308  95.117  -61.208  53.304  1
504309  95.154  -61.213  53.270  1
504310  95.192  -61.218  53.235  1
504311  95.232  -61.224  53.202  1
504312  95.270  -61.230  53.169  1
504313  95.308  -61.237  53.138  1
504314  95.345  -61.243  53.108  1
504315  95.383  -61.250  53.075  1
504316  95.418  -61.255  53.041  1
504317  95.454  -61.259  53.009  1
504318  95.490  -61.264  52.976  1
504319  95.525  -61.268  52.943  1
504320  95.561  -61.273  52.912  1
504321  95.596  -61.277  52.880  1
504322  95.633  -61.281  52.846  1
504323  95.670  -61.285  52.811  1
504324  95.708  -61.288  52.775  1
504325  95.746  -61.292  52.741  1
504326  95.783  -61.296  52.707  1
504327  95.820  -61.301  52.675  1
504328  95.857  -61.306  52.642  1
504329  95.894  -61.311  52.607  1
504330  95.932  -61.315  52.572  1
504331  95.972  -61.318  52.534  1
504332  96.013  -61.321  52.499  1
504333  96.052  -61.324  52.464  1
504334  96.093  -61.327  52.428  1
504335  96.133  -61.331  52.392  1
504336  96.173  -61.334  52.355  1
504337  96.214  -61.337  52.319  1
504338  96.254  -61.341  52.285  1
504339  96.294  -61.345  52.251  1
504340  96.334  -61.349  52.218  1
504341  96.375  -61.353  52.184  1
504342  96.421  -61.347  52.150  1
504343  96.467  -61.343  52.117  1
504344  96.503  -61.348  52.082  1
504345  96.535  -61.356  52.048  1
504346  96.567  -61.365  52.018  1
504347  96.599  -61.373  51.984  1
504348  96.631  -61.381  51.950  1
504349  96.662  -61.394  51.917  1
504350  96.695  -61.404  51.883  1
504351  96.742  -61.403  51.849  1
504352  96.782  -61.408  51.815  1
504353  96.819  -61.414  51.780  1
504354  96.856  -61.420  51.745  1
504355  96.893  -61.426  51.710  1
504356  96.930  -61.432  51.675  1
504357  96.967  -61.438  51.640  1
504358  97.007  -61.438  51.604  1
504359  97.046  -61.437  51.567  1
504360  97.085  -61.435  51.528  1
504361  97.125  -61.434  51.489  1
504362  97.164  -61.432  51.448  1
504363  97.204  -61.428  51.408  1
504364  97.243  -61.425  51.368  1
504365  97.282  -61.431  51.330  1
504366  97.321  -61.437  51.291  1
504367  97.361  -61.443  51.251  1
504368  97.400  -61.449  51.212  1
504369  97.439  -61.454  51.171  1
504370  97.480  -61.454  51.132  1
504371  97.523  -61.447  51.094  1
504372  97.567  -61.438  51.057  1
504373  97.610  -61.431  51.019  1
504374  97.653  -61.423  50.982  1
504375  97.700  -61.423  50.943  1
504376  97.749  -61.428  50.904  1
504377  97.797  -61.433  50.866  1
504378  97.846  -61.437  50.830  1
504379  97.869  -61.444  50.791  1
504380  97.879  -61.454  50.753  1
504381  97.903  -61.470  50.714  1
504382  97.927  -61.486  50.676  1
504383  97.951  -61.501  50.637  1
504384  97.975  -61.517  50.599  1
504385  98.000  -61.532  50.562  1
504386  98.024  -61.548  50.525  1
504387  98.048  -61.564  50.489  1
504836  88.120  -59.293  56.104  1
504837  88.172  -59.300  56.080  1
504838  88.224  -59.307  56.056  1
504839  88.276  -59.314  56.033  1
504840  88.328  -59.321  56.011  1
504841  88.380  -59.328  55.988  1
504842  88.432  -59.334  55.962  1
504843  88.484  -59.341  55.937  1
504844  88.536  -59.348  55.914  1
504845  88.588  -59.355  55.888  1
504846  88.640  -59.362  55.862  1
504847  88.692  -59.369  55.834  1
504848  88.744  -59.376  55.804  1
504849  88.796  -59.383  55.775  1
504850  88.848  -59.390  55.747  1
504851  88.905  -59.381  55.721  1
504852  88.959  -59.375  55.696  1
504853  88.998  -59.395  55.673  1
504854  89.039  -59.416  55.651  1
504855  89.079  -59.435  55.629  1
504856  89.119  -59.456  55.608  1
504857  89.159  -59.475  55.589  1
504858  89.199  -59.495  55.571  1
504859  89.239  -59.516  55.554  1
504860  89.279  -59.535  55.537  1
504861  89.319  -59.555  55.521  1
504862  89.353  -59.573  55.508  1
504863  89.388  -59.589  55.496  1
504864  89.409  -59.602  55.486  1
504865  89.428  -59.614  55.477  1
504866  89.442  -59.624  55.468  1
504867  89.463  -59.635  55.458  1
504868  89.504  -59.650  55.450  1
504869  89.544  -59.665  55.444  1
504870  89.585  -59.679  55.440  1
504871  89.625  -59.694  55.434  1
504872  89.666  -59.709  55.424  1
504873  89.706  -59.723  55.412  1
504874  89.747  -59.739  55.401  1
504875  89.788  -59.756  55.392  1
504876  89.831  -59.778  55.386  1
504877  89.874  -59.799  55.380  1
504878  89.918  -59.820  55.373  1
504879  89.963  -59.840  55.366  1
504880  90.009  -59.861  55.359  1
504881  90.054  -59.880  55.352  1
504882  90.099  -59.895  55.348  1
504883  90.144  -59.907  55.340  1
504884  90.188  -59.919  55.325  1
504885  90.232  -59.931  55.306  1
504886  90.276  -59.943  55.287  1
504887  90.321  -59.955  55.265  1
504888  90.365  -59.967  55.243  1
504889  90.409  -59.979  55.221  1
504890  90.454  -59.991  55.198  1
504891  90.498  -60.003  55.175  1
504892  90.542  -60.015  55.153  1
504893  90.587  -60.027  55.132  1
504894  90.631  -60.039  55.112  1
504895  90.675  -60.051  55.094  1
504896  90.720  -60.063  55.078  1
504897  90.764  -60.075  55.064  1
504898  90.809  -60.087  55.052  1
504899  90.853  -60.099  55.044  1
504900  90.897  -60.110  55.039  1
504901  90.940  -60.121  55.038  1
504902  90.975  -60.155  55.038  1
504903  91.012  -60.188  55.035  1
504904  91.048  -60.221  55.032  1
504905  91.084  -60.254  55.030  1
504906  91.126  -60.264  55.029  1
504907  91.168  -60.271  55.032  1
504908  91.211  -60.278  55.035  1
504909  91.253  -60.285  55.036  1
504910  91.295  -60.292  55.035  1
504911  91.338  -60.299  55.034  1
504912  91.380  -60.306  55.029  1
504913  91.423  -60.312  55.029  1
504914  91.465  -60.319  55.030  1
504915  91.508  -60.327  55.026  1
504916  91.550  -60.334  55.018  1
504917  91.592  -60.340  55.006  1
504918  91.635  -60.347  54.990  1
504919  91.677  -60.354  54.972  1
504920  91.716  -60.362  54.951  1
504921  91.742  -60.370  54.928  1
504922  91.769  -60.378  54.907  1
504923  91.795  -60.387  54.896  1
504924  91.821  -60.395  54.890  1
504925  91.848  -60.403  54.883  1
504926  91.874  -60.411  54.874  1
504927  91.900  -60.419  54.862  1
504928  91.909  -60.434  54.846  1
504929  91.930  -60.450  54.828  1
504930  91.969  -60.466  54.810  1
504931  92.009  -60.481  54.797  1
504932  92.050  -60.497  54.789  1
504933  92.086  -60.515  54.783  1
504934  92.121  -60.534  54.778  1
504935  92.156  -60.553  54.771  1
504936  92.191  -60.572  54.763  1
504937  92.226  -60.591  54.757  1
504938  92.261  -60.610  54.757  1
504939  92.296  -60.629  54.757  1
504940  92.331  -60.647  54.751  1
504941  92.373  -60.660  54.739  1
504942  92.418  -60.669  54.718  1
504943  92.463  -60.679  54.690  1
504944  92.508  -60.689  54.656  1
504945  92.553  -60.698  54.634  1
504946  92.597  -60.708  54.617  1
504947  92.642  -60.718  54.602  1
504948  92.688  -60.728  54.586  1
504949  92.731  -60.736  54.568  1
504950  92.772  -60.742  54.549  1
504951  92.813  -60.748  54.522  1
504952  92.854  -60.754  54.493  1
504953  92.895  -60.760  54.470  1
504954  92.936  -60.766  54.475  1
504955  92.977  -60.771  54.483  1
504956  93.018  -60.777  54.492  1
504957  93.059  -60.783  54.498  1
504958  93.099  -60.789  54.502  1
504959  93.140  -60.795  54.505  1
504960  93.182  -60.801  54.502  1
504961  93.222  -60.807  54.493  1
504962  93.263  -60.812  54.482  1
504963  93.304  -60.818  54.469  1
504964  93.345  -60.824  54.451  1
504965  93.386  -60.830  54.431  1
504966  93.427  -60.837  54.413  1
504967  93.469  -60.849  54.398  1
504968  93.511  -60.862  54.383  1
504969  93.553  -60.874  54.365  1
504970  93.594  -60.887  54.345  1
504971  93.637  -60.899  54.327  1
504972  93.678  -60.911  54.310  1
504973  93.718  -60.921  54.290  1
504974  93.757  -60.932  54.268  1
504975  93.797  -60.942  54.249  1
504976  93.838  -60.952  54.230  1
504977  93.881  -60.962  54.217  1
504978  93.924  -60.972  54.210  1
504979  93.967  -60.983  54.205  1
504980  94.010  -60.992  54.195  1
504981  94.053  -61.002  54.192  1
504982  94.096  -61.013  54.187  1
504983  94.137  -61.024  54.181  1
504984  94.179  -61.036  54.169  1
504985  94.222  -61.045  54.149  1
504986  94.266  -61.055  54.124  1
504987  94.310  -61.064  54.095  1
504988  94.352  -61.074  54.064  1
504989  94.395  -61.083  54.033  1
504990  94.437  -61.092  54.002  1
504991  94.480  -61.101  53.967  1
504992  94.522  -61.110  53.928  1
504993  94.564  -61.117  53.888  1
504994  94.605  -61.124  53.847  1
504995  94.643  -61.130  53.805  1
504996  94.681  -61.136  53.765  1
504997  94.718  -61.143  53.728  1
504998  94.755  -61.150  53.692  1
504999  94.791  -61.156  53.659  1
505000  94.820  -61.154  53.627  1
505001  94.848  -61.152  53.598  1
505002  94.877  -61.150  53.566  1
505003  94.908  -61.149  53.531  1
505004  94.942  -61.151  53.493  1
505005  94.978  -61.155  53.452  1
505006  95.015  -61.160  53.411  1
505007  95.051  -61.165  53.373  1
505008  95.087  -61.169  53.337  1
505009  95.123  -61.174  53.303  1
505010  95.160  -61.178  53.270  1
505011  95.198  -61.183  53.236  1
505012  95.239  -61.189  53.202  1
505013  95.278  -61.195  53.170  1
505014  95.316  -61.202  53.139  1
505015  95.353  -61.208  53.108  1
505016  95.390  -61.214  53.076  1
505017  95.425  -61.218  53.043  1
505018  95.461  -61.223  53.010  1
505019  95.496  -61.227  52.977  1
505020  95.532  -61.232  52.945  1
505021  95.567  -61.237  52.913  1
505022  95.603  -61.241  52.882  1
505023  95.638  -61.246  52.848  1
505024  95.676  -61.249  52.812  1
505025  95.714  -61.252  52.777  1
505026  95.751  -61.257  52.742  1
505027  95.788  -61.262  52.705  1
505028  95.825  -61.267  52.670  1
505029  95.863  -61.271  52.634  1
505030  95.899  -61.276  52.598  1
505031  95.937  -61.281  52.563  1
505032  95.977  -61.284  52.527  1
505033  96.017  -61.287  52.493  1
505034  96.057  -61.290  52.460  1
505035  96.098  -61.294  52.426  1
505036  96.138  -61.298  52.390  1
505037  96.178  -61.302  52.352  1
505038  96.219  -61.306  52.315  1
505039  96.259  -61.309  52.277  1
505040  96.299  -61.313  52.242  1
505041  96.339  -61.317  52.208  1
505042  96.381  -61.318  52.171  1
505043  96.427  -61.313  52.137  1
505044  96.473  -61.309  52.102  1
505045  96.515  -61.308  52.067  1
505046  96.547  -61.316  52.035  1
505047  96.580  -61.324  52.006  1
505048  96.612  -61.333  51.975  1
505049  96.644  -61.341  51.944  1
505050  96.676  -61.349  51.913  1
505051  96.709  -61.359  51.881  1
505052  96.747  -61.364  51.849  1
505053  96.784  -61.370  51.814  1
505054  96.821  -61.376  51.779  1
505055  96.859  -61.382  51.744  1
505056  96.895  -61.388  51.709  1
505057  96.933  -61.394  51.673  1
505058  96.970  -61.400  51.639  1
505059  97.007  -61.406  51.604  1
505060  97.044  -61.412  51.568  1
505061  97.084  -61.410  51.529  1
505062  97.123  -61.409  51.489  1
505063  97.163  -61.407  51.447  1
505064  97.202  -61.403  51.405  1
505065  97.241  -61.398  51.363  1
505066  97.281  -61.404  51.324  1
505067  97.320  -61.410  51.285  1
505068  97.359  -61.415  51.244  1
505069  97.398  -61.422  51.206  1
505070  97.439  -61.422  51.166  1
505071  97.483  -61.415  51.127  1
505072  97.526  -61.406  51.090  1
505073  97.569  -61.399  51.053  1
505074  97.612  -61.391  51.016  1
505075  97.656  -61.384  50.979  1
505076  97.705  -61.389  50.941  1
505077  97.753  -61.393  50.902  1
505078  97.802  -61.398  50.865  1
505079  97.851  -61.403  50.828  1
505080  97.873  -61.409  50.791  1
505081  97.880  -61.419  50.753  1
505082  97.904  -61.434  50.715  1
505083  97.929  -61.450  50.677  1
505084  97.953  -61.466  50.638  1
505085  97.977  -61.481  50.601  1
505086  98.001  -61.497  50.564  1
505087  98.025  -61.512  50.527  1
505088  98.050  -61.528  50.491  1
505537  88.146  -59.249  56.109  1
505538  88.198  -59.256  56.085  1
505539  88.251  -59.262  56.062  1
505540  88.303  -59.270  56.040  1
505541  88.354  -59.277  56.017  1
505542  88.407  -59.284  55.996  1
505543  88.459  -59.291  55.972  1
505544  88.510  -59.297  55.949  1
505545  88.563  -59.304  55.926  1
505546  88.615  -59.311  55.901  1
505547  88.667  -59.318  55.875  1
505548  88.719  -59.325  55.848  1
505549  88.771  -59.332  55.819  1
505550  88.823  -59.339  55.790  1
505551  88.875  -59.346  55.761  1
505552  88.932  -59.334  55.734  1
505553  88.978  -59.344  55.709  1
505554  89.018  -59.363  55.685  1
505555  89.058  -59.384  55.662  1
505556  89.098  -59.403  55.640  1
505557  89.138  -59.423  55.620  1
505558  89.179  -59.444  55.602  1
505559  89.218  -59.463  55.584  1
505560  89.257  -59.482  55.568  1
505561  89.292  -59.500  55.554  1
505562  89.326  -59.516  55.539  1
505563  89.361  -59.533  55.529  1
505564  89.395  -59.550  55.521  1
505565  89.415  -59.563  55.516  1
505566  89.434  -59.576  55.511  1
505567  89.453  -59.588  55.505  1
505568  89.478  -59.601  55.497  1
505569  89.519  -59.617  55.490  1
505570  89.559  -59.632  55.484  1
505571  89.600  -59.647  55.480  1
505572  89.640  -59.661  55.477  1
505573  89.681  -59.676  55.470  1
505574  89.721  -59.691  55.461  1
505575  89.761  -59.706  55.450  1
505576  89.802  -59.720  55.440  1
505577  89.844  -59.741  55.438  1
505578  89.887  -59.763  55.432  1
505579  89.933  -59.783  55.424  1
505580  89.978  -59.803  55.415  1
505581  90.023  -59.817  55.407  1
505582  90.068  -59.829  55.402  1
505583  90.112  -59.841  55.402  1
505584  90.156  -59.853  55.397  1
505585  90.200  -59.865  55.385  1
505586  90.245  -59.877  55.365  1
505587  90.289  -59.889  55.341  1
505588  90.333  -59.901  55.311  1
505589  90.378  -59.913  55.284  1
505590  90.422  -59.925  55.257  1
505591  90.466  -59.937  55.229  1
505592  90.511  -59.949  55.202  1
505593  90.555  -59.961  55.177  1
505594  90.600  -59.973  55.153  1
505595  90.644  -59.985  55.129  1
505596  90.688  -59.997  55.107  1
505597  90.733  -60.009  55.087  1
505598  90.777  -60.021  55.070  1
505599  90.821  -60.033  55.057  1
505600  90.866  -60.045  55.046  1
505601  90.910  -60.057  55.039  1
505602  90.952  -60.071  55.035  1
505603  90.989  -60.105  55.032  1
505604  91.025  -60.138  55.028  1
505605  91.061  -60.171  55.024  1
505606  91.097  -60.204  55.024  1
505607  91.137  -60.222  55.025  1
505608  91.179  -60.230  55.027  1
505609  91.221  -60.237  55.026  1
505610  91.264  -60.243  55.025  1
505611  91.306  -60.250  55.022  1
505612  91.349  -60.257  55.020  1
505613  91.391  -60.264  55.017  1
505614  91.434  -60.271  55.017  1
505615  91.476  -60.278  55.017  1
505616  91.518  -60.285  55.015  1
505617  91.561  -60.292  55.010  1
505618  91.603  -60.299  55.000  1
505619  91.646  -60.306  54.985  1
505620  91.677  -60.314  54.967  1
505621  91.703  -60.322  54.945  1
505622  91.729  -60.331  54.920  1
505623  91.756  -60.339  54.892  1
505624  91.782  -60.347  54.872  1
505625  91.808  -60.355  54.858  1
505626  91.835  -60.363  54.848  1
505627  91.861  -60.372  54.837  1
505628  91.887  -60.380  54.826  1
505629  91.914  -60.388  54.813  1
505630  91.936  -60.403  54.797  1
505631  91.975  -60.419  54.783  1
505632  92.010  -60.438  54.772  1
505633  92.045  -60.457  54.763  1
505634  92.080  -60.476  54.758  1
505635  92.115  -60.495  54.754  1
505636  92.150  -60.514  54.750  1
505637  92.185  -60.533  54.746  1
505638  92.220  -60.553  54.743  1
505639  92.255  -60.572  54.740  1
505640  92.290  -60.591  54.738  1
505641  92.332  -60.603  54.731  1
505642  92.377  -60.613  54.720  1
505643  92.422  -60.622  54.704  1
505644  92.467  -60.632  54.681  1
505645  92.512  -60.641  54.652  1
505646  92.557  -60.651  54.626  1
505647  92.601  -60.660  54.605  1
505648  92.646  -60.670  54.589  1
505649  92.692  -60.680  54.575  1
505650  92.736  -60.690  54.560  1
505651  92.779  -60.697  54.539  1
505652  92.819  -60.703  54.514  1
505653  92.861  -60.709  54.487  1
505654  92.902  -60.714  54.465  1
505655  92.942  -60.720  54.459  1
505656  92.983  -60.726  54.466  1
505657  93.024  -60.732  54.475  1
505658  93.065  -60.738  54.484  1
505659  93.106  -60.744  54.492  1
505660  93.147  -60.750  54.499  1
505661  93.188  -60.755  54.498  1
505662  93.229  -60.761  54.496  1
505663  93.270  -60.767  54.491  1
505664  93.310  -60.773  54.483  1
505665  93.352  -60.779  54.465  1
505666  93.393  -60.785  54.451  1
505667  93.434  -60.796  54.432  1
505668  93.476  -60.809  54.410  1
505669  93.518  -60.821  54.388  1
505670  93.560  -60.834  54.364  1
505671  93.602  -60.846  54.344  1
505672  93.644  -60.858  54.327  1
505673  93.686  -60.871  54.310  1
505674  93.727  -60.883  54.291  1
505675  93.767  -60.893  54.269  1
505676  93.806  -60.903  54.248  1
505677  93.848  -60.914  54.230  1
505678  93.891  -60.923  54.215  1
505679  93.934  -60.934  54.204  1
505680  93.977  -60.944  54.196  1
505681  94.020  -60.954  54.184  1
505682  94.061  -60.965  54.178  1
505683  94.103  -60.977  54.173  1
505684  94.144  -60.989  54.165  1
505685  94.186  -60.999  54.153  1
505686  94.229  -61.009  54.135  1
505687  94.273  -61.019  54.113  1
505688  94.317  -61.028  54.087  1
505689  94.360  -61.038  54.058  1
505690  94.403  -61.048  54.028  1
505691  94.447  -61.057  53.997  1
505692  94.490  -61.067  53.965  1
505693  94.533  -61.076  53.929  1
505694  94.574  -61.084  53.891  1
505695  94.611  -61.090  53.849  1
505696  94.648  -61.097  53.805  1
505697  94.686  -61.104  53.762  1
505698  94.723  -61.111  53.724  1
505699  94.760  -61.118  53.688  1
505700  94.797  -61.124  53.654  1
505701  94.827  -61.124  53.623  1
505702  94.856  -61.122  53.594  1
505703  94.885  -61.120  53.562  1
505704  94.918  -61.121  53.528  1
505705  94.951  -61.121  53.492  1
505706  94.985  -61.121  53.453  1
505707  95.021  -61.125  53.413  1
505708  95.057  -61.130  53.376  1
505709  95.094  -61.134  53.340  1
505710  95.130  -61.138  53.306  1
505711  95.166  -61.143  53.273  1
505712  95.205  -61.148  53.239  1
505713  95.245  -61.154  53.205  1
505714  95.285  -61.159  53.173  1
505715  95.323  -61.166  53.142  1
505716  95.361  -61.173  53.110  1
505717  95.397  -61.177  53.078  1
505718  95.432  -61.182  53.045  1
505719  95.468  -61.187  53.010  1
505720  95.503  -61.191  52.978  1
505721  95.539  -61.196  52.946  1
505722  95.574  -61.200  52.914  1
505723  95.610  -61.205  52.882  1
505724  95.645  -61.209  52.848  1
505725  95.682  -61.214  52.813  1
505726  95.719  -61.218  52.777  1
505727  95.756  -61.223  52.741  1
505728  95.793  -61.227  52.704  1
505729  95.830  -61.233  52.668  1
505730  95.868  -61.237  52.632  1
505731  95.905  -61.242  52.596  1
505732  95.942  -61.246  52.560  1
505733  95.982  -61.250  52.525  1
505734  96.022  -61.254  52.490  1
505735  96.062  -61.258  52.457  1
505736  96.103  -61.262  52.424  1
505737  96.143  -61.265  52.388  1
505738  96.183  -61.269  52.350  1
505739  96.224  -61.273  52.312  1
505740  96.264  -61.277  52.275  1
505741  96.304  -61.281  52.239  1
505742  96.344  -61.284  52.203  1
505743  96.387  -61.284  52.167  1
505744  96.434  -61.279  52.130  1
505745  96.479  -61.274  52.095  1
505746  96.525  -61.270  52.059  1
505747  96.560  -61.276  52.025  1
505748  96.592  -61.284  51.994  1
505749  96.624  -61.293  51.962  1
505750  96.657  -61.301  51.932  1
505751  96.689  -61.309  51.904  1
505752  96.721  -61.318  51.875  1
505753  96.756  -61.330  51.845  1
505754  96.792  -61.335  51.812  1
505755  96.827  -61.340  51.776  1
505756  96.864  -61.346  51.741  1
505757  96.899  -61.352  51.705  1
505758  96.936  -61.357  51.670  1
505759  96.972  -61.363  51.636  1
505760  97.010  -61.369  51.600  1
505761  97.046  -61.375  51.564  1
505762  97.084  -61.381  51.527  1
505763  97.122  -61.384  51.487  1
505764  97.161  -61.383  51.445  1
505765  97.201  -61.378  51.403  1
505766  97.240  -61.371  51.361  1
505767  97.279  -61.377  51.321  1
505768  97.318  -61.383  51.282  1
505769  97.358  -61.389  51.241  1
505770  97.398  -61.390  51.203  1
505771  97.442  -61.383  51.164  1
505772  97.485  -61.375  51.126  1
505773  97.528  -61.367  51.088  1
505774  97.571  -61.359  51.050  1
505775  97.614  -61.352  51.013  1
505776  97.660  -61.350  50.976  1
505777  97.709  -61.355  50.939  1
505778  97.758  -61.359  50.901  1
505779  97.806  -61.364  50.864  1
505780  97.855  -61.368  50.827  1
505781  97.878  -61.375  50.791  1
505782  97.882  -61.384  50.753  1
505783  97.907  -61.400  50.715  1
505784  97.931  -61.415  50.678  1
505785  97.955  -61.431  50.638  1
505786  97.979  -61.447  50.603  1
505787  98.003  -61.462  50.566  1
505788  98.027  -61.478  50.529  1
506238  88.173  -59.205  56.113  1
506239  88.225  -59.212  56.089  1
506240  88.277  -59.218  56.067  1
506241  88.329  -59.225  56.045  1
506242  88.382  -59.233  56.023  1
506243  88.433  -59.240  56.002  1
506244  88.485  -59.247  55.980  1
506245  88.538  -59.253  55.957  1
506246  88.590  -59.260  55.936  1
506247  88.641  -59.267  55.912  1
506248  88.694  -59.274  55.887  1
506249  88.746  -59.281  55.861  1
506250  88.798  -59.287  55.833  1
506251  88.850  -59.295  55.802  1
506252  88.902  -59.300  55.775  1
506253  88.958  -59.291  55.746  1
506254  88.997  -59.311  55.720  1
506255  89.038  -59.331  55.696  1
506256  89.078  -59.351  55.672  1
506257  89.118  -59.372  55.650  1
506258  89.158  -59.391  55.631  1
506259  89.195  -59.410  55.612  1
506260  89.230  -59.427  55.595  1
506261  89.264  -59.444  55.580  1
506262  89.299  -59.460  55.567  1
506263  89.333  -59.477  55.555  1
506264  89.367  -59.494  55.548  1
506265  89.401  -59.511  55.543  1
506266  89.421  -59.523  55.540  1
506267  89.441  -59.536  55.537  1
506268  89.460  -59.548  55.532  1
506269  89.493  -59.563  55.525  1
506270  89.533  -59.579  55.518  1
506271  89.574  -59.595  55.513  1
506272  89.614  -59.610  55.512  1
506273  89.655  -59.626  55.515  1
506274  89.695  -59.642  55.514  1
506275  89.736  -59.658  55.511  1
506276  89.776  -59.673  55.504  1
506277  89.817  -59.688  55.495  1
506278  89.858  -59.704  55.497  1
506279  89.902  -59.725  55.491  1
506280  89.947  -59.739  55.480  1
506281  89.991  -59.751  55.467  1
506282  90.036  -59.763  55.457  1
506283  90.080  -59.775  55.453  1
506284  90.124  -59.787  55.453  1
506285  90.169  -59.799  55.449  1
506286  90.213  -59.811  55.440  1
506287  90.258  -59.823  55.423  1
506288  90.302  -59.835  55.397  1
506289  90.346  -59.847  55.364  1
506290  90.391  -59.859  55.332  1
506291  90.435  -59.871  55.299  1
506292  90.479  -59.883  55.265  1
506293  90.524  -59.895  55.233  1
506294  90.568  -59.908  55.202  1
506295  90.612  -59.920  55.174  1
506296  90.657  -59.933  55.146  1
506297  90.701  -59.946  55.121  1
506298  90.746  -59.958  55.098  1
506299  90.790  -59.971  55.079  1
506300  90.835  -59.983  55.062  1
506301  90.879  -59.996  55.048  1
506302  90.924  -60.008  55.038  1
506303  90.965  -60.024  55.033  1
506304  91.001  -60.055  55.026  1
506305  91.037  -60.088  55.019  1
506306  91.074  -60.121  55.016  1
506307  91.109  -60.155  55.018  1
506308  91.147  -60.181  55.021  1
506309  91.189  -60.188  55.020  1
506310  91.232  -60.195  55.017  1
506311  91.275  -60.202  55.014  1
506312  91.317  -60.209  55.011  1
506313  91.359  -60.216  55.008  1
506314  91.402  -60.223  55.005  1
506315  91.444  -60.230  55.004  1
506316  91.487  -60.237  55.003  1
506317  91.529  -60.243  55.001  1
506318  91.572  -60.250  54.997  1
506319  91.611  -60.258  54.989  1
506320  91.638  -60.266  54.975  1
506321  91.664  -60.275  54.957  1
506322  91.690  -60.283  54.935  1
506323  91.717  -60.291  54.909  1
506324  91.743  -60.300  54.882  1
506325  91.769  -60.307  54.858  1
506326  91.796  -60.315  54.838  1
506327  91.822  -60.324  54.820  1
506328  91.848  -60.332  54.805  1
506329  91.875  -60.340  54.789  1
506330  91.910  -60.350  54.777  1
506331  91.934  -60.362  54.764  1
506332  91.969  -60.381  54.751  1
506333  92.004  -60.400  54.741  1
506334  92.039  -60.419  54.735  1
506335  92.074  -60.438  54.731  1
506336  92.109  -60.457  54.730  1
506337  92.144  -60.476  54.729  1
506338  92.179  -60.495  54.727  1
506339  92.214  -60.514  54.726  1
506340  92.249  -60.533  54.722  1
506341  92.291  -60.546  54.716  1
506342  92.336  -60.555  54.709  1
506343  92.381  -60.565  54.698  1
506344  92.426  -60.575  54.685  1
506345  92.471  -60.585  54.668  1
506346  92.516  -60.594  54.644  1
506347  92.561  -60.604  54.619  1
506348  92.605  -60.613  54.597  1
506349  92.650  -60.622  54.581  1
506350  92.696  -60.632  54.566  1
506351  92.740  -60.642  54.552  1
506352  92.785  -60.652  54.535  1
506353  92.826  -60.657  54.515  1
506354  92.867  -60.663  54.494  1
506355  92.908  -60.669  54.472  1
506356  92.949  -60.676  54.458  1
506357  92.990  -60.681  54.454  1
506358  93.030  -60.687  54.457  1
506359  93.072  -60.693  54.464  1
506360  93.113  -60.698  54.475  1
506361  93.153  -60.704  54.482  1
506362  93.194  -60.710  54.487  1
506363  93.235  -60.716  54.490  1
506364  93.276  -60.722  54.491  1
506365  93.317  -60.728  54.489  1
506366  93.358  -60.734  54.477  1
506367  93.400  -60.744  54.466  1
506368  93.441  -60.756  54.449  1
506369  93.483  -60.768  54.428  1
506370  93.525  -60.781  54.405  1
506371  93.567  -60.793  54.380  1
506372  93.609  -60.806  54.362  1
506373  93.651  -60.818  54.342  1
506374  93.693  -60.830  54.321  1
506375  93.735  -60.843  54.299  1
506376  93.776  -60.854  54.276  1
506377  93.816  -60.865  54.254  1
506378  93.858  -60.875  54.236  1
506379  93.901  -60.885  54.217  1
506380  93.943  -60.895  54.199  1
506381  93.985  -60.907  54.185  1
506382  94.027  -60.918  54.172  1
506383  94.068  -60.930  54.163  1
506384  94.110  -60.941  54.155  1
506385  94.151  -60.952  54.146  1
506386  94.193  -60.964  54.132  1
506387  94.237  -60.973  54.116  1
506388  94.280  -60.983  54.097  1
506389  94.324  -60.992  54.075  1
506390  94.367  -61.002  54.049  1
506391  94.410  -61.011  54.021  1
506392  94.454  -61.021  53.991  1
506393  94.497  -61.031  53.959  1
506394  94.540  -61.040  53.925  1
506395  94.578  -61.045  53.889  1
506396  94.616  -61.055  53.848  1
506397  94.654  -61.064  53.803  1
506398  94.691  -61.071  53.762  1
506399  94.728  -61.078  53.725  1
506400  94.765  -61.084  53.691  1
506401  94.803  -61.091  53.657  1
506402  94.835  -61.093  53.626  1
506403  94.863  -61.092  53.596  1
506404  94.895  -61.091  53.564  1
506405  94.928  -61.091  53.531  1
506406  94.962  -61.091  53.496  1
506407  94.995  -61.091  53.459  1
506408  95.029  -61.092  53.422  1
506409  95.064  -61.094  53.386  1
506410  95.100  -61.099  53.352  1
506411  95.136  -61.103  53.318  1
506412  95.173  -61.108  53.284  1
506413  95.211  -61.113  53.247  1
506414  95.252  -61.119  53.212  1
506415  95.292  -61.124  53.178  1
506416  95.331  -61.130  53.145  1
506417  95.368  -61.136  53.113  1
506418  95.403  -61.141  53.080  1
506419  95.439  -61.146  53.045  1
506420  95.474  -61.150  53.010  1
506421  95.510  -61.155  52.976  1
506422  95.544  -61.161  52.944  1
506423  95.577  -61.167  52.912  1
506424  95.611  -61.173  52.880  1
506425  95.649  -61.176  52.846  1
506426  95.692  -61.181  52.811  1
506427  95.751  -61.193  52.776  1
506428  95.788  -61.199  52.740  1
506429  95.826  -61.203  52.703  1
506430  95.864  -61.208  52.668  1
506431  95.899  -61.215  52.633  1
506432  95.927  -61.228  52.597  1
506433  95.958  -61.226  52.560  1
506434  95.995  -61.207  52.524  1
506435  96.027  -61.221  52.488  1
506436  96.067  -61.225  52.455  1
506437  96.108  -61.229  52.422  1
506438  96.148  -61.233  52.387  1
506439  96.188  -61.237  52.349  1
506440  96.229  -61.240  52.312  1
506441  96.269  -61.244  52.276  1
506442  96.309  -61.248  52.239  1
506443  96.349  -61.252  52.202  1
506444  96.394  -61.249  52.165  1
506445  96.440  -61.245  52.127  1
506446  96.485  -61.240  52.091  1
506447  96.531  -61.236  52.054  1
506448  96.573  -61.236  52.018  1
506449  96.605  -61.244  51.985  1
506450  96.637  -61.252  51.952  1
506451  96.669  -61.261  51.921  1
506452  96.701  -61.269  51.893  1
506453  96.735  -61.280  51.865  1
506454  96.768  -61.294  51.837  1
506455  96.804  -61.302  51.806  1
506456  96.840  -61.308  51.772  1
506457  96.876  -61.313  51.738  1
506458  96.912  -61.319  51.703  1
506459  96.948  -61.324  51.667  1
506460  96.984  -61.330  51.631  1
506461  97.020  -61.335  51.595  1
506462  97.055  -61.341  51.559  1
506463  97.092  -61.346  51.522  1
506464  97.127  -61.352  51.485  1
506465  97.161  -61.356  51.444  1
506466  97.199  -61.352  51.401  1
506467  97.238  -61.346  51.360  1
506468  97.278  -61.350  51.319  1
506469  97.317  -61.356  51.280  1
506470  97.357  -61.359  51.240  1
506471  97.400  -61.351  51.201  1
506472  97.444  -61.343  51.162  1
506473  97.487  -61.335  51.124  1
506474  97.530  -61.328  51.086  1
506475  97.573  -61.320  51.048  1
506476  97.616  -61.312  51.011  1
506477  97.665  -61.315  50.975  1
506478  97.714  -61.321  50.937  1
506479  97.762  -61.325  50.900  1
506480  97.811  -61.330  50.863  1
506481  97.860  -61.334  50.827  1
506482  97.882  -61.341  50.790  1
506483  97.886  -61.349  50.753  1
506484  97.908  -61.364  50.715  1
506485  97.932  -61.380  50.678  1
506486  97.956  -61.396  50.640  1
506487  97.981  -61.411  50.604  1
506488  98.005  -61.427  50.567  1
506939  88.200  -59.161  56.114  1
506940  88.252  -59.168  56.093  1
506941  88.304  -59.175  56.071  1
506942  88.356  -59.181  56.049  1
506943  88.408  -59.188  56.028  1
506944  88.460  -59.196  56.007  1
506945  88.512  -59.203  55.986  1
506946  88.564  -59.209  55.964  1
506947  88.616  -59.216  55.943  1
506948  88.668  -59.223  55.920  1
506949  88.720  -59.230  55.896  1
506950  88.772  -59.237  55.871  1
506951  88.824  -59.244  55.844  1
506952  88.877  -59.250  55.815  1
506953  88.930  -59.252  55.786  1
506954  88.977  -59.259  55.759  1
506955  89.017  -59.279  55.732  1
506956  89.057  -59.299  55.707  1
506957  89.097  -59.319  55.684  1
506958  89.134  -59.338  55.660  1
506959  89.168  -59.354  55.639  1
506960  89.202  -59.371  55.621  1
506961  89.237  -59.388  55.604  1
506962  89.271  -59.404  55.588  1
506963  89.305  -59.421  55.578  1
506964  89.339  -59.438  55.568  1
506965  89.374  -59.455  55.563  1
506966  89.408  -59.472  55.561  1
506967  89.428  -59.485  55.558  1
506968  89.447  -59.497  55.556  1
506969  89.470  -59.510  55.552  1
506970  89.509  -59.525  55.545  1
506971  89.547  -59.540  55.540  1
506972  89.588  -59.556  55.538  1
506973  89.628  -59.572  55.541  1
506974  89.669  -59.588  55.548  1
506975  89.709  -59.604  55.552  1
506976  89.750  -59.620  55.553  1
506977  89.791  -59.635  55.553  1
506978  89.831  -59.651  55.554  1
506979  89.872  -59.667  55.559  1
506980  89.916  -59.681  55.556  1
506981  89.961  -59.694  55.544  1
506982  90.006  -59.706  55.526  1
506983  90.050  -59.719  55.510  1
506984  90.094  -59.732  55.501  1
506985  90.139  -59.745  55.497  1
506986  90.183  -59.757  55.493  1
506987  90.228  -59.770  55.487  1
506988  90.272  -59.783  55.478  1
506989  90.316  -59.795  55.453  1
506990  90.361  -59.808  55.418  1
506991  90.405  -59.820  55.382  1
506992  90.450  -59.833  55.345  1
506993  90.494  -59.845  55.304  1
506994  90.538  -59.858  55.265  1
506995  90.583  -59.871  55.229  1
506996  90.627  -59.884  55.196  1
506997  90.672  -59.896  55.164  1
506998  90.716  -59.909  55.135  1
506999  90.761  -59.922  55.109  1
507000  90.805  -59.934  55.087  1
507001  90.850  -59.947  55.067  1
507002  90.894  -59.960  55.051  1
507003  90.938  -59.973  55.038  1
507004  90.977  -59.989  55.029  1
507005  91.014  -60.008  55.020  1
507006  91.050  -60.039  55.013  1
507007  91.086  -60.071  55.008  1
507008  91.122  -60.105  55.007  1
507009  91.158  -60.138  55.009  1
507010  91.201  -60.146  55.010  1
507011  91.243  -60.153  55.009  1
507012  91.285  -60.161  55.006  1
507013  91.328  -60.168  55.003  1
507014  91.370  -60.174  55.000  1
507015  91.413  -60.181  54.996  1
507016  91.455  -60.188  54.991  1
507017  91.498  -60.195  54.988  1
507018  91.540  -60.202  54.985  1
507019  91.572  -60.210  54.982  1
507020  91.599  -60.218  54.975  1
507021  91.625  -60.227  54.962  1
507022  91.651  -60.235  54.944  1
507023  91.677  -60.243  54.923  1
507024  91.704  -60.251  54.897  1
507025  91.730  -60.259  54.872  1
507026  91.756  -60.268  54.846  1
507027  91.784  -60.277  54.822  1
507028  91.819  -60.286  54.801  1
507029  91.854  -60.295  54.783  1
507030  91.889  -60.305  54.765  1
507031  91.917  -60.315  54.749  1
507032  91.936  -60.327  54.735  1
507033  91.963  -60.343  54.722  1
507034  91.999  -60.362  54.712  1
507035  92.033  -60.381  54.706  1
507036  92.069  -60.400  54.703  1
507037  92.103  -60.419  54.703  1
507038  92.139  -60.437  54.704  1
507039  92.174  -60.456  54.704  1
507040  92.209  -60.475  54.703  1
507041  92.250  -60.488  54.701  1
507042  92.295  -60.498  54.697  1
507043  92.340  -60.508  54.690  1
507044  92.385  -60.517  54.679  1
507045  92.430  -60.527  54.666  1
507046  92.475  -60.537  54.650  1
507047  92.520  -60.547  54.631  1
507048  92.565  -60.556  54.612  1
507049  92.609  -60.566  54.594  1
507050  92.654  -60.575  54.577  1
507051  92.700  -60.585  54.561  1
507052  92.744  -60.594  54.547  1
507053  92.789  -60.604  54.535  1
507054  92.833  -60.613  54.521  1
507055  92.873  -60.619  54.503  1
507056  92.915  -60.624  54.483  1
507057  92.955  -60.630  54.463  1
507058  92.996  -60.636  54.450  1
507059  93.037  -60.641  54.445  1
507060  93.078  -60.647  54.447  1
507061  93.119  -60.654  54.455  1
507062  93.160  -60.660  54.463  1
507063  93.201  -60.665  54.472  1
507064  93.242  -60.671  54.479  1
507065  93.283  -60.677  54.484  1
507066  93.324  -60.682  54.487  1
507067  93.365  -60.691  54.480  1
507068  93.407  -60.703  54.473  1
507069  93.448  -60.715  54.459  1
507070  93.491  -60.728  54.439  1
507071  93.533  -60.740  54.416  1
507072  93.574  -60.753  54.393  1
507073  93.616  -60.765  54.376  1
507074  93.658  -60.777  54.357  1
507075  93.700  -60.790  54.338  1
507076  93.742  -60.802  54.318  1
507077  93.784  -60.815  54.295  1
507078  93.825  -60.826  54.278  1
507079  93.867  -60.836  54.259  1
507080  93.909  -60.848  54.234  1
507081  93.951  -60.860  54.204  1
507082  93.992  -60.871  54.178  1
507083  94.034  -60.882  54.159  1
507084  94.075  -60.894  54.143  1
507085  94.117  -60.905  54.133  1
507086  94.158  -60.917  54.122  1
507087  94.200  -60.928  54.107  1
507088  94.244  -60.937  54.094  1
507089  94.287  -60.947  54.078  1
507090  94.331  -60.957  54.059  1
507091  94.374  -60.966  54.036  1
507092  94.417  -60.976  54.011  1
507093  94.461  -60.986  53.983  1
507094  94.504  -60.995  53.950  1
507095  94.544  -61.001  53.916  1
507096  94.581  -61.005  53.883  1
507097  94.618  -61.011  53.845  1
507098  94.656  -61.019  53.802  1
507099  94.695  -61.033  53.764  1
507100  94.734  -61.045  53.732  1
507101  94.771  -61.052  53.700  1
507102  94.808  -61.058  53.668  1
507103  94.843  -61.063  53.637  1
507104  94.872  -61.061  53.606  1
507105  94.905  -61.061  53.575  1
507106  94.938  -61.061  53.543  1
507107  94.972  -61.061  53.508  1
507108  95.005  -61.062  53.472  1
507109  95.039  -61.062  53.436  1
507110  95.072  -61.062  53.402  1
507111  95.107  -61.064  53.369  1
507112  95.143  -61.068  53.334  1
507113  95.179  -61.073  53.298  1
507114  95.218  -61.078  53.261  1
507115  95.258  -61.083  53.225  1
507116  95.299  -61.089  53.190  1
507117  95.339  -61.096  53.155  1
507118  95.373  -61.101  53.120  1
507119  95.407  -61.108  53.085  1
507120  95.440  -61.114  53.048  1
507121  95.473  -61.120  53.012  1
507122  95.507  -61.127  52.977  1
507123  95.540  -61.133  52.942  1
507124  95.575  -61.138  52.909  1
507125  95.614  -61.139  52.876  1
507126  95.653  -61.142  52.841  1
507127  95.692  -61.144  52.806  1
507128  95.752  -61.157  52.771  1
507129  95.811  -61.170  52.734  1
507130  95.857  -61.183  52.698  1
507131  95.885  -61.197  52.664  1
507132  95.912  -61.211  52.629  1
507133  95.940  -61.224  52.592  1
507134  95.976  -61.202  52.555  1
507135  96.019  -61.152  52.519  1
507136  96.049  -61.168  52.484  1
507137  96.079  -61.184  52.452  1
507138  96.113  -61.196  52.420  1
507139  96.153  -61.200  52.387  1
507140  96.193  -61.204  52.353  1
507141  96.234  -61.208  52.318  1
507142  96.274  -61.212  52.282  1
507143  96.314  -61.215  52.245  1
507144  96.355  -61.219  52.205  1
507145  96.400  -61.215  52.165  1
507146  96.446  -61.211  52.127  1
507147  96.491  -61.206  52.090  1
507148  96.537  -61.202  52.052  1
507149  96.583  -61.197  52.015  1
507150  96.617  -61.204  51.979  1
507151  96.650  -61.212  51.945  1
507152  96.682  -61.221  51.912  1
507153  96.714  -61.229  51.880  1
507154  96.748  -61.243  51.851  1
507155  96.782  -61.257  51.824  1
507156  96.817  -61.269  51.797  1
507157  96.853  -61.275  51.766  1
507158  96.888  -61.281  51.734  1
507159  96.925  -61.286  51.700  1
507160  96.960  -61.291  51.664  1
507161  96.996  -61.297  51.627  1
507162  97.032  -61.302  51.589  1
507163  97.068  -61.308  51.553  1
507164  97.104  -61.314  51.517  1
507165  97.140  -61.316  51.481  1
507166  97.171  -61.316  51.442  1
507167  97.198  -61.326  51.399  1
507168  97.237  -61.321  51.359  1
507169  97.276  -61.323  51.318  1
507170  97.316  -61.327  51.278  1
507171  97.360  -61.319  51.239  1
507172  97.402  -61.312  51.200  1
507173  97.446  -61.303  51.161  1
507174  97.489  -61.296  51.123  1
507175  97.532  -61.288  51.085  1
507176  97.576  -61.281  51.048  1
507177  97.621  -61.277  51.010  1
507178  97.669  -61.281  50.974  1
507179  97.718  -61.286  50.937  1
507180  97.767  -61.291  50.900  1
507181  97.815  -61.296  50.863  1
507182  97.864  -61.300  50.827  1
507183  97.887  -61.307  50.790  1
507184  97.890  -61.315  50.753  1
507185  97.910  -61.329  50.716  1
507186  97.934  -61.344  50.679  1
507187  97.958  -61.360  50.641  1
507188  97.983  -61.376  50.605  1
507640  88.227  -59.117  56.116  1
507641  88.279  -59.124  56.094  1
507642  88.331  -59.131  56.072  1
507643  88.383  -59.137  56.052  1
507644  88.435  -59.144  56.031  1
507645  88.487  -59.151  56.011  1
507646  88.539  -59.159  55.991  1
507647  88.591  -59.165  55.969  1
507648  88.643  -59.172  55.948  1
507649  88.695  -59.179  55.926  1
507650  88.747  -59.186  55.903  1
507651  88.799  -59.193  55.879  1
507652  88.851  -59.200  55.853  1
507653  88.903  -59.206  55.826  1
507654  88.957  -59.207  55.797  1
507655  88.996  -59.227  55.770  1
507656  89.037  -59.247  55.743  1
507657  89.072  -59.265  55.718  1
507658  89.106  -59.281  55.693  1
507659  89.140  -59.298  55.669  1
507660  89.175  -59.315  55.649  1
507661  89.209  -59.331  55.630  1
507662  89.243  -59.348  55.613  1
507663  89.277  -59.366  55.598  1
507664  89.312  -59.382  55.586  1
507665  89.346  -59.399  55.577  1
507666  89.381  -59.416  55.571  1
507667  89.415  -59.432  55.569  1
507668  89.434  -59.445  55.565  1
507669  89.453  -59.457  55.564  1
507670  89.486  -59.472  55.561  1
507671  89.524  -59.487  55.558  1
507672  89.563  -59.502  55.556  1
507673  89.602  -59.517  55.559  1
507674  89.642  -59.533  55.567  1
507675  89.683  -59.549  55.576  1
507676  89.724  -59.565  55.584  1
507677  89.764  -59.581  55.590  1
507678  89.805  -59.597  55.596  1
507679  89.846  -59.613  55.606  1
507680  89.887  -59.628  55.614  1
507681  89.932  -59.642  55.614  1
507682  89.976  -59.657  55.604  1
507683  90.020  -59.670  55.586  1
507684  90.064  -59.682  55.567  1
507685  90.109  -59.695  55.552  1
507686  90.154  -59.708  55.541  1
507687  90.198  -59.720  55.532  1
507688  90.242  -59.733  55.525  1
507689  90.287  -59.746  55.513  1
507690  90.331  -59.759  55.489  1
507691  90.376  -59.771  55.459  1
507692  90.420  -59.784  55.425  1
507693  90.464  -59.797  55.389  1
507694  90.509  -59.809  55.347  1
507695  90.553  -59.822  55.300  1
507696  90.598  -59.835  55.257  1
507697  90.642  -59.848  55.218  1
507698  90.687  -59.860  55.183  1
507699  90.731  -59.873  55.150  1
507700  90.776  -59.886  55.122  1
507701  90.820  -59.898  55.095  1
507702  90.864  -59.911  55.073  1
507703  90.909  -59.924  55.053  1
507704  90.953  -59.936  55.038  1
507705  90.990  -59.955  55.025  1
507706  91.026  -59.974  55.015  1
507707  91.063  -59.992  55.008  1
507708  91.099  -60.022  55.003  1
507709  91.135  -60.055  54.999  1
507710  91.171  -60.088  54.995  1
507711  91.211  -60.105  54.994  1
507712  91.253  -60.112  54.992  1
507713  91.296  -60.119  54.989  1
507714  91.338  -60.126  54.986  1
507715  91.381  -60.133  54.984  1
507716  91.423  -60.140  54.980  1
507717  91.466  -60.147  54.977  1
507718  91.507  -60.154  54.975  1
507719  91.533  -60.162  54.972  1
507720  91.560  -60.171  54.968  1
507721  91.586  -60.179  54.959  1
507722  91.612  -60.187  54.945  1
507723  91.639  -60.196  54.927  1
507724  91.665  -60.203  54.907  1
507725  91.693  -60.212  54.884  1
507726  91.728  -60.221  54.861  1
507727  91.763  -60.231  54.835  1
507728  91.798  -60.240  54.810  1
507729  91.833  -60.250  54.787  1
507730  91.868  -60.259  54.768  1
507731  91.901  -60.269  54.748  1
507732  91.920  -60.281  54.729  1
507733  91.939  -60.293  54.711  1
507734  91.958  -60.304  54.697  1
507735  91.993  -60.323  54.686  1
507736  92.028  -60.342  54.679  1
507737  92.063  -60.361  54.675  1
507738  92.098  -60.380  54.674  1
507739  92.133  -60.400  54.674  1
507740  92.168  -60.419  54.674  1
507741  92.210  -60.431  54.674  1
507742  92.254  -60.441  54.673  1
507743  92.299  -60.450  54.670  1
507744  92.344  -60.460  54.665  1
507745  92.389  -60.470  54.656  1
507746  92.434  -60.479  54.646  1
507747  92.479  -60.489  54.635  1
507748  92.524  -60.499  54.622  1
507749  92.569  -60.509  54.606  1
507750  92.614  -60.518  54.591  1
507751  92.658  -60.528  54.578  1
507752  92.703  -60.538  54.565  1
507753  92.748  -60.547  54.554  1
507754  92.793  -60.557  54.543  1
507755  92.838  -60.566  54.528  1
507756  92.880  -60.573  54.509  1
507757  92.921  -60.579  54.493  1
507758  92.962  -60.585  54.474  1
507759  93.003  -60.591  54.456  1
507760  93.044  -60.597  54.443  1
507761  93.085  -60.603  54.434  1
507762  93.126  -60.608  54.432  1
507763  93.166  -60.614  54.442  1
507764  93.207  -60.620  54.454  1
507765  93.249  -60.626  54.464  1
507766  93.289  -60.632  54.472  1
507767  93.330  -60.638  54.479  1
507768  93.372  -60.650  54.476  1
507769  93.414  -60.663  54.472  1
507770  93.456  -60.675  54.460  1
507771  93.498  -60.687  54.442  1
507772  93.540  -60.700  54.419  1
507773  93.581  -60.712  54.398  1
507774  93.624  -60.725  54.381  1
507775  93.665  -60.737  54.365  1
507776  93.707  -60.749  54.348  1
507777  93.749  -60.762  54.330  1
507778  93.791  -60.774  54.311  1
507779  93.832  -60.789  54.294  1
507780  93.874  -60.801  54.272  1
507781  93.916  -60.812  54.244  1
507782  93.958  -60.823  54.212  1
507783  93.999  -60.835  54.182  1
507784  94.041  -60.846  54.155  1
507785  94.082  -60.857  54.133  1
507786  94.124  -60.870  54.117  1
507787  94.166  -60.881  54.102  1
507788  94.207  -60.892  54.084  1
507789  94.251  -60.901  54.069  1
507790  94.294  -60.911  54.052  1
507791  94.338  -60.921  54.033  1
507792  94.381  -60.930  54.014  1
507793  94.424  -60.940  53.992  1
507794  94.468  -60.950  53.966  1
507795  94.509  -60.957  53.936  1
507796  94.548  -60.961  53.904  1
507797  94.585  -60.966  53.872  1
507798  94.622  -60.971  53.839  1
507799  94.659  -60.976  53.804  1
507800  94.696  -60.983  53.774  1
507801  94.735  -60.996  53.747  1
507802  94.774  -61.010  53.718  1
507803  94.813  -61.024  53.689  1
507804  94.850  -61.032  53.661  1
507805  94.883  -61.032  53.628  1
507806  94.916  -61.032  53.597  1
507807  94.949  -61.032  53.564  1
507808  94.982  -61.033  53.530  1
507809  95.016  -61.033  53.493  1
507810  95.049  -61.033  53.457  1
507811  95.083  -61.033  53.423  1
507812  95.116  -61.033  53.389  1
507813  95.149  -61.033  53.353  1
507814  95.186  -61.038  53.316  1
507815  95.225  -61.043  53.279  1
507816  95.265  -61.049  53.242  1
507817  95.303  -61.054  53.206  1
507818  95.339  -61.060  53.169  1
507819  95.373  -61.068  53.132  1
507820  95.403  -61.079  53.094  1
507821  95.436  -61.086  53.055  1
507822  95.469  -61.092  53.017  1
507823  95.502  -61.099  52.980  1
507824  95.541  -61.102  52.943  1
507825  95.580  -61.104  52.909  1
507826  95.619  -61.105  52.874  1
507827  95.658  -61.108  52.838  1
507828  95.697  -61.110  52.802  1
507829  95.751  -61.121  52.766  1
507830  95.811  -61.133  52.729  1
507831  95.850  -61.139  52.693  1
507832  95.878  -61.142  52.659  1
507833  95.920  -61.149  52.624  1
507834  95.950  -61.180  52.587  1
507835  95.988  -61.162  52.550  1
507836  96.035  -61.102  52.514  1
507837  96.072  -61.112  52.482  1
507838  96.103  -61.129  52.452  1
507839  96.133  -61.145  52.424  1
507840  96.163  -61.161  52.393  1
507841  96.198  -61.172  52.361  1
507842  96.239  -61.176  52.327  1
507843  96.279  -61.180  52.292  1
507844  96.319  -61.183  52.255  1
507845  96.360  -61.186  52.216  1
507846  96.406  -61.181  52.173  1
507847  96.452  -61.177  52.131  1
507848  96.498  -61.172  52.091  1
507849  96.543  -61.168  52.053  1
507850  96.589  -61.163  52.015  1
507851  96.629  -61.164  51.979  1
507852  96.662  -61.172  51.943  1
507853  96.694  -61.180  51.908  1
507854  96.727  -61.191  51.875  1
507855  96.761  -61.205  51.844  1
507856  96.796  -61.220  51.814  1
507857  96.829  -61.234  51.785  1
507858  96.865  -61.242  51.755  1
507859  96.901  -61.248  51.725  1
507860  96.937  -61.253  51.693  1
507861  96.973  -61.259  51.660  1
507862  97.009  -61.264  51.626  1
507863  97.044  -61.270  51.590  1
507864  97.081  -61.275  51.553  1
507865  97.116  -61.281  51.515  1
507866  97.151  -61.272  51.476  1
507867  97.180  -61.277  51.437  1
507868  97.208  -61.286  51.397  1
507869  97.235  -61.295  51.357  1
507870  97.275  -61.295  51.318  1
507871  97.318  -61.287  51.279  1
507872  97.362  -61.280  51.240  1
507873  97.405  -61.271  51.200  1
507874  97.448  -61.264  51.161  1
507875  97.492  -61.256  51.123  1
507876  97.534  -61.249  51.085  1
507877  97.578  -61.240  51.048  1
507878  97.626  -61.243  51.012  1
507879  97.674  -61.247  50.975  1
507880  97.723  -61.252  50.938  1
507881  97.772  -61.256  50.901  1
507882  97.820  -61.261  50.864  1
507883  97.869  -61.266  50.827  1
507884  97.891  -61.272  50.792  1
507885  97.895  -61.281  50.755  1
507886  97.912  -61.293  50.717  1
507887  97.936  -61.309  50.680  1
507888  97.960  -61.325  50.643  1
507889  97.984  -61.340  50.607  1
508342  88.306  -59.080  56.094  1
508343  88.358  -59.087  56.072  1
508344  88.410  -59.093  56.052  1
508345  88.462  -59.100  56.032  1
508346  88.514  -59.107  56.012  1
508347  88.566  -59.114  55.992  1
508348  88.618  -59.121  55.971  1
508349  88.670  -59.128  55.951  1
508350  88.722  -59.135  55.930  1
508351  88.774  -59.142  55.908  1
508352  88.826  -59.149  55.885  1
508353  88.878  -59.156  55.861  1
508354  88.930  -59.162  55.834  1
508355  88.976  -59.175  55.806  1
508356  89.010  -59.192  55.780  1
508357  89.044  -59.209  55.754  1
508358  89.079  -59.225  55.728  1
508359  89.113  -59.242  55.702  1
508360  89.147  -59.259  55.678  1
508361  89.182  -59.275  55.657  1
508362  89.216  -59.293  55.639  1
508363  89.250  -59.309  55.622  1
508364  89.284  -59.326  55.607  1
508365  89.319  -59.343  55.595  1
508366  89.353  -59.359  55.586  1
508367  89.387  -59.377  55.581  1
508368  89.421  -59.394  55.577  1
508369  89.441  -59.406  55.573  1
508370  89.463  -59.419  55.572  1
508371  89.502  -59.434  55.571  1
508372  89.540  -59.449  55.569  1
508373  89.578  -59.463  55.570  1
508374  89.617  -59.479  55.575  1
508375  89.657  -59.494  55.584  1
508376  89.697  -59.510  55.596  1
508377  89.738  -59.526  55.607  1
508378  89.779  -59.542  55.619  1
508379  89.819  -59.558  55.632  1
508380  89.860  -59.574  55.647  1
508381  89.902  -59.589  55.661  1
508382  89.947  -59.604  55.665  1
508383  89.991  -59.618  55.659  1
508384  90.035  -59.632  55.645  1
508385  90.080  -59.646  55.627  1
508386  90.124  -59.659  55.608  1
508387  90.168  -59.672  55.590  1
508388  90.213  -59.685  55.577  1
508389  90.257  -59.697  55.567  1
508390  90.302  -59.710  55.553  1
508391  90.346  -59.723  55.525  1
508392  90.390  -59.735  55.491  1
508393  90.435  -59.748  55.456  1
508394  90.479  -59.761  55.419  1
508395  90.524  -59.773  55.379  1
508396  90.568  -59.786  55.333  1
508397  90.612  -59.798  55.285  1
508398  90.657  -59.811  55.241  1
508399  90.701  -59.823  55.201  1
508400  90.746  -59.836  55.165  1
508401  90.790  -59.849  55.133  1
508402  90.835  -59.862  55.104  1
508403  90.879  -59.874  55.078  1
508404  90.924  -59.887  55.056  1
508405  90.965  -59.902  55.038  1
508406  91.002  -59.920  55.024  1
508407  91.038  -59.939  55.013  1
508408  91.075  -59.958  55.006  1
508409  91.111  -59.977  55.000  1
508410  91.148  -60.005  54.992  1
508411  91.184  -60.038  54.983  1
508412  91.222  -60.064  54.978  1
508413  91.264  -60.071  54.974  1
508414  91.307  -60.077  54.971  1
508415  91.349  -60.084  54.970  1
508416  91.392  -60.092  54.968  1
508417  91.434  -60.099  54.966  1
508418  91.468  -60.106  54.964  1
508419  91.494  -60.115  54.963  1
508420  91.520  -60.123  54.960  1
508421  91.547  -60.131  54.955  1
508422  91.573  -60.140  54.945  1
508423  91.602  -60.148  54.931  1
508424  91.637  -60.157  54.914  1
508425  91.672  -60.167  54.893  1
508426  91.707  -60.176  54.870  1
508427  91.742  -60.186  54.846  1
508428  91.777  -60.195  54.823  1
508429  91.812  -60.205  54.800  1
508430  91.847  -60.214  54.778  1
508431  91.882  -60.224  54.758  1
508432  91.905  -60.234  54.737  1
508433  91.923  -60.246  54.718  1
508434  91.942  -60.258  54.699  1
508435  91.961  -60.270  54.682  1
508436  91.987  -60.285  54.667  1
508437  92.022  -60.304  54.654  1
508438  92.057  -60.323  54.647  1
508439  92.092  -60.342  54.642  1
508440  92.128  -60.361  54.639  1
508441  92.168  -60.374  54.638  1
508442  92.213  -60.384  54.640  1
508443  92.259  -60.394  54.639  1
508444  92.303  -60.403  54.637  1
508445  92.348  -60.412  54.634  1
508446  92.393  -60.422  54.629  1
508447  92.438  -60.432  54.621  1
508448  92.483  -60.441  54.614  1
508449  92.528  -60.451  54.607  1
508450  92.573  -60.461  54.597  1
508451  92.618  -60.471  54.586  1
508452  92.662  -60.480  54.577  1
508453  92.707  -60.490  54.567  1
508454  92.753  -60.500  54.560  1
508455  92.797  -60.510  54.548  1
508456  92.842  -60.519  54.532  1
508457  92.886  -60.528  54.513  1
508458  92.927  -60.534  54.496  1
508459  92.969  -60.540  54.478  1
508460  93.009  -60.546  54.459  1
508461  93.050  -60.551  54.443  1
508462  93.091  -60.557  54.432  1
508463  93.132  -60.563  54.424  1
508464  93.173  -60.569  54.424  1
508465  93.214  -60.575  54.430  1
508466  93.255  -60.581  54.441  1
508467  93.296  -60.587  54.453  1
508468  93.337  -60.597  54.462  1
508469  93.379  -60.610  54.463  1
508470  93.421  -60.622  54.459  1
508471  93.463  -60.635  54.449  1
508472  93.505  -60.647  54.433  1
508473  93.547  -60.659  54.412  1
508474  93.589  -60.672  54.392  1
508475  93.631  -60.684  54.377  1
508476  93.673  -60.696  54.364  1
508477  93.714  -60.709  54.350  1
508478  93.756  -60.723  54.336  1
508479  93.796  -60.738  54.323  1
508480  93.837  -60.753  54.303  1
508481  93.880  -60.765  54.279  1
508482  93.923  -60.776  54.250  1
508483  93.965  -60.788  54.221  1
508484  94.006  -60.799  54.191  1
508485  94.048  -60.810  54.159  1
508486  94.089  -60.822  54.134  1
508487  94.131  -60.833  54.113  1
508488  94.173  -60.845  54.095  1
508489  94.214  -60.856  54.078  1
508490  94.258  -60.866  54.062  1
508491  94.301  -60.876  54.044  1
508492  94.345  -60.885  54.025  1
508493  94.388  -60.895  54.006  1
508494  94.431  -60.904  53.986  1
508495  94.474  -60.913  53.963  1
508496  94.512  -60.917  53.939  1
508497  94.551  -60.922  53.913  1
508498  94.589  -60.926  53.884  1
508499  94.625  -60.932  53.854  1
508500  94.662  -60.936  53.824  1
508501  94.699  -60.941  53.796  1
508502  94.736  -60.947  53.768  1
508503  94.775  -60.961  53.742  1
508504  94.814  -60.974  53.716  1
508505  94.853  -60.988  53.690  1
508506  94.887  -60.990  53.662  1
508507  94.921  -60.992  53.632  1
508508  94.955  -60.993  53.601  1
508509  94.989  -60.995  53.565  1
508510  95.023  -60.996  53.528  1
508511  95.057  -60.998  53.488  1
508512  95.091  -60.999  53.450  1
508513  95.125  -61.001  53.413  1
508514  95.159  -61.002  53.377  1
508515  95.193  -61.004  53.343  1
508516  95.229  -61.008  53.305  1
508517  95.266  -61.013  53.267  1
508518  95.303  -61.019  53.229  1
508519  95.339  -61.024  53.190  1
508520  95.375  -61.030  53.150  1
508521  95.405  -61.041  53.110  1
508522  95.436  -61.052  53.068  1
508523  95.468  -61.062  53.027  1
508524  95.507  -61.065  52.987  1
508525  95.545  -61.067  52.948  1
508526  95.585  -61.070  52.910  1
508527  95.623  -61.071  52.874  1
508528  95.663  -61.074  52.835  1
508529  95.701  -61.076  52.798  1
508530  95.751  -61.083  52.761  1
508531  95.811  -61.096  52.725  1
508532  95.842  -61.100  52.689  1
508533  95.870  -61.102  52.655  1
508534  95.898  -61.105  52.619  1
508535  95.954  -61.077  52.582  1
508536  95.989  -61.078  52.546  1
508537  96.022  -61.085  52.511  1
508538  96.081  -61.081  52.480  1
508539  96.116  -61.090  52.453  1
508540  96.151  -61.099  52.427  1
508541  96.185  -61.108  52.400  1
508542  96.217  -61.122  52.370  1
508543  96.247  -61.138  52.336  1
508544  96.284  -61.147  52.302  1
508545  96.324  -61.151  52.266  1
508546  96.366  -61.152  52.228  1
508547  96.412  -61.147  52.183  1
508548  96.458  -61.143  52.138  1
508549  96.504  -61.138  52.096  1
508550  96.549  -61.133  52.056  1
508551  96.595  -61.129  52.017  1
508552  96.641  -61.124  51.980  1
508553  96.674  -61.131  51.943  1
508554  96.707  -61.139  51.908  1
508555  96.741  -61.153  51.874  1
508556  96.774  -61.168  51.841  1
508557  96.809  -61.183  51.810  1
508558  96.843  -61.197  51.778  1
508559  96.877  -61.209  51.747  1
508560  96.913  -61.215  51.717  1
508561  96.949  -61.221  51.686  1
508562  96.985  -61.226  51.654  1
508563  97.021  -61.231  51.622  1
508564  97.057  -61.237  51.587  1
508565  97.093  -61.243  51.551  1
508566  97.128  -61.238  51.513  1
508567  97.163  -61.228  51.474  1
508568  97.190  -61.237  51.437  1
508569  97.218  -61.246  51.397  1
508570  97.245  -61.255  51.359  1
508571  97.278  -61.255  51.320  1
508572  97.321  -61.248  51.281  1
508573  97.364  -61.240  51.242  1
508574  97.407  -61.232  51.203  1
508575  97.450  -61.224  51.164  1
508576  97.494  -61.217  51.126  1
508577  97.537  -61.208  51.088  1
508578  97.581  -61.203  51.051  1
508579  97.630  -61.208  51.014  1
508580  97.678  -61.213  50.977  1
508581  97.727  -61.218  50.941  1
508582  97.776  -61.222  50.903  1
508583  97.824  -61.227  50.866  1
508584  97.873  -61.231  50.831  1
508585  97.896  -61.238  50.795  1
508586  97.899  -61.246  50.758  1
508587  97.914  -61.259  50.721  1
508588  97.938  -61.274  50.684  1
508589  97.962  -61.290  50.646  1
509043  88.332  -59.036  56.093  1
509044  88.385  -59.043  56.072  1
509045  88.436  -59.049  56.052  1
509046  88.488  -59.056  56.032  1
509047  88.541  -59.063  56.012  1
509048  88.593  -59.070  55.992  1
509049  88.644  -59.077  55.972  1
509050  88.697  -59.084  55.952  1
509051  88.749  -59.091  55.932  1
509052  88.801  -59.098  55.910  1
509053  88.853  -59.105  55.888  1
509054  88.904  -59.112  55.864  1
509055  88.949  -59.124  55.839  1
509056  88.985  -59.137  55.813  1
509057  89.018  -59.153  55.787  1
509058  89.051  -59.169  55.761  1
509059  89.086  -59.186  55.735  1
509060  89.120  -59.203  55.710  1
509061  89.154  -59.220  55.686  1
509062  89.188  -59.237  55.665  1
509063  89.223  -59.253  55.646  1
509064  89.257  -59.270  55.630  1
509065  89.291  -59.287  55.617  1
509066  89.325  -59.304  55.605  1
509067  89.360  -59.321  55.597  1
509068  89.394  -59.338  55.592  1
509069  89.427  -59.354  55.589  1
509070  89.447  -59.366  55.586  1
509071  89.478  -59.381  55.585  1
509072  89.517  -59.396  55.585  1
509073  89.555  -59.410  55.585  1
509074  89.594  -59.425  55.588  1
509075  89.632  -59.441  55.592  1
509076  89.671  -59.456  55.601  1
509077  89.712  -59.472  55.612  1
509078  89.752  -59.488  55.625  1
509079  89.793  -59.504  55.640  1
509080  89.833  -59.519  55.658  1
509081  89.874  -59.535  55.677  1
509082  89.917  -59.550  55.695  1
509083  89.962  -59.564  55.707  1
509084  90.006  -59.579  55.709  1
509085  90.050  -59.593  55.699  1
509086  90.095  -59.607  55.687  1
509087  90.139  -59.622  55.674  1
509088  90.183  -59.635  55.651  1
509089  90.228  -59.648  55.628  1
509090  90.272  -59.660  55.615  1
509091  90.316  -59.673  55.598  1
509092  90.361  -59.686  55.561  1
509093  90.405  -59.698  55.521  1
509094  90.450  -59.711  55.481  1
509095  90.494  -59.724  55.442  1
509096  90.538  -59.737  55.403  1
509097  90.583  -59.749  55.359  1
509098  90.627  -59.762  55.309  1
509099  90.672  -59.775  55.261  1
509100  90.716  -59.787  55.218  1
509101  90.761  -59.800  55.179  1
509102  90.805  -59.813  55.144  1
509103  90.850  -59.826  55.112  1
509104  90.894  -59.838  55.085  1
509105  90.938  -59.851  55.060  1
509106  90.977  -59.868  55.040  1
509107  91.014  -59.886  55.025  1
509108  91.050  -59.905  55.013  1
509109  91.087  -59.924  55.005  1
509110  91.123  -59.942  54.998  1
509111  91.160  -59.961  54.991  1
509112  91.196  -59.989  54.980  1
509113  91.233  -60.021  54.970  1
509114  91.275  -60.029  54.961  1
509115  91.317  -60.036  54.956  1
509116  91.360  -60.043  54.955  1
509117  91.402  -60.050  54.957  1
509118  91.429  -60.058  54.954  1
509119  91.455  -60.067  54.952  1
509120  91.482  -60.075  54.951  1
509121  91.511  -60.083  54.948  1
509122  91.546  -60.093  54.943  1
509123  91.581  -60.102  54.932  1
509124  91.616  -60.112  54.918  1
509125  91.651  -60.121  54.900  1
509126  91.686  -60.130  54.879  1
509127  91.721  -60.140  54.856  1
509128  91.756  -60.149  54.832  1
509129  91.791  -60.159  54.811  1
509130  91.826  -60.168  54.789  1
509131  91.861  -60.178  54.768  1
509132  91.888  -60.189  54.750  1
509133  91.908  -60.200  54.732  1
509134  91.926  -60.212  54.713  1
509135  91.945  -60.224  54.692  1
509136  91.964  -60.235  54.672  1
509137  91.983  -60.247  54.655  1
509138  92.017  -60.265  54.640  1
509139  92.052  -60.284  54.629  1
509140  92.087  -60.303  54.619  1
509141  92.128  -60.317  54.612  1
509142  92.172  -60.327  54.606  1
509143  92.217  -60.336  54.601  1
509144  92.263  -60.346  54.599  1
509145  92.307  -60.356  54.597  1
509146  92.352  -60.365  54.596  1
509147  92.397  -60.375  54.593  1
509148  92.442  -60.384  54.587  1
509149  92.487  -60.394  54.582  1
509150  92.532  -60.404  54.582  1
509151  92.577  -60.413  54.583  1
509152  92.622  -60.423  54.580  1
509153  92.666  -60.433  54.572  1
509154  92.711  -60.442  54.567  1
509155  92.757  -60.452  54.562  1
509156  92.801  -60.462  54.550  1
509157  92.846  -60.472  54.533  1
509158  92.891  -60.481  54.514  1
509159  92.934  -60.489  54.495  1
509160  92.975  -60.494  54.477  1
509161  93.016  -60.500  54.458  1
509162  93.057  -60.506  54.441  1
509163  93.097  -60.512  54.428  1
509164  93.139  -60.518  54.416  1
509165  93.180  -60.524  54.410  1
509166  93.220  -60.530  54.411  1
509167  93.261  -60.535  54.418  1
509168  93.302  -60.544  54.427  1
509169  93.345  -60.557  54.436  1
509170  93.386  -60.569  54.442  1
509171  93.428  -60.582  54.441  1
509172  93.470  -60.594  54.431  1
509173  93.512  -60.606  54.415  1
509174  93.554  -60.619  54.398  1
509175  93.596  -60.631  54.380  1
509176  93.638  -60.644  54.365  1
509177  93.679  -60.658  54.352  1
509178  93.719  -60.673  54.340  1
509179  93.760  -60.688  54.330  1
509180  93.801  -60.703  54.318  1
509181  93.843  -60.717  54.301  1
509182  93.886  -60.729  54.280  1
509183  93.929  -60.740  54.256  1
509184  93.972  -60.752  54.229  1
509185  94.013  -60.763  54.197  1
509186  94.055  -60.775  54.174  1
509187  94.097  -60.786  54.153  1
509188  94.138  -60.798  54.129  1
509189  94.180  -60.809  54.107  1
509190  94.221  -60.820  54.093  1
509191  94.265  -60.830  54.077  1
509192  94.308  -60.839  54.059  1
509193  94.352  -60.849  54.036  1
509194  94.395  -60.859  54.012  1
509195  94.438  -60.868  53.992  1
509196  94.478  -60.873  53.972  1
509197  94.517  -60.878  53.954  1
509198  94.555  -60.882  53.932  1
509199  94.593  -60.887  53.906  1
509200  94.629  -60.892  53.876  1
509201  94.666  -60.897  53.848  1
509202  94.702  -60.901  53.819  1
509203  94.739  -60.906  53.792  1
509204  94.776  -60.911  53.768  1
509205  94.815  -60.924  53.746  1
509206  94.854  -60.938  53.722  1
509207  94.888  -60.941  53.697  1
509208  94.922  -60.942  53.668  1
509209  94.956  -60.944  53.637  1
509210  94.990  -60.945  53.602  1
509211  95.024  -60.946  53.564  1
509212  95.058  -60.948  53.524  1
509213  95.093  -60.951  53.483  1
509214  95.128  -60.956  53.443  1
509215  95.164  -60.961  53.405  1
509216  95.199  -60.967  53.369  1
509217  95.235  -60.973  53.330  1
509218  95.271  -60.978  53.290  1
509219  95.308  -60.984  53.250  1
509220  95.344  -60.989  53.209  1
509221  95.380  -60.995  53.168  1
509222  95.411  -61.007  53.127  1
509223  95.442  -61.018  53.084  1
509224  95.477  -61.025  53.041  1
509225  95.514  -61.029  53.000  1
509226  95.551  -61.033  52.959  1
509227  95.589  -61.035  52.919  1
509228  95.628  -61.037  52.881  1
509229  95.667  -61.039  52.841  1
509230  95.706  -61.042  52.802  1
509231  95.751  -61.047  52.764  1
509232  95.808  -61.059  52.725  1
509233  95.835  -61.061  52.689  1
509234  95.863  -61.063  52.653  1
509235  95.891  -61.065  52.616  1
509236  95.918  -61.067  52.579  1
509237  95.951  -61.071  52.543  1
509238  96.009  -61.067  52.510  1
509239  96.068  -61.064  52.480  1
509240  96.124  -61.062  52.453  1
509241  96.158  -61.071  52.427  1
509242  96.193  -61.080  52.401  1
509243  96.228  -61.089  52.374  1
509244  96.262  -61.098  52.343  1
509245  96.297  -61.106  52.311  1
509246  96.331  -61.115  52.276  1
509247  96.372  -61.118  52.239  1
509248  96.418  -61.113  52.195  1
509249  96.464  -61.108  52.148  1
509250  96.510  -61.104  52.104  1
509251  96.555  -61.099  52.062  1
509252  96.602  -61.095  52.022  1
509253  96.648  -61.089  51.985  1
509254  96.687  -61.091  51.946  1
509255  96.720  -61.102  51.911  1
509256  96.754  -61.116  51.876  1
509257  96.788  -61.130  51.842  1
509258  96.822  -61.146  51.809  1
509259  96.856  -61.160  51.777  1
509260  96.890  -61.174  51.744  1
509261  96.926  -61.182  51.712  1
509262  96.962  -61.187  51.680  1
509263  96.998  -61.193  51.648  1
509264  97.034  -61.199  51.617  1
509265  97.070  -61.204  51.582  1
509266  97.105  -61.204  51.547  1
509267  97.140  -61.194  51.511  1
509268  97.173  -61.188  51.474  1
509269  97.200  -61.197  51.438  1
509270  97.228  -61.207  51.400  1
509271  97.255  -61.224  51.362  1
509272  97.282  -61.216  51.323  1
509273  97.323  -61.208  51.284  1
509274  97.366  -61.200  51.245  1
509275  97.409  -61.193  51.206  1
509276  97.453  -61.185  51.167  1
509277  97.496  -61.177  51.129  1
509278  97.539  -61.169  51.092  1
509279  97.586  -61.169  51.055  1
509280  97.635  -61.174  51.018  1
509281  97.683  -61.179  50.980  1
509282  97.732  -61.183  50.944  1
509283  97.781  -61.188  50.907  1
509284  97.829  -61.193  50.869  1
509285  97.878  -61.197  50.834  1
509286  97.900  -61.204  50.798  1
509287  97.904  -61.212  50.761  1
509288  97.916  -61.223  50.724  1
509289  97.940  -61.239  50.687  1
509290  97.964  -61.255  50.649  1
509744  88.359  -58.992  56.092  1
509745  88.411  -58.999  56.071  1
509746  88.463  -59.005  56.051  1
509747  88.516  -59.012  56.031  1
509748  88.567  -59.019  56.011  1
509749  88.619  -59.026  55.991  1
509750  88.672  -59.033  55.969  1
509751  88.723  -59.040  55.951  1
509752  88.775  -59.047  55.931  1
509753  88.825  -59.055  55.910  1
509754  88.871  -59.067  55.889  1
509755  88.916  -59.079  55.866  1
509756  88.960  -59.091  55.842  1
509757  88.995  -59.102  55.817  1
509758  89.029  -59.118  55.792  1
509759  89.062  -59.134  55.767  1
509760  89.095  -59.149  55.742  1
509761  89.128  -59.165  55.717  1
509762  89.161  -59.181  55.694  1
509763  89.195  -59.197  55.673  1
509764  89.230  -59.214  55.655  1
509765  89.264  -59.231  55.640  1
509766  89.298  -59.248  55.627  1
509767  89.332  -59.265  55.617  1
509768  89.367  -59.281  55.613  1
509769  89.401  -59.298  55.612  1
509770  89.434  -59.315  55.613  1
509771  89.455  -59.328  55.609  1
509772  89.493  -59.343  55.607  1
509773  89.532  -59.357  55.607  1
509774  89.570  -59.372  55.607  1
509775  89.609  -59.388  55.609  1
509776  89.648  -59.403  55.612  1
509777  89.686  -59.417  55.620  1
509778  89.726  -59.433  55.630  1
509779  89.766  -59.449  55.643  1
509780  89.807  -59.465  55.660  1
509781  89.848  -59.481  55.681  1
509782  89.889  -59.497  55.700  1
509783  89.933  -59.511  55.720  1
509784  89.977  -59.526  55.737  1
509785  90.021  -59.540  55.746  1
509786  90.065  -59.554  55.742  1
509787  90.110  -59.569  55.735  1
509788  90.154  -59.582  55.729  1
509789  90.198  -59.597  55.710  1
509790  90.242  -59.611  55.684  1
509791  90.287  -59.624  55.666  1
509792  90.331  -59.637  55.648  1
509793  90.376  -59.650  55.607  1
509794  90.420  -59.663  55.558  1
509795  90.464  -59.675  55.507  1
509796  90.509  -59.688  55.459  1
509797  90.553  -59.701  55.418  1
509798  90.598  -59.713  55.375  1
509799  90.642  -59.726  55.327  1
509800  90.687  -59.739  55.279  1
509801  90.731  -59.751  55.233  1
509802  90.776  -59.764  55.191  1
509803  90.820  -59.776  55.154  1
509804  90.864  -59.789  55.121  1
509805  90.909  -59.801  55.091  1
509806  90.952  -59.815  55.064  1
509807  90.989  -59.834  55.042  1
509808  91.026  -59.852  55.026  1
509809  91.063  -59.870  55.013  1
509810  91.099  -59.889  55.002  1
509811  91.136  -59.908  54.993  1
509812  91.172  -59.927  54.986  1
509813  91.209  -59.945  54.975  1
509814  91.245  -59.972  54.963  1
509815  91.286  -59.988  54.952  1
509816  91.328  -59.995  54.944  1
509817  91.363  -60.002  54.941  1
509818  91.390  -60.011  54.941  1
509819  91.420  -60.019  54.938  1
509820  91.455  -60.029  54.936  1
509821  91.490  -60.038  54.934  1
509822  91.525  -60.048  54.931  1
509823  91.560  -60.057  54.926  1
509824  91.595  -60.067  54.916  1
509825  91.630  -60.076  54.902  1
509826  91.665  -60.086  54.885  1
509827  91.700  -60.095  54.864  1
509828  91.735  -60.105  54.841  1
509829  91.771  -60.114  54.818  1
509830  91.805  -60.123  54.797  1
509831  91.841  -60.133  54.777  1
509832  91.873  -60.143  54.760  1
509833  91.891  -60.154  54.744  1
509834  91.911  -60.166  54.730  1
509835  91.929  -60.177  54.712  1
509836  91.948  -60.189  54.693  1
509837  91.967  -60.201  54.674  1
509838  91.986  -60.212  54.656  1
509839  92.011  -60.227  54.638  1
509840  92.046  -60.246  54.619  1
509841  92.087  -60.260  54.603  1
509842  92.132  -60.269  54.590  1
509843  92.176  -60.279  54.578  1
509844  92.221  -60.289  54.569  1
509845  92.267  -60.298  54.562  1
509846  92.311  -60.308  54.558  1
509847  92.356  -60.318  54.554  1
509848  92.401  -60.328  54.551  1
509849  92.446  -60.337  54.547  1
509850  92.491  -60.347  54.544  1
509851  92.536  -60.356  54.548  1
509852  92.581  -60.366  54.555  1
509853  92.626  -60.375  54.561  1
509854  92.670  -60.385  54.559  1
509855  92.715  -60.395  54.553  1
509856  92.761  -60.404  54.545  1
509857  92.805  -60.414  54.535  1
509858  92.850  -60.424  54.524  1
509859  92.895  -60.434  54.506  1
509860  92.940  -60.443  54.487  1
509861  92.982  -60.450  54.469  1
509862  93.022  -60.455  54.453  1
509863  93.063  -60.461  54.438  1
509864  93.104  -60.467  54.421  1
509865  93.145  -60.473  54.406  1
509866  93.186  -60.478  54.398  1
509867  93.227  -60.485  54.398  1
509868  93.268  -60.491  54.400  1
509869  93.310  -60.503  54.403  1
509870  93.352  -60.516  54.410  1
509871  93.394  -60.528  54.418  1
509872  93.435  -60.541  54.418  1
509873  93.478  -60.553  54.409  1
509874  93.519  -60.566  54.394  1
509875  93.561  -60.578  54.381  1
509876  93.603  -60.592  54.365  1
509877  93.643  -60.607  54.349  1
509878  93.684  -60.622  54.335  1
509879  93.724  -60.638  54.325  1
509880  93.765  -60.653  54.318  1
509881  93.806  -60.668  54.307  1
509882  93.848  -60.681  54.292  1
509883  93.891  -60.693  54.274  1
509884  93.935  -60.704  54.253  1
509885  93.978  -60.716  54.230  1
509886  94.020  -60.727  54.207  1
509887  94.062  -60.738  54.188  1
509888  94.104  -60.750  54.167  1
509889  94.145  -60.762  54.144  1
509890  94.187  -60.773  54.121  1
509891  94.228  -60.785  54.107  1
509892  94.272  -60.794  54.093  1
509893  94.315  -60.804  54.075  1
509894  94.358  -60.814  54.053  1
509895  94.402  -60.823  54.030  1
509896  94.442  -60.829  54.010  1
509897  94.481  -60.834  53.993  1
509898  94.520  -60.839  53.975  1
509899  94.559  -60.843  53.952  1
509900  94.596  -60.848  53.926  1
509901  94.633  -60.853  53.897  1
509902  94.670  -60.857  53.865  1
509903  94.706  -60.862  53.838  1
509904  94.743  -60.867  53.815  1
509905  94.779  -60.871  53.796  1
509906  94.816  -60.876  53.778  1
509907  94.855  -60.889  53.757  1
509908  94.889  -60.891  53.733  1
509909  94.923  -60.892  53.704  1
509910  94.957  -60.894  53.673  1
509911  94.992  -60.899  53.640  1
509912  95.028  -60.904  53.601  1
509913  95.063  -60.910  53.562  1
509914  95.099  -60.915  53.520  1
509915  95.134  -60.920  53.478  1
509916  95.170  -60.926  53.436  1
509917  95.205  -60.931  53.396  1
509918  95.242  -60.938  53.354  1
509919  95.278  -60.944  53.312  1
509920  95.315  -60.949  53.270  1
509921  95.351  -60.955  53.228  1
509922  95.386  -60.961  53.185  1
509923  95.417  -60.973  53.143  1
509924  95.449  -60.984  53.099  1
509925  95.485  -60.988  53.055  1
509926  95.523  -60.992  53.012  1
509927  95.559  -60.995  52.970  1
509928  95.597  -60.999  52.929  1
509929  95.633  -61.003  52.889  1
509930  95.672  -61.005  52.848  1
509931  95.711  -61.008  52.808  1
509932  95.751  -61.011  52.768  1
509933  95.800  -61.020  52.727  1
509934  95.828  -61.022  52.690  1
509935  95.855  -61.024  52.654  1
509936  95.888  -61.027  52.616  1
509937  95.929  -61.033  52.579  1
509938  95.970  -61.037  52.542  1
509939  96.011  -61.042  52.510  1
509940  96.055  -61.046  52.482  1
509941  96.114  -61.042  52.455  1
509942  96.166  -61.042  52.428  1
509943  96.200  -61.052  52.402  1
509944  96.235  -61.061  52.376  1
509945  96.270  -61.069  52.347  1
509946  96.304  -61.078  52.317  1
509947  96.340  -61.081  52.284  1
509948  96.377  -61.083  52.249  1
509949  96.419  -61.080  52.206  1
509950  96.466  -61.075  52.160  1
509951  96.513  -61.071  52.115  1
509952  96.560  -61.065  52.072  1
509953  96.607  -61.061  52.031  1
509954  96.654  -61.055  51.993  1
509955  96.699  -61.051  51.954  1
509956  96.733  -61.064  51.917  1
509957  96.767  -61.079  51.881  1
509958  96.802  -61.093  51.845  1
509959  96.835  -61.108  51.811  1
509960  96.870  -61.122  51.779  1
509961  96.904  -61.137  51.745  1
509962  96.938  -61.149  51.712  1
509963  96.974  -61.155  51.679  1
509964  97.010  -61.160  51.646  1
509965  97.046  -61.166  51.613  1
509966  97.082  -61.169  51.578  1
509967  97.116  -61.160  51.544  1
509968  97.151  -61.150  51.511  1
509969  97.182  -61.149  51.476  1
509970  97.210  -61.158  51.441  1
509971  97.238  -61.174  51.403  1
509972  97.266  -61.191  51.365  1
509973  97.292  -61.179  51.326  1
509974  97.325  -61.168  51.286  1
509975  97.368  -61.161  51.248  1
509976  97.412  -61.153  51.209  1
509977  97.455  -61.145  51.171  1
509978  97.498  -61.137  51.133  1
509979  97.541  -61.130  51.095  1
509980  97.590  -61.135  51.058  1
509981  97.639  -61.139  51.021  1
509982  97.687  -61.144  50.984  1
509983  97.736  -61.149  50.948  1
509984  97.785  -61.154  50.910  1
509985  97.833  -61.158  50.873  1
509986  97.882  -61.163  50.837  1
509987  97.905  -61.170  50.802  1
509988  97.909  -61.178  50.765  1
509989  97.917  -61.188  50.728  1
509990  97.941  -61.203  50.690  1
509991  97.965  -61.219  50.653  1
509992  97.990  -61.235  50.617  1
510446  88.438  -58.955  56.069  1
510447  88.490  -58.961  56.049  1
510448  88.542  -58.968  56.029  1
510449  88.594  -58.975  56.009  1
510450  88.646  -58.982  55.989  1
510451  88.698  -58.989  55.968  1
510452  88.747  -58.998  55.949  1
510453  88.792  -59.010  55.929  1
510454  88.838  -59.022  55.909  1
510455  88.884  -59.034  55.888  1
510456  88.929  -59.046  55.866  1
510457  88.970  -59.057  55.843  1
510458  89.005  -59.068  55.819  1
510459  89.040  -59.081  55.795  1
510460  89.072  -59.097  55.772  1
510461  89.106  -59.113  55.748  1
510462  89.139  -59.129  55.725  1
510463  89.172  -59.145  55.702  1
510464  89.205  -59.161  55.681  1
510465  89.238  -59.177  55.664  1
510466  89.271  -59.193  55.650  1
510467  89.305  -59.209  55.638  1
510468  89.339  -59.225  55.631  1
510469  89.373  -59.243  55.631  1
510470  89.407  -59.259  55.635  1
510471  89.440  -59.275  55.640  1
510472  89.471  -59.290  55.640  1
510473  89.509  -59.304  55.639  1
510474  89.547  -59.319  55.640  1
510475  89.586  -59.334  55.642  1
510476  89.624  -59.350  55.642  1
510477  89.663  -59.364  55.640  1
510478  89.701  -59.379  55.645  1
510479  89.740  -59.394  55.654  1
510480  89.781  -59.410  55.665  1
510481  89.821  -59.426  55.680  1
510482  89.862  -59.442  55.699  1
510483  89.904  -59.458  55.718  1
510484  89.948  -59.472  55.739  1
510485  89.992  -59.487  55.758  1
510486  90.036  -59.501  55.773  1
510487  90.081  -59.515  55.777  1
510488  90.125  -59.529  55.775  1
510489  90.169  -59.544  55.773  1
510490  90.214  -59.558  55.757  1
510491  90.257  -59.573  55.731  1
510492  90.302  -59.587  55.709  1
510493  90.346  -59.601  55.686  1
510494  90.390  -59.613  55.643  1
510495  90.435  -59.626  55.591  1
510496  90.479  -59.638  55.535  1
510497  90.524  -59.651  55.479  1
510498  90.568  -59.664  55.431  1
510499  90.613  -59.676  55.385  1
510500  90.657  -59.689  55.339  1
510501  90.701  -59.702  55.294  1
510502  90.746  -59.715  55.248  1
510503  90.790  -59.727  55.202  1
510504  90.835  -59.740  55.162  1
510505  90.879  -59.753  55.127  1
510506  90.924  -59.765  55.095  1
510507  90.964  -59.781  55.067  1
510508  91.001  -59.799  55.045  1
510509  91.038  -59.818  55.028  1
510510  91.075  -59.836  55.014  1
510511  91.111  -59.855  54.999  1
510512  91.148  -59.873  54.986  1
510513  91.184  -59.892  54.977  1
510514  91.221  -59.911  54.967  1
510515  91.258  -59.929  54.954  1
510516  91.297  -59.946  54.943  1
510517  91.329  -59.955  54.935  1
510518  91.364  -59.964  54.928  1
510519  91.399  -59.974  54.924  1
510520  91.434  -59.983  54.920  1
510521  91.469  -59.992  54.917  1
510522  91.504  -60.002  54.913  1
510523  91.539  -60.011  54.909  1
510524  91.574  -60.021  54.901  1
510525  91.609  -60.030  54.890  1
510526  91.644  -60.040  54.877  1
510527  91.679  -60.049  54.862  1
510528  91.715  -60.059  54.843  1
510529  91.749  -60.068  54.820  1
510530  91.785  -60.078  54.799  1
510531  91.819  -60.087  54.781  1
510532  91.855  -60.097  54.768  1
510533  91.876  -60.108  54.757  1
510534  91.894  -60.120  54.744  1
510535  91.914  -60.131  54.731  1
510536  91.932  -60.143  54.720  1
510537  91.951  -60.155  54.710  1
510538  91.970  -60.166  54.697  1
510539  91.989  -60.178  54.676  1
510540  92.007  -60.190  54.650  1
510541  92.046  -60.202  54.619  1
510542  92.091  -60.212  54.592  1
510543  92.136  -60.222  54.573  1
510544  92.180  -60.231  54.557  1
510545  92.225  -60.241  54.543  1
510546  92.271  -60.251  54.533  1
510547  92.315  -60.261  54.525  1
510548  92.360  -60.270  54.518  1
510549  92.405  -60.280  54.514  1
510550  92.450  -60.290  54.513  1
510551  92.495  -60.299  54.515  1
510552  92.540  -60.309  54.520  1
510553  92.585  -60.318  54.527  1
510554  92.630  -60.328  54.534  1
510555  92.674  -60.337  54.538  1
510556  92.719  -60.347  54.531  1
510557  92.765  -60.357  54.521  1
510558  92.809  -60.367  54.511  1
510559  92.854  -60.376  54.499  1
510560  92.899  -60.386  54.485  1
510561  92.944  -60.396  54.466  1
510562  92.988  -60.404  54.450  1
510563  93.029  -60.410  54.436  1
510564  93.070  -60.416  54.423  1
510565  93.111  -60.422  54.409  1
510566  93.151  -60.428  54.399  1
510567  93.193  -60.434  54.400  1
510568  93.233  -60.439  54.405  1
510569  93.275  -60.450  54.408  1
510570  93.317  -60.463  54.406  1
510571  93.359  -60.475  54.401  1
510572  93.401  -60.488  54.396  1
510573  93.443  -60.500  54.389  1
510574  93.485  -60.513  54.380  1
510575  93.525  -60.527  54.369  1
510576  93.566  -60.542  54.362  1
510577  93.607  -60.557  54.346  1
510578  93.648  -60.572  54.328  1
510579  93.689  -60.587  54.314  1
510580  93.729  -60.602  54.305  1
510581  93.770  -60.617  54.300  1
510582  93.811  -60.632  54.290  1
510583  93.853  -60.645  54.279  1
510584  93.897  -60.657  54.265  1
510585  93.940  -60.668  54.247  1
510586  93.983  -60.680  54.228  1
510587  94.027  -60.691  54.214  1
510588  94.069  -60.703  54.198  1
510589  94.111  -60.714  54.178  1
510590  94.152  -60.726  54.156  1
510591  94.194  -60.737  54.133  1
510592  94.236  -60.748  54.118  1
510593  94.279  -60.758  54.104  1
510594  94.322  -60.768  54.086  1
510595  94.365  -60.777  54.066  1
510596  94.407  -60.785  54.045  1
510597  94.446  -60.790  54.027  1
510598  94.485  -60.795  54.010  1
510599  94.524  -60.799  53.991  1
510600  94.563  -60.804  53.968  1
510601  94.600  -60.808  53.940  1
510602  94.636  -60.814  53.912  1
510603  94.673  -60.818  53.884  1
510604  94.710  -60.823  53.863  1
510605  94.747  -60.827  53.845  1
510606  94.783  -60.832  53.828  1
510607  94.820  -60.836  53.810  1
510608  94.857  -60.842  53.787  1
510609  94.893  -60.848  53.762  1
510610  94.928  -60.853  53.733  1
510611  94.964  -60.858  53.704  1
510612  94.999  -60.864  53.673  1
510613  95.035  -60.869  53.636  1
510614  95.070  -60.874  53.597  1
510615  95.106  -60.879  53.555  1
510616  95.141  -60.885  53.512  1
510617  95.176  -60.890  53.468  1
510618  95.212  -60.896  53.424  1
510619  95.249  -60.903  53.378  1
510620  95.285  -60.909  53.333  1
510621  95.321  -60.914  53.289  1
510622  95.357  -60.920  53.244  1
510623  95.392  -60.927  53.199  1
510624  95.423  -60.939  53.157  1
510625  95.457  -60.946  53.112  1
510626  95.494  -60.950  53.068  1
510627  95.531  -60.954  53.024  1
510628  95.568  -60.958  52.980  1
510629  95.605  -60.961  52.939  1
510630  95.642  -60.965  52.898  1
510631  95.679  -60.969  52.856  1
510632  95.716  -60.973  52.814  1
510633  95.755  -60.976  52.772  1
510634  95.793  -60.980  52.731  1
510635  95.827  -60.984  52.693  1
510636  95.868  -60.989  52.656  1
510637  95.908  -60.994  52.618  1
510638  95.950  -60.999  52.580  1
510639  95.990  -61.005  52.543  1
510640  96.031  -61.009  52.512  1
510641  96.072  -61.014  52.484  1
510642  96.113  -61.019  52.458  1
510643  96.159  -61.021  52.431  1
510644  96.208  -61.024  52.403  1
510645  96.243  -61.032  52.377  1
510646  96.278  -61.039  52.349  1
510647  96.315  -61.040  52.320  1
510648  96.352  -61.042  52.290  1
510649  96.388  -61.043  52.257  1
510650  96.425  -61.045  52.218  1
510651  96.466  -61.043  52.173  1
510652  96.513  -61.039  52.129  1
510653  96.559  -61.033  52.085  1
510654  96.606  -61.029  52.043  1
510655  96.653  -61.024  52.003  1
510656  96.700  -61.019  51.963  1
510657  96.741  -61.027  51.924  1
510658  96.780  -61.042  51.887  1
510659  96.815  -61.056  51.851  1
510660  96.849  -61.071  51.816  1
510661  96.883  -61.085  51.783  1
510662  96.917  -61.099  51.748  1
510663  96.951  -61.114  51.715  1
510664  96.986  -61.122  51.681  1
510665  97.023  -61.127  51.647  1
510666  97.058  -61.133  51.614  1
510667  97.093  -61.125  51.579  1
510668  97.128  -61.116  51.545  1
510669  97.163  -61.106  51.510  1
510670  97.192  -61.109  51.476  1
510671  97.220  -61.124  51.441  1
510672  97.248  -61.141  51.406  1
510673  97.276  -61.153  51.369  1
510674  97.302  -61.141  51.330  1
510675  97.328  -61.129  51.290  1
510676  97.371  -61.121  51.251  1
510677  97.414  -61.114  51.213  1
510678  97.457  -61.105  51.175  1
510679  97.500  -61.098  51.137  1
510680  97.546  -61.096  51.099  1
510681  97.595  -61.101  51.062  1
510682  97.644  -61.105  51.025  1
510683  97.692  -61.110  50.988  1
510684  97.741  -61.114  50.951  1
510685  97.790  -61.119  50.914  1
510686  97.838  -61.124  50.877  1
510687  97.887  -61.129  50.841  1
510688  97.910  -61.136  50.805  1
510689  97.913  -61.143  50.768  1
510690  97.919  -61.152  50.731  1
510691  97.943  -61.168  50.693  1
510692  97.967  -61.183  50.656  1
510693  97.992  -61.199  50.620  1
510694  98.016  -61.215  50.584  1
511147  88.465  -58.911  56.067  1
511148  88.517  -58.918  56.046  1
511149  88.569  -58.924  56.026  1
511150  88.621  -58.931  56.006  1
511151  88.669  -58.941  55.986  1
511152  88.714  -58.952  55.966  1
511153  88.760  -58.965  55.946  1
511154  88.806  -58.977  55.927  1
511155  88.851  -58.989  55.907  1
511156  88.896  -59.000  55.887  1
511157  88.942  -59.012  55.866  1
511158  88.979  -59.024  55.843  1
511159  89.015  -59.035  55.821  1
511160  89.050  -59.046  55.798  1
511161  89.084  -59.062  55.777  1
511162  89.117  -59.077  55.754  1
511163  89.150  -59.093  55.731  1
511164  89.183  -59.109  55.710  1
511165  89.216  -59.125  55.690  1
511166  89.249  -59.141  55.673  1
511167  89.282  -59.157  55.661  1
511168  89.315  -59.173  55.651  1
511169  89.348  -59.188  55.646  1
511170  89.382  -59.204  55.648  1
511171  89.414  -59.220  55.657  1
511172  89.448  -59.237  55.666  1
511173  89.486  -59.251  55.669  1
511174  89.525  -59.266  55.670  1
511175  89.563  -59.281  55.673  1
511176  89.601  -59.297  55.675  1
511177  89.640  -59.311  55.673  1
511178  89.678  -59.326  55.671  1
511179  89.717  -59.341  55.677  1
511180  89.755  -59.356  55.686  1
511181  89.795  -59.372  55.696  1
511182  89.836  -59.388  55.710  1
511183  89.876  -59.403  55.725  1
511184  89.919  -59.419  55.739  1
511185  89.963  -59.433  55.756  1
511186  90.007  -59.447  55.773  1
511187  90.051  -59.462  55.788  1
511188  90.096  -59.476  55.798  1
511189  90.140  -59.491  55.806  1
511190  90.184  -59.505  55.800  1
511191  90.229  -59.519  55.783  1
511192  90.272  -59.533  55.763  1
511193  90.317  -59.547  55.742  1
511194  90.361  -59.562  55.715  1
511195  90.405  -59.576  55.671  1
511196  90.450  -59.590  55.619  1
511197  90.494  -59.602  55.561  1
511198  90.539  -59.615  55.499  1
511199  90.583  -59.628  55.446  1
511200  90.627  -59.641  55.396  1
511201  90.672  -59.653  55.351  1
511202  90.716  -59.666  55.308  1
511203  90.761  -59.679  55.260  1
511204  90.805  -59.691  55.212  1
511205  90.850  -59.704  55.169  1
511206  90.894  -59.717  55.132  1
511207  90.939  -59.729  55.098  1
511208  90.976  -59.747  55.069  1
511209  91.013  -59.765  55.045  1
511210  91.050  -59.784  55.027  1
511211  91.087  -59.802  55.010  1
511212  91.123  -59.820  54.993  1
511213  91.160  -59.839  54.977  1
511214  91.197  -59.858  54.966  1
511215  91.233  -59.877  54.954  1
511216  91.271  -59.893  54.943  1
511217  91.308  -59.908  54.934  1
511218  91.343  -59.919  54.926  1
511219  91.378  -59.929  54.915  1
511220  91.413  -59.938  54.906  1
511221  91.448  -59.948  54.901  1
511222  91.483  -59.957  54.896  1
511223  91.518  -59.967  54.890  1
511224  91.554  -59.976  54.884  1
511225  91.588  -59.985  54.875  1
511226  91.624  -59.995  54.863  1
511227  91.658  -60.004  54.849  1
511228  91.694  -60.014  54.835  1
511229  91.729  -60.023  54.818  1
511230  91.764  -60.033  54.798  1
511231  91.799  -60.042  54.780  1
511232  91.834  -60.052  54.766  1
511233  91.860  -60.062  54.756  1
511234  91.879  -60.074  54.750  1
511235  91.897  -60.085  54.746  1
511236  91.917  -60.097  54.741  1
511237  91.935  -60.108  54.734  1
511238  91.954  -60.121  54.725  1
511239  91.973  -60.132  54.712  1
511240  91.992  -60.143  54.691  1
511241  92.018  -60.150  54.662  1
511242  92.058  -60.155  54.629  1
511243  92.100  -60.165  54.594  1
511244  92.143  -60.174  54.565  1
511245  92.186  -60.184  54.549  1
511246  92.229  -60.193  54.538  1
511247  92.275  -60.203  54.525  1
511248  92.319  -60.213  54.513  1
511249  92.364  -60.223  54.502  1
511250  92.409  -60.232  54.491  1
511251  92.454  -60.242  54.492  1
511252  92.499  -60.252  54.500  1
511253  92.544  -60.261  54.500  1
511254  92.589  -60.271  54.498  1
511255  92.634  -60.281  54.502  1
511256  92.678  -60.290  54.511  1
511257  92.723  -60.300  54.505  1
511258  92.768  -60.309  54.496  1
511259  92.813  -60.319  54.486  1
511260  92.858  -60.329  54.473  1
511261  92.903  -60.338  54.461  1
511262  92.948  -60.348  54.445  1
511263  92.993  -60.358  54.430  1
511264  93.036  -60.365  54.418  1
511265  93.076  -60.371  54.409  1
511266  93.117  -60.377  54.402  1
511267  93.158  -60.383  54.400  1
511268  93.199  -60.388  54.406  1
511269  93.240  -60.397  54.412  1
511270  93.282  -60.410  54.415  1
511271  93.324  -60.422  54.413  1
511272  93.366  -60.434  54.405  1
511273  93.408  -60.447  54.397  1
511274  93.449  -60.461  54.388  1
511275  93.490  -60.476  54.376  1
511276  93.531  -60.491  54.365  1
511277  93.571  -60.506  54.353  1
511278  93.612  -60.522  54.336  1
511279  93.653  -60.537  54.318  1
511280  93.693  -60.552  54.301  1
511281  93.734  -60.566  54.287  1
511282  93.775  -60.582  54.277  1
511283  93.816  -60.597  54.269  1
511284  93.858  -60.609  54.260  1
511285  93.902  -60.620  54.249  1
511286  93.945  -60.632  54.237  1
511287  93.989  -60.644  54.228  1
511288  94.032  -60.655  54.217  1
511289  94.075  -60.667  54.202  1
511290  94.118  -60.679  54.184  1
511291  94.159  -60.690  54.163  1
511292  94.201  -60.701  54.141  1
511293  94.243  -60.713  54.125  1
511294  94.286  -60.723  54.110  1
511295  94.329  -60.732  54.092  1
511296  94.372  -60.741  54.074  1
511297  94.411  -60.746  54.059  1
511298  94.450  -60.751  54.043  1
511299  94.489  -60.755  54.024  1
511300  94.528  -60.760  54.004  1
511301  94.567  -60.764  53.980  1
511302  94.603  -60.769  53.954  1
511303  94.640  -60.774  53.927  1
511304  94.677  -60.779  53.905  1
511305  94.713  -60.783  53.889  1
511306  94.750  -60.788  53.875  1
511307  94.787  -60.792  53.858  1
511308  94.826  -60.798  53.838  1
511309  94.863  -60.803  53.814  1
511310  94.899  -60.810  53.787  1
511311  94.934  -60.817  53.759  1
511312  94.970  -60.823  53.730  1
511313  95.005  -60.828  53.700  1
511314  95.041  -60.833  53.664  1
511315  95.076  -60.839  53.624  1
511316  95.112  -60.844  53.583  1
511317  95.147  -60.849  53.540  1
511318  95.183  -60.854  53.495  1
511319  95.219  -60.861  53.449  1
511320  95.255  -60.867  53.401  1
511321  95.292  -60.874  53.353  1
511322  95.328  -60.879  53.306  1
511323  95.365  -60.885  53.260  1
511324  95.398  -60.894  53.215  1
511325  95.429  -60.905  53.170  1
511326  95.466  -60.909  53.124  1
511327  95.503  -60.913  53.079  1
511328  95.540  -60.917  53.034  1
511329  95.577  -60.920  52.990  1
511330  95.614  -60.924  52.946  1
511331  95.651  -60.928  52.904  1
511332  95.688  -60.932  52.861  1
511333  95.725  -60.936  52.818  1
511334  95.761  -60.941  52.777  1
511335  95.801  -60.945  52.737  1
511336  95.842  -60.950  52.697  1
511337  95.883  -60.955  52.660  1
511338  95.924  -60.960  52.622  1
511339  95.966  -60.965  52.583  1
511340  96.007  -60.970  52.547  1
511341  96.048  -60.975  52.515  1
511342  96.090  -60.980  52.486  1
511343  96.131  -60.986  52.460  1
511344  96.172  -60.990  52.434  1
511345  96.214  -60.995  52.406  1
511346  96.252  -60.998  52.378  1
511347  96.289  -60.999  52.349  1
511348  96.325  -61.001  52.321  1
511349  96.362  -61.002  52.293  1
511350  96.398  -61.005  52.264  1
511351  96.435  -61.006  52.229  1
511352  96.472  -61.008  52.188  1
511353  96.512  -61.007  52.145  1
511354  96.559  -61.002  52.101  1
511355  96.605  -60.997  52.057  1
511356  96.652  -60.992  52.015  1
511357  96.699  -60.987  51.974  1
511358  96.742  -60.991  51.934  1
511359  96.781  -61.005  51.896  1
511360  96.819  -61.020  51.859  1
511361  96.858  -61.033  51.824  1
511362  96.896  -61.048  51.789  1
511363  96.931  -61.062  51.753  1
511364  96.964  -61.077  51.719  1
511365  96.999  -61.089  51.685  1
511366  97.035  -61.095  51.651  1
511367  97.070  -61.091  51.618  1
511368  97.105  -61.081  51.582  1
511369  97.140  -61.072  51.547  1
511370  97.174  -61.062  51.512  1
511371  97.203  -61.074  51.476  1
511372  97.231  -61.091  51.443  1
511373  97.258  -61.108  51.408  1
511374  97.286  -61.116  51.372  1
511375  97.312  -61.104  51.334  1
511376  97.338  -61.092  51.294  1
511377  97.373  -61.082  51.255  1
511378  97.416  -61.074  51.217  1
511379  97.459  -61.066  51.180  1
511380  97.503  -61.058  51.142  1
511381  97.550  -61.061  51.103  1
511382  97.599  -61.067  51.067  1
511383  97.648  -61.071  51.030  1
511384  97.697  -61.076  50.993  1
511385  97.745  -61.080  50.955  1
511386  97.794  -61.085  50.918  1
511387  97.843  -61.089  50.881  1
511388  97.891  -61.094  50.845  1
511389  97.914  -61.101  50.808  1
511390  97.918  -61.109  50.772  1
511391  97.921  -61.118  50.735  1
511392  97.945  -61.133  50.697  1
511393  97.969  -61.149  50.659  1
511394  97.993  -61.165  50.623  1
511395  98.017  -61.180  50.587  1
511396  98.041  -61.196  50.551  1
511823  87.341  -58.780  56.862  1
511824  87.383  -58.779  56.828  1
511825  87.425  -58.777  56.793  1
511826  87.468  -58.776  56.757  1
511827  87.510  -58.774  56.720  1
511828  87.553  -58.772  56.683  1
511829  87.595  -58.770  56.644  1
511830  87.637  -58.769  56.606  1
511831  87.674  -58.771  56.568  1
511832  87.711  -58.773  56.529  1
511833  87.747  -58.775  56.490  1
511848  88.491  -58.866  56.065  1
511849  88.544  -58.874  56.044  1
511850  88.591  -58.883  56.023  1
511851  88.636  -58.896  56.003  1
511852  88.682  -58.908  55.983  1
511853  88.728  -58.919  55.963  1
511854  88.773  -58.931  55.943  1
511855  88.818  -58.943  55.924  1
511856  88.863  -58.955  55.905  1
511857  88.909  -58.967  55.886  1
511858  88.954  -58.979  55.866  1
511859  88.989  -58.990  55.844  1
511860  89.025  -59.001  55.822  1
511861  89.060  -59.012  55.801  1
511862  89.094  -59.026  55.780  1
511863  89.127  -59.041  55.759  1
511864  89.161  -59.057  55.738  1
511865  89.194  -59.073  55.718  1
511866  89.227  -59.089  55.699  1
511867  89.260  -59.105  55.683  1
511868  89.293  -59.121  55.670  1
511869  89.326  -59.137  55.661  1
511870  89.359  -59.153  55.656  1
511871  89.392  -59.168  55.658  1
511872  89.425  -59.184  55.668  1
511873  89.460  -59.196  55.681  1
511874  89.500  -59.212  55.690  1
511875  89.540  -59.228  55.697  1
511876  89.579  -59.244  55.703  1
511877  89.617  -59.258  55.706  1
511878  89.655  -59.273  55.703  1
511879  89.693  -59.288  55.704  1
511880  89.732  -59.303  55.712  1
511881  89.770  -59.318  55.722  1
511882  89.809  -59.333  55.734  1
511883  89.850  -59.349  55.749  1
511884  89.891  -59.365  55.760  1
511885  89.934  -59.380  55.770  1
511886  89.978  -59.394  55.782  1
511887  90.022  -59.409  55.795  1
511888  90.067  -59.423  55.811  1
511889  90.111  -59.437  55.824  1
511890  90.155  -59.451  55.831  1
511891  90.199  -59.466  55.825  1
511892  90.244  -59.480  55.808  1
511893  90.288  -59.494  55.784  1
511894  90.332  -59.509  55.755  1
511895  90.376  -59.523  55.726  1
511896  90.421  -59.538  55.684  1
511897  90.465  -59.551  55.632  1
511898  90.509  -59.566  55.574  1
511899  90.553  -59.579  55.516  1
511900  90.598  -59.591  55.461  1
511901  90.642  -59.604  55.409  1
511902  90.687  -59.616  55.362  1
511903  90.731  -59.629  55.319  1
511904  90.776  -59.642  55.271  1
511905  90.820  -59.654  55.219  1
511906  90.865  -59.667  55.175  1
511907  90.909  -59.680  55.135  1
511908  90.952  -59.694  55.100  1
511909  90.989  -59.712  55.069  1
511910  91.025  -59.731  55.043  1
511911  91.062  -59.749  55.022  1
511912  91.099  -59.768  55.003  1
511913  91.136  -59.786  54.984  1
511914  91.172  -59.805  54.968  1
511915  91.209  -59.823  54.955  1
511916  91.246  -59.838  54.942  1
511917  91.283  -59.854  54.932  1
511918  91.320  -59.869  54.923  1
511919  91.357  -59.883  54.915  1
511920  91.392  -59.892  54.904  1
511921  91.427  -59.902  54.894  1
511922  91.462  -59.911  54.887  1
511923  91.497  -59.921  54.882  1
511924  91.532  -59.930  54.877  1
511925  91.568  -59.940  54.869  1
511926  91.602  -59.949  54.858  1
511927  91.638  -59.959  54.842  1
511928  91.672  -59.968  54.824  1
511929  91.708  -59.977  54.806  1
511930  91.743  -59.987  54.789  1
511931  91.778  -59.996  54.773  1
511932  91.813  -60.006  54.759  1
511933  91.844  -60.016  54.750  1
511934  91.863  -60.027  54.744  1
511935  91.882  -60.040  54.741  1
511936  91.900  -60.051  54.750  1
511937  91.920  -60.062  54.752  1
511938  91.938  -60.074  54.748  1
511939  91.957  -60.086  54.738  1
511940  91.977  -60.096  54.722  1
511941  92.005  -60.102  54.699  1
511942  92.032  -60.108  54.669  1
511943  92.075  -60.108  54.632  1
511944  92.118  -60.118  54.594  1
511945  92.160  -60.127  54.560  1
511946  92.203  -60.137  54.542  1
511947  92.245  -60.146  54.535  1
511948  92.287  -60.155  54.525  1
511949  92.330  -60.165  54.514  1
511950  92.372  -60.175  54.501  1
511951  92.415  -60.185  54.486  1
511952  92.458  -60.194  54.476  1
511953  92.503  -60.204  54.475  1
511954  92.548  -60.214  54.478  1
511955  92.593  -60.224  54.480  1
511956  92.638  -60.233  54.476  1
511957  92.683  -60.243  54.479  1
511958  92.727  -60.253  54.484  1
511959  92.772  -60.262  54.482  1
511960  92.817  -60.271  54.472  1
511961  92.862  -60.281  54.457  1
511962  92.907  -60.291  54.443  1
511963  92.952  -60.300  54.429  1
511964  92.997  -60.310  54.413  1
511965  93.042  -60.320  54.401  1
511966  93.083  -60.326  54.398  1
511967  93.124  -60.331  54.402  1
511968  93.164  -60.337  54.409  1
511969  93.206  -60.344  54.414  1
511970  93.248  -60.357  54.419  1
511971  93.289  -60.369  54.422  1
511972  93.332  -60.382  54.422  1
511973  93.372  -60.396  54.415  1
511974  93.413  -60.411  54.408  1
511975  93.454  -60.426  54.397  1
511976  93.495  -60.441  54.384  1
511977  93.536  -60.456  54.371  1
511978  93.576  -60.471  54.357  1
511979  93.617  -60.486  54.340  1
511980  93.657  -60.501  54.321  1
511981  93.698  -60.516  54.302  1
511982  93.739  -60.532  54.283  1
511983  93.780  -60.546  54.268  1
511984  93.821  -60.561  54.255  1
511985  93.864  -60.573  54.244  1
511986  93.907  -60.585  54.232  1
511987  93.951  -60.596  54.222  1
511988  93.994  -60.607  54.216  1
511989  94.038  -60.619  54.207  1
511990  94.081  -60.631  54.195  1
511991  94.124  -60.642  54.181  1
511992  94.167  -60.654  54.164  1
511993  94.208  -60.666  54.145  1
511994  94.250  -60.677  54.127  1
511995  94.293  -60.686  54.112  1
511996  94.336  -60.696  54.097  1
511997  94.376  -60.701  54.082  1
511998  94.415  -60.707  54.068  1
511999  94.454  -60.711  54.051  1
512000  94.493  -60.716  54.034  1
512001  94.532  -60.720  54.013  1
512002  94.570  -60.725  53.990  1
512003  94.607  -60.729  53.968  1
512004  94.644  -60.735  53.949  1
512005  94.680  -60.739  53.931  1
512006  94.717  -60.744  53.916  1
512007  94.755  -60.748  53.901  1
512008  94.794  -60.754  53.883  1
512009  94.832  -60.759  53.861  1
512010  94.870  -60.764  53.837  1
512011  94.905  -60.771  53.809  1
512012  94.941  -60.779  53.780  1
512013  94.976  -60.785  53.751  1
512014  95.012  -60.792  53.722  1
512015  95.047  -60.798  53.685  1
512016  95.083  -60.803  53.646  1
512017  95.118  -60.808  53.605  1
512018  95.154  -60.814  53.563  1
512019  95.189  -60.819  53.518  1
512020  95.226  -60.826  53.471  1
512021  95.262  -60.832  53.422  1
512022  95.299  -60.839  53.373  1
512023  95.335  -60.845  53.325  1
512024  95.371  -60.851  53.278  1
512025  95.404  -60.860  53.233  1
512026  95.438  -60.868  53.187  1
512027  95.475  -60.872  53.139  1
512028  95.512  -60.876  53.092  1
512029  95.548  -60.879  53.046  1
512030  95.586  -60.883  53.000  1
512031  95.622  -60.887  52.955  1
512032  95.660  -60.891  52.912  1
512033  95.696  -60.897  52.868  1
512034  95.732  -60.903  52.825  1
512035  95.768  -60.909  52.782  1
512036  95.808  -60.908  52.741  1
512037  95.849  -60.913  52.702  1
512038  95.891  -60.918  52.663  1
512039  95.932  -60.923  52.624  1
512040  95.973  -60.928  52.586  1
512041  96.014  -60.933  52.550  1
512042  96.055  -60.939  52.517  1
512043  96.097  -60.944  52.489  1
512044  96.138  -60.948  52.463  1
512045  96.179  -60.954  52.436  1
512046  96.219  -60.958  52.408  1
512047  96.257  -60.960  52.379  1
512048  96.297  -60.961  52.351  1
512049  96.336  -60.962  52.324  1
512050  96.373  -60.964  52.297  1
512051  96.409  -60.965  52.269  1
512052  96.446  -60.967  52.237  1
512053  96.482  -60.968  52.201  1
512054  96.519  -60.970  52.161  1
512055  96.558  -60.970  52.119  1
512056  96.605  -60.964  52.076  1
512057  96.652  -60.960  52.032  1
512058  96.698  -60.955  51.989  1
512059  96.743  -60.955  51.948  1
512060  96.782  -60.969  51.909  1
512061  96.821  -60.983  51.871  1
512062  96.859  -60.997  51.834  1
512063  96.898  -61.011  51.799  1
512064  96.937  -61.026  51.763  1
512065  96.975  -61.039  51.728  1
512066  97.012  -61.054  51.693  1
512067  97.047  -61.057  51.658  1
512068  97.082  -61.047  51.625  1
512069  97.118  -61.033  51.590  1
512070  97.156  -61.011  51.554  1
512071  97.187  -61.014  51.517  1
512072  97.213  -61.041  51.481  1
512073  97.241  -61.058  51.446  1
512074  97.269  -61.077  51.410  1
512075  97.296  -61.078  51.374  1
512076  97.322  -61.066  51.337  1
512077  97.349  -61.054  51.298  1
512078  97.375  -61.042  51.260  1
512079  97.418  -61.034  51.222  1
512080  97.461  -61.027  51.185  1
512081  97.507  -61.023  51.147  1
512082  97.555  -61.027  51.108  1
512083  97.604  -61.032  51.071  1
512084  97.653  -61.036  51.036  1
512085  97.701  -61.042  50.998  1
512086  97.750  -61.046  50.960  1
512087  97.799  -61.051  50.922  1
512088  97.847  -61.055  50.885  1
512089  97.896  -61.060  50.849  1
512090  97.918  -61.067  50.811  1
512091  97.922  -61.075  50.775  1
512092  97.926  -61.083  50.738  1
512093  97.947  -61.098  50.700  1
512094  97.971  -61.113  50.662  1
512095  97.995  -61.129  50.626  1
512096  98.019  -61.145  50.589  1
512097  98.043  -61.160  50.553  1
512098  98.068  -61.176  50.517  1
512522  87.272  -58.735  56.937  1
512523  87.315  -58.733  56.905  1
512524  87.357  -58.732  56.872  1
512525  87.400  -58.730  56.838  1
512526  87.442  -58.729  56.804  1
512527  87.484  -58.726  56.768  1
512528  87.527  -58.725  56.731  1
512529  87.569  -58.723  56.693  1
512530  87.612  -58.722  56.655  1
512531  87.652  -58.721  56.615  1
512532  87.689  -58.723  56.577  1
512533  87.726  -58.725  56.537  1
512534  87.763  -58.726  56.498  1
512535  87.799  -58.729  56.460  1
512536  87.842  -58.733  56.423  1
512549  88.513  -58.827  56.063  1
512550  88.558  -58.838  56.042  1
512551  88.604  -58.850  56.021  1
512552  88.649  -58.862  56.001  1
512553  88.695  -58.874  55.981  1
512554  88.740  -58.886  55.960  1
512555  88.785  -58.898  55.940  1
512556  88.831  -58.910  55.921  1
512557  88.877  -58.921  55.903  1
512558  88.922  -58.933  55.884  1
512559  88.963  -58.945  55.864  1
512560  88.999  -58.956  55.843  1
512561  89.034  -58.968  55.823  1
512562  89.070  -58.979  55.803  1
512563  89.105  -58.990  55.783  1
512564  89.138  -59.005  55.764  1
512565  89.172  -59.021  55.744  1
512566  89.204  -59.037  55.725  1
512567  89.238  -59.053  55.707  1
512568  89.271  -59.069  55.692  1
512569  89.304  -59.085  55.680  1
512570  89.337  -59.101  55.670  1
512571  89.370  -59.117  55.665  1
512572  89.403  -59.133  55.665  1
512573  89.437  -59.149  55.671  1
512574  89.472  -59.155  55.683  1
512575  89.512  -59.171  55.697  1
512576  89.552  -59.187  55.708  1
512577  89.592  -59.203  55.717  1
512578  89.631  -59.219  55.724  1
512579  89.671  -59.235  55.726  1
512580  89.709  -59.250  55.734  1
512581  89.747  -59.265  55.748  1
512582  89.786  -59.280  55.763  1
512583  89.824  -59.295  55.780  1
512584  89.864  -59.311  55.799  1
512585  89.905  -59.327  55.806  1
512586  89.949  -59.341  55.812  1
512587  89.993  -59.355  55.817  1
512588  90.037  -59.369  55.823  1
512589  90.082  -59.384  55.839  1
512590  90.126  -59.398  55.849  1
512591  90.170  -59.413  55.851  1
512592  90.215  -59.427  55.845  1
512593  90.259  -59.441  55.829  1
512594  90.303  -59.456  55.802  1
512595  90.347  -59.469  55.768  1
512596  90.391  -59.484  55.733  1
512597  90.436  -59.498  55.691  1
512598  90.480  -59.513  55.644  1
512599  90.524  -59.527  55.590  1
512600  90.569  -59.541  55.529  1
512601  90.613  -59.555  55.472  1
512602  90.657  -59.568  55.417  1
512603  90.701  -59.580  55.367  1
512604  90.746  -59.593  55.320  1
512605  90.791  -59.606  55.271  1
512606  90.835  -59.619  55.222  1
512607  90.879  -59.631  55.176  1
512608  90.924  -59.644  55.135  1
512609  90.964  -59.660  55.099  1
512610  91.001  -59.678  55.067  1
512611  91.037  -59.697  55.039  1
512612  91.074  -59.715  55.015  1
512613  91.111  -59.734  54.993  1
512614  91.148  -59.752  54.975  1
512615  91.185  -59.767  54.959  1
512616  91.222  -59.783  54.944  1
512617  91.259  -59.798  54.931  1
512618  91.296  -59.814  54.920  1
512619  91.333  -59.830  54.912  1
512620  91.371  -59.845  54.904  1
512621  91.406  -59.857  54.893  1
512622  91.441  -59.866  54.882  1
512623  91.476  -59.876  54.873  1
512624  91.512  -59.885  54.866  1
512625  91.546  -59.895  54.859  1
512626  91.582  -59.904  54.850  1
512627  91.616  -59.914  54.838  1
512628  91.652  -59.923  54.821  1
512629  91.687  -59.933  54.803  1
512630  91.722  -59.942  54.785  1
512631  91.757  -59.952  54.768  1
512632  91.792  -59.961  54.752  1
512633  91.827  -59.970  54.740  1
512634  91.847  -59.982  54.734  1
512635  91.866  -59.993  54.735  1
512636  91.885  -60.005  54.744  1
512637  91.904  -60.017  54.753  1
512638  91.923  -60.028  54.756  1
512639  91.941  -60.040  54.753  1
512640  91.964  -60.049  54.743  1
512641  91.992  -60.054  54.727  1
512642  92.019  -60.059  54.700  1
512643  92.047  -60.065  54.668  1
512644  92.089  -60.066  54.629  1
512645  92.135  -60.070  54.591  1
512646  92.177  -60.080  54.559  1
512647  92.219  -60.089  54.538  1
512648  92.262  -60.099  54.532  1
512649  92.304  -60.108  54.526  1
512650  92.347  -60.118  54.517  1
512651  92.389  -60.127  54.503  1
512652  92.432  -60.137  54.487  1
512653  92.474  -60.147  54.469  1
512654  92.516  -60.156  54.460  1
512655  92.559  -60.166  54.458  1
512656  92.601  -60.176  54.458  1
512657  92.644  -60.186  54.456  1
512658  92.687  -60.195  54.455  1
512659  92.731  -60.205  54.457  1
512660  92.776  -60.215  54.456  1
512661  92.821  -60.224  54.451  1
512662  92.866  -60.234  54.442  1
512663  92.911  -60.243  54.429  1
512664  92.956  -60.253  54.417  1
512665  93.001  -60.262  54.408  1
512666  93.046  -60.272  54.403  1
512667  93.089  -60.281  54.404  1
512668  93.130  -60.287  54.408  1
512669  93.171  -60.292  54.421  1
512670  93.213  -60.304  54.425  1
512671  93.255  -60.316  54.427  1
512672  93.296  -60.331  54.430  1
512673  93.337  -60.345  54.434  1
512674  93.377  -60.360  54.431  1
512675  93.418  -60.375  54.424  1
512676  93.459  -60.391  54.415  1
512677  93.500  -60.406  54.403  1
512678  93.540  -60.421  54.390  1
512679  93.581  -60.435  54.376  1
512680  93.622  -60.450  54.359  1
512681  93.662  -60.466  54.338  1
512682  93.703  -60.481  54.315  1
512683  93.744  -60.496  54.292  1
512684  93.784  -60.511  54.271  1
512685  93.826  -60.525  54.250  1
512686  93.869  -60.537  54.233  1
512687  93.913  -60.548  54.218  1
512688  93.956  -60.560  54.206  1
512689  93.999  -60.572  54.198  1
512690  94.043  -60.583  54.192  1
512691  94.086  -60.594  54.183  1
512692  94.130  -60.607  54.172  1
512693  94.173  -60.618  54.159  1
512694  94.215  -60.629  54.144  1
512695  94.257  -60.641  54.127  1
512696  94.300  -60.651  54.111  1
512697  94.341  -60.657  54.098  1
512698  94.380  -60.662  54.085  1
512699  94.419  -60.666  54.072  1
512700  94.458  -60.672  54.056  1
512701  94.496  -60.676  54.039  1
512702  94.536  -60.681  54.021  1
512703  94.574  -60.685  54.003  1
512704  94.611  -60.690  53.986  1
512705  94.647  -60.695  53.970  1
512706  94.685  -60.700  53.952  1
512707  94.724  -60.705  53.936  1
512708  94.762  -60.710  53.918  1
512709  94.801  -60.715  53.897  1
512710  94.839  -60.720  53.875  1
512711  94.876  -60.726  53.848  1
512712  94.912  -60.733  53.820  1
512713  94.947  -60.740  53.791  1
512714  94.983  -60.747  53.761  1
512715  95.018  -60.754  53.730  1
512716  95.054  -60.761  53.692  1
512717  95.089  -60.767  53.654  1
512718  95.125  -60.773  53.614  1
512719  95.160  -60.778  53.573  1
512720  95.196  -60.783  53.530  1
512721  95.232  -60.790  53.486  1
512722  95.269  -60.797  53.439  1
512723  95.305  -60.804  53.393  1
512724  95.342  -60.810  53.348  1
512725  95.378  -60.816  53.303  1
512726  95.410  -60.826  53.257  1
512727  95.446  -60.831  53.209  1
512728  95.483  -60.835  53.159  1
512729  95.520  -60.839  53.109  1
512730  95.557  -60.842  53.060  1
512731  95.594  -60.846  53.012  1
512732  95.630  -60.852  52.967  1
512733  95.667  -60.858  52.922  1
512734  95.703  -60.865  52.877  1
512735  95.740  -60.871  52.832  1
512736  95.776  -60.875  52.789  1
512737  95.815  -60.871  52.746  1
512738  95.856  -60.876  52.706  1
512739  95.898  -60.882  52.666  1
512740  95.939  -60.886  52.627  1
512741  95.980  -60.892  52.588  1
512742  96.022  -60.897  52.552  1
512743  96.063  -60.901  52.521  1
512744  96.104  -60.907  52.492  1
512745  96.145  -60.912  52.466  1
512746  96.186  -60.917  52.439  1
512747  96.223  -60.920  52.411  1
512748  96.261  -60.922  52.382  1
512749  96.301  -60.923  52.354  1
512750  96.340  -60.924  52.327  1
512751  96.379  -60.925  52.301  1
512752  96.419  -60.926  52.274  1
512753  96.456  -60.927  52.245  1
512754  96.493  -60.929  52.212  1
512755  96.530  -60.930  52.175  1
512756  96.566  -60.932  52.135  1
512757  96.604  -60.933  52.093  1
512758  96.651  -60.928  52.050  1
512759  96.698  -60.923  52.007  1
512760  96.744  -60.918  51.965  1
512761  96.783  -60.933  51.925  1
512762  96.822  -60.947  51.886  1
512763  96.861  -60.961  51.848  1
512764  96.899  -60.975  51.811  1
512765  96.938  -60.989  51.775  1
512766  96.976  -61.003  51.739  1
512767  97.022  -61.011  51.704  1
512768  97.071  -61.016  51.670  1
512769  97.111  -60.980  51.637  1
512770  97.150  -60.944  51.602  1
512771  97.185  -60.922  51.565  1
512772  97.206  -60.957  51.528  1
512773  97.227  -60.997  51.491  1
512774  97.251  -61.027  51.454  1
512775  97.280  -61.044  51.417  1
512776  97.306  -61.041  51.380  1
512777  97.332  -61.029  51.343  1
512778  97.359  -61.017  51.305  1
512779  97.385  -61.005  51.268  1
512780  97.421  -60.995  51.230  1
512781  97.464  -60.987  51.192  1
512782  97.511  -60.989  51.154  1
512783  97.560  -60.993  51.116  1
512784  97.608  -60.998  51.079  1
512785  97.657  -61.002  51.042  1
512786  97.706  -61.007  51.005  1
512787  97.754  -61.012  50.968  1
512788  97.803  -61.017  50.930  1
512789  97.852  -61.021  50.892  1
512790  97.900  -61.026  50.855  1
512791  97.923  -61.033  50.818  1
512792  97.927  -61.041  50.780  1
512793  97.930  -61.049  50.743  1
512794  97.948  -61.062  50.704  1
512795  97.972  -61.078  50.666  1
512796  97.997  -61.094  50.629  1
512797  98.021  -61.109  50.593  1
512798  98.045  -61.125  50.556  1
512799  98.069  -61.140  50.519  1
512800  98.093  -61.156  50.482  1
512801  98.119  -61.154  50.445  1
513222  87.247  -58.688  56.976  1
513223  87.289  -58.686  56.947  1
513224  87.331  -58.685  56.916  1
513225  87.374  -58.683  56.883  1
513226  87.416  -58.682  56.850  1
513227  87.459  -58.679  56.816  1
513228  87.501  -58.678  56.780  1
513229  87.543  -58.676  56.743  1
513230  87.586  -58.675  56.705  1
513231  87.628  -58.673  56.666  1
513232  87.668  -58.673  56.626  1
513233  87.704  -58.675  56.587  1
513234  87.741  -58.677  56.547  1
513235  87.778  -58.679  56.507  1
513236  87.817  -58.682  56.468  1
513237  87.869  -58.689  56.430  1
513238  87.921  -58.695  56.394  1
513250  88.526  -58.793  56.061  1
513251  88.571  -58.805  56.039  1
513252  88.617  -58.817  56.019  1
513253  88.662  -58.829  55.999  1
513254  88.707  -58.840  55.978  1
513255  88.753  -58.852  55.957  1
513256  88.798  -58.864  55.937  1
513257  88.844  -58.877  55.918  1
513258  88.889  -58.888  55.900  1
513259  88.934  -58.900  55.881  1
513260  88.973  -58.911  55.862  1
513261  89.009  -58.923  55.842  1
513262  89.044  -58.934  55.822  1
513263  89.080  -58.945  55.804  1
513264  89.115  -58.956  55.786  1
513265  89.149  -58.970  55.767  1
513266  89.182  -58.986  55.748  1
513267  89.215  -59.002  55.730  1
513268  89.249  -59.018  55.713  1
513269  89.281  -59.034  55.700  1
513270  89.315  -59.049  55.689  1
513271  89.348  -59.065  55.680  1
513272  89.381  -59.081  55.673  1
513273  89.414  -59.096  55.670  1
513274  89.448  -59.105  55.672  1
513275  89.484  -59.114  55.682  1
513276  89.524  -59.130  55.696  1
513277  89.564  -59.146  55.711  1
513278  89.604  -59.162  55.724  1
513279  89.643  -59.178  55.736  1
513280  89.683  -59.194  55.744  1
513281  89.723  -59.210  55.759  1
513282  89.762  -59.227  55.776  1
513283  89.801  -59.242  55.796  1
513284  89.840  -59.257  55.817  1
513285  89.878  -59.272  55.840  1
513286  89.920  -59.287  55.850  1
513287  89.964  -59.302  55.853  1
513288  90.009  -59.316  55.854  1
513289  90.052  -59.331  55.859  1
513290  90.097  -59.345  55.873  1
513291  90.141  -59.359  55.868  1
513292  90.185  -59.373  55.861  1
513293  90.230  -59.388  55.853  1
513294  90.274  -59.402  55.843  1
513295  90.318  -59.416  55.818  1
513296  90.362  -59.431  55.781  1
513297  90.406  -59.445  55.737  1
513298  90.451  -59.460  55.696  1
513299  90.495  -59.474  55.656  1
513300  90.539  -59.488  55.608  1
513301  90.584  -59.502  55.544  1
513302  90.628  -59.516  55.484  1
513303  90.672  -59.531  55.426  1
513304  90.717  -59.544  55.372  1
513305  90.761  -59.557  55.320  1
513306  90.805  -59.569  55.270  1
513307  90.850  -59.582  55.221  1
513308  90.894  -59.595  55.175  1
513309  90.939  -59.607  55.133  1
513310  90.976  -59.626  55.096  1
513311  91.013  -59.644  55.063  1
513312  91.049  -59.662  55.034  1
513313  91.086  -59.681  55.008  1
513314  91.123  -59.697  54.985  1
513315  91.160  -59.713  54.966  1
513316  91.198  -59.728  54.949  1
513317  91.235  -59.744  54.933  1
513318  91.272  -59.759  54.921  1
513319  91.309  -59.774  54.911  1
513320  91.346  -59.790  54.902  1
513321  91.383  -59.805  54.893  1
513322  91.421  -59.821  54.882  1
513323  91.455  -59.830  54.870  1
513324  91.491  -59.839  54.858  1
513325  91.526  -59.849  54.847  1
513326  91.561  -59.858  54.839  1
513327  91.596  -59.868  54.830  1
513328  91.631  -59.877  54.817  1
513329  91.666  -59.887  54.801  1
513330  91.701  -59.896  54.784  1
513331  91.736  -59.906  54.766  1
513332  91.771  -59.915  54.749  1
513333  91.806  -59.925  54.734  1
513334  91.831  -59.936  54.724  1
513335  91.850  -59.947  54.719  1
513336  91.869  -59.959  54.723  1
513337  91.888  -59.971  54.736  1
513338  91.907  -59.982  54.744  1
513339  91.926  -59.994  54.745  1
513340  91.951  -60.000  54.740  1
513341  91.979  -60.006  54.728  1
513342  92.007  -60.011  54.711  1
513343  92.034  -60.017  54.688  1
513344  92.062  -60.022  54.662  1
513345  92.104  -60.023  54.632  1
513346  92.151  -60.022  54.601  1
513347  92.194  -60.032  54.571  1
513348  92.236  -60.042  54.544  1
513349  92.279  -60.051  54.523  1
513350  92.321  -60.061  54.516  1
513351  92.364  -60.071  54.512  1
513352  92.406  -60.080  54.504  1
513353  92.448  -60.090  54.493  1
513354  92.491  -60.099  54.475  1
513355  92.533  -60.109  54.459  1
513356  92.576  -60.118  54.443  1
513357  92.619  -60.128  54.433  1
513358  92.661  -60.138  54.439  1
513359  92.703  -60.148  54.437  1
513360  92.745  -60.157  54.431  1
513361  92.788  -60.167  54.430  1
513362  92.831  -60.177  54.431  1
513363  92.873  -60.187  54.429  1
513364  92.916  -60.196  54.419  1
513365  92.960  -60.206  54.412  1
513366  93.005  -60.215  54.407  1
513367  93.050  -60.224  54.407  1
513368  93.095  -60.234  54.412  1
513369  93.137  -60.241  54.416  1
513370  93.178  -60.251  54.429  1
513371  93.219  -60.265  54.434  1
513372  93.260  -60.280  54.436  1
513373  93.301  -60.295  54.438  1
513374  93.342  -60.310  54.439  1
513375  93.382  -60.325  54.437  1
513376  93.423  -60.340  54.433  1
513377  93.464  -60.355  54.427  1
513378  93.504  -60.370  54.419  1
513379  93.545  -60.385  54.408  1
513380  93.586  -60.400  54.394  1
513381  93.627  -60.416  54.377  1
513382  93.667  -60.430  54.357  1
513383  93.708  -60.445  54.336  1
513384  93.749  -60.460  54.313  1
513385  93.789  -60.475  54.290  1
513386  93.831  -60.489  54.266  1
513387  93.874  -60.501  54.242  1
513388  93.918  -60.513  54.218  1
513389  93.961  -60.524  54.196  1
513390  94.005  -60.535  54.182  1
513391  94.048  -60.547  54.172  1
513392  94.091  -60.559  54.164  1
513393  94.135  -60.570  54.156  1
513394  94.178  -60.582  54.147  1
513395  94.222  -60.594  54.137  1
513396  94.264  -60.605  54.122  1
513397  94.306  -60.613  54.108  1
513398  94.345  -60.618  54.096  1
513399  94.384  -60.622  54.084  1
513400  94.422  -60.627  54.072  1
513401  94.462  -60.632  54.058  1
513402  94.500  -60.637  54.043  1
513403  94.539  -60.641  54.029  1
513404  94.577  -60.646  54.015  1
513405  94.615  -60.651  54.002  1
513406  94.654  -60.656  53.988  1
513407  94.692  -60.661  53.968  1
513408  94.731  -60.666  53.949  1
513409  94.769  -60.671  53.929  1
513410  94.808  -60.676  53.907  1
513411  94.846  -60.681  53.882  1
513412  94.882  -60.688  53.854  1
513413  94.918  -60.695  53.825  1
513414  94.954  -60.701  53.795  1
513415  94.989  -60.708  53.764  1
513416  95.025  -60.716  53.730  1
513417  95.060  -60.723  53.692  1
513418  95.096  -60.729  53.654  1
513419  95.131  -60.736  53.616  1
513420  95.167  -60.742  53.576  1
513421  95.202  -60.748  53.534  1
513422  95.239  -60.755  53.493  1
513423  95.275  -60.762  53.450  1
513424  95.312  -60.769  53.409  1
513425  95.348  -60.776  53.368  1
513426  95.385  -60.781  53.325  1
513427  95.418  -60.789  53.280  1
513428  95.455  -60.793  53.233  1
513429  95.492  -60.797  53.181  1
513430  95.529  -60.801  53.128  1
513431  95.565  -60.807  53.078  1
513432  95.602  -60.814  53.027  1
513433  95.638  -60.820  52.979  1
513434  95.674  -60.826  52.933  1
513435  95.710  -60.833  52.886  1
513436  95.747  -60.839  52.840  1
513437  95.784  -60.841  52.795  1
513438  95.823  -60.835  52.752  1
513439  95.864  -60.839  52.710  1
513440  95.905  -60.845  52.670  1
513441  95.946  -60.850  52.631  1
513442  95.987  -60.855  52.592  1
513443  96.029  -60.860  52.556  1
513444  96.070  -60.865  52.525  1
513445  96.111  -60.870  52.497  1
513446  96.153  -60.875  52.469  1
513447  96.191  -60.879  52.442  1
513448  96.228  -60.882  52.413  1
513449  96.265  -60.884  52.385  1
513450  96.305  -60.885  52.358  1
513451  96.344  -60.886  52.331  1
513452  96.384  -60.887  52.305  1
513453  96.423  -60.888  52.279  1
513454  96.462  -60.889  52.251  1
513455  96.502  -60.890  52.220  1
513456  96.540  -60.892  52.186  1
513457  96.577  -60.893  52.148  1
513458  96.613  -60.895  52.108  1
513459  96.650  -60.896  52.068  1
513460  96.697  -60.891  52.026  1
513461  96.744  -60.886  51.983  1
513462  96.785  -60.896  51.942  1
513463  96.823  -60.911  51.903  1
513464  96.862  -60.924  51.864  1
513465  96.900  -60.939  51.826  1
513466  96.941  -60.951  51.789  1
513467  96.991  -60.955  51.752  1
513468  97.039  -60.960  51.718  1
513469  97.089  -60.964  51.685  1
513470  97.137  -60.965  51.651  1
513471  97.176  -60.929  51.616  1
513472  97.205  -60.923  51.579  1
513473  97.225  -60.942  51.541  1
513474  97.246  -60.961  51.503  1
513475  97.266  -60.980  51.464  1
513476  97.290  -61.011  51.426  1
513477  97.316  -61.003  51.389  1
513478  97.343  -60.991  51.351  1
513479  97.369  -60.979  51.314  1
513480  97.395  -60.967  51.278  1
513481  97.423  -60.955  51.240  1
513482  97.467  -60.949  51.202  1
513483  97.516  -60.955  51.163  1
513484  97.564  -60.959  51.125  1
513485  97.613  -60.964  51.089  1
513486  97.662  -60.968  51.050  1
513487  97.710  -60.973  51.013  1
513488  97.759  -60.977  50.976  1
513489  97.808  -60.982  50.938  1
513490  97.857  -60.987  50.899  1
513491  97.905  -60.992  50.862  1
513492  97.927  -60.998  50.825  1
513493  97.931  -61.007  50.787  1
513494  97.935  -61.014  50.748  1
513495  97.950  -61.027  50.710  1
513496  97.974  -61.042  50.671  1
513497  97.999  -61.058  50.634  1
513498  98.023  -61.074  50.597  1
513499  98.047  -61.089  50.560  1
513500  98.071  -61.105  50.523  1
513501  98.095  -61.121  50.485  1
513502  98.121  -61.110  50.448  1
513503  98.155  -61.111  50.412  1
513921  87.178  -58.642  57.041  1
513922  87.221  -58.641  57.014  1
513923  87.263  -58.639  56.986  1
513924  87.305  -58.638  56.958  1
513925  87.348  -58.636  56.928  1
513926  87.390  -58.635  56.896  1
513927  87.433  -58.632  56.864  1
513928  87.475  -58.631  56.830  1
513929  87.517  -58.629  56.793  1
513930  87.560  -58.628  56.756  1
513931  87.602  -58.626  56.718  1
513932  87.645  -58.625  56.679  1
513933  87.683  -58.626  56.638  1
513934  87.720  -58.627  56.599  1
513935  87.756  -58.629  56.557  1
513936  87.793  -58.631  56.517  1
513937  87.843  -58.637  56.477  1
513938  87.896  -58.645  56.438  1
513939  87.947  -58.651  56.401  1
513940  87.999  -58.658  56.364  1
513951  88.539  -58.759  56.059  1
513952  88.584  -58.771  56.038  1
513953  88.629  -58.783  56.017  1
513954  88.675  -58.795  55.996  1
513955  88.720  -58.807  55.974  1
513956  88.766  -58.819  55.954  1
513957  88.811  -58.831  55.935  1
513958  88.856  -58.842  55.916  1
513959  88.902  -58.855  55.897  1
513960  88.947  -58.867  55.878  1
513961  88.983  -58.878  55.859  1
513962  89.019  -58.889  55.841  1
513963  89.054  -58.900  55.822  1
513964  89.089  -58.911  55.804  1
513965  89.125  -58.923  55.787  1
513966  89.160  -58.933  55.770  1
513967  89.193  -58.949  55.752  1
513968  89.227  -58.965  55.735  1
513969  89.259  -58.981  55.720  1
513970  89.293  -58.997  55.707  1
513971  89.326  -59.013  55.696  1
513972  89.359  -59.029  55.687  1
513973  89.392  -59.045  55.679  1
513974  89.425  -59.061  55.675  1
513975  89.459  -59.062  55.675  1
513976  89.496  -59.072  55.680  1
513977  89.536  -59.089  55.689  1
513978  89.576  -59.105  55.704  1
513979  89.616  -59.121  55.723  1
513980  89.655  -59.137  55.742  1
513981  89.695  -59.153  55.758  1
513982  89.735  -59.169  55.777  1
513983  89.774  -59.185  55.797  1
513984  89.814  -59.202  55.819  1
513985  89.853  -59.218  55.843  1
513986  89.893  -59.234  55.867  1
513987  89.935  -59.249  55.880  1
513988  89.979  -59.263  55.882  1
513989  90.024  -59.277  55.879  1
513990  90.068  -59.291  55.876  1
513991  90.112  -59.306  55.882  1
513992  90.156  -59.320  55.875  1
513993  90.200  -59.334  55.859  1
513994  90.245  -59.349  55.846  1
513995  90.289  -59.363  55.838  1
513996  90.333  -59.378  55.822  1
513997  90.377  -59.392  55.790  1
513998  90.422  -59.406  55.745  1
513999  90.466  -59.420  55.708  1
514000  90.510  -59.435  55.676  1
514001  90.554  -59.449  55.630  1
514002  90.599  -59.463  55.565  1
514003  90.643  -59.478  55.500  1
514004  90.687  -59.492  55.437  1
514005  90.731  -59.507  55.377  1
514006  90.776  -59.520  55.320  1
514007  90.820  -59.533  55.268  1
514008  90.865  -59.546  55.217  1
514009  90.909  -59.558  55.171  1
514010  90.952  -59.573  55.129  1
514011  90.988  -59.591  55.092  1
514012  91.025  -59.610  55.059  1
514013  91.062  -59.626  55.028  1
514014  91.099  -59.642  55.002  1
514015  91.136  -59.657  54.978  1
514016  91.173  -59.673  54.958  1
514017  91.211  -59.689  54.940  1
514018  91.248  -59.704  54.924  1
514019  91.285  -59.720  54.911  1
514020  91.322  -59.735  54.899  1
514021  91.359  -59.751  54.890  1
514022  91.396  -59.766  54.881  1
514023  91.434  -59.782  54.869  1
514024  91.469  -59.795  54.856  1
514025  91.505  -59.804  54.844  1
514026  91.540  -59.814  54.833  1
514027  91.575  -59.823  54.822  1
514028  91.610  -59.832  54.811  1
514029  91.645  -59.842  54.798  1
514030  91.680  -59.851  54.783  1
514031  91.715  -59.861  54.767  1
514032  91.750  -59.870  54.750  1
514033  91.785  -59.880  54.735  1
514034  91.816  -59.889  54.721  1
514035  91.835  -59.901  54.709  1
514036  91.853  -59.913  54.705  1
514037  91.872  -59.924  54.708  1
514038  91.891  -59.936  54.720  1
514039  91.911  -59.947  54.726  1
514040  91.938  -59.952  54.724  1
514041  91.966  -59.958  54.716  1
514042  91.994  -59.963  54.704  1
514043  92.021  -59.969  54.691  1
514044  92.049  -59.974  54.673  1
514045  92.077  -59.980  54.654  1
514046  92.119  -59.980  54.631  1
514047  92.166  -59.980  54.607  1
514048  92.211  -59.984  54.580  1
514049  92.253  -59.994  54.549  1
514050  92.296  -60.004  54.522  1
514051  92.338  -60.013  54.506  1
514052  92.380  -60.023  54.497  1
514053  92.423  -60.033  54.491  1
514054  92.465  -60.043  54.474  1
514055  92.508  -60.052  54.460  1
514056  92.551  -60.061  54.445  1
514057  92.593  -60.071  54.429  1
514058  92.635  -60.081  54.419  1
514059  92.677  -60.090  54.422  1
514060  92.720  -60.100  54.432  1
514061  92.763  -60.110  54.432  1
514062  92.805  -60.119  54.431  1
514063  92.848  -60.129  54.428  1
514064  92.890  -60.139  54.418  1
514065  92.932  -60.149  54.418  1
514066  92.975  -60.158  54.418  1
514067  93.017  -60.168  54.412  1
514068  93.060  -60.177  54.409  1
514069  93.102  -60.187  54.420  1
514070  93.143  -60.199  54.426  1
514071  93.184  -60.214  54.433  1
514072  93.224  -60.229  54.439  1
514073  93.265  -60.244  54.443  1
514074  93.306  -60.259  54.443  1
514075  93.346  -60.275  54.438  1
514076  93.387  -60.290  54.439  1
514077  93.428  -60.305  54.437  1
514078  93.469  -60.319  54.434  1
514079  93.509  -60.334  54.427  1
514080  93.550  -60.350  54.419  1
514081  93.590  -60.365  54.405  1
514082  93.631  -60.380  54.390  1
514083  93.672  -60.395  54.371  1
514084  93.713  -60.409  54.350  1
514085  93.754  -60.425  54.327  1
514086  93.794  -60.440  54.303  1
514087  93.836  -60.453  54.278  1
514088  93.880  -60.465  54.252  1
514089  93.923  -60.476  54.226  1
514090  93.967  -60.488  54.199  1
514091  94.010  -60.500  54.175  1
514092  94.053  -60.511  54.158  1
514093  94.097  -60.522  54.147  1
514094  94.140  -60.535  54.139  1
514095  94.184  -60.546  54.131  1
514096  94.227  -60.557  54.125  1
514097  94.270  -60.569  54.114  1
514098  94.309  -60.573  54.101  1
514099  94.348  -60.578  54.088  1
514100  94.387  -60.582  54.075  1
514101  94.426  -60.587  54.064  1
514102  94.465  -60.592  54.054  1
514103  94.503  -60.597  54.045  1
514104  94.542  -60.601  54.035  1
514105  94.583  -60.607  54.025  1
514106  94.622  -60.612  54.013  1
514107  94.661  -60.617  53.997  1
514108  94.699  -60.622  53.976  1
514109  94.738  -60.627  53.954  1
514110  94.776  -60.632  53.933  1
514111  94.815  -60.637  53.910  1
514112  94.853  -60.642  53.883  1
514113  94.889  -60.649  53.854  1
514114  94.924  -60.656  53.824  1
514115  94.960  -60.663  53.793  1
514116  94.995  -60.669  53.761  1
514117  95.031  -60.677  53.727  1
514118  95.066  -60.684  53.688  1
514119  95.102  -60.691  53.652  1
514120  95.137  -60.698  53.615  1
514121  95.173  -60.704  53.577  1
514122  95.209  -60.713  53.537  1
514123  95.246  -60.720  53.497  1
514124  95.282  -60.726  53.459  1
514125  95.319  -60.733  53.422  1
514126  95.355  -60.740  53.384  1
514127  95.391  -60.747  53.343  1
514128  95.426  -60.752  53.301  1
514129  95.464  -60.757  53.254  1
514130  95.500  -60.763  53.201  1
514131  95.536  -60.770  53.147  1
514132  95.572  -60.776  53.094  1
514133  95.609  -60.782  53.042  1
514134  95.645  -60.788  52.992  1
514135  95.682  -60.795  52.944  1
514136  95.718  -60.801  52.895  1
514137  95.754  -60.808  52.847  1
514138  95.792  -60.806  52.800  1
514139  95.830  -60.801  52.756  1
514140  95.871  -60.803  52.714  1
514141  95.912  -60.808  52.674  1
514142  95.953  -60.814  52.635  1
514143  95.994  -60.818  52.597  1
514144  96.036  -60.823  52.562  1
514145  96.077  -60.829  52.529  1
514146  96.118  -60.833  52.500  1
514147  96.159  -60.839  52.472  1
514148  96.195  -60.842  52.445  1
514149  96.232  -60.845  52.417  1
514150  96.270  -60.846  52.389  1
514151  96.309  -60.847  52.361  1
514152  96.348  -60.848  52.334  1
514153  96.388  -60.849  52.307  1
514154  96.427  -60.850  52.281  1
514155  96.466  -60.851  52.253  1
514156  96.506  -60.852  52.225  1
514157  96.545  -60.854  52.193  1
514158  96.585  -60.854  52.158  1
514159  96.624  -60.855  52.120  1
514160  96.661  -60.857  52.082  1
514161  96.697  -60.858  52.042  1
514162  96.743  -60.854  52.003  1
514163  96.786  -60.860  51.964  1
514164  96.824  -60.874  51.924  1
514165  96.863  -60.888  51.883  1
514166  96.909  -60.895  51.844  1
514167  96.959  -60.899  51.806  1
514168  97.008  -60.904  51.769  1
514169  97.057  -60.909  51.733  1
514170  97.106  -60.914  51.700  1
514171  97.155  -60.918  51.664  1
514172  97.202  -60.914  51.629  1
514173  97.225  -60.925  51.592  1
514174  97.244  -60.941  51.555  1
514175  97.260  -60.950  51.516  1
514176  97.277  -60.960  51.477  1
514177  97.300  -60.969  51.439  1
514178  97.331  -60.960  51.401  1
514179  97.357  -60.949  51.364  1
514180  97.382  -60.939  51.327  1
514181  97.406  -60.927  51.290  1
514182  97.432  -60.917  51.253  1
514183  97.471  -60.915  51.214  1
514184  97.520  -60.920  51.174  1
514185  97.569  -60.924  51.136  1
514186  97.617  -60.930  51.099  1
514187  97.666  -60.934  51.060  1
514188  97.715  -60.939  51.023  1
514189  97.764  -60.943  50.985  1
514190  97.812  -60.948  50.946  1
514191  97.861  -60.952  50.907  1
514192  97.910  -60.958  50.870  1
514193  97.932  -60.964  50.832  1
514194  97.936  -60.972  50.794  1
514195  97.939  -60.980  50.755  1
514196  97.952  -60.992  50.717  1
514197  97.976  -61.008  50.678  1
514198  98.000  -61.024  50.640  1
514199  98.024  -61.039  50.602  1
514200  98.049  -61.055  50.564  1
514201  98.073  -61.070  50.527  1
514202  98.097  -61.079  50.490  1
514203  98.125  -61.069  50.451  1
514204  98.161  -61.074  50.414  1
514205  98.198  -61.077  50.378  1
514206  98.234  -61.082  50.342  1
514621  87.154  -58.587  57.074  1
514622  87.195  -58.594  57.049  1
514623  87.237  -58.592  57.023  1
514624  87.280  -58.591  56.997  1
514625  87.322  -58.589  56.968  1
514626  87.364  -58.587  56.940  1
514627  87.407  -58.585  56.909  1
514628  87.449  -58.584  56.877  1
514629  87.492  -58.582  56.843  1
514630  87.534  -58.581  56.807  1
514631  87.576  -58.579  56.770  1
514632  87.619  -58.578  56.732  1
514633  87.661  -58.576  56.692  1
514634  87.698  -58.578  56.650  1
514635  87.735  -58.579  56.611  1
514636  87.772  -58.581  56.569  1
514637  87.818  -58.586  56.528  1
514638  87.870  -58.593  56.487  1
514639  87.922  -58.600  56.447  1
514640  87.974  -58.607  56.409  1
514641  88.027  -58.614  56.372  1
514642  88.078  -58.621  56.336  1
514643  88.130  -58.628  56.302  1
514652  88.551  -58.726  56.058  1
514653  88.597  -58.738  56.036  1
514654  88.642  -58.750  56.015  1
514655  88.687  -58.761  55.993  1
514656  88.733  -58.773  55.971  1
514657  88.778  -58.786  55.951  1
514658  88.824  -58.798  55.931  1
514659  88.869  -58.809  55.913  1
514660  88.914  -58.821  55.893  1
514661  88.957  -58.833  55.876  1
514662  88.993  -58.844  55.857  1
514663  89.028  -58.855  55.839  1
514664  89.063  -58.867  55.822  1
514665  89.099  -58.878  55.805  1
514666  89.134  -58.889  55.788  1
514667  89.170  -58.900  55.772  1
514668  89.204  -58.914  55.756  1
514669  89.237  -58.930  55.740  1
514670  89.270  -58.946  55.726  1
514671  89.304  -58.961  55.713  1
514672  89.336  -58.977  55.702  1
514673  89.370  -58.993  55.693  1
514674  89.403  -59.009  55.686  1
514675  89.436  -59.018  55.681  1
514676  89.470  -59.018  55.679  1
514677  89.509  -59.031  55.681  1
514678  89.548  -59.047  55.688  1
514679  89.588  -59.063  55.701  1
514680  89.627  -59.080  55.719  1
514681  89.667  -59.096  55.743  1
514682  89.707  -59.112  55.764  1
514683  89.747  -59.128  55.782  1
514684  89.787  -59.144  55.802  1
514685  89.826  -59.160  55.825  1
514686  89.866  -59.176  55.853  1
514687  89.907  -59.195  55.875  1
514688  89.947  -59.209  55.891  1
514689  89.986  -59.214  55.897  1
514690  90.032  -59.229  55.892  1
514691  90.077  -59.245  55.882  1
514692  90.122  -59.260  55.878  1
514693  90.167  -59.275  55.871  1
514694  90.212  -59.291  55.852  1
514695  90.257  -59.306  55.835  1
514696  90.302  -59.322  55.827  1
514697  90.347  -59.337  55.818  1
514698  90.392  -59.353  55.789  1
514699  90.437  -59.367  55.747  1
514700  90.481  -59.381  55.712  1
514701  90.525  -59.396  55.685  1
514702  90.570  -59.410  55.644  1
514703  90.614  -59.424  55.582  1
514704  90.658  -59.438  55.516  1
514705  90.702  -59.453  55.450  1
514706  90.746  -59.467  55.384  1
514707  90.791  -59.482  55.321  1
514708  90.835  -59.496  55.265  1
514709  90.879  -59.510  55.214  1
514710  90.924  -59.522  55.167  1
514711  90.964  -59.538  55.125  1
514712  91.001  -59.556  55.087  1
514713  91.038  -59.572  55.053  1
514714  91.075  -59.587  55.023  1
514715  91.112  -59.602  54.996  1
514716  91.149  -59.618  54.972  1
514717  91.186  -59.633  54.950  1
514718  91.223  -59.649  54.932  1
514719  91.260  -59.664  54.915  1
514720  91.298  -59.680  54.901  1
514721  91.335  -59.695  54.888  1
514722  91.372  -59.711  54.877  1
514723  91.409  -59.726  54.867  1
514724  91.446  -59.742  54.855  1
514725  91.484  -59.757  54.842  1
514726  91.519  -59.768  54.830  1
514727  91.554  -59.777  54.819  1
514728  91.589  -59.787  54.808  1
514729  91.624  -59.796  54.796  1
514730  91.659  -59.806  54.784  1
514731  91.694  -59.815  54.770  1
514732  91.729  -59.824  54.756  1
514733  91.764  -59.834  54.740  1
514734  91.799  -59.843  54.729  1
514735  91.819  -59.855  54.717  1
514736  91.838  -59.867  54.707  1
514737  91.856  -59.878  54.699  1
514738  91.875  -59.890  54.690  1
514739  91.898  -59.898  54.690  1
514740  91.926  -59.904  54.692  1
514741  91.953  -59.910  54.686  1
514742  91.981  -59.915  54.676  1
514743  92.008  -59.920  54.669  1
514744  92.036  -59.926  54.666  1
514745  92.064  -59.931  54.657  1
514746  92.091  -59.937  54.642  1
514747  92.133  -59.938  54.626  1
514748  92.180  -59.937  54.608  1
514749  92.228  -59.937  54.585  1
514750  92.270  -59.946  54.553  1
514751  92.312  -59.956  54.525  1
514752  92.355  -59.966  54.500  1
514753  92.398  -59.976  54.484  1
514754  92.440  -59.985  54.477  1
514755  92.483  -59.995  54.463  1
514756  92.525  -60.005  54.450  1
514757  92.567  -60.014  54.436  1
514758  92.609  -60.024  54.421  1
514759  92.652  -60.033  54.409  1
514760  92.695  -60.043  54.407  1
514761  92.737  -60.052  54.418  1
514762  92.780  -60.062  54.423  1
514763  92.822  -60.072  54.425  1
514764  92.864  -60.082  54.422  1
514765  92.907  -60.091  54.413  1
514766  92.949  -60.101  54.415  1
514767  92.992  -60.111  54.415  1
514768  93.034  -60.120  54.413  1
514769  93.077  -60.130  54.415  1
514770  93.119  -60.140  54.422  1
514771  93.158  -60.150  54.429  1
514772  93.195  -60.171  54.435  1
514773  93.230  -60.192  54.438  1
514774  93.270  -60.209  54.439  1
514775  93.310  -60.224  54.436  1
514776  93.351  -60.239  54.429  1
514777  93.392  -60.254  54.433  1
514778  93.433  -60.269  54.435  1
514779  93.474  -60.284  54.432  1
514780  93.514  -60.299  54.427  1
514781  93.555  -60.314  54.419  1
514782  93.595  -60.329  54.408  1
514783  93.636  -60.344  54.396  1
514784  93.677  -60.359  54.379  1
514785  93.718  -60.375  54.359  1
514786  93.758  -60.390  54.335  1
514787  93.799  -60.404  54.310  1
514788  93.842  -60.417  54.286  1
514789  93.885  -60.428  54.260  1
514790  93.928  -60.441  54.232  1
514791  93.972  -60.452  54.203  1
514792  94.015  -60.463  54.173  1
514793  94.059  -60.475  54.151  1
514794  94.102  -60.487  54.136  1
514795  94.145  -60.498  54.125  1
514796  94.189  -60.510  54.115  1
514797  94.230  -60.519  54.109  1
514798  94.272  -60.527  54.100  1
514799  94.311  -60.532  54.089  1
514800  94.350  -60.537  54.076  1
514801  94.389  -60.541  54.062  1
514802  94.428  -60.546  54.052  1
514803  94.467  -60.550  54.045  1
514804  94.505  -60.555  54.040  1
514805  94.546  -60.560  54.034  1
514806  94.590  -60.566  54.026  1
514807  94.629  -60.572  54.013  1
514808  94.668  -60.578  53.995  1
514809  94.706  -60.583  53.974  1
514810  94.745  -60.588  53.952  1
514811  94.783  -60.593  53.930  1
514812  94.821  -60.598  53.908  1
514813  94.859  -60.604  53.880  1
514814  94.895  -60.610  53.850  1
514815  94.930  -60.617  53.820  1
514816  94.966  -60.624  53.789  1
514817  95.001  -60.632  53.757  1
514818  95.037  -60.638  53.728  1
514819  95.072  -60.645  53.692  1
514820  95.109  -60.651  53.657  1
514821  95.146  -60.657  53.621  1
514822  95.181  -60.666  53.582  1
514823  95.216  -60.675  53.541  1
514824  95.253  -60.682  53.501  1
514825  95.289  -60.690  53.464  1
514826  95.325  -60.697  53.428  1
514827  95.362  -60.704  53.392  1
514828  95.398  -60.712  53.356  1
514829  95.435  -60.718  53.315  1
514830  95.471  -60.725  53.270  1
514831  95.507  -60.731  53.219  1
514832  95.543  -60.738  53.165  1
514833  95.580  -60.744  53.109  1
514834  95.616  -60.751  53.056  1
514835  95.653  -60.757  53.003  1
514836  95.689  -60.763  52.953  1
514837  95.725  -60.770  52.903  1
514838  95.761  -60.776  52.853  1
514839  95.800  -60.772  52.805  1
514840  95.838  -60.766  52.760  1
514841  95.878  -60.767  52.719  1
514842  95.919  -60.771  52.679  1
514843  95.961  -60.776  52.640  1
514844  96.002  -60.782  52.603  1
514845  96.043  -60.787  52.568  1
514846  96.084  -60.792  52.534  1
514847  96.125  -60.797  52.503  1
514848  96.163  -60.801  52.475  1
514849  96.199  -60.804  52.449  1
514850  96.236  -60.807  52.421  1
514851  96.274  -60.808  52.392  1
514852  96.313  -60.809  52.363  1
514853  96.353  -60.810  52.335  1
514854  96.392  -60.811  52.308  1
514855  96.431  -60.812  52.281  1
514856  96.471  -60.814  52.253  1
514857  96.510  -60.814  52.226  1
514858  96.549  -60.816  52.197  1
514859  96.589  -60.817  52.165  1
514860  96.628  -60.817  52.131  1
514861  96.667  -60.819  52.094  1
514862  96.707  -60.820  52.057  1
514863  96.745  -60.821  52.020  1
514864  96.787  -60.823  51.982  1
514865  96.829  -60.834  51.943  1
514866  96.878  -60.839  51.901  1
514867  96.927  -60.844  51.862  1
514868  96.976  -60.848  51.824  1
514869  97.023  -60.856  51.787  1
514870  97.069  -60.863  51.750  1
514871  97.116  -60.870  51.715  1
514872  97.163  -60.877  51.679  1
514873  97.210  -60.885  51.642  1
514874  97.227  -60.888  51.605  1
514875  97.242  -60.892  51.567  1
514876  97.259  -60.901  51.528  1
514877  97.276  -60.911  51.490  1
514878  97.316  -60.919  51.452  1
514879  97.391  -60.926  51.414  1
514880  97.384  -60.902  51.377  1
514881  97.400  -60.894  51.340  1
514882  97.422  -60.889  51.305  1
514883  97.444  -60.884  51.267  1
514884  97.478  -60.882  51.228  1
514885  97.525  -60.886  51.189  1
514886  97.573  -60.890  51.149  1
514887  97.622  -60.895  51.112  1
514888  97.671  -60.900  51.072  1
514889  97.719  -60.904  51.034  1
514890  97.768  -60.909  50.996  1
514891  97.817  -60.914  50.957  1
514892  97.866  -60.918  50.918  1
514893  97.914  -60.923  50.879  1
514894  97.936  -60.930  50.841  1
514895  97.940  -60.938  50.802  1
514896  97.944  -60.946  50.763  1
514897  97.954  -60.957  50.724  1
514898  97.978  -60.972  50.683  1
514899  98.002  -60.988  50.646  1
514900  98.026  -61.004  50.608  1
514901  98.051  -61.019  50.570  1
514902  98.075  -61.035  50.531  1
514903  98.100  -61.036  50.493  1
514904  98.131  -61.032  50.454  1
514905  98.167  -61.036  50.417  1
514906  98.204  -61.040  50.380  1
514907  98.240  -61.045  50.343  1
514908  98.277  -61.049  50.306  1
515321  87.133  -58.507  57.104  1
515322  87.174  -58.518  57.080  1
515323  87.214  -58.529  57.056  1
515324  87.254  -58.540  57.031  1
515325  87.296  -58.542  57.006  1
515326  87.338  -58.540  56.979  1
515327  87.381  -58.538  56.951  1
515328  87.423  -58.537  56.922  1
515329  87.466  -58.535  56.889  1
515330  87.508  -58.534  56.856  1
515331  87.550  -58.532  56.821  1
515332  87.593  -58.531  56.784  1
515333  87.635  -58.529  56.745  1
515334  87.677  -58.528  56.706  1
515335  87.713  -58.530  56.664  1
515336  87.750  -58.532  56.624  1
515337  87.793  -58.535  56.582  1
515338  87.845  -58.542  56.540  1
515339  87.897  -58.549  56.499  1
515340  87.949  -58.556  56.459  1
515341  88.001  -58.563  56.420  1
515342  88.053  -58.570  56.381  1
515343  88.105  -58.577  56.344  1
515344  88.155  -58.585  56.309  1
515345  88.201  -58.598  56.275  1
515353  88.564  -58.692  56.058  1
515354  88.609  -58.705  56.035  1
515355  88.655  -58.717  56.014  1
515356  88.700  -58.728  55.992  1
515357  88.746  -58.740  55.970  1
515358  88.791  -58.752  55.949  1
515359  88.836  -58.764  55.930  1
515360  88.882  -58.776  55.911  1
515361  88.927  -58.788  55.892  1
515362  88.967  -58.799  55.874  1
515363  89.002  -58.811  55.857  1
515364  89.038  -58.822  55.839  1
515365  89.073  -58.833  55.821  1
515366  89.109  -58.844  55.805  1
515367  89.144  -58.855  55.790  1
515368  89.180  -58.867  55.774  1
515369  89.215  -58.878  55.759  1
515370  89.248  -58.894  55.745  1
515371  89.281  -58.910  55.730  1
515372  89.314  -58.926  55.719  1
515373  89.347  -58.942  55.709  1
515374  89.381  -58.958  55.700  1
515375  89.413  -58.973  55.692  1
515376  89.447  -58.974  55.687  1
515377  89.481  -58.974  55.683  1
515378  89.521  -58.990  55.683  1
515379  89.560  -59.006  55.689  1
515380  89.600  -59.022  55.699  1
515381  89.639  -59.038  55.715  1
515382  89.679  -59.055  55.740  1
515383  89.719  -59.071  55.760  1
515384  89.759  -59.087  55.776  1
515385  89.799  -59.103  55.792  1
515386  89.839  -59.121  55.814  1
515387  89.880  -59.139  55.841  1
515388  89.921  -59.158  55.866  1
515389  89.962  -59.175  55.882  1
515390  90.000  -59.178  55.890  1
515391  90.038  -59.181  55.888  1
515392  90.081  -59.193  55.875  1
515393  90.126  -59.208  55.862  1
515394  90.171  -59.223  55.850  1
515395  90.217  -59.238  55.834  1
515396  90.261  -59.254  55.820  1
515397  90.307  -59.269  55.812  1
515398  90.352  -59.284  55.807  1
515399  90.397  -59.300  55.779  1
515400  90.442  -59.316  55.743  1
515401  90.487  -59.331  55.711  1
515402  90.532  -59.347  55.686  1
515403  90.577  -59.362  55.648  1
515404  90.622  -59.377  55.590  1
515405  90.667  -59.392  55.525  1
515406  90.713  -59.408  55.456  1
515407  90.757  -59.423  55.387  1
515408  90.803  -59.438  55.318  1
515409  90.848  -59.454  55.259  1
515410  90.893  -59.469  55.207  1
515411  90.938  -59.485  55.160  1
515412  90.976  -59.501  55.119  1
515413  91.013  -59.516  55.080  1
515414  91.050  -59.532  55.046  1
515415  91.088  -59.547  55.016  1
515416  91.125  -59.563  54.989  1
515417  91.162  -59.579  54.964  1
515418  91.199  -59.594  54.943  1
515419  91.236  -59.610  54.924  1
515420  91.274  -59.625  54.907  1
515421  91.311  -59.641  54.892  1
515422  91.348  -59.656  54.878  1
515423  91.385  -59.671  54.864  1
515424  91.422  -59.687  54.853  1
515425  91.459  -59.702  54.840  1
515426  91.496  -59.718  54.829  1
515427  91.533  -59.732  54.818  1
515428  91.568  -59.742  54.807  1
515429  91.603  -59.751  54.797  1
515430  91.638  -59.761  54.785  1
515431  91.673  -59.770  54.774  1
515432  91.708  -59.779  54.762  1
515433  91.743  -59.789  54.751  1
515434  91.778  -59.798  54.738  1
515435  91.803  -59.809  54.729  1
515436  91.822  -59.820  54.721  1
515437  91.841  -59.833  54.714  1
515438  91.859  -59.844  54.703  1
515439  91.885  -59.851  54.686  1
515440  91.913  -59.856  54.671  1
515441  91.940  -59.861  54.663  1
515442  91.968  -59.867  54.654  1
515443  91.996  -59.873  54.645  1
515444  92.023  -59.878  54.638  1
515445  92.051  -59.883  54.633  1
515446  92.078  -59.889  54.625  1
515447  92.106  -59.894  54.613  1
515448  92.148  -59.895  54.599  1
515449  92.195  -59.895  54.582  1
515450  92.242  -59.894  54.567  1
515451  92.287  -59.899  54.550  1
515452  92.330  -59.908  54.527  1
515453  92.372  -59.918  54.503  1
515454  92.415  -59.928  54.482  1
515455  92.457  -59.938  54.468  1
515456  92.499  -59.947  54.467  1
515457  92.542  -59.957  54.451  1
515458  92.584  -59.967  54.434  1
515459  92.627  -59.976  54.419  1
515460  92.669  -59.986  54.405  1
515461  92.712  -59.996  54.394  1
515462  92.754  -60.005  54.399  1
515463  92.796  -60.014  54.408  1
515464  92.839  -60.024  54.414  1
515465  92.881  -60.034  54.414  1
515466  92.924  -60.044  54.408  1
515467  92.966  -60.053  54.409  1
515468  93.009  -60.063  54.406  1
515469  93.051  -60.073  54.407  1
515470  93.093  -60.082  54.413  1
515471  93.135  -60.092  54.416  1
515472  93.174  -60.102  54.427  1
515473  93.210  -60.123  54.436  1
515474  93.246  -60.143  54.439  1
515475  93.282  -60.165  54.438  1
515476  93.318  -60.185  54.436  1
515477  93.356  -60.203  54.426  1
515478  93.397  -60.218  54.422  1
515479  93.437  -60.234  54.417  1
515480  93.478  -60.249  54.412  1
515481  93.519  -60.264  54.408  1
515482  93.560  -60.279  54.404  1
515483  93.601  -60.293  54.395  1
515484  93.641  -60.309  54.384  1
515485  93.682  -60.324  54.368  1
515486  93.722  -60.339  54.349  1
515487  93.763  -60.354  54.329  1
515488  93.804  -60.369  54.306  1
515489  93.847  -60.381  54.279  1
515490  93.890  -60.393  54.251  1
515491  93.934  -60.404  54.222  1
515492  93.977  -60.416  54.198  1
515493  94.020  -60.428  54.175  1
515494  94.064  -60.439  54.154  1
515495  94.108  -60.450  54.134  1
515496  94.149  -60.460  54.116  1
515497  94.191  -60.469  54.101  1
515498  94.232  -60.477  54.090  1
515499  94.274  -60.485  54.082  1
515500  94.314  -60.491  54.072  1
515501  94.352  -60.496  54.060  1
515502  94.391  -60.500  54.046  1
515503  94.430  -60.505  54.037  1
515504  94.469  -60.510  54.032  1
515505  94.509  -60.514  54.031  1
515506  94.552  -60.520  54.028  1
515507  94.595  -60.525  54.021  1
515508  94.636  -60.532  54.008  1
515509  94.674  -60.538  53.991  1
515510  94.713  -60.544  53.971  1
515511  94.751  -60.549  53.951  1
515512  94.790  -60.554  53.930  1
515513  94.828  -60.559  53.908  1
515514  94.865  -60.565  53.882  1
515515  94.901  -60.572  53.851  1
515516  94.936  -60.579  53.821  1
515517  94.972  -60.586  53.790  1
515518  95.008  -60.593  53.758  1
515519  95.045  -60.599  53.728  1
515520  95.082  -60.604  53.694  1
515521  95.118  -60.610  53.658  1
515522  95.154  -60.619  53.620  1
515523  95.188  -60.629  53.580  1
515524  95.224  -60.638  53.538  1
515525  95.260  -60.645  53.498  1
515526  95.296  -60.653  53.461  1
515527  95.333  -60.660  53.426  1
515528  95.369  -60.667  53.392  1
515529  95.405  -60.676  53.357  1
515530  95.442  -60.684  53.318  1
515531  95.478  -60.693  53.275  1
515532  95.515  -60.700  53.226  1
515533  95.551  -60.706  53.173  1
515534  95.587  -60.713  53.119  1
515535  95.623  -60.719  53.067  1
515536  95.660  -60.725  53.015  1
515537  95.696  -60.732  52.963  1
515538  95.733  -60.738  52.911  1
515539  95.769  -60.743  52.860  1
515540  95.808  -60.737  52.810  1
515541  95.846  -60.732  52.765  1
515542  95.885  -60.729  52.724  1
515543  95.926  -60.735  52.685  1
515544  95.968  -60.740  52.647  1
515545  96.009  -60.745  52.609  1
515546  96.050  -60.750  52.573  1
515547  96.092  -60.755  52.540  1
515548  96.131  -60.760  52.507  1
515549  96.167  -60.763  52.478  1
515550  96.203  -60.766  52.452  1
515551  96.240  -60.769  52.424  1
515552  96.278  -60.770  52.394  1
515553  96.318  -60.771  52.365  1
515554  96.357  -60.773  52.336  1
515555  96.396  -60.773  52.308  1
515556  96.436  -60.774  52.281  1
515557  96.475  -60.776  52.252  1
515558  96.514  -60.776  52.225  1
515559  96.553  -60.777  52.199  1
515560  96.593  -60.779  52.170  1
515561  96.632  -60.779  52.138  1
515562  96.671  -60.781  52.105  1
515563  96.711  -60.782  52.071  1
515564  96.750  -60.782  52.035  1
515565  96.791  -60.787  51.998  1
515566  96.836  -60.795  51.959  1
515567  96.882  -60.802  51.918  1
515568  96.929  -60.809  51.879  1
515569  96.976  -60.817  51.841  1
515570  97.023  -60.824  51.803  1
515571  97.069  -60.831  51.766  1
515572  97.116  -60.839  51.729  1
515573  97.163  -60.845  51.693  1
515574  97.210  -60.853  51.655  1
515575  97.227  -60.856  51.617  1
515576  97.243  -60.859  51.579  1
515577  97.258  -60.861  51.541  1
515578  97.274  -60.864  51.504  1
515579  97.304  -60.868  51.466  1
515580  97.341  -60.871  51.429  1
515581  97.377  -60.875  51.391  1
515582  97.411  -60.863  51.355  1
515583  97.433  -60.858  51.319  1
515584  97.455  -60.854  51.282  1
515585  97.487  -60.851  51.243  1
515586  97.533  -60.854  51.204  1
515587  97.579  -60.857  51.164  1
515588  97.627  -60.861  51.126  1
515589  97.675  -60.865  51.086  1
515590  97.724  -60.870  51.047  1
515591  97.773  -60.875  51.008  1
515592  97.821  -60.879  50.969  1
515593  97.870  -60.884  50.929  1
515594  97.919  -60.889  50.890  1
515595  97.941  -60.895  50.851  1
515596  97.944  -60.904  50.811  1
515597  97.948  -60.912  50.771  1
515598  97.955  -60.921  50.731  1
515599  97.980  -60.937  50.691  1
515600  98.004  -60.952  50.653  1
515601  98.028  -60.968  50.614  1
515602  98.052  -60.984  50.575  1
515603  98.076  -60.999  50.536  1
515604  98.102  -60.992  50.497  1
515605  98.138  -60.994  50.457  1
515606  98.174  -60.998  50.420  1
515607  98.210  -61.003  50.382  1
515608  98.246  -61.008  50.344  1
515609  98.283  -61.011  50.306  1
515610  98.319  -61.016  50.270  1
515611  98.355  -61.020  50.232  1
516021  87.113  -58.427  57.131  1
516022  87.153  -58.438  57.110  1
516023  87.194  -58.449  57.087  1
516024  87.234  -58.460  57.064  1
516025  87.274  -58.471  57.040  1
516026  87.315  -58.482  57.015  1
516027  87.355  -58.491  56.989  1
516028  87.397  -58.490  56.962  1
516029  87.440  -58.488  56.933  1
516030  87.482  -58.487  56.903  1
516031  87.525  -58.485  56.870  1
516032  87.567  -58.484  56.835  1
516033  87.609  -58.482  56.798  1
516034  87.652  -58.480  56.760  1
516035  87.692  -58.480  56.720  1
516036  87.728  -58.482  56.679  1
516037  87.768  -58.485  56.637  1
516038  87.820  -58.491  56.596  1
516039  87.872  -58.498  56.555  1
516040  87.924  -58.505  56.513  1
516041  87.976  -58.512  56.472  1
516042  88.028  -58.519  56.432  1
516043  88.077  -58.528  56.392  1
516044  88.123  -58.540  56.355  1
516045  88.168  -58.552  56.319  1
516046  88.213  -58.563  56.284  1
516047  88.259  -58.576  56.251  1
516052  88.486  -58.636  56.109  1
516053  88.531  -58.647  56.083  1
516054  88.576  -58.659  56.058  1
516055  88.622  -58.671  56.035  1
516056  88.668  -58.683  56.014  1
516057  88.713  -58.695  55.991  1
516058  88.758  -58.707  55.969  1
516059  88.804  -58.719  55.949  1
516060  88.849  -58.730  55.929  1
516061  88.895  -58.742  55.910  1
516062  88.940  -58.755  55.891  1
516063  88.977  -58.766  55.873  1
516064  89.012  -58.777  55.856  1
516065  89.048  -58.788  55.839  1
516066  89.083  -58.799  55.821  1
516067  89.119  -58.811  55.805  1
516068  89.154  -58.822  55.791  1
516069  89.189  -58.833  55.777  1
516070  89.225  -58.844  55.763  1
516071  89.259  -58.858  55.749  1
516072  89.292  -58.874  55.735  1
516073  89.325  -58.889  55.725  1
516074  89.358  -58.905  55.715  1
516075  89.391  -58.921  55.707  1
516076  89.425  -58.931  55.699  1
516077  89.458  -58.931  55.693  1
516078  89.493  -58.933  55.688  1
516079  89.533  -58.949  55.689  1
516080  89.573  -58.965  55.692  1
516081  89.612  -58.981  55.698  1
516082  89.652  -58.997  55.711  1
516083  89.691  -59.013  55.733  1
516084  89.731  -59.030  55.749  1
516085  89.771  -59.046  55.762  1
516086  89.812  -59.065  55.777  1
516087  89.853  -59.084  55.796  1
516088  89.894  -59.102  55.821  1
516089  89.936  -59.121  55.848  1
516090  89.976  -59.139  55.867  1
516091  90.015  -59.145  55.876  1
516092  90.053  -59.148  55.875  1
516093  90.092  -59.150  55.861  1
516094  90.131  -59.156  55.841  1
516095  90.176  -59.171  55.826  1
516096  90.221  -59.186  55.814  1
516097  90.266  -59.202  55.804  1
516098  90.311  -59.217  55.795  1
516099  90.356  -59.232  55.782  1
516100  90.401  -59.248  55.757  1
516101  90.447  -59.263  55.730  1
516102  90.492  -59.278  55.705  1
516103  90.537  -59.294  55.680  1
516104  90.582  -59.309  55.641  1
516105  90.627  -59.325  55.585  1
516106  90.672  -59.340  55.521  1
516107  90.717  -59.356  55.453  1
516108  90.762  -59.371  55.385  1
516109  90.807  -59.386  55.313  1
516110  90.853  -59.402  55.252  1
516111  90.897  -59.418  55.198  1
516112  90.942  -59.443  55.152  1
516113  90.983  -59.462  55.111  1
516114  91.023  -59.477  55.072  1
516115  91.063  -59.492  55.039  1
516116  91.100  -59.508  55.010  1
516117  91.138  -59.523  54.983  1
516118  91.175  -59.539  54.958  1
516119  91.212  -59.554  54.936  1
516120  91.249  -59.570  54.917  1
516121  91.286  -59.585  54.900  1
516122  91.323  -59.601  54.884  1
516123  91.361  -59.616  54.869  1
516124  91.398  -59.632  54.855  1
516125  91.435  -59.648  54.843  1
516126  91.472  -59.663  54.832  1
516127  91.509  -59.679  54.820  1
516128  91.546  -59.694  54.810  1
516129  91.582  -59.705  54.800  1
516130  91.617  -59.715  54.790  1
516131  91.652  -59.724  54.780  1
516132  91.687  -59.734  54.771  1
516133  91.722  -59.743  54.763  1
516134  91.757  -59.753  54.754  1
516135  91.787  -59.763  54.746  1
516136  91.806  -59.774  54.737  1
516137  91.824  -59.786  54.734  1
516138  91.845  -59.797  54.728  1
516139  91.872  -59.802  54.714  1
516140  91.900  -59.808  54.691  1
516141  91.928  -59.814  54.661  1
516142  91.955  -59.819  54.640  1
516143  91.983  -59.824  54.627  1
516144  92.010  -59.830  54.617  1
516145  92.038  -59.835  54.608  1
516146  92.066  -59.841  54.600  1
516147  92.093  -59.846  54.590  1
516148  92.121  -59.851  54.579  1
516149  92.162  -59.852  54.564  1
516150  92.210  -59.851  54.548  1
516151  92.257  -59.851  54.536  1
516152  92.304  -59.851  54.530  1
516153  92.347  -59.861  54.517  1
516154  92.389  -59.870  54.500  1
516155  92.431  -59.880  54.482  1
516156  92.474  -59.890  54.465  1
516157  92.516  -59.900  54.459  1
516158  92.559  -59.909  54.449  1
516159  92.601  -59.919  54.438  1
516160  92.644  -59.929  54.424  1
516161  92.686  -59.939  54.405  1
516162  92.728  -59.948  54.385  1
516163  92.771  -59.958  54.379  1
516164  92.813  -59.967  54.385  1
516165  92.856  -59.977  54.394  1
516166  92.898  -59.986  54.399  1
516167  92.941  -59.996  54.402  1
516168  92.983  -60.006  54.399  1
516169  93.025  -60.015  54.389  1
516170  93.068  -60.025  54.390  1
516171  93.111  -60.035  54.402  1
516172  93.150  -60.043  54.402  1
516173  93.189  -60.054  54.421  1
516174  93.224  -60.074  54.435  1
516175  93.261  -60.096  54.440  1
516176  93.297  -60.116  54.439  1
516177  93.333  -60.137  54.439  1
516178  93.369  -60.158  54.427  1
516179  93.406  -60.178  54.416  1
516180  93.442  -60.198  54.406  1
516181  93.483  -60.213  54.398  1
516182  93.524  -60.228  54.392  1
516183  93.564  -60.243  54.386  1
516184  93.605  -60.259  54.377  1
516185  93.646  -60.273  54.366  1
516186  93.687  -60.288  54.352  1
516187  93.727  -60.303  54.335  1
516188  93.768  -60.318  54.317  1
516189  93.809  -60.334  54.295  1
516190  93.852  -60.345  54.272  1
516191  93.896  -60.356  54.252  1
516192  93.939  -60.369  54.234  1
516193  93.982  -60.380  54.218  1
516194  94.026  -60.391  54.200  1
516195  94.069  -60.402  54.180  1
516196  94.110  -60.410  54.158  1
516197  94.151  -60.419  54.134  1
516198  94.193  -60.428  54.111  1
516199  94.235  -60.436  54.089  1
516200  94.276  -60.444  54.071  1
516201  94.316  -60.450  54.055  1
516202  94.354  -60.454  54.040  1
516203  94.393  -60.459  54.027  1
516204  94.432  -60.463  54.017  1
516205  94.471  -60.468  54.016  1
516206  94.514  -60.474  54.016  1
516207  94.557  -60.479  54.014  1
516208  94.600  -60.485  54.007  1
516209  94.642  -60.491  53.997  1
516210  94.681  -60.497  53.984  1
516211  94.719  -60.503  53.967  1
516212  94.758  -60.509  53.951  1
516213  94.796  -60.515  53.934  1
516214  94.835  -60.520  53.914  1
516215  94.872  -60.526  53.887  1
516216  94.907  -60.533  53.858  1
516217  94.944  -60.540  53.827  1
516218  94.980  -60.546  53.795  1
516219  95.017  -60.552  53.762  1
516220  95.054  -60.557  53.728  1
516221  95.091  -60.563  53.693  1
516222  95.126  -60.572  53.654  1
516223  95.161  -60.581  53.614  1
516224  95.196  -60.591  53.573  1
516225  95.231  -60.600  53.532  1
516226  95.267  -60.608  53.492  1
516227  95.303  -60.615  53.455  1
516228  95.340  -60.622  53.420  1
516229  95.376  -60.630  53.387  1
516230  95.412  -60.639  53.353  1
516231  95.449  -60.647  53.316  1
516232  95.485  -60.657  53.274  1
516233  95.522  -60.665  53.227  1
516234  95.558  -60.674  53.177  1
516235  95.595  -60.681  53.125  1
516236  95.631  -60.687  53.076  1
516237  95.667  -60.694  53.024  1
516238  95.703  -60.700  52.973  1
516239  95.740  -60.707  52.920  1
516240  95.777  -60.708  52.867  1
516241  95.815  -60.703  52.817  1
516242  95.853  -60.698  52.772  1
516243  95.892  -60.693  52.729  1
516244  95.934  -60.698  52.690  1
516245  95.975  -60.703  52.652  1
516246  96.016  -60.708  52.615  1
516247  96.057  -60.713  52.579  1
516248  96.099  -60.719  52.544  1
516249  96.135  -60.722  52.511  1
516250  96.171  -60.724  52.480  1
516251  96.208  -60.727  52.453  1
516252  96.244  -60.730  52.424  1
516253  96.283  -60.732  52.394  1
516254  96.322  -60.733  52.365  1
516255  96.361  -60.735  52.336  1
516256  96.400  -60.735  52.306  1
516257  96.440  -60.736  52.278  1
516258  96.479  -60.738  52.249  1
516259  96.518  -60.738  52.222  1
516260  96.557  -60.739  52.196  1
516261  96.597  -60.741  52.169  1
516262  96.637  -60.742  52.141  1
516263  96.676  -60.743  52.112  1
516264  96.717  -60.741  52.080  1
516265  96.758  -60.741  52.045  1
516266  96.800  -60.751  52.008  1
516267  96.836  -60.763  51.970  1
516268  96.882  -60.770  51.931  1
516269  96.929  -60.777  51.892  1
516270  96.976  -60.785  51.854  1
516271  97.023  -60.792  51.816  1
516272  97.069  -60.799  51.778  1
516273  97.116  -60.807  51.741  1
516274  97.163  -60.814  51.705  1
516275  97.210  -60.821  51.668  1
516276  97.228  -60.824  51.631  1
516277  97.243  -60.827  51.594  1
516278  97.259  -60.830  51.557  1
516279  97.275  -60.832  51.519  1
516280  97.311  -60.834  51.481  1
516281  97.348  -60.838  51.444  1
516282  97.384  -60.841  51.407  1
516283  97.422  -60.832  51.369  1
516284  97.444  -60.828  51.334  1
516285  97.466  -60.823  51.297  1
516286  97.495  -60.820  51.259  1
516287  97.541  -60.823  51.219  1
516288  97.587  -60.826  51.180  1
516289  97.633  -60.828  51.141  1
516290  97.680  -60.831  51.102  1
516291  97.729  -60.836  51.063  1
516292  97.777  -60.840  51.022  1
516293  97.826  -60.845  50.982  1
516294  97.875  -60.850  50.942  1
516295  97.923  -60.854  50.902  1
516296  97.945  -60.861  50.861  1
516297  97.949  -60.870  50.821  1
516298  97.953  -60.877  50.780  1
516299  97.957  -60.886  50.739  1
516300  97.982  -60.901  50.699  1
516301  98.006  -60.917  50.659  1
516302  98.030  -60.933  50.619  1
516303  98.054  -60.948  50.580  1
516304  98.078  -60.961  50.541  1
516305  98.107  -60.952  50.501  1
516306  98.144  -60.957  50.462  1
516307  98.180  -60.961  50.423  1
516308  98.216  -60.966  50.384  1
516309  98.252  -60.970  50.346  1
516310  98.289  -60.974  50.307  1
516311  98.325  -60.979  50.270  1
516312  98.361  -60.983  50.231  1
516722  87.133  -58.358  57.136  1
516723  87.174  -58.369  57.116  1
516724  87.214  -58.380  57.095  1
516725  87.254  -58.391  57.072  1
516726  87.294  -58.402  57.048  1
516727  87.335  -58.413  57.024  1
516728  87.375  -58.424  56.999  1
516729  87.415  -58.435  56.973  1
516730  87.456  -58.440  56.945  1
516731  87.499  -58.438  56.916  1
516732  87.541  -58.437  56.883  1
516733  87.583  -58.435  56.848  1
516734  87.626  -58.433  56.812  1
516735  87.668  -58.432  56.775  1
516736  87.707  -58.432  56.735  1
516737  87.744  -58.434  56.695  1
516738  87.794  -58.441  56.654  1
516739  87.847  -58.448  56.613  1
516740  87.899  -58.454  56.571  1
516741  87.951  -58.461  56.529  1
516742  87.999  -58.471  56.487  1
516743  88.044  -58.483  56.445  1
516744  88.090  -58.495  56.405  1
516745  88.135  -58.507  56.367  1
516746  88.181  -58.519  56.330  1
516747  88.226  -58.530  56.295  1
516748  88.271  -58.542  56.260  1
516749  88.317  -58.554  56.228  1
516750  88.362  -58.567  56.198  1
516751  88.408  -58.578  56.169  1
516752  88.453  -58.590  56.140  1
516753  88.498  -58.602  56.113  1
516754  88.544  -58.614  56.086  1
516755  88.590  -58.626  56.060  1
516756  88.635  -58.638  56.036  1
516757  88.680  -58.649  56.014  1
516758  88.725  -58.661  55.991  1
516759  88.771  -58.673  55.969  1
516760  88.817  -58.686  55.948  1
516761  88.862  -58.697  55.928  1
516762  88.907  -58.709  55.909  1
516763  88.951  -58.721  55.892  1
516764  88.986  -58.732  55.873  1
516765  89.022  -58.743  55.856  1
516766  89.057  -58.755  55.839  1
516767  89.093  -58.766  55.822  1
516768  89.128  -58.777  55.807  1
516769  89.164  -58.788  55.793  1
516770  89.199  -58.799  55.779  1
516771  89.235  -58.811  55.766  1
516772  89.270  -58.822  55.754  1
516773  89.303  -58.838  55.741  1
516774  89.336  -58.854  55.731  1
516775  89.369  -58.870  55.722  1
516776  89.402  -58.886  55.714  1
516777  89.436  -58.888  55.706  1
516778  89.470  -58.887  55.700  1
516779  89.505  -58.892  55.695  1
516780  89.545  -58.908  55.694  1
516781  89.584  -58.924  55.695  1
516782  89.624  -58.940  55.700  1
516783  89.664  -58.956  55.708  1
516784  89.703  -58.972  55.722  1
516785  89.745  -58.991  55.733  1
516786  89.786  -59.009  55.745  1
516787  89.827  -59.028  55.757  1
516788  89.868  -59.046  55.774  1
516789  89.909  -59.065  55.797  1
516790  89.950  -59.084  55.822  1
516791  89.991  -59.102  55.844  1
516792  90.030  -59.112  55.857  1
516793  90.069  -59.115  55.855  1
516794  90.107  -59.117  55.841  1
516795  90.145  -59.120  55.819  1
516796  90.183  -59.123  55.805  1
516797  90.226  -59.134  55.796  1
516798  90.270  -59.150  55.787  1
516799  90.316  -59.165  55.775  1
516800  90.361  -59.180  55.757  1
516801  90.406  -59.195  55.737  1
516802  90.451  -59.211  55.716  1
516803  90.496  -59.226  55.693  1
516804  90.541  -59.241  55.664  1
516805  90.586  -59.257  55.620  1
516806  90.632  -59.272  55.563  1
516807  90.676  -59.287  55.497  1
516808  90.722  -59.303  55.429  1
516809  90.766  -59.319  55.363  1
516810  90.812  -59.334  55.297  1
516811  90.857  -59.352  55.238  1
516812  90.901  -59.377  55.186  1
516813  90.945  -59.401  55.141  1
516814  90.988  -59.423  55.101  1
516815  91.028  -59.438  55.064  1
516816  91.068  -59.453  55.032  1
516817  91.107  -59.469  55.003  1
516818  91.147  -59.484  54.977  1
516819  91.186  -59.500  54.952  1
516820  91.225  -59.515  54.930  1
516821  91.262  -59.530  54.911  1
516822  91.299  -59.546  54.893  1
516823  91.336  -59.561  54.877  1
516824  91.374  -59.577  54.862  1
516825  91.411  -59.592  54.848  1
516826  91.448  -59.608  54.836  1
516827  91.485  -59.623  54.825  1
516828  91.522  -59.638  54.815  1
516829  91.559  -59.654  54.807  1
516830  91.596  -59.670  54.799  1
516831  91.632  -59.679  54.790  1
516832  91.666  -59.689  54.782  1
516833  91.702  -59.698  54.777  1
516834  91.736  -59.707  54.773  1
516835  91.771  -59.717  54.769  1
516836  91.790  -59.729  54.762  1
516837  91.809  -59.740  54.756  1
516838  91.832  -59.749  54.752  1
516839  91.859  -59.754  54.744  1
516840  91.887  -59.760  54.726  1
516841  91.915  -59.765  54.699  1
516842  91.942  -59.770  54.661  1
516843  91.970  -59.776  54.629  1
516844  91.997  -59.782  54.606  1
516845  92.025  -59.787  54.591  1
516846  92.053  -59.792  54.581  1
516847  92.080  -59.798  54.567  1
516848  92.108  -59.804  54.554  1
516849  92.135  -59.809  54.540  1
516850  92.177  -59.810  54.526  1
516851  92.224  -59.809  54.513  1
516852  92.272  -59.808  54.505  1
516853  92.319  -59.808  54.505  1
516854  92.363  -59.814  54.503  1
516855  92.406  -59.823  54.495  1
516856  92.448  -59.833  54.482  1
516857  92.491  -59.842  54.465  1
516858  92.533  -59.852  54.453  1
516859  92.576  -59.862  54.446  1
516860  92.618  -59.871  54.438  1
516861  92.660  -59.881  54.426  1
516862  92.703  -59.891  54.407  1
516863  92.745  -59.901  54.388  1
516864  92.788  -59.910  54.378  1
516865  92.830  -59.920  54.373  1
516866  92.873  -59.930  54.374  1
516867  92.915  -59.939  54.382  1
516868  92.957  -59.949  54.387  1
516869  93.000  -59.958  54.383  1
516870  93.043  -59.968  54.378  1
516871  93.085  -59.977  54.382  1
516872  93.127  -59.987  54.397  1
516873  93.165  -59.996  54.411  1
516874  93.204  -60.005  54.415  1
516875  93.239  -60.027  54.427  1
516876  93.276  -60.047  54.437  1
516877  93.312  -60.068  54.441  1
516878  93.348  -60.089  54.446  1
516879  93.384  -60.109  54.434  1
516880  93.421  -60.130  54.424  1
516881  93.457  -60.151  54.413  1
516882  93.493  -60.171  54.400  1
516883  93.529  -60.192  54.385  1
516884  93.569  -60.208  54.367  1
516885  93.610  -60.223  54.354  1
516886  93.651  -60.238  54.343  1
516887  93.692  -60.253  54.332  1
516888  93.732  -60.268  54.318  1
516889  93.773  -60.283  54.303  1
516890  93.814  -60.297  54.284  1
516891  93.857  -60.309  54.269  1
516892  93.901  -60.321  54.259  1
516893  93.944  -60.332  54.253  1
516894  93.988  -60.343  54.244  1
516895  94.029  -60.353  54.230  1
516896  94.071  -60.361  54.211  1
516897  94.112  -60.369  54.187  1
516898  94.153  -60.378  54.160  1
516899  94.195  -60.386  54.131  1
516900  94.237  -60.394  54.102  1
516901  94.278  -60.403  54.077  1
516902  94.318  -60.409  54.055  1
516903  94.356  -60.413  54.034  1
516904  94.395  -60.418  54.016  1
516905  94.434  -60.422  54.001  1
516906  94.477  -60.428  53.997  1
516907  94.520  -60.434  53.997  1
516908  94.562  -60.439  53.997  1
516909  94.606  -60.445  53.992  1
516910  94.648  -60.450  53.983  1
516911  94.688  -60.456  53.972  1
516912  94.726  -60.463  53.959  1
516913  94.765  -60.469  53.947  1
516914  94.804  -60.475  53.932  1
516915  94.842  -60.481  53.912  1
516916  94.880  -60.487  53.886  1
516917  94.916  -60.493  53.857  1
516918  94.953  -60.499  53.826  1
516919  94.990  -60.505  53.794  1
516920  95.026  -60.510  53.760  1
516921  95.063  -60.516  53.724  1
516922  95.099  -60.524  53.685  1
516923  95.134  -60.534  53.644  1
516924  95.169  -60.544  53.601  1
516925  95.203  -60.553  53.559  1
516926  95.238  -60.563  53.520  1
516927  95.274  -60.570  53.483  1
516928  95.311  -60.578  53.445  1
516929  95.347  -60.585  53.409  1
516930  95.383  -60.594  53.376  1
516931  95.419  -60.602  53.343  1
516932  95.456  -60.611  53.306  1
516933  95.492  -60.619  53.267  1
516934  95.529  -60.629  53.223  1
516935  95.565  -60.637  53.176  1
516936  95.602  -60.646  53.129  1
516937  95.638  -60.654  53.083  1
516938  95.675  -60.662  53.033  1
516939  95.711  -60.668  52.983  1
516940  95.747  -60.675  52.930  1
516941  95.784  -60.674  52.876  1
516942  95.823  -60.669  52.826  1
516943  95.862  -60.663  52.779  1
516944  95.900  -60.657  52.735  1
516945  95.941  -60.661  52.696  1
516946  95.982  -60.666  52.658  1
516947  96.023  -60.672  52.620  1
516948  96.064  -60.676  52.584  1
516949  96.103  -60.680  52.548  1
516950  96.139  -60.683  52.515  1
516951  96.176  -60.686  52.483  1
516952  96.212  -60.689  52.453  1
516953  96.248  -60.692  52.423  1
516954  96.287  -60.695  52.393  1
516955  96.326  -60.695  52.364  1
516956  96.365  -60.697  52.334  1
516957  96.404  -60.698  52.305  1
516958  96.444  -60.698  52.276  1
516959  96.483  -60.700  52.246  1
516960  96.523  -60.701  52.219  1
516961  96.562  -60.701  52.192  1
516962  96.601  -60.703  52.166  1
516963  96.642  -60.701  52.141  1
516964  96.682  -60.698  52.115  1
516965  96.724  -60.696  52.086  1
516966  96.768  -60.704  52.053  1
516967  96.810  -60.715  52.017  1
516968  96.841  -60.729  51.980  1
516969  96.882  -60.738  51.942  1
516970  96.929  -60.745  51.904  1
516971  96.976  -60.753  51.866  1
516972  97.023  -60.760  51.829  1
516973  97.069  -60.767  51.792  1
516974  97.116  -60.775  51.755  1
516975  97.163  -60.782  51.718  1
516976  97.210  -60.789  51.681  1
516977  97.229  -60.792  51.644  1
516978  97.244  -60.795  51.606  1
516979  97.259  -60.798  51.569  1
516980  97.281  -60.801  51.531  1
516981  97.317  -60.801  51.494  1
516982  97.354  -60.804  51.457  1
516983  97.390  -60.807  51.421  1
516984  97.427  -60.810  51.384  1
516985  97.455  -60.798  51.348  1
516986  97.477  -60.793  51.312  1
516987  97.504  -60.789  51.274  1
516988  97.550  -60.792  51.236  1
516989  97.596  -60.795  51.197  1
516990  97.642  -60.797  51.157  1
516991  97.688  -60.799  51.118  1
516992  97.734  -60.802  51.079  1
516993  97.782  -60.806  51.038  1
516994  97.830  -60.810  50.998  1
516995  97.879  -60.816  50.956  1
516996  97.928  -60.820  50.915  1
516997  97.950  -60.827  50.873  1
516998  97.953  -60.835  50.832  1
516999  97.957  -60.843  50.789  1
517000  97.961  -60.851  50.748  1
517001  97.984  -60.867  50.707  1
517002  98.008  -60.882  50.667  1
517003  98.032  -60.898  50.627  1
517004  98.056  -60.914  50.586  1
517005  98.081  -60.917  50.546  1
517006  98.113  -60.915  50.506  1
517007  98.150  -60.920  50.465  1
517008  98.186  -60.924  50.426  1
517009  98.222  -60.928  50.387  1
517010  98.258  -60.933  50.348  1
517011  98.295  -60.937  50.309  1
517012  98.332  -60.941  50.270  1
517013  98.368  -60.945  50.231  1
517014  98.404  -60.950  50.193  1
517423  87.153  -58.289  57.140  1
517424  87.194  -58.300  57.121  1
517425  87.234  -58.311  57.101  1
517426  87.274  -58.322  57.079  1
517427  87.314  -58.333  57.056  1
517428  87.354  -58.344  57.033  1
517429  87.395  -58.355  57.008  1
517430  87.435  -58.366  56.983  1
517431  87.475  -58.376  56.957  1
517432  87.515  -58.388  56.927  1
517433  87.558  -58.388  56.895  1
517434  87.600  -58.386  56.861  1
517435  87.642  -58.385  56.827  1
517436  87.685  -58.383  56.791  1
517437  87.722  -58.385  56.751  1
517438  87.769  -58.389  56.712  1
517439  87.821  -58.397  56.671  1
517440  87.873  -58.404  56.630  1
517441  87.921  -58.413  56.588  1
517442  87.966  -58.426  56.545  1
517443  88.012  -58.438  56.503  1
517444  88.057  -58.449  56.461  1
517445  88.103  -58.461  56.421  1
517446  88.148  -58.473  56.382  1
517447  88.193  -58.485  56.344  1
517448  88.239  -58.497  56.306  1
517449  88.284  -58.509  56.270  1
517450  88.330  -58.521  56.236  1
517451  88.375  -58.532  56.205  1
517452  88.420  -58.545  56.175  1
517453  88.466  -58.557  56.146  1
517454  88.511  -58.569  56.117  1
517455  88.557  -58.580  56.090  1
517456  88.602  -58.592  56.064  1
517457  88.647  -58.604  56.038  1
517458  88.693  -58.616  56.015  1
517459  88.739  -58.628  55.992  1
517460  88.784  -58.640  55.970  1
517461  88.829  -58.652  55.949  1
517462  88.875  -58.664  55.929  1
517463  88.920  -58.676  55.910  1
517464  88.961  -58.687  55.892  1
517465  88.996  -58.698  55.874  1
517466  89.032  -58.710  55.856  1
517467  89.067  -58.721  55.839  1
517468  89.103  -58.732  55.823  1
517469  89.138  -58.743  55.809  1
517470  89.174  -58.755  55.795  1
517471  89.209  -58.766  55.782  1
517472  89.244  -58.777  55.770  1
517473  89.280  -58.788  55.759  1
517474  89.314  -58.802  55.747  1
517475  89.347  -58.818  55.738  1
517476  89.380  -58.834  55.729  1
517477  89.413  -58.845  55.721  1
517478  89.447  -58.844  55.714  1
517479  89.481  -58.844  55.709  1
517480  89.517  -58.850  55.704  1
517481  89.557  -58.866  55.701  1
517482  89.596  -58.883  55.701  1
517483  89.636  -58.899  55.703  1
517484  89.677  -58.917  55.708  1
517485  89.718  -58.935  55.717  1
517486  89.759  -58.954  55.726  1
517487  89.800  -58.972  55.735  1
517488  89.841  -58.991  55.747  1
517489  89.882  -59.009  55.760  1
517490  89.923  -59.027  55.777  1
517491  89.964  -59.046  55.796  1
517492  90.005  -59.065  55.814  1
517493  90.045  -59.078  55.826  1
517494  90.084  -59.081  55.825  1
517495  90.121  -59.084  55.815  1
517496  90.160  -59.087  55.801  1
517497  90.198  -59.090  55.791  1
517498  90.236  -59.093  55.782  1
517499  90.275  -59.096  55.769  1
517500  90.320  -59.112  55.750  1
517501  90.365  -59.128  55.731  1
517502  90.410  -59.143  55.717  1
517503  90.456  -59.159  55.701  1
517504  90.501  -59.174  55.677  1
517505  90.546  -59.189  55.640  1
517506  90.591  -59.204  55.591  1
517507  90.636  -59.220  55.532  1
517508  90.681  -59.235  55.467  1
517509  90.726  -59.250  55.400  1
517510  90.771  -59.266  55.338  1
517511  90.816  -59.285  55.278  1
517512  90.860  -59.310  55.224  1
517513  90.904  -59.335  55.176  1
517514  90.949  -59.359  55.132  1
517515  90.993  -59.384  55.093  1
517516  91.033  -59.399  55.057  1
517517  91.072  -59.415  55.025  1
517518  91.112  -59.430  54.996  1
517519  91.152  -59.445  54.971  1
517520  91.191  -59.460  54.948  1
517521  91.231  -59.475  54.926  1
517522  91.271  -59.491  54.906  1
517523  91.310  -59.507  54.887  1
517524  91.349  -59.522  54.871  1
517525  91.386  -59.538  54.856  1
517526  91.424  -59.553  54.842  1
517527  91.461  -59.568  54.831  1
517528  91.498  -59.584  54.820  1
517529  91.535  -59.599  54.812  1
517530  91.572  -59.615  54.807  1
517531  91.609  -59.630  54.802  1
517532  91.646  -59.643  54.794  1
517533  91.680  -59.652  54.787  1
517534  91.716  -59.662  54.784  1
517535  91.750  -59.671  54.783  1
517536  91.774  -59.682  54.781  1
517537  91.793  -59.694  54.775  1
517538  91.819  -59.701  54.769  1
517539  91.847  -59.706  54.764  1
517540  91.874  -59.712  54.753  1
517541  91.901  -59.717  54.733  1
517542  91.929  -59.723  54.704  1
517543  91.957  -59.728  54.663  1
517544  91.985  -59.733  54.624  1
517545  92.012  -59.739  54.595  1
517546  92.039  -59.745  54.576  1
517547  92.067  -59.750  54.566  1
517548  92.095  -59.755  54.560  1
517549  92.123  -59.761  54.554  1
517550  92.150  -59.766  54.548  1
517551  92.192  -59.767  54.539  1
517552  92.239  -59.767  54.527  1
517553  92.287  -59.766  54.513  1
517554  92.334  -59.765  54.494  1
517555  92.380  -59.766  54.489  1
517556  92.423  -59.776  54.488  1
517557  92.465  -59.786  54.481  1
517558  92.508  -59.795  54.466  1
517559  92.550  -59.804  54.451  1
517560  92.592  -59.814  54.442  1
517561  92.635  -59.824  54.434  1
517562  92.677  -59.834  54.423  1
517563  92.720  -59.843  54.412  1
517564  92.762  -59.853  54.398  1
517565  92.805  -59.863  54.387  1
517566  92.847  -59.872  54.371  1
517567  92.889  -59.882  54.361  1
517568  92.932  -59.892  54.367  1
517569  92.975  -59.902  54.373  1
517570  93.017  -59.911  54.374  1
517571  93.060  -59.920  54.376  1
517572  93.102  -59.930  54.384  1
517573  93.142  -59.939  54.397  1
517574  93.181  -59.948  54.412  1
517575  93.219  -59.958  54.413  1
517576  93.255  -59.978  54.422  1
517577  93.291  -59.999  54.432  1
517578  93.327  -60.020  54.439  1
517579  93.363  -60.040  54.444  1
517580  93.400  -60.061  54.437  1
517581  93.436  -60.082  54.430  1
517582  93.472  -60.102  54.421  1
517583  93.508  -60.123  54.409  1
517584  93.544  -60.144  54.392  1
517585  93.580  -60.165  54.373  1
517586  93.617  -60.185  54.361  1
517587  93.655  -60.202  54.348  1
517588  93.696  -60.218  54.334  1
517589  93.737  -60.233  54.320  1
517590  93.778  -60.247  54.305  1
517591  93.820  -60.262  54.293  1
517592  93.863  -60.273  54.284  1
517593  93.906  -60.284  54.279  1
517594  93.948  -60.294  54.277  1
517595  93.990  -60.303  54.271  1
517596  94.031  -60.311  54.258  1
517597  94.073  -60.319  54.241  1
517598  94.114  -60.328  54.219  1
517599  94.155  -60.336  54.191  1
517600  94.197  -60.344  54.159  1
517601  94.239  -60.353  54.128  1
517602  94.280  -60.362  54.098  1
517603  94.320  -60.367  54.070  1
517604  94.358  -60.372  54.041  1
517605  94.397  -60.376  54.013  1
517606  94.439  -60.381  53.991  1
517607  94.482  -60.387  53.980  1
517608  94.525  -60.393  53.978  1
517609  94.568  -60.399  53.978  1
517610  94.611  -60.404  53.974  1
517611  94.654  -60.410  53.966  1
517612  94.695  -60.416  53.957  1
517613  94.733  -60.422  53.948  1
517614  94.772  -60.428  53.937  1
517615  94.810  -60.434  53.923  1
517616  94.850  -60.440  53.903  1
517617  94.889  -60.446  53.878  1
517618  94.925  -60.452  53.849  1
517619  94.962  -60.458  53.819  1
517620  94.999  -60.463  53.787  1
517621  95.035  -60.469  53.752  1
517622  95.071  -60.477  53.716  1
517623  95.106  -60.486  53.675  1
517624  95.141  -60.496  53.632  1
517625  95.176  -60.506  53.591  1
517626  95.210  -60.516  53.551  1
517627  95.245  -60.525  53.515  1
517628  95.281  -60.533  53.479  1
517629  95.318  -60.541  53.441  1
517630  95.354  -60.548  53.402  1
517631  95.390  -60.557  53.365  1
517632  95.427  -60.566  53.330  1
517633  95.463  -60.575  53.293  1
517634  95.499  -60.583  53.255  1
517635  95.536  -60.592  53.213  1
517636  95.572  -60.600  53.170  1
517637  95.609  -60.610  53.127  1
517638  95.645  -60.618  53.084  1
517639  95.682  -60.627  53.038  1
517640  95.718  -60.635  52.990  1
517641  95.754  -60.643  52.939  1
517642  95.793  -60.640  52.886  1
517643  95.831  -60.634  52.835  1
517644  95.869  -60.629  52.788  1
517645  95.908  -60.622  52.744  1
517646  95.948  -60.625  52.703  1
517647  95.989  -60.630  52.664  1
517648  96.031  -60.635  52.625  1
517649  96.071  -60.639  52.587  1
517650  96.107  -60.642  52.551  1
517651  96.144  -60.645  52.517  1
517652  96.180  -60.648  52.485  1
517653  96.217  -60.651  52.453  1
517654  96.253  -60.654  52.422  1
517655  96.291  -60.657  52.391  1
517656  96.330  -60.657  52.361  1
517657  96.370  -60.659  52.332  1
517658  96.409  -60.660  52.303  1
517659  96.448  -60.660  52.274  1
517660  96.487  -60.662  52.244  1
517661  96.527  -60.663  52.215  1
517662  96.567  -60.662  52.189  1
517663  96.608  -60.660  52.163  1
517664  96.649  -60.657  52.139  1
517665  96.690  -60.654  52.116  1
517666  96.733  -60.659  52.090  1
517667  96.778  -60.668  52.059  1
517668  96.819  -60.679  52.025  1
517669  96.851  -60.692  51.989  1
517670  96.883  -60.706  51.953  1
517671  96.929  -60.713  51.916  1
517672  96.976  -60.721  51.879  1
517673  97.022  -60.729  51.842  1
517674  97.069  -60.735  51.806  1
517675  97.116  -60.743  51.770  1
517676  97.163  -60.750  51.733  1
517677  97.210  -60.757  51.695  1
517678  97.229  -60.760  51.658  1
517679  97.245  -60.763  51.619  1
517680  97.260  -60.767  51.581  1
517681  97.287  -60.768  51.544  1
517682  97.324  -60.769  51.507  1
517683  97.361  -60.770  51.471  1
517684  97.397  -60.773  51.435  1
517685  97.434  -60.777  51.399  1
517686  97.466  -60.767  51.363  1
517687  97.489  -60.762  51.327  1
517688  97.512  -60.758  51.290  1
517689  97.559  -60.760  51.253  1
517690  97.604  -60.763  51.214  1
517691  97.650  -60.766  51.175  1
517692  97.697  -60.768  51.135  1
517693  97.742  -60.771  51.096  1
517694  97.788  -60.773  51.055  1
517695  97.835  -60.776  51.013  1
517696  97.884  -60.781  50.971  1
517697  97.932  -60.785  50.929  1
517698  97.954  -60.792  50.886  1
517699  97.958  -60.801  50.843  1
517700  97.962  -60.809  50.801  1
517701  97.965  -60.817  50.758  1
517702  97.985  -60.831  50.716  1
517703  98.009  -60.847  50.675  1
517704  98.033  -60.863  50.634  1
517705  98.058  -60.878  50.594  1
517706  98.083  -60.873  50.553  1
517707  98.120  -60.878  50.512  1
517708  98.156  -60.882  50.470  1
517709  98.193  -60.886  50.430  1
517710  98.229  -60.891  50.390  1
517711  98.265  -60.895  50.350  1
517712  98.301  -60.899  50.310  1
517713  98.338  -60.904  50.271  1
517714  98.374  -60.908  50.231  1
517715  98.410  -60.912  50.192  1
518124  87.173  -58.220  57.145  1
518125  87.213  -58.231  57.126  1
518126  87.254  -58.242  57.106  1
518127  87.294  -58.253  57.085  1
518128  87.334  -58.264  57.064  1
518129  87.374  -58.275  57.042  1
518130  87.415  -58.286  57.018  1
518131  87.455  -58.297  56.993  1
518132  87.495  -58.307  56.967  1
518133  87.536  -58.319  56.939  1
518134  87.576  -58.329  56.907  1
518135  87.617  -58.338  56.875  1
518136  87.659  -58.336  56.842  1
518137  87.701  -58.335  56.808  1
518138  87.744  -58.338  56.768  1
518139  87.796  -58.345  56.728  1
518140  87.843  -58.357  56.688  1
518141  87.888  -58.368  56.647  1
518142  87.933  -58.380  56.605  1
518143  87.979  -58.392  56.563  1
518144  88.025  -58.404  56.520  1
518145  88.070  -58.416  56.479  1
518146  88.115  -58.428  56.438  1
518147  88.160  -58.440  56.398  1
518148  88.206  -58.451  56.358  1
518149  88.252  -58.463  56.320  1
518150  88.297  -58.476  56.283  1
518151  88.342  -58.488  56.248  1
518152  88.388  -58.499  56.215  1
518153  88.433  -58.511  56.184  1
518154  88.479  -58.523  56.152  1
518155  88.524  -58.535  56.123  1
518156  88.569  -58.547  56.094  1
518157  88.615  -58.559  56.067  1
518158  88.660  -58.571  56.042  1
518159  88.706  -58.582  56.018  1
518160  88.751  -58.595  55.994  1
518161  88.797  -58.607  55.971  1
518162  88.842  -58.618  55.950  1
518163  88.888  -58.629  55.929  1
518164  88.933  -58.641  55.911  1
518165  88.971  -58.654  55.892  1
518166  89.006  -58.665  55.874  1
518167  89.042  -58.676  55.857  1
518168  89.077  -58.687  55.840  1
518169  89.112  -58.698  55.824  1
518170  89.148  -58.710  55.811  1
518171  89.183  -58.720  55.798  1
518172  89.218  -58.732  55.785  1
518173  89.254  -58.743  55.774  1
518174  89.290  -58.755  55.763  1
518175  89.325  -58.766  55.753  1
518176  89.358  -58.782  55.744  1
518177  89.391  -58.798  55.737  1
518178  89.424  -58.801  55.730  1
518179  89.458  -58.801  55.725  1
518180  89.492  -58.800  55.720  1
518181  89.529  -58.809  55.715  1
518182  89.568  -58.825  55.712  1
518183  89.609  -58.842  55.710  1
518184  89.650  -58.861  55.709  1
518185  89.691  -58.880  55.711  1
518186  89.732  -58.898  55.717  1
518187  89.773  -58.917  55.725  1
518188  89.814  -58.935  55.733  1
518189  89.856  -58.954  55.742  1
518190  89.896  -58.972  55.752  1
518191  89.938  -58.990  55.763  1
518192  89.978  -59.009  55.775  1
518193  90.020  -59.027  55.787  1
518194  90.060  -59.045  55.795  1
518195  90.098  -59.048  55.796  1
518196  90.136  -59.051  55.792  1
518197  90.175  -59.053  55.785  1
518198  90.213  -59.056  55.779  1
518199  90.251  -59.059  55.770  1
518200  90.290  -59.062  55.750  1
518201  90.327  -59.065  55.726  1
518202  90.370  -59.075  55.714  1
518203  90.415  -59.090  55.700  1
518204  90.460  -59.106  55.678  1
518205  90.505  -59.121  55.646  1
518206  90.550  -59.137  55.604  1
518207  90.595  -59.152  55.551  1
518208  90.641  -59.168  55.493  1
518209  90.685  -59.183  55.431  1
518210  90.731  -59.198  55.368  1
518211  90.776  -59.219  55.309  1
518212  90.820  -59.244  55.257  1
518213  90.864  -59.269  55.210  1
518214  90.908  -59.294  55.165  1
518215  90.953  -59.318  55.124  1
518216  90.997  -59.343  55.085  1
518217  91.038  -59.360  55.050  1
518218  91.077  -59.375  55.018  1
518219  91.117  -59.391  54.990  1
518220  91.157  -59.406  54.965  1
518221  91.196  -59.422  54.943  1
518222  91.236  -59.437  54.922  1
518223  91.276  -59.452  54.901  1
518224  91.315  -59.468  54.883  1
518225  91.355  -59.483  54.866  1
518226  91.394  -59.498  54.851  1
518227  91.434  -59.513  54.837  1
518228  91.473  -59.529  54.827  1
518229  91.511  -59.544  54.816  1
518230  91.548  -59.560  54.808  1
518231  91.585  -59.576  54.805  1
518232  91.622  -59.591  54.804  1
518233  91.659  -59.607  54.798  1
518234  91.695  -59.616  54.791  1
518235  91.730  -59.626  54.787  1
518236  91.758  -59.636  54.786  1
518237  91.779  -59.647  54.786  1
518238  91.806  -59.653  54.781  1
518239  91.834  -59.658  54.777  1
518240  91.861  -59.663  54.770  1
518241  91.889  -59.669  54.757  1
518242  91.917  -59.674  54.737  1
518243  91.944  -59.680  54.706  1
518244  91.971  -59.685  54.666  1
518245  91.999  -59.691  54.624  1
518246  92.027  -59.696  54.590  1
518247  92.055  -59.701  54.567  1
518248  92.082  -59.707  54.554  1
518249  92.109  -59.713  54.554  1
518250  92.137  -59.718  54.552  1
518251  92.165  -59.723  54.548  1
518252  92.206  -59.725  54.543  1
518253  92.254  -59.724  54.534  1
518254  92.301  -59.723  54.520  1
518255  92.349  -59.722  54.499  1
518256  92.396  -59.721  54.486  1
518257  92.440  -59.728  54.479  1
518258  92.482  -59.738  54.472  1
518259  92.524  -59.748  54.464  1
518260  92.567  -59.757  54.452  1
518261  92.609  -59.767  54.441  1
518262  92.652  -59.776  54.432  1
518263  92.694  -59.786  54.422  1
518264  92.737  -59.796  54.412  1
518265  92.779  -59.805  54.404  1
518266  92.821  -59.815  54.393  1
518267  92.864  -59.825  54.381  1
518268  92.907  -59.834  54.369  1
518269  92.949  -59.844  54.360  1
518270  92.992  -59.854  54.365  1
518271  93.034  -59.864  54.376  1
518272  93.076  -59.873  54.388  1
518273  93.119  -59.883  54.397  1
518274  93.157  -59.891  54.404  1
518275  93.195  -59.899  54.408  1
518276  93.233  -59.909  54.413  1
518277  93.270  -59.930  54.418  1
518278  93.306  -59.951  54.425  1
518279  93.342  -59.971  54.433  1
518280  93.378  -59.992  54.437  1
518281  93.415  -60.013  54.436  1
518282  93.451  -60.033  54.433  1
518283  93.487  -60.054  54.425  1
518284  93.523  -60.075  54.413  1
518285  93.559  -60.096  54.398  1
518286  93.595  -60.116  54.380  1
518287  93.632  -60.137  54.368  1
518288  93.668  -60.158  54.356  1
518289  93.704  -60.178  54.344  1
518290  93.742  -60.197  54.332  1
518291  93.783  -60.212  54.319  1
518292  93.825  -60.225  54.309  1
518293  93.867  -60.236  54.300  1
518294  93.909  -60.244  54.294  1
518295  93.951  -60.253  54.291  1
518296  93.992  -60.261  54.284  1
518297  94.033  -60.269  54.275  1
518298  94.075  -60.278  54.259  1
518299  94.116  -60.287  54.240  1
518300  94.157  -60.295  54.216  1
518301  94.199  -60.303  54.188  1
518302  94.241  -60.312  54.161  1
518303  94.282  -60.320  54.131  1
518304  94.322  -60.326  54.099  1
518305  94.360  -60.331  54.064  1
518306  94.402  -60.336  54.028  1
518307  94.445  -60.341  53.997  1
518308  94.487  -60.347  53.975  1
518309  94.531  -60.353  53.963  1
518310  94.573  -60.358  53.957  1
518311  94.616  -60.364  53.951  1
518312  94.659  -60.369  53.944  1
518313  94.701  -60.375  53.939  1
518314  94.740  -60.381  53.932  1
518315  94.779  -60.387  53.922  1
518316  94.818  -60.393  53.907  1
518317  94.858  -60.399  53.889  1
518318  94.898  -60.405  53.864  1
518319  94.934  -60.411  53.835  1
518320  94.971  -60.416  53.805  1
518321  95.008  -60.422  53.773  1
518322  95.044  -60.429  53.738  1
518323  95.079  -60.439  53.703  1
518324  95.114  -60.449  53.662  1
518325  95.148  -60.459  53.621  1
518326  95.183  -60.469  53.582  1
518327  95.218  -60.478  53.546  1
518328  95.252  -60.488  53.513  1
518329  95.288  -60.496  53.478  1
518330  95.325  -60.503  53.439  1
518331  95.361  -60.512  53.398  1
518332  95.398  -60.520  53.357  1
518333  95.434  -60.529  53.319  1
518334  95.470  -60.538  53.282  1
518335  95.507  -60.547  53.243  1
518336  95.543  -60.555  53.203  1
518337  95.580  -60.564  53.162  1
518338  95.616  -60.572  53.122  1
518339  95.653  -60.582  53.081  1
518340  95.689  -60.590  53.038  1
518341  95.726  -60.597  52.993  1
518342  95.762  -60.604  52.945  1
518343  95.800  -60.605  52.895  1
518344  95.839  -60.600  52.845  1
518345  95.877  -60.594  52.796  1
518346  95.915  -60.588  52.751  1
518347  95.955  -60.588  52.709  1
518348  95.996  -60.593  52.669  1
518349  96.038  -60.598  52.628  1
518350  96.075  -60.601  52.590  1
518351  96.111  -60.604  52.553  1
518352  96.148  -60.607  52.519  1
518353  96.184  -60.610  52.487  1
518354  96.221  -60.613  52.455  1
518355  96.257  -60.616  52.423  1
518356  96.295  -60.619  52.392  1
518357  96.334  -60.619  52.361  1
518358  96.374  -60.621  52.331  1
518359  96.413  -60.622  52.302  1
518360  96.452  -60.622  52.273  1
518361  96.492  -60.623  52.244  1
518362  96.533  -60.620  52.215  1
518363  96.574  -60.617  52.187  1
518364  96.615  -60.615  52.160  1
518365  96.656  -60.612  52.136  1
518366  96.698  -60.613  52.113  1
518367  96.743  -60.623  52.089  1
518368  96.788  -60.632  52.061  1
518369  96.829  -60.643  52.030  1
518370  96.861  -60.657  51.996  1
518371  96.893  -60.670  51.961  1
518372  96.929  -60.682  51.926  1
518373  96.976  -60.689  51.891  1
518374  97.022  -60.697  51.857  1
518375  97.069  -60.704  51.823  1
518376  97.116  -60.711  51.787  1
518377  97.163  -60.718  51.750  1
518378  97.209  -60.726  51.712  1
518379  97.230  -60.729  51.673  1
518380  97.245  -60.732  51.634  1
518381  97.261  -60.735  51.595  1
518382  97.294  -60.735  51.557  1
518383  97.330  -60.736  51.520  1
518384  97.368  -60.737  51.483  1
518385  97.404  -60.739  51.448  1
518386  97.440  -60.743  51.413  1
518387  97.477  -60.737  51.377  1
518388  97.500  -60.732  51.342  1
518389  97.522  -60.727  51.306  1
518390  97.567  -60.729  51.270  1
518391  97.613  -60.732  51.232  1
518392  97.659  -60.735  51.194  1
518393  97.705  -60.737  51.154  1
518394  97.751  -60.740  51.114  1
518395  97.797  -60.742  51.072  1
518396  97.843  -60.745  51.029  1
518397  97.889  -60.748  50.987  1
518398  97.937  -60.751  50.944  1
518399  97.959  -60.758  50.900  1
518400  97.962  -60.767  50.856  1
518401  97.966  -60.775  50.813  1
518402  97.970  -60.783  50.770  1
518403  97.987  -60.796  50.726  1
518404  98.011  -60.811  50.684  1
518405  98.035  -60.827  50.643  1
518406  98.060  -60.842  50.602  1
518407  98.090  -60.836  50.561  1
518408  98.126  -60.841  50.518  1
518409  98.162  -60.845  50.475  1
518410  98.199  -60.849  50.434  1
518411  98.235  -60.854  50.394  1
518412  98.271  -60.857  50.353  1
518413  98.307  -60.862  50.312  1
518414  98.344  -60.867  50.272  1
518415  98.380  -60.870  50.231  1
518416  98.416  -60.875  50.192  1
518417  98.452  -60.879  50.154  1
518825  87.193  -58.151  57.150  1
518826  87.233  -58.162  57.131  1
518827  87.274  -58.173  57.112  1
518828  87.314  -58.184  57.091  1
518829  87.354  -58.195  57.072  1
518830  87.395  -58.206  57.050  1
518831  87.435  -58.217  57.027  1
518832  87.475  -58.228  57.003  1
518833  87.515  -58.238  56.977  1
518834  87.556  -58.250  56.950  1
518835  87.596  -58.260  56.919  1
518836  87.636  -58.271  56.888  1
518837  87.676  -58.282  56.856  1
518838  87.719  -58.288  56.823  1
518839  87.765  -58.299  56.784  1
518840  87.810  -58.311  56.744  1
518841  87.855  -58.323  56.704  1
518842  87.901  -58.335  56.664  1
518843  87.946  -58.346  56.623  1
518844  87.992  -58.358  56.582  1
518845  88.038  -58.369  56.540  1
518846  88.083  -58.381  56.498  1
518847  88.128  -58.392  56.456  1
518848  88.174  -58.404  56.414  1
518849  88.219  -58.416  56.374  1
518850  88.265  -58.427  56.335  1
518851  88.311  -58.438  56.297  1
518852  88.356  -58.450  56.260  1
518853  88.402  -58.462  56.226  1
518854  88.447  -58.473  56.193  1
518855  88.492  -58.485  56.160  1
518856  88.538  -58.496  56.130  1
518857  88.583  -58.508  56.100  1
518858  88.629  -58.520  56.072  1
518859  88.675  -58.531  56.046  1
518860  88.720  -58.542  56.021  1
518861  88.766  -58.554  55.997  1
518862  88.811  -58.566  55.974  1
518863  88.856  -58.577  55.952  1
518864  88.898  -58.588  55.931  1
518865  88.939  -58.601  55.912  1
518866  88.982  -58.623  55.893  1
518867  89.018  -58.633  55.876  1
518868  89.053  -58.644  55.859  1
518869  89.088  -58.654  55.842  1
518870  89.122  -58.665  55.826  1
518871  89.158  -58.676  55.813  1
518872  89.193  -58.687  55.800  1
518873  89.229  -58.698  55.789  1
518874  89.264  -58.710  55.777  1
518875  89.300  -58.720  55.767  1
518876  89.335  -58.732  55.758  1
518877  89.369  -58.746  55.751  1
518878  89.402  -58.758  55.745  1
518879  89.436  -58.758  55.741  1
518880  89.469  -58.757  55.739  1
518881  89.503  -58.757  55.735  1
518882  89.541  -58.768  55.730  1
518883  89.583  -58.787  55.724  1
518884  89.623  -58.805  55.719  1
518885  89.665  -58.824  55.717  1
518886  89.705  -58.842  55.719  1
518887  89.747  -58.861  55.726  1
518888  89.788  -58.880  55.734  1
518889  89.829  -58.898  55.741  1
518890  89.870  -58.917  55.746  1
518891  89.911  -58.935  55.752  1
518892  89.952  -58.953  55.756  1
518893  89.993  -58.972  55.759  1
518894  90.034  -58.990  55.763  1
518895  90.075  -59.008  55.767  1
518896  90.113  -59.015  55.769  1
518897  90.152  -59.018  55.771  1
518898  90.190  -59.020  55.769  1
518899  90.228  -59.023  55.764  1
518900  90.266  -59.026  55.753  1
518901  90.304  -59.029  55.729  1
518902  90.342  -59.031  55.704  1
518903  90.381  -59.034  55.692  1
518904  90.419  -59.038  55.674  1
518905  90.465  -59.053  55.646  1
518906  90.510  -59.069  55.607  1
518907  90.555  -59.084  55.561  1
518908  90.600  -59.099  55.508  1
518909  90.645  -59.115  55.452  1
518910  90.690  -59.131  55.396  1
518911  90.735  -59.153  55.341  1
518912  90.779  -59.178  55.290  1
518913  90.823  -59.203  55.243  1
518914  90.868  -59.227  55.199  1
518915  90.912  -59.252  55.158  1
518916  90.956  -59.276  55.118  1
518917  91.001  -59.301  55.078  1
518918  91.043  -59.322  55.045  1
518919  91.082  -59.337  55.012  1
518920  91.122  -59.352  54.984  1
518921  91.162  -59.367  54.959  1
518922  91.201  -59.383  54.938  1
518923  91.241  -59.398  54.917  1
518924  91.281  -59.413  54.897  1
518925  91.320  -59.428  54.879  1
518926  91.360  -59.444  54.862  1
518927  91.399  -59.460  54.846  1
518928  91.439  -59.475  54.832  1
518929  91.478  -59.490  54.822  1
518930  91.518  -59.505  54.811  1
518931  91.558  -59.520  54.803  1
518932  91.597  -59.536  54.798  1
518933  91.635  -59.551  54.797  1
518934  91.672  -59.566  54.791  1
518935  91.709  -59.581  54.786  1
518936  91.743  -59.590  54.783  1
518937  91.766  -59.599  54.783  1
518938  91.793  -59.604  54.784  1
518939  91.821  -59.610  54.787  1
518940  91.849  -59.616  54.786  1
518941  91.876  -59.621  54.780  1
518942  91.904  -59.626  54.766  1
518943  91.931  -59.632  54.744  1
518944  91.959  -59.637  54.713  1
518945  91.987  -59.643  54.672  1
518946  92.014  -59.648  54.629  1
518947  92.041  -59.654  54.592  1
518948  92.069  -59.659  54.564  1
518949  92.097  -59.664  54.547  1
518950  92.125  -59.670  54.548  1
518951  92.152  -59.676  54.546  1
518952  92.179  -59.681  54.543  1
518953  92.221  -59.682  54.540  1
518954  92.269  -59.681  54.537  1
518955  92.316  -59.680  54.528  1
518956  92.363  -59.679  54.511  1
518957  92.411  -59.679  54.493  1
518958  92.456  -59.681  54.477  1
518959  92.499  -59.691  54.466  1
518960  92.542  -59.700  54.462  1
518961  92.584  -59.710  54.454  1
518962  92.626  -59.720  54.444  1
518963  92.669  -59.729  54.432  1
518964  92.711  -59.739  54.421  1
518965  92.754  -59.748  54.409  1
518966  92.796  -59.758  54.399  1
518967  92.839  -59.767  54.389  1
518968  92.881  -59.777  54.379  1
518969  92.924  -59.787  54.369  1
518970  92.966  -59.797  54.359  1
518971  93.008  -59.806  54.364  1
518972  93.051  -59.816  54.378  1
518973  93.093  -59.826  54.392  1
518974  93.134  -59.835  54.402  1
518975  93.172  -59.843  54.408  1
518976  93.210  -59.851  54.406  1
518977  93.249  -59.861  54.405  1
518978  93.285  -59.882  54.406  1
518979  93.321  -59.902  54.410  1
518980  93.357  -59.923  54.416  1
518981  93.394  -59.944  54.424  1
518982  93.430  -59.964  54.429  1
518983  93.466  -59.985  54.428  1
518984  93.502  -60.006  54.421  1
518985  93.538  -60.027  54.409  1
518986  93.574  -60.047  54.397  1
518987  93.611  -60.068  54.385  1
518988  93.647  -60.089  54.375  1
518989  93.683  -60.109  54.366  1
518990  93.719  -60.130  54.357  1
518991  93.755  -60.151  54.347  1
518992  93.791  -60.171  54.335  1
518993  93.829  -60.186  54.325  1
518994  93.869  -60.194  54.314  1
518995  93.911  -60.202  54.303  1
518996  93.953  -60.212  54.297  1
518997  93.994  -60.220  54.291  1
518998  94.035  -60.228  54.283  1
518999  94.077  -60.237  54.270  1
519000  94.118  -60.245  54.253  1
519001  94.159  -60.253  54.233  1
519002  94.201  -60.262  54.212  1
519003  94.243  -60.270  54.190  1
519004  94.284  -60.278  54.162  1
519005  94.324  -60.284  54.129  1
519006  94.364  -60.290  54.092  1
519007  94.407  -60.295  54.052  1
519008  94.450  -60.301  54.013  1
519009  94.493  -60.306  53.980  1
519010  94.536  -60.312  53.956  1
519011  94.579  -60.318  53.942  1
519012  94.622  -60.324  53.936  1
519013  94.665  -60.329  53.930  1
519014  94.707  -60.335  53.923  1
519015  94.747  -60.340  53.913  1
519016  94.787  -60.347  53.900  1
519017  94.826  -60.353  53.884  1
519018  94.866  -60.358  53.864  1
519019  94.905  -60.364  53.840  1
519020  94.944  -60.370  53.812  1
519021  94.980  -60.375  53.782  1
519022  95.017  -60.382  53.750  1
519023  95.051  -60.392  53.716  1
519024  95.086  -60.401  53.682  1
519025  95.121  -60.411  53.646  1
519026  95.156  -60.421  53.611  1
519027  95.190  -60.431  53.578  1
519028  95.225  -60.441  53.546  1
519029  95.260  -60.450  53.514  1
519030  95.296  -60.459  53.478  1
519031  95.332  -60.466  53.438  1
519032  95.368  -60.475  53.396  1
519033  95.405  -60.484  53.353  1
519034  95.441  -60.493  53.313  1
519035  95.477  -60.501  53.274  1
519036  95.514  -60.510  53.233  1
519037  95.551  -60.518  53.193  1
519038  95.587  -60.526  53.153  1
519039  95.624  -60.534  53.114  1
519040  95.661  -60.542  53.074  1
519041  95.697  -60.550  53.034  1
519042  95.734  -60.557  52.993  1
519043  95.769  -60.563  52.948  1
519044  95.807  -60.564  52.901  1
519045  95.846  -60.563  52.853  1
519046  95.885  -60.560  52.803  1
519047  95.923  -60.553  52.757  1
519048  95.962  -60.551  52.715  1
519049  96.004  -60.557  52.674  1
519050  96.043  -60.560  52.633  1
519051  96.079  -60.563  52.594  1
519052  96.115  -60.566  52.557  1
519053  96.152  -60.569  52.523  1
519054  96.188  -60.572  52.490  1
519055  96.225  -60.575  52.458  1
519056  96.261  -60.579  52.425  1
519057  96.299  -60.581  52.394  1
519058  96.338  -60.582  52.363  1
519059  96.378  -60.583  52.333  1
519060  96.417  -60.584  52.303  1
519061  96.458  -60.581  52.274  1
519062  96.499  -60.579  52.244  1
519063  96.540  -60.575  52.215  1
519064  96.581  -60.572  52.186  1
519065  96.622  -60.569  52.158  1
519066  96.664  -60.569  52.133  1
519067  96.709  -60.578  52.110  1
519068  96.753  -60.587  52.085  1
519069  96.798  -60.596  52.059  1
519070  96.838  -60.607  52.030  1
519071  96.870  -60.620  51.999  1
519072  96.902  -60.634  51.966  1
519073  96.934  -60.647  51.934  1
519074  96.976  -60.657  51.902  1
519075  97.022  -60.665  51.870  1
519076  97.069  -60.672  51.838  1
519077  97.116  -60.679  51.804  1
519078  97.163  -60.686  51.768  1
519079  97.209  -60.694  51.729  1
519080  97.231  -60.698  51.689  1
519081  97.246  -60.700  51.649  1
519082  97.263  -60.703  51.609  1
519083  97.300  -60.704  51.570  1
519084  97.337  -60.704  51.533  1
519085  97.374  -60.705  51.497  1
519086  97.411  -60.706  51.461  1
519087  97.447  -60.709  51.426  1
519088  97.484  -60.713  51.391  1
519089  97.511  -60.701  51.355  1
519090  97.533  -60.697  51.319  1
519091  97.576  -60.698  51.283  1
519092  97.621  -60.701  51.246  1
519093  97.667  -60.704  51.207  1
519094  97.714  -60.706  51.168  1
519095  97.759  -60.708  51.128  1
519096  97.805  -60.711  51.087  1
519097  97.851  -60.713  51.045  1
519098  97.897  -60.716  51.002  1
519099  97.943  -60.719  50.959  1
519100  97.963  -60.724  50.915  1
519101  97.967  -60.732  50.870  1
519102  97.970  -60.741  50.826  1
519103  97.974  -60.748  50.782  1
519104  97.989  -60.760  50.738  1
519105  98.013  -60.776  50.696  1
519106  98.037  -60.792  50.654  1
519107  98.062  -60.798  50.611  1
519108  98.096  -60.798  50.569  1
519109  98.132  -60.803  50.526  1
519110  98.168  -60.807  50.482  1
519111  98.205  -60.812  50.440  1
519112  98.241  -60.816  50.399  1
519113  98.277  -60.820  50.358  1
519114  98.313  -60.825  50.316  1
519115  98.350  -60.829  50.276  1
519116  98.386  -60.833  50.234  1
519117  98.423  -60.838  50.194  1
519118  98.459  -60.842  50.155  1
519526  87.213  -58.082  57.155  1
519527  87.254  -58.095  57.136  1
519528  87.294  -58.109  57.117  1
519529  87.335  -58.122  57.096  1
519530  87.375  -58.137  57.077  1
519531  87.416  -58.150  57.056  1
519532  87.457  -58.164  57.034  1
519533  87.497  -58.178  57.010  1
519534  87.538  -58.191  56.986  1
519535  87.579  -58.206  56.959  1
519536  87.619  -58.219  56.931  1
519537  87.660  -58.233  56.900  1
519538  87.700  -58.247  56.868  1
519539  87.743  -58.254  56.836  1
519540  87.779  -58.259  56.799  1
519541  87.825  -58.270  56.760  1
519542  87.870  -58.282  56.721  1
519543  87.916  -58.294  56.681  1
519544  87.961  -58.305  56.641  1
519545  88.006  -58.316  56.600  1
519546  88.052  -58.328  56.558  1
519547  88.098  -58.340  56.516  1
519548  88.143  -58.351  56.474  1
519549  88.189  -58.363  56.433  1
519550  88.234  -58.375  56.393  1
519551  88.280  -58.386  56.352  1
519552  88.325  -58.397  56.313  1
519553  88.370  -58.409  56.275  1
519554  88.416  -58.421  56.239  1
519555  88.462  -58.432  56.204  1
519556  88.507  -58.444  56.170  1
519557  88.553  -58.455  56.138  1
519558  88.598  -58.466  56.107  1
519559  88.644  -58.479  56.077  1
519560  88.689  -58.490  56.051  1
519561  88.735  -58.501  56.025  1
519562  88.780  -58.513  56.001  1
519563  88.823  -58.524  55.977  1
519564  88.863  -58.535  55.954  1
519565  88.903  -58.545  55.932  1
519566  88.946  -58.563  55.914  1
519567  88.989  -58.585  55.895  1
519568  89.030  -58.603  55.877  1
519569  89.065  -58.614  55.860  1
519570  89.100  -58.624  55.844  1
519571  89.134  -58.635  55.827  1
519572  89.170  -58.645  55.814  1
519573  89.204  -58.655  55.802  1
519574  89.239  -58.666  55.791  1
519575  89.274  -58.676  55.780  1
519576  89.309  -58.687  55.772  1
519577  89.344  -58.698  55.763  1
519578  89.380  -58.711  55.758  1
519579  89.413  -58.714  55.755  1
519580  89.448  -58.715  55.752  1
519581  89.484  -58.719  55.753  1
519582  89.521  -58.723  55.749  1
519583  89.558  -58.733  55.742  1
519584  89.597  -58.750  55.734  1
519585  89.638  -58.768  55.727  1
519586  89.679  -58.787  55.726  1
519587  89.720  -58.805  55.730  1
519588  89.761  -58.824  55.739  1
519589  89.802  -58.842  55.748  1
519590  89.843  -58.861  55.755  1
519591  89.884  -58.879  55.758  1
519592  89.925  -58.898  55.762  1
519593  89.966  -58.916  55.761  1
519594  90.007  -58.935  55.758  1
519595  90.048  -58.953  55.755  1
519596  90.089  -58.971  55.752  1
519597  90.128  -58.981  55.751  1
519598  90.167  -58.984  55.753  1
519599  90.205  -58.987  55.749  1
519600  90.243  -58.990  55.742  1
519601  90.282  -58.993  55.728  1
519602  90.319  -58.996  55.703  1
519603  90.358  -58.998  55.682  1
519604  90.396  -59.001  55.667  1
519605  90.434  -59.004  55.643  1
519606  90.472  -59.007  55.608  1
519607  90.514  -59.017  55.566  1
519608  90.559  -59.032  55.517  1
519609  90.604  -59.047  55.467  1
519610  90.650  -59.062  55.416  1
519611  90.694  -59.087  55.367  1
519612  90.738  -59.111  55.320  1
519613  90.783  -59.136  55.276  1
519614  90.827  -59.161  55.234  1
519615  90.871  -59.185  55.196  1
519616  90.916  -59.210  55.158  1
519617  90.960  -59.234  55.119  1
519618  91.004  -59.259  55.079  1
519619  91.048  -59.282  55.043  1
519620  91.087  -59.298  55.010  1
519621  91.127  -59.313  54.980  1
519622  91.167  -59.328  54.954  1
519623  91.206  -59.344  54.931  1
519624  91.246  -59.359  54.910  1
519625  91.286  -59.375  54.893  1
519626  91.325  -59.390  54.875  1
519627  91.365  -59.405  54.858  1
519628  91.404  -59.420  54.841  1
519629  91.444  -59.435  54.828  1
519630  91.484  -59.451  54.816  1
519631  91.523  -59.466  54.806  1
519632  91.563  -59.482  54.796  1
519633  91.602  -59.497  54.789  1
519634  91.642  -59.512  54.784  1
519635  91.681  -59.528  54.780  1
519636  91.721  -59.543  54.776  1
519637  91.753  -59.551  54.774  1
519638  91.780  -59.557  54.774  1
519639  91.808  -59.562  54.779  1
519640  91.836  -59.567  54.787  1
519641  91.863  -59.573  54.790  1
519642  91.891  -59.578  54.785  1
519643  91.918  -59.584  54.773  1
519644  91.946  -59.589  54.751  1
519645  91.974  -59.595  54.718  1
519646  92.001  -59.600  54.680  1
519647  92.029  -59.605  54.641  1
519648  92.056  -59.611  54.606  1
519649  92.084  -59.616  54.576  1
519650  92.111  -59.622  54.552  1
519651  92.139  -59.627  54.547  1
519652  92.167  -59.632  54.550  1
519653  92.194  -59.638  54.550  1
519654  92.236  -59.639  54.544  1
519655  92.283  -59.638  54.539  1
519656  92.331  -59.638  54.537  1
519657  92.378  -59.637  54.528  1
519658  92.425  -59.636  54.514  1
519659  92.473  -59.635  54.496  1
519660  92.516  -59.643  54.474  1
519661  92.558  -59.653  54.461  1
519662  92.601  -59.662  54.457  1
519663  92.643  -59.672  54.449  1
519664  92.686  -59.682  54.435  1
519665  92.728  -59.692  54.420  1
519666  92.771  -59.701  54.404  1
519667  92.813  -59.710  54.391  1
519668  92.856  -59.720  54.381  1
519669  92.898  -59.729  54.373  1
519670  92.940  -59.739  54.365  1
519671  92.983  -59.749  54.358  1
519672  93.025  -59.759  54.363  1
519673  93.068  -59.768  54.379  1
519674  93.110  -59.778  54.396  1
519675  93.148  -59.786  54.408  1
519676  93.187  -59.795  54.411  1
519677  93.225  -59.804  54.411  1
519678  93.264  -59.813  54.411  1
519679  93.300  -59.833  54.412  1
519680  93.336  -59.854  54.412  1
519681  93.372  -59.875  54.411  1
519682  93.409  -59.895  54.410  1
519683  93.445  -59.916  54.413  1
519684  93.481  -59.937  54.413  1
519685  93.517  -59.958  54.407  1
519686  93.553  -59.978  54.396  1
519687  93.589  -59.999  54.384  1
519688  93.626  -60.020  54.375  1
519689  93.662  -60.040  54.363  1
519690  93.698  -60.061  54.354  1
519691  93.734  -60.082  54.347  1
519692  93.770  -60.102  54.343  1
519693  93.806  -60.120  54.337  1
519694  93.843  -60.135  54.327  1
519695  93.880  -60.149  54.314  1
519696  93.921  -60.159  54.303  1
519697  93.961  -60.167  54.293  1
519698  94.001  -60.176  54.288  1
519699  94.041  -60.185  54.280  1
519700  94.081  -60.194  54.269  1
519701  94.122  -60.203  54.257  1
519702  94.161  -60.212  54.243  1
519703  94.203  -60.220  54.230  1
519704  94.245  -60.229  54.215  1
519705  94.286  -60.237  54.190  1
519706  94.327  -60.243  54.158  1
519707  94.369  -60.249  54.121  1
519708  94.412  -60.255  54.079  1
519709  94.455  -60.261  54.033  1
519710  94.498  -60.266  53.991  1
519711  94.541  -60.272  53.956  1
519712  94.584  -60.278  53.933  1
519713  94.628  -60.284  53.922  1
519714  94.671  -60.289  53.915  1
519715  94.714  -60.295  53.905  1
519716  94.755  -60.300  53.892  1
519717  94.794  -60.306  53.876  1
519718  94.834  -60.312  53.859  1
519719  94.874  -60.317  53.839  1
519720  94.913  -60.323  53.816  1
519721  94.953  -60.328  53.790  1
519722  94.989  -60.334  53.761  1
519723  95.024  -60.344  53.731  1
519724  95.059  -60.354  53.700  1
519725  95.094  -60.364  53.669  1
519726  95.128  -60.374  53.636  1
519727  95.163  -60.384  53.605  1
519728  95.198  -60.393  53.575  1
519729  95.233  -60.403  53.545  1
519730  95.267  -60.412  53.513  1
519731  95.303  -60.422  53.476  1
519732  95.339  -60.430  53.435  1
519733  95.376  -60.438  53.393  1
519734  95.412  -60.447  53.351  1
519735  95.449  -60.454  53.310  1
519736  95.485  -60.463  53.271  1
519737  95.522  -60.471  53.231  1
519738  95.559  -60.478  53.190  1
519739  95.596  -60.487  53.149  1
519740  95.632  -60.494  53.108  1
519741  95.669  -60.503  53.067  1
519742  95.705  -60.510  53.027  1
519743  95.741  -60.516  52.988  1
519744  95.777  -60.520  52.947  1
519745  95.815  -60.523  52.903  1
519746  95.853  -60.522  52.854  1
519747  95.892  -60.522  52.806  1
519748  95.931  -60.519  52.762  1
519749  95.970  -60.515  52.722  1
519750  96.011  -60.519  52.682  1
519751  96.047  -60.522  52.640  1
519752  96.083  -60.525  52.600  1
519753  96.120  -60.528  52.563  1
519754  96.156  -60.532  52.528  1
519755  96.192  -60.535  52.495  1
519756  96.229  -60.538  52.463  1
519757  96.265  -60.541  52.429  1
519758  96.303  -60.543  52.398  1
519759  96.342  -60.544  52.367  1
519760  96.383  -60.542  52.337  1
519761  96.425  -60.539  52.307  1
519762  96.465  -60.536  52.277  1
519763  96.507  -60.533  52.246  1
519764  96.547  -60.531  52.216  1
519765  96.589  -60.528  52.187  1
519766  96.629  -60.525  52.158  1
519767  96.674  -60.532  52.130  1
519768  96.719  -60.541  52.105  1
519769  96.763  -60.550  52.079  1
519770  96.808  -60.560  52.053  1
519771  96.848  -60.570  52.026  1
519772  96.880  -60.584  51.998  1
519773  96.912  -60.598  51.969  1
519774  96.944  -60.612  51.939  1
519775  96.976  -60.626  51.910  1
519776  97.022  -60.633  51.881  1
519777  97.069  -60.640  51.850  1
519778  97.116  -60.647  51.817  1
519779  97.163  -60.654  51.780  1
519780  97.209  -60.662  51.743  1
519781  97.231  -60.666  51.703  1
519782  97.246  -60.668  51.662  1
519783  97.270  -60.670  51.621  1
519784  97.307  -60.671  51.581  1
519785  97.344  -60.672  51.543  1
519786  97.380  -60.673  51.506  1
519787  97.418  -60.673  51.471  1
519788  97.454  -60.675  51.436  1
519789  97.491  -60.679  51.401  1
519790  97.522  -60.671  51.365  1
519791  97.544  -60.666  51.330  1
519792  97.584  -60.667  51.294  1
519793  97.630  -60.669  51.257  1
519794  97.676  -60.673  51.219  1
519795  97.722  -60.675  51.180  1
519796  97.768  -60.677  51.140  1
519797  97.814  -60.680  51.099  1
519798  97.860  -60.682  51.058  1
519799  97.906  -60.685  51.015  1
519800  97.938  -60.688  50.973  1
519801  97.963  -60.691  50.928  1
519802  97.971  -60.698  50.883  1
519803  97.975  -60.706  50.839  1
519804  97.979  -60.714  50.794  1
519805  97.991  -60.726  50.750  1
519806  98.015  -60.741  50.707  1
519807  98.039  -60.757  50.664  1
519808  98.066  -60.757  50.622  1
519809  98.102  -60.761  50.578  1
519810  98.138  -60.766  50.535  1
519811  98.174  -60.770  50.490  1
519812  98.211  -60.774  50.447  1
519813  98.247  -60.779  50.405  1
519814  98.284  -60.783  50.362  1
519815  98.320  -60.787  50.320  1
519816  98.356  -60.792  50.278  1
519817  98.392  -60.796  50.236  1
519818  98.429  -60.801  50.195  1
519819  98.465  -60.804  50.156  1
520227  87.238  -58.056  57.159  1
520228  87.279  -58.069  57.140  1
520229  87.320  -58.083  57.121  1
520230  87.360  -58.096  57.101  1
520231  87.401  -58.111  57.081  1
520232  87.441  -58.125  57.060  1
520233  87.482  -58.138  57.039  1
520234  87.523  -58.152  57.017  1
520235  87.563  -58.165  56.993  1
520236  87.604  -58.180  56.967  1
520237  87.645  -58.194  56.939  1
520238  87.685  -58.207  56.910  1
520239  87.726  -58.221  56.879  1
520240  87.768  -58.225  56.848  1
520241  87.811  -58.227  56.812  1
520242  87.846  -58.232  56.775  1
520243  87.885  -58.241  56.737  1
520244  87.930  -58.253  56.698  1
520245  87.976  -58.264  56.659  1
520246  88.022  -58.275  56.618  1
520247  88.067  -58.288  56.576  1
520248  88.112  -58.299  56.535  1
520249  88.158  -58.310  56.493  1
520250  88.203  -58.322  56.451  1
520251  88.249  -58.334  56.410  1
520252  88.294  -58.345  56.369  1
520253  88.340  -58.357  56.329  1
520254  88.385  -58.368  56.290  1
520255  88.431  -58.379  56.253  1
520256  88.476  -58.391  56.216  1
520257  88.522  -58.403  56.182  1
520258  88.567  -58.414  56.149  1
520259  88.613  -58.426  56.116  1
520260  88.659  -58.438  56.085  1
520261  88.704  -58.449  56.057  1
520262  88.747  -58.460  56.031  1
520263  88.787  -58.470  56.005  1
520264  88.828  -58.481  55.980  1
520265  88.868  -58.491  55.958  1
520266  88.909  -58.505  55.935  1
520267  88.952  -58.526  55.916  1
520268  88.995  -58.547  55.897  1
520269  89.038  -58.568  55.879  1
520270  89.077  -58.583  55.862  1
520271  89.112  -58.594  55.846  1
520272  89.146  -58.604  55.829  1
520273  89.182  -58.614  55.816  1
520274  89.216  -58.625  55.805  1
520275  89.251  -58.636  55.794  1
520276  89.286  -58.646  55.784  1
520277  89.321  -58.657  55.776  1
520278  89.356  -58.667  55.769  1
520279  89.391  -58.677  55.764  1
520280  89.433  -58.682  55.761  1
520281  89.469  -58.686  55.757  1
520282  89.506  -58.689  55.756  1
520283  89.542  -58.693  55.752  1
520284  89.579  -58.699  55.745  1
520285  89.618  -58.717  55.739  1
520286  89.657  -58.733  55.735  1
520287  89.695  -58.751  55.736  1
520288  89.734  -58.768  55.744  1
520289  89.775  -58.786  55.755  1
520290  89.816  -58.805  55.764  1
520291  89.858  -58.824  55.770  1
520292  89.898  -58.842  55.772  1
520293  89.939  -58.861  55.772  1
520294  89.980  -58.879  55.766  1
520295  90.021  -58.898  55.759  1
520296  90.062  -58.916  55.750  1
520297  90.103  -58.934  55.743  1
520298  90.144  -58.948  55.735  1
520299  90.182  -58.951  55.731  1
520300  90.220  -58.954  55.723  1
520301  90.258  -58.956  55.711  1
520302  90.296  -58.959  55.695  1
520303  90.334  -58.962  55.671  1
520304  90.373  -58.965  55.651  1
520305  90.411  -58.968  55.631  1
520306  90.449  -58.971  55.604  1
520307  90.487  -58.974  55.566  1
520308  90.525  -58.976  55.523  1
520309  90.564  -58.980  55.479  1
520310  90.609  -58.996  55.434  1
520311  90.653  -59.020  55.388  1
520312  90.697  -59.045  55.344  1
520313  90.742  -59.070  55.304  1
520314  90.786  -59.094  55.266  1
520315  90.830  -59.119  55.231  1
520316  90.875  -59.143  55.199  1
520317  90.920  -59.168  55.165  1
520318  90.964  -59.193  55.127  1
520319  91.008  -59.218  55.086  1
520320  91.052  -59.243  55.047  1
520321  91.092  -59.259  55.011  1
520322  91.132  -59.274  54.978  1
520323  91.172  -59.290  54.950  1
520324  91.211  -59.305  54.926  1
520325  91.251  -59.320  54.905  1
520326  91.291  -59.335  54.887  1
520327  91.330  -59.350  54.870  1
520328  91.370  -59.366  54.854  1
520329  91.410  -59.381  54.837  1
520330  91.449  -59.397  54.823  1
520331  91.489  -59.412  54.811  1
520332  91.528  -59.427  54.799  1
520333  91.568  -59.443  54.790  1
520334  91.607  -59.458  54.782  1
520335  91.647  -59.473  54.774  1
520336  91.687  -59.488  54.768  1
520337  91.731  -59.501  54.763  1
520338  91.767  -59.509  54.760  1
520339  91.795  -59.513  54.761  1
520340  91.822  -59.519  54.769  1
520341  91.850  -59.525  54.781  1
520342  91.878  -59.530  54.788  1
520343  91.906  -59.535  54.787  1
520344  91.933  -59.541  54.776  1
520345  91.960  -59.547  54.757  1
520346  91.988  -59.552  54.726  1
520347  92.016  -59.557  54.691  1
520348  92.044  -59.563  54.657  1
520349  92.071  -59.568  54.626  1
520350  92.098  -59.574  54.596  1
520351  92.126  -59.579  54.567  1
520352  92.154  -59.585  54.553  1
520353  92.181  -59.590  54.554  1
520354  92.209  -59.595  54.557  1
520355  92.250  -59.597  54.554  1
520356  92.298  -59.596  54.547  1
520357  92.345  -59.595  54.548  1
520358  92.392  -59.595  54.535  1
520359  92.440  -59.594  54.517  1
520360  92.487  -59.593  54.497  1
520361  92.533  -59.595  54.477  1
520362  92.575  -59.605  54.464  1
520363  92.618  -59.615  54.456  1
520364  92.660  -59.624  54.444  1
520365  92.703  -59.634  54.430  1
520366  92.745  -59.644  54.418  1
520367  92.788  -59.654  54.401  1
520368  92.830  -59.663  54.389  1
520369  92.872  -59.673  54.376  1
520370  92.915  -59.682  54.365  1
520371  92.957  -59.692  54.358  1
520372  93.000  -59.701  54.356  1
520373  93.042  -59.711  54.361  1
520374  93.085  -59.721  54.379  1
520375  93.125  -59.730  54.400  1
520376  93.163  -59.739  54.416  1
520377  93.202  -59.747  54.414  1
520378  93.240  -59.755  54.419  1
520379  93.279  -59.764  54.423  1
520380  93.315  -59.785  54.423  1
520381  93.351  -59.806  54.418  1
520382  93.388  -59.826  54.410  1
520383  93.424  -59.847  54.399  1
520384  93.460  -59.868  54.398  1
520385  93.496  -59.889  54.396  1
520386  93.532  -59.909  54.391  1
520387  93.568  -59.930  54.382  1
520388  93.605  -59.951  54.371  1
520389  93.641  -59.971  54.362  1
520390  93.677  -59.992  54.351  1
520391  93.713  -60.013  54.341  1
520392  93.749  -60.033  54.334  1
520393  93.786  -60.052  54.327  1
520394  93.822  -60.067  54.320  1
520395  93.858  -60.083  54.312  1
520396  93.895  -60.098  54.303  1
520397  93.932  -60.113  54.292  1
520398  93.972  -60.122  54.281  1
520399  94.012  -60.131  54.273  1
520400  94.052  -60.140  54.265  1
520401  94.092  -60.149  54.255  1
520402  94.133  -60.158  54.247  1
520403  94.173  -60.167  54.240  1
520404  94.213  -60.176  54.230  1
520405  94.253  -60.184  54.221  1
520406  94.293  -60.193  54.201  1
520407  94.334  -60.202  54.174  1
520408  94.376  -60.209  54.141  1
520409  94.419  -60.215  54.102  1
520410  94.462  -60.221  54.054  1
520411  94.505  -60.226  54.009  1
520412  94.548  -60.232  53.966  1
520413  94.592  -60.238  53.929  1
520414  94.634  -60.243  53.907  1
520415  94.678  -60.249  53.897  1
520416  94.720  -60.255  53.883  1
520417  94.762  -60.261  53.868  1
520418  94.802  -60.266  53.850  1
520419  94.841  -60.271  53.831  1
520420  94.881  -60.277  53.813  1
520421  94.921  -60.282  53.792  1
520422  94.961  -60.288  53.769  1
520423  94.996  -60.297  53.743  1
520424  95.031  -60.307  53.715  1
520425  95.066  -60.317  53.687  1
520426  95.101  -60.327  53.658  1
520427  95.135  -60.337  53.630  1
520428  95.170  -60.347  53.601  1
520429  95.205  -60.356  53.572  1
520430  95.240  -60.366  53.542  1
520431  95.274  -60.375  53.510  1
520432  95.310  -60.383  53.472  1
520433  95.347  -60.391  53.431  1
520434  95.384  -60.399  53.389  1
520435  95.420  -60.407  53.348  1
520436  95.457  -60.416  53.308  1
520437  95.494  -60.423  53.269  1
520438  95.530  -60.431  53.230  1
520439  95.567  -60.439  53.190  1
520440  95.604  -60.447  53.149  1
520441  95.640  -60.455  53.107  1
520442  95.677  -60.463  53.066  1
520443  95.713  -60.469  53.024  1
520444  95.749  -60.474  52.983  1
520445  95.785  -60.478  52.942  1
520446  95.822  -60.481  52.900  1
520447  95.861  -60.481  52.857  1
520448  95.899  -60.481  52.816  1
520449  95.938  -60.481  52.775  1
520450  95.977  -60.479  52.735  1
520451  96.015  -60.481  52.695  1
520452  96.051  -60.485  52.652  1
520453  96.088  -60.488  52.612  1
520454  96.124  -60.491  52.575  1
520455  96.160  -60.494  52.539  1
520456  96.197  -60.497  52.505  1
520457  96.233  -60.500  52.473  1
520458  96.270  -60.503  52.440  1
520459  96.309  -60.503  52.408  1
520460  96.349  -60.500  52.376  1
520461  96.391  -60.497  52.345  1
520462  96.432  -60.494  52.314  1
520463  96.473  -60.491  52.284  1
520464  96.514  -60.488  52.252  1
520465  96.555  -60.486  52.220  1
520466  96.596  -60.483  52.189  1
520467  96.639  -60.487  52.160  1
520468  96.683  -60.496  52.131  1
520469  96.728  -60.505  52.104  1
520470  96.773  -60.514  52.075  1
520471  96.817  -60.523  52.047  1
520472  96.858  -60.535  52.020  1
520473  96.889  -60.548  51.993  1
520474  96.922  -60.562  51.968  1
520475  96.953  -60.575  51.942  1
520476  96.985  -60.589  51.915  1
520477  97.022  -60.601  51.885  1
520478  97.069  -60.608  51.854  1
520479  97.116  -60.616  51.821  1
520480  97.163  -60.622  51.784  1
520481  97.209  -60.630  51.748  1
520482  97.232  -60.634  51.710  1
520483  97.247  -60.637  51.671  1
520484  97.277  -60.638  51.630  1
520485  97.313  -60.638  51.589  1
520486  97.350  -60.639  51.549  1
520487  97.387  -60.640  51.511  1
520488  97.424  -60.641  51.475  1
520489  97.461  -60.641  51.440  1
520490  97.497  -60.644  51.407  1
520491  97.533  -60.641  51.373  1
520492  97.555  -60.636  51.338  1
520493  97.593  -60.636  51.302  1
520494  97.639  -60.638  51.266  1
520495  97.684  -60.641  51.229  1
520496  97.731  -60.644  51.191  1
520497  97.777  -60.646  51.151  1
520498  97.822  -60.649  51.110  1
520499  97.868  -60.651  51.069  1
520500  97.903  -60.654  51.026  1
520501  97.929  -60.657  50.984  1
520502  97.954  -60.660  50.940  1
520503  97.976  -60.663  50.895  1
520504  97.980  -60.672  50.851  1
520505  97.984  -60.680  50.805  1
520506  97.992  -60.690  50.761  1
520507  98.016  -60.706  50.718  1
520508  98.040  -60.721  50.675  1
520509  98.072  -60.720  50.632  1
520510  98.108  -60.724  50.588  1
520511  98.145  -60.729  50.544  1
520512  98.181  -60.732  50.497  1
520513  98.217  -60.737  50.454  1
520514  98.253  -60.742  50.411  1
520515  98.290  -60.745  50.367  1
520516  98.326  -60.750  50.324  1
520517  98.362  -60.754  50.281  1
520518  98.398  -60.759  50.238  1
520519  98.435  -60.763  50.197  1
520520  98.471  -60.767  50.157  1
520521  98.507  -60.772  50.116  1
520927  87.223  -58.015  57.180  1
520928  87.264  -58.030  57.161  1
520929  87.304  -58.043  57.143  1
520930  87.345  -58.057  57.125  1
520931  87.386  -58.071  57.105  1
520932  87.426  -58.084  57.085  1
520933  87.467  -58.099  57.064  1
520934  87.508  -58.112  57.043  1
520935  87.548  -58.126  57.022  1
520936  87.589  -58.140  56.998  1
520937  87.630  -58.153  56.973  1
520938  87.670  -58.168  56.947  1
520939  87.711  -58.181  56.919  1
520940  87.752  -58.193  56.888  1
520941  87.794  -58.195  56.857  1
520942  87.837  -58.197  56.823  1
520943  87.880  -58.200  56.787  1
520944  87.914  -58.205  56.750  1
520945  87.945  -58.212  56.712  1
520946  87.990  -58.223  56.673  1
520947  88.036  -58.234  56.634  1
520948  88.081  -58.247  56.594  1
520949  88.127  -58.258  56.553  1
520950  88.173  -58.269  56.512  1
520951  88.218  -58.281  56.470  1
520952  88.263  -58.292  56.428  1
520953  88.309  -58.304  56.386  1
520954  88.354  -58.316  56.345  1
520955  88.400  -58.327  56.306  1
520956  88.446  -58.338  56.267  1
520957  88.491  -58.350  56.230  1
520958  88.537  -58.362  56.194  1
520959  88.582  -58.373  56.160  1
520960  88.627  -58.385  56.127  1
520961  88.672  -58.396  56.095  1
520962  88.712  -58.407  56.065  1
520963  88.753  -58.417  56.038  1
520964  88.793  -58.428  56.011  1
520965  88.833  -58.438  55.986  1
520966  88.874  -58.448  55.962  1
520967  88.916  -58.468  55.939  1
520968  88.959  -58.488  55.919  1
520969  89.002  -58.510  55.900  1
520970  89.045  -58.530  55.882  1
520971  89.088  -58.551  55.865  1
520972  89.124  -58.563  55.847  1
520973  89.159  -58.573  55.833  1
520974  89.194  -58.584  55.819  1
520975  89.229  -58.595  55.808  1
520976  89.263  -58.605  55.797  1
520977  89.299  -58.615  55.788  1
520978  89.333  -58.626  55.781  1
520979  89.368  -58.636  55.774  1
520980  89.405  -58.646  55.770  1
520981  89.452  -58.652  55.766  1
520982  89.490  -58.657  55.761  1
520983  89.527  -58.661  55.759  1
520984  89.563  -58.664  55.755  1
520985  89.600  -58.667  55.750  1
520986  89.638  -58.683  55.747  1
520987  89.677  -58.700  55.748  1
520988  89.716  -58.717  55.754  1
520989  89.755  -58.734  55.763  1
520990  89.794  -58.751  55.772  1
520991  89.832  -58.769  55.778  1
520992  89.872  -58.786  55.781  1
520993  89.912  -58.805  55.781  1
520994  89.954  -58.824  55.777  1
520995  89.994  -58.842  55.770  1
520996  90.036  -58.861  55.760  1
520997  90.077  -58.879  55.749  1
520998  90.118  -58.897  55.736  1
520999  90.159  -58.914  55.722  1
521000  90.197  -58.918  55.709  1
521001  90.235  -58.921  55.695  1
521002  90.273  -58.923  55.679  1
521003  90.311  -58.926  55.662  1
521004  90.350  -58.929  55.639  1
521005  90.388  -58.932  55.619  1
521006  90.426  -58.934  55.596  1
521007  90.464  -58.937  55.566  1
521008  90.502  -58.940  55.530  1
521009  90.540  -58.944  55.491  1
521010  90.579  -58.949  55.451  1
521011  90.617  -58.955  55.411  1
521012  90.657  -58.978  55.371  1
521013  90.701  -59.003  55.333  1
521014  90.746  -59.028  55.299  1
521015  90.790  -59.052  55.270  1
521016  90.834  -59.077  55.240  1
521017  90.879  -59.102  55.211  1
521018  90.923  -59.127  55.180  1
521019  90.967  -59.152  55.144  1
521020  91.012  -59.176  55.102  1
521021  91.056  -59.201  55.058  1
521022  91.097  -59.220  55.016  1
521023  91.137  -59.235  54.980  1
521024  91.177  -59.250  54.950  1
521025  91.216  -59.265  54.924  1
521026  91.256  -59.281  54.901  1
521027  91.296  -59.297  54.882  1
521028  91.335  -59.312  54.865  1
521029  91.375  -59.327  54.850  1
521030  91.414  -59.343  54.834  1
521031  91.454  -59.358  54.820  1
521032  91.494  -59.373  54.806  1
521033  91.533  -59.388  54.794  1
521034  91.573  -59.403  54.784  1
521035  91.612  -59.419  54.776  1
521036  91.655  -59.433  54.768  1
521037  91.700  -59.446  54.763  1
521038  91.739  -59.460  54.757  1
521039  91.775  -59.470  54.753  1
521040  91.810  -59.471  54.752  1
521041  91.838  -59.476  54.757  1
521042  91.865  -59.482  54.766  1
521043  91.892  -59.488  54.772  1
521044  91.920  -59.493  54.775  1
521045  91.948  -59.498  54.773  1
521046  91.976  -59.504  54.764  1
521047  92.003  -59.509  54.742  1
521048  92.030  -59.515  54.712  1
521049  92.058  -59.520  54.681  1
521050  92.086  -59.526  54.651  1
521051  92.113  -59.531  54.622  1
521052  92.141  -59.536  54.592  1
521053  92.168  -59.542  54.566  1
521054  92.196  -59.547  54.559  1
521055  92.224  -59.553  54.564  1
521056  92.265  -59.554  54.565  1
521057  92.312  -59.554  54.560  1
521058  92.360  -59.552  54.559  1
521059  92.407  -59.551  54.541  1
521060  92.454  -59.551  54.519  1
521061  92.502  -59.550  54.501  1
521062  92.549  -59.549  54.487  1
521063  92.592  -59.557  54.473  1
521064  92.635  -59.567  54.462  1
521065  92.677  -59.577  54.449  1
521066  92.720  -59.586  54.436  1
521067  92.762  -59.596  54.423  1
521068  92.804  -59.606  54.408  1
521069  92.847  -59.616  54.393  1
521070  92.889  -59.625  54.379  1
521071  92.932  -59.635  54.367  1
521072  92.974  -59.645  54.357  1
521073  93.017  -59.654  54.352  1
521074  93.059  -59.663  54.356  1
521075  93.101  -59.673  54.369  1
521076  93.140  -59.682  54.388  1
521077  93.179  -59.690  54.406  1
521078  93.217  -59.699  54.416  1
521079  93.256  -59.707  54.420  1
521080  93.294  -59.716  54.419  1
521081  93.330  -59.737  54.414  1
521082  93.366  -59.757  54.408  1
521083  93.403  -59.778  54.404  1
521084  93.439  -59.799  54.393  1
521085  93.475  -59.820  54.388  1
521086  93.511  -59.840  54.383  1
521087  93.547  -59.861  54.376  1
521088  93.583  -59.882  54.367  1
521089  93.620  -59.902  54.359  1
521090  93.656  -59.924  54.349  1
521091  93.692  -59.944  54.339  1
521092  93.728  -59.964  54.330  1
521093  93.765  -59.983  54.320  1
521094  93.801  -59.999  54.307  1
521095  93.837  -60.014  54.297  1
521096  93.874  -60.030  54.291  1
521097  93.910  -60.046  54.284  1
521098  93.947  -60.061  54.275  1
521099  93.983  -60.077  54.264  1
521100  94.024  -60.086  54.253  1
521101  94.063  -60.095  54.245  1
521102  94.104  -60.104  54.237  1
521103  94.144  -60.113  54.232  1
521104  94.184  -60.121  54.230  1
521105  94.224  -60.130  54.222  1
521106  94.264  -60.140  54.216  1
521107  94.305  -60.149  54.201  1
521108  94.345  -60.157  54.178  1
521109  94.387  -60.165  54.150  1
521110  94.428  -60.172  54.114  1
521111  94.470  -60.180  54.069  1
521112  94.512  -60.187  54.023  1
521113  94.555  -60.193  53.976  1
521114  94.598  -60.198  53.930  1
521115  94.641  -60.204  53.894  1
521116  94.684  -60.209  53.873  1
521117  94.728  -60.215  53.854  1
521118  94.769  -60.221  53.835  1
521119  94.809  -60.226  53.817  1
521120  94.848  -60.232  53.798  1
521121  94.889  -60.237  53.783  1
521122  94.928  -60.244  53.765  1
521123  94.967  -60.253  53.746  1
521124  95.003  -60.262  53.723  1
521125  95.038  -60.271  53.699  1
521126  95.072  -60.281  53.675  1
521127  95.107  -60.291  53.649  1
521128  95.142  -60.301  53.622  1
521129  95.177  -60.310  53.595  1
521130  95.211  -60.320  53.566  1
521131  95.246  -60.330  53.535  1
521132  95.284  -60.339  53.502  1
521133  95.320  -60.346  53.466  1
521134  95.355  -60.352  53.426  1
521135  95.392  -60.359  53.385  1
521136  95.428  -60.368  53.345  1
521137  95.465  -60.376  53.306  1
521138  95.502  -60.384  53.268  1
521139  95.539  -60.392  53.230  1
521140  95.576  -60.400  53.192  1
521141  95.612  -60.408  53.152  1
521142  95.649  -60.416  53.111  1
521143  95.685  -60.422  53.069  1
521144  95.721  -60.427  53.023  1
521145  95.756  -60.431  52.980  1
521146  95.793  -60.437  52.938  1
521147  95.829  -60.441  52.897  1
521148  95.868  -60.441  52.862  1
521149  95.906  -60.440  52.826  1
521150  95.946  -60.439  52.789  1
521151  95.984  -60.439  52.750  1
521152  96.022  -60.439  52.709  1
521153  96.058  -60.442  52.667  1
521154  96.095  -60.445  52.627  1
521155  96.131  -60.447  52.590  1
521156  96.168  -60.450  52.554  1
521157  96.204  -60.453  52.519  1
521158  96.241  -60.456  52.487  1
521159  96.277  -60.459  52.453  1
521160  96.316  -60.458  52.420  1
521161  96.357  -60.455  52.387  1
521162  96.398  -60.452  52.355  1
521163  96.439  -60.450  52.324  1
521164  96.480  -60.447  52.293  1
521165  96.521  -60.444  52.260  1
521166  96.562  -60.441  52.227  1
521167  96.604  -60.441  52.194  1
521168  96.649  -60.450  52.163  1
521169  96.693  -60.459  52.133  1
521170  96.738  -60.469  52.105  1
521171  96.783  -60.478  52.074  1
521172  96.827  -60.488  52.044  1
521173  96.867  -60.498  52.016  1
521174  96.899  -60.512  51.988  1
521175  96.931  -60.525  51.962  1
521176  96.963  -60.540  51.938  1
521177  96.995  -60.553  51.912  1
521178  97.027  -60.567  51.884  1
521179  97.069  -60.576  51.852  1
521180  97.116  -60.584  51.820  1
521181  97.163  -60.591  51.783  1
521182  97.209  -60.598  51.746  1
521183  97.232  -60.602  51.709  1
521184  97.248  -60.605  51.671  1
521185  97.283  -60.606  51.633  1
521186  97.320  -60.607  51.592  1
521187  97.357  -60.607  51.552  1
521188  97.393  -60.608  51.513  1
521189  97.430  -60.609  51.475  1
521190  97.467  -60.610  51.440  1
521191  97.504  -60.611  51.407  1
521192  97.540  -60.614  51.374  1
521193  97.566  -60.606  51.340  1
521194  97.601  -60.605  51.305  1
521195  97.647  -60.607  51.270  1
521196  97.693  -60.610  51.235  1
521197  97.739  -60.613  51.198  1
521198  97.785  -60.615  51.159  1
521199  97.831  -60.617  51.119  1
521200  97.868  -60.620  51.079  1
521201  97.893  -60.623  51.037  1
521202  97.919  -60.626  50.994  1
521203  97.944  -60.629  50.950  1
521204  97.969  -60.632  50.906  1
521205  97.984  -60.638  50.861  1
521206  97.988  -60.646  50.816  1
521207  97.994  -60.655  50.772  1
521208  98.018  -60.670  50.729  1
521209  98.043  -60.679  50.687  1
521210  98.078  -60.682  50.644  1
521211  98.114  -60.687  50.598  1
521212  98.151  -60.691  50.551  1
521213  98.187  -60.695  50.505  1
521214  98.223  -60.700  50.461  1
521215  98.260  -60.704  50.417  1
521216  98.296  -60.708  50.372  1
521217  98.332  -60.713  50.328  1
521218  98.368  -60.717  50.284  1
521219  98.405  -60.721  50.240  1
521220  98.441  -60.726  50.198  1
521221  98.478  -60.730  50.158  1
521222  98.514  -60.734  50.117  1
521628  87.249  -57.990  57.181  1
521629  87.289  -58.004  57.163  1
521630  87.330  -58.018  57.145  1
521631  87.371  -58.031  57.127  1
521632  87.411  -58.045  57.107  1
521633  87.452  -58.059  57.087  1
521634  87.493  -58.072  57.067  1
521635  87.533  -58.087  57.047  1
521636  87.574  -58.100  57.025  1
521637  87.614  -58.114  57.003  1
521638  87.655  -58.128  56.979  1
521639  87.696  -58.141  56.953  1
521640  87.736  -58.156  56.926  1
521641  87.778  -58.163  56.897  1
521642  87.821  -58.165  56.866  1
521643  87.863  -58.168  56.832  1
521644  87.906  -58.170  56.798  1
521645  87.949  -58.172  56.763  1
521646  87.981  -58.178  56.726  1
521647  88.012  -58.185  56.688  1
521648  88.051  -58.194  56.650  1
521649  88.096  -58.205  56.611  1
521650  88.141  -58.217  56.571  1
521651  88.187  -58.228  56.531  1
521652  88.233  -58.240  56.489  1
521653  88.278  -58.251  56.446  1
521654  88.324  -58.263  56.404  1
521655  88.369  -58.275  56.363  1
521656  88.415  -58.286  56.322  1
521657  88.460  -58.297  56.283  1
521658  88.505  -58.310  56.245  1
521659  88.551  -58.321  56.207  1
521660  88.597  -58.332  56.172  1
521661  88.637  -58.343  56.138  1
521662  88.677  -58.354  56.105  1
521663  88.717  -58.363  56.075  1
521664  88.758  -58.374  56.046  1
521665  88.798  -58.385  56.019  1
521666  88.838  -58.395  55.993  1
521667  88.880  -58.409  55.968  1
521668  88.922  -58.430  55.945  1
521669  88.966  -58.451  55.923  1
521670  89.009  -58.472  55.904  1
521671  89.051  -58.493  55.885  1
521672  89.095  -58.513  55.867  1
521673  89.136  -58.532  55.851  1
521674  89.171  -58.543  55.836  1
521675  89.206  -58.554  55.823  1
521676  89.241  -58.563  55.812  1
521677  89.275  -58.574  55.803  1
521678  89.311  -58.585  55.794  1
521679  89.345  -58.595  55.786  1
521680  89.380  -58.606  55.780  1
521681  89.418  -58.615  55.775  1
521682  89.465  -58.621  55.770  1
521683  89.512  -58.627  55.766  1
521684  89.548  -58.631  55.763  1
521685  89.585  -58.635  55.760  1
521686  89.621  -58.639  55.758  1
521687  89.659  -58.648  55.759  1
521688  89.698  -58.666  55.765  1
521689  89.737  -58.683  55.774  1
521690  89.775  -58.701  55.780  1
521691  89.814  -58.718  55.785  1
521692  89.853  -58.735  55.787  1
521693  89.892  -58.752  55.784  1
521694  89.931  -58.770  55.780  1
521695  89.969  -58.787  55.772  1
521696  90.009  -58.805  55.763  1
521697  90.050  -58.824  55.752  1
521698  90.091  -58.842  55.739  1
521699  90.132  -58.860  55.724  1
521700  90.173  -58.879  55.708  1
521701  90.212  -58.884  55.689  1
521702  90.250  -58.887  55.670  1
521703  90.288  -58.890  55.650  1
521704  90.326  -58.892  55.631  1
521705  90.365  -58.896  55.608  1
521706  90.403  -58.899  55.587  1
521707  90.441  -58.902  55.561  1
521708  90.479  -58.908  55.531  1
521709  90.518  -58.912  55.499  1
521710  90.556  -58.918  55.465  1
521711  90.595  -58.922  55.429  1
521712  90.633  -58.927  55.393  1
521713  90.669  -58.941  55.358  1
521714  90.705  -58.961  55.326  1
521715  90.749  -58.987  55.298  1
521716  90.794  -59.011  55.273  1
521717  90.838  -59.036  55.247  1
521718  90.882  -59.061  55.218  1
521719  90.927  -59.085  55.187  1
521720  90.971  -59.110  55.153  1
521721  91.015  -59.134  55.114  1
521722  91.060  -59.159  55.072  1
521723  91.102  -59.181  55.030  1
521724  91.142  -59.196  54.990  1
521725  91.182  -59.212  54.954  1
521726  91.221  -59.227  54.925  1
521727  91.261  -59.242  54.900  1
521728  91.301  -59.258  54.879  1
521729  91.340  -59.273  54.861  1
521730  91.380  -59.288  54.846  1
521731  91.419  -59.303  54.832  1
521732  91.459  -59.319  54.817  1
521733  91.499  -59.334  54.802  1
521734  91.538  -59.350  54.790  1
521735  91.578  -59.365  54.781  1
521736  91.622  -59.378  54.773  1
521737  91.667  -59.391  54.766  1
521738  91.711  -59.403  54.761  1
521739  91.747  -59.418  54.755  1
521740  91.784  -59.432  54.750  1
521741  91.819  -59.432  54.747  1
521742  91.852  -59.434  54.748  1
521743  91.880  -59.439  54.753  1
521744  91.908  -59.444  54.758  1
521745  91.935  -59.450  54.762  1
521746  91.962  -59.456  54.766  1
521747  91.990  -59.461  54.763  1
521748  92.018  -59.466  54.748  1
521749  92.046  -59.472  54.724  1
521750  92.073  -59.478  54.697  1
521751  92.100  -59.483  54.672  1
521752  92.128  -59.488  54.648  1
521753  92.156  -59.494  54.622  1
521754  92.183  -59.499  54.592  1
521755  92.211  -59.505  54.571  1
521756  92.238  -59.510  54.565  1
521757  92.280  -59.511  54.573  1
521758  92.327  -59.510  54.571  1
521759  92.374  -59.510  54.567  1
521760  92.422  -59.509  54.552  1
521761  92.469  -59.508  54.534  1
521762  92.516  -59.507  54.523  1
521763  92.564  -59.507  54.511  1
521764  92.609  -59.510  54.490  1
521765  92.652  -59.519  54.477  1
521766  92.694  -59.529  54.465  1
521767  92.736  -59.539  54.451  1
521768  92.779  -59.549  54.436  1
521769  92.821  -59.558  54.422  1
521770  92.864  -59.568  54.406  1
521771  92.906  -59.578  54.390  1
521772  92.949  -59.587  54.376  1
521773  92.991  -59.597  54.363  1
521774  93.034  -59.607  54.354  1
521775  93.076  -59.616  54.353  1
521776  93.117  -59.626  54.360  1
521777  93.155  -59.634  54.373  1
521778  93.194  -59.642  54.389  1
521779  93.232  -59.651  54.407  1
521780  93.271  -59.659  54.415  1
521781  93.309  -59.668  54.416  1
521782  93.345  -59.689  54.412  1
521783  93.381  -59.709  54.405  1
521784  93.418  -59.729  54.402  1
521785  93.454  -59.751  54.394  1
521786  93.490  -59.771  54.389  1
521787  93.526  -59.792  54.385  1
521788  93.562  -59.813  54.379  1
521789  93.599  -59.833  54.372  1
521790  93.635  -59.855  54.364  1
521791  93.671  -59.875  54.356  1
521792  93.707  -59.895  54.347  1
521793  93.744  -59.914  54.337  1
521794  93.780  -59.930  54.324  1
521795  93.817  -59.946  54.307  1
521796  93.853  -59.961  54.289  1
521797  93.889  -59.977  54.271  1
521798  93.926  -59.992  54.258  1
521799  93.962  -60.008  54.250  1
521800  93.999  -60.024  54.242  1
521801  94.035  -60.040  54.230  1
521802  94.074  -60.050  54.222  1
521803  94.115  -60.058  54.215  1
521804  94.155  -60.068  54.212  1
521805  94.195  -60.077  54.211  1
521806  94.235  -60.086  54.206  1
521807  94.275  -60.094  54.202  1
521808  94.316  -60.103  54.192  1
521809  94.356  -60.112  54.174  1
521810  94.398  -60.119  54.150  1
521811  94.439  -60.127  54.119  1
521812  94.481  -60.135  54.078  1
521813  94.522  -60.143  54.034  1
521814  94.563  -60.151  53.985  1
521815  94.605  -60.159  53.933  1
521816  94.648  -60.164  53.886  1
521817  94.691  -60.170  53.854  1
521818  94.735  -60.175  53.828  1
521819  94.776  -60.181  53.805  1
521820  94.816  -60.187  53.784  1
521821  94.856  -60.192  53.766  1
521822  94.895  -60.200  53.753  1
521823  94.934  -60.209  53.738  1
521824  94.974  -60.217  53.721  1
521825  95.010  -60.226  53.701  1
521826  95.045  -60.236  53.679  1
521827  95.079  -60.246  53.657  1
521828  95.114  -60.255  53.633  1
521829  95.149  -60.265  53.608  1
521830  95.183  -60.275  53.581  1
521831  95.218  -60.284  53.553  1
521832  95.256  -60.293  53.522  1
521833  95.295  -60.302  53.489  1
521834  95.330  -60.308  53.454  1
521835  95.365  -60.314  53.417  1
521836  95.400  -60.320  53.380  1
521837  95.437  -60.328  53.343  1
521838  95.473  -60.337  53.306  1
521839  95.510  -60.344  53.269  1
521840  95.547  -60.353  53.233  1
521841  95.584  -60.360  53.196  1
521842  95.620  -60.369  53.157  1
521843  95.657  -60.375  53.116  1
521844  95.692  -60.380  53.073  1
521845  95.728  -60.385  53.026  1
521846  95.764  -60.390  52.984  1
521847  95.800  -60.395  52.945  1
521848  95.836  -60.400  52.904  1
521849  95.875  -60.400  52.868  1
521850  95.913  -60.399  52.835  1
521851  95.953  -60.398  52.799  1
521852  95.990  -60.398  52.763  1
521853  96.028  -60.398  52.725  1
521854  96.065  -60.398  52.684  1
521855  96.102  -60.401  52.645  1
521856  96.138  -60.404  52.608  1
521857  96.175  -60.407  52.572  1
521858  96.212  -60.409  52.538  1
521859  96.248  -60.412  52.503  1
521860  96.285  -60.415  52.468  1
521861  96.324  -60.412  52.434  1
521862  96.364  -60.410  52.400  1
521863  96.405  -60.407  52.367  1
521864  96.446  -60.404  52.335  1
521865  96.487  -60.402  52.304  1
521866  96.528  -60.399  52.269  1
521867  96.570  -60.396  52.235  1
521868  96.614  -60.405  52.202  1
521869  96.659  -60.414  52.169  1
521870  96.703  -60.424  52.137  1
521871  96.748  -60.433  52.108  1
521872  96.793  -60.442  52.076  1
521873  96.837  -60.451  52.045  1
521874  96.877  -60.463  52.014  1
521875  96.908  -60.476  51.985  1
521876  96.941  -60.490  51.957  1
521877  96.972  -60.503  51.932  1
521878  97.005  -60.517  51.907  1
521879  97.037  -60.531  51.879  1
521880  97.069  -60.544  51.848  1
521881  97.116  -60.552  51.815  1
521882  97.163  -60.559  51.779  1
521883  97.209  -60.566  51.743  1
521884  97.233  -60.570  51.706  1
521885  97.252  -60.572  51.669  1
521886  97.290  -60.573  51.633  1
521887  97.326  -60.574  51.593  1
521888  97.363  -60.575  51.553  1
521889  97.400  -60.575  51.513  1
521890  97.437  -60.576  51.474  1
521891  97.474  -60.577  51.439  1
521892  97.511  -60.578  51.407  1
521893  97.547  -60.581  51.374  1
521894  97.577  -60.575  51.341  1
521895  97.610  -60.574  51.307  1
521896  97.656  -60.576  51.273  1
521897  97.702  -60.579  51.239  1
521898  97.748  -60.582  51.203  1
521899  97.794  -60.584  51.165  1
521900  97.833  -60.587  51.127  1
521901  97.858  -60.589  51.087  1
521902  97.883  -60.592  51.045  1
521903  97.909  -60.595  51.002  1
521904  97.934  -60.598  50.958  1
521905  97.959  -60.601  50.914  1
521906  97.984  -60.604  50.869  1
521907  97.993  -60.612  50.824  1
521908  97.996  -60.619  50.781  1
521909  98.020  -60.635  50.739  1
521910  98.048  -60.641  50.697  1
521911  98.084  -60.645  50.655  1
521912  98.121  -60.649  50.609  1
521913  98.157  -60.654  50.560  1
521914  98.193  -60.658  50.513  1
521915  98.229  -60.662  50.467  1
521916  98.266  -60.666  50.422  1
521917  98.302  -60.671  50.378  1
521918  98.339  -60.676  50.333  1
521919  98.375  -60.679  50.288  1
521920  98.411  -60.684  50.243  1
521921  98.447  -60.688  50.201  1
521922  98.484  -60.692  50.159  1
521923  98.520  -60.697  50.118  1
521924  98.556  -60.701  50.077  1
522329  87.274  -57.964  57.181  1
522330  87.315  -57.977  57.163  1
522331  87.355  -57.992  57.145  1
522332  87.396  -58.006  57.127  1
522333  87.437  -58.019  57.109  1
522334  87.477  -58.033  57.089  1
522335  87.518  -58.046  57.069  1
522336  87.559  -58.061  57.049  1
522337  87.599  -58.075  57.029  1
522338  87.640  -58.088  57.006  1
522339  87.681  -58.102  56.983  1
522340  87.721  -58.115  56.958  1
522341  87.762  -58.129  56.933  1
522342  87.804  -58.134  56.904  1
522343  87.847  -58.136  56.873  1
522344  87.890  -58.138  56.841  1
522345  87.932  -58.140  56.808  1
522346  87.975  -58.143  56.774  1
522347  88.017  -58.145  56.738  1
522348  88.049  -58.152  56.702  1
522349  88.080  -58.158  56.665  1
522350  88.112  -58.165  56.627  1
522351  88.156  -58.176  56.588  1
522352  88.202  -58.187  56.548  1
522353  88.247  -58.199  56.506  1
522354  88.293  -58.210  56.464  1
522355  88.338  -58.222  56.422  1
522356  88.384  -58.234  56.381  1
522357  88.429  -58.245  56.339  1
522358  88.475  -58.256  56.299  1
522359  88.520  -58.268  56.260  1
522360  88.561  -58.279  56.222  1
522361  88.602  -58.289  56.185  1
522362  88.642  -58.300  56.150  1
522363  88.682  -58.310  56.117  1
522364  88.722  -58.321  56.084  1
522365  88.763  -58.332  56.055  1
522366  88.803  -58.341  56.027  1
522367  88.843  -58.352  56.000  1
522368  88.886  -58.372  55.976  1
522369  88.929  -58.392  55.951  1
522370  88.972  -58.413  55.929  1
522371  89.015  -58.435  55.908  1
522372  89.058  -58.455  55.889  1
522373  89.101  -58.476  55.871  1
522374  89.144  -58.497  55.855  1
522375  89.183  -58.512  55.840  1
522376  89.218  -58.523  55.828  1
522377  89.253  -58.533  55.817  1
522378  89.287  -58.544  55.808  1
522379  89.323  -58.554  55.800  1
522380  89.357  -58.565  55.794  1
522381  89.392  -58.576  55.789  1
522382  89.431  -58.584  55.786  1
522383  89.478  -58.590  55.782  1
522384  89.525  -58.596  55.778  1
522385  89.569  -58.601  55.775  1
522386  89.606  -58.605  55.772  1
522387  89.642  -58.609  55.772  1
522388  89.679  -58.615  55.776  1
522389  89.718  -58.632  55.784  1
522390  89.757  -58.649  55.794  1
522391  89.796  -58.667  55.796  1
522392  89.835  -58.684  55.795  1
522393  89.874  -58.701  55.791  1
522394  89.912  -58.719  55.783  1
522395  89.951  -58.736  55.775  1
522396  89.990  -58.753  55.765  1
522397  90.029  -58.770  55.754  1
522398  90.068  -58.788  55.742  1
522399  90.106  -58.805  55.728  1
522400  90.147  -58.823  55.711  1
522401  90.187  -58.842  55.692  1
522402  90.227  -58.851  55.670  1
522403  90.265  -58.854  55.649  1
522404  90.303  -58.857  55.628  1
522405  90.341  -58.861  55.607  1
522406  90.380  -58.866  55.586  1
522407  90.418  -58.871  55.563  1
522408  90.457  -58.876  55.539  1
522409  90.495  -58.881  55.511  1
522410  90.533  -58.886  55.481  1
522411  90.572  -58.891  55.449  1
522412  90.610  -58.896  55.416  1
522413  90.649  -58.901  55.383  1
522414  90.687  -58.905  55.351  1
522415  90.722  -58.926  55.323  1
522416  90.756  -58.946  55.300  1
522417  90.797  -58.969  55.276  1
522418  90.841  -58.994  55.249  1
522419  90.886  -59.019  55.219  1
522420  90.930  -59.043  55.188  1
522421  90.974  -59.068  55.155  1
522422  91.019  -59.093  55.121  1
522423  91.064  -59.118  55.082  1
522424  91.107  -59.142  55.041  1
522425  91.147  -59.157  55.000  1
522426  91.187  -59.173  54.962  1
522427  91.226  -59.188  54.930  1
522428  91.266  -59.203  54.903  1
522429  91.305  -59.218  54.880  1
522430  91.345  -59.234  54.860  1
522431  91.385  -59.250  54.843  1
522432  91.424  -59.265  54.828  1
522433  91.464  -59.280  54.814  1
522434  91.504  -59.295  54.800  1
522435  91.544  -59.310  54.788  1
522436  91.589  -59.322  54.779  1
522437  91.634  -59.335  54.772  1
522438  91.679  -59.348  54.768  1
522439  91.720  -59.362  54.763  1
522440  91.756  -59.376  54.757  1
522441  91.792  -59.391  54.751  1
522442  91.827  -59.394  54.746  1
522443  91.863  -59.394  54.745  1
522444  91.894  -59.397  54.744  1
522445  91.922  -59.402  54.745  1
522446  91.950  -59.407  54.749  1
522447  91.977  -59.413  54.755  1
522448  92.005  -59.419  54.757  1
522449  92.032  -59.424  54.750  1
522450  92.060  -59.429  54.734  1
522451  92.088  -59.435  54.712  1
522452  92.115  -59.440  54.689  1
522453  92.143  -59.446  54.669  1
522454  92.170  -59.451  54.645  1
522455  92.198  -59.457  54.615  1
522456  92.226  -59.462  54.585  1
522457  92.253  -59.467  54.566  1
522458  92.294  -59.469  54.565  1
522459  92.342  -59.468  54.566  1
522460  92.389  -59.467  54.565  1
522461  92.436  -59.466  54.557  1
522462  92.484  -59.466  54.550  1
522463  92.531  -59.465  54.549  1
522464  92.578  -59.464  54.535  1
522465  92.626  -59.463  54.518  1
522466  92.668  -59.472  54.503  1
522467  92.711  -59.482  54.492  1
522468  92.754  -59.491  54.480  1
522469  92.796  -59.501  54.467  1
522470  92.838  -59.511  54.456  1
522471  92.881  -59.520  54.437  1
522472  92.923  -59.530  54.416  1
522473  92.966  -59.540  54.398  1
522474  93.008  -59.550  54.381  1
522475  93.051  -59.559  54.366  1
522476  93.093  -59.569  54.356  1
522477  93.132  -59.577  54.351  1
522478  93.170  -59.585  54.354  1
522479  93.209  -59.595  54.367  1
522480  93.247  -59.603  54.390  1
522481  93.286  -59.611  54.405  1
522482  93.324  -59.620  54.411  1
522483  93.360  -59.640  54.411  1
522484  93.397  -59.660  54.405  1
522485  93.433  -59.682  54.400  1
522486  93.469  -59.702  54.395  1
522487  93.505  -59.723  54.391  1
522488  93.541  -59.744  54.387  1
522489  93.577  -59.764  54.381  1
522490  93.614  -59.785  54.375  1
522491  93.650  -59.806  54.366  1
522492  93.686  -59.826  54.356  1
522493  93.722  -59.846  54.348  1
522494  93.759  -59.862  54.338  1
522495  93.795  -59.877  54.324  1
522496  93.832  -59.893  54.305  1
522497  93.868  -59.908  54.281  1
522498  93.905  -59.924  54.255  1
522499  93.941  -59.939  54.233  1
522500  93.978  -59.955  54.219  1
522501  94.014  -59.971  54.211  1
522502  94.051  -59.986  54.201  1
522503  94.087  -60.002  54.194  1
522504  94.126  -60.014  54.189  1
522505  94.166  -60.023  54.188  1
522506  94.206  -60.031  54.186  1
522507  94.247  -60.040  54.183  1
522508  94.286  -60.049  54.179  1
522509  94.327  -60.058  54.170  1
522510  94.367  -60.067  54.157  1
522511  94.409  -60.074  54.139  1
522512  94.451  -60.082  54.114  1
522513  94.492  -60.090  54.077  1
522514  94.533  -60.098  54.036  1
522515  94.574  -60.105  53.991  1
522516  94.616  -60.113  53.942  1
522517  94.657  -60.121  53.888  1
522518  94.699  -60.129  53.845  1
522519  94.741  -60.136  53.810  1
522520  94.783  -60.141  53.779  1
522521  94.823  -60.148  53.753  1
522522  94.862  -60.156  53.733  1
522523  94.901  -60.165  53.722  1
522524  94.941  -60.173  53.710  1
522525  94.980  -60.181  53.695  1
522526  95.017  -60.190  53.677  1
522527  95.051  -60.199  53.658  1
522528  95.086  -60.209  53.636  1
522529  95.121  -60.219  53.614  1
522530  95.156  -60.229  53.590  1
522531  95.190  -60.239  53.564  1
522532  95.229  -60.247  53.536  1
522533  95.267  -60.256  53.507  1
522534  95.305  -60.264  53.475  1
522535  95.340  -60.270  53.442  1
522536  95.375  -60.276  53.409  1
522537  95.410  -60.282  53.375  1
522538  95.445  -60.289  53.340  1
522539  95.482  -60.297  53.305  1
522540  95.518  -60.305  53.270  1
522541  95.555  -60.313  53.236  1
522542  95.592  -60.321  53.200  1
522543  95.628  -60.328  53.160  1
522544  95.664  -60.333  53.119  1
522545  95.700  -60.338  53.074  1
522546  95.736  -60.343  53.029  1
522547  95.771  -60.348  52.989  1
522548  95.808  -60.353  52.955  1
522549  95.843  -60.358  52.916  1
522550  95.882  -60.358  52.880  1
522551  95.921  -60.358  52.846  1
522552  95.959  -60.357  52.812  1
522553  95.997  -60.357  52.777  1
522554  96.035  -60.357  52.742  1
522555  96.073  -60.357  52.703  1
522556  96.110  -60.358  52.664  1
522557  96.146  -60.360  52.627  1
522558  96.183  -60.363  52.592  1
522559  96.219  -60.366  52.558  1
522560  96.256  -60.369  52.524  1
522561  96.294  -60.370  52.489  1
522562  96.333  -60.368  52.455  1
522563  96.372  -60.365  52.420  1
522564  96.412  -60.362  52.385  1
522565  96.454  -60.359  52.352  1
522566  96.495  -60.357  52.318  1
522567  96.536  -60.354  52.283  1
522568  96.579  -60.360  52.248  1
522569  96.624  -60.369  52.213  1
522570  96.669  -60.378  52.179  1
522571  96.713  -60.387  52.145  1
522572  96.758  -60.397  52.114  1
522573  96.803  -60.406  52.082  1
522574  96.847  -60.415  52.049  1
522575  96.886  -60.426  52.017  1
522576  96.918  -60.440  51.986  1
522577  96.950  -60.453  51.956  1
522578  96.982  -60.467  51.928  1
522579  97.014  -60.481  51.900  1
522580  97.046  -60.495  51.872  1
522581  97.078  -60.509  51.842  1
522582  97.116  -60.520  51.809  1
522583  97.162  -60.527  51.774  1
522584  97.209  -60.535  51.739  1
522585  97.234  -60.538  51.703  1
522586  97.259  -60.541  51.667  1
522587  97.296  -60.541  51.630  1
522588  97.333  -60.541  51.592  1
522589  97.370  -60.542  51.551  1
522590  97.406  -60.543  51.511  1
522591  97.443  -60.544  51.474  1
522592  97.480  -60.544  51.440  1
522593  97.517  -60.545  51.407  1
522594  97.554  -60.547  51.375  1
522595  97.588  -60.545  51.342  1
522596  97.618  -60.542  51.308  1
522597  97.664  -60.545  51.275  1
522598  97.710  -60.547  51.241  1
522599  97.756  -60.550  51.207  1
522600  97.798  -60.553  51.170  1
522601  97.823  -60.556  51.133  1
522602  97.848  -60.559  51.093  1
522603  97.873  -60.562  51.050  1
522604  97.899  -60.565  51.008  1
522605  97.924  -60.568  50.965  1
522606  97.949  -60.571  50.920  1
522607  97.974  -60.574  50.876  1
522608  97.997  -60.577  50.831  1
522609  98.001  -60.585  50.788  1
522610  98.022  -60.600  50.747  1
522611  98.054  -60.604  50.706  1
522612  98.090  -60.607  50.664  1
522613  98.127  -60.612  50.619  1
522614  98.163  -60.616  50.570  1
522615  98.200  -60.620  50.521  1
522616  98.236  -60.625  50.474  1
522617  98.272  -60.629  50.428  1
522618  98.308  -60.633  50.383  1
522619  98.345  -60.638  50.337  1
522620  98.381  -60.642  50.293  1
522621  98.417  -60.647  50.247  1
522622  98.453  -60.651  50.204  1
522623  98.490  -60.655  50.162  1
522624  98.526  -60.660  50.119  1
522625  98.563  -60.663  50.078  1
523030  87.300  -57.938  57.180  1
523031  87.340  -57.952  57.162  1
523032  87.381  -57.965  57.145  1
523033  87.422  -57.980  57.126  1
523034  87.462  -57.993  57.108  1
523035  87.503  -58.007  57.090  1
523036  87.544  -58.021  57.070  1
523037  87.584  -58.034  57.051  1
523038  87.625  -58.049  57.031  1
523039  87.666  -58.062  57.008  1
523040  87.706  -58.076  56.985  1
523041  87.747  -58.090  56.961  1
523042  87.787  -58.102  56.937  1
523043  87.830  -58.104  56.909  1
523044  87.873  -58.106  56.879  1
523045  87.916  -58.109  56.847  1
523046  87.959  -58.111  56.815  1
523047  88.001  -58.113  56.782  1
523048  88.044  -58.115  56.747  1
523049  88.084  -58.118  56.713  1
523050  88.116  -58.125  56.677  1
523051  88.147  -58.131  56.640  1
523052  88.179  -58.137  56.602  1
523053  88.216  -58.147  56.563  1
523054  88.262  -58.158  56.523  1
523055  88.308  -58.169  56.481  1
523056  88.353  -58.181  56.440  1
523057  88.398  -58.193  56.398  1
523058  88.444  -58.204  56.356  1
523059  88.486  -58.215  56.316  1
523060  88.527  -58.225  56.276  1
523061  88.567  -58.236  56.237  1
523062  88.607  -58.247  56.199  1
523063  88.647  -58.256  56.163  1
523064  88.688  -58.267  56.129  1
523065  88.728  -58.278  56.096  1
523066  88.768  -58.288  56.066  1
523067  88.809  -58.299  56.038  1
523068  88.850  -58.313  56.010  1
523069  88.893  -58.334  55.983  1
523070  88.935  -58.355  55.958  1
523071  88.979  -58.375  55.936  1
523072  89.022  -58.397  55.914  1
523073  89.065  -58.418  55.894  1
523074  89.108  -58.438  55.876  1
523075  89.151  -58.460  55.860  1
523076  89.194  -58.480  55.845  1
523077  89.230  -58.492  55.833  1
523078  89.265  -58.503  55.823  1
523079  89.300  -58.513  55.814  1
523080  89.335  -58.524  55.806  1
523081  89.370  -58.534  55.803  1
523082  89.404  -58.545  55.801  1
523083  89.445  -58.554  55.799  1
523084  89.491  -58.559  55.798  1
523085  89.538  -58.565  55.795  1
523086  89.585  -58.571  55.792  1
523087  89.627  -58.576  55.790  1
523088  89.664  -58.580  55.789  1
523089  89.700  -58.584  55.791  1
523090  89.739  -58.598  55.797  1
523091  89.777  -58.616  55.801  1
523092  89.816  -58.633  55.799  1
523093  89.855  -58.651  55.795  1
523094  89.894  -58.667  55.788  1
523095  89.933  -58.685  55.777  1
523096  89.972  -58.702  55.766  1
523097  90.011  -58.720  55.755  1
523098  90.049  -58.736  55.743  1
523099  90.088  -58.754  55.731  1
523100  90.127  -58.771  55.715  1
523101  90.166  -58.789  55.697  1
523102  90.204  -58.806  55.676  1
523103  90.242  -58.820  55.653  1
523104  90.281  -58.825  55.630  1
523105  90.319  -58.830  55.609  1
523106  90.357  -58.835  55.588  1
523107  90.396  -58.839  55.568  1
523108  90.434  -58.845  55.547  1
523109  90.472  -58.849  55.524  1
523110  90.511  -58.855  55.499  1
523111  90.549  -58.859  55.473  1
523112  90.588  -58.864  55.444  1
523113  90.626  -58.869  55.415  1
523114  90.664  -58.874  55.383  1
523115  90.702  -58.879  55.350  1
523116  90.740  -58.890  55.316  1
523117  90.774  -58.911  55.294  1
523118  90.809  -58.931  55.269  1
523119  90.845  -58.952  55.240  1
523120  90.890  -58.977  55.210  1
523121  90.934  -59.002  55.178  1
523122  90.978  -59.027  55.148  1
523123  91.023  -59.052  55.117  1
523124  91.067  -59.076  55.084  1
523125  91.111  -59.101  55.048  1
523126  91.152  -59.118  55.011  1
523127  91.192  -59.134  54.974  1
523128  91.231  -59.149  54.937  1
523129  91.271  -59.165  54.908  1
523130  91.310  -59.180  54.882  1
523131  91.350  -59.195  54.860  1
523132  91.390  -59.210  54.842  1
523133  91.429  -59.225  54.826  1
523134  91.469  -59.241  54.811  1
523135  91.512  -59.255  54.798  1
523136  91.557  -59.268  54.787  1
523137  91.602  -59.281  54.778  1
523138  91.647  -59.294  54.771  1
523139  91.692  -59.306  54.769  1
523140  91.728  -59.320  54.765  1
523141  91.764  -59.334  54.761  1
523142  91.800  -59.349  54.757  1
523143  91.836  -59.355  54.755  1
523144  91.871  -59.355  54.758  1
523145  91.907  -59.356  54.760  1
523146  91.937  -59.359  54.758  1
523147  91.964  -59.365  54.752  1
523148  91.992  -59.370  54.746  1
523149  92.019  -59.375  54.749  1
523150  92.047  -59.381  54.750  1
523151  92.075  -59.387  54.743  1
523152  92.102  -59.392  54.727  1
523153  92.130  -59.397  54.704  1
523154  92.157  -59.403  54.682  1
523155  92.185  -59.409  54.660  1
523156  92.213  -59.414  54.634  1
523157  92.240  -59.419  54.601  1
523158  92.268  -59.425  54.568  1
523159  92.309  -59.426  54.551  1
523160  92.356  -59.425  54.555  1
523161  92.404  -59.425  54.558  1
523162  92.451  -59.424  54.559  1
523163  92.498  -59.423  54.561  1
523164  92.546  -59.422  54.564  1
523165  92.593  -59.422  54.553  1
523166  92.640  -59.421  54.540  1
523167  92.686  -59.425  54.529  1
523168  92.728  -59.435  54.519  1
523169  92.770  -59.444  54.508  1
523170  92.813  -59.453  54.497  1
523171  92.855  -59.463  54.486  1
523172  92.898  -59.473  54.467  1
523173  92.940  -59.482  54.446  1
523174  92.983  -59.492  54.423  1
523175  93.025  -59.502  54.399  1
523176  93.067  -59.512  54.378  1
523177  93.109  -59.521  54.364  1
523178  93.147  -59.529  54.356  1
523179  93.185  -59.538  54.354  1
523180  93.224  -59.546  54.355  1
523181  93.262  -59.554  54.366  1
523182  93.300  -59.563  54.379  1
523183  93.339  -59.572  54.391  1
523184  93.375  -59.591  54.398  1
523185  93.412  -59.613  54.397  1
523186  93.448  -59.633  54.392  1
523187  93.484  -59.654  54.391  1
523188  93.520  -59.675  54.389  1
523189  93.556  -59.695  54.386  1
523190  93.592  -59.716  54.381  1
523191  93.629  -59.737  54.373  1
523192  93.665  -59.757  54.362  1
523193  93.701  -59.778  54.350  1
523194  93.737  -59.794  54.341  1
523195  93.774  -59.809  54.333  1
523196  93.811  -59.825  54.319  1
523197  93.847  -59.840  54.299  1
523198  93.884  -59.856  54.272  1
523199  93.920  -59.871  54.241  1
523200  93.957  -59.887  54.213  1
523201  93.993  -59.902  54.193  1
523202  94.030  -59.918  54.182  1
523203  94.066  -59.934  54.172  1
523204  94.103  -59.949  54.164  1
523205  94.139  -59.965  54.161  1
523206  94.177  -59.977  54.161  1
523207  94.217  -59.986  54.158  1
523208  94.258  -59.996  54.155  1
523209  94.297  -60.005  54.149  1
523210  94.338  -60.013  54.143  1
523211  94.379  -60.021  54.133  1
523212  94.420  -60.029  54.118  1
523213  94.462  -60.037  54.096  1
523214  94.503  -60.045  54.065  1
523215  94.544  -60.052  54.029  1
523216  94.586  -60.061  53.987  1
523217  94.627  -60.068  53.941  1
523218  94.669  -60.076  53.893  1
523219  94.710  -60.083  53.846  1
523220  94.751  -60.093  53.809  1
523221  94.790  -60.103  53.778  1
523222  94.829  -60.112  53.749  1
523223  94.868  -60.121  53.723  1
523224  94.908  -60.129  53.699  1
523225  94.947  -60.137  53.682  1
523226  94.986  -60.146  53.667  1
523227  95.024  -60.154  53.653  1
523228  95.058  -60.164  53.636  1
523229  95.093  -60.174  53.614  1
523230  95.127  -60.184  53.592  1
523231  95.162  -60.193  53.567  1
523232  95.200  -60.202  53.542  1
523233  95.239  -60.211  53.517  1
523234  95.278  -60.219  53.489  1
523235  95.314  -60.227  53.461  1
523236  95.349  -60.233  53.432  1
523237  95.384  -60.239  53.401  1
523238  95.419  -60.245  53.369  1
523239  95.454  -60.251  53.337  1
523240  95.490  -60.258  53.304  1
523241  95.527  -60.265  53.271  1
523242  95.563  -60.274  53.237  1
523243  95.600  -60.281  53.202  1
523244  95.635  -60.286  53.162  1
523245  95.672  -60.291  53.120  1
523246  95.707  -60.297  53.074  1
523247  95.743  -60.301  53.031  1
523248  95.779  -60.306  52.995  1
523249  95.815  -60.311  52.965  1
523250  95.851  -60.316  52.930  1
523251  95.889  -60.317  52.895  1
523252  95.928  -60.317  52.861  1
523253  95.966  -60.316  52.827  1
523254  96.004  -60.316  52.794  1
523255  96.041  -60.316  52.762  1
523256  96.079  -60.316  52.725  1
523257  96.116  -60.316  52.687  1
523258  96.154  -60.317  52.651  1
523259  96.190  -60.320  52.616  1
523260  96.227  -60.322  52.582  1
523261  96.263  -60.325  52.548  1
523262  96.302  -60.325  52.514  1
523263  96.341  -60.322  52.479  1
523264  96.380  -60.320  52.443  1
523265  96.420  -60.318  52.407  1
523266  96.461  -60.315  52.373  1
523267  96.502  -60.312  52.337  1
523268  96.544  -60.315  52.301  1
523269  96.589  -60.324  52.264  1
523270  96.634  -60.333  52.228  1
523271  96.678  -60.342  52.192  1
523272  96.723  -60.351  52.157  1
523273  96.768  -60.360  52.124  1
523274  96.812  -60.369  52.089  1
523275  96.857  -60.378  52.055  1
523276  96.896  -60.390  52.021  1
523277  96.928  -60.403  51.988  1
523278  96.960  -60.418  51.957  1
523279  96.992  -60.431  51.927  1
523280  97.024  -60.445  51.896  1
523281  97.056  -60.459  51.866  1
523282  97.088  -60.472  51.836  1
523283  97.120  -60.486  51.802  1
523284  97.162  -60.495  51.768  1
523285  97.209  -60.503  51.733  1
523286  97.234  -60.506  51.697  1
523287  97.265  -60.508  51.661  1
523288  97.302  -60.509  51.624  1
523289  97.339  -60.510  51.585  1
523290  97.376  -60.510  51.547  1
523291  97.413  -60.511  51.509  1
523292  97.450  -60.512  51.474  1
523293  97.487  -60.513  51.443  1
523294  97.524  -60.513  51.410  1
523295  97.561  -60.514  51.377  1
523296  97.597  -60.516  51.343  1
523297  97.627  -60.511  51.308  1
523298  97.673  -60.514  51.273  1
523299  97.719  -60.516  51.241  1
523300  97.763  -60.519  51.206  1
523301  97.788  -60.522  51.171  1
523302  97.813  -60.525  51.134  1
523303  97.839  -60.528  51.095  1
523304  97.864  -60.531  51.054  1
523305  97.889  -60.534  51.011  1
523306  97.914  -60.537  50.968  1
523307  97.939  -60.540  50.924  1
523308  97.964  -60.543  50.880  1
523309  97.990  -60.546  50.835  1
523310  98.005  -60.551  50.793  1
523311  98.024  -60.562  50.753  1
523312  98.061  -60.566  50.712  1
523313  98.097  -60.570  50.670  1
523314  98.133  -60.575  50.626  1
523315  98.169  -60.579  50.579  1
523316  98.206  -60.583  50.529  1
523317  98.242  -60.588  50.481  1
523318  98.278  -60.591  50.434  1
523319  98.314  -60.596  50.388  1
523320  98.351  -60.600  50.342  1
523321  98.387  -60.605  50.297  1
523322  98.424  -60.609  50.251  1
523323  98.460  -60.613  50.207  1
523324  98.496  -60.618  50.164  1
523325  98.532  -60.622  50.122  1
523326  98.569  -60.626  50.080  1
523327  98.605  -60.631  50.038  1
523731  87.322  -57.905  57.177  1
523732  87.362  -57.918  57.159  1
523733  87.403  -57.932  57.142  1
523734  87.443  -57.946  57.124  1
523735  87.483  -57.959  57.106  1
523736  87.524  -57.972  57.088  1
523737  87.564  -57.985  57.069  1
523738  87.605  -57.999  57.051  1
523739  87.645  -58.012  57.031  1
523740  87.685  -58.025  57.009  1
523741  87.726  -58.039  56.987  1
523742  87.766  -58.052  56.963  1
523743  87.810  -58.062  56.939  1
523744  87.854  -58.068  56.912  1
523745  87.899  -58.076  56.882  1
523746  87.942  -58.079  56.851  1
523747  87.985  -58.081  56.820  1
523748  88.028  -58.084  56.788  1
523749  88.070  -58.086  56.755  1
523750  88.113  -58.088  56.721  1
523751  88.152  -58.092  56.687  1
523752  88.184  -58.098  56.651  1
523753  88.215  -58.105  56.613  1
523754  88.247  -58.111  56.576  1
523755  88.278  -58.118  56.537  1
523756  88.322  -58.128  56.497  1
523757  88.367  -58.140  56.456  1
523758  88.411  -58.151  56.415  1
523759  88.451  -58.162  56.373  1
523760  88.491  -58.172  56.332  1
523761  88.532  -58.182  56.292  1
523762  88.572  -58.193  56.253  1
523763  88.612  -58.203  56.215  1
523764  88.652  -58.214  56.177  1
523765  88.693  -58.225  56.142  1
523766  88.733  -58.234  56.109  1
523767  88.773  -58.245  56.078  1
523768  88.814  -58.256  56.049  1
523769  88.856  -58.275  56.020  1
523770  88.899  -58.297  55.992  1
523771  88.942  -58.317  55.966  1
523772  88.985  -58.338  55.943  1
523773  89.028  -58.359  55.921  1
523774  89.071  -58.380  55.901  1
523775  89.114  -58.400  55.882  1
523776  89.158  -58.422  55.866  1
523777  89.200  -58.443  55.850  1
523778  89.242  -58.462  55.838  1
523779  89.277  -58.473  55.828  1
523780  89.312  -58.482  55.819  1
523781  89.347  -58.493  55.814  1
523782  89.382  -58.504  55.813  1
523783  89.416  -58.514  55.814  1
523784  89.458  -58.523  55.815  1
523785  89.505  -58.529  55.816  1
523786  89.551  -58.535  55.813  1
523787  89.599  -58.540  55.811  1
523788  89.646  -58.546  55.809  1
523789  89.685  -58.551  55.806  1
523790  89.722  -58.554  55.805  1
523791  89.759  -58.565  55.806  1
523792  89.798  -58.582  55.803  1
523793  89.837  -58.599  55.798  1
523794  89.876  -58.617  55.791  1
523795  89.914  -58.634  55.784  1
523796  89.953  -58.651  55.772  1
523797  89.992  -58.668  55.762  1
523798  90.031  -58.686  55.751  1
523799  90.070  -58.703  55.740  1
523800  90.108  -58.720  55.728  1
523801  90.148  -58.737  55.714  1
523802  90.183  -58.754  55.691  1
523803  90.216  -58.767  55.666  1
523804  90.254  -58.775  55.641  1
523805  90.294  -58.789  55.617  1
523806  90.334  -58.803  55.595  1
523807  90.373  -58.808  55.575  1
523808  90.411  -58.813  55.557  1
523809  90.450  -58.818  55.538  1
523810  90.488  -58.823  55.517  1
523811  90.526  -58.828  55.494  1
523812  90.565  -58.833  55.471  1
523813  90.603  -58.838  55.446  1
523814  90.642  -58.842  55.418  1
523815  90.680  -58.848  55.386  1
523816  90.718  -58.852  55.351  1
523817  90.756  -58.858  55.313  1
523818  90.792  -58.875  55.287  1
523819  90.826  -58.896  55.260  1
523820  90.861  -58.916  55.231  1
523821  90.896  -58.936  55.202  1
523822  90.938  -58.960  55.173  1
523823  90.982  -58.985  55.145  1
523824  91.026  -59.010  55.118  1
523825  91.071  -59.034  55.090  1
523826  91.115  -59.059  55.058  1
523827  91.157  -59.080  55.024  1
523828  91.196  -59.095  54.988  1
523829  91.236  -59.110  54.950  1
523830  91.276  -59.125  54.916  1
523831  91.315  -59.140  54.887  1
523832  91.355  -59.156  54.863  1
523833  91.395  -59.171  54.843  1
523834  91.435  -59.187  54.825  1
523835  91.480  -59.200  54.809  1
523836  91.524  -59.212  54.797  1
523837  91.569  -59.225  54.787  1
523838  91.614  -59.238  54.777  1
523839  91.659  -59.251  54.771  1
523840  91.701  -59.264  54.770  1
523841  91.736  -59.278  54.768  1
523842  91.773  -59.293  54.766  1
523843  91.809  -59.308  54.767  1
523844  91.845  -59.316  54.769  1
523845  91.880  -59.316  54.772  1
523846  91.916  -59.317  54.775  1
523847  91.951  -59.317  54.773  1
523848  91.979  -59.322  54.764  1
523849  92.007  -59.328  54.750  1
523850  92.034  -59.333  54.744  1
523851  92.062  -59.338  54.743  1
523852  92.089  -59.344  54.741  1
523853  92.117  -59.350  54.733  1
523854  92.145  -59.355  54.716  1
523855  92.172  -59.360  54.692  1
523856  92.200  -59.366  54.667  1
523857  92.227  -59.371  54.640  1
523858  92.255  -59.377  54.609  1
523859  92.283  -59.382  54.580  1
523860  92.323  -59.384  54.559  1
523861  92.371  -59.383  54.548  1
523862  92.418  -59.381  54.551  1
523863  92.465  -59.381  54.559  1
523864  92.513  -59.380  54.563  1
523865  92.560  -59.379  54.554  1
523866  92.607  -59.378  54.559  1
523867  92.655  -59.378  54.554  1
523868  92.702  -59.377  54.551  1
523869  92.745  -59.387  54.545  1
523870  92.787  -59.397  54.533  1
523871  92.830  -59.406  54.523  1
523872  92.872  -59.416  54.509  1
523873  92.915  -59.425  54.491  1
523874  92.957  -59.435  54.468  1
523875  92.999  -59.444  54.441  1
523876  93.042  -59.454  54.413  1
523877  93.084  -59.464  54.389  1
523878  93.123  -59.472  54.373  1
523879  93.162  -59.482  54.363  1
523880  93.200  -59.490  54.357  1
523881  93.239  -59.498  54.352  1
523882  93.277  -59.507  54.354  1
523883  93.315  -59.515  54.360  1
523884  93.354  -59.523  54.368  1
523885  93.391  -59.544  54.375  1
523886  93.427  -59.564  54.378  1
523887  93.463  -59.585  54.374  1
523888  93.499  -59.606  54.374  1
523889  93.535  -59.626  54.373  1
523890  93.571  -59.647  54.370  1
523891  93.608  -59.668  54.366  1
523892  93.644  -59.689  54.358  1
523893  93.680  -59.709  54.347  1
523894  93.716  -59.725  54.336  1
523895  93.753  -59.741  54.325  1
523896  93.789  -59.757  54.313  1
523897  93.826  -59.772  54.300  1
523898  93.862  -59.788  54.279  1
523899  93.899  -59.803  54.255  1
523900  93.935  -59.819  54.231  1
523901  93.972  -59.834  54.205  1
523902  94.008  -59.850  54.181  1
523903  94.045  -59.865  54.161  1
523904  94.081  -59.881  54.144  1
523905  94.118  -59.897  54.133  1
523906  94.154  -59.912  54.130  1
523907  94.191  -59.928  54.131  1
523908  94.228  -59.941  54.128  1
523909  94.269  -59.950  54.122  1
523910  94.309  -59.959  54.116  1
523911  94.349  -59.968  54.110  1
523912  94.390  -59.977  54.103  1
523913  94.431  -59.984  54.091  1
523914  94.473  -59.992  54.071  1
523915  94.514  -60.000  54.045  1
523916  94.555  -60.008  54.013  1
523917  94.597  -60.015  53.975  1
523918  94.638  -60.023  53.934  1
523919  94.678  -60.033  53.892  1
523920  94.717  -60.043  53.846  1
523921  94.757  -60.055  53.807  1
523922  94.796  -60.065  53.774  1
523923  94.835  -60.075  53.743  1
523924  94.875  -60.085  53.713  1
523925  94.914  -60.093  53.686  1
523926  94.953  -60.102  53.663  1
523927  94.992  -60.110  53.643  1
523928  95.030  -60.118  53.626  1
523929  95.065  -60.128  53.610  1
523930  95.100  -60.138  53.590  1
523931  95.134  -60.148  53.568  1
523932  95.173  -60.156  53.543  1
523933  95.211  -60.165  53.518  1
523934  95.250  -60.174  53.494  1
523935  95.288  -60.182  53.468  1
523936  95.324  -60.189  53.442  1
523937  95.359  -60.195  53.416  1
523938  95.394  -60.201  53.388  1
523939  95.429  -60.207  53.359  1
523940  95.464  -60.213  53.329  1
523941  95.499  -60.219  53.298  1
523942  95.535  -60.226  53.267  1
523943  95.571  -60.234  53.235  1
523944  95.607  -60.240  53.199  1
523945  95.643  -60.244  53.160  1
523946  95.679  -60.249  53.117  1
523947  95.715  -60.254  53.071  1
523948  95.751  -60.259  53.031  1
523949  95.787  -60.265  52.999  1
523950  95.823  -60.269  52.974  1
523951  95.859  -60.275  52.944  1
523952  95.896  -60.276  52.915  1
523953  95.935  -60.276  52.882  1
523954  95.972  -60.276  52.850  1
523955  96.010  -60.275  52.819  1
523956  96.047  -60.275  52.787  1
523957  96.085  -60.275  52.751  1
523958  96.123  -60.275  52.717  1
523959  96.161  -60.275  52.682  1
523960  96.198  -60.276  52.646  1
523961  96.234  -60.279  52.611  1
523962  96.271  -60.282  52.577  1
523963  96.310  -60.280  52.543  1
523964  96.349  -60.278  52.506  1
523965  96.389  -60.275  52.469  1
523966  96.428  -60.272  52.433  1
523967  96.468  -60.270  52.398  1
523968  96.510  -60.269  52.361  1
523969  96.554  -60.278  52.323  1
523970  96.599  -60.287  52.284  1
523971  96.644  -60.297  52.246  1
523972  96.688  -60.306  52.209  1
523973  96.733  -60.315  52.172  1
523974  96.778  -60.324  52.136  1
523975  96.822  -60.333  52.100  1
523976  96.867  -60.343  52.063  1
523977  96.905  -60.354  52.028  1
523978  96.937  -60.368  51.993  1
523979  96.969  -60.381  51.961  1
523980  97.001  -60.395  51.928  1
523981  97.033  -60.409  51.895  1
523982  97.066  -60.422  51.863  1
523983  97.097  -60.437  51.831  1
523984  97.130  -60.450  51.796  1
523985  97.162  -60.463  51.762  1
523986  97.209  -60.471  51.727  1
523987  97.235  -60.475  51.691  1
523988  97.272  -60.475  51.655  1
523989  97.309  -60.476  51.618  1
523990  97.346  -60.477  51.580  1
523991  97.383  -60.478  51.544  1
523992  97.420  -60.478  51.509  1
523993  97.456  -60.479  51.475  1
523994  97.493  -60.480  51.444  1
523995  97.530  -60.481  51.411  1
523996  97.567  -60.481  51.377  1
523997  97.604  -60.482  51.342  1
523998  97.636  -60.480  51.308  1
523999  97.681  -60.483  51.273  1
524000  97.727  -60.485  51.240  1
524001  97.753  -60.488  51.206  1
524002  97.778  -60.491  51.171  1
524003  97.803  -60.494  51.134  1
524004  97.828  -60.497  51.094  1
524005  97.854  -60.500  51.054  1
524006  97.879  -60.503  51.012  1
524007  97.904  -60.506  50.969  1
524008  97.929  -60.509  50.926  1
524009  97.954  -60.512  50.883  1
524010  97.980  -60.515  50.840  1
524011  98.005  -60.518  50.799  1
524012  98.030  -60.524  50.757  1
524013  98.067  -60.528  50.716  1
524014  98.103  -60.533  50.674  1
524015  98.139  -60.537  50.630  1
524016  98.175  -60.541  50.585  1
524017  98.212  -60.546  50.536  1
524018  98.248  -60.550  50.488  1
524019  98.284  -60.554  50.440  1
524020  98.321  -60.559  50.393  1
524021  98.357  -60.563  50.347  1
524022  98.393  -60.567  50.302  1
524023  98.430  -60.572  50.256  1
524024  98.466  -60.576  50.211  1
524025  98.502  -60.580  50.168  1
524026  98.538  -60.585  50.126  1
524027  98.575  -60.589  50.083  1
524028  98.611  -60.594  50.040  1
524432  87.339  -57.862  57.173  1
524433  87.379  -57.875  57.155  1
524434  87.419  -57.889  57.138  1
524435  87.460  -57.902  57.121  1
524436  87.500  -57.915  57.103  1
524437  87.541  -57.929  57.085  1
524438  87.581  -57.942  57.066  1
524439  87.621  -57.955  57.047  1
524440  87.662  -57.969  57.028  1
524441  87.702  -57.982  57.007  1
524442  87.743  -57.996  56.985  1
524443  87.785  -58.007  56.962  1
524444  87.830  -58.015  56.939  1
524445  87.874  -58.021  56.911  1
524446  87.919  -58.029  56.882  1
524447  87.964  -58.036  56.852  1
524448  88.008  -58.043  56.822  1
524449  88.053  -58.051  56.791  1
524450  88.097  -58.056  56.761  1
524451  88.139  -58.059  56.728  1
524452  88.182  -58.061  56.695  1
524453  88.219  -58.065  56.660  1
524454  88.251  -58.071  56.624  1
524455  88.282  -58.078  56.587  1
524456  88.314  -58.084  56.549  1
524457  88.344  -58.090  56.510  1
524458  88.376  -58.098  56.470  1
524459  88.416  -58.108  56.429  1
524460  88.456  -58.118  56.389  1
524461  88.496  -58.129  56.348  1
524462  88.537  -58.140  56.308  1
524463  88.577  -58.150  56.269  1
524464  88.617  -58.160  56.230  1
524465  88.658  -58.171  56.193  1
524466  88.698  -58.181  56.157  1
524467  88.738  -58.192  56.122  1
524468  88.778  -58.203  56.090  1
524469  88.820  -58.217  56.060  1
524470  88.863  -58.238  56.031  1
524471  88.906  -58.259  56.002  1
524472  88.949  -58.280  55.976  1
524473  88.992  -58.300  55.952  1
524474  89.035  -58.322  55.929  1
524475  89.078  -58.342  55.908  1
524476  89.121  -58.363  55.889  1
524477  89.164  -58.384  55.872  1
524478  89.207  -58.405  55.857  1
524479  89.250  -58.426  55.844  1
524480  89.289  -58.441  55.834  1
524481  89.324  -58.452  55.825  1
524482  89.359  -58.463  55.821  1
524483  89.394  -58.473  55.820  1
524484  89.428  -58.484  55.822  1
524485  89.471  -58.491  55.824  1
524486  89.518  -58.498  55.825  1
524487  89.565  -58.504  55.826  1
524488  89.612  -58.510  55.827  1
524489  89.659  -58.515  55.825  1
524490  89.705  -58.521  55.821  1
524491  89.743  -58.525  55.815  1
524492  89.779  -58.531  55.811  1
524493  89.818  -58.548  55.802  1
524494  89.858  -58.566  55.793  1
524495  89.896  -58.582  55.787  1
524496  89.935  -58.600  55.780  1
524497  89.974  -58.617  55.770  1
524498  90.013  -58.635  55.761  1
524499  90.051  -58.652  55.752  1
524500  90.090  -58.669  55.741  1
524501  90.127  -58.686  55.728  1
524502  90.160  -58.701  55.711  1
524503  90.193  -58.715  55.685  1
524504  90.229  -58.725  55.657  1
524505  90.267  -58.733  55.630  1
524506  90.305  -58.739  55.606  1
524507  90.346  -58.758  55.587  1
524508  90.387  -58.777  55.571  1
524509  90.427  -58.786  55.557  1
524510  90.465  -58.792  55.540  1
524511  90.504  -58.796  55.520  1
524512  90.542  -58.802  55.501  1
524513  90.580  -58.806  55.477  1
524514  90.619  -58.811  55.452  1
524515  90.657  -58.816  55.423  1
524516  90.695  -58.821  55.391  1
524517  90.734  -58.826  55.354  1
524518  90.773  -58.831  55.313  1
524519  90.810  -58.839  55.280  1
524520  90.845  -58.860  55.251  1
524521  90.879  -58.880  55.224  1
524522  90.913  -58.901  55.197  1
524523  90.948  -58.922  55.173  1
524524  90.986  -58.943  55.146  1
524525  91.030  -58.968  55.122  1
524526  91.074  -58.993  55.096  1
524527  91.118  -59.018  55.068  1
524528  91.162  -59.040  55.037  1
524529  91.202  -59.055  55.003  1
524530  91.241  -59.071  54.967  1
524531  91.281  -59.087  54.932  1
524532  91.320  -59.102  54.900  1
524533  91.360  -59.117  54.872  1
524534  91.402  -59.131  54.848  1
524535  91.447  -59.144  54.827  1
524536  91.492  -59.157  54.811  1
524537  91.536  -59.170  54.797  1
524538  91.581  -59.183  54.785  1
524539  91.626  -59.196  54.776  1
524540  91.671  -59.209  54.770  1
524541  91.709  -59.223  54.768  1
524542  91.745  -59.237  54.770  1
524543  91.781  -59.252  54.775  1
524544  91.817  -59.266  54.784  1
524545  91.853  -59.277  54.788  1
524546  91.888  -59.278  54.786  1
524547  91.924  -59.278  54.787  1
524548  91.959  -59.278  54.787  1
524549  91.994  -59.279  54.781  1
524550  92.021  -59.285  54.765  1
524551  92.049  -59.291  54.746  1
524552  92.077  -59.296  54.737  1
524553  92.104  -59.301  54.735  1
524554  92.132  -59.306  54.733  1
524555  92.159  -59.312  54.722  1
524556  92.187  -59.318  54.701  1
524557  92.215  -59.323  54.677  1
524558  92.242  -59.328  54.653  1
524559  92.270  -59.334  54.627  1
524560  92.297  -59.340  54.600  1
524561  92.338  -59.341  54.577  1
524562  92.385  -59.340  54.560  1
524563  92.433  -59.339  54.554  1
524564  92.480  -59.338  54.556  1
524565  92.527  -59.338  54.561  1
524566  92.575  -59.337  54.556  1
524567  92.622  -59.336  54.559  1
524568  92.669  -59.335  54.560  1
524569  92.717  -59.334  54.557  1
524570  92.762  -59.339  54.550  1
524571  92.804  -59.349  54.541  1
524572  92.847  -59.359  54.526  1
524573  92.889  -59.369  54.507  1
524574  92.931  -59.378  54.488  1
524575  92.974  -59.388  54.466  1
524576  93.016  -59.397  54.441  1
524577  93.059  -59.407  54.417  1
524578  93.100  -59.416  54.399  1
524579  93.138  -59.425  54.384  1
524580  93.177  -59.433  54.372  1
524581  93.215  -59.441  54.363  1
524582  93.254  -59.450  54.356  1
524583  93.292  -59.459  54.350  1
524584  93.331  -59.467  54.347  1
524585  93.369  -59.475  54.347  1
524586  93.406  -59.495  54.351  1
524587  93.442  -59.516  54.354  1
524588  93.478  -59.537  54.353  1
524589  93.514  -59.557  54.353  1
524590  93.550  -59.578  54.352  1
524591  93.586  -59.599  54.350  1
524592  93.623  -59.620  54.347  1
524593  93.659  -59.640  54.342  1
524594  93.695  -59.657  54.334  1
524595  93.732  -59.673  54.325  1
524596  93.768  -59.688  54.315  1
524597  93.805  -59.704  54.302  1
524598  93.841  -59.720  54.289  1
524599  93.878  -59.735  54.270  1
524600  93.914  -59.751  54.251  1
524601  93.951  -59.766  54.230  1
524602  93.987  -59.782  54.208  1
524603  94.024  -59.797  54.186  1
524604  94.060  -59.813  54.165  1
524605  94.097  -59.828  54.144  1
524606  94.133  -59.844  54.128  1
524607  94.170  -59.860  54.115  1
524608  94.206  -59.875  54.103  1
524609  94.243  -59.891  54.095  1
524610  94.280  -59.905  54.089  1
524611  94.320  -59.914  54.081  1
524612  94.360  -59.923  54.072  1
524613  94.401  -59.931  54.063  1
524614  94.442  -59.939  54.053  1
524615  94.484  -59.947  54.039  1
524616  94.525  -59.955  54.015  1
524617  94.567  -59.962  53.985  1
524618  94.606  -59.973  53.952  1
524619  94.645  -59.983  53.917  1
524620  94.684  -59.994  53.881  1
524621  94.723  -60.005  53.840  1
524622  94.763  -60.016  53.801  1
524623  94.802  -60.027  53.765  1
524624  94.841  -60.036  53.734  1
524625  94.881  -60.047  53.704  1
524626  94.920  -60.058  53.681  1
524627  94.960  -60.066  53.651  1
524628  94.999  -60.074  53.622  1
524629  95.037  -60.083  53.600  1
524630  95.071  -60.093  53.584  1
524631  95.106  -60.102  53.564  1
524632  95.144  -60.111  53.542  1
524633  95.183  -60.119  53.518  1
524634  95.222  -60.128  53.493  1
524635  95.260  -60.137  53.468  1
524636  95.299  -60.145  53.444  1
524637  95.334  -60.151  53.420  1
524638  95.369  -60.157  53.397  1
524639  95.404  -60.163  53.373  1
524640  95.439  -60.169  53.346  1
524641  95.474  -60.175  53.318  1
524642  95.509  -60.182  53.289  1
524643  95.544  -60.188  53.259  1
524644  95.579  -60.193  53.228  1
524645  95.615  -60.198  53.192  1
524646  95.651  -60.202  53.153  1
524647  95.687  -60.208  53.109  1
524648  95.723  -60.212  53.065  1
524649  95.758  -60.218  53.030  1
524650  95.794  -60.222  53.004  1
524651  95.830  -60.228  52.982  1
524652  95.866  -60.233  52.958  1
524653  95.903  -60.235  52.932  1
524654  95.941  -60.235  52.903  1
524655  95.978  -60.235  52.873  1
524656  96.016  -60.234  52.844  1
524657  96.054  -60.234  52.814  1
524658  96.092  -60.234  52.781  1
524659  96.129  -60.234  52.747  1
524660  96.167  -60.234  52.712  1
524661  96.205  -60.234  52.677  1
524662  96.242  -60.235  52.642  1
524663  96.279  -60.237  52.608  1
524664  96.318  -60.234  52.572  1
524665  96.358  -60.232  52.534  1
524666  96.397  -60.230  52.497  1
524667  96.437  -60.228  52.460  1
524668  96.476  -60.225  52.427  1
524669  96.520  -60.233  52.390  1
524670  96.565  -60.242  52.351  1
524671  96.609  -60.251  52.310  1
524672  96.654  -60.260  52.269  1
524673  96.698  -60.269  52.229  1
524674  96.743  -60.279  52.190  1
524675  96.788  -60.288  52.153  1
524676  96.832  -60.297  52.114  1
524677  96.877  -60.306  52.075  1
524678  96.915  -60.318  52.038  1
524679  96.947  -60.331  52.001  1
524680  96.979  -60.345  51.966  1
524681  97.011  -60.359  51.932  1
524682  97.043  -60.373  51.897  1
524683  97.075  -60.387  51.862  1
524684  97.107  -60.400  51.828  1
524685  97.139  -60.414  51.792  1
524686  97.171  -60.428  51.757  1
524687  97.209  -60.439  51.722  1
524688  97.242  -60.443  51.685  1
524689  97.279  -60.444  51.648  1
524690  97.315  -60.444  51.612  1
524691  97.352  -60.445  51.577  1
524692  97.389  -60.445  51.544  1
524693  97.426  -60.446  51.510  1
524694  97.463  -60.447  51.476  1
524695  97.500  -60.447  51.443  1
524696  97.536  -60.448  51.410  1
524697  97.574  -60.449  51.376  1
524698  97.610  -60.450  51.342  1
524699  97.644  -60.449  51.308  1
524700  97.690  -60.452  51.274  1
524701  97.718  -60.454  51.239  1
524702  97.743  -60.457  51.205  1
524703  97.768  -60.460  51.170  1
524704  97.793  -60.463  51.133  1
524705  97.818  -60.466  51.093  1
524706  97.844  -60.469  51.053  1
524707  97.869  -60.472  51.012  1
524708  97.894  -60.475  50.970  1
524709  97.921  -60.478  50.928  1
524710  97.948  -60.481  50.885  1
524711  97.974  -60.484  50.844  1
524712  98.001  -60.486  50.803  1
524713  98.036  -60.487  50.761  1
524714  98.073  -60.491  50.719  1
524715  98.109  -60.495  50.676  1
524716  98.145  -60.500  50.633  1
524717  98.182  -60.504  50.589  1
524718  98.218  -60.508  50.541  1
524719  98.254  -60.513  50.494  1
524720  98.291  -60.517  50.446  1
524721  98.327  -60.522  50.398  1
524722  98.363  -60.525  50.352  1
524723  98.400  -60.530  50.307  1
524724  98.436  -60.535  50.261  1
524725  98.472  -60.538  50.216  1
524726  98.508  -60.543  50.173  1
524727  98.545  -60.547  50.129  1
524728  98.581  -60.552  50.086  1
524729  98.618  -60.556  50.043  1
525133  87.355  -57.819  57.168  1
525134  87.396  -57.832  57.151  1
525135  87.436  -57.846  57.133  1
525136  87.477  -57.858  57.117  1
525137  87.517  -57.872  57.100  1
525138  87.557  -57.886  57.081  1
525139  87.598  -57.899  57.062  1
525140  87.638  -57.912  57.043  1
525141  87.679  -57.925  57.024  1
525142  87.719  -57.939  57.003  1
525143  87.759  -57.952  56.982  1
525144  87.805  -57.960  56.959  1
525145  87.850  -57.967  56.935  1
525146  87.895  -57.974  56.908  1
525147  87.939  -57.982  56.880  1
525148  87.984  -57.989  56.851  1
525149  88.028  -57.996  56.823  1
525150  88.073  -58.004  56.793  1
525151  88.117  -58.011  56.763  1
525152  88.162  -58.018  56.732  1
525153  88.206  -58.025  56.700  1
525154  88.251  -58.033  56.667  1
525155  88.286  -58.038  56.632  1
525156  88.314  -58.043  56.597  1
525157  88.341  -58.050  56.560  1
525158  88.369  -58.055  56.521  1
525159  88.397  -58.061  56.482  1
525160  88.424  -58.066  56.442  1
525161  88.462  -58.075  56.403  1
525162  88.502  -58.086  56.363  1
525163  88.542  -58.096  56.324  1
525164  88.582  -58.107  56.285  1
525165  88.623  -58.118  56.246  1
525166  88.663  -58.128  56.208  1
525167  88.703  -58.138  56.172  1
525168  88.744  -58.149  56.137  1
525169  88.783  -58.159  56.104  1
525170  88.826  -58.179  56.073  1
525171  88.870  -58.200  56.043  1
525172  88.912  -58.221  56.013  1
525173  88.956  -58.242  55.986  1
525174  88.998  -58.263  55.961  1
525175  89.042  -58.284  55.938  1
525176  89.085  -58.305  55.917  1
525177  89.127  -58.325  55.897  1
525178  89.171  -58.347  55.879  1
525179  89.213  -58.367  55.864  1
525180  89.257  -58.388  55.850  1
525181  89.300  -58.410  55.839  1
525182  89.336  -58.422  55.831  1
525183  89.371  -58.432  55.826  1
525184  89.406  -58.443  55.825  1
525185  89.441  -58.453  55.826  1
525186  89.484  -58.460  55.828  1
525187  89.531  -58.466  55.831  1
525188  89.578  -58.473  55.835  1
525189  89.625  -58.479  55.836  1
525190  89.672  -58.485  55.833  1
525191  89.719  -58.491  55.827  1
525192  89.764  -58.496  55.817  1
525193  89.801  -58.500  55.808  1
525194  89.839  -58.514  55.797  1
525195  89.878  -58.532  55.790  1
525196  89.916  -58.549  55.786  1
525197  89.955  -58.567  55.779  1
525198  89.994  -58.583  55.770  1
525199  90.033  -58.601  55.764  1
525200  90.071  -58.618  55.757  1
525201  90.104  -58.632  55.746  1
525202  90.137  -58.648  55.730  1
525203  90.170  -58.663  55.706  1
525204  90.204  -58.676  55.677  1
525205  90.242  -58.683  55.647  1
525206  90.280  -58.690  55.620  1
525207  90.318  -58.697  55.599  1
525208  90.357  -58.708  55.581  1
525209  90.398  -58.726  55.571  1
525210  90.439  -58.745  55.559  1
525211  90.481  -58.764  55.544  1
525212  90.519  -58.770  55.526  1
525213  90.557  -58.775  55.507  1
525214  90.596  -58.780  55.483  1
525215  90.635  -58.785  55.456  1
525216  90.673  -58.789  55.426  1
525217  90.711  -58.795  55.392  1
525218  90.749  -58.799  55.353  1
525219  90.788  -58.805  55.313  1
525220  90.826  -58.809  55.278  1
525221  90.862  -58.824  55.249  1
525222  90.897  -58.845  55.223  1
525223  90.932  -58.866  55.199  1
525224  90.966  -58.886  55.176  1
525225  91.001  -58.907  55.152  1
525226  91.035  -58.927  55.128  1
525227  91.078  -58.951  55.105  1
525228  91.122  -58.976  55.080  1
525229  91.167  -59.001  55.051  1
525230  91.207  -59.017  55.018  1
525231  91.246  -59.032  54.985  1
525232  91.286  -59.048  54.952  1
525233  91.325  -59.063  54.918  1
525234  91.369  -59.076  54.885  1
525235  91.414  -59.089  54.856  1
525236  91.459  -59.102  54.832  1
525237  91.504  -59.115  54.813  1
525238  91.548  -59.128  54.798  1
525239  91.593  -59.140  54.785  1
525240  91.638  -59.153  54.776  1
525241  91.681  -59.167  54.770  1
525242  91.717  -59.181  54.767  1
525243  91.753  -59.196  54.771  1
525244  91.789  -59.210  54.779  1
525245  91.825  -59.225  54.789  1
525246  91.862  -59.238  54.795  1
525247  91.897  -59.239  54.796  1
525248  91.932  -59.239  54.795  1
525249  91.968  -59.240  54.793  1
525250  92.003  -59.240  54.790  1
525251  92.036  -59.242  54.781  1
525252  92.064  -59.248  54.761  1
525253  92.091  -59.253  54.743  1
525254  92.119  -59.259  54.730  1
525255  92.147  -59.264  54.723  1
525256  92.174  -59.269  54.717  1
525257  92.202  -59.275  54.707  1
525258  92.229  -59.281  54.692  1
525259  92.257  -59.286  54.674  1
525260  92.285  -59.291  54.653  1
525261  92.312  -59.297  54.628  1
525262  92.353  -59.298  54.602  1
525263  92.400  -59.297  54.582  1
525264  92.447  -59.297  54.565  1
525265  92.495  -59.296  54.559  1
525266  92.542  -59.295  54.566  1
525267  92.589  -59.294  54.567  1
525268  92.637  -59.294  54.565  1
525269  92.684  -59.293  54.565  1
525270  92.731  -59.292  54.561  1
525271  92.779  -59.292  54.553  1
525272  92.821  -59.302  54.547  1
525273  92.863  -59.311  54.535  1
525274  92.906  -59.321  54.517  1
525275  92.948  -59.331  54.497  1
525276  92.991  -59.340  54.474  1
525277  93.034  -59.350  54.449  1
525278  93.076  -59.359  54.424  1
525279  93.115  -59.368  54.403  1
525280  93.153  -59.377  54.386  1
525281  93.192  -59.385  54.373  1
525282  93.230  -59.394  54.362  1
525283  93.269  -59.402  54.355  1
525284  93.307  -59.410  54.348  1
525285  93.346  -59.419  54.343  1
525286  93.384  -59.428  54.339  1
525287  93.421  -59.447  54.337  1
525288  93.457  -59.468  54.335  1
525289  93.493  -59.488  54.331  1
525290  93.529  -59.509  54.329  1
525291  93.565  -59.530  54.327  1
525292  93.602  -59.551  54.326  1
525293  93.638  -59.571  54.327  1
525294  93.674  -59.588  54.325  1
525295  93.711  -59.604  54.321  1
525296  93.747  -59.620  54.315  1
525297  93.784  -59.635  54.308  1
525298  93.820  -59.651  54.297  1
525299  93.857  -59.667  54.283  1
525300  93.893  -59.682  54.266  1
525301  93.929  -59.698  54.250  1
525302  93.966  -59.714  54.231  1
525303  94.002  -59.729  54.211  1
525304  94.039  -59.745  54.190  1
525305  94.075  -59.760  54.169  1
525306  94.112  -59.776  54.147  1
525307  94.148  -59.791  54.125  1
525308  94.185  -59.807  54.106  1
525309  94.221  -59.822  54.092  1
525310  94.258  -59.838  54.083  1
525311  94.294  -59.854  54.078  1
525312  94.331  -59.869  54.071  1
525313  94.371  -59.878  54.062  1
525314  94.412  -59.886  54.054  1
525315  94.454  -59.894  54.043  1
525316  94.495  -59.902  54.027  1
525317  94.534  -59.913  54.007  1
525318  94.573  -59.924  53.984  1
525319  94.612  -59.934  53.958  1
525320  94.651  -59.945  53.929  1
525321  94.690  -59.956  53.896  1
525322  94.730  -59.967  53.857  1
525323  94.769  -59.977  53.817  1
525324  94.808  -59.988  53.778  1
525325  94.847  -59.998  53.742  1
525326  94.887  -60.008  53.706  1
525327  94.926  -60.019  53.673  1
525328  94.966  -60.029  53.640  1
525329  95.005  -60.038  53.609  1
525330  95.044  -60.047  53.582  1
525331  95.078  -60.057  53.558  1
525332  95.117  -60.065  53.536  1
525333  95.156  -60.074  53.513  1
525334  95.194  -60.083  53.488  1
525335  95.233  -60.091  53.463  1
525336  95.271  -60.099  53.440  1
525337  95.309  -60.108  53.417  1
525338  95.344  -60.114  53.397  1
525339  95.379  -60.120  53.377  1
525340  95.414  -60.126  53.355  1
525341  95.449  -60.132  53.330  1
525342  95.484  -60.138  53.304  1
525343  95.518  -60.144  53.277  1
525344  95.553  -60.151  53.247  1
525345  95.588  -60.156  53.216  1
525346  95.624  -60.161  53.182  1
525347  95.660  -60.165  53.142  1
525348  95.695  -60.170  53.100  1
525349  95.731  -60.174  53.059  1
525350  95.767  -60.179  53.029  1
525351  95.803  -60.184  53.008  1
525352  95.838  -60.188  52.991  1
525353  95.874  -60.193  52.972  1
525354  95.910  -60.199  52.948  1
525355  95.948  -60.199  52.922  1
525356  95.985  -60.198  52.895  1
525357  96.023  -60.197  52.868  1
525358  96.060  -60.196  52.840  1
525359  96.098  -60.196  52.808  1
525360  96.136  -60.195  52.775  1
525361  96.174  -60.194  52.741  1
525362  96.211  -60.193  52.707  1
525363  96.249  -60.193  52.672  1
525364  96.288  -60.193  52.637  1
525365  96.327  -60.194  52.599  1
525366  96.366  -60.195  52.561  1
525367  96.405  -60.196  52.524  1
525368  96.444  -60.196  52.487  1
525369  96.481  -60.197  52.454  1
525370  96.527  -60.203  52.417  1
525371  96.573  -60.210  52.377  1
525372  96.618  -60.216  52.336  1
525373  96.664  -60.224  52.293  1
525374  96.708  -60.234  52.252  1
525375  96.753  -60.243  52.211  1
525376  96.797  -60.252  52.171  1
525377  96.842  -60.261  52.131  1
525378  96.887  -60.270  52.091  1
525379  96.925  -60.281  52.052  1
525380  96.956  -60.296  52.014  1
525381  96.989  -60.309  51.978  1
525382  97.020  -60.323  51.941  1
525383  97.052  -60.337  51.905  1
525384  97.085  -60.350  51.868  1
525385  97.116  -60.364  51.831  1
525386  97.149  -60.378  51.795  1
525387  97.180  -60.392  51.758  1
525388  97.213  -60.406  51.722  1
525389  97.248  -60.410  51.685  1
525390  97.285  -60.411  51.648  1
525391  97.322  -60.412  51.612  1
525392  97.359  -60.412  51.577  1
525393  97.396  -60.413  51.543  1
525394  97.433  -60.414  51.510  1
525395  97.469  -60.415  51.478  1
525396  97.506  -60.416  51.445  1
525397  97.543  -60.416  51.411  1
525398  97.580  -60.417  51.378  1
525399  97.617  -60.418  51.345  1
525400  97.654  -60.419  51.311  1
525401  97.682  -60.421  51.276  1
525402  97.709  -60.424  51.241  1
525403  97.735  -60.426  51.204  1
525404  97.762  -60.429  51.168  1
525405  97.789  -60.431  51.130  1
525406  97.815  -60.434  51.091  1
525407  97.842  -60.437  51.052  1
525408  97.868  -60.440  51.012  1
525409  97.895  -60.443  50.971  1
525410  97.921  -60.446  50.930  1
525411  97.948  -60.448  50.888  1
525412  97.974  -60.451  50.847  1
525413  98.001  -60.453  50.806  1
525414  98.037  -60.460  50.764  1
525415  98.079  -60.453  50.722  1
525416  98.115  -60.458  50.679  1
525417  98.152  -60.463  50.635  1
525418  98.188  -60.466  50.591  1
525419  98.224  -60.471  50.545  1
525420  98.261  -60.475  50.498  1
525421  98.297  -60.480  50.451  1
525422  98.333  -60.484  50.405  1
525423  98.369  -60.488  50.357  1
525424  98.406  -60.493  50.312  1
525425  98.442  -60.497  50.266  1
525426  98.479  -60.501  50.221  1
525427  98.515  -60.506  50.178  1
525428  98.551  -60.510  50.134  1
525429  98.587  -60.514  50.091  1
525430  98.624  -60.519  50.047  1
525431  98.660  -60.523  50.004  1
525834  87.372  -57.775  57.160  1
525835  87.413  -57.789  57.143  1
525836  87.453  -57.802  57.126  1
525837  87.493  -57.815  57.110  1
525838  87.534  -57.829  57.093  1
525839  87.574  -57.842  57.075  1
525840  87.615  -57.855  57.058  1
525841  87.655  -57.869  57.039  1
525842  87.695  -57.882  57.019  1
525843  87.736  -57.896  56.998  1
525844  87.781  -57.905  56.977  1
525845  87.826  -57.913  56.953  1
525846  87.870  -57.920  56.929  1
525847  87.915  -57.927  56.904  1
525848  87.959  -57.935  56.877  1
525849  88.004  -57.942  56.849  1
525850  88.048  -57.949  56.821  1
525851  88.093  -57.956  56.792  1
525852  88.137  -57.964  56.762  1
525853  88.182  -57.971  56.731  1
525854  88.226  -57.978  56.700  1
525855  88.269  -57.987  56.668  1
525856  88.303  -57.998  56.635  1
525857  88.336  -58.009  56.601  1
525858  88.366  -58.014  56.566  1
525859  88.395  -58.020  56.530  1
525860  88.422  -58.025  56.492  1
525861  88.450  -58.031  56.454  1
525862  88.477  -58.037  56.415  1
525863  88.507  -58.043  56.376  1
525864  88.547  -58.053  56.338  1
525865  88.588  -58.064  56.300  1
525866  88.628  -58.075  56.261  1
525867  88.668  -58.085  56.223  1
525868  88.708  -58.096  56.186  1
525869  88.749  -58.106  56.152  1
525870  88.790  -58.121  56.118  1
525871  88.833  -58.142  56.086  1
525872  88.876  -58.162  56.055  1
525873  88.919  -58.184  56.026  1
525874  88.962  -58.204  55.997  1
525875  89.005  -58.225  55.971  1
525876  89.048  -58.247  55.948  1
525877  89.091  -58.267  55.925  1
525878  89.134  -58.288  55.905  1
525879  89.177  -58.309  55.886  1
525880  89.220  -58.330  55.870  1
525881  89.263  -58.350  55.856  1
525882  89.306  -58.372  55.844  1
525883  89.348  -58.391  55.836  1
525884  89.383  -58.401  55.830  1
525885  89.418  -58.412  55.826  1
525886  89.453  -58.422  55.825  1
525887  89.497  -58.429  55.828  1
525888  89.544  -58.435  55.834  1
525889  89.592  -58.441  55.839  1
525890  89.638  -58.448  55.840  1
525891  89.685  -58.454  55.836  1
525892  89.732  -58.460  55.828  1
525893  89.779  -58.466  55.816  1
525894  89.822  -58.470  55.804  1
525895  89.860  -58.481  55.794  1
525896  89.898  -58.498  55.789  1
525897  89.937  -58.515  55.786  1
525898  89.976  -58.532  55.780  1
525899  90.015  -58.550  55.773  1
525900  90.048  -58.565  55.768  1
525901  90.081  -58.579  55.760  1
525902  90.114  -58.595  55.747  1
525903  90.147  -58.610  55.727  1
525904  90.179  -58.624  55.700  1
525905  90.217  -58.632  55.668  1
525906  90.255  -58.640  55.638  1
525907  90.293  -58.648  55.613  1
525908  90.330  -58.654  55.594  1
525909  90.368  -58.662  55.581  1
525910  90.408  -58.677  55.574  1
525911  90.450  -58.695  55.564  1
525912  90.492  -58.714  55.550  1
525913  90.533  -58.733  55.533  1
525914  90.573  -58.748  55.513  1
525915  90.612  -58.753  55.488  1
525916  90.650  -58.758  55.458  1
525917  90.688  -58.763  55.426  1
525918  90.727  -58.768  55.390  1
525919  90.765  -58.773  55.350  1
525920  90.804  -58.778  55.311  1
525921  90.842  -58.783  55.277  1
525922  90.880  -58.789  55.248  1
525923  90.915  -58.810  55.223  1
525924  90.949  -58.830  55.199  1
525925  90.984  -58.851  55.176  1
525926  91.019  -58.871  55.154  1
525927  91.053  -58.892  55.133  1
525928  91.088  -58.912  55.112  1
525929  91.126  -58.934  55.090  1
525930  91.170  -58.959  55.066  1
525931  91.212  -58.978  55.038  1
525932  91.251  -58.993  55.010  1
525933  91.292  -59.008  54.978  1
525934  91.336  -59.021  54.942  1
525935  91.381  -59.034  54.902  1
525936  91.426  -59.047  54.865  1
525937  91.471  -59.060  54.839  1
525938  91.516  -59.072  54.817  1
525939  91.561  -59.085  54.800  1
525940  91.605  -59.098  54.786  1
525941  91.650  -59.111  54.775  1
525942  91.689  -59.125  54.770  1
525943  91.726  -59.140  54.767  1
525944  91.761  -59.154  54.770  1
525945  91.798  -59.168  54.779  1
525946  91.834  -59.183  54.790  1
525947  91.870  -59.197  54.798  1
525948  91.906  -59.200  54.801  1
525949  91.941  -59.200  54.802  1
525950  91.977  -59.201  54.801  1
525951  92.012  -59.202  54.800  1
525952  92.048  -59.202  54.796  1
525953  92.078  -59.205  54.780  1
525954  92.106  -59.210  54.761  1
525955  92.134  -59.216  54.743  1
525956  92.161  -59.222  54.732  1
525957  92.189  -59.227  54.733  1
525958  92.216  -59.232  54.731  1
525959  92.244  -59.237  54.723  1
525960  92.272  -59.244  54.709  1
525961  92.299  -59.249  54.689  1
525962  92.327  -59.254  54.663  1
525963  92.367  -59.256  54.636  1
525964  92.415  -59.255  54.613  1
525965  92.462  -59.254  54.591  1
525966  92.509  -59.253  54.578  1
525967  92.557  -59.253  54.583  1
525968  92.604  -59.252  54.588  1
525969  92.651  -59.251  54.580  1
525970  92.699  -59.250  54.571  1
525971  92.746  -59.250  54.563  1
525972  92.794  -59.249  54.556  1
525973  92.838  -59.254  54.552  1
525974  92.880  -59.264  54.546  1
525975  92.923  -59.273  54.533  1
525976  92.966  -59.283  54.512  1
525977  93.008  -59.293  54.487  1
525978  93.050  -59.302  54.461  1
525979  93.091  -59.312  54.434  1
525980  93.130  -59.320  54.410  1
525981  93.168  -59.328  54.391  1
525982  93.207  -59.337  54.375  1
525983  93.246  -59.346  54.363  1
525984  93.284  -59.354  54.355  1
525985  93.323  -59.363  54.347  1
525986  93.361  -59.371  54.341  1
525987  93.399  -59.379  54.338  1
525988  93.436  -59.399  54.333  1
525989  93.472  -59.419  54.327  1
525990  93.508  -59.440  54.321  1
525991  93.544  -59.461  54.314  1
525992  93.580  -59.482  54.308  1
525993  93.617  -59.502  54.305  1
525994  93.653  -59.520  54.304  1
525995  93.690  -59.536  54.303  1
525996  93.726  -59.551  54.301  1
525997  93.763  -59.567  54.298  1
525998  93.799  -59.582  54.293  1
525999  93.836  -59.598  54.285  1
526000  93.872  -59.613  54.275  1
526001  93.909  -59.629  54.260  1
526002  93.945  -59.645  54.245  1
526003  93.981  -59.660  54.228  1
526004  94.018  -59.676  54.207  1
526005  94.054  -59.692  54.188  1
526006  94.091  -59.707  54.168  1
526007  94.127  -59.723  54.146  1
526008  94.164  -59.739  54.122  1
526009  94.200  -59.754  54.103  1
526010  94.237  -59.770  54.096  1
526011  94.273  -59.785  54.088  1
526012  94.310  -59.801  54.081  1
526013  94.346  -59.817  54.074  1
526014  94.383  -59.832  54.067  1
526015  94.423  -59.842  54.059  1
526016  94.462  -59.852  54.046  1
526017  94.501  -59.864  54.026  1
526018  94.540  -59.874  54.008  1
526019  94.579  -59.885  53.990  1
526020  94.618  -59.895  53.969  1
526021  94.657  -59.907  53.942  1
526022  94.696  -59.917  53.911  1
526023  94.736  -59.928  53.872  1
526024  94.775  -59.939  53.830  1
526025  94.814  -59.949  53.789  1
526026  94.853  -59.960  53.749  1
526027  94.893  -59.970  53.710  1
526028  94.932  -59.980  53.674  1
526029  94.972  -59.991  53.642  1
526030  95.012  -60.001  53.613  1
526031  95.050  -60.011  53.585  1
526032  95.089  -60.020  53.557  1
526033  95.127  -60.028  53.530  1
526034  95.166  -60.036  53.504  1
526035  95.204  -60.046  53.477  1
526036  95.243  -60.054  53.448  1
526037  95.281  -60.062  53.420  1
526038  95.319  -60.070  53.396  1
526039  95.353  -60.076  53.375  1
526040  95.389  -60.082  53.356  1
526041  95.423  -60.088  53.336  1
526042  95.458  -60.095  53.313  1
526043  95.492  -60.101  53.287  1
526044  95.527  -60.108  53.259  1
526045  95.561  -60.114  53.231  1
526046  95.597  -60.119  53.201  1
526047  95.632  -60.124  53.168  1
526048  95.668  -60.129  53.131  1
526049  95.704  -60.134  53.091  1
526050  95.740  -60.138  53.055  1
526051  95.775  -60.143  53.030  1
526052  95.811  -60.147  53.014  1
526053  95.846  -60.152  53.000  1
526054  95.881  -60.159  52.983  1
526055  95.917  -60.165  52.961  1
526056  95.955  -60.170  52.938  1
526057  95.992  -60.170  52.914  1
526058  96.030  -60.169  52.888  1
526059  96.067  -60.168  52.861  1
526060  96.105  -60.168  52.829  1
526061  96.143  -60.167  52.798  1
526062  96.181  -60.166  52.766  1
526063  96.218  -60.165  52.733  1
526064  96.256  -60.165  52.699  1
526065  96.295  -60.165  52.665  1
526066  96.334  -60.166  52.626  1
526067  96.373  -60.167  52.588  1
526068  96.412  -60.168  52.550  1
526069  96.450  -60.168  52.513  1
526070  96.487  -60.170  52.479  1
526071  96.533  -60.176  52.443  1
526072  96.579  -60.182  52.403  1
526073  96.625  -60.189  52.361  1
526074  96.671  -60.195  52.318  1
526075  96.717  -60.201  52.276  1
526076  96.762  -60.208  52.233  1
526077  96.807  -60.215  52.191  1
526078  96.852  -60.224  52.150  1
526079  96.896  -60.234  52.108  1
526080  96.934  -60.246  52.068  1
526081  96.966  -60.259  52.029  1
526082  96.998  -60.273  51.992  1
526083  97.030  -60.287  51.954  1
526084  97.062  -60.300  51.916  1
526085  97.094  -60.314  51.878  1
526086  97.124  -60.327  51.839  1
526087  97.154  -60.340  51.801  1
526088  97.184  -60.353  51.763  1
526089  97.215  -60.365  51.726  1
526090  97.248  -60.372  51.689  1
526091  97.285  -60.373  51.651  1
526092  97.321  -60.374  51.614  1
526093  97.358  -60.375  51.579  1
526094  97.395  -60.375  51.544  1
526095  97.432  -60.376  51.510  1
526096  97.469  -60.377  51.478  1
526097  97.506  -60.378  51.445  1
526098  97.542  -60.378  51.412  1
526099  97.579  -60.379  51.379  1
526100  97.616  -60.380  51.346  1
526101  97.654  -60.382  51.313  1
526102  97.692  -60.392  51.279  1
526103  97.715  -60.394  51.243  1
526104  97.737  -60.394  51.205  1
526105  97.762  -60.397  51.167  1
526106  97.789  -60.400  51.130  1
526107  97.815  -60.402  51.091  1
526108  97.842  -60.405  51.052  1
526109  97.868  -60.407  51.012  1
526110  97.895  -60.410  50.973  1
526111  97.922  -60.413  50.932  1
526112  97.948  -60.416  50.892  1
526113  97.974  -60.419  50.851  1
526114  98.001  -60.422  50.811  1
526115  98.038  -60.428  50.770  1
526116  98.081  -60.424  50.728  1
526117  98.122  -60.421  50.685  1
526118  98.158  -60.425  50.640  1
526119  98.194  -60.429  50.594  1
526120  98.230  -60.434  50.548  1
526121  98.267  -60.438  50.502  1
526122  98.303  -60.442  50.456  1
526123  98.339  -60.447  50.409  1
526124  98.376  -60.451  50.363  1
526125  98.412  -60.455  50.317  1
526126  98.448  -60.459  50.271  1
526127  98.485  -60.464  50.226  1
526128  98.521  -60.468  50.182  1
526129  98.557  -60.472  50.138  1
526130  98.593  -60.477  50.094  1
526131  98.630  -60.481  50.051  1
526132  98.666  -60.485  50.008  1
526535  87.389  -57.732  57.151  1
526536  87.429  -57.746  57.135  1
526537  87.470  -57.759  57.118  1
526538  87.510  -57.772  57.102  1
526539  87.551  -57.786  57.085  1
526540  87.591  -57.799  57.067  1
526541  87.631  -57.812  57.050  1
526542  87.672  -57.826  57.031  1
526543  87.712  -57.839  57.011  1
526544  87.753  -57.852  56.991  1
526545  87.801  -57.858  56.970  1
526546  87.846  -57.866  56.947  1
526547  87.890  -57.873  56.922  1
526548  87.934  -57.880  56.897  1
526549  87.979  -57.888  56.871  1
526550  88.024  -57.895  56.845  1
526551  88.068  -57.902  56.817  1
526552  88.113  -57.909  56.788  1
526553  88.157  -57.917  56.759  1
526554  88.202  -57.924  56.729  1
526555  88.247  -57.931  56.699  1
526556  88.282  -57.943  56.668  1
526557  88.315  -57.954  56.636  1
526558  88.349  -57.965  56.603  1
526559  88.383  -57.977  56.570  1
526560  88.414  -57.984  56.535  1
526561  88.444  -57.990  56.498  1
526562  88.474  -57.996  56.462  1
526563  88.502  -58.001  56.424  1
526564  88.530  -58.007  56.387  1
526565  88.558  -58.012  56.350  1
526566  88.593  -58.021  56.313  1
526567  88.633  -58.031  56.275  1
526568  88.673  -58.042  56.237  1
526569  88.713  -58.053  56.201  1
526570  88.754  -58.063  56.167  1
526571  88.797  -58.084  56.134  1
526572  88.840  -58.104  56.101  1
526573  88.883  -58.125  56.068  1
526574  88.926  -58.146  56.038  1
526575  88.969  -58.167  56.009  1
526576  89.012  -58.187  55.982  1
526577  89.055  -58.209  55.958  1
526578  89.098  -58.230  55.934  1
526579  89.141  -58.250  55.914  1
526580  89.184  -58.272  55.894  1
526581  89.227  -58.292  55.877  1
526582  89.270  -58.313  55.862  1
526583  89.313  -58.334  55.850  1
526584  89.356  -58.355  55.840  1
526585  89.395  -58.371  55.833  1
526586  89.430  -58.382  55.827  1
526587  89.465  -58.392  55.825  1
526588  89.511  -58.398  55.826  1
526589  89.558  -58.404  55.832  1
526590  89.605  -58.410  55.835  1
526591  89.652  -58.416  55.835  1
526592  89.698  -58.422  55.831  1
526593  89.745  -58.429  55.823  1
526594  89.793  -58.435  55.809  1
526595  89.839  -58.441  55.799  1
526596  89.880  -58.447  55.793  1
526597  89.919  -58.464  55.790  1
526598  89.958  -58.482  55.786  1
526599  89.992  -58.497  55.781  1
526600  90.025  -58.512  55.776  1
526601  90.058  -58.527  55.770  1
526602  90.091  -58.542  55.759  1
526603  90.124  -58.557  55.743  1
526604  90.157  -58.572  55.720  1
526605  90.191  -58.583  55.692  1
526606  90.230  -58.590  55.660  1
526607  90.267  -58.598  55.631  1
526608  90.305  -58.605  55.610  1
526609  90.343  -58.612  55.594  1
526610  90.381  -58.620  55.584  1
526611  90.419  -58.627  55.576  1
526612  90.460  -58.645  55.566  1
526613  90.502  -58.664  55.554  1
526614  90.543  -58.683  55.538  1
526615  90.585  -58.702  55.518  1
526616  90.626  -58.720  55.490  1
526617  90.666  -58.732  55.458  1
526618  90.704  -58.736  55.422  1
526619  90.742  -58.742  55.383  1
526620  90.781  -58.746  55.344  1
526621  90.819  -58.751  55.307  1
526622  90.858  -58.756  55.277  1
526623  90.896  -58.761  55.249  1
526624  90.933  -58.774  55.224  1
526625  90.967  -58.795  55.202  1
526626  91.002  -58.815  55.178  1
526627  91.036  -58.836  55.158  1
526628  91.071  -58.856  55.139  1
526629  91.105  -58.877  55.120  1
526630  91.140  -58.897  55.102  1
526631  91.175  -58.918  55.081  1
526632  91.217  -58.939  55.054  1
526633  91.259  -58.953  55.026  1
526634  91.304  -58.966  54.995  1
526635  91.349  -58.979  54.959  1
526636  91.393  -58.992  54.919  1
526637  91.438  -59.005  54.879  1
526638  91.483  -59.018  54.848  1
526639  91.528  -59.030  54.823  1
526640  91.573  -59.043  54.804  1
526641  91.618  -59.056  54.790  1
526642  91.662  -59.069  54.777  1
526643  91.698  -59.084  54.770  1
526644  91.734  -59.098  54.765  1
526645  91.770  -59.112  54.766  1
526646  91.806  -59.127  54.774  1
526647  91.842  -59.141  54.789  1
526648  91.878  -59.156  54.796  1
526649  91.914  -59.162  54.801  1
526650  91.949  -59.162  54.805  1
526651  91.985  -59.162  54.808  1
526652  92.020  -59.162  54.810  1
526653  92.056  -59.163  54.808  1
526654  92.091  -59.164  54.799  1
526655  92.121  -59.168  54.784  1
526656  92.148  -59.173  54.765  1
526657  92.176  -59.179  54.749  1
526658  92.204  -59.184  54.746  1
526659  92.231  -59.190  54.745  1
526660  92.259  -59.195  54.739  1
526661  92.286  -59.200  54.729  1
526662  92.314  -59.206  54.714  1
526663  92.342  -59.212  54.694  1
526664  92.382  -59.213  54.669  1
526665  92.429  -59.212  54.645  1
526666  92.477  -59.211  54.623  1
526667  92.524  -59.210  54.605  1
526668  92.571  -59.209  54.591  1
526669  92.619  -59.209  54.590  1
526670  92.666  -59.208  54.581  1
526671  92.714  -59.207  54.569  1
526672  92.761  -59.206  54.562  1
526673  92.808  -59.206  54.563  1
526674  92.855  -59.206  54.566  1
526675  92.898  -59.216  54.561  1
526676  92.940  -59.226  54.548  1
526677  92.982  -59.235  54.529  1
526678  93.025  -59.245  54.506  1
526679  93.067  -59.255  54.479  1
526680  93.107  -59.263  54.449  1
526681  93.145  -59.272  54.423  1
526682  93.184  -59.281  54.400  1
526683  93.222  -59.289  54.381  1
526684  93.261  -59.297  54.366  1
526685  93.299  -59.306  54.356  1
526686  93.337  -59.315  54.347  1
526687  93.376  -59.323  54.341  1
526688  93.414  -59.331  54.338  1
526689  93.451  -59.350  54.332  1
526690  93.487  -59.371  54.325  1
526691  93.523  -59.392  54.315  1
526692  93.559  -59.413  54.303  1
526693  93.595  -59.433  54.294  1
526694  93.632  -59.452  54.288  1
526695  93.669  -59.468  54.284  1
526696  93.705  -59.483  54.281  1
526697  93.742  -59.499  54.280  1
526698  93.778  -59.514  54.277  1
526699  93.815  -59.530  54.273  1
526700  93.851  -59.545  54.267  1
526701  93.888  -59.561  54.258  1
526702  93.924  -59.576  54.245  1
526703  93.960  -59.592  54.230  1
526704  93.997  -59.607  54.212  1
526705  94.033  -59.623  54.192  1
526706  94.070  -59.639  54.172  1
526707  94.106  -59.654  54.154  1
526708  94.143  -59.670  54.135  1
526709  94.179  -59.685  54.115  1
526710  94.216  -59.701  54.099  1
526711  94.252  -59.717  54.089  1
526712  94.289  -59.732  54.083  1
526713  94.324  -59.751  54.077  1
526714  94.359  -59.772  54.074  1
526715  94.394  -59.792  54.069  1
526716  94.429  -59.804  54.061  1
526717  94.468  -59.814  54.050  1
526718  94.507  -59.825  54.033  1
526719  94.546  -59.836  54.016  1
526720  94.585  -59.847  53.998  1
526721  94.624  -59.858  53.976  1
526722  94.664  -59.868  53.950  1
526723  94.702  -59.879  53.919  1
526724  94.742  -59.890  53.881  1
526725  94.781  -59.901  53.841  1
526726  94.820  -59.911  53.798  1
526727  94.860  -59.921  53.755  1
526728  94.899  -59.931  53.715  1
526729  94.938  -59.942  53.680  1
526730  94.978  -59.952  53.651  1
526731  95.019  -59.962  53.624  1
526732  95.059  -59.973  53.596  1
526733  95.098  -59.982  53.565  1
526734  95.137  -59.991  53.535  1
526735  95.177  -60.000  53.506  1
526736  95.215  -60.008  53.476  1
526737  95.254  -60.017  53.443  1
526738  95.293  -60.026  53.411  1
526739  95.328  -60.032  53.383  1
526740  95.363  -60.038  53.360  1
526741  95.398  -60.045  53.339  1
526742  95.432  -60.052  53.319  1
526743  95.467  -60.058  53.296  1
526744  95.501  -60.065  53.270  1
526745  95.536  -60.071  53.241  1
526746  95.570  -60.077  53.212  1
526747  95.605  -60.083  53.183  1
526748  95.641  -60.087  53.153  1
526749  95.677  -60.092  53.118  1
526750  95.712  -60.096  53.082  1
526751  95.749  -60.101  53.054  1
526752  95.784  -60.105  53.035  1
526753  95.819  -60.112  53.022  1
526754  95.853  -60.118  53.012  1
526755  95.888  -60.125  52.995  1
526756  95.924  -60.131  52.975  1
526757  95.962  -60.136  52.953  1
526758  96.000  -60.141  52.930  1
526759  96.037  -60.141  52.905  1
526760  96.075  -60.140  52.878  1
526761  96.112  -60.140  52.848  1
526762  96.150  -60.139  52.818  1
526763  96.188  -60.138  52.785  1
526764  96.226  -60.137  52.752  1
526765  96.263  -60.137  52.718  1
526766  96.303  -60.137  52.684  1
526767  96.341  -60.139  52.647  1
526768  96.381  -60.140  52.610  1
526769  96.418  -60.140  52.573  1
526770  96.454  -60.140  52.538  1
526771  96.494  -60.142  52.503  1
526772  96.540  -60.149  52.466  1
526773  96.586  -60.155  52.426  1
526774  96.631  -60.161  52.385  1
526775  96.677  -60.168  52.344  1
526776  96.723  -60.174  52.302  1
526777  96.768  -60.181  52.259  1
526778  96.814  -60.187  52.216  1
526779  96.860  -60.193  52.172  1
526780  96.906  -60.199  52.129  1
526781  96.942  -60.209  52.088  1
526782  96.972  -60.221  52.048  1
526783  97.002  -60.234  52.009  1
526784  97.032  -60.247  51.970  1
526785  97.063  -60.260  51.931  1
526786  97.093  -60.272  51.891  1
526787  97.123  -60.285  51.852  1
526788  97.153  -60.298  51.812  1
526789  97.183  -60.311  51.773  1
526790  97.214  -60.324  51.734  1
526791  97.246  -60.334  51.696  1
526792  97.283  -60.334  51.657  1
526793  97.319  -60.335  51.619  1
526794  97.356  -60.336  51.582  1
526795  97.393  -60.337  51.546  1
526796  97.430  -60.337  51.511  1
526797  97.466  -60.337  51.478  1
526798  97.503  -60.338  51.445  1
526799  97.540  -60.339  51.412  1
526800  97.577  -60.340  51.379  1
526801  97.614  -60.340  51.346  1
526802  97.653  -60.347  51.314  1
526803  97.694  -60.358  51.282  1
526804  97.731  -60.368  51.245  1
526805  97.754  -60.369  51.206  1
526806  97.776  -60.369  51.168  1
526807  97.799  -60.371  51.130  1
526808  97.821  -60.372  51.092  1
526809  97.844  -60.373  51.053  1
526810  97.868  -60.375  51.014  1
526811  97.895  -60.378  50.975  1
526812  97.922  -60.381  50.935  1
526813  97.948  -60.383  50.896  1
526814  97.974  -60.386  50.856  1
526815  98.001  -60.389  50.818  1
526816  98.040  -60.397  50.777  1
526817  98.080  -60.402  50.735  1
526818  98.127  -60.385  50.692  1
526819  98.164  -60.387  50.646  1
526820  98.200  -60.392  50.599  1
526821  98.237  -60.397  50.551  1
526822  98.273  -60.400  50.506  1
526823  98.309  -60.405  50.460  1
526824  98.346  -60.409  50.414  1
526825  98.382  -60.413  50.368  1
526826  98.418  -60.418  50.322  1
526827  98.454  -60.422  50.276  1
526828  98.491  -60.426  50.231  1
526829  98.527  -60.431  50.187  1
526830  98.563  -60.435  50.143  1
526831  98.599  -60.440  50.099  1
526832  98.636  -60.444  50.055  1
526833  98.672  -60.448  50.012  1
526834  98.709  -60.453  49.969  1
527237  87.446  -57.702  57.126  1
527238  87.487  -57.715  57.109  1
527239  87.527  -57.729  57.093  1
527240  87.567  -57.742  57.077  1
527241  87.608  -57.755  57.058  1
527242  87.648  -57.769  57.041  1
527243  87.689  -57.782  57.022  1
527244  87.729  -57.796  57.003  1
527245  87.776  -57.804  56.982  1
527246  87.821  -57.811  56.961  1
527247  87.865  -57.819  56.938  1
527248  87.910  -57.826  56.915  1
527249  87.955  -57.833  56.890  1
527250  87.999  -57.840  56.864  1
527251  88.044  -57.848  56.837  1
527252  88.088  -57.855  56.811  1
527253  88.133  -57.862  56.783  1
527254  88.178  -57.870  56.755  1
527255  88.222  -57.877  56.726  1
527256  88.260  -57.887  56.697  1
527257  88.294  -57.899  56.667  1
527258  88.328  -57.910  56.635  1
527259  88.361  -57.921  56.603  1
527260  88.395  -57.933  56.571  1
527261  88.428  -57.944  56.537  1
527262  88.462  -57.955  56.502  1
527263  88.492  -57.961  56.468  1
527264  88.522  -57.966  56.431  1
527265  88.552  -57.971  56.396  1
527266  88.582  -57.977  56.360  1
527267  88.611  -57.983  56.324  1
527268  88.638  -57.989  56.288  1
527269  88.678  -57.999  56.251  1
527270  88.718  -58.009  56.215  1
527271  88.760  -58.024  56.181  1
527272  88.803  -58.046  56.148  1
527273  88.846  -58.067  56.114  1
527274  88.889  -58.087  56.082  1
527275  88.932  -58.109  56.051  1
527276  88.975  -58.129  56.021  1
527277  89.018  -58.150  55.993  1
527278  89.061  -58.171  55.967  1
527279  89.104  -58.192  55.944  1
527280  89.147  -58.213  55.923  1
527281  89.190  -58.234  55.902  1
527282  89.234  -58.255  55.884  1
527283  89.276  -58.275  55.868  1
527284  89.319  -58.297  55.856  1
527285  89.363  -58.317  55.845  1
527286  89.405  -58.338  55.836  1
527287  89.442  -58.351  55.829  1
527288  89.477  -58.361  55.826  1
527289  89.524  -58.367  55.827  1
527290  89.571  -58.373  55.829  1
527291  89.618  -58.379  55.829  1
527292  89.665  -58.385  55.827  1
527293  89.712  -58.391  55.821  1
527294  89.759  -58.397  55.813  1
527295  89.806  -58.404  55.803  1
527296  89.852  -58.410  55.796  1
527297  89.899  -58.416  55.793  1
527298  89.937  -58.429  55.790  1
527299  89.969  -58.444  55.785  1
527300  90.002  -58.459  55.782  1
527301  90.035  -58.474  55.776  1
527302  90.068  -58.488  55.767  1
527303  90.101  -58.504  55.753  1
527304  90.133  -58.519  55.734  1
527305  90.167  -58.533  55.710  1
527306  90.204  -58.541  55.682  1
527307  90.242  -58.548  55.652  1
527308  90.280  -58.555  55.626  1
527309  90.318  -58.563  55.607  1
527310  90.356  -58.570  55.595  1
527311  90.394  -58.577  55.589  1
527312  90.432  -58.585  55.580  1
527313  90.471  -58.596  55.570  1
527314  90.512  -58.614  55.556  1
527315  90.554  -58.633  55.538  1
527316  90.595  -58.652  55.516  1
527317  90.637  -58.670  55.486  1
527318  90.678  -58.689  55.450  1
527319  90.719  -58.708  55.411  1
527320  90.758  -58.715  55.374  1
527321  90.797  -58.720  55.341  1
527322  90.835  -58.725  55.313  1
527323  90.873  -58.730  55.287  1
527324  90.911  -58.735  55.261  1
527325  90.950  -58.739  55.238  1
527326  90.985  -58.759  55.216  1
527327  91.019  -58.780  55.190  1
527328  91.054  -58.800  55.165  1
527329  91.089  -58.820  55.144  1
527330  91.123  -58.841  55.129  1
527331  91.158  -58.861  55.115  1
527332  91.192  -58.882  55.095  1
527333  91.229  -58.898  55.068  1
527334  91.271  -58.911  55.038  1
527335  91.316  -58.924  55.004  1
527336  91.361  -58.936  54.968  1
527337  91.406  -58.949  54.930  1
527338  91.451  -58.962  54.889  1
527339  91.496  -58.975  54.857  1
527340  91.540  -58.988  54.832  1
527341  91.585  -59.001  54.811  1
527342  91.630  -59.014  54.795  1
527343  91.670  -59.027  54.780  1
527344  91.706  -59.042  54.770  1
527345  91.742  -59.056  54.764  1
527346  91.779  -59.071  54.762  1
527347  91.814  -59.085  54.765  1
527348  91.851  -59.099  54.776  1
527349  91.887  -59.114  54.786  1
527350  91.923  -59.123  54.793  1
527351  91.958  -59.123  54.796  1
527352  91.994  -59.124  54.798  1
527353  92.029  -59.124  54.803  1
527354  92.064  -59.124  54.808  1
527355  92.100  -59.125  54.811  1
527356  92.135  -59.125  54.806  1
527357  92.163  -59.131  54.792  1
527358  92.191  -59.136  54.772  1
527359  92.218  -59.141  54.754  1
527360  92.246  -59.147  54.746  1
527361  92.274  -59.153  54.742  1
527362  92.301  -59.158  54.737  1
527363  92.329  -59.163  54.730  1
527364  92.356  -59.168  54.720  1
527365  92.397  -59.170  54.701  1
527366  92.444  -59.169  54.677  1
527367  92.491  -59.168  54.656  1
527368  92.538  -59.168  54.635  1
527369  92.586  -59.167  54.609  1
527370  92.633  -59.166  54.603  1
527371  92.681  -59.165  54.593  1
527372  92.728  -59.165  54.581  1
527373  92.776  -59.164  54.572  1
527374  92.823  -59.163  54.567  1
527375  92.870  -59.162  54.564  1
527376  92.914  -59.168  54.562  1
527377  92.957  -59.178  54.553  1
527378  92.999  -59.188  54.536  1
527379  93.042  -59.197  54.513  1
527380  93.083  -59.207  54.486  1
527381  93.122  -59.215  54.455  1
527382  93.160  -59.224  54.429  1
527383  93.199  -59.232  54.406  1
527384  93.237  -59.241  54.387  1
527385  93.276  -59.250  54.372  1
527386  93.314  -59.258  54.359  1
527387  93.352  -59.266  54.349  1
527388  93.391  -59.275  54.341  1
527389  93.429  -59.284  54.334  1
527390  93.466  -59.302  54.328  1
527391  93.502  -59.323  54.323  1
527392  93.538  -59.344  54.312  1
527393  93.574  -59.364  54.298  1
527394  93.611  -59.384  54.285  1
527395  93.647  -59.399  54.275  1
527396  93.684  -59.415  54.265  1
527397  93.720  -59.430  54.261  1
527398  93.757  -59.446  54.258  1
527399  93.793  -59.462  54.254  1
527400  93.830  -59.477  54.250  1
527401  93.866  -59.493  54.244  1
527402  93.903  -59.508  54.234  1
527403  93.939  -59.524  54.223  1
527404  93.976  -59.539  54.208  1
527405  94.012  -59.555  54.191  1
527406  94.049  -59.570  54.172  1
527407  94.085  -59.586  54.154  1
527408  94.122  -59.602  54.136  1
527409  94.158  -59.617  54.118  1
527410  94.194  -59.636  54.101  1
527411  94.228  -59.656  54.087  1
527412  94.264  -59.676  54.076  1
527413  94.298  -59.697  54.070  1
527414  94.334  -59.717  54.065  1
527415  94.368  -59.737  54.063  1
527416  94.404  -59.757  54.060  1
527417  94.437  -59.766  54.053  1
527418  94.475  -59.776  54.045  1
527419  94.513  -59.786  54.030  1
527420  94.552  -59.798  54.014  1
527421  94.591  -59.808  53.996  1
527422  94.630  -59.819  53.973  1
527423  94.670  -59.830  53.946  1
527424  94.708  -59.841  53.914  1
527425  94.748  -59.851  53.876  1
527426  94.787  -59.862  53.836  1
527427  94.826  -59.872  53.795  1
527428  94.866  -59.883  53.754  1
527429  94.905  -59.893  53.715  1
527430  94.946  -59.903  53.684  1
527431  94.986  -59.914  53.657  1
527432  95.027  -59.924  53.630  1
527433  95.067  -59.935  53.603  1
527434  95.107  -59.944  53.576  1
527435  95.146  -59.953  53.549  1
527436  95.185  -59.962  53.520  1
527437  95.225  -59.971  53.488  1
527438  95.264  -59.980  53.454  1
527439  95.303  -59.989  53.419  1
527440  95.338  -59.995  53.383  1
527441  95.372  -60.002  53.351  1
527442  95.406  -60.008  53.325  1
527443  95.441  -60.014  53.302  1
527444  95.475  -60.021  53.279  1
527445  95.510  -60.027  53.252  1
527446  95.544  -60.034  53.224  1
527447  95.579  -60.040  53.194  1
527448  95.614  -60.046  53.165  1
527449  95.650  -60.050  53.137  1
527450  95.686  -60.055  53.105  1
527451  95.722  -60.059  53.076  1
527452  95.757  -60.065  53.055  1
527453  95.792  -60.071  53.042  1
527454  95.826  -60.078  53.032  1
527455  95.861  -60.085  53.024  1
527456  95.895  -60.091  53.008  1
527457  95.931  -60.097  52.990  1
527458  95.969  -60.102  52.969  1
527459  96.007  -60.107  52.946  1
527460  96.044  -60.112  52.921  1
527461  96.082  -60.112  52.894  1
527462  96.119  -60.112  52.865  1
527463  96.157  -60.111  52.834  1
527464  96.195  -60.110  52.800  1
527465  96.233  -60.109  52.766  1
527466  96.271  -60.109  52.734  1
527467  96.310  -60.110  52.702  1
527468  96.349  -60.111  52.667  1
527469  96.387  -60.112  52.632  1
527470  96.423  -60.112  52.598  1
527471  96.459  -60.112  52.563  1
527472  96.501  -60.115  52.528  1
527473  96.546  -60.121  52.491  1
527474  96.592  -60.127  52.452  1
527475  96.638  -60.134  52.411  1
527476  96.683  -60.140  52.370  1
527477  96.729  -60.146  52.327  1
527478  96.775  -60.152  52.283  1
527479  96.821  -60.159  52.239  1
527480  96.867  -60.165  52.196  1
527481  96.907  -60.168  52.153  1
527482  96.940  -60.169  52.111  1
527483  96.971  -60.180  52.070  1
527484  97.002  -60.193  52.031  1
527485  97.032  -60.206  51.992  1
527486  97.062  -60.218  51.952  1
527487  97.092  -60.231  51.911  1
527488  97.122  -60.243  51.870  1
527489  97.153  -60.256  51.829  1
527490  97.183  -60.269  51.788  1
527491  97.213  -60.282  51.747  1
527492  97.243  -60.295  51.707  1
527493  97.280  -60.295  51.667  1
527494  97.317  -60.296  51.628  1
527495  97.354  -60.297  51.590  1
527496  97.391  -60.297  51.553  1
527497  97.428  -60.298  51.517  1
527498  97.464  -60.299  51.482  1
527499  97.501  -60.300  51.449  1
527500  97.538  -60.300  51.415  1
527501  97.575  -60.301  51.381  1
527502  97.611  -60.302  51.348  1
527503  97.652  -60.312  51.315  1
527504  97.693  -60.323  51.281  1
527505  97.734  -60.334  51.245  1
527506  97.771  -60.343  51.208  1
527507  97.793  -60.343  51.171  1
527508  97.815  -60.345  51.134  1
527509  97.838  -60.346  51.096  1
527510  97.860  -60.347  51.058  1
527511  97.882  -60.348  51.018  1
527512  97.905  -60.349  50.979  1
527513  97.927  -60.350  50.939  1
527514  97.950  -60.351  50.901  1
527515  97.975  -60.353  50.862  1
527516  98.002  -60.356  50.823  1
527517  98.041  -60.365  50.783  1
527518  98.081  -60.373  50.742  1
527519  98.126  -60.363  50.699  1
527520  98.170  -60.350  50.654  1
527521  98.207  -60.354  50.607  1
527522  98.243  -60.359  50.558  1
527523  98.279  -60.363  50.511  1
527524  98.315  -60.368  50.466  1
527525  98.352  -60.372  50.420  1
527526  98.388  -60.376  50.373  1
527527  98.424  -60.381  50.328  1
527528  98.460  -60.384  50.282  1
527529  98.497  -60.389  50.236  1
527530  98.533  -60.394  50.192  1
527531  98.570  -60.398  50.148  1
527532  98.606  -60.402  50.104  1
527533  98.642  -60.406  50.060  1
527534  98.678  -60.411  50.016  1
527535  98.715  -60.415  49.973  1
527940  87.544  -57.686  57.083  1
527941  87.584  -57.699  57.067  1
527942  87.625  -57.712  57.049  1
527943  87.665  -57.726  57.031  1
527944  87.706  -57.739  57.013  1
527945  87.748  -57.752  56.993  1
527946  87.796  -57.757  56.972  1
527947  87.841  -57.764  56.951  1
527948  87.886  -57.772  56.928  1
527949  87.930  -57.779  56.905  1
527950  87.975  -57.786  56.881  1
527951  88.020  -57.793  56.855  1
527952  88.064  -57.801  56.829  1
527953  88.109  -57.808  56.803  1
527954  88.153  -57.815  56.775  1
527955  88.198  -57.823  56.747  1
527956  88.239  -57.831  56.719  1
527957  88.272  -57.843  56.690  1
527958  88.306  -57.855  56.660  1
527959  88.340  -57.866  56.630  1
527960  88.374  -57.877  56.600  1
527961  88.407  -57.889  56.569  1
527962  88.441  -57.900  56.537  1
527963  88.475  -57.912  56.505  1
527964  88.508  -57.924  56.471  1
527965  88.540  -57.931  56.437  1
527966  88.570  -57.937  56.403  1
527967  88.600  -57.943  56.368  1
527968  88.630  -57.948  56.333  1
527969  88.661  -57.953  56.299  1
527970  88.690  -57.959  56.263  1
527971  88.724  -57.967  56.228  1
527972  88.767  -57.987  56.194  1
527973  88.810  -58.008  56.161  1
527974  88.853  -58.029  56.128  1
527975  88.896  -58.050  56.096  1
527976  88.939  -58.071  56.064  1
527977  88.982  -58.092  56.033  1
527978  89.025  -58.112  56.004  1
527979  89.068  -58.134  55.977  1
527980  89.111  -58.154  55.953  1
527981  89.154  -58.175  55.931  1
527982  89.197  -58.196  55.910  1
527983  89.240  -58.217  55.891  1
527984  89.283  -58.238  55.873  1
527985  89.326  -58.259  55.861  1
527986  89.369  -58.280  55.850  1
527987  89.412  -58.300  55.840  1
527988  89.454  -58.320  55.833  1
527989  89.490  -58.331  55.829  1
527990  89.537  -58.337  55.829  1
527991  89.585  -58.342  55.827  1
527992  89.631  -58.348  55.823  1
527993  89.678  -58.354  55.818  1
527994  89.725  -58.360  55.812  1
527995  89.771  -58.366  55.805  1
527996  89.816  -58.370  55.798  1
527997  89.862  -58.375  55.794  1
527998  89.907  -58.379  55.791  1
527999  89.947  -58.389  55.789  1
528000  89.979  -58.406  55.785  1
528001  90.012  -58.421  55.781  1
528002  90.045  -58.436  55.772  1
528003  90.078  -58.451  55.760  1
528004  90.110  -58.466  55.743  1
528005  90.144  -58.481  55.721  1
528006  90.179  -58.491  55.696  1
528007  90.217  -58.498  55.669  1
528008  90.255  -58.505  55.643  1
528009  90.293  -58.513  55.621  1
528010  90.331  -58.520  55.606  1
528011  90.369  -58.527  55.598  1
528012  90.406  -58.535  55.594  1
528013  90.445  -58.542  55.585  1
528014  90.482  -58.549  55.573  1
528015  90.523  -58.565  55.557  1
528016  90.564  -58.583  55.536  1
528017  90.606  -58.602  55.510  1
528018  90.647  -58.621  55.478  1
528019  90.688  -58.639  55.440  1
528020  90.730  -58.658  55.402  1
528021  90.771  -58.677  55.371  1
528022  90.812  -58.693  55.346  1
528023  90.851  -58.698  55.322  1
528024  90.889  -58.703  55.298  1
528025  90.927  -58.708  55.273  1
528026  90.965  -58.713  55.248  1
528027  91.003  -58.723  55.226  1
528028  91.037  -58.744  55.202  1
528029  91.072  -58.764  55.175  1
528030  91.106  -58.785  55.152  1
528031  91.141  -58.805  55.134  1
528032  91.176  -58.826  55.120  1
528033  91.212  -58.843  55.100  1
528034  91.249  -58.856  55.074  1
528035  91.287  -58.869  55.039  1
528036  91.328  -58.881  55.002  1
528037  91.373  -58.894  54.964  1
528038  91.418  -58.907  54.928  1
528039  91.463  -58.920  54.892  1
528040  91.508  -58.933  54.865  1
528041  91.553  -58.946  54.841  1
528042  91.597  -58.958  54.819  1
528043  91.642  -58.971  54.801  1
528044  91.678  -58.986  54.785  1
528045  91.715  -59.000  54.773  1
528046  91.750  -59.015  54.764  1
528047  91.787  -59.029  54.758  1
528048  91.823  -59.043  54.757  1
528049  91.859  -59.058  54.762  1
528050  91.895  -59.072  54.772  1
528051  91.931  -59.084  54.778  1
528052  91.966  -59.084  54.783  1
528053  92.002  -59.085  54.789  1
528054  92.037  -59.085  54.798  1
528055  92.073  -59.086  54.807  1
528056  92.108  -59.086  54.812  1
528057  92.144  -59.087  54.811  1
528058  92.178  -59.088  54.804  1
528059  92.206  -59.093  54.791  1
528060  92.233  -59.099  54.775  1
528061  92.261  -59.104  54.766  1
528062  92.288  -59.110  54.760  1
528063  92.316  -59.115  54.754  1
528064  92.344  -59.121  54.748  1
528065  92.371  -59.126  54.739  1
528066  92.411  -59.128  54.725  1
528067  92.458  -59.127  54.706  1
528068  92.506  -59.126  54.685  1
528069  92.553  -59.125  54.664  1
528070  92.600  -59.124  54.647  1
528071  92.648  -59.124  54.634  1
528072  92.696  -59.123  54.621  1
528073  92.743  -59.122  54.608  1
528074  92.790  -59.121  54.593  1
528075  92.838  -59.121  54.571  1
528076  92.885  -59.120  54.558  1
528077  92.931  -59.121  54.557  1
528078  92.974  -59.131  54.550  1
528079  93.016  -59.140  54.534  1
528080  93.059  -59.150  54.512  1
528081  93.098  -59.159  54.484  1
528082  93.137  -59.168  54.456  1
528083  93.175  -59.176  54.432  1
528084  93.214  -59.184  54.411  1
528085  93.252  -59.193  54.392  1
528086  93.290  -59.201  54.377  1
528087  93.329  -59.210  54.364  1
528088  93.367  -59.218  54.353  1
528089  93.406  -59.227  54.342  1
528090  93.444  -59.235  54.333  1
528091  93.481  -59.254  54.325  1
528092  93.517  -59.275  54.317  1
528093  93.553  -59.295  54.306  1
528094  93.589  -59.316  54.292  1
528095  93.626  -59.331  54.277  1
528096  93.662  -59.347  54.265  1
528097  93.699  -59.362  54.253  1
528098  93.735  -59.378  54.244  1
528099  93.772  -59.393  54.237  1
528100  93.808  -59.409  54.229  1
528101  93.845  -59.425  54.222  1
528102  93.882  -59.440  54.215  1
528103  93.918  -59.456  54.206  1
528104  93.955  -59.471  54.193  1
528105  93.991  -59.487  54.178  1
528106  94.028  -59.502  54.163  1
528107  94.063  -59.520  54.150  1
528108  94.098  -59.541  54.132  1
528109  94.133  -59.561  54.113  1
528110  94.168  -59.581  54.096  1
528111  94.203  -59.601  54.082  1
528112  94.238  -59.622  54.069  1
528113  94.273  -59.642  54.057  1
528114  94.308  -59.662  54.050  1
528115  94.343  -59.682  54.047  1
528116  94.378  -59.703  54.045  1
528117  94.413  -59.723  54.043  1
528118  94.447  -59.729  54.037  1
528119  94.483  -59.738  54.031  1
528120  94.521  -59.748  54.019  1
528121  94.559  -59.759  54.004  1
528122  94.598  -59.770  53.985  1
528123  94.636  -59.781  53.961  1
528124  94.676  -59.792  53.934  1
528125  94.714  -59.802  53.900  1
528126  94.754  -59.813  53.863  1
528127  94.793  -59.823  53.825  1
528128  94.833  -59.834  53.786  1
528129  94.873  -59.844  53.747  1
528130  94.913  -59.855  53.710  1
528131  94.954  -59.865  53.682  1
528132  94.994  -59.875  53.657  1
528133  95.035  -59.886  53.632  1
528134  95.075  -59.896  53.607  1
528135  95.115  -59.906  53.582  1
528136  95.155  -59.914  53.555  1
528137  95.194  -59.924  53.527  1
528138  95.233  -59.933  53.496  1
528139  95.273  -59.942  53.462  1
528140  95.313  -59.951  53.427  1
528141  95.349  -59.958  53.390  1
528142  95.382  -59.964  53.355  1
528143  95.415  -59.971  53.323  1
528144  95.450  -59.978  53.293  1
528145  95.484  -59.984  53.265  1
528146  95.519  -59.991  53.236  1
528147  95.553  -59.997  53.208  1
528148  95.588  -60.004  53.179  1
528149  95.623  -60.009  53.152  1
528150  95.659  -60.014  53.127  1
528151  95.694  -60.018  53.101  1
528152  95.729  -60.024  53.078  1
528153  95.764  -60.031  53.062  1
528154  95.798  -60.037  53.052  1
528155  95.833  -60.044  53.045  1
528156  95.867  -60.051  53.037  1
528157  95.902  -60.057  53.023  1
528158  95.938  -60.063  53.006  1
528159  95.976  -60.068  52.985  1
528160  96.014  -60.073  52.962  1
528161  96.051  -60.078  52.938  1
528162  96.089  -60.083  52.909  1
528163  96.126  -60.083  52.880  1
528164  96.164  -60.082  52.846  1
528165  96.202  -60.082  52.811  1
528166  96.240  -60.081  52.777  1
528167  96.278  -60.081  52.747  1
528168  96.318  -60.082  52.717  1
528169  96.355  -60.083  52.686  1
528170  96.391  -60.083  52.655  1
528171  96.428  -60.083  52.622  1
528172  96.464  -60.083  52.589  1
528173  96.507  -60.087  52.554  1
528174  96.553  -60.093  52.518  1
528175  96.599  -60.100  52.479  1
528176  96.644  -60.106  52.439  1
528177  96.690  -60.112  52.397  1
528178  96.736  -60.119  52.352  1
528179  96.782  -60.125  52.307  1
528180  96.827  -60.131  52.264  1
528181  96.869  -60.134  52.220  1
528182  96.903  -60.134  52.178  1
528183  96.937  -60.136  52.136  1
528184  96.970  -60.138  52.094  1
528185  97.001  -60.151  52.054  1
528186  97.031  -60.164  52.015  1
528187  97.061  -60.177  51.974  1
528188  97.091  -60.190  51.932  1
528189  97.121  -60.202  51.890  1
528190  97.152  -60.215  51.847  1
528191  97.182  -60.228  51.804  1
528192  97.212  -60.240  51.762  1
528193  97.242  -60.253  51.721  1
528194  97.278  -60.256  51.680  1
528195  97.315  -60.257  51.640  1
528196  97.352  -60.258  51.600  1
528197  97.388  -60.259  51.562  1
528198  97.425  -60.259  51.524  1
528199  97.462  -60.260  51.489  1
528200  97.499  -60.261  51.454  1
528201  97.536  -60.262  51.420  1
528202  97.573  -60.262  51.386  1
528203  97.610  -60.265  51.354  1
528204  97.651  -60.276  51.321  1
528205  97.692  -60.287  51.286  1
528206  97.733  -60.299  51.250  1
528207  97.774  -60.309  51.213  1
528208  97.809  -60.318  51.176  1
528209  97.831  -60.318  51.139  1
528210  97.854  -60.320  51.100  1
528211  97.876  -60.321  51.062  1
528212  97.899  -60.322  51.022  1
528213  97.921  -60.323  50.982  1
528214  97.944  -60.325  50.943  1
528215  97.966  -60.325  50.904  1
528216  97.989  -60.326  50.865  1
528217  98.010  -60.327  50.827  1
528218  98.043  -60.333  50.788  1
528219  98.083  -60.341  50.747  1
528220  98.125  -60.341  50.705  1
528221  98.171  -60.325  50.662  1
528222  98.213  -60.317  50.616  1
528223  98.249  -60.322  50.567  1
528224  98.285  -60.326  50.519  1
528225  98.321  -60.330  50.472  1
528226  98.358  -60.334  50.426  1
528227  98.394  -60.339  50.379  1
528228  98.431  -60.343  50.333  1
528229  98.467  -60.347  50.288  1
528230  98.503  -60.352  50.242  1
528231  98.539  -60.356  50.198  1
528232  98.576  -60.360  50.153  1
528233  98.612  -60.365  50.109  1
528234  98.648  -60.369  50.065  1
528235  98.685  -60.373  50.021  1
528236  98.721  -60.378  49.978  1
528642  87.601  -57.655  57.055  1
528643  87.642  -57.669  57.038  1
528644  87.682  -57.683  57.019  1
528645  87.722  -57.695  57.000  1
528646  87.772  -57.703  56.981  1
528647  87.817  -57.710  56.961  1
528648  87.861  -57.717  56.940  1
528649  87.906  -57.724  56.917  1
528650  87.950  -57.732  56.894  1
528651  87.995  -57.739  56.869  1
528652  88.039  -57.746  56.844  1
528653  88.084  -57.754  56.819  1
528654  88.128  -57.761  56.794  1
528655  88.173  -57.768  56.766  1
528656  88.217  -57.776  56.738  1
528657  88.251  -57.787  56.711  1
528658  88.284  -57.799  56.682  1
528659  88.318  -57.811  56.653  1
528660  88.352  -57.822  56.624  1
528661  88.386  -57.833  56.594  1
528662  88.419  -57.845  56.565  1
528663  88.453  -57.856  56.534  1
528664  88.487  -57.868  56.504  1
528665  88.521  -57.880  56.472  1
528666  88.554  -57.891  56.439  1
528667  88.587  -57.902  56.406  1
528668  88.617  -57.907  56.373  1
528669  88.647  -57.913  56.340  1
528670  88.678  -57.918  56.307  1
528671  88.708  -57.924  56.274  1
528672  88.738  -57.930  56.240  1
528673  88.768  -57.951  56.207  1
528674  88.812  -57.971  56.174  1
528675  88.855  -57.993  56.143  1
528676  88.899  -58.013  56.109  1
528677  88.942  -58.034  56.077  1
528678  88.985  -58.055  56.045  1
528679  89.029  -58.075  56.015  1
528680  89.072  -58.096  55.988  1
528681  89.116  -58.117  55.963  1
528682  89.159  -58.138  55.940  1
528683  89.203  -58.159  55.918  1
528684  89.246  -58.180  55.897  1
528685  89.290  -58.200  55.879  1
528686  89.333  -58.222  55.866  1
528687  89.376  -58.242  55.855  1
528688  89.419  -58.263  55.844  1
528689  89.462  -58.284  55.835  1
528690  89.504  -58.300  55.829  1
528691  89.551  -58.306  55.826  1
528692  89.596  -58.310  55.822  1
528693  89.641  -58.315  55.817  1
528694  89.686  -58.319  55.812  1
528695  89.732  -58.324  55.807  1
528696  89.777  -58.328  55.800  1
528697  89.822  -58.333  55.796  1
528698  89.868  -58.338  55.793  1
528699  89.913  -58.342  55.790  1
528700  89.957  -58.347  55.787  1
528701  89.989  -58.365  55.785  1
528702  90.022  -58.382  55.779  1
528703  90.054  -58.398  55.767  1
528704  90.088  -58.413  55.751  1
528705  90.120  -58.428  55.732  1
528706  90.154  -58.441  55.709  1
528707  90.192  -58.448  55.683  1
528708  90.230  -58.456  55.659  1
528709  90.268  -58.463  55.636  1
528710  90.306  -58.470  55.618  1
528711  90.343  -58.477  55.606  1
528712  90.382  -58.485  55.600  1
528713  90.419  -58.492  55.593  1
528714  90.457  -58.499  55.584  1
528715  90.495  -58.507  55.569  1
528716  90.533  -58.515  55.549  1
528717  90.575  -58.533  55.524  1
528718  90.616  -58.552  55.496  1
528719  90.658  -58.571  55.465  1
528720  90.699  -58.590  55.430  1
528721  90.740  -58.608  55.399  1
528722  90.782  -58.627  55.376  1
528723  90.823  -58.646  55.359  1
528724  90.865  -58.664  55.335  1
528725  90.904  -58.676  55.309  1
528726  90.943  -58.682  55.283  1
528727  90.981  -58.686  55.257  1
528728  91.020  -58.692  55.234  1
528729  91.055  -58.708  55.211  1
528730  91.090  -58.729  55.184  1
528731  91.124  -58.749  55.159  1
528732  91.159  -58.770  55.138  1
528733  91.194  -58.789  55.122  1
528734  91.232  -58.802  55.103  1
528735  91.270  -58.814  55.076  1
528736  91.308  -58.827  55.043  1
528737  91.346  -58.839  55.007  1
528738  91.385  -58.852  54.972  1
528739  91.430  -58.864  54.945  1
528740  91.475  -58.877  54.918  1
528741  91.520  -58.890  54.893  1
528742  91.565  -58.903  54.866  1
528743  91.609  -58.916  54.838  1
528744  91.651  -58.930  54.813  1
528745  91.687  -58.944  54.795  1
528746  91.723  -58.958  54.778  1
528747  91.759  -58.973  54.766  1
528748  91.795  -58.987  54.757  1
528749  91.831  -59.002  54.752  1
528750  91.867  -59.016  54.749  1
528751  91.904  -59.030  54.752  1
528752  91.939  -59.045  54.758  1
528753  91.975  -59.046  54.768  1
528754  92.010  -59.046  54.779  1
528755  92.046  -59.046  54.793  1
528756  92.081  -59.047  54.803  1
528757  92.117  -59.047  54.809  1
528758  92.152  -59.048  54.811  1
528759  92.188  -59.049  54.809  1
528760  92.220  -59.051  54.802  1
528761  92.248  -59.056  54.788  1
528762  92.275  -59.062  54.778  1
528763  92.303  -59.067  54.769  1
528764  92.331  -59.072  54.761  1
528765  92.358  -59.078  54.752  1
528766  92.386  -59.084  54.744  1
528767  92.426  -59.085  54.736  1
528768  92.473  -59.084  54.723  1
528769  92.520  -59.084  54.706  1
528770  92.568  -59.083  54.691  1
528771  92.616  -59.082  54.678  1
528772  92.663  -59.081  54.663  1
528773  92.710  -59.081  54.648  1
528774  92.758  -59.080  54.633  1
528775  92.805  -59.079  54.617  1
528776  92.852  -59.078  54.600  1
528777  92.900  -59.077  54.578  1
528778  92.947  -59.076  54.558  1
528779  92.991  -59.084  54.539  1
528780  93.033  -59.093  54.520  1
528781  93.075  -59.102  54.499  1
528782  93.113  -59.111  54.474  1
528783  93.152  -59.119  54.452  1
528784  93.190  -59.128  54.432  1
528785  93.228  -59.137  54.414  1
528786  93.267  -59.145  54.397  1
528787  93.305  -59.153  54.384  1
528788  93.344  -59.162  54.370  1
528789  93.382  -59.170  54.358  1
528790  93.421  -59.179  54.346  1
528791  93.460  -59.187  54.335  1
528792  93.496  -59.206  54.323  1
528793  93.532  -59.226  54.313  1
528794  93.568  -59.247  54.301  1
528795  93.605  -59.262  54.287  1
528796  93.641  -59.278  54.272  1
528797  93.678  -59.294  54.258  1
528798  93.714  -59.309  54.244  1
528799  93.751  -59.325  54.231  1
528800  93.787  -59.341  54.220  1
528801  93.824  -59.356  54.209  1
528802  93.860  -59.372  54.198  1
528803  93.897  -59.388  54.187  1
528804  93.933  -59.405  54.177  1
528805  93.968  -59.425  54.165  1
528806  94.003  -59.445  54.151  1
528807  94.038  -59.466  54.136  1
528808  94.073  -59.486  54.120  1
528809  94.108  -59.506  54.101  1
528810  94.142  -59.526  54.082  1
528811  94.178  -59.547  54.065  1
528812  94.212  -59.567  54.051  1
528813  94.248  -59.587  54.039  1
528814  94.282  -59.607  54.030  1
528815  94.318  -59.628  54.024  1
528816  94.352  -59.648  54.021  1
528817  94.388  -59.668  54.018  1
528818  94.422  -59.685  54.015  1
528819  94.456  -59.693  54.010  1
528820  94.490  -59.700  54.003  1
528821  94.529  -59.710  53.995  1
528822  94.567  -59.721  53.980  1
528823  94.605  -59.732  53.961  1
528824  94.643  -59.742  53.937  1
528825  94.682  -59.753  53.910  1
528826  94.720  -59.764  53.876  1
528827  94.760  -59.774  53.841  1
528828  94.800  -59.785  53.806  1
528829  94.840  -59.795  53.772  1
528830  94.881  -59.806  53.735  1
528831  94.921  -59.816  53.702  1
528832  94.962  -59.826  53.675  1
528833  95.002  -59.837  53.652  1
528834  95.043  -59.848  53.630  1
528835  95.084  -59.858  53.608  1
528836  95.124  -59.867  53.583  1
528837  95.164  -59.877  53.557  1
528838  95.203  -59.886  53.530  1
528839  95.244  -59.895  53.500  1
528840  95.283  -59.904  53.467  1
528841  95.324  -59.913  53.433  1
528842  95.364  -59.922  53.396  1
528843  95.396  -59.929  53.361  1
528844  95.428  -59.935  53.327  1
528845  95.461  -59.941  53.293  1
528846  95.493  -59.948  53.261  1
528847  95.527  -59.954  53.231  1
528848  95.562  -59.961  53.204  1
528849  95.596  -59.967  53.177  1
528850  95.631  -59.972  53.153  1
528851  95.667  -59.977  53.129  1
528852  95.701  -59.984  53.104  1
528853  95.736  -59.990  53.085  1
528854  95.770  -59.997  53.073  1
528855  95.805  -60.004  53.065  1
528856  95.840  -60.010  53.057  1
528857  95.874  -60.017  53.050  1
528858  95.909  -60.024  53.036  1
528859  95.945  -60.029  53.019  1
528860  95.983  -60.034  52.999  1
528861  96.021  -60.039  52.976  1
528862  96.058  -60.044  52.949  1
528863  96.096  -60.049  52.920  1
528864  96.133  -60.054  52.888  1
528865  96.171  -60.054  52.854  1
528866  96.209  -60.053  52.821  1
528867  96.247  -60.052  52.791  1
528868  96.286  -60.054  52.763  1
528869  96.323  -60.054  52.735  1
528870  96.360  -60.054  52.706  1
528871  96.396  -60.054  52.676  1
528872  96.433  -60.055  52.646  1
528873  96.469  -60.055  52.614  1
528874  96.514  -60.060  52.580  1
528875  96.559  -60.066  52.544  1
528876  96.605  -60.072  52.505  1
528877  96.651  -60.079  52.466  1
528878  96.696  -60.085  52.423  1
528879  96.742  -60.092  52.378  1
528880  96.788  -60.098  52.333  1
528881  96.829  -60.101  52.290  1
528882  96.868  -60.102  52.247  1
528883  96.900  -60.100  52.204  1
528884  96.934  -60.102  52.162  1
528885  96.967  -60.105  52.119  1
528886  97.000  -60.109  52.078  1
528887  97.030  -60.122  52.038  1
528888  97.061  -60.135  51.996  1
528889  97.091  -60.148  51.954  1
528890  97.121  -60.161  51.910  1
528891  97.151  -60.173  51.867  1
528892  97.181  -60.186  51.824  1
528893  97.212  -60.199  51.781  1
528894  97.242  -60.212  51.738  1
528895  97.276  -60.218  51.695  1
528896  97.313  -60.218  51.653  1
528897  97.350  -60.219  51.612  1
528898  97.386  -60.219  51.572  1
528899  97.423  -60.220  51.533  1
528900  97.460  -60.221  51.497  1
528901  97.497  -60.221  51.461  1
528902  97.533  -60.222  51.427  1
528903  97.570  -60.223  51.393  1
528904  97.609  -60.230  51.361  1
528905  97.651  -60.241  51.329  1
528906  97.691  -60.252  51.293  1
528907  97.732  -60.263  51.257  1
528908  97.773  -60.275  51.219  1
528909  97.814  -60.286  51.181  1
528910  97.848  -60.293  51.143  1
528911  97.870  -60.294  51.104  1
528912  97.893  -60.295  51.065  1
528913  97.915  -60.297  51.025  1
528914  97.938  -60.297  50.985  1
528915  97.960  -60.298  50.945  1
528916  97.983  -60.300  50.906  1
528917  98.005  -60.300  50.866  1
528918  98.025  -60.301  50.828  1
528919  98.045  -60.301  50.791  1
528920  98.084  -60.309  50.751  1
528921  98.124  -60.317  50.710  1
528922  98.170  -60.302  50.668  1
528923  98.216  -60.285  50.623  1
528924  98.255  -60.284  50.575  1
528925  98.292  -60.288  50.527  1
528926  98.328  -60.293  50.479  1
528927  98.364  -60.297  50.432  1
528928  98.401  -60.301  50.385  1
528929  98.437  -60.306  50.339  1
528930  98.473  -60.310  50.294  1
528931  98.509  -60.315  50.248  1
528932  98.546  -60.318  50.204  1
528933  98.582  -60.323  50.159  1
528934  98.618  -60.328  50.115  1
528935  98.654  -60.331  50.071  1
528936  98.691  -60.336  50.027  1
528937  98.727  -60.340  49.984  1
528938  98.764  -60.345  49.942  1
529345  87.699  -57.639  57.007  1
529346  87.743  -57.650  56.987  1
529347  87.792  -57.656  56.968  1
529348  87.837  -57.663  56.948  1
529349  87.881  -57.670  56.927  1
529350  87.926  -57.677  56.904  1
529351  87.970  -57.685  56.880  1
529352  88.015  -57.692  56.856  1
529353  88.059  -57.699  56.832  1
529354  88.104  -57.707  56.808  1
529355  88.148  -57.714  56.781  1
529356  88.193  -57.721  56.755  1
529357  88.229  -57.732  56.728  1
529358  88.263  -57.743  56.701  1
529359  88.297  -57.755  56.673  1
529360  88.331  -57.767  56.645  1
529361  88.364  -57.778  56.616  1
529362  88.398  -57.789  56.587  1
529363  88.431  -57.801  56.558  1
529364  88.465  -57.812  56.529  1
529365  88.499  -57.824  56.501  1
529366  88.533  -57.836  56.471  1
529367  88.566  -57.847  56.439  1
529368  88.600  -57.858  56.406  1
529369  88.634  -57.870  56.375  1
529370  88.665  -57.877  56.344  1
529371  88.695  -57.883  56.313  1
529372  88.725  -57.889  56.282  1
529373  88.756  -57.895  56.250  1
529374  88.782  -57.912  56.218  1
529375  88.811  -57.936  56.187  1
529376  88.855  -57.956  56.155  1
529377  88.898  -57.977  56.122  1
529378  88.942  -57.998  56.089  1
529379  88.985  -58.019  56.057  1
529380  89.029  -58.040  56.026  1
529381  89.072  -58.061  55.999  1
529382  89.115  -58.081  55.974  1
529383  89.159  -58.102  55.950  1
529384  89.202  -58.123  55.926  1
529385  89.246  -58.144  55.905  1
529386  89.289  -58.165  55.886  1
529387  89.333  -58.185  55.872  1
529388  89.376  -58.206  55.859  1
529389  89.419  -58.227  55.847  1
529390  89.468  -58.244  55.837  1
529391  89.516  -58.260  55.829  1
529392  89.556  -58.268  55.823  1
529393  89.602  -58.272  55.818  1
529394  89.647  -58.277  55.812  1
529395  89.692  -58.281  55.807  1
529396  89.738  -58.286  55.802  1
529397  89.782  -58.291  55.797  1
529398  89.828  -58.295  55.793  1
529399  89.873  -58.300  55.790  1
529400  89.918  -58.305  55.787  1
529401  89.964  -58.310  55.785  1
529402  90.000  -58.322  55.784  1
529403  90.033  -58.340  55.774  1
529404  90.065  -58.357  55.760  1
529405  90.097  -58.375  55.741  1
529406  90.130  -58.390  55.720  1
529407  90.167  -58.398  55.695  1
529408  90.205  -58.406  55.672  1
529409  90.243  -58.413  55.650  1
529410  90.281  -58.420  55.630  1
529411  90.319  -58.428  55.615  1
529412  90.357  -58.435  55.606  1
529413  90.394  -58.442  55.601  1
529414  90.432  -58.450  55.592  1
529415  90.470  -58.457  55.580  1
529416  90.508  -58.464  55.561  1
529417  90.546  -58.472  55.536  1
529418  90.585  -58.484  55.508  1
529419  90.626  -58.502  55.480  1
529420  90.668  -58.521  55.450  1
529421  90.710  -58.540  55.420  1
529422  90.751  -58.558  55.394  1
529423  90.792  -58.577  55.377  1
529424  90.834  -58.596  55.360  1
529425  90.875  -58.615  55.340  1
529426  90.917  -58.633  55.318  1
529427  90.958  -58.652  55.293  1
529428  90.997  -58.660  55.264  1
529429  91.035  -58.665  55.239  1
529430  91.073  -58.673  55.217  1
529431  91.107  -58.693  55.192  1
529432  91.142  -58.714  55.166  1
529433  91.177  -58.735  55.141  1
529434  91.215  -58.747  55.122  1
529435  91.252  -58.760  55.102  1
529436  91.290  -58.772  55.077  1
529437  91.328  -58.785  55.048  1
529438  91.366  -58.797  55.016  1
529439  91.403  -58.810  54.985  1
529440  91.442  -58.823  54.966  1
529441  91.487  -58.835  54.944  1
529442  91.532  -58.848  54.918  1
529443  91.577  -58.861  54.890  1
529444  91.622  -58.874  54.862  1
529445  91.659  -58.888  54.831  1
529446  91.695  -58.902  54.807  1
529447  91.731  -58.917  54.787  1
529448  91.768  -58.931  54.770  1
529449  91.803  -58.946  54.758  1
529450  91.840  -58.960  54.749  1
529451  91.876  -58.974  54.745  1
529452  91.912  -58.989  54.743  1
529453  91.948  -59.003  54.746  1
529454  91.984  -59.007  54.752  1
529455  92.019  -59.008  54.761  1
529456  92.055  -59.008  54.775  1
529457  92.090  -59.008  54.788  1
529458  92.126  -59.008  54.801  1
529459  92.161  -59.009  54.809  1
529460  92.196  -59.009  54.810  1
529461  92.232  -59.010  54.804  1
529462  92.263  -59.014  54.791  1
529463  92.290  -59.019  54.781  1
529464  92.317  -59.024  54.771  1
529465  92.345  -59.030  54.760  1
529466  92.373  -59.035  54.748  1
529467  92.401  -59.040  54.740  1
529468  92.440  -59.043  54.737  1
529469  92.488  -59.041  54.730  1
529470  92.535  -59.040  54.721  1
529471  92.583  -59.040  54.711  1
529472  92.630  -59.039  54.700  1
529473  92.677  -59.038  54.683  1
529474  92.725  -59.037  54.667  1
529475  92.772  -59.037  54.650  1
529476  92.819  -59.036  54.632  1
529477  92.867  -59.035  54.614  1
529478  92.914  -59.034  54.591  1
529479  92.961  -59.034  54.563  1
529480  93.007  -59.036  54.537  1
529481  93.050  -59.046  54.514  1
529482  93.090  -59.054  54.496  1
529483  93.128  -59.063  54.475  1
529484  93.167  -59.071  54.455  1
529485  93.205  -59.080  54.438  1
529486  93.243  -59.088  54.422  1
529487  93.282  -59.096  54.407  1
529488  93.321  -59.106  54.394  1
529489  93.359  -59.114  54.381  1
529490  93.398  -59.122  54.369  1
529491  93.436  -59.131  54.355  1
529492  93.475  -59.139  54.342  1
529493  93.511  -59.157  54.327  1
529494  93.547  -59.178  54.314  1
529495  93.584  -59.194  54.300  1
529496  93.620  -59.210  54.286  1
529497  93.657  -59.225  54.270  1
529498  93.693  -59.241  54.254  1
529499  93.730  -59.256  54.238  1
529500  93.766  -59.272  54.221  1
529501  93.802  -59.289  54.207  1
529502  93.837  -59.309  54.194  1
529503  93.872  -59.330  54.179  1
529504  93.907  -59.350  54.164  1
529505  93.942  -59.370  54.152  1
529506  93.977  -59.391  54.140  1
529507  94.012  -59.411  54.127  1
529508  94.047  -59.431  54.111  1
529509  94.082  -59.451  54.091  1
529510  94.117  -59.472  54.072  1
529511  94.152  -59.492  54.054  1
529512  94.187  -59.512  54.038  1
529513  94.222  -59.532  54.024  1
529514  94.257  -59.553  54.012  1
529515  94.292  -59.573  54.003  1
529516  94.327  -59.593  53.997  1
529517  94.362  -59.613  53.994  1
529518  94.397  -59.634  53.991  1
529519  94.431  -59.649  53.988  1
529520  94.466  -59.657  53.983  1
529521  94.499  -59.663  53.975  1
529522  94.536  -59.673  53.963  1
529523  94.574  -59.683  53.948  1
529524  94.612  -59.694  53.931  1
529525  94.650  -59.704  53.910  1
529526  94.689  -59.715  53.886  1
529527  94.727  -59.726  53.858  1
529528  94.767  -59.736  53.826  1
529529  94.808  -59.746  53.792  1
529530  94.848  -59.757  53.756  1
529531  94.889  -59.767  53.718  1
529532  94.930  -59.777  53.687  1
529533  94.970  -59.788  53.662  1
529534  95.011  -59.798  53.640  1
529535  95.052  -59.808  53.620  1
529536  95.092  -59.819  53.602  1
529537  95.132  -59.830  53.580  1
529538  95.174  -59.839  53.556  1
529539  95.214  -59.848  53.530  1
529540  95.254  -59.857  53.500  1
529541  95.294  -59.867  53.469  1
529542  95.334  -59.876  53.437  1
529543  95.374  -59.885  53.402  1
529544  95.410  -59.892  53.370  1
529545  95.443  -59.898  53.337  1
529546  95.475  -59.905  53.303  1
529547  95.508  -59.911  53.266  1
529548  95.540  -59.917  53.236  1
529549  95.573  -59.924  53.209  1
529550  95.606  -59.930  53.185  1
529551  95.639  -59.937  53.161  1
529552  95.674  -59.943  53.137  1
529553  95.708  -59.950  53.110  1
529554  95.743  -59.957  53.094  1
529555  95.777  -59.963  53.085  1
529556  95.812  -59.970  53.077  1
529557  95.846  -59.977  53.069  1
529558  95.881  -59.983  53.061  1
529559  95.915  -59.989  53.047  1
529560  95.952  -59.995  53.030  1
529561  95.990  -60.000  53.009  1
529562  96.028  -60.005  52.985  1
529563  96.065  -60.010  52.957  1
529564  96.103  -60.015  52.927  1
529565  96.141  -60.020  52.893  1
529566  96.178  -60.025  52.859  1
529567  96.216  -60.025  52.829  1
529568  96.254  -60.025  52.802  1
529569  96.292  -60.026  52.776  1
529570  96.328  -60.026  52.749  1
529571  96.365  -60.026  52.722  1
529572  96.401  -60.026  52.694  1
529573  96.438  -60.026  52.666  1
529574  96.474  -60.026  52.635  1
529575  96.520  -60.032  52.602  1
529576  96.566  -60.039  52.567  1
529577  96.611  -60.045  52.528  1
529578  96.657  -60.052  52.488  1
529579  96.703  -60.058  52.446  1
529580  96.749  -60.064  52.402  1
529581  96.791  -60.068  52.360  1
529582  96.829  -60.068  52.317  1
529583  96.865  -60.068  52.274  1
529584  96.896  -60.067  52.232  1
529585  96.930  -60.068  52.189  1
529586  96.964  -60.071  52.146  1
529587  96.998  -60.073  52.105  1
529588  97.029  -60.080  52.063  1
529589  97.060  -60.093  52.019  1
529590  97.090  -60.106  51.976  1
529591  97.120  -60.119  51.930  1
529592  97.150  -60.131  51.887  1
529593  97.180  -60.144  51.843  1
529594  97.211  -60.157  51.799  1
529595  97.241  -60.170  51.756  1
529596  97.274  -60.178  51.713  1
529597  97.310  -60.179  51.669  1
529598  97.347  -60.180  51.626  1
529599  97.384  -60.181  51.585  1
529600  97.421  -60.181  51.545  1
529601  97.458  -60.182  51.506  1
529602  97.495  -60.183  51.469  1
529603  97.531  -60.184  51.435  1
529604  97.568  -60.184  51.401  1
529605  97.609  -60.194  51.368  1
529606  97.650  -60.206  51.334  1
529607  97.690  -60.217  51.300  1
529608  97.732  -60.228  51.263  1
529609  97.773  -60.239  51.225  1
529610  97.813  -60.250  51.186  1
529611  97.854  -60.262  51.147  1
529612  97.887  -60.268  51.108  1
529613  97.910  -60.269  51.068  1
529614  97.932  -60.270  51.029  1
529615  97.954  -60.271  50.988  1
529616  97.977  -60.272  50.947  1
529617  97.999  -60.274  50.906  1
529618  98.021  -60.275  50.866  1
529619  98.040  -60.275  50.827  1
529620  98.057  -60.273  50.791  1
529621  98.086  -60.277  50.753  1
529622  98.126  -60.285  50.713  1
529623  98.169  -60.280  50.670  1
529624  98.215  -60.263  50.626  1
529625  98.262  -60.246  50.580  1
529626  98.298  -60.251  50.534  1
529627  98.334  -60.256  50.487  1
529628  98.370  -60.259  50.439  1
529629  98.407  -60.264  50.391  1
529630  98.443  -60.268  50.345  1
529631  98.479  -60.273  50.300  1
529632  98.515  -60.277  50.255  1
529633  98.552  -60.281  50.210  1
529634  98.588  -60.286  50.167  1
529635  98.625  -60.290  50.122  1
529636  98.661  -60.294  50.077  1
529637  98.697  -60.299  50.033  1
529638  98.733  -60.303  49.990  1
529639  98.770  -60.307  49.949  1
530047  87.768  -57.601  56.974  1
530048  87.812  -57.609  56.954  1
530049  87.857  -57.616  56.934  1
530050  87.901  -57.623  56.913  1
530051  87.946  -57.630  56.890  1
530052  87.990  -57.638  56.867  1
530053  88.035  -57.645  56.844  1
530054  88.079  -57.652  56.820  1
530055  88.124  -57.660  56.796  1
530056  88.169  -57.667  56.770  1
530057  88.208  -57.677  56.744  1
530058  88.242  -57.688  56.718  1
530059  88.275  -57.699  56.691  1
530060  88.309  -57.711  56.662  1
530061  88.343  -57.723  56.634  1
530062  88.377  -57.734  56.606  1
530063  88.410  -57.746  56.578  1
530064  88.444  -57.757  56.550  1
530065  88.478  -57.768  56.522  1
530066  88.511  -57.780  56.495  1
530067  88.545  -57.792  56.466  1
530068  88.578  -57.803  56.435  1
530069  88.612  -57.814  56.405  1
530070  88.646  -57.826  56.376  1
530071  88.680  -57.838  56.345  1
530072  88.713  -57.848  56.316  1
530073  88.743  -57.854  56.287  1
530074  88.773  -57.859  56.258  1
530075  88.801  -57.874  56.227  1
530076  88.825  -57.898  56.197  1
530077  88.854  -57.921  56.166  1
530078  88.898  -57.942  56.133  1
530079  88.941  -57.962  56.100  1
530080  88.985  -57.983  56.068  1
530081  89.028  -58.004  56.036  1
530082  89.071  -58.024  56.009  1
530083  89.115  -58.046  55.983  1
530084  89.159  -58.066  55.958  1
530085  89.202  -58.087  55.934  1
530086  89.245  -58.108  55.911  1
530087  89.289  -58.128  55.893  1
530088  89.334  -58.148  55.877  1
530089  89.383  -58.165  55.863  1
530090  89.432  -58.182  55.850  1
530091  89.481  -58.199  55.839  1
530092  89.530  -58.216  55.830  1
530093  89.568  -58.227  55.821  1
530094  89.607  -58.235  55.815  1
530095  89.653  -58.240  55.809  1
530096  89.698  -58.244  55.804  1
530097  89.743  -58.249  55.798  1
530098  89.789  -58.253  55.795  1
530099  89.834  -58.258  55.790  1
530100  89.879  -58.263  55.787  1
530101  89.924  -58.267  55.785  1
530102  89.969  -58.272  55.782  1
530103  90.011  -58.280  55.780  1
530104  90.043  -58.297  55.769  1
530105  90.076  -58.315  55.753  1
530106  90.108  -58.332  55.733  1
530107  90.141  -58.349  55.711  1
530108  90.180  -58.356  55.686  1
530109  90.218  -58.363  55.663  1
530110  90.256  -58.370  55.643  1
530111  90.294  -58.378  55.626  1
530112  90.331  -58.385  55.614  1
530113  90.369  -58.392  55.607  1
530114  90.407  -58.400  55.601  1
530115  90.445  -58.407  55.590  1
530116  90.483  -58.414  55.573  1
530117  90.521  -58.422  55.549  1
530118  90.558  -58.429  55.520  1
530119  90.597  -58.436  55.490  1
530120  90.637  -58.453  55.463  1
530121  90.679  -58.471  55.437  1
530122  90.720  -58.490  55.413  1
530123  90.761  -58.509  55.393  1
530124  90.803  -58.527  55.378  1
530125  90.844  -58.546  55.363  1
530126  90.886  -58.565  55.346  1
530127  90.927  -58.583  55.326  1
530128  90.968  -58.602  55.302  1
530129  91.010  -58.621  55.274  1
530130  91.051  -58.639  55.248  1
530131  91.089  -58.643  55.222  1
530132  91.126  -58.658  55.195  1
530133  91.160  -58.679  55.167  1
530134  91.197  -58.692  55.141  1
530135  91.235  -58.705  55.119  1
530136  91.273  -58.717  55.098  1
530137  91.310  -58.730  55.074  1
530138  91.348  -58.742  55.051  1
530139  91.386  -58.755  55.028  1
530140  91.424  -58.768  55.007  1
530141  91.461  -58.780  54.988  1
530142  91.500  -58.793  54.966  1
530143  91.544  -58.806  54.939  1
530144  91.589  -58.819  54.913  1
530145  91.632  -58.832  54.887  1
530146  91.667  -58.846  54.854  1
530147  91.704  -58.861  54.824  1
530148  91.740  -58.875  54.798  1
530149  91.776  -58.889  54.777  1
530150  91.812  -58.904  54.761  1
530151  91.848  -58.918  54.750  1
530152  91.884  -58.933  54.743  1
530153  91.920  -58.947  54.738  1
530154  91.956  -58.961  54.738  1
530155  91.992  -58.968  54.742  1
530156  92.027  -58.969  54.750  1
530157  92.063  -58.969  54.763  1
530158  92.098  -58.970  54.782  1
530159  92.134  -58.970  54.800  1
530160  92.169  -58.971  54.812  1
530161  92.205  -58.971  54.815  1
530162  92.240  -58.971  54.811  1
530163  92.276  -58.972  54.798  1
530164  92.305  -58.976  54.782  1
530165  92.333  -58.982  54.767  1
530166  92.360  -58.987  54.755  1
530167  92.387  -58.993  54.743  1
530168  92.415  -58.998  54.731  1
530169  92.455  -58.999  54.724  1
530170  92.502  -58.999  54.723  1
530171  92.550  -58.998  54.725  1
530172  92.597  -58.997  54.722  1
530173  92.645  -58.996  54.710  1
530174  92.692  -58.996  54.694  1
530175  92.739  -58.995  54.677  1
530176  92.787  -58.994  54.660  1
530177  92.834  -58.993  54.642  1
530178  92.881  -58.993  54.619  1
530179  92.929  -58.992  54.599  1
530180  92.976  -58.991  54.571  1
530181  93.023  -58.990  54.543  1
530182  93.066  -58.998  54.520  1
530183  93.105  -59.006  54.502  1
530184  93.143  -59.015  54.484  1
530185  93.182  -59.023  54.466  1
530186  93.220  -59.032  54.449  1
530187  93.259  -59.040  54.434  1
530188  93.297  -59.049  54.421  1
530189  93.336  -59.057  54.409  1
530190  93.374  -59.065  54.397  1
530191  93.413  -59.074  54.385  1
530192  93.451  -59.083  54.374  1
530193  93.489  -59.091  54.360  1
530194  93.526  -59.109  54.345  1
530195  93.563  -59.126  54.327  1
530196  93.599  -59.141  54.308  1
530197  93.636  -59.157  54.289  1
530198  93.672  -59.174  54.272  1
530199  93.707  -59.194  54.255  1
530200  93.742  -59.214  54.237  1
530201  93.777  -59.234  54.219  1
530202  93.812  -59.255  54.203  1
530203  93.847  -59.275  54.188  1
530204  93.882  -59.295  54.172  1
530205  93.917  -59.316  54.157  1
530206  93.952  -59.336  54.136  1
530207  93.987  -59.356  54.118  1
530208  94.022  -59.376  54.103  1
530209  94.057  -59.397  54.086  1
530210  94.091  -59.417  54.067  1
530211  94.126  -59.438  54.049  1
530212  94.161  -59.457  54.032  1
530213  94.196  -59.478  54.016  1
530214  94.231  -59.498  54.001  1
530215  94.266  -59.519  53.988  1
530216  94.301  -59.538  53.976  1
530217  94.336  -59.559  53.969  1
530218  94.371  -59.579  53.965  1
530219  94.406  -59.599  53.963  1
530220  94.441  -59.613  53.960  1
530221  94.475  -59.620  53.956  1
530222  94.509  -59.627  53.945  1
530223  94.543  -59.635  53.930  1
530224  94.581  -59.645  53.915  1
530225  94.620  -59.656  53.898  1
530226  94.658  -59.667  53.879  1
530227  94.696  -59.677  53.857  1
530228  94.735  -59.687  53.831  1
530229  94.776  -59.697  53.801  1
530230  94.817  -59.707  53.767  1
530231  94.857  -59.717  53.731  1
530232  94.898  -59.727  53.694  1
530233  94.938  -59.738  53.664  1
530234  94.979  -59.748  53.639  1
530235  95.020  -59.758  53.619  1
530236  95.060  -59.769  53.601  1
530237  95.101  -59.779  53.584  1
530238  95.141  -59.792  53.564  1
530239  95.181  -59.802  53.542  1
530240  95.222  -59.811  53.519  1
530241  95.263  -59.820  53.493  1
530242  95.304  -59.829  53.464  1
530243  95.344  -59.838  53.435  1
530244  95.384  -59.847  53.404  1
530245  95.424  -59.856  53.373  1
530246  95.457  -59.862  53.342  1
530247  95.490  -59.869  53.309  1
530248  95.522  -59.875  53.277  1
530249  95.555  -59.881  53.247  1
530250  95.585  -59.889  53.219  1
530251  95.614  -59.896  53.192  1
530252  95.647  -59.903  53.164  1
530253  95.681  -59.910  53.138  1
530254  95.715  -59.917  53.118  1
530255  95.750  -59.923  53.107  1
530256  95.784  -59.930  53.099  1
530257  95.819  -59.936  53.090  1
530258  95.853  -59.942  53.080  1
530259  95.888  -59.949  53.069  1
530260  95.922  -59.955  53.056  1
530261  95.959  -59.961  53.037  1
530262  95.997  -59.966  53.014  1
530263  96.035  -59.971  52.989  1
530264  96.073  -59.976  52.961  1
530265  96.110  -59.981  52.929  1
530266  96.148  -59.986  52.893  1
530267  96.185  -59.991  52.862  1
530268  96.223  -59.996  52.836  1
530269  96.260  -59.997  52.813  1
530270  96.297  -59.997  52.786  1
530271  96.333  -59.997  52.761  1
530272  96.370  -59.997  52.735  1
530273  96.406  -59.997  52.710  1
530274  96.443  -59.997  52.683  1
530275  96.481  -59.999  52.655  1
530276  96.527  -60.005  52.623  1
530277  96.572  -60.011  52.588  1
530278  96.618  -60.018  52.549  1
530279  96.664  -60.024  52.508  1
530280  96.710  -60.030  52.467  1
530281  96.751  -60.033  52.425  1
530282  96.790  -60.034  52.385  1
530283  96.828  -60.035  52.343  1
530284  96.861  -60.034  52.301  1
530285  96.893  -60.033  52.259  1
530286  96.927  -60.035  52.217  1
530287  96.960  -60.037  52.175  1
530288  96.994  -60.040  52.133  1
530289  97.028  -60.042  52.089  1
530290  97.059  -60.052  52.044  1
530291  97.089  -60.065  51.999  1
530292  97.119  -60.077  51.953  1
530293  97.150  -60.090  51.909  1
530294  97.180  -60.102  51.864  1
530295  97.210  -60.115  51.819  1
530296  97.240  -60.128  51.774  1
530297  97.272  -60.140  51.730  1
530298  97.308  -60.140  51.685  1
530299  97.345  -60.141  51.641  1
530300  97.382  -60.142  51.599  1
530301  97.419  -60.143  51.557  1
530302  97.455  -60.143  51.517  1
530303  97.492  -60.143  51.479  1
530304  97.529  -60.144  51.442  1
530305  97.567  -60.148  51.406  1
530306  97.608  -60.159  51.371  1
530307  97.649  -60.170  51.336  1
530308  97.690  -60.181  51.302  1
530309  97.731  -60.193  51.264  1
530310  97.772  -60.204  51.226  1
530311  97.813  -60.215  51.187  1
530312  97.854  -60.226  51.148  1
530313  97.894  -60.237  51.110  1
530314  97.926  -60.243  51.070  1
530315  97.948  -60.244  51.031  1
530316  97.970  -60.245  50.990  1
530317  97.993  -60.246  50.948  1
530318  98.015  -60.247  50.907  1
530319  98.038  -60.249  50.866  1
530320  98.056  -60.248  50.825  1
530321  98.072  -60.246  50.787  1
530322  98.088  -60.246  50.749  1
530323  98.127  -60.253  50.709  1
530324  98.167  -60.258  50.667  1
530325  98.214  -60.241  50.624  1
530326  98.261  -60.224  50.580  1
530327  98.304  -60.214  50.535  1
530328  98.340  -60.218  50.490  1
530329  98.376  -60.222  50.444  1
530330  98.413  -60.227  50.397  1
530331  98.449  -60.231  50.351  1
530332  98.486  -60.235  50.305  1
530333  98.522  -60.240  50.261  1
530334  98.558  -60.244  50.217  1
530335  98.594  -60.248  50.173  1
530336  98.631  -60.253  50.129  1
530337  98.667  -60.257  50.084  1
530338  98.703  -60.261  50.040  1
530339  98.739  -60.265  49.997  1
530340  98.776  -60.270  49.956  1
530749  87.832  -57.561  56.941  1
530750  87.877  -57.569  56.921  1
530751  87.921  -57.576  56.899  1
530752  87.966  -57.583  56.877  1
530753  88.010  -57.591  56.855  1
530754  88.055  -57.598  56.832  1
530755  88.100  -57.605  56.809  1
530756  88.144  -57.613  56.783  1
530757  88.187  -57.620  56.759  1
530758  88.220  -57.633  56.733  1
530759  88.254  -57.644  56.707  1
530760  88.287  -57.655  56.680  1
530761  88.321  -57.667  56.651  1
530762  88.355  -57.679  56.622  1
530763  88.389  -57.690  56.595  1
530764  88.422  -57.702  56.568  1
530765  88.456  -57.713  56.540  1
530766  88.490  -57.724  56.513  1
530767  88.524  -57.736  56.486  1
530768  88.557  -57.748  56.458  1
530769  88.591  -57.759  56.429  1
530770  88.624  -57.771  56.400  1
530771  88.658  -57.782  56.372  1
530772  88.692  -57.794  56.343  1
530773  88.725  -57.805  56.316  1
530774  88.759  -57.817  56.288  1
530775  88.790  -57.824  56.261  1
530776  88.820  -57.834  56.233  1
530777  88.844  -57.858  56.206  1
530778  88.868  -57.883  56.175  1
530779  88.897  -57.905  56.143  1
530780  88.941  -57.927  56.110  1
530781  88.984  -57.947  56.077  1
530782  89.028  -57.968  56.046  1
530783  89.071  -57.989  56.018  1
530784  89.115  -58.009  55.990  1
530785  89.158  -58.031  55.965  1
530786  89.201  -58.051  55.941  1
530787  89.249  -58.069  55.917  1
530788  89.298  -58.087  55.899  1
530789  89.347  -58.103  55.882  1
530790  89.396  -58.120  55.867  1
530791  89.445  -58.137  55.854  1
530792  89.494  -58.154  55.842  1
530793  89.543  -58.171  55.831  1
530794  89.584  -58.184  55.822  1
530795  89.620  -58.194  55.815  1
530796  89.659  -58.203  55.808  1
530797  89.704  -58.207  55.802  1
530798  89.749  -58.212  55.797  1
530799  89.794  -58.216  55.793  1
530800  89.839  -58.221  55.788  1
530801  89.885  -58.225  55.784  1
530802  89.930  -58.230  55.782  1
530803  89.975  -58.234  55.779  1
530804  90.020  -58.239  55.774  1
530805  90.054  -58.256  55.763  1
530806  90.086  -58.272  55.745  1
530807  90.118  -58.290  55.725  1
530808  90.151  -58.307  55.702  1
530809  90.186  -58.318  55.678  1
530810  90.228  -58.322  55.657  1
530811  90.268  -58.328  55.637  1
530812  90.306  -58.335  55.621  1
530813  90.344  -58.343  55.609  1
530814  90.382  -58.350  55.601  1
530815  90.420  -58.357  55.591  1
530816  90.458  -58.365  55.578  1
530817  90.496  -58.372  55.558  1
530818  90.534  -58.379  55.532  1
530819  90.572  -58.387  55.502  1
530820  90.609  -58.394  55.472  1
530821  90.648  -58.403  55.450  1
530822  90.689  -58.421  55.429  1
530823  90.731  -58.440  55.411  1
530824  90.772  -58.459  55.398  1
530825  90.813  -58.478  55.382  1
530826  90.855  -58.496  55.368  1
530827  90.896  -58.515  55.351  1
530828  90.938  -58.534  55.331  1
530829  90.979  -58.552  55.309  1
530830  91.020  -58.571  55.282  1
530831  91.062  -58.590  55.255  1
530832  91.103  -58.608  55.227  1
530833  91.143  -58.623  55.199  1
530834  91.179  -58.638  55.171  1
530835  91.218  -58.651  55.145  1
530836  91.255  -58.663  55.120  1
530837  91.293  -58.676  55.099  1
530838  91.331  -58.689  55.078  1
530839  91.369  -58.701  55.059  1
530840  91.406  -58.714  55.042  1
530841  91.444  -58.726  55.025  1
530842  91.482  -58.739  55.007  1
530843  91.520  -58.751  54.987  1
530844  91.558  -58.764  54.962  1
530845  91.601  -58.777  54.935  1
530846  91.640  -58.790  54.910  1
530847  91.676  -58.805  54.879  1
530848  91.712  -58.819  54.846  1
530849  91.748  -58.833  54.815  1
530850  91.784  -58.848  54.789  1
530851  91.820  -58.862  54.768  1
530852  91.856  -58.877  54.754  1
530853  91.892  -58.891  54.743  1
530854  91.929  -58.905  54.737  1
530855  91.964  -58.920  54.735  1
530856  92.001  -58.930  54.737  1
530857  92.036  -58.930  54.744  1
530858  92.071  -58.930  54.755  1
530859  92.107  -58.931  54.777  1
530860  92.142  -58.931  54.796  1
530861  92.178  -58.932  54.809  1
530862  92.213  -58.932  54.813  1
530863  92.249  -58.933  54.808  1
530864  92.284  -58.933  54.794  1
530865  92.319  -58.933  54.775  1
530866  92.347  -58.939  54.756  1
530867  92.375  -58.945  54.742  1
530868  92.403  -58.950  54.732  1
530869  92.430  -58.955  54.718  1
530870  92.470  -58.957  54.708  1
530871  92.517  -58.956  54.703  1
530872  92.565  -58.955  54.704  1
530873  92.612  -58.955  54.702  1
530874  92.659  -58.954  54.693  1
530875  92.707  -58.953  54.681  1
530876  92.754  -58.952  54.669  1
530877  92.801  -58.952  54.656  1
530878  92.849  -58.951  54.641  1
530879  92.896  -58.950  54.622  1
530880  92.943  -58.949  54.604  1
530881  92.991  -58.949  54.587  1
530882  93.038  -58.948  54.570  1
530883  93.080  -58.955  54.548  1
530884  93.119  -58.963  54.525  1
530885  93.157  -58.971  54.504  1
530886  93.196  -58.978  54.486  1
530887  93.234  -58.986  54.468  1
530888  93.273  -58.993  54.451  1
530889  93.312  -59.001  54.439  1
530890  93.351  -59.009  54.426  1
530891  93.389  -59.018  54.415  1
530892  93.428  -59.026  54.405  1
530893  93.466  -59.034  54.395  1
530894  93.504  -59.043  54.383  1
530895  93.541  -59.058  54.365  1
530896  93.576  -59.078  54.345  1
530897  93.611  -59.099  54.321  1
530898  93.646  -59.119  54.298  1
530899  93.681  -59.139  54.277  1
530900  93.716  -59.159  54.259  1
530901  93.751  -59.180  54.239  1
530902  93.786  -59.200  54.220  1
530903  93.821  -59.220  54.201  1
530904  93.856  -59.240  54.183  1
530905  93.891  -59.261  54.165  1
530906  93.926  -59.281  54.147  1
530907  93.961  -59.301  54.125  1
530908  93.996  -59.322  54.105  1
530909  94.031  -59.342  54.087  1
530910  94.066  -59.363  54.071  1
530911  94.101  -59.382  54.052  1
530912  94.136  -59.403  54.032  1
530913  94.171  -59.423  54.014  1
530914  94.206  -59.444  53.996  1
530915  94.241  -59.463  53.980  1
530916  94.276  -59.484  53.967  1
530917  94.311  -59.504  53.953  1
530918  94.346  -59.525  53.944  1
530919  94.381  -59.544  53.936  1
530920  94.416  -59.565  53.931  1
530921  94.450  -59.576  53.928  1
530922  94.484  -59.583  53.925  1
530923  94.518  -59.591  53.914  1
530924  94.552  -59.598  53.898  1
530925  94.589  -59.607  53.881  1
530926  94.627  -59.618  53.862  1
530927  94.666  -59.629  53.842  1
530928  94.704  -59.639  53.821  1
530929  94.744  -59.649  53.796  1
530930  94.784  -59.658  53.767  1
530931  94.825  -59.667  53.735  1
530932  94.866  -59.677  53.701  1
530933  94.906  -59.688  53.666  1
530934  94.947  -59.698  53.636  1
530935  94.988  -59.708  53.612  1
530936  95.028  -59.719  53.592  1
530937  95.069  -59.729  53.575  1
530938  95.109  -59.740  53.558  1
530939  95.149  -59.752  53.541  1
530940  95.189  -59.765  53.522  1
530941  95.230  -59.774  53.502  1
530942  95.271  -59.783  53.480  1
530943  95.312  -59.792  53.456  1
530944  95.353  -59.801  53.429  1
530945  95.394  -59.809  53.402  1
530946  95.435  -59.818  53.373  1
530947  95.472  -59.826  53.344  1
530948  95.504  -59.833  53.313  1
530949  95.534  -59.840  53.283  1
530950  95.563  -59.848  53.252  1
530951  95.592  -59.855  53.222  1
530952  95.621  -59.863  53.193  1
530953  95.654  -59.870  53.166  1
530954  95.688  -59.877  53.145  1
530955  95.723  -59.883  53.131  1
530956  95.757  -59.889  53.122  1
530957  95.792  -59.896  53.113  1
530958  95.826  -59.902  53.102  1
530959  95.861  -59.909  53.091  1
530960  95.895  -59.915  53.079  1
530961  95.930  -59.922  53.063  1
530962  95.966  -59.927  53.042  1
530963  96.004  -59.933  53.018  1
530964  96.041  -59.938  52.990  1
530965  96.079  -59.942  52.961  1
530966  96.116  -59.948  52.929  1
530967  96.154  -59.953  52.897  1
530968  96.191  -59.958  52.870  1
530969  96.229  -59.963  52.846  1
530970  96.265  -59.968  52.823  1
530971  96.302  -59.968  52.798  1
530972  96.338  -59.968  52.772  1
530973  96.375  -59.969  52.747  1
530974  96.411  -59.969  52.723  1
530975  96.448  -59.969  52.698  1
530976  96.487  -59.971  52.670  1
530977  96.533  -59.977  52.639  1
530978  96.579  -59.983  52.605  1
530979  96.624  -59.990  52.568  1
530980  96.670  -59.996  52.527  1
530981  96.713  -60.000  52.486  1
530982  96.751  -60.001  52.446  1
530983  96.789  -60.002  52.407  1
530984  96.825  -60.002  52.368  1
530985  96.857  -60.000  52.328  1
530986  96.889  -59.999  52.287  1
530987  96.923  -60.001  52.245  1
530988  96.957  -60.004  52.206  1
530989  96.991  -60.006  52.163  1
530990  97.024  -60.008  52.118  1
530991  97.058  -60.011  52.071  1
530992  97.088  -60.023  52.025  1
530993  97.118  -60.036  51.979  1
530994  97.149  -60.049  51.933  1
530995  97.179  -60.061  51.886  1
530996  97.210  -60.074  51.839  1
530997  97.240  -60.086  51.793  1
530998  97.270  -60.099  51.747  1
530999  97.306  -60.101  51.701  1
531000  97.343  -60.102  51.657  1
531001  97.380  -60.102  51.613  1
531002  97.417  -60.103  51.571  1
531003  97.453  -60.104  51.529  1
531004  97.490  -60.105  51.489  1
531005  97.527  -60.105  51.449  1
531006  97.566  -60.112  51.411  1
531007  97.607  -60.124  51.373  1
531008  97.648  -60.135  51.337  1
531009  97.689  -60.146  51.301  1
531010  97.730  -60.157  51.264  1
531011  97.771  -60.168  51.226  1
531012  97.812  -60.180  51.187  1
531013  97.853  -60.190  51.149  1
531014  97.894  -60.202  51.111  1
531015  97.935  -60.213  51.072  1
531016  97.965  -60.218  51.033  1
531017  97.987  -60.219  50.992  1
531018  98.010  -60.221  50.950  1
531019  98.032  -60.221  50.908  1
531020  98.055  -60.223  50.866  1
531021  98.072  -60.221  50.824  1
531022  98.087  -60.221  50.784  1
531023  98.103  -60.219  50.745  1
531024  98.129  -60.221  50.705  1
531025  98.168  -60.230  50.664  1
531026  98.213  -60.219  50.621  1
531027  98.259  -60.202  50.578  1
531028  98.306  -60.186  50.534  1
531029  98.347  -60.181  50.491  1
531030  98.383  -60.185  50.447  1
531031  98.419  -60.189  50.402  1
531032  98.455  -60.193  50.356  1
531033  98.492  -60.198  50.310  1
531034  98.528  -60.202  50.267  1
531035  98.564  -60.206  50.224  1
531036  98.600  -60.211  50.180  1
531037  98.637  -60.215  50.135  1
531038  98.673  -60.219  50.091  1
531039  98.709  -60.224  50.047  1
531040  98.745  -60.228  50.004  1
531041  98.782  -60.232  49.963  1
531452  87.941  -57.529  56.883  1
531453  87.986  -57.536  56.861  1
531454  88.031  -57.544  56.839  1
531455  88.075  -57.551  56.815  1
531456  88.120  -57.558  56.793  1
531457  88.164  -57.566  56.768  1
531458  88.199  -57.576  56.743  1
531459  88.233  -57.589  56.717  1
531460  88.266  -57.600  56.692  1
531461  88.300  -57.611  56.667  1
531462  88.333  -57.623  56.640  1
531463  88.367  -57.634  56.611  1
531464  88.401  -57.646  56.583  1
531465  88.434  -57.658  56.556  1
531466  88.468  -57.669  56.529  1
531467  88.502  -57.680  56.503  1
531468  88.536  -57.692  56.476  1
531469  88.569  -57.704  56.449  1
531470  88.603  -57.715  56.421  1
531471  88.637  -57.727  56.393  1
531472  88.671  -57.738  56.365  1
531473  88.704  -57.750  56.338  1
531474  88.738  -57.761  56.311  1
531475  88.771  -57.773  56.285  1
531476  88.805  -57.784  56.259  1
531477  88.838  -57.795  56.234  1
531478  88.862  -57.819  56.208  1
531479  88.887  -57.843  56.179  1
531480  88.911  -57.868  56.149  1
531481  88.941  -57.890  56.117  1
531482  88.984  -57.912  56.086  1
531483  89.027  -57.932  56.055  1
531484  89.071  -57.953  56.026  1
531485  89.115  -57.974  55.997  1
531486  89.164  -57.990  55.971  1
531487  89.212  -58.008  55.946  1
531488  89.262  -58.024  55.923  1
531489  89.311  -58.041  55.905  1
531490  89.359  -58.059  55.887  1
531491  89.409  -58.075  55.871  1
531492  89.458  -58.092  55.857  1
531493  89.507  -58.109  55.845  1
531494  89.556  -58.126  55.834  1
531495  89.600  -58.140  55.824  1
531496  89.636  -58.150  55.816  1
531497  89.672  -58.160  55.809  1
531498  89.709  -58.169  55.804  1
531499  89.755  -58.174  55.798  1
531500  89.800  -58.178  55.793  1
531501  89.845  -58.183  55.787  1
531502  89.890  -58.187  55.782  1
531503  89.936  -58.193  55.778  1
531504  89.981  -58.197  55.773  1
531505  90.026  -58.202  55.766  1
531506  90.064  -58.213  55.753  1
531507  90.097  -58.231  55.734  1
531508  90.129  -58.248  55.714  1
531509  90.162  -58.265  55.693  1
531510  90.195  -58.277  55.672  1
531511  90.233  -58.285  55.651  1
531512  90.275  -58.289  55.632  1
531513  90.318  -58.294  55.616  1
531514  90.357  -58.300  55.602  1
531515  90.395  -58.307  55.591  1
531516  90.433  -58.315  55.577  1
531517  90.471  -58.322  55.561  1
531518  90.509  -58.329  55.541  1
531519  90.546  -58.337  55.515  1
531520  90.584  -58.344  55.487  1
531521  90.622  -58.351  55.461  1
531522  90.660  -58.359  55.441  1
531523  90.699  -58.372  55.424  1
531524  90.741  -58.390  55.408  1
531525  90.783  -58.409  55.393  1
531526  90.824  -58.428  55.377  1
531527  90.865  -58.446  55.361  1
531528  90.906  -58.465  55.343  1
531529  90.948  -58.484  55.324  1
531530  90.990  -58.503  55.304  1
531531  91.031  -58.521  55.280  1
531532  91.072  -58.540  55.255  1
531533  91.113  -58.559  55.231  1
531534  91.154  -58.579  55.205  1
531535  91.194  -58.601  55.178  1
531536  91.232  -58.614  55.151  1
531537  91.270  -58.626  55.124  1
531538  91.308  -58.639  55.102  1
531539  91.346  -58.651  55.083  1
531540  91.384  -58.663  55.066  1
531541  91.423  -58.675  55.051  1
531542  91.460  -58.687  55.036  1
531543  91.499  -58.700  55.019  1
531544  91.537  -58.712  55.002  1
531545  91.575  -58.724  54.981  1
531546  91.612  -58.736  54.957  1
531547  91.648  -58.748  54.933  1
531548  91.684  -58.763  54.905  1
531549  91.720  -58.777  54.870  1
531550  91.756  -58.792  54.836  1
531551  91.793  -58.806  54.806  1
531552  91.828  -58.820  54.782  1
531553  91.865  -58.835  54.763  1
531554  91.901  -58.849  54.749  1
531555  91.937  -58.864  54.738  1
531556  91.973  -58.879  54.732  1
531557  92.009  -58.891  54.731  1
531558  92.044  -58.892  54.735  1
531559  92.080  -58.892  54.743  1
531560  92.116  -58.892  54.763  1
531561  92.151  -58.892  54.782  1
531562  92.187  -58.893  54.794  1
531563  92.222  -58.893  54.794  1
531564  92.258  -58.894  54.789  1
531565  92.293  -58.894  54.779  1
531566  92.328  -58.895  54.761  1
531567  92.362  -58.896  54.739  1
531568  92.389  -58.902  54.725  1
531569  92.417  -58.907  54.717  1
531570  92.445  -58.913  54.705  1
531571  92.485  -58.914  54.695  1
531572  92.532  -58.914  54.692  1
531573  92.579  -58.913  54.694  1
531574  92.627  -58.912  54.695  1
531575  92.674  -58.911  54.690  1
531576  92.721  -58.911  54.684  1
531577  92.769  -58.910  54.677  1
531578  92.816  -58.909  54.667  1
531579  92.863  -58.908  54.653  1
531580  92.911  -58.907  54.635  1
531581  92.957  -58.908  54.616  1
531582  93.003  -58.914  54.600  1
531583  93.049  -58.921  54.585  1
531584  93.087  -58.930  54.568  1
531585  93.126  -58.937  54.548  1
531586  93.165  -58.945  54.528  1
531587  93.204  -58.952  54.509  1
531588  93.242  -58.960  54.492  1
531589  93.281  -58.968  54.474  1
531590  93.320  -58.975  54.458  1
531591  93.359  -58.983  54.443  1
531592  93.397  -58.991  54.433  1
531593  93.436  -58.999  54.424  1
531594  93.475  -59.006  54.415  1
531595  93.513  -59.014  54.403  1
531596  93.550  -59.027  54.386  1
531597  93.586  -59.044  54.366  1
531598  93.621  -59.064  54.340  1
531599  93.655  -59.084  54.312  1
531600  93.691  -59.105  54.287  1
531601  93.725  -59.125  54.264  1
531602  93.761  -59.145  54.244  1
531603  93.795  -59.165  54.222  1
531604  93.831  -59.186  54.202  1
531605  93.865  -59.206  54.182  1
531606  93.901  -59.226  54.161  1
531607  93.935  -59.247  54.140  1
531608  93.971  -59.267  54.119  1
531609  94.005  -59.287  54.099  1
531610  94.041  -59.307  54.080  1
531611  94.075  -59.328  54.062  1
531612  94.110  -59.348  54.042  1
531613  94.145  -59.369  54.023  1
531614  94.180  -59.388  54.004  1
531615  94.215  -59.409  53.986  1
531616  94.250  -59.429  53.969  1
531617  94.285  -59.450  53.953  1
531618  94.320  -59.469  53.937  1
531619  94.355  -59.490  53.925  1
531620  94.390  -59.510  53.913  1
531621  94.425  -59.531  53.904  1
531622  94.459  -59.540  53.897  1
531623  94.493  -59.547  53.890  1
531624  94.527  -59.554  53.876  1
531625  94.561  -59.561  53.861  1
531626  94.597  -59.569  53.843  1
531627  94.635  -59.579  53.822  1
531628  94.673  -59.590  53.801  1
531629  94.711  -59.601  53.783  1
531630  94.752  -59.610  53.759  1
531631  94.793  -59.620  53.732  1
531632  94.834  -59.629  53.703  1
531633  94.875  -59.638  53.672  1
531634  94.915  -59.648  53.640  1
531635  94.956  -59.658  53.610  1
531636  94.996  -59.669  53.583  1
531637  95.037  -59.679  53.559  1
531638  95.077  -59.689  53.539  1
531639  95.118  -59.701  53.525  1
531640  95.158  -59.714  53.510  1
531641  95.197  -59.726  53.494  1
531642  95.238  -59.737  53.478  1
531643  95.278  -59.746  53.461  1
531644  95.320  -59.754  53.441  1
531645  95.361  -59.764  53.418  1
531646  95.402  -59.773  53.394  1
531647  95.443  -59.781  53.370  1
531648  95.482  -59.790  53.343  1
531649  95.513  -59.798  53.314  1
531650  95.542  -59.806  53.284  1
531651  95.570  -59.814  53.252  1
531652  95.600  -59.822  53.219  1
531653  95.629  -59.830  53.191  1
531654  95.661  -59.836  53.169  1
531655  95.695  -59.843  53.156  1
531656  95.730  -59.849  53.146  1
531657  95.764  -59.856  53.137  1
531658  95.799  -59.862  53.127  1
531659  95.833  -59.869  53.115  1
531660  95.868  -59.876  53.102  1
531661  95.902  -59.882  53.088  1
531662  95.936  -59.889  53.070  1
531663  95.971  -59.895  53.047  1
531664  96.009  -59.900  53.021  1
531665  96.046  -59.905  52.993  1
531666  96.084  -59.910  52.963  1
531667  96.121  -59.915  52.933  1
531668  96.159  -59.920  52.903  1
531669  96.196  -59.926  52.878  1
531670  96.233  -59.931  52.855  1
531671  96.270  -59.936  52.832  1
531672  96.307  -59.940  52.806  1
531673  96.343  -59.940  52.783  1
531674  96.380  -59.940  52.759  1
531675  96.416  -59.940  52.735  1
531676  96.453  -59.940  52.710  1
531677  96.493  -59.943  52.683  1
531678  96.539  -59.950  52.652  1
531679  96.585  -59.956  52.619  1
531680  96.631  -59.963  52.583  1
531681  96.673  -59.966  52.543  1
531682  96.712  -59.967  52.503  1
531683  96.750  -59.967  52.465  1
531684  96.789  -59.968  52.428  1
531685  96.822  -59.967  52.392  1
531686  96.854  -59.967  52.354  1
531687  96.886  -59.965  52.313  1
531688  96.920  -59.967  52.270  1
531689  96.953  -59.970  52.232  1
531690  96.987  -59.972  52.190  1
531691  97.021  -59.974  52.146  1
531692  97.054  -59.977  52.100  1
531693  97.088  -59.981  52.052  1
531694  97.118  -59.994  52.003  1
531695  97.148  -60.007  51.955  1
531696  97.178  -60.020  51.907  1
531697  97.209  -60.032  51.860  1
531698  97.239  -60.045  51.813  1
531699  97.269  -60.058  51.765  1
531700  97.304  -60.062  51.718  1
531701  97.341  -60.063  51.674  1
531702  97.377  -60.064  51.630  1
531703  97.414  -60.065  51.587  1
531704  97.451  -60.065  51.544  1
531705  97.488  -60.066  51.502  1
531706  97.525  -60.067  51.460  1
531707  97.566  -60.077  51.420  1
531708  97.606  -60.088  51.380  1
531709  97.647  -60.099  51.341  1
531710  97.688  -60.111  51.302  1
531711  97.729  -60.122  51.263  1
531712  97.770  -60.133  51.225  1
531713  97.811  -60.144  51.187  1
531714  97.852  -60.155  51.149  1
531715  97.893  -60.167  51.111  1
531716  97.934  -60.177  51.073  1
531717  97.975  -60.189  51.034  1
531718  98.004  -60.193  50.994  1
531719  98.026  -60.194  50.953  1
531720  98.049  -60.196  50.911  1
531721  98.071  -60.196  50.868  1
531722  98.087  -60.196  50.825  1
531723  98.103  -60.194  50.783  1
531724  98.119  -60.193  50.743  1
531725  98.135  -60.191  50.703  1
531726  98.169  -60.198  50.661  1
531727  98.212  -60.197  50.618  1
531728  98.258  -60.181  50.575  1
531729  98.304  -60.164  50.532  1
531730  98.351  -60.146  50.490  1
531731  98.389  -60.147  50.449  1
531732  98.425  -60.152  50.405  1
531733  98.461  -60.156  50.360  1
531734  98.498  -60.161  50.316  1
531735  98.534  -60.165  50.273  1
531736  98.570  -60.169  50.230  1
531737  98.606  -60.174  50.187  1
531738  98.643  -60.177  50.142  1
531739  98.679  -60.182  50.098  1
531740  98.716  -60.187  50.054  1
531741  98.752  -60.191  50.011  1
531742  98.788  -60.191  49.969  1
531743  98.820  -60.168  49.927  1
532163  88.346  -57.579  56.626  1
532164  88.380  -57.590  56.600  1
532165  88.413  -57.602  56.572  1
532166  88.447  -57.614  56.543  1
532167  88.480  -57.625  56.517  1
532168  88.514  -57.636  56.491  1
532169  88.548  -57.648  56.464  1
532170  88.581  -57.660  56.438  1
532171  88.615  -57.671  56.411  1
532172  88.649  -57.683  56.384  1
532173  88.683  -57.694  56.357  1
532174  88.716  -57.706  56.331  1
532175  88.750  -57.717  56.306  1
532176  88.784  -57.729  56.280  1
532177  88.818  -57.740  56.256  1
532178  88.856  -57.757  56.232  1
532179  88.881  -57.780  56.207  1
532180  88.905  -57.804  56.180  1
532181  88.930  -57.828  56.152  1
532182  88.954  -57.852  56.122  1
532183  88.983  -57.876  56.092  1
532184  89.029  -57.895  56.062  1
532185  89.079  -57.912  56.033  1
532186  89.127  -57.929  56.005  1
532187  89.177  -57.946  55.978  1
532188  89.226  -57.962  55.953  1
532189  89.274  -57.980  55.929  1
532190  89.324  -57.996  55.909  1
532191  89.373  -58.013  55.891  1
532192  89.421  -58.031  55.875  1
532193  89.471  -58.047  55.861  1
532194  89.520  -58.065  55.848  1
532195  89.569  -58.081  55.837  1
532196  89.615  -58.096  55.827  1
532197  89.652  -58.106  55.818  1
532198  89.688  -58.117  55.812  1
532199  89.724  -58.127  55.806  1
532200  89.761  -58.137  55.801  1
532201  89.806  -58.141  55.794  1
532202  89.851  -58.146  55.788  1
532203  89.896  -58.150  55.781  1
532204  89.942  -58.155  55.775  1
532205  89.986  -58.159  55.768  1
532206  90.032  -58.164  55.759  1
532207  90.075  -58.171  55.745  1
532208  90.107  -58.188  55.726  1
532209  90.140  -58.206  55.707  1
532210  90.172  -58.223  55.688  1
532211  90.206  -58.234  55.668  1
532212  90.240  -58.246  55.648  1
532213  90.281  -58.252  55.628  1
532214  90.323  -58.256  55.609  1
532215  90.365  -58.261  55.590  1
532216  90.407  -58.266  55.575  1
532217  90.446  -58.272  55.559  1
532218  90.483  -58.280  55.541  1
532219  90.521  -58.287  55.521  1
532220  90.559  -58.294  55.498  1
532221  90.597  -58.301  55.474  1
532222  90.635  -58.309  55.452  1
532223  90.673  -58.316  55.434  1
532224  90.711  -58.323  55.417  1
532225  90.751  -58.341  55.400  1
532226  90.793  -58.359  55.382  1
532227  90.834  -58.378  55.365  1
532228  90.876  -58.397  55.348  1
532229  90.917  -58.415  55.330  1
532230  90.959  -58.434  55.313  1
532231  91.000  -58.453  55.294  1
532232  91.041  -58.471  55.270  1
532233  91.083  -58.490  55.243  1
532234  91.124  -58.510  55.219  1
532235  91.164  -58.533  55.196  1
532236  91.204  -58.557  55.171  1
532237  91.243  -58.580  55.143  1
532238  91.281  -58.592  55.117  1
532239  91.319  -58.604  55.096  1
532240  91.357  -58.617  55.078  1
532241  91.395  -58.629  55.062  1
532242  91.433  -58.642  55.048  1
532243  91.471  -58.654  55.035  1
532244  91.510  -58.666  55.022  1
532245  91.547  -58.678  55.010  1
532246  91.586  -58.690  54.995  1
532247  91.622  -58.702  54.975  1
532248  91.657  -58.712  54.954  1
532249  91.693  -58.721  54.927  1
532250  91.729  -58.736  54.893  1
532251  91.765  -58.750  54.857  1
532252  91.801  -58.764  54.824  1
532253  91.837  -58.780  54.797  1
532254  91.873  -58.794  54.774  1
532255  91.909  -58.808  54.756  1
532256  91.945  -58.823  54.742  1
532257  91.982  -58.837  54.732  1
532258  92.017  -58.852  54.727  1
532259  92.053  -58.853  54.727  1
532260  92.088  -58.853  54.730  1
532261  92.124  -58.854  54.741  1
532262  92.159  -58.854  54.756  1
532263  92.195  -58.855  54.767  1
532264  92.230  -58.855  54.768  1
532265  92.266  -58.855  54.759  1
532266  92.301  -58.855  54.746  1
532267  92.337  -58.856  54.729  1
532268  92.372  -58.856  54.713  1
532269  92.404  -58.859  54.703  1
532270  92.432  -58.864  54.697  1
532271  92.459  -58.870  54.692  1
532272  92.499  -58.872  54.698  1
532273  92.547  -58.871  54.709  1
532274  92.594  -58.870  54.716  1
532275  92.641  -58.869  54.717  1
532276  92.689  -58.868  54.712  1
532277  92.736  -58.867  54.706  1
532278  92.783  -58.867  54.698  1
532279  92.831  -58.866  54.687  1
532280  92.877  -58.869  54.671  1
532281  92.923  -58.875  54.650  1
532282  92.968  -58.881  54.630  1
532283  93.014  -58.886  54.611  1
532284  93.058  -58.893  54.594  1
532285  93.095  -58.903  54.581  1
532286  93.134  -58.911  54.564  1
532287  93.173  -58.919  54.544  1
532288  93.212  -58.927  54.525  1
532289  93.251  -58.934  54.507  1
532290  93.289  -58.942  54.489  1
532291  93.328  -58.949  54.471  1
532292  93.366  -58.958  54.456  1
532293  93.405  -58.965  54.444  1
532294  93.444  -58.973  54.434  1
532295  93.483  -58.980  54.424  1
532296  93.521  -58.989  54.412  1
532297  93.558  -59.002  54.397  1
532298  93.594  -59.016  54.378  1
532299  93.630  -59.030  54.355  1
532300  93.665  -59.050  54.330  1
532301  93.700  -59.070  54.305  1
532302  93.735  -59.090  54.279  1
532303  93.770  -59.111  54.258  1
532304  93.805  -59.131  54.236  1
532305  93.840  -59.151  54.214  1
532306  93.875  -59.171  54.194  1
532307  93.910  -59.192  54.173  1
532308  93.945  -59.212  54.149  1
532309  93.980  -59.232  54.128  1
532310  94.015  -59.253  54.106  1
532311  94.050  -59.273  54.084  1
532312  94.085  -59.294  54.061  1
532313  94.120  -59.313  54.038  1
532314  94.155  -59.334  54.021  1
532315  94.190  -59.354  54.003  1
532316  94.224  -59.375  53.985  1
532317  94.260  -59.394  53.967  1
532318  94.294  -59.415  53.947  1
532319  94.330  -59.435  53.929  1
532320  94.364  -59.456  53.914  1
532321  94.400  -59.475  53.899  1
532322  94.434  -59.496  53.885  1
532323  94.469  -59.504  53.873  1
532324  94.502  -59.510  53.862  1
532325  94.537  -59.517  53.848  1
532326  94.570  -59.525  53.833  1
532327  94.605  -59.532  53.816  1
532328  94.642  -59.541  53.795  1
532329  94.680  -59.552  53.773  1
532330  94.720  -59.563  53.753  1
532331  94.761  -59.572  53.729  1
532332  94.802  -59.581  53.702  1
532333  94.842  -59.590  53.672  1
532334  94.883  -59.599  53.642  1
532335  94.924  -59.609  53.611  1
532336  94.964  -59.619  53.582  1
532337  95.005  -59.629  53.555  1
532338  95.046  -59.639  53.529  1
532339  95.086  -59.650  53.508  1
532340  95.126  -59.662  53.490  1
532341  95.166  -59.675  53.475  1
532342  95.205  -59.687  53.459  1
532343  95.245  -59.700  53.444  1
532344  95.286  -59.709  53.429  1
532345  95.327  -59.718  53.412  1
532346  95.369  -59.726  53.392  1
532347  95.409  -59.736  53.373  1
532348  95.451  -59.744  53.354  1
532349  95.486  -59.754  53.332  1
532350  95.519  -59.764  53.306  1
532351  95.549  -59.773  53.275  1
532352  95.578  -59.780  53.243  1
532353  95.607  -59.788  53.216  1
532354  95.636  -59.796  53.195  1
532355  95.668  -59.803  53.179  1
532356  95.702  -59.810  53.169  1
532357  95.737  -59.816  53.160  1
532358  95.771  -59.823  53.151  1
532359  95.806  -59.829  53.141  1
532360  95.840  -59.836  53.128  1
532361  95.874  -59.842  53.112  1
532362  95.908  -59.849  53.097  1
532363  95.942  -59.855  53.076  1
532364  95.977  -59.862  53.051  1
532365  96.014  -59.867  53.024  1
532366  96.052  -59.872  52.996  1
532367  96.089  -59.877  52.969  1
532368  96.127  -59.883  52.938  1
532369  96.164  -59.888  52.911  1
532370  96.201  -59.893  52.887  1
532371  96.238  -59.898  52.864  1
532372  96.274  -59.904  52.840  1
532373  96.311  -59.909  52.814  1
532374  96.348  -59.911  52.792  1
532375  96.385  -59.911  52.769  1
532376  96.421  -59.911  52.746  1
532377  96.457  -59.911  52.722  1
532378  96.500  -59.916  52.695  1
532379  96.546  -59.923  52.664  1
532380  96.592  -59.929  52.631  1
532381  96.635  -59.933  52.595  1
532382  96.673  -59.933  52.557  1
532383  96.711  -59.934  52.518  1
532384  96.749  -59.935  52.481  1
532385  96.786  -59.935  52.448  1
532386  96.818  -59.934  52.414  1
532387  96.850  -59.933  52.378  1
532388  96.882  -59.932  52.338  1
532389  96.916  -59.934  52.296  1
532390  96.950  -59.936  52.258  1
532391  96.983  -59.939  52.217  1
532392  97.017  -59.941  52.175  1
532393  97.051  -59.943  52.129  1
532394  97.085  -59.946  52.080  1
532395  97.117  -59.952  52.029  1
532396  97.148  -59.965  51.978  1
532397  97.178  -59.978  51.929  1
532398  97.208  -59.991  51.881  1
532399  97.238  -60.003  51.834  1
532400  97.268  -60.016  51.785  1
532401  97.302  -60.024  51.738  1
532402  97.338  -60.024  51.694  1
532403  97.375  -60.024  51.650  1
532404  97.412  -60.025  51.606  1
532405  97.449  -60.026  51.562  1
532406  97.486  -60.027  51.519  1
532407  97.524  -60.030  51.476  1
532408  97.565  -60.042  51.434  1
532409  97.606  -60.053  51.392  1
532410  97.647  -60.065  51.350  1
532411  97.687  -60.075  51.309  1
532412  97.728  -60.086  51.268  1
532413  97.770  -60.098  51.228  1
532414  97.810  -60.108  51.189  1
532415  97.851  -60.120  51.151  1
532416  97.892  -60.131  51.112  1
532417  97.933  -60.143  51.073  1
532418  97.974  -60.153  51.034  1
532419  98.015  -60.165  50.995  1
532420  98.042  -60.168  50.955  1
532421  98.065  -60.170  50.913  1
532422  98.087  -60.171  50.870  1
532423  98.102  -60.169  50.828  1
532424  98.119  -60.168  50.786  1
532425  98.134  -60.167  50.746  1
532426  98.150  -60.165  50.705  1
532427  98.171  -60.166  50.663  1
532428  98.211  -60.174  50.621  1
532429  98.257  -60.159  50.578  1
532430  98.303  -60.141  50.536  1
532431  98.350  -60.124  50.494  1
532432  98.395  -60.110  50.452  1
532433  98.431  -60.115  50.409  1
532434  98.467  -60.119  50.366  1
532435  98.504  -60.123  50.323  1
532436  98.541  -60.127  50.279  1
532437  98.577  -60.132  50.237  1
532438  98.613  -60.136  50.195  1
532439  98.649  -60.140  50.151  1
532440  98.686  -60.145  50.107  1
532441  98.722  -60.149  50.063  1
532442  98.758  -60.153  50.020  1
532443  98.793  -60.150  49.976  1
532444  98.827  -60.127  49.935  1
532445  98.859  -60.105  49.892  1
532866  88.425  -57.558  56.559  1
532867  88.459  -57.570  56.531  1
532868  88.493  -57.581  56.504  1
532869  88.527  -57.592  56.478  1
532870  88.560  -57.604  56.452  1
532871  88.594  -57.616  56.426  1
532872  88.627  -57.627  56.400  1
532873  88.661  -57.639  56.375  1
532874  88.695  -57.650  56.349  1
532875  88.729  -57.662  56.325  1
532876  88.762  -57.673  56.300  1
532877  88.797  -57.686  56.275  1
532878  88.835  -57.702  56.251  1
532879  88.874  -57.718  56.226  1
532880  88.900  -57.741  56.203  1
532881  88.924  -57.765  56.178  1
532882  88.949  -57.789  56.152  1
532883  88.973  -57.814  56.124  1
532884  88.998  -57.836  56.095  1
532885  89.042  -57.850  56.067  1
532886  89.091  -57.867  56.039  1
532887  89.140  -57.883  56.011  1
532888  89.189  -57.901  55.983  1
532889  89.238  -57.918  55.957  1
532890  89.287  -57.934  55.933  1
532891  89.336  -57.952  55.913  1
532892  89.386  -57.968  55.895  1
532893  89.435  -57.986  55.878  1
532894  89.483  -58.003  55.864  1
532895  89.533  -58.019  55.851  1
532896  89.582  -58.037  55.840  1
532897  89.631  -58.053  55.830  1
532898  89.667  -58.063  55.822  1
532899  89.703  -58.073  55.815  1
532900  89.740  -58.083  55.809  1
532901  89.776  -58.093  55.804  1
532902  89.813  -58.103  55.797  1
532903  89.857  -58.109  55.790  1
532904  89.902  -58.113  55.783  1
532905  89.947  -58.118  55.775  1
532906  89.992  -58.122  55.766  1
532907  90.038  -58.127  55.755  1
532908  90.083  -58.131  55.740  1
532909  90.118  -58.146  55.722  1
532910  90.150  -58.163  55.703  1
532911  90.183  -58.181  55.686  1
532912  90.217  -58.193  55.666  1
532913  90.250  -58.204  55.646  1
532914  90.286  -58.214  55.627  1
532915  90.328  -58.219  55.607  1
532916  90.370  -58.223  55.586  1
532917  90.412  -58.228  55.568  1
532918  90.454  -58.232  55.550  1
532919  90.496  -58.237  55.531  1
532920  90.534  -58.244  55.511  1
532921  90.572  -58.252  55.491  1
532922  90.610  -58.259  55.467  1
532923  90.648  -58.266  55.447  1
532924  90.686  -58.274  55.426  1
532925  90.724  -58.281  55.403  1
532926  90.762  -58.291  55.383  1
532927  90.804  -58.309  55.363  1
532928  90.845  -58.328  55.346  1
532929  90.886  -58.347  55.329  1
532930  90.928  -58.366  55.314  1
532931  90.969  -58.384  55.299  1
532932  91.011  -58.403  55.282  1
532933  91.052  -58.422  55.258  1
532934  91.093  -58.440  55.228  1
532935  91.134  -58.463  55.202  1
532936  91.173  -58.488  55.179  1
532937  91.213  -58.511  55.155  1
532938  91.252  -58.535  55.129  1
532939  91.292  -58.558  55.104  1
532940  91.330  -58.571  55.083  1
532941  91.368  -58.583  55.066  1
532942  91.406  -58.595  55.050  1
532943  91.444  -58.607  55.035  1
532944  91.483  -58.620  55.023  1
532945  91.521  -58.632  55.012  1
532946  91.559  -58.645  55.001  1
532947  91.597  -58.657  54.988  1
532948  91.631  -58.668  54.973  1
532949  91.666  -58.678  54.954  1
532950  91.702  -58.687  54.931  1
532951  91.737  -58.697  54.903  1
532952  91.773  -58.709  54.872  1
532953  91.809  -58.723  54.841  1
532954  91.846  -58.738  54.811  1
532955  91.881  -58.752  54.784  1
532956  91.918  -58.767  54.763  1
532957  91.954  -58.781  54.748  1
532958  91.990  -58.795  54.736  1
532959  92.026  -58.810  54.725  1
532960  92.062  -58.814  54.720  1
532961  92.097  -58.814  54.718  1
532962  92.133  -58.815  54.721  1
532963  92.168  -58.815  54.729  1
532964  92.203  -58.816  54.739  1
532965  92.239  -58.816  54.740  1
532966  92.274  -58.817  54.732  1
532967  92.310  -58.817  54.722  1
532968  92.345  -58.817  54.711  1
532969  92.381  -58.817  54.699  1
532970  92.416  -58.818  54.690  1
532971  92.446  -58.822  54.686  1
532972  92.474  -58.827  54.687  1
532973  92.514  -58.829  54.697  1
532974  92.561  -58.828  54.709  1
532975  92.609  -58.827  54.715  1
532976  92.656  -58.827  54.715  1
532977  92.703  -58.826  54.713  1
532978  92.751  -58.825  54.707  1
532979  92.796  -58.830  54.696  1
532980  92.842  -58.836  54.684  1
532981  92.888  -58.841  54.669  1
532982  92.933  -58.847  54.651  1
532983  92.979  -58.853  54.633  1
532984  93.024  -58.859  54.616  1
532985  93.066  -58.867  54.599  1
532986  93.103  -58.877  54.583  1
532987  93.142  -58.886  54.567  1
532988  93.181  -58.893  54.550  1
532989  93.219  -58.901  54.531  1
532990  93.258  -58.908  54.513  1
532991  93.297  -58.916  54.496  1
532992  93.336  -58.924  54.480  1
532993  93.374  -58.932  54.465  1
532994  93.413  -58.940  54.453  1
532995  93.452  -58.947  54.441  1
532996  93.490  -58.955  54.429  1
532997  93.529  -58.964  54.417  1
532998  93.565  -58.977  54.403  1
532999  93.602  -58.991  54.385  1
533000  93.638  -59.005  54.365  1
533001  93.674  -59.018  54.344  1
533002  93.709  -59.036  54.320  1
533003  93.745  -59.056  54.295  1
533004  93.779  -59.077  54.273  1
533005  93.815  -59.096  54.252  1
533006  93.849  -59.117  54.231  1
533007  93.885  -59.137  54.210  1
533008  93.919  -59.158  54.189  1
533009  93.955  -59.178  54.166  1
533010  93.989  -59.198  54.143  1
533011  94.024  -59.218  54.120  1
533012  94.059  -59.239  54.098  1
533013  94.094  -59.259  54.077  1
533014  94.129  -59.279  54.057  1
533015  94.164  -59.300  54.037  1
533016  94.199  -59.319  54.018  1
533017  94.234  -59.340  54.000  1
533018  94.269  -59.360  53.981  1
533019  94.304  -59.381  53.961  1
533020  94.339  -59.400  53.941  1
533021  94.374  -59.421  53.921  1
533022  94.409  -59.441  53.902  1
533023  94.444  -59.460  53.884  1
533024  94.478  -59.466  53.869  1
533025  94.512  -59.474  53.857  1
533026  94.546  -59.481  53.843  1
533027  94.580  -59.488  53.828  1
533028  94.614  -59.495  53.810  1
533029  94.649  -59.504  53.787  1
533030  94.688  -59.514  53.762  1
533031  94.729  -59.524  53.735  1
533032  94.769  -59.533  53.707  1
533033  94.810  -59.542  53.677  1
533034  94.851  -59.551  53.645  1
533035  94.892  -59.561  53.613  1
533036  94.932  -59.570  53.585  1
533037  94.973  -59.579  53.558  1
533038  95.014  -59.589  53.532  1
533039  95.054  -59.600  53.507  1
533040  95.095  -59.610  53.484  1
533041  95.134  -59.623  53.464  1
533042  95.174  -59.635  53.447  1
533043  95.214  -59.648  53.430  1
533044  95.254  -59.661  53.415  1
533045  95.294  -59.673  53.400  1
533046  95.335  -59.681  53.386  1
533047  95.376  -59.690  53.369  1
533048  95.417  -59.698  53.352  1
533049  95.457  -59.707  53.334  1
533050  95.489  -59.718  53.315  1
533051  95.522  -59.728  53.293  1
533052  95.555  -59.738  53.265  1
533053  95.586  -59.747  53.240  1
533054  95.615  -59.754  53.222  1
533055  95.644  -59.762  53.207  1
533056  95.675  -59.770  53.195  1
533057  95.709  -59.776  53.186  1
533058  95.744  -59.783  53.177  1
533059  95.778  -59.789  53.166  1
533060  95.813  -59.795  53.155  1
533061  95.846  -59.802  53.142  1
533062  95.881  -59.809  53.126  1
533063  95.914  -59.816  53.108  1
533064  95.948  -59.823  53.084  1
533065  95.982  -59.830  53.058  1
533066  96.020  -59.835  53.031  1
533067  96.057  -59.839  53.003  1
533068  96.095  -59.845  52.973  1
533069  96.131  -59.850  52.945  1
533070  96.168  -59.855  52.919  1
533071  96.205  -59.861  52.896  1
533072  96.242  -59.866  52.873  1
533073  96.279  -59.871  52.848  1
533074  96.316  -59.877  52.822  1
533075  96.353  -59.882  52.801  1
533076  96.389  -59.883  52.780  1
533077  96.426  -59.883  52.757  1
533078  96.462  -59.883  52.733  1
533079  96.507  -59.889  52.704  1
533080  96.552  -59.895  52.672  1
533081  96.595  -59.899  52.640  1
533082  96.633  -59.900  52.604  1
533083  96.672  -59.901  52.566  1
533084  96.711  -59.902  52.529  1
533085  96.749  -59.902  52.496  1
533086  96.783  -59.902  52.464  1
533087  96.815  -59.900  52.433  1
533088  96.847  -59.898  52.399  1
533089  96.879  -59.898  52.362  1
533090  96.912  -59.901  52.323  1
533091  96.946  -59.903  52.285  1
533092  96.980  -59.905  52.246  1
533093  97.014  -59.908  52.205  1
533094  97.047  -59.910  52.160  1
533095  97.082  -59.912  52.109  1
533096  97.115  -59.914  52.055  1
533097  97.147  -59.924  52.003  1
533098  97.177  -59.936  51.952  1
533099  97.207  -59.949  51.904  1
533100  97.237  -59.962  51.856  1
533101  97.267  -59.974  51.807  1
533102  97.299  -59.984  51.761  1
533103  97.336  -59.985  51.717  1
533104  97.373  -59.986  51.673  1
533105  97.410  -59.986  51.628  1
533106  97.447  -59.987  51.584  1
533107  97.484  -59.988  51.539  1
533108  97.523  -59.996  51.495  1
533109  97.564  -60.007  51.450  1
533110  97.605  -60.018  51.406  1
533111  97.646  -60.029  51.362  1
533112  97.687  -60.040  51.319  1
533113  97.728  -60.051  51.277  1
533114  97.769  -60.062  51.235  1
533115  97.809  -60.074  51.194  1
533116  97.851  -60.085  51.155  1
533117  97.891  -60.096  51.115  1
533118  97.932  -60.107  51.075  1
533119  97.973  -60.118  51.036  1
533120  98.014  -60.129  50.997  1
533121  98.055  -60.140  50.957  1
533122  98.081  -60.143  50.915  1
533123  98.102  -60.144  50.874  1
533124  98.118  -60.143  50.832  1
533125  98.134  -60.142  50.792  1
533126  98.150  -60.140  50.751  1
533127  98.166  -60.139  50.710  1
533128  98.181  -60.137  50.668  1
533129  98.212  -60.142  50.627  1
533130  98.256  -60.136  50.584  1
533131  98.302  -60.119  50.541  1
533132  98.349  -60.102  50.500  1
533133  98.395  -60.086  50.458  1
533134  98.438  -60.077  50.415  1
533135  98.474  -60.081  50.373  1
533136  98.510  -60.086  50.330  1
533137  98.547  -60.090  50.287  1
533138  98.583  -60.094  50.245  1
533139  98.619  -60.099  50.203  1
533140  98.655  -60.103  50.159  1
533141  98.692  -60.108  50.115  1
533142  98.728  -60.112  50.072  1
533143  98.764  -60.116  50.028  1
533144  98.799  -60.109  49.985  1
533145  98.832  -60.086  49.943  1
533146  98.865  -60.065  49.900  1
533147  98.906  -60.047  49.858  1
533568  88.471  -57.526  56.519  1
533569  88.505  -57.537  56.491  1
533570  88.539  -57.548  56.465  1
533571  88.572  -57.560  56.440  1
533572  88.606  -57.572  56.415  1
533573  88.640  -57.583  56.390  1
533574  88.674  -57.595  56.366  1
533575  88.707  -57.606  56.341  1
533576  88.741  -57.617  56.316  1
533577  88.777  -57.632  56.291  1
533578  88.815  -57.648  56.267  1
533579  88.853  -57.664  56.243  1
533580  88.892  -57.680  56.219  1
533581  88.918  -57.702  56.197  1
533582  88.943  -57.726  56.173  1
533583  88.967  -57.750  56.148  1
533584  88.991  -57.774  56.122  1
533585  89.018  -57.797  56.097  1
533586  89.059  -57.808  56.069  1
533587  89.104  -57.822  56.042  1
533588  89.153  -57.839  56.015  1
533589  89.202  -57.855  55.987  1
533590  89.251  -57.873  55.961  1
533591  89.300  -57.890  55.937  1
533592  89.349  -57.907  55.917  1
533593  89.398  -57.924  55.898  1
533594  89.448  -57.940  55.881  1
533595  89.496  -57.958  55.866  1
533596  89.545  -57.974  55.854  1
533597  89.595  -57.991  55.843  1
533598  89.644  -58.009  55.833  1
533599  89.683  -58.020  55.826  1
533600  89.719  -58.030  55.820  1
533601  89.756  -58.040  55.814  1
533602  89.792  -58.050  55.809  1
533603  89.828  -58.059  55.803  1
533604  89.865  -58.070  55.796  1
533605  89.908  -58.075  55.788  1
533606  89.953  -58.081  55.780  1
533607  89.998  -58.085  55.769  1
533608  90.043  -58.090  55.757  1
533609  90.089  -58.094  55.742  1
533610  90.128  -58.104  55.724  1
533611  90.161  -58.122  55.705  1
533612  90.193  -58.139  55.686  1
533613  90.227  -58.150  55.667  1
533614  90.261  -58.162  55.648  1
533615  90.295  -58.173  55.629  1
533616  90.333  -58.181  55.609  1
533617  90.376  -58.186  55.587  1
533618  90.417  -58.191  55.567  1
533619  90.460  -58.195  55.548  1
533620  90.502  -58.200  55.528  1
533621  90.544  -58.204  55.509  1
533622  90.585  -58.209  55.491  1
533623  90.622  -58.216  55.470  1
533624  90.661  -58.224  55.451  1
533625  90.698  -58.231  55.430  1
533626  90.736  -58.238  55.407  1
533627  90.774  -58.246  55.384  1
533628  90.814  -58.260  55.358  1
533629  90.856  -58.278  55.336  1
533630  90.897  -58.297  55.319  1
533631  90.938  -58.316  55.304  1
533632  90.979  -58.334  55.288  1
533633  91.021  -58.353  55.269  1
533634  91.063  -58.372  55.244  1
533635  91.103  -58.393  55.211  1
533636  91.143  -58.417  55.181  1
533637  91.182  -58.441  55.153  1
533638  91.222  -58.466  55.129  1
533639  91.262  -58.489  55.108  1
533640  91.301  -58.513  55.089  1
533641  91.341  -58.537  55.070  1
533642  91.379  -58.549  55.053  1
533643  91.417  -58.561  55.037  1
533644  91.455  -58.574  55.023  1
533645  91.494  -58.586  55.013  1
533646  91.531  -58.598  55.003  1
533647  91.570  -58.610  54.993  1
533648  91.608  -58.623  54.982  1
533649  91.641  -58.633  54.972  1
533650  91.674  -58.644  54.958  1
533651  91.710  -58.653  54.939  1
533652  91.746  -58.663  54.918  1
533653  91.782  -58.672  54.893  1
533654  91.818  -58.682  54.865  1
533655  91.854  -58.696  54.833  1
533656  91.890  -58.711  54.810  1
533657  91.926  -58.725  54.785  1
533658  91.962  -58.739  54.761  1
533659  91.998  -58.754  54.742  1
533660  92.034  -58.768  54.730  1
533661  92.070  -58.776  54.721  1
533662  92.105  -58.776  54.715  1
533663  92.141  -58.777  54.712  1
533664  92.176  -58.777  54.711  1
533665  92.212  -58.777  54.712  1
533666  92.247  -58.777  54.711  1
533667  92.283  -58.778  54.708  1
533668  92.318  -58.778  54.707  1
533669  92.354  -58.779  54.705  1
533670  92.389  -58.779  54.698  1
533671  92.425  -58.780  54.688  1
533672  92.460  -58.780  54.684  1
533673  92.489  -58.785  54.688  1
533674  92.528  -58.786  54.695  1
533675  92.576  -58.786  54.701  1
533676  92.623  -58.785  54.702  1
533677  92.670  -58.784  54.703  1
533678  92.716  -58.790  54.704  1
533679  92.762  -58.796  54.701  1
533680  92.807  -58.802  54.692  1
533681  92.853  -58.808  54.678  1
533682  92.899  -58.814  54.662  1
533683  92.944  -58.820  54.649  1
533684  92.990  -58.826  54.635  1
533685  93.036  -58.832  54.621  1
533686  93.074  -58.841  54.607  1
533687  93.112  -58.851  54.591  1
533688  93.150  -58.860  54.576  1
533689  93.189  -58.867  54.560  1
533690  93.227  -58.875  54.542  1
533691  93.266  -58.883  54.525  1
533692  93.305  -58.890  54.509  1
533693  93.344  -58.899  54.493  1
533694  93.382  -58.906  54.477  1
533695  93.421  -58.914  54.463  1
533696  93.460  -58.921  54.449  1
533697  93.498  -58.929  54.435  1
533698  93.536  -58.939  54.420  1
533699  93.572  -58.952  54.405  1
533700  93.609  -58.966  54.388  1
533701  93.645  -58.980  54.370  1
533702  93.682  -58.993  54.350  1
533703  93.718  -59.007  54.330  1
533704  93.754  -59.021  54.311  1
533705  93.789  -59.042  54.291  1
533706  93.824  -59.062  54.272  1
533707  93.859  -59.083  54.251  1
533708  93.894  -59.102  54.230  1
533709  93.929  -59.123  54.207  1
533710  93.964  -59.143  54.185  1
533711  93.999  -59.164  54.161  1
533712  94.034  -59.184  54.138  1
533713  94.069  -59.204  54.116  1
533714  94.104  -59.225  54.096  1
533715  94.139  -59.245  54.078  1
533716  94.174  -59.265  54.058  1
533717  94.208  -59.285  54.037  1
533718  94.244  -59.306  54.017  1
533719  94.278  -59.326  53.998  1
533720  94.314  -59.346  53.977  1
533721  94.348  -59.366  53.955  1
533722  94.384  -59.387  53.932  1
533723  94.418  -59.407  53.912  1
533724  94.453  -59.423  53.893  1
533725  94.487  -59.430  53.877  1
533726  94.521  -59.438  53.865  1
533727  94.555  -59.444  53.853  1
533728  94.589  -59.451  53.839  1
533729  94.623  -59.459  53.821  1
533730  94.657  -59.466  53.799  1
533731  94.696  -59.475  53.771  1
533732  94.737  -59.485  53.738  1
533733  94.778  -59.494  53.704  1
533734  94.818  -59.504  53.670  1
533735  94.859  -59.513  53.636  1
533736  94.900  -59.522  53.604  1
533737  94.941  -59.532  53.578  1
533738  94.981  -59.541  53.554  1
533739  95.022  -59.550  53.531  1
533740  95.063  -59.560  53.507  1
533741  95.103  -59.571  53.481  1
533742  95.143  -59.584  53.458  1
533743  95.183  -59.597  53.437  1
533744  95.222  -59.610  53.418  1
533745  95.262  -59.622  53.400  1
533746  95.302  -59.635  53.381  1
533747  95.342  -59.645  53.365  1
533748  95.384  -59.653  53.349  1
533749  95.424  -59.662  53.331  1
533750  95.460  -59.671  53.312  1
533751  95.493  -59.682  53.294  1
533752  95.526  -59.692  53.277  1
533753  95.558  -59.702  53.256  1
533754  95.591  -59.712  53.243  1
533755  95.622  -59.721  53.234  1
533756  95.652  -59.729  53.225  1
533757  95.682  -59.736  53.216  1
533758  95.716  -59.742  53.207  1
533759  95.751  -59.749  53.195  1
533760  95.785  -59.756  53.182  1
533761  95.819  -59.763  53.169  1
533762  95.853  -59.769  53.155  1
533763  95.887  -59.776  53.139  1
533764  95.920  -59.783  53.120  1
533765  95.955  -59.789  53.094  1
533766  95.988  -59.796  53.067  1
533767  96.025  -59.802  53.039  1
533768  96.062  -59.807  53.010  1
533769  96.099  -59.812  52.980  1
533770  96.136  -59.817  52.954  1
533771  96.173  -59.823  52.930  1
533772  96.210  -59.828  52.907  1
533773  96.247  -59.833  52.885  1
533774  96.284  -59.839  52.860  1
533775  96.321  -59.844  52.834  1
533776  96.358  -59.849  52.812  1
533777  96.394  -59.855  52.790  1
533778  96.431  -59.855  52.767  1
533779  96.467  -59.855  52.742  1
533780  96.513  -59.861  52.712  1
533781  96.556  -59.865  52.680  1
533782  96.595  -59.866  52.647  1
533783  96.633  -59.867  52.612  1
533784  96.671  -59.867  52.576  1
533785  96.710  -59.868  52.542  1
533786  96.747  -59.869  52.511  1
533787  96.779  -59.867  52.479  1
533788  96.811  -59.866  52.448  1
533789  96.843  -59.865  52.415  1
533790  96.875  -59.864  52.379  1
533791  96.909  -59.867  52.342  1
533792  96.943  -59.869  52.306  1
533793  96.976  -59.871  52.268  1
533794  97.011  -59.873  52.228  1
533795  97.044  -59.876  52.182  1
533796  97.078  -59.879  52.132  1
533797  97.112  -59.881  52.078  1
533798  97.146  -59.883  52.026  1
533799  97.176  -59.895  51.977  1
533800  97.207  -59.908  51.930  1
533801  97.237  -59.920  51.883  1
533802  97.267  -59.933  51.836  1
533803  97.297  -59.946  51.792  1
533804  97.334  -59.946  51.747  1
533805  97.371  -59.947  51.701  1
533806  97.407  -59.948  51.655  1
533807  97.444  -59.948  51.609  1
533808  97.481  -59.949  51.562  1
533809  97.522  -59.960  51.516  1
533810  97.563  -59.971  51.469  1
533811  97.604  -59.983  51.423  1
533812  97.645  -59.993  51.378  1
533813  97.686  -60.005  51.334  1
533814  97.727  -60.016  51.290  1
533815  97.768  -60.027  51.247  1
533816  97.809  -60.038  51.204  1
533817  97.850  -60.049  51.163  1
533818  97.890  -60.061  51.123  1
533819  97.932  -60.071  51.081  1
533820  97.972  -60.083  51.040  1
533821  98.013  -60.094  51.000  1
533822  98.054  -60.105  50.960  1
533823  98.095  -60.116  50.919  1
533824  98.118  -60.118  50.879  1
533825  98.134  -60.117  50.840  1
533826  98.149  -60.115  50.800  1
533827  98.165  -60.114  50.760  1
533828  98.181  -60.112  50.719  1
533829  98.197  -60.112  50.678  1
533830  98.214  -60.110  50.635  1
533831  98.254  -60.114  50.591  1
533832  98.301  -60.097  50.549  1
533833  98.348  -60.080  50.507  1
533834  98.394  -60.064  50.465  1
533835  98.440  -60.047  50.422  1
533836  98.480  -60.044  50.380  1
533837  98.516  -60.049  50.338  1
533838  98.553  -60.052  50.296  1
533839  98.589  -60.057  50.254  1
533840  98.625  -60.061  50.211  1
533841  98.661  -60.066  50.168  1
533842  98.698  -60.070  50.124  1
533843  98.734  -60.074  50.081  1
533844  98.771  -60.079  50.037  1
533845  98.805  -60.068  49.994  1
533846  98.838  -60.046  49.951  1
533847  98.871  -60.024  49.908  1
533848  98.915  -60.008  49.866  1
533849  98.978  -60.006  49.823  1
534270  88.517  -57.493  56.478  1
534271  88.551  -57.504  56.455  1
534272  88.585  -57.516  56.430  1
534273  88.618  -57.528  56.405  1
534274  88.652  -57.539  56.381  1
534275  88.686  -57.551  56.358  1
534276  88.719  -57.562  56.333  1
534277  88.756  -57.577  56.307  1
534278  88.794  -57.593  56.282  1
534279  88.833  -57.609  56.259  1
534280  88.871  -57.625  56.236  1
534281  88.909  -57.641  56.212  1
534282  88.937  -57.663  56.190  1
534283  88.961  -57.687  56.167  1
534284  88.986  -57.711  56.143  1
534285  89.010  -57.736  56.118  1
534286  89.037  -57.758  56.093  1
534287  89.079  -57.768  56.067  1
534288  89.120  -57.779  56.042  1
534289  89.166  -57.794  56.016  1
534290  89.215  -57.811  55.990  1
534291  89.264  -57.828  55.965  1
534292  89.313  -57.845  55.943  1
534293  89.362  -57.861  55.921  1
534294  89.411  -57.879  55.901  1
534295  89.460  -57.896  55.884  1
534296  89.510  -57.912  55.869  1
534297  89.558  -57.930  55.857  1
534298  89.607  -57.946  55.846  1
534299  89.657  -57.963  55.837  1
534300  89.698  -57.977  55.829  1
534301  89.735  -57.987  55.824  1
534302  89.771  -57.996  55.819  1
534303  89.808  -58.006  55.814  1
534304  89.844  -58.016  55.809  1
534305  89.880  -58.026  55.803  1
534306  89.917  -58.036  55.796  1
534307  89.959  -58.043  55.790  1
534308  90.004  -58.047  55.779  1
534309  90.049  -58.052  55.767  1
534310  90.094  -58.056  55.750  1
534311  90.139  -58.062  55.731  1
534312  90.172  -58.079  55.712  1
534313  90.204  -58.096  55.693  1
534314  90.238  -58.109  55.675  1
534315  90.271  -58.120  55.657  1
534316  90.305  -58.131  55.640  1
534317  90.339  -58.143  55.621  1
534318  90.381  -58.148  55.596  1
534319  90.423  -58.153  55.575  1
534320  90.465  -58.157  55.553  1
534321  90.507  -58.162  55.532  1
534322  90.549  -58.166  55.513  1
534323  90.591  -58.171  55.497  1
534324  90.634  -58.175  55.478  1
534325  90.673  -58.181  55.460  1
534326  90.711  -58.189  55.440  1
534327  90.749  -58.196  55.418  1
534328  90.787  -58.203  55.393  1
534329  90.825  -58.210  55.362  1
534330  90.866  -58.228  55.332  1
534331  90.907  -58.247  55.309  1
534332  90.949  -58.266  55.290  1
534333  90.990  -58.285  55.272  1
534334  91.031  -58.303  55.251  1
534335  91.073  -58.323  55.225  1
534336  91.112  -58.347  55.196  1
534337  91.152  -58.372  55.170  1
534338  91.191  -58.395  55.148  1
534339  91.231  -58.419  55.130  1
534340  91.271  -58.444  55.114  1
534341  91.311  -58.468  55.094  1
534342  91.351  -58.491  55.073  1
534343  91.390  -58.516  55.052  1
534344  91.428  -58.528  55.033  1
534345  91.466  -58.540  55.019  1
534346  91.504  -58.552  55.009  1
534347  91.542  -58.564  54.996  1
534348  91.581  -58.577  54.985  1
534349  91.617  -58.589  54.978  1
534350  91.650  -58.599  54.973  1
534351  91.683  -58.610  54.965  1
534352  91.719  -58.619  54.952  1
534353  91.755  -58.629  54.935  1
534354  91.791  -58.638  54.914  1
534355  91.826  -58.648  54.889  1
534356  91.862  -58.657  54.857  1
534357  91.898  -58.669  54.834  1
534358  91.934  -58.683  54.808  1
534359  91.970  -58.698  54.781  1
534360  92.007  -58.712  54.758  1
534361  92.042  -58.726  54.738  1
534362  92.079  -58.737  54.726  1
534363  92.114  -58.737  54.717  1
534364  92.149  -58.738  54.712  1
534365  92.185  -58.738  54.709  1
534366  92.220  -58.739  54.711  1
534367  92.256  -58.739  54.715  1
534368  92.291  -58.739  54.720  1
534369  92.327  -58.739  54.724  1
534370  92.362  -58.740  54.726  1
534371  92.398  -58.740  54.724  1
534372  92.433  -58.741  54.715  1
534373  92.469  -58.741  54.707  1
534374  92.504  -58.742  54.699  1
534375  92.543  -58.744  54.690  1
534376  92.590  -58.745  54.683  1
534377  92.636  -58.751  54.678  1
534378  92.681  -58.757  54.679  1
534379  92.727  -58.762  54.685  1
534380  92.772  -58.768  54.688  1
534381  92.818  -58.774  54.686  1
534382  92.863  -58.780  54.673  1
534383  92.909  -58.786  54.656  1
534384  92.955  -58.792  54.650  1
534385  93.000  -58.798  54.641  1
534386  93.044  -58.805  54.632  1
534387  93.082  -58.814  54.622  1
534388  93.120  -58.824  54.607  1
534389  93.158  -58.834  54.591  1
534390  93.197  -58.842  54.575  1
534391  93.235  -58.849  54.559  1
534392  93.274  -58.857  54.544  1
534393  93.312  -58.864  54.529  1
534394  93.351  -58.873  54.513  1
534395  93.390  -58.880  54.498  1
534396  93.429  -58.888  54.482  1
534397  93.468  -58.896  54.465  1
534398  93.506  -58.903  54.449  1
534399  93.544  -58.914  54.432  1
534400  93.580  -58.927  54.416  1
534401  93.616  -58.942  54.400  1
534402  93.652  -58.955  54.383  1
534403  93.689  -58.969  54.366  1
534404  93.725  -58.983  54.349  1
534405  93.762  -58.996  54.332  1
534406  93.798  -59.010  54.317  1
534407  93.833  -59.027  54.297  1
534408  93.868  -59.048  54.275  1
534409  93.903  -59.068  54.251  1
534410  93.938  -59.089  54.228  1
534411  93.973  -59.109  54.207  1
534412  94.008  -59.129  54.183  1
534413  94.043  -59.150  54.159  1
534414  94.078  -59.170  54.137  1
534415  94.113  -59.190  54.118  1
534416  94.148  -59.210  54.100  1
534417  94.183  -59.231  54.080  1
534418  94.218  -59.251  54.059  1
534419  94.253  -59.271  54.038  1
534420  94.288  -59.291  54.017  1
534421  94.323  -59.312  53.995  1
534422  94.358  -59.332  53.970  1
534423  94.393  -59.352  53.947  1
534424  94.428  -59.372  53.926  1
534425  94.462  -59.387  53.907  1
534426  94.496  -59.394  53.890  1
534427  94.530  -59.400  53.876  1
534428  94.564  -59.408  53.865  1
534429  94.598  -59.415  53.851  1
534430  94.632  -59.422  53.833  1
534431  94.666  -59.429  53.811  1
534432  94.705  -59.438  53.780  1
534433  94.746  -59.447  53.743  1
534434  94.787  -59.457  53.706  1
534435  94.828  -59.466  53.669  1
534436  94.868  -59.475  53.635  1
534437  94.909  -59.484  53.604  1
534438  94.950  -59.494  53.579  1
534439  94.991  -59.503  53.555  1
534440  95.031  -59.512  53.532  1
534441  95.072  -59.521  53.508  1
534442  95.112  -59.532  53.482  1
534443  95.151  -59.545  53.456  1
534444  95.191  -59.557  53.434  1
534445  95.231  -59.570  53.414  1
534446  95.270  -59.583  53.396  1
534447  95.310  -59.596  53.378  1
534448  95.350  -59.607  53.359  1
534449  95.391  -59.616  53.341  1
534450  95.431  -59.625  53.322  1
534451  95.464  -59.635  53.304  1
534452  95.497  -59.645  53.289  1
534453  95.530  -59.656  53.275  1
534454  95.562  -59.666  53.259  1
534455  95.595  -59.676  53.252  1
534456  95.628  -59.686  53.248  1
534457  95.659  -59.695  53.244  1
534458  95.689  -59.703  53.236  1
534459  95.723  -59.709  53.229  1
534460  95.757  -59.716  53.214  1
534461  95.792  -59.723  53.199  1
534462  95.825  -59.729  53.183  1
534463  95.859  -59.736  53.167  1
534464  95.893  -59.743  53.151  1
534465  95.927  -59.750  53.131  1
534466  95.961  -59.757  53.106  1
534467  95.994  -59.764  53.077  1
534468  96.030  -59.770  53.047  1
534469  96.067  -59.774  53.017  1
534470  96.104  -59.779  52.989  1
534471  96.141  -59.785  52.965  1
534472  96.178  -59.790  52.942  1
534473  96.215  -59.795  52.921  1
534474  96.251  -59.801  52.899  1
534475  96.288  -59.806  52.874  1
534476  96.325  -59.811  52.848  1
534477  96.362  -59.817  52.824  1
534478  96.399  -59.822  52.800  1
534479  96.436  -59.826  52.776  1
534480  96.474  -59.827  52.750  1
534481  96.517  -59.832  52.720  1
534482  96.555  -59.833  52.687  1
534483  96.594  -59.833  52.654  1
534484  96.632  -59.834  52.620  1
534485  96.671  -59.835  52.586  1
534486  96.709  -59.836  52.554  1
534487  96.743  -59.835  52.525  1
534488  96.776  -59.834  52.494  1
534489  96.807  -59.833  52.463  1
534490  96.839  -59.831  52.430  1
534491  96.872  -59.831  52.394  1
534492  96.906  -59.833  52.359  1
534493  96.940  -59.836  52.323  1
534494  96.973  -59.838  52.285  1
534495  97.007  -59.840  52.244  1
534496  97.041  -59.842  52.198  1
534497  97.075  -59.845  52.149  1
534498  97.108  -59.847  52.097  1
534499  97.142  -59.849  52.047  1
534500  97.175  -59.853  52.000  1
534501  97.206  -59.866  51.954  1
534502  97.236  -59.879  51.908  1
534503  97.266  -59.892  51.864  1
534504  97.296  -59.904  51.821  1
534505  97.332  -59.907  51.776  1
534506  97.369  -59.908  51.730  1
534507  97.405  -59.908  51.683  1
534508  97.442  -59.909  51.635  1
534509  97.480  -59.914  51.588  1
534510  97.521  -59.925  51.540  1
534511  97.563  -59.936  51.491  1
534512  97.603  -59.947  51.443  1
534513  97.644  -59.958  51.396  1
534514  97.685  -59.969  51.349  1
534515  97.726  -59.980  51.304  1
534516  97.767  -59.992  51.259  1
534517  97.808  -60.003  51.215  1
534518  97.849  -60.014  51.172  1
534519  97.890  -60.025  51.130  1
534520  97.931  -60.036  51.088  1
534521  97.971  -60.047  51.046  1
534522  98.013  -60.058  51.005  1
534523  98.054  -60.070  50.965  1
534524  98.094  -60.081  50.924  1
534525  98.129  -60.085  50.884  1
534526  98.149  -60.090  50.846  1
534527  98.165  -60.089  50.806  1
534528  98.181  -60.087  50.767  1
534529  98.197  -60.086  50.726  1
534530  98.213  -60.085  50.686  1
534531  98.228  -60.083  50.644  1
534532  98.255  -60.086  50.601  1
534533  98.300  -60.075  50.559  1
534534  98.346  -60.058  50.516  1
534535  98.393  -60.042  50.474  1
534536  98.439  -60.025  50.432  1
534537  98.486  -60.008  50.390  1
534538  98.522  -60.011  50.347  1
534539  98.559  -60.015  50.305  1
534540  98.595  -60.020  50.263  1
534541  98.632  -60.024  50.220  1
534542  98.668  -60.028  50.177  1
534543  98.704  -60.033  50.134  1
534544  98.740  -60.037  50.090  1
534545  98.777  -60.041  50.047  1
534546  98.811  -60.028  50.004  1
534547  98.844  -60.005  49.961  1
534548  98.877  -59.983  49.918  1
534549  98.923  -59.970  49.875  1
534550  98.986  -59.967  49.832  1
534551  99.049  -59.966  49.790  1
534972  88.563  -57.460  56.441  1
534973  88.597  -57.472  56.417  1
534974  88.630  -57.484  56.393  1
534975  88.664  -57.495  56.369  1
534976  88.698  -57.507  56.346  1
534977  88.736  -57.523  56.322  1
534978  88.774  -57.539  56.299  1
534979  88.813  -57.554  56.276  1
534980  88.851  -57.570  56.253  1
534981  88.889  -57.586  56.230  1
534982  88.927  -57.602  56.205  1
534983  88.956  -57.624  56.182  1
534984  88.980  -57.648  56.160  1
534985  89.004  -57.672  56.137  1
534986  89.029  -57.696  56.112  1
534987  89.056  -57.717  56.089  1
534988  89.098  -57.729  56.064  1
534989  89.139  -57.739  56.040  1
534990  89.181  -57.750  56.015  1
534991  89.228  -57.766  55.990  1
534992  89.277  -57.783  55.967  1
534993  89.326  -57.800  55.944  1
534994  89.375  -57.817  55.922  1
534995  89.424  -57.833  55.903  1
534996  89.473  -57.851  55.886  1
534997  89.522  -57.868  55.872  1
534998  89.571  -57.884  55.859  1
534999  89.620  -57.902  55.849  1
535000  89.669  -57.918  55.840  1
535001  89.714  -57.933  55.833  1
535002  89.751  -57.943  55.828  1
535003  89.787  -57.953  55.823  1
535004  89.823  -57.963  55.819  1
535005  89.860  -57.973  55.815  1
535006  89.896  -57.983  55.810  1
535007  89.933  -57.993  55.806  1
535008  89.969  -58.003  55.803  1
535009  90.010  -58.010  55.794  1
535010  90.055  -58.015  55.781  1
535011  90.100  -58.019  55.763  1
535012  90.146  -58.024  55.741  1
535013  90.182  -58.037  55.722  1
535014  90.215  -58.054  55.704  1
535015  90.248  -58.066  55.687  1
535016  90.282  -58.078  55.671  1
535017  90.316  -58.090  55.656  1
535018  90.350  -58.101  55.638  1
535019  90.386  -58.110  55.611  1
535020  90.428  -58.115  55.590  1
535021  90.470  -58.119  55.567  1
535022  90.512  -58.124  55.545  1
535023  90.554  -58.128  55.524  1
535024  90.597  -58.133  55.511  1
535025  90.639  -58.137  55.494  1
535026  90.681  -58.142  55.477  1
535027  90.723  -58.147  55.458  1
535028  90.762  -58.153  55.435  1
535029  90.800  -58.161  55.407  1
535030  90.837  -58.168  55.373  1
535031  90.876  -58.178  55.335  1
535032  90.918  -58.197  55.301  1
535033  90.959  -58.216  55.275  1
535034  91.001  -58.234  55.254  1
535035  91.042  -58.253  55.234  1
535036  91.082  -58.277  55.208  1
535037  91.121  -58.301  55.186  1
535038  91.161  -58.325  55.167  1
535039  91.201  -58.350  55.152  1
535040  91.241  -58.373  55.139  1
535041  91.280  -58.397  55.127  1
535042  91.320  -58.422  55.109  1
535043  91.360  -58.446  55.087  1
535044  91.399  -58.469  55.063  1
535045  91.439  -58.494  55.042  1
535046  91.477  -58.507  55.024  1
535047  91.515  -58.519  55.015  1
535048  91.554  -58.531  55.007  1
535049  91.592  -58.543  55.000  1
535050  91.627  -58.554  54.995  1
535051  91.659  -58.565  54.988  1
535052  91.692  -58.576  54.981  1
535053  91.728  -58.585  54.972  1
535054  91.764  -58.595  54.957  1
535055  91.799  -58.604  54.935  1
535056  91.836  -58.614  54.907  1
535057  91.871  -58.623  54.882  1
535058  91.907  -58.632  54.855  1
535059  91.943  -58.642  54.830  1
535060  91.979  -58.656  54.807  1
535061  92.015  -58.670  54.781  1
535062  92.051  -58.685  54.751  1
535063  92.087  -58.698  54.734  1
535064  92.123  -58.698  54.723  1
535065  92.158  -58.699  54.716  1
535066  92.194  -58.699  54.712  1
535067  92.229  -58.700  54.714  1
535068  92.265  -58.700  54.721  1
535069  92.300  -58.701  54.727  1
535070  92.335  -58.701  54.732  1
535071  92.371  -58.701  54.736  1
535072  92.406  -58.701  54.738  1
535073  92.442  -58.702  54.733  1
535074  92.477  -58.703  54.728  1
535075  92.516  -58.706  54.721  1
535076  92.555  -58.711  54.715  1
535077  92.600  -58.717  54.711  1
535078  92.646  -58.723  54.706  1
535079  92.692  -58.729  54.701  1
535080  92.737  -58.735  54.694  1
535081  92.783  -58.741  54.688  1
535082  92.829  -58.747  54.684  1
535083  92.874  -58.753  54.679  1
535084  92.920  -58.758  54.674  1
535085  92.966  -58.764  54.673  1
535086  93.011  -58.770  54.669  1
535087  93.052  -58.779  54.660  1
535088  93.090  -58.789  54.649  1
535089  93.128  -58.798  54.634  1
535090  93.166  -58.808  54.615  1
535091  93.204  -58.816  54.598  1
535092  93.243  -58.824  54.581  1
535093  93.282  -58.831  54.567  1
535094  93.321  -58.839  54.555  1
535095  93.359  -58.847  54.540  1
535096  93.398  -58.855  54.524  1
535097  93.437  -58.862  54.507  1
535098  93.476  -58.870  54.488  1
535099  93.514  -58.877  54.469  1
535100  93.551  -58.889  54.449  1
535101  93.587  -58.903  54.432  1
535102  93.624  -58.917  54.416  1
535103  93.660  -58.930  54.401  1
535104  93.696  -58.944  54.386  1
535105  93.732  -58.958  54.372  1
535106  93.769  -58.971  54.358  1
535107  93.805  -58.985  54.345  1
535108  93.842  -58.999  54.327  1
535109  93.877  -59.014  54.304  1
535110  93.913  -59.034  54.279  1
535111  93.947  -59.054  54.251  1
535112  93.983  -59.074  54.227  1
535113  94.017  -59.095  54.203  1
535114  94.053  -59.115  54.179  1
535115  94.087  -59.135  54.156  1
535116  94.123  -59.156  54.138  1
535117  94.157  -59.176  54.121  1
535118  94.192  -59.196  54.102  1
535119  94.227  -59.216  54.081  1
535120  94.262  -59.237  54.060  1
535121  94.297  -59.257  54.038  1
535122  94.332  -59.277  54.015  1
535123  94.367  -59.297  53.992  1
535124  94.402  -59.318  53.969  1
535125  94.437  -59.338  53.946  1
535126  94.472  -59.350  53.924  1
535127  94.505  -59.357  53.902  1
535128  94.540  -59.364  53.884  1
535129  94.573  -59.372  53.873  1
535130  94.608  -59.378  53.862  1
535131  94.641  -59.385  53.845  1
535132  94.678  -59.394  53.822  1
535133  94.719  -59.403  53.790  1
535134  94.760  -59.413  53.751  1
535135  94.801  -59.422  53.711  1
535136  94.841  -59.432  53.673  1
535137  94.882  -59.441  53.639  1
535138  94.923  -59.450  53.608  1
535139  94.964  -59.459  53.582  1
535140  95.004  -59.468  53.556  1
535141  95.045  -59.478  53.530  1
535142  95.085  -59.488  53.505  1
535143  95.122  -59.498  53.479  1
535144  95.161  -59.510  53.454  1
535145  95.200  -59.520  53.430  1
535146  95.239  -59.532  53.409  1
535147  95.279  -59.544  53.390  1
535148  95.318  -59.557  53.372  1
535149  95.358  -59.569  53.353  1
535150  95.399  -59.579  53.334  1
535151  95.435  -59.589  53.316  1
535152  95.468  -59.599  53.299  1
535153  95.500  -59.609  53.284  1
535154  95.533  -59.620  53.270  1
535155  95.566  -59.629  53.256  1
535156  95.599  -59.640  53.255  1
535157  95.631  -59.650  53.256  1
535158  95.664  -59.660  53.256  1
535159  95.696  -59.670  53.253  1
535160  95.730  -59.676  53.246  1
535161  95.764  -59.682  53.231  1
535162  95.798  -59.689  53.213  1
535163  95.831  -59.697  53.193  1
535164  95.865  -59.704  53.173  1
535165  95.898  -59.710  53.154  1
535166  95.932  -59.717  53.134  1
535167  95.966  -59.724  53.109  1
535168  96.000  -59.731  53.081  1
535169  96.034  -59.737  53.052  1
535170  96.071  -59.742  53.024  1
535171  96.108  -59.748  53.000  1
535172  96.145  -59.753  52.979  1
535173  96.182  -59.758  52.957  1
535174  96.219  -59.764  52.935  1
535175  96.256  -59.768  52.911  1
535176  96.293  -59.773  52.888  1
535177  96.330  -59.779  52.862  1
535178  96.367  -59.784  52.836  1
535179  96.403  -59.789  52.812  1
535180  96.441  -59.795  52.787  1
535181  96.478  -59.798  52.760  1
535182  96.517  -59.799  52.729  1
535183  96.555  -59.800  52.694  1
535184  96.593  -59.801  52.663  1
535185  96.631  -59.801  52.631  1
535186  96.670  -59.802  52.598  1
535187  96.708  -59.802  52.567  1
535188  96.740  -59.801  52.538  1
535189  96.772  -59.800  52.507  1
535190  96.804  -59.798  52.476  1
535191  96.836  -59.798  52.444  1
535192  96.869  -59.797  52.408  1
535193  96.902  -59.800  52.373  1
535194  96.936  -59.802  52.336  1
535195  96.970  -59.804  52.297  1
535196  97.004  -59.807  52.255  1
535197  97.037  -59.809  52.208  1
535198  97.071  -59.811  52.160  1
535199  97.105  -59.814  52.111  1
535200  97.139  -59.816  52.065  1
535201  97.172  -59.818  52.020  1
535202  97.205  -59.824  51.975  1
535203  97.235  -59.837  51.932  1
535204  97.265  -59.850  51.891  1
535205  97.296  -59.862  51.849  1
535206  97.329  -59.868  51.806  1
535207  97.366  -59.869  51.760  1
535208  97.403  -59.870  51.712  1
535209  97.440  -59.870  51.662  1
535210  97.480  -59.878  51.615  1
535211  97.521  -59.889  51.565  1
535212  97.562  -59.901  51.515  1
535213  97.602  -59.911  51.465  1
535214  97.644  -59.923  51.415  1
535215  97.684  -59.934  51.367  1
535216  97.725  -59.946  51.318  1
535217  97.766  -59.956  51.271  1
535218  97.807  -59.967  51.225  1
535219  97.848  -59.979  51.180  1
535220  97.889  -59.989  51.137  1
535221  97.930  -60.001  51.095  1
535222  97.971  -60.012  51.052  1
535223  98.011  -60.024  51.010  1
535224  98.051  -60.034  50.969  1
535225  98.090  -60.046  50.929  1
535226  98.130  -60.046  50.889  1
535227  98.153  -60.048  50.850  1
535228  98.174  -60.054  50.811  1
535229  98.196  -60.061  50.772  1
535230  98.212  -60.060  50.732  1
535231  98.228  -60.058  50.692  1
535232  98.244  -60.057  50.651  1
535233  98.260  -60.056  50.610  1
535234  98.299  -60.053  50.568  1
535235  98.345  -60.036  50.526  1
535236  98.391  -60.020  50.484  1
535237  98.438  -60.002  50.443  1
535238  98.485  -59.986  50.401  1
535239  98.529  -59.974  50.358  1
535240  98.565  -59.978  50.314  1
535241  98.601  -59.982  50.273  1
535242  98.638  -59.986  50.231  1
535243  98.674  -59.991  50.188  1
535244  98.710  -59.996  50.145  1
535245  98.746  -59.999  50.101  1
535246  98.783  -60.004  50.058  1
535247  98.816  -59.987  50.014  1
535248  98.850  -59.964  49.971  1
535249  98.882  -59.942  49.928  1
535250  98.932  -59.930  49.885  1
535251  98.995  -59.929  49.842  1
535252  99.055  -59.927  49.799  1
535674  88.609  -57.428  56.402  1
535675  88.642  -57.440  56.379  1
535676  88.677  -57.452  56.356  1
535677  88.715  -57.468  56.333  1
535678  88.754  -57.484  56.311  1
535679  88.792  -57.500  56.289  1
535680  88.830  -57.516  56.267  1
535681  88.869  -57.532  56.244  1
535682  88.907  -57.548  56.221  1
535683  88.945  -57.564  56.197  1
535684  88.974  -57.585  56.173  1
535685  88.998  -57.609  56.150  1
535686  89.023  -57.633  56.128  1
535687  89.047  -57.658  56.107  1
535688  89.076  -57.678  56.085  1
535689  89.117  -57.689  56.060  1
535690  89.159  -57.700  56.036  1
535691  89.200  -57.711  56.013  1
535692  89.242  -57.721  55.988  1
535693  89.290  -57.738  55.966  1
535694  89.339  -57.755  55.944  1
535695  89.388  -57.772  55.923  1
535696  89.437  -57.789  55.904  1
535697  89.486  -57.805  55.887  1
535698  89.535  -57.823  55.873  1
535699  89.584  -57.840  55.861  1
535700  89.633  -57.856  55.851  1
535701  89.682  -57.874  55.842  1
535702  89.730  -57.890  55.835  1
535703  89.766  -57.899  55.830  1
535704  89.803  -57.909  55.828  1
535705  89.839  -57.920  55.824  1
535706  89.875  -57.930  55.822  1
535707  89.912  -57.940  55.820  1
535708  89.948  -57.949  55.818  1
535709  89.984  -57.959  55.817  1
535710  90.021  -57.969  55.811  1
535711  90.060  -57.977  55.799  1
535712  90.106  -57.982  55.780  1
535713  90.151  -57.987  55.756  1
535714  90.193  -57.994  55.736  1
535715  90.225  -58.012  55.718  1
535716  90.259  -58.024  55.700  1
535717  90.293  -58.036  55.686  1
535718  90.326  -58.047  55.672  1
535719  90.361  -58.059  55.653  1
535720  90.394  -58.070  55.625  1
535721  90.434  -58.078  55.602  1
535722  90.475  -58.082  55.578  1
535723  90.518  -58.087  55.555  1
535724  90.559  -58.091  55.536  1
535725  90.602  -58.096  55.523  1
535726  90.644  -58.100  55.506  1
535727  90.686  -58.105  55.488  1
535728  90.728  -58.109  55.467  1
535729  90.770  -58.114  55.440  1
535730  90.812  -58.118  55.408  1
535731  90.851  -58.125  55.373  1
535732  90.888  -58.133  55.336  1
535733  90.929  -58.147  55.300  1
535734  90.970  -58.165  55.268  1
535735  91.011  -58.184  55.244  1
535736  91.051  -58.207  55.220  1
535737  91.091  -58.231  55.200  1
535738  91.131  -58.255  55.185  1
535739  91.170  -58.279  55.175  1
535740  91.210  -58.303  55.166  1
535741  91.250  -58.328  55.157  1
535742  91.290  -58.351  55.146  1
535743  91.329  -58.375  55.129  1
535744  91.369  -58.400  55.106  1
535745  91.409  -58.424  55.081  1
535746  91.448  -58.448  55.056  1
535747  91.488  -58.472  55.035  1
535748  91.526  -58.485  55.024  1
535749  91.565  -58.497  55.017  1
535750  91.602  -58.510  55.012  1
535751  91.637  -58.520  55.008  1
535752  91.669  -58.531  55.003  1
535753  91.701  -58.542  54.997  1
535754  91.737  -58.551  54.987  1
535755  91.773  -58.560  54.971  1
535756  91.808  -58.570  54.950  1
535757  91.844  -58.579  54.922  1
535758  91.880  -58.589  54.895  1
535759  91.916  -58.598  54.864  1
535760  91.951  -58.608  54.836  1
535761  91.988  -58.617  54.812  1
535762  92.023  -58.629  54.788  1
535763  92.060  -58.643  54.768  1
535764  92.095  -58.657  54.750  1
535765  92.131  -58.660  54.736  1
535766  92.166  -58.661  54.725  1
535767  92.202  -58.661  54.718  1
535768  92.237  -58.661  54.719  1
535769  92.273  -58.661  54.726  1
535770  92.308  -58.662  54.730  1
535771  92.344  -58.662  54.733  1
535772  92.381  -58.664  54.737  1
535773  92.420  -58.667  54.744  1
535774  92.459  -58.671  54.744  1
535775  92.498  -58.674  54.743  1
535776  92.533  -58.678  54.742  1
535777  92.566  -58.683  54.740  1
535778  92.612  -58.689  54.739  1
535779  92.657  -58.695  54.733  1
535780  92.703  -58.701  54.725  1
535781  92.748  -58.708  54.716  1
535782  92.794  -58.713  54.711  1
535783  92.839  -58.719  54.708  1
535784  92.885  -58.725  54.706  1
535785  92.931  -58.731  54.705  1
535786  92.976  -58.737  54.702  1
535787  93.022  -58.743  54.695  1
535788  93.060  -58.752  54.685  1
535789  93.098  -58.762  54.674  1
535790  93.136  -58.771  54.662  1
535791  93.174  -58.781  54.644  1
535792  93.212  -58.790  54.625  1
535793  93.251  -58.798  54.608  1
535794  93.290  -58.805  54.593  1
535795  93.329  -58.813  54.584  1
535796  93.367  -58.821  54.573  1
535797  93.406  -58.829  54.558  1
535798  93.444  -58.836  54.540  1
535799  93.483  -58.844  54.519  1
535800  93.522  -58.852  54.496  1
535801  93.559  -58.864  54.472  1
535802  93.595  -58.878  54.452  1
535803  93.631  -58.892  54.436  1
535804  93.667  -58.905  54.422  1
535805  93.704  -58.919  54.410  1
535806  93.740  -58.933  54.399  1
535807  93.776  -58.946  54.388  1
535808  93.813  -58.960  54.377  1
535809  93.849  -58.974  54.359  1
535810  93.886  -58.988  54.336  1
535811  93.922  -59.002  54.309  1
535812  93.957  -59.020  54.276  1
535813  93.992  -59.040  54.248  1
535814  94.027  -59.060  54.223  1
535815  94.062  -59.081  54.199  1
535816  94.097  -59.101  54.177  1
535817  94.132  -59.121  54.159  1
535818  94.167  -59.141  54.144  1
535819  94.202  -59.162  54.126  1
535820  94.237  -59.182  54.106  1
535821  94.272  -59.202  54.084  1
535822  94.307  -59.222  54.063  1
535823  94.342  -59.243  54.039  1
535824  94.377  -59.263  54.016  1
535825  94.412  -59.283  53.992  1
535826  94.447  -59.303  53.968  1
535827  94.481  -59.313  53.943  1
535828  94.515  -59.321  53.918  1
535829  94.549  -59.328  53.894  1
535830  94.583  -59.334  53.877  1
535831  94.617  -59.342  53.861  1
535832  94.652  -59.350  53.842  1
535833  94.691  -59.358  53.820  1
535834  94.732  -59.368  53.790  1
535835  94.773  -59.378  53.754  1
535836  94.814  -59.388  53.715  1
535837  94.855  -59.397  53.676  1
535838  94.896  -59.406  53.640  1
535839  94.936  -59.415  53.608  1
535840  94.977  -59.425  53.576  1
535841  95.018  -59.434  53.545  1
535842  95.059  -59.443  53.517  1
535843  95.096  -59.454  53.490  1
535844  95.133  -59.465  53.465  1
535845  95.172  -59.476  53.445  1
535846  95.211  -59.487  53.424  1
535847  95.250  -59.498  53.401  1
535848  95.289  -59.510  53.380  1
535849  95.328  -59.520  53.362  1
535850  95.367  -59.532  53.343  1
535851  95.406  -59.542  53.326  1
535852  95.439  -59.553  53.311  1
535853  95.471  -59.563  53.295  1
535854  95.505  -59.574  53.279  1
535855  95.537  -59.585  53.262  1
535856  95.570  -59.595  53.253  1
535857  95.603  -59.605  53.255  1
535858  95.636  -59.616  53.261  1
535859  95.669  -59.626  53.265  1
535860  95.702  -59.637  53.266  1
535861  95.734  -59.645  53.260  1
535862  95.768  -59.651  53.245  1
535863  95.802  -59.658  53.225  1
535864  95.835  -59.665  53.203  1
535865  95.869  -59.672  53.180  1
535866  95.902  -59.679  53.159  1
535867  95.936  -59.686  53.138  1
535868  95.970  -59.693  53.113  1
535869  96.004  -59.699  53.086  1
535870  96.039  -59.705  53.059  1
535871  96.075  -59.710  53.033  1
535872  96.112  -59.716  53.012  1
535873  96.149  -59.721  52.993  1
535874  96.186  -59.726  52.972  1
535875  96.223  -59.732  52.949  1
535876  96.260  -59.737  52.926  1
535877  96.297  -59.742  52.901  1
535878  96.334  -59.747  52.874  1
535879  96.371  -59.752  52.847  1
535880  96.407  -59.757  52.822  1
535881  96.443  -59.761  52.796  1
535882  96.479  -59.764  52.768  1
535883  96.516  -59.766  52.736  1
535884  96.554  -59.767  52.703  1
535885  96.593  -59.767  52.673  1
535886  96.631  -59.768  52.643  1
535887  96.669  -59.769  52.612  1
535888  96.704  -59.769  52.581  1
535889  96.736  -59.767  52.550  1
535890  96.768  -59.766  52.519  1
535891  96.800  -59.765  52.489  1
535892  96.832  -59.764  52.457  1
535893  96.865  -59.764  52.422  1
535894  96.899  -59.766  52.386  1
535895  96.933  -59.768  52.347  1
535896  96.966  -59.770  52.306  1
535897  97.000  -59.773  52.262  1
535898  97.034  -59.775  52.217  1
535899  97.068  -59.778  52.169  1
535900  97.101  -59.780  52.123  1
535901  97.135  -59.783  52.081  1
535902  97.169  -59.785  52.038  1
535903  97.203  -59.787  51.995  1
535904  97.234  -59.795  51.953  1
535905  97.264  -59.808  51.914  1
535906  97.295  -59.821  51.875  1
535907  97.327  -59.830  51.835  1
535908  97.364  -59.830  51.791  1
535909  97.401  -59.830  51.744  1
535910  97.438  -59.832  51.694  1
535911  97.479  -59.843  51.644  1
535912  97.520  -59.854  51.592  1
535913  97.561  -59.865  51.542  1
535914  97.602  -59.877  51.491  1
535915  97.643  -59.888  51.440  1
535916  97.683  -59.898  51.388  1
535917  97.725  -59.910  51.337  1
535918  97.766  -59.921  51.287  1
535919  97.806  -59.932  51.238  1
535920  97.847  -59.943  51.190  1
535921  97.888  -59.955  51.144  1
535922  97.928  -59.965  51.100  1
535923  97.967  -59.977  51.056  1
535924  98.008  -59.988  51.013  1
535925  98.048  -59.999  50.972  1
535926  98.087  -60.008  50.931  1
535927  98.129  -60.011  50.893  1
535928  98.155  -60.004  50.854  1
535929  98.177  -60.010  50.815  1
535930  98.199  -60.017  50.776  1
535931  98.220  -60.023  50.737  1
535932  98.241  -60.030  50.696  1
535933  98.260  -60.031  50.656  1
535934  98.275  -60.030  50.616  1
535935  98.298  -60.031  50.575  1
535936  98.344  -60.014  50.536  1
535937  98.390  -59.997  50.497  1
535938  98.437  -59.980  50.457  1
535939  98.484  -59.964  50.414  1
535940  98.530  -59.947  50.370  1
535941  98.571  -59.940  50.326  1
535942  98.607  -59.945  50.284  1
535943  98.644  -59.949  50.242  1
535944  98.680  -59.954  50.200  1
535945  98.716  -59.958  50.157  1
535946  98.753  -59.962  50.112  1
535947  98.789  -59.967  50.069  1
535948  98.822  -59.946  50.025  1
535949  98.855  -59.924  49.981  1
535950  98.888  -59.901  49.938  1
535951  98.940  -59.892  49.895  1
535952  99.003  -59.890  49.851  1
535953  99.054  -59.890  49.808  1
535954  99.082  -59.894  49.766  1
536376  88.657  -57.398  56.364  1
536377  88.695  -57.413  56.342  1
536378  88.733  -57.429  56.319  1
536379  88.771  -57.445  56.298  1
536380  88.810  -57.461  56.277  1
536381  88.848  -57.477  56.255  1
536382  88.886  -57.493  56.234  1
536383  88.924  -57.510  56.211  1
536384  88.963  -57.526  56.189  1
536385  88.993  -57.546  56.166  1
536386  89.017  -57.570  56.142  1
536387  89.042  -57.594  56.120  1
536388  89.066  -57.618  56.099  1
536389  89.095  -57.639  56.077  1
536390  89.137  -57.649  56.053  1
536391  89.178  -57.660  56.030  1
536392  89.219  -57.671  56.007  1
536393  89.261  -57.682  55.984  1
536394  89.303  -57.693  55.964  1
536395  89.352  -57.710  55.943  1
536396  89.401  -57.727  55.922  1
536397  89.450  -57.744  55.904  1
536398  89.499  -57.761  55.887  1
536399  89.548  -57.777  55.873  1
536400  89.597  -57.795  55.862  1
536401  89.646  -57.811  55.852  1
536402  89.695  -57.829  55.843  1
536403  89.744  -57.846  55.837  1
536404  89.782  -57.856  55.833  1
536405  89.818  -57.866  55.831  1
536406  89.855  -57.876  55.828  1
536407  89.891  -57.886  55.827  1
536408  89.928  -57.896  55.826  1
536409  89.964  -57.906  55.825  1
536410  90.000  -57.916  55.824  1
536411  90.036  -57.926  55.818  1
536412  90.073  -57.936  55.807  1
536413  90.112  -57.944  55.791  1
536414  90.157  -57.949  55.772  1
536415  90.202  -57.953  55.757  1
536416  90.236  -57.970  55.739  1
536417  90.269  -57.982  55.717  1
536418  90.303  -57.993  55.698  1
536419  90.337  -58.006  55.680  1
536420  90.371  -58.017  55.659  1
536421  90.405  -58.028  55.632  1
536422  90.439  -58.040  55.608  1
536423  90.481  -58.044  55.585  1
536424  90.523  -58.049  55.563  1
536425  90.565  -58.053  55.547  1
536426  90.607  -58.058  55.532  1
536427  90.649  -58.062  55.515  1
536428  90.691  -58.067  55.494  1
536429  90.733  -58.071  55.469  1
536430  90.776  -58.076  55.439  1
536431  90.818  -58.081  55.404  1
536432  90.860  -58.085  55.369  1
536433  90.901  -58.090  55.333  1
536434  90.939  -58.098  55.297  1
536435  90.980  -58.116  55.264  1
536436  91.021  -58.137  55.240  1
536437  91.061  -58.161  55.219  1
536438  91.100  -58.185  55.202  1
536439  91.140  -58.209  55.191  1
536440  91.180  -58.234  55.185  1
536441  91.220  -58.257  55.181  1
536442  91.259  -58.281  55.176  1
536443  91.299  -58.306  55.164  1
536444  91.338  -58.330  55.147  1
536445  91.378  -58.354  55.125  1
536446  91.418  -58.378  55.102  1
536447  91.458  -58.402  55.074  1
536448  91.498  -58.426  55.051  1
536449  91.537  -58.450  55.034  1
536450  91.575  -58.463  55.023  1
536451  91.613  -58.476  55.018  1
536452  91.646  -58.486  55.018  1
536453  91.678  -58.497  55.017  1
536454  91.711  -58.507  55.011  1
536455  91.745  -58.517  54.998  1
536456  91.781  -58.526  54.980  1
536457  91.817  -58.536  54.958  1
536458  91.853  -58.545  54.932  1
536459  91.889  -58.555  54.903  1
536460  91.925  -58.564  54.872  1
536461  91.960  -58.574  54.847  1
536462  91.996  -58.583  54.828  1
536463  92.032  -58.593  54.811  1
536464  92.068  -58.602  54.799  1
536465  92.104  -58.616  54.781  1
536466  92.140  -58.621  54.759  1
536467  92.175  -58.622  54.739  1
536468  92.211  -58.622  54.726  1
536469  92.246  -58.623  54.725  1
536470  92.285  -58.626  54.733  1
536471  92.324  -58.629  54.741  1
536472  92.363  -58.632  54.745  1
536473  92.402  -58.636  54.745  1
536474  92.441  -58.639  54.745  1
536475  92.480  -58.642  54.749  1
536476  92.518  -58.645  54.748  1
536477  92.548  -58.651  54.747  1
536478  92.577  -58.656  54.747  1
536479  92.622  -58.662  54.748  1
536480  92.667  -58.668  54.747  1
536481  92.713  -58.673  54.748  1
536482  92.759  -58.679  54.750  1
536483  92.804  -58.686  54.752  1
536484  92.850  -58.692  54.752  1
536485  92.896  -58.698  54.747  1
536486  92.941  -58.704  54.743  1
536487  92.987  -58.709  54.735  1
536488  93.030  -58.717  54.724  1
536489  93.068  -58.726  54.711  1
536490  93.106  -58.736  54.699  1
536491  93.144  -58.745  54.687  1
536492  93.182  -58.755  54.669  1
536493  93.220  -58.764  54.651  1
536494  93.259  -58.772  54.632  1
536495  93.297  -58.780  54.617  1
536496  93.336  -58.787  54.606  1
536497  93.375  -58.795  54.597  1
536498  93.414  -58.803  54.583  1
536499  93.452  -58.811  54.566  1
536500  93.491  -58.818  54.544  1
536501  93.530  -58.826  54.519  1
536502  93.566  -58.839  54.495  1
536503  93.603  -58.853  54.474  1
536504  93.639  -58.867  54.458  1
536505  93.675  -58.881  54.445  1
536506  93.711  -58.895  54.435  1
536507  93.748  -58.908  54.425  1
536508  93.784  -58.922  54.417  1
536509  93.820  -58.936  54.404  1
536510  93.856  -58.949  54.387  1
536511  93.893  -58.963  54.365  1
536512  93.929  -58.977  54.338  1
536513  93.966  -58.990  54.303  1
536514  94.001  -59.005  54.271  1
536515  94.037  -59.026  54.243  1
536516  94.071  -59.046  54.220  1
536517  94.106  -59.066  54.200  1
536518  94.141  -59.087  54.182  1
536519  94.176  -59.107  54.168  1
536520  94.211  -59.128  54.152  1
536521  94.246  -59.147  54.133  1
536522  94.281  -59.168  54.112  1
536523  94.316  -59.188  54.091  1
536524  94.351  -59.209  54.067  1
536525  94.386  -59.228  54.041  1
536526  94.421  -59.249  54.016  1
536527  94.456  -59.269  53.990  1
536528  94.490  -59.277  53.962  1
536529  94.524  -59.284  53.935  1
536530  94.558  -59.291  53.907  1
536531  94.592  -59.298  53.883  1
536532  94.626  -59.306  53.860  1
536533  94.665  -59.314  53.837  1
536534  94.704  -59.323  53.813  1
536535  94.745  -59.333  53.784  1
536536  94.786  -59.343  53.750  1
536537  94.828  -59.353  53.713  1
536538  94.868  -59.363  53.674  1
536539  94.909  -59.372  53.637  1
536540  94.950  -59.381  53.604  1
536541  94.991  -59.390  53.573  1
536542  95.032  -59.399  53.543  1
536543  95.070  -59.410  53.515  1
536544  95.107  -59.421  53.487  1
536545  95.144  -59.432  53.461  1
536546  95.182  -59.443  53.435  1
536547  95.222  -59.453  53.411  1
536548  95.260  -59.465  53.389  1
536549  95.300  -59.475  53.368  1
536550  95.338  -59.487  53.349  1
536551  95.378  -59.498  53.332  1
536552  95.411  -59.510  53.317  1
536553  95.445  -59.521  53.301  1
536554  95.477  -59.532  53.284  1
536555  95.511  -59.541  53.269  1
536556  95.543  -59.552  53.261  1
536557  95.576  -59.563  53.260  1
536558  95.609  -59.573  53.262  1
536559  95.642  -59.584  53.266  1
536560  95.675  -59.595  53.271  1
536561  95.707  -59.604  53.272  1
536562  95.739  -59.613  53.265  1
536563  95.772  -59.620  53.252  1
536564  95.806  -59.627  53.233  1
536565  95.839  -59.634  53.213  1
536566  95.873  -59.641  53.191  1
536567  95.906  -59.648  53.168  1
536568  95.940  -59.654  53.144  1
536569  95.974  -59.661  53.119  1
536570  96.009  -59.667  53.094  1
536571  96.044  -59.673  53.069  1
536572  96.080  -59.679  53.046  1
536573  96.116  -59.684  53.026  1
536574  96.153  -59.689  53.009  1
536575  96.190  -59.695  52.988  1
536576  96.227  -59.700  52.965  1
536577  96.264  -59.705  52.941  1
536578  96.301  -59.710  52.915  1
536579  96.338  -59.715  52.885  1
536580  96.375  -59.720  52.857  1
536581  96.410  -59.723  52.830  1
536582  96.445  -59.726  52.803  1
536583  96.480  -59.729  52.776  1
536584  96.516  -59.732  52.744  1
536585  96.553  -59.734  52.713  1
536586  96.592  -59.735  52.684  1
536587  96.630  -59.736  52.655  1
536588  96.669  -59.736  52.625  1
536589  96.700  -59.735  52.595  1
536590  96.733  -59.733  52.563  1
536591  96.764  -59.732  52.533  1
536592  96.797  -59.731  52.502  1
536593  96.829  -59.729  52.469  1
536594  96.862  -59.730  52.435  1
536595  96.895  -59.732  52.398  1
536596  96.929  -59.735  52.357  1
536597  96.963  -59.737  52.315  1
536598  96.997  -59.739  52.271  1
536599  97.030  -59.742  52.226  1
536600  97.064  -59.744  52.181  1
536601  97.098  -59.746  52.138  1
536602  97.132  -59.748  52.097  1
536603  97.165  -59.751  52.055  1
536604  97.199  -59.753  52.013  1
536605  97.233  -59.756  51.974  1
536606  97.264  -59.767  51.936  1
536607  97.294  -59.779  51.899  1
536608  97.325  -59.790  51.860  1
536609  97.362  -59.791  51.818  1
536610  97.399  -59.792  51.772  1
536611  97.437  -59.796  51.723  1
536612  97.478  -59.808  51.674  1
536613  97.519  -59.819  51.622  1
536614  97.560  -59.830  51.570  1
536615  97.601  -59.841  51.519  1
536616  97.642  -59.852  51.466  1
536617  97.683  -59.864  51.412  1
536618  97.724  -59.874  51.358  1
536619  97.764  -59.886  51.306  1
536620  97.805  -59.897  51.255  1
536621  97.845  -59.908  51.205  1
536622  97.885  -59.919  51.157  1
536623  97.925  -59.930  51.109  1
536624  97.964  -59.941  51.062  1
536625  98.004  -59.952  51.017  1
536626  98.044  -59.964  50.974  1
536627  98.085  -59.971  50.932  1
536628  98.127  -59.974  50.894  1
536629  98.157  -59.962  50.855  1
536630  98.179  -59.966  50.816  1
536631  98.201  -59.973  50.777  1
536632  98.223  -59.979  50.738  1
536633  98.244  -59.986  50.698  1
536634  98.266  -59.992  50.658  1
536635  98.287  -59.999  50.619  1
536636  98.307  -60.002  50.583  1
536637  98.343  -59.992  50.547  1
536638  98.389  -59.975  50.511  1
536639  98.436  -59.958  50.472  1
536640  98.482  -59.942  50.429  1
536641  98.528  -59.925  50.385  1
536642  98.575  -59.908  50.341  1
536643  98.614  -59.908  50.297  1
536644  98.650  -59.912  50.255  1
536645  98.687  -59.916  50.212  1
536646  98.723  -59.920  50.168  1
536647  98.759  -59.925  50.124  1
536648  98.795  -59.928  50.080  1
536649  98.828  -59.905  50.036  1
536650  98.861  -59.883  49.992  1
536651  98.894  -59.861  49.948  1
536652  98.949  -59.853  49.904  1
536653  99.012  -59.851  49.861  1
536654  99.052  -59.853  49.818  1
536655  99.081  -59.857  49.776  1
536656  99.110  -59.861  49.734  1
537078  88.713  -57.375  56.327  1
537079  88.751  -57.391  56.305  1
537080  88.789  -57.407  56.284  1
537081  88.828  -57.423  56.263  1
537082  88.866  -57.439  56.242  1
537083  88.904  -57.455  56.222  1
537084  88.943  -57.471  56.200  1
537085  88.981  -57.487  56.179  1
537086  89.012  -57.507  56.158  1
537087  89.036  -57.531  56.136  1
537088  89.060  -57.555  56.112  1
537089  89.085  -57.579  56.091  1
537090  89.115  -57.598  56.069  1
537091  89.156  -57.610  56.047  1
537092  89.198  -57.620  56.025  1
537093  89.239  -57.631  56.003  1
537094  89.280  -57.642  55.980  1
537095  89.322  -57.653  55.961  1
537096  89.365  -57.665  55.940  1
537097  89.414  -57.682  55.920  1
537098  89.463  -57.699  55.902  1
537099  89.512  -57.716  55.886  1
537100  89.561  -57.733  55.873  1
537101  89.610  -57.750  55.862  1
537102  89.659  -57.767  55.853  1
537103  89.708  -57.783  55.845  1
537104  89.757  -57.801  55.838  1
537105  89.798  -57.813  55.835  1
537106  89.834  -57.823  55.832  1
537107  89.870  -57.833  55.830  1
537108  89.906  -57.843  55.830  1
537109  89.943  -57.852  55.829  1
537110  89.979  -57.862  55.829  1
537111  90.016  -57.873  55.825  1
537112  90.052  -57.883  55.820  1
537113  90.089  -57.893  55.810  1
537114  90.125  -57.902  55.797  1
537115  90.163  -57.912  55.785  1
537116  90.208  -57.916  55.773  1
537117  90.246  -57.927  55.755  1
537118  90.280  -57.940  55.731  1
537119  90.314  -57.952  55.706  1
537120  90.347  -57.963  55.682  1
537121  90.381  -57.974  55.657  1
537122  90.415  -57.986  55.630  1
537123  90.449  -57.998  55.606  1
537124  90.486  -58.007  55.584  1
537125  90.528  -58.012  55.565  1
537126  90.570  -58.016  55.550  1
537127  90.612  -58.021  55.534  1
537128  90.655  -58.025  55.514  1
537129  90.696  -58.030  55.489  1
537130  90.739  -58.034  55.461  1
537131  90.781  -58.039  55.429  1
537132  90.823  -58.043  55.394  1
537133  90.865  -58.048  55.359  1
537134  90.907  -58.053  55.324  1
537135  90.949  -58.057  55.291  1
537136  90.991  -58.067  55.262  1
537137  91.030  -58.091  55.239  1
537138  91.070  -58.115  55.220  1
537139  91.109  -58.139  55.205  1
537140  91.149  -58.163  55.195  1
537141  91.189  -58.187  55.191  1
537142  91.229  -58.212  55.190  1
537143  91.269  -58.235  55.187  1
537144  91.308  -58.260  55.175  1
537145  91.348  -58.284  55.158  1
537146  91.387  -58.308  55.137  1
537147  91.427  -58.332  55.115  1
537148  91.467  -58.356  55.090  1
537149  91.507  -58.380  55.069  1
537150  91.546  -58.404  55.052  1
537151  91.586  -58.428  55.040  1
537152  91.623  -58.441  55.032  1
537153  91.655  -58.452  55.026  1
537154  91.688  -58.463  55.022  1
537155  91.720  -58.473  55.014  1
537156  91.754  -58.483  55.002  1
537157  91.790  -58.492  54.984  1
537158  91.826  -58.502  54.959  1
537159  91.862  -58.511  54.932  1
537160  91.897  -58.521  54.905  1
537161  91.933  -58.530  54.880  1
537162  91.969  -58.540  54.862  1
537163  92.005  -58.549  54.851  1
537164  92.041  -58.559  54.842  1
537165  92.077  -58.568  54.834  1
537166  92.112  -58.578  54.814  1
537167  92.151  -58.585  54.785  1
537168  92.190  -58.588  54.756  1
537169  92.228  -58.592  54.735  1
537170  92.267  -58.595  54.728  1
537171  92.306  -58.598  54.733  1
537172  92.345  -58.601  54.743  1
537173  92.384  -58.604  54.749  1
537174  92.423  -58.607  54.750  1
537175  92.461  -58.610  54.745  1
537176  92.500  -58.614  54.749  1
537177  92.533  -58.618  54.753  1
537178  92.563  -58.623  54.758  1
537179  92.592  -58.629  54.764  1
537180  92.633  -58.634  54.770  1
537181  92.678  -58.640  54.774  1
537182  92.724  -58.646  54.777  1
537183  92.770  -58.652  54.778  1
537184  92.815  -58.658  54.781  1
537185  92.861  -58.664  54.784  1
537186  92.907  -58.670  54.780  1
537187  92.952  -58.676  54.780  1
537188  92.998  -58.682  54.772  1
537189  93.039  -58.690  54.761  1
537190  93.076  -58.700  54.746  1
537191  93.115  -58.709  54.725  1
537192  93.152  -58.719  54.705  1
537193  93.190  -58.729  54.691  1
537194  93.228  -58.738  54.673  1
537195  93.267  -58.746  54.655  1
537196  93.305  -58.754  54.639  1
537197  93.344  -58.762  54.623  1
537198  93.383  -58.770  54.613  1
537199  93.422  -58.777  54.601  1
537200  93.461  -58.785  54.584  1
537201  93.499  -58.792  54.564  1
537202  93.538  -58.802  54.539  1
537203  93.574  -58.815  54.515  1
537204  93.610  -58.829  54.495  1
537205  93.646  -58.842  54.480  1
537206  93.683  -58.856  54.470  1
537207  93.719  -58.870  54.462  1
537208  93.755  -58.883  54.453  1
537209  93.791  -58.897  54.445  1
537210  93.828  -58.911  54.431  1
537211  93.864  -58.924  54.412  1
537212  93.900  -58.938  54.388  1
537213  93.936  -58.952  54.361  1
537214  93.973  -58.965  54.326  1
537215  94.009  -58.979  54.295  1
537216  94.046  -58.993  54.267  1
537217  94.081  -59.012  54.244  1
537218  94.116  -59.032  54.227  1
537219  94.151  -59.052  54.210  1
537220  94.186  -59.072  54.193  1
537221  94.221  -59.093  54.179  1
537222  94.256  -59.113  54.163  1
537223  94.290  -59.134  54.144  1
537224  94.326  -59.153  54.122  1
537225  94.360  -59.174  54.100  1
537226  94.396  -59.194  54.071  1
537227  94.430  -59.215  54.041  1
537228  94.466  -59.234  54.011  1
537229  94.499  -59.240  53.983  1
537230  94.534  -59.247  53.953  1
537231  94.567  -59.255  53.923  1
537232  94.602  -59.262  53.892  1
537233  94.639  -59.270  53.861  1
537234  94.677  -59.278  53.831  1
537235  94.717  -59.287  53.802  1
537236  94.758  -59.297  53.773  1
537237  94.800  -59.308  53.741  1
537238  94.841  -59.318  53.707  1
537239  94.882  -59.328  53.671  1
537240  94.923  -59.337  53.635  1
537241  94.964  -59.347  53.601  1
537242  95.004  -59.356  53.573  1
537243  95.044  -59.366  53.545  1
537244  95.082  -59.376  53.517  1
537245  95.119  -59.388  53.489  1
537246  95.156  -59.398  53.460  1
537247  95.193  -59.409  53.428  1
537248  95.232  -59.420  53.403  1
537249  95.271  -59.432  53.381  1
537250  95.310  -59.442  53.360  1
537251  95.349  -59.453  53.340  1
537252  95.383  -59.465  53.323  1
537253  95.417  -59.476  53.308  1
537254  95.450  -59.488  53.292  1
537255  95.483  -59.499  53.278  1
537256  95.517  -59.510  53.269  1
537257  95.549  -59.520  53.266  1
537258  95.582  -59.531  53.266  1
537259  95.615  -59.541  53.267  1
537260  95.648  -59.552  53.268  1
537261  95.681  -59.563  53.270  1
537262  95.713  -59.572  53.270  1
537263  95.744  -59.580  53.265  1
537264  95.776  -59.588  53.254  1
537265  95.810  -59.595  53.239  1
537266  95.843  -59.602  53.221  1
537267  95.877  -59.609  53.201  1
537268  95.910  -59.616  53.180  1
537269  95.944  -59.623  53.159  1
537270  95.979  -59.629  53.135  1
537271  96.014  -59.635  53.111  1
537272  96.049  -59.641  53.087  1
537273  96.084  -59.647  53.065  1
537274  96.120  -59.652  53.046  1
537275  96.157  -59.657  53.026  1
537276  96.194  -59.663  53.005  1
537277  96.231  -59.668  52.981  1
537278  96.268  -59.673  52.956  1
537279  96.305  -59.679  52.929  1
537280  96.341  -59.682  52.899  1
537281  96.376  -59.685  52.868  1
537282  96.411  -59.689  52.839  1
537283  96.447  -59.692  52.811  1
537284  96.482  -59.695  52.784  1
537285  96.518  -59.698  52.753  1
537286  96.553  -59.701  52.724  1
537287  96.591  -59.701  52.697  1
537288  96.629  -59.702  52.669  1
537289  96.665  -59.702  52.639  1
537290  96.697  -59.701  52.609  1
537291  96.729  -59.700  52.578  1
537292  96.761  -59.698  52.547  1
537293  96.793  -59.697  52.516  1
537294  96.825  -59.696  52.482  1
537295  96.858  -59.697  52.448  1
537296  96.892  -59.699  52.409  1
537297  96.926  -59.701  52.369  1
537298  96.959  -59.704  52.326  1
537299  96.993  -59.706  52.281  1
537300  97.027  -59.708  52.236  1
537301  97.061  -59.710  52.194  1
537302  97.094  -59.713  52.153  1
537303  97.128  -59.715  52.112  1
537304  97.162  -59.717  52.071  1
537305  97.195  -59.720  52.031  1
537306  97.229  -59.722  51.995  1
537307  97.263  -59.725  51.957  1
537308  97.293  -59.738  51.921  1
537309  97.323  -59.751  51.884  1
537310  97.360  -59.752  51.842  1
537311  97.396  -59.753  51.797  1
537312  97.437  -59.761  51.750  1
537313  97.477  -59.772  51.702  1
537314  97.518  -59.783  51.650  1
537315  97.559  -59.795  51.598  1
537316  97.600  -59.806  51.546  1
537317  97.641  -59.817  51.492  1
537318  97.682  -59.828  51.436  1
537319  97.722  -59.839  51.380  1
537320  97.762  -59.850  51.325  1
537321  97.802  -59.861  51.272  1
537322  97.842  -59.873  51.221  1
537323  97.881  -59.883  51.170  1
537324  97.922  -59.895  51.118  1
537325  97.961  -59.906  51.069  1
537326  98.001  -59.917  51.022  1
537327  98.041  -59.928  50.976  1
537328  98.082  -59.933  50.934  1
537329  98.124  -59.936  50.894  1
537330  98.157  -59.927  50.854  1
537331  98.182  -59.923  50.816  1
537332  98.204  -59.929  50.777  1
537333  98.225  -59.935  50.738  1
537334  98.247  -59.942  50.698  1
537335  98.269  -59.948  50.660  1
537336  98.290  -59.955  50.624  1
537337  98.311  -59.961  50.590  1
537338  98.344  -59.962  50.557  1
537339  98.388  -59.953  50.523  1
537340  98.435  -59.936  50.486  1
537341  98.481  -59.920  50.444  1
537342  98.527  -59.903  50.401  1
537343  98.574  -59.886  50.357  1
537344  98.620  -59.870  50.313  1
537345  98.656  -59.874  50.269  1
537346  98.693  -59.879  50.225  1
537347  98.729  -59.883  50.181  1
537348  98.765  -59.887  50.136  1
537349  98.801  -59.887  50.091  1
537350  98.834  -59.864  50.048  1
537351  98.867  -59.842  50.003  1
537352  98.900  -59.820  49.959  1
537353  98.958  -59.814  49.915  1
537354  99.021  -59.812  49.871  1
537355  99.051  -59.816  49.828  1
537356  99.079  -59.820  49.786  1
537357  99.108  -59.824  49.744  1
537358  99.137  -59.828  49.702  1
537780  88.769  -57.352  56.290  1
537781  88.807  -57.369  56.269  1
537782  88.845  -57.385  56.249  1
537783  88.884  -57.401  56.229  1
537784  88.922  -57.416  56.209  1
537785  88.960  -57.432  56.188  1
537786  88.998  -57.448  56.167  1
537787  89.030  -57.468  56.147  1
537788  89.054  -57.492  56.127  1
537789  89.079  -57.517  56.106  1
537790  89.103  -57.540  56.085  1
537791  89.134  -57.559  56.064  1
537792  89.176  -57.570  56.042  1
537793  89.217  -57.581  56.021  1
537794  89.258  -57.592  55.999  1
537795  89.300  -57.602  55.976  1
537796  89.341  -57.614  55.957  1
537797  89.383  -57.624  55.937  1
537798  89.426  -57.637  55.917  1
537799  89.476  -57.654  55.899  1
537800  89.525  -57.671  55.883  1
537801  89.574  -57.688  55.871  1
537802  89.623  -57.705  55.860  1
537803  89.672  -57.722  55.851  1
537804  89.721  -57.739  55.844  1
537805  89.770  -57.755  55.837  1
537806  89.813  -57.770  55.834  1
537807  89.849  -57.780  55.831  1
537808  89.886  -57.789  55.829  1
537809  89.922  -57.799  55.827  1
537810  89.959  -57.809  55.826  1
537811  89.995  -57.819  55.825  1
537812  90.031  -57.829  55.821  1
537813  90.068  -57.839  55.816  1
537814  90.104  -57.849  55.809  1
537815  90.141  -57.859  55.800  1
537816  90.177  -57.869  55.792  1
537817  90.214  -57.879  55.784  1
537818  90.257  -57.885  55.767  1
537819  90.291  -57.898  55.742  1
537820  90.324  -57.910  55.711  1
537821  90.358  -57.921  55.679  1
537822  90.392  -57.933  55.652  1
537823  90.426  -57.944  55.625  1
537824  90.460  -57.955  55.602  1
537825  90.494  -57.967  55.581  1
537826  90.533  -57.974  55.563  1
537827  90.576  -57.978  55.546  1
537828  90.617  -57.983  55.526  1
537829  90.660  -57.987  55.501  1
537830  90.702  -57.992  55.473  1
537831  90.744  -57.996  55.442  1
537832  90.786  -58.001  55.409  1
537833  90.828  -58.006  55.375  1
537834  90.871  -58.011  55.342  1
537835  90.916  -58.017  55.311  1
537836  90.961  -58.024  55.282  1
537837  91.004  -58.036  55.257  1
537838  91.043  -58.059  55.236  1
537839  91.083  -58.083  55.219  1
537840  91.123  -58.106  55.204  1
537841  91.162  -58.131  55.195  1
537842  91.202  -58.154  55.192  1
537843  91.242  -58.178  55.194  1
537844  91.281  -58.201  55.191  1
537845  91.321  -58.225  55.180  1
537846  91.360  -58.249  55.163  1
537847  91.400  -58.272  55.142  1
537848  91.440  -58.296  55.120  1
537849  91.479  -58.320  55.099  1
537850  91.519  -58.344  55.081  1
537851  91.559  -58.367  55.066  1
537852  91.598  -58.391  55.056  1
537853  91.638  -58.407  55.049  1
537854  91.665  -58.418  55.041  1
537855  91.697  -58.429  55.036  1
537856  91.730  -58.439  55.027  1
537857  91.763  -58.449  55.014  1
537858  91.799  -58.459  54.998  1
537859  91.835  -58.468  54.975  1
537860  91.870  -58.478  54.949  1
537861  91.907  -58.487  54.923  1
537862  91.942  -58.497  54.900  1
537863  91.980  -58.507  54.884  1
537864  92.017  -58.517  54.871  1
537865  92.055  -58.527  54.863  1
537866  92.092  -58.538  54.853  1
537867  92.130  -58.548  54.835  1
537868  92.171  -58.557  54.810  1
537869  92.210  -58.560  54.779  1
537870  92.249  -58.563  54.747  1
537871  92.288  -58.566  54.729  1
537872  92.326  -58.569  54.726  1
537873  92.366  -58.573  54.735  1
537874  92.405  -58.576  54.746  1
537875  92.443  -58.579  54.751  1
537876  92.482  -58.582  54.745  1
537877  92.519  -58.585  54.746  1
537878  92.549  -58.591  54.756  1
537879  92.578  -58.596  54.767  1
537880  92.608  -58.601  54.778  1
537881  92.643  -58.607  54.785  1
537882  92.689  -58.613  54.790  1
537883  92.735  -58.619  54.794  1
537884  92.780  -58.625  54.796  1
537885  92.826  -58.630  54.801  1
537886  92.871  -58.636  54.805  1
537887  92.917  -58.642  54.802  1
537888  92.963  -58.648  54.801  1
537889  93.008  -58.654  54.795  1
537890  93.047  -58.664  54.784  1
537891  93.084  -58.673  54.768  1
537892  93.123  -58.683  54.748  1
537893  93.160  -58.692  54.726  1
537894  93.198  -58.702  54.707  1
537895  93.236  -58.712  54.687  1
537896  93.275  -58.720  54.669  1
537897  93.313  -58.728  54.652  1
537898  93.352  -58.736  54.636  1
537899  93.391  -58.744  54.622  1
537900  93.429  -58.751  54.608  1
537901  93.468  -58.759  54.592  1
537902  93.507  -58.767  54.574  1
537903  93.545  -58.777  54.552  1
537904  93.581  -58.790  54.530  1
537905  93.618  -58.804  54.516  1
537906  93.654  -58.817  54.505  1
537907  93.690  -58.831  54.497  1
537908  93.726  -58.845  54.490  1
537909  93.763  -58.858  54.482  1
537910  93.799  -58.872  54.473  1
537911  93.835  -58.886  54.457  1
537912  93.871  -58.899  54.435  1
537913  93.908  -58.914  54.409  1
537914  93.944  -58.927  54.382  1
537915  93.980  -58.941  54.350  1
537916  94.016  -58.955  54.320  1
537917  94.053  -58.968  54.292  1
537918  94.089  -58.982  54.268  1
537919  94.125  -58.997  54.251  1
537920  94.160  -59.018  54.238  1
537921  94.195  -59.038  54.219  1
537922  94.230  -59.059  54.205  1
537923  94.265  -59.078  54.190  1
537924  94.300  -59.099  54.171  1
537925  94.335  -59.119  54.149  1
537926  94.370  -59.140  54.124  1
537927  94.405  -59.159  54.094  1
537928  94.440  -59.180  54.062  1
537929  94.475  -59.197  54.030  1
537930  94.508  -59.204  53.998  1
537931  94.543  -59.211  53.967  1
537932  94.576  -59.218  53.936  1
537933  94.613  -59.226  53.905  1
537934  94.651  -59.234  53.873  1
537935  94.690  -59.244  53.842  1
537936  94.731  -59.253  53.812  1
537937  94.772  -59.262  53.781  1
537938  94.813  -59.272  53.746  1
537939  94.854  -59.282  53.712  1
537940  94.895  -59.292  53.678  1
537941  94.936  -59.302  53.645  1
537942  94.977  -59.312  53.611  1
537943  95.018  -59.321  53.581  1
537944  95.056  -59.332  53.553  1
537945  95.093  -59.343  53.523  1
537946  95.130  -59.354  53.490  1
537947  95.167  -59.365  53.458  1
537948  95.204  -59.375  53.429  1
537949  95.243  -59.387  53.403  1
537950  95.282  -59.398  53.379  1
537951  95.321  -59.409  53.356  1
537952  95.355  -59.420  53.334  1
537953  95.389  -59.432  53.316  1
537954  95.422  -59.443  53.298  1
537955  95.456  -59.454  53.285  1
537956  95.489  -59.466  53.279  1
537957  95.522  -59.477  53.276  1
537958  95.555  -59.488  53.276  1
537959  95.588  -59.499  53.273  1
537960  95.621  -59.510  53.272  1
537961  95.654  -59.519  53.269  1
537962  95.687  -59.530  53.268  1
537963  95.719  -59.539  53.268  1
537964  95.750  -59.547  53.264  1
537965  95.781  -59.556  53.256  1
537966  95.814  -59.564  53.243  1
537967  95.847  -59.571  53.229  1
537968  95.881  -59.578  53.212  1
537969  95.914  -59.585  53.193  1
537970  95.949  -59.591  53.173  1
537971  95.984  -59.597  53.150  1
537972  96.019  -59.603  53.126  1
537973  96.054  -59.609  53.103  1
537974  96.089  -59.615  53.083  1
537975  96.124  -59.620  53.064  1
537976  96.161  -59.626  53.045  1
537977  96.198  -59.631  53.023  1
537978  96.235  -59.636  52.998  1
537979  96.272  -59.641  52.971  1
537980  96.308  -59.645  52.941  1
537981  96.343  -59.648  52.909  1
537982  96.378  -59.651  52.878  1
537983  96.413  -59.654  52.849  1
537984  96.449  -59.657  52.821  1
537985  96.484  -59.660  52.794  1
537986  96.520  -59.663  52.764  1
537987  96.555  -59.666  52.737  1
537988  96.591  -59.669  52.712  1
537989  96.629  -59.670  52.685  1
537990  96.661  -59.669  52.656  1
537991  96.693  -59.667  52.626  1
537992  96.726  -59.666  52.594  1
537993  96.757  -59.664  52.562  1
537994  96.790  -59.663  52.529  1
537995  96.821  -59.662  52.495  1
537996  96.855  -59.663  52.457  1
537997  96.888  -59.665  52.416  1
537998  96.922  -59.667  52.374  1
537999  96.956  -59.670  52.330  1
538000  96.990  -59.672  52.288  1
538001  97.023  -59.675  52.246  1
538002  97.057  -59.677  52.206  1
538003  97.091  -59.679  52.167  1
538004  97.124  -59.682  52.125  1
538005  97.158  -59.684  52.085  1
538006  97.192  -59.686  52.049  1
538007  97.226  -59.689  52.015  1
538008  97.260  -59.691  51.979  1
538009  97.293  -59.696  51.943  1
538010  97.323  -59.709  51.905  1
538011  97.358  -59.713  51.864  1
538012  97.395  -59.714  51.820  1
538013  97.436  -59.726  51.773  1
538014  97.476  -59.737  51.727  1
538015  97.518  -59.748  51.677  1
538016  97.559  -59.759  51.626  1
538017  97.599  -59.770  51.572  1
538018  97.640  -59.782  51.516  1
538019  97.679  -59.792  51.458  1
538020  97.719  -59.804  51.399  1
538021  97.759  -59.815  51.342  1
538022  97.799  -59.826  51.288  1
538023  97.839  -59.837  51.235  1
538024  97.878  -59.848  51.182  1
538025  97.918  -59.859  51.128  1
538026  97.958  -59.870  51.076  1
538027  97.998  -59.881  51.027  1
538028  98.037  -59.892  50.980  1
538029  98.080  -59.895  50.936  1
538030  98.122  -59.898  50.894  1
538031  98.156  -59.892  50.853  1
538032  98.185  -59.879  50.814  1
538033  98.207  -59.885  50.775  1
538034  98.228  -59.892  50.736  1
538035  98.249  -59.898  50.699  1
538036  98.271  -59.905  50.662  1
538037  98.293  -59.911  50.630  1
538038  98.314  -59.917  50.598  1
538039  98.352  -59.925  50.567  1
538040  98.390  -59.910  50.534  1
538041  98.433  -59.909  50.499  1
538042  98.480  -59.898  50.458  1
538043  98.526  -59.881  50.416  1
538044  98.573  -59.864  50.373  1
538045  98.619  -59.847  50.330  1
538046  98.662  -59.837  50.285  1
538047  98.699  -59.842  50.239  1
538048  98.735  -59.845  50.193  1
538049  98.771  -59.850  50.148  1
538050  98.807  -59.846  50.103  1
538051  98.840  -59.824  50.059  1
538052  98.873  -59.801  50.015  1
538053  98.906  -59.779  49.971  1
538054  98.967  -59.775  49.927  1
538055  99.020  -59.775  49.882  1
538056  99.049  -59.779  49.838  1
538057  99.078  -59.783  49.796  1
538058  99.106  -59.787  49.754  1
538059  99.135  -59.791  49.712  1
538060  99.164  -59.795  49.671  1
538482  88.825  -57.330  56.254  1
538483  88.863  -57.346  56.236  1
538484  88.901  -57.362  56.216  1
538485  88.940  -57.378  56.196  1
538486  88.978  -57.394  56.175  1
538487  89.016  -57.410  56.155  1
538488  89.049  -57.429  56.136  1
538489  89.073  -57.453  56.116  1
538490  89.098  -57.477  56.096  1
538491  89.122  -57.501  56.076  1
538492  89.154  -57.520  56.055  1
538493  89.195  -57.530  56.034  1
538494  89.237  -57.541  56.013  1
538495  89.278  -57.552  55.992  1
538496  89.319  -57.563  55.971  1
538497  89.361  -57.573  55.951  1
538498  89.402  -57.585  55.932  1
538499  89.444  -57.595  55.914  1
538500  89.488  -57.609  55.895  1
538501  89.538  -57.626  55.880  1
538502  89.587  -57.643  55.868  1
538503  89.635  -57.660  55.858  1
538504  89.685  -57.677  55.849  1
538505  89.734  -57.694  55.842  1
538506  89.782  -57.711  55.835  1
538507  89.829  -57.726  55.831  1
538508  89.865  -57.736  55.828  1
538509  89.901  -57.746  55.826  1
538510  89.938  -57.756  55.823  1
538511  89.974  -57.766  55.821  1
538512  90.011  -57.776  55.819  1
538513  90.047  -57.786  55.814  1
538514  90.084  -57.796  55.809  1
538515  90.120  -57.805  55.802  1
538516  90.156  -57.815  55.793  1
538517  90.192  -57.826  55.786  1
538518  90.229  -57.836  55.778  1
538519  90.265  -57.846  55.764  1
538520  90.301  -57.856  55.740  1
538521  90.335  -57.868  55.708  1
538522  90.369  -57.879  55.671  1
538523  90.402  -57.890  55.644  1
538524  90.437  -57.902  55.618  1
538525  90.470  -57.914  55.594  1
538526  90.504  -57.925  55.574  1
538527  90.539  -57.936  55.555  1
538528  90.581  -57.940  55.536  1
538529  90.623  -57.945  55.511  1
538530  90.665  -57.949  55.482  1
538531  90.707  -57.954  55.452  1
538532  90.750  -57.959  55.420  1
538533  90.795  -57.966  55.387  1
538534  90.840  -57.973  55.355  1
538535  90.885  -57.979  55.325  1
538536  90.930  -57.986  55.298  1
538537  90.975  -57.992  55.272  1
538538  91.018  -58.006  55.249  1
538539  91.058  -58.029  55.230  1
538540  91.097  -58.053  55.213  1
538541  91.137  -58.077  55.198  1
538542  91.176  -58.100  55.187  1
538543  91.216  -58.124  55.180  1
538544  91.255  -58.148  55.175  1
538545  91.295  -58.172  55.170  1
538546  91.335  -58.195  55.162  1
538547  91.374  -58.219  55.148  1
538548  91.414  -58.243  55.131  1
538549  91.453  -58.266  55.111  1
538550  91.493  -58.290  55.093  1
538551  91.533  -58.313  55.080  1
538552  91.572  -58.338  55.073  1
538553  91.614  -58.355  55.071  1
538554  91.658  -58.366  55.068  1
538555  91.688  -58.388  55.061  1
538556  91.716  -58.397  55.053  1
538557  91.744  -58.407  55.043  1
538558  91.773  -58.416  55.029  1
538559  91.810  -58.426  55.012  1
538560  91.847  -58.436  54.989  1
538561  91.885  -58.446  54.962  1
538562  91.922  -58.457  54.934  1
538563  91.959  -58.466  54.911  1
538564  91.997  -58.477  54.892  1
538565  92.034  -58.487  54.876  1
538566  92.072  -58.498  54.865  1
538567  92.109  -58.507  54.851  1
538568  92.150  -58.518  54.835  1
538569  92.192  -58.528  54.813  1
538570  92.231  -58.531  54.786  1
538571  92.270  -58.534  54.753  1
538572  92.308  -58.537  54.732  1
538573  92.347  -58.541  54.722  1
538574  92.386  -58.544  54.725  1
538575  92.425  -58.547  54.733  1
538576  92.464  -58.550  54.741  1
538577  92.503  -58.553  54.745  1
538578  92.534  -58.558  54.745  1
538579  92.564  -58.563  54.753  1
538580  92.593  -58.569  54.767  1
538581  92.623  -58.574  54.780  1
538582  92.654  -58.579  54.784  1
538583  92.700  -58.585  54.789  1
538584  92.745  -58.591  54.796  1
538585  92.791  -58.597  54.804  1
538586  92.837  -58.603  54.812  1
538587  92.882  -58.609  54.816  1
538588  92.928  -58.615  54.814  1
538589  92.974  -58.621  54.813  1
538590  93.016  -58.628  54.808  1
538591  93.055  -58.638  54.798  1
538592  93.092  -58.647  54.784  1
538593  93.131  -58.657  54.766  1
538594  93.168  -58.667  54.742  1
538595  93.206  -58.676  54.720  1
538596  93.245  -58.686  54.700  1
538597  93.282  -58.695  54.680  1
538598  93.321  -58.702  54.661  1
538599  93.360  -58.711  54.644  1
538600  93.399  -58.718  54.628  1
538601  93.437  -58.726  54.613  1
538602  93.476  -58.733  54.599  1
538603  93.515  -58.741  54.582  1
538604  93.552  -58.751  54.566  1
538605  93.588  -58.765  54.550  1
538606  93.625  -58.779  54.534  1
538607  93.661  -58.792  54.521  1
538608  93.698  -58.806  54.512  1
538609  93.734  -58.820  54.507  1
538610  93.770  -58.834  54.501  1
538611  93.806  -58.848  54.489  1
538612  93.843  -58.861  54.474  1
538613  93.879  -58.875  54.456  1
538614  93.915  -58.889  54.433  1
538615  93.952  -58.902  54.406  1
538616  93.988  -58.916  54.376  1
538617  94.024  -58.930  54.347  1
538618  94.060  -58.943  54.317  1
538619  94.097  -58.957  54.290  1
538620  94.133  -58.971  54.272  1
538621  94.170  -58.984  54.264  1
538622  94.205  -59.003  54.246  1
538623  94.240  -59.024  54.230  1
538624  94.274  -59.044  54.214  1
538625  94.310  -59.065  54.194  1
538626  94.344  -59.084  54.172  1
538627  94.380  -59.105  54.144  1
538628  94.414  -59.125  54.114  1
538629  94.450  -59.146  54.082  1
538630  94.484  -59.160  54.049  1
538631  94.518  -59.168  54.014  1
538632  94.552  -59.175  53.983  1
538633  94.587  -59.182  53.952  1
538634  94.626  -59.190  53.920  1
538635  94.664  -59.200  53.888  1
538636  94.702  -59.208  53.855  1
538637  94.744  -59.218  53.823  1
538638  94.785  -59.228  53.789  1
538639  94.826  -59.237  53.753  1
538640  94.867  -59.247  53.719  1
538641  94.908  -59.257  53.686  1
538642  94.950  -59.267  53.653  1
538643  94.991  -59.277  53.621  1
538644  95.030  -59.287  53.590  1
538645  95.067  -59.299  53.559  1
538646  95.104  -59.309  53.527  1
538647  95.141  -59.320  53.495  1
538648  95.179  -59.331  53.466  1
538649  95.216  -59.342  53.441  1
538650  95.254  -59.353  53.418  1
538651  95.293  -59.364  53.395  1
538652  95.328  -59.375  53.374  1
538653  95.361  -59.387  53.355  1
538654  95.394  -59.398  53.334  1
538655  95.428  -59.410  53.313  1
538656  95.461  -59.421  53.299  1
538657  95.494  -59.432  53.290  1
538658  95.528  -59.444  53.285  1
538659  95.561  -59.455  53.282  1
538660  95.594  -59.466  53.280  1
538661  95.627  -59.477  53.278  1
538662  95.660  -59.488  53.273  1
538663  95.693  -59.498  53.269  1
538664  95.725  -59.507  53.269  1
538665  95.756  -59.515  53.265  1
538666  95.787  -59.524  53.259  1
538667  95.818  -59.532  53.250  1
538668  95.851  -59.539  53.237  1
538669  95.885  -59.547  53.223  1
538670  95.919  -59.554  53.205  1
538671  95.954  -59.559  53.186  1
538672  95.989  -59.565  53.163  1
538673  96.024  -59.571  53.140  1
538674  96.059  -59.577  53.118  1
538675  96.094  -59.582  53.099  1
538676  96.129  -59.588  53.082  1
538677  96.166  -59.594  53.063  1
538678  96.202  -59.599  53.041  1
538679  96.239  -59.604  53.014  1
538680  96.274  -59.607  52.984  1
538681  96.309  -59.610  52.951  1
538682  96.344  -59.613  52.917  1
538683  96.380  -59.616  52.887  1
538684  96.415  -59.619  52.860  1
538685  96.451  -59.622  52.833  1
538686  96.486  -59.625  52.806  1
538687  96.521  -59.628  52.775  1
538688  96.556  -59.631  52.751  1
538689  96.592  -59.634  52.727  1
538690  96.626  -59.636  52.701  1
538691  96.658  -59.635  52.672  1
538692  96.690  -59.633  52.642  1
538693  96.722  -59.632  52.610  1
538694  96.754  -59.631  52.577  1
538695  96.786  -59.629  52.542  1
538696  96.818  -59.629  52.505  1
538697  96.851  -59.629  52.465  1
538698  96.885  -59.632  52.422  1
538699  96.919  -59.634  52.380  1
538700  96.952  -59.636  52.337  1
538701  96.986  -59.638  52.297  1
538702  97.020  -59.641  52.257  1
538703  97.053  -59.643  52.217  1
538704  97.087  -59.645  52.176  1
538705  97.121  -59.648  52.135  1
538706  97.155  -59.650  52.098  1
538707  97.189  -59.653  52.065  1
538708  97.223  -59.655  52.034  1
538709  97.256  -59.657  51.999  1
538710  97.290  -59.660  51.963  1
538711  97.322  -59.667  51.926  1
538712  97.356  -59.674  51.885  1
538713  97.394  -59.679  51.840  1
538714  97.435  -59.690  51.794  1
538715  97.476  -59.701  51.747  1
538716  97.517  -59.713  51.697  1
538717  97.557  -59.724  51.645  1
538718  97.596  -59.735  51.591  1
538719  97.636  -59.746  51.535  1
538720  97.676  -59.757  51.476  1
538721  97.716  -59.768  51.415  1
538722  97.755  -59.779  51.356  1
538723  97.795  -59.790  51.299  1
538724  97.836  -59.801  51.244  1
538725  97.875  -59.813  51.191  1
538726  97.915  -59.823  51.136  1
538727  97.955  -59.835  51.082  1
538728  97.995  -59.846  51.031  1
538729  98.035  -59.855  50.984  1
538730  98.077  -59.858  50.938  1
538731  98.119  -59.861  50.895  1
538732  98.155  -59.857  50.854  1
538733  98.184  -59.844  50.815  1
538734  98.209  -59.841  50.776  1
538735  98.231  -59.848  50.738  1
538736  98.252  -59.854  50.701  1
538737  98.274  -59.861  50.666  1
538738  98.295  -59.867  50.633  1
538739  98.317  -59.873  50.603  1
538740  98.358  -59.881  50.574  1
538741  98.398  -59.873  50.543  1
538742  98.437  -59.858  50.509  1
538743  98.479  -59.852  50.470  1
538744  98.525  -59.858  50.429  1
538745  98.572  -59.842  50.388  1
538746  98.618  -59.825  50.345  1
538747  98.664  -59.808  50.302  1
538748  98.705  -59.804  50.256  1
538749  98.741  -59.808  50.208  1
538750  98.778  -59.813  50.160  1
538751  98.812  -59.806  50.115  1
538752  98.846  -59.783  50.071  1
538753  98.878  -59.761  50.026  1
538754  98.912  -59.739  49.981  1
538755  98.975  -59.736  49.937  1
538756  99.019  -59.738  49.892  1
538757  99.048  -59.742  49.847  1
538758  99.076  -59.745  49.806  1
538759  99.105  -59.750  49.764  1
538760  99.134  -59.754  49.722  1
538761  99.162  -59.757  49.681  1
538762  99.191  -59.761  49.641  1
539185  88.919  -57.323  56.202  1
539186  88.958  -57.339  56.182  1
539187  88.996  -57.355  56.162  1
539188  89.034  -57.371  56.143  1
539189  89.067  -57.390  56.124  1
539190  89.092  -57.414  56.105  1
539191  89.116  -57.438  56.085  1
539192  89.140  -57.462  56.066  1
539193  89.173  -57.480  56.045  1
539194  89.214  -57.491  56.025  1
539195  89.256  -57.501  56.005  1
539196  89.298  -57.512  55.986  1
539197  89.339  -57.523  55.965  1
539198  89.380  -57.534  55.946  1
539199  89.421  -57.545  55.928  1
539200  89.463  -57.556  55.910  1
539201  89.505  -57.567  55.892  1
539202  89.550  -57.581  55.878  1
539203  89.599  -57.598  55.866  1
539204  89.649  -57.615  55.855  1
539205  89.697  -57.632  55.846  1
539206  89.747  -57.648  55.838  1
539207  89.796  -57.666  55.830  1
539208  89.844  -57.683  55.827  1
539209  89.881  -57.692  55.824  1
539210  89.917  -57.702  55.821  1
539211  89.954  -57.712  55.817  1
539212  89.990  -57.723  55.814  1
539213  90.026  -57.733  55.811  1
539214  90.062  -57.742  55.805  1
539215  90.099  -57.752  55.799  1
539216  90.135  -57.762  55.791  1
539217  90.172  -57.772  55.783  1
539218  90.208  -57.782  55.774  1
539219  90.245  -57.792  55.766  1
539220  90.280  -57.805  55.750  1
539221  90.314  -57.816  55.725  1
539222  90.347  -57.827  55.693  1
539223  90.381  -57.839  55.657  1
539224  90.414  -57.849  55.629  1
539225  90.448  -57.861  55.603  1
539226  90.481  -57.872  55.579  1
539227  90.515  -57.883  55.559  1
539228  90.548  -57.894  55.541  1
539229  90.586  -57.903  55.520  1
539230  90.630  -57.909  55.490  1
539231  90.675  -57.915  55.459  1
539232  90.720  -57.921  55.428  1
539233  90.765  -57.928  55.396  1
539234  90.810  -57.935  55.365  1
539235  90.855  -57.941  55.336  1
539236  90.900  -57.948  55.310  1
539237  90.945  -57.954  55.286  1
539238  90.990  -57.961  55.263  1
539239  91.032  -57.976  55.242  1
539240  91.072  -57.999  55.224  1
539241  91.111  -58.023  55.208  1
539242  91.151  -58.046  55.194  1
539243  91.190  -58.071  55.183  1
539244  91.230  -58.094  55.174  1
539245  91.270  -58.118  55.167  1
539246  91.309  -58.141  55.159  1
539247  91.349  -58.165  55.149  1
539248  91.388  -58.189  55.138  1
539249  91.428  -58.212  55.125  1
539250  91.467  -58.236  55.111  1
539251  91.507  -58.260  55.099  1
539252  91.546  -58.284  55.089  1
539253  91.587  -58.305  55.081  1
539254  91.631  -58.316  55.075  1
539255  91.674  -58.326  55.073  1
539256  91.709  -58.345  55.070  1
539257  91.739  -58.367  55.066  1
539258  91.767  -58.378  55.055  1
539259  91.795  -58.386  55.039  1
539260  91.827  -58.396  55.019  1
539261  91.864  -58.406  54.992  1
539262  91.901  -58.416  54.965  1
539263  91.939  -58.426  54.937  1
539264  91.977  -58.437  54.911  1
539265  92.014  -58.447  54.890  1
539266  92.052  -58.457  54.874  1
539267  92.089  -58.467  54.860  1
539268  92.127  -58.478  54.844  1
539269  92.170  -58.488  54.830  1
539270  92.212  -58.498  54.811  1
539271  92.251  -58.502  54.786  1
539272  92.290  -58.505  54.757  1
539273  92.329  -58.509  54.735  1
539274  92.368  -58.512  54.722  1
539275  92.407  -58.515  54.718  1
539276  92.446  -58.518  54.721  1
539277  92.485  -58.521  54.727  1
539278  92.520  -58.526  54.734  1
539279  92.549  -58.531  54.736  1
539280  92.579  -58.536  54.742  1
539281  92.609  -58.542  54.753  1
539282  92.638  -58.546  54.767  1
539283  92.667  -58.551  54.774  1
539284  92.711  -58.557  54.772  1
539285  92.756  -58.563  54.776  1
539286  92.802  -58.570  54.786  1
539287  92.847  -58.576  54.799  1
539288  92.893  -58.581  54.809  1
539289  92.938  -58.587  54.809  1
539290  92.984  -58.593  54.808  1
539291  93.025  -58.601  54.806  1
539292  93.063  -58.611  54.801  1
539293  93.100  -58.621  54.790  1
539294  93.139  -58.630  54.774  1
539295  93.177  -58.640  54.752  1
539296  93.215  -58.650  54.730  1
539297  93.253  -58.659  54.710  1
539298  93.290  -58.669  54.690  1
539299  93.329  -58.676  54.669  1
539300  93.368  -58.685  54.650  1
539301  93.407  -58.692  54.633  1
539302  93.445  -58.700  54.620  1
539303  93.484  -58.708  54.607  1
539304  93.522  -58.715  54.594  1
539305  93.560  -58.726  54.583  1
539306  93.596  -58.741  54.572  1
539307  93.632  -58.755  54.557  1
539308  93.669  -58.768  54.542  1
539309  93.705  -58.782  54.530  1
539310  93.742  -58.795  54.521  1
539311  93.778  -58.809  54.513  1
539312  93.814  -58.823  54.503  1
539313  93.850  -58.836  54.491  1
539314  93.887  -58.850  54.476  1
539315  93.923  -58.864  54.457  1
539316  93.959  -58.877  54.431  1
539317  93.995  -58.891  54.405  1
539318  94.032  -58.905  54.377  1
539319  94.068  -58.918  54.348  1
539320  94.104  -58.932  54.321  1
539321  94.140  -58.946  54.299  1
539322  94.177  -58.960  54.285  1
539323  94.213  -58.974  54.269  1
539324  94.249  -58.990  54.252  1
539325  94.284  -59.010  54.234  1
539326  94.319  -59.030  54.215  1
539327  94.354  -59.050  54.190  1
539328  94.389  -59.071  54.163  1
539329  94.424  -59.091  54.134  1
539330  94.459  -59.111  54.102  1
539331  94.493  -59.124  54.069  1
539332  94.527  -59.131  54.034  1
539333  94.561  -59.138  54.004  1
539334  94.600  -59.146  53.972  1
539335  94.638  -59.156  53.939  1
539336  94.677  -59.164  53.905  1
539337  94.715  -59.172  53.869  1
539338  94.757  -59.182  53.834  1
539339  94.798  -59.193  53.797  1
539340  94.839  -59.203  53.762  1
539341  94.880  -59.213  53.728  1
539342  94.921  -59.224  53.693  1
539343  94.962  -59.235  53.660  1
539344  95.002  -59.246  53.629  1
539345  95.043  -59.256  53.597  1
539346  95.079  -59.267  53.564  1
539347  95.116  -59.278  53.532  1
539348  95.153  -59.287  53.503  1
539349  95.190  -59.298  53.478  1
539350  95.227  -59.309  53.456  1
539351  95.264  -59.320  53.434  1
539352  95.300  -59.331  53.412  1
539353  95.333  -59.343  53.391  1
539354  95.367  -59.354  53.372  1
539355  95.400  -59.366  53.351  1
539356  95.433  -59.377  53.331  1
539357  95.467  -59.388  53.315  1
539358  95.500  -59.400  53.305  1
539359  95.533  -59.411  53.299  1
539360  95.566  -59.422  53.293  1
539361  95.600  -59.434  53.291  1
539362  95.633  -59.445  53.287  1
539363  95.666  -59.456  53.282  1
539364  95.699  -59.466  53.277  1
539365  95.730  -59.474  53.277  1
539366  95.761  -59.482  53.273  1
539367  95.793  -59.491  53.266  1
539368  95.824  -59.500  53.257  1
539369  95.855  -59.508  53.245  1
539370  95.889  -59.515  53.230  1
539371  95.923  -59.521  53.214  1
539372  95.959  -59.527  53.194  1
539373  95.994  -59.533  53.172  1
539374  96.029  -59.539  53.151  1
539375  96.064  -59.544  53.133  1
539376  96.099  -59.551  53.115  1
539377  96.134  -59.557  53.098  1
539378  96.170  -59.562  53.077  1
539379  96.205  -59.566  53.053  1
539380  96.240  -59.569  53.024  1
539381  96.276  -59.573  52.992  1
539382  96.311  -59.576  52.958  1
539383  96.346  -59.580  52.923  1
539384  96.382  -59.583  52.895  1
539385  96.417  -59.587  52.868  1
539386  96.453  -59.591  52.843  1
539387  96.488  -59.595  52.816  1
539388  96.524  -59.598  52.788  1
539389  96.559  -59.602  52.764  1
539390  96.595  -59.606  52.741  1
539391  96.625  -59.604  52.715  1
539392  96.654  -59.601  52.687  1
539393  96.686  -59.600  52.657  1
539394  96.718  -59.598  52.625  1
539395  96.750  -59.597  52.590  1
539396  96.783  -59.596  52.553  1
539397  96.814  -59.595  52.514  1
539398  96.848  -59.596  52.471  1
539399  96.881  -59.598  52.428  1
539400  96.915  -59.601  52.387  1
539401  96.949  -59.603  52.347  1
539402  96.982  -59.605  52.308  1
539403  97.016  -59.607  52.269  1
539404  97.050  -59.610  52.226  1
539405  97.084  -59.612  52.183  1
539406  97.118  -59.614  52.143  1
539407  97.152  -59.616  52.109  1
539408  97.185  -59.619  52.080  1
539409  97.219  -59.621  52.052  1
539410  97.253  -59.623  52.017  1
539411  97.287  -59.626  51.982  1
539412  97.320  -59.628  51.945  1
539413  97.353  -59.635  51.904  1
539414  97.393  -59.644  51.859  1
539415  97.434  -59.655  51.812  1
539416  97.474  -59.666  51.763  1
539417  97.514  -59.677  51.712  1
539418  97.554  -59.689  51.659  1
539419  97.593  -59.699  51.605  1
539420  97.633  -59.710  51.548  1
539421  97.673  -59.722  51.489  1
539422  97.713  -59.732  51.428  1
539423  97.752  -59.744  51.368  1
539424  97.792  -59.755  51.310  1
539425  97.832  -59.766  51.253  1
539426  97.872  -59.777  51.199  1
539427  97.912  -59.789  51.143  1
539428  97.951  -59.799  51.089  1
539429  97.991  -59.811  51.037  1
539430  98.032  -59.817  50.988  1
539431  98.074  -59.820  50.941  1
539432  98.117  -59.823  50.898  1
539433  98.155  -59.822  50.856  1
539434  98.184  -59.808  50.817  1
539435  98.212  -59.797  50.778  1
539436  98.233  -59.804  50.740  1
539437  98.255  -59.810  50.703  1
539438  98.277  -59.817  50.669  1
539439  98.298  -59.823  50.636  1
539440  98.319  -59.830  50.606  1
539441  98.363  -59.838  50.578  1
539442  98.407  -59.836  50.549  1
539443  98.445  -59.821  50.518  1
539444  98.484  -59.806  50.480  1
539445  98.523  -59.796  50.441  1
539446  98.570  -59.805  50.400  1
539447  98.617  -59.803  50.358  1
539448  98.663  -59.786  50.316  1
539449  98.710  -59.770  50.270  1
539450  98.747  -59.771  50.221  1
539451  98.784  -59.775  50.173  1
539452  98.818  -59.765  50.126  1
539453  98.851  -59.742  50.082  1
539454  98.884  -59.720  50.037  1
539455  98.921  -59.699  49.992  1
539456  98.984  -59.698  49.947  1
539457  99.017  -59.701  49.902  1
539458  99.046  -59.704  49.858  1
539459  99.075  -59.708  49.816  1
539460  99.103  -59.712  49.774  1
539461  99.132  -59.717  49.733  1
539462  99.161  -59.720  49.692  1
539463  99.190  -59.724  49.651  1
539464  99.218  -59.728  49.612  1
539887  88.975  -57.300  56.167  1
539888  89.014  -57.316  56.149  1
539889  89.052  -57.333  56.130  1
539890  89.086  -57.351  56.111  1
539891  89.110  -57.375  56.093  1
539892  89.135  -57.399  56.074  1
539893  89.159  -57.423  56.055  1
539894  89.193  -57.440  56.036  1
539895  89.234  -57.451  56.016  1
539896  89.275  -57.462  55.996  1
539897  89.317  -57.473  55.979  1
539898  89.358  -57.483  55.959  1
539899  89.400  -57.495  55.941  1
539900  89.441  -57.505  55.923  1
539901  89.482  -57.516  55.906  1
539902  89.524  -57.527  55.888  1
539903  89.565  -57.538  55.875  1
539904  89.612  -57.553  55.863  1
539905  89.661  -57.570  55.852  1
539906  89.710  -57.587  55.843  1
539907  89.759  -57.604  55.834  1
539908  89.809  -57.621  55.826  1
539909  89.858  -57.638  55.822  1
539910  89.896  -57.649  55.818  1
539911  89.933  -57.659  55.814  1
539912  89.969  -57.669  55.810  1
539913  90.006  -57.679  55.805  1
539914  90.042  -57.689  55.799  1
539915  90.078  -57.699  55.793  1
539916  90.115  -57.709  55.785  1
539917  90.151  -57.719  55.776  1
539918  90.187  -57.729  55.767  1
539919  90.224  -57.739  55.759  1
539920  90.259  -57.751  55.747  1
539921  90.294  -57.766  55.728  1
539922  90.327  -57.777  55.702  1
539923  90.361  -57.789  55.671  1
539924  90.395  -57.799  55.639  1
539925  90.428  -57.811  55.611  1
539926  90.462  -57.822  55.584  1
539927  90.495  -57.833  55.561  1
539928  90.529  -57.844  55.541  1
539929  90.562  -57.855  55.522  1
539930  90.599  -57.871  55.499  1
539931  90.644  -57.877  55.467  1
539932  90.689  -57.884  55.436  1
539933  90.734  -57.890  55.406  1
539934  90.779  -57.897  55.378  1
539935  90.824  -57.903  55.351  1
539936  90.869  -57.910  55.325  1
539937  90.914  -57.916  55.303  1
539938  90.959  -57.923  55.282  1
539939  91.004  -57.929  55.262  1
539940  91.046  -57.946  55.242  1
539941  91.085  -57.969  55.225  1
539942  91.125  -57.993  55.210  1
539943  91.165  -58.017  55.197  1
539944  91.204  -58.040  55.186  1
539945  91.244  -58.064  55.177  1
539946  91.284  -58.088  55.169  1
539947  91.323  -58.112  55.156  1
539948  91.363  -58.135  55.143  1
539949  91.402  -58.159  55.132  1
539950  91.442  -58.183  55.124  1
539951  91.482  -58.206  55.117  1
539952  91.521  -58.230  55.111  1
539953  91.561  -58.253  55.104  1
539954  91.604  -58.266  55.095  1
539955  91.648  -58.277  55.087  1
539956  91.692  -58.287  55.081  1
539957  91.729  -58.303  55.079  1
539958  91.759  -58.325  55.075  1
539959  91.790  -58.347  55.066  1
539960  91.818  -58.357  55.049  1
539961  91.846  -58.366  55.026  1
539962  91.881  -58.376  54.995  1
539963  91.919  -58.386  54.968  1
539964  91.956  -58.397  54.946  1
539965  91.994  -58.407  54.926  1
539966  92.031  -58.417  54.910  1
539967  92.068  -58.428  54.896  1
539968  92.106  -58.438  54.880  1
539969  92.147  -58.448  54.862  1
539970  92.190  -58.458  54.840  1
539971  92.232  -58.468  54.812  1
539972  92.272  -58.474  54.782  1
539973  92.311  -58.477  54.758  1
539974  92.350  -58.480  54.740  1
539975  92.388  -58.483  54.725  1
539976  92.428  -58.486  54.715  1
539977  92.466  -58.490  54.710  1
539978  92.505  -58.493  54.713  1
539979  92.535  -58.498  54.719  1
539980  92.564  -58.504  54.724  1
539981  92.594  -58.508  54.731  1
539982  92.624  -58.513  54.742  1
539983  92.653  -58.519  54.755  1
539984  92.683  -58.524  54.763  1
539985  92.721  -58.530  54.764  1
539986  92.767  -58.536  54.773  1
539987  92.812  -58.542  54.789  1
539988  92.858  -58.548  54.806  1
539989  92.904  -58.554  54.817  1
539990  92.949  -58.560  54.821  1
539991  92.995  -58.566  54.821  1
539992  93.033  -58.575  54.819  1
539993  93.071  -58.585  54.812  1
539994  93.109  -58.595  54.799  1
539995  93.147  -58.604  54.785  1
539996  93.185  -58.614  54.767  1
539997  93.223  -58.623  54.749  1
539998  93.261  -58.632  54.731  1
539999  93.298  -58.642  54.712  1
540000  93.337  -58.651  54.692  1
540001  93.376  -58.659  54.668  1
540002  93.414  -58.667  54.647  1
540003  93.453  -58.674  54.631  1
540004  93.492  -58.682  54.621  1
540005  93.531  -58.689  54.615  1
540006  93.567  -58.702  54.605  1
540007  93.604  -58.716  54.598  1
540008  93.640  -58.730  54.587  1
540009  93.676  -58.743  54.572  1
540010  93.712  -58.757  54.553  1
540011  93.749  -58.770  54.532  1
540012  93.785  -58.784  54.521  1
540013  93.822  -58.798  54.513  1
540014  93.858  -58.811  54.506  1
540015  93.894  -58.825  54.495  1
540016  93.930  -58.839  54.480  1
540017  93.967  -58.852  54.457  1
540018  94.003  -58.867  54.434  1
540019  94.039  -58.880  54.408  1
540020  94.075  -58.894  54.381  1
540021  94.112  -58.908  54.356  1
540022  94.148  -58.921  54.331  1
540023  94.184  -58.935  54.307  1
540024  94.220  -58.949  54.288  1
540025  94.257  -58.962  54.270  1
540026  94.293  -58.976  54.250  1
540027  94.328  -58.996  54.231  1
540028  94.363  -59.016  54.207  1
540029  94.398  -59.036  54.183  1
540030  94.433  -59.056  54.155  1
540031  94.468  -59.077  54.124  1
540032  94.502  -59.087  54.090  1
540033  94.537  -59.094  54.055  1
540034  94.574  -59.102  54.025  1
540035  94.613  -59.112  53.991  1
540036  94.651  -59.120  53.958  1
540037  94.689  -59.128  53.924  1
540038  94.729  -59.139  53.889  1
540039  94.769  -59.150  53.851  1
540040  94.810  -59.161  53.812  1
540041  94.850  -59.171  53.774  1
540042  94.891  -59.182  53.735  1
540043  94.932  -59.193  53.697  1
540044  94.973  -59.204  53.661  1
540045  95.014  -59.215  53.628  1
540046  95.054  -59.225  53.597  1
540047  95.092  -59.236  53.567  1
540048  95.129  -59.247  53.539  1
540049  95.166  -59.257  53.517  1
540050  95.203  -59.268  53.494  1
540051  95.240  -59.278  53.471  1
540052  95.276  -59.289  53.450  1
540053  95.309  -59.302  53.428  1
540054  95.342  -59.312  53.405  1
540055  95.375  -59.324  53.385  1
540056  95.408  -59.335  53.368  1
540057  95.441  -59.346  53.350  1
540058  95.474  -59.357  53.334  1
540059  95.508  -59.369  53.321  1
540060  95.540  -59.379  53.315  1
540061  95.573  -59.391  53.307  1
540062  95.607  -59.402  53.303  1
540063  95.639  -59.413  53.299  1
540064  95.673  -59.424  53.294  1
540065  95.704  -59.433  53.289  1
540066  95.736  -59.441  53.287  1
540067  95.767  -59.450  53.281  1
540068  95.798  -59.459  53.273  1
540069  95.829  -59.467  53.264  1
540070  95.861  -59.475  53.252  1
540071  95.894  -59.483  53.236  1
540072  95.929  -59.489  53.220  1
540073  95.964  -59.495  53.200  1
540074  95.999  -59.501  53.180  1
540075  96.034  -59.507  53.161  1
540076  96.070  -59.513  53.146  1
540077  96.105  -59.518  53.129  1
540078  96.140  -59.524  53.110  1
540079  96.174  -59.530  53.088  1
540080  96.208  -59.536  53.060  1
540081  96.243  -59.540  53.028  1
540082  96.278  -59.544  52.995  1
540083  96.314  -59.547  52.963  1
540084  96.349  -59.551  52.932  1
540085  96.385  -59.555  52.905  1
540086  96.420  -59.559  52.880  1
540087  96.456  -59.563  52.854  1
540088  96.491  -59.566  52.828  1
540089  96.527  -59.569  52.802  1
540090  96.562  -59.573  52.777  1
540091  96.595  -59.575  52.753  1
540092  96.624  -59.572  52.728  1
540093  96.654  -59.569  52.700  1
540094  96.683  -59.566  52.670  1
540095  96.715  -59.564  52.637  1
540096  96.747  -59.563  52.600  1
540097  96.779  -59.562  52.561  1
540098  96.811  -59.560  52.522  1
540099  96.844  -59.562  52.480  1
540100  96.878  -59.564  52.439  1
540101  96.911  -59.566  52.399  1
540102  96.945  -59.569  52.358  1
540103  96.979  -59.571  52.318  1
540104  97.013  -59.574  52.278  1
540105  97.047  -59.576  52.233  1
540106  97.081  -59.579  52.189  1
540107  97.114  -59.581  52.148  1
540108  97.148  -59.583  52.115  1
540109  97.182  -59.585  52.089  1
540110  97.216  -59.588  52.063  1
540111  97.249  -59.590  52.032  1
540112  97.283  -59.592  51.998  1
540113  97.317  -59.595  51.960  1
540114  97.352  -59.598  51.918  1
540115  97.391  -59.608  51.873  1
540116  97.431  -59.620  51.823  1
540117  97.470  -59.631  51.773  1
540118  97.510  -59.641  51.719  1
540119  97.550  -59.653  51.664  1
540120  97.590  -59.664  51.609  1
540121  97.630  -59.675  51.552  1
540122  97.669  -59.686  51.495  1
540123  97.709  -59.698  51.436  1
540124  97.749  -59.708  51.379  1
540125  97.789  -59.720  51.323  1
540126  97.829  -59.731  51.265  1
540127  97.869  -59.742  51.208  1
540128  97.909  -59.753  51.152  1
540129  97.948  -59.764  51.096  1
540130  97.988  -59.775  51.043  1
540131  98.030  -59.779  50.992  1
540132  98.072  -59.783  50.945  1
540133  98.113  -59.786  50.901  1
540134  98.154  -59.787  50.859  1
540135  98.183  -59.773  50.819  1
540136  98.212  -59.760  50.780  1
540137  98.236  -59.760  50.741  1
540138  98.258  -59.766  50.705  1
540139  98.279  -59.773  50.671  1
540140  98.301  -59.779  50.638  1
540141  98.322  -59.786  50.608  1
540142  98.368  -59.794  50.580  1
540143  98.416  -59.799  50.554  1
540144  98.454  -59.784  50.524  1
540145  98.492  -59.769  50.488  1
540146  98.530  -59.754  50.450  1
540147  98.568  -59.740  50.409  1
540148  98.615  -59.749  50.368  1
540149  98.662  -59.758  50.327  1
540150  98.709  -59.748  50.281  1
540151  98.754  -59.733  50.234  1
540152  98.790  -59.738  50.186  1
540153  98.824  -59.724  50.138  1
540154  98.857  -59.701  50.092  1
540155  98.890  -59.679  50.047  1
540156  98.929  -59.660  50.002  1
540157  98.987  -59.660  49.957  1
540158  99.016  -59.663  49.912  1
540159  99.045  -59.667  49.868  1
540160  99.073  -59.671  49.827  1
540161  99.102  -59.675  49.785  1
540162  99.131  -59.679  49.744  1
540163  99.159  -59.683  49.702  1
540164  99.188  -59.687  49.661  1
540165  99.217  -59.691  49.622  1
540589  89.031  -57.279  56.135  1
540590  89.069  -57.294  56.117  1
540591  89.105  -57.312  56.099  1
540592  89.129  -57.336  56.081  1
540593  89.154  -57.360  56.063  1
540594  89.178  -57.385  56.045  1
540595  89.212  -57.401  56.027  1
540596  89.254  -57.411  56.008  1
540597  89.295  -57.423  55.989  1
540598  89.336  -57.433  55.972  1
540599  89.378  -57.444  55.953  1
540600  89.419  -57.454  55.935  1
540601  89.461  -57.466  55.919  1
540602  89.502  -57.476  55.902  1
540603  89.543  -57.487  55.884  1
540604  89.585  -57.498  55.871  1
540605  89.626  -57.509  55.859  1
540606  89.674  -57.525  55.849  1
540607  89.723  -57.542  55.839  1
540608  89.772  -57.559  55.830  1
540609  89.821  -57.576  55.822  1
540610  89.871  -57.593  55.816  1
540611  89.912  -57.606  55.811  1
540612  89.949  -57.616  55.806  1
540613  89.985  -57.626  55.801  1
540614  90.021  -57.636  55.795  1
540615  90.057  -57.645  55.787  1
540616  90.094  -57.655  55.779  1
540617  90.130  -57.665  55.770  1
540618  90.167  -57.675  55.759  1
540619  90.203  -57.686  55.748  1
540620  90.239  -57.697  55.735  1
540621  90.273  -57.713  55.718  1
540622  90.308  -57.727  55.697  1
540623  90.341  -57.739  55.672  1
540624  90.375  -57.749  55.643  1
540625  90.408  -57.761  55.615  1
540626  90.442  -57.772  55.588  1
540627  90.475  -57.783  55.562  1
540628  90.509  -57.794  55.539  1
540629  90.542  -57.805  55.520  1
540630  90.579  -57.820  55.500  1
540631  90.616  -57.836  55.474  1
540632  90.659  -57.846  55.443  1
540633  90.704  -57.852  55.414  1
540634  90.749  -57.859  55.387  1
540635  90.794  -57.865  55.363  1
540636  90.838  -57.872  55.339  1
540637  90.883  -57.878  55.316  1
540638  90.929  -57.885  55.298  1
540639  90.973  -57.892  55.281  1
540640  91.018  -57.898  55.264  1
540641  91.060  -57.916  55.247  1
540642  91.099  -57.940  55.232  1
540643  91.139  -57.963  55.219  1
540644  91.178  -57.987  55.207  1
540645  91.218  -58.011  55.199  1
540646  91.258  -58.034  55.194  1
540647  91.297  -58.058  55.189  1
540648  91.337  -58.081  55.177  1
540649  91.377  -58.106  55.161  1
540650  91.416  -58.129  55.144  1
540651  91.456  -58.153  55.133  1
540652  91.495  -58.176  55.133  1
540653  91.535  -58.200  55.131  1
540654  91.577  -58.216  55.127  1
540655  91.621  -58.227  55.119  1
540656  91.664  -58.238  55.108  1
540657  91.708  -58.248  55.094  1
540658  91.749  -58.261  55.089  1
540659  91.780  -58.283  55.084  1
540660  91.810  -58.305  55.074  1
540661  91.841  -58.328  55.058  1
540662  91.869  -58.338  55.034  1
540663  91.898  -58.346  55.004  1
540664  91.936  -58.357  54.979  1
540665  91.973  -58.366  54.958  1
540666  92.011  -58.377  54.939  1
540667  92.048  -58.388  54.922  1
540668  92.085  -58.397  54.905  1
540669  92.125  -58.408  54.886  1
540670  92.167  -58.418  54.866  1
540671  92.210  -58.428  54.842  1
540672  92.252  -58.438  54.818  1
540673  92.293  -58.445  54.798  1
540674  92.332  -58.448  54.783  1
540675  92.370  -58.451  54.768  1
540676  92.409  -58.454  54.750  1
540677  92.448  -58.458  54.730  1
540678  92.487  -58.461  54.714  1
540679  92.520  -58.466  54.708  1
540680  92.550  -58.471  54.711  1
540681  92.580  -58.476  54.715  1
540682  92.609  -58.481  54.726  1
540683  92.639  -58.486  54.740  1
540684  92.668  -58.491  54.751  1
540685  92.698  -58.497  54.755  1
540686  92.732  -58.502  54.768  1
540687  92.778  -58.508  54.788  1
540688  92.823  -58.514  54.810  1
540689  92.869  -58.520  54.827  1
540690  92.914  -58.526  54.835  1
540691  92.960  -58.532  54.839  1
540692  93.003  -58.539  54.840  1
540693  93.041  -58.549  54.837  1
540694  93.079  -58.558  54.828  1
540695  93.117  -58.568  54.814  1
540696  93.155  -58.578  54.801  1
540697  93.193  -58.587  54.787  1
540698  93.231  -58.597  54.772  1
540699  93.269  -58.607  54.755  1
540700  93.307  -58.616  54.736  1
540701  93.345  -58.625  54.716  1
540702  93.383  -58.633  54.693  1
540703  93.422  -58.641  54.670  1
540704  93.461  -58.648  54.651  1
540705  93.500  -58.656  54.637  1
540706  93.539  -58.664  54.633  1
540707  93.575  -58.677  54.627  1
540708  93.611  -58.691  54.619  1
540709  93.647  -58.705  54.608  1
540710  93.684  -58.718  54.593  1
540711  93.720  -58.732  54.573  1
540712  93.756  -58.745  54.551  1
540713  93.792  -58.759  54.536  1
540714  93.829  -58.773  54.525  1
540715  93.865  -58.787  54.515  1
540716  93.902  -58.801  54.506  1
540717  93.938  -58.814  54.497  1
540718  93.974  -58.828  54.482  1
540719  94.010  -58.842  54.461  1
540720  94.047  -58.855  54.439  1
540721  94.083  -58.869  54.418  1
540722  94.119  -58.883  54.395  1
540723  94.155  -58.896  54.368  1
540724  94.192  -58.910  54.330  1
540725  94.228  -58.924  54.304  1
540726  94.264  -58.937  54.284  1
540727  94.300  -58.951  54.265  1
540728  94.337  -58.965  54.243  1
540729  94.372  -58.981  54.223  1
540730  94.408  -59.002  54.202  1
540731  94.442  -59.022  54.176  1
540732  94.478  -59.042  54.145  1
540733  94.512  -59.051  54.111  1
540734  94.548  -59.059  54.075  1
540735  94.586  -59.068  54.043  1
540736  94.625  -59.076  54.009  1
540737  94.664  -59.087  53.975  1
540738  94.703  -59.097  53.940  1
540739  94.742  -59.108  53.903  1
540740  94.781  -59.119  53.863  1
540741  94.821  -59.130  53.824  1
540742  94.861  -59.140  53.784  1
540743  94.902  -59.151  53.743  1
540744  94.943  -59.162  53.704  1
540745  94.984  -59.173  53.668  1
540746  95.025  -59.184  53.636  1
540747  95.065  -59.194  53.605  1
540748  95.105  -59.205  53.578  1
540749  95.142  -59.215  53.554  1
540750  95.179  -59.226  53.532  1
540751  95.215  -59.237  53.509  1
540752  95.253  -59.247  53.486  1
540753  95.287  -59.259  53.464  1
540754  95.319  -59.275  53.443  1
540755  95.352  -59.285  53.423  1
540756  95.386  -59.297  53.404  1
540757  95.418  -59.308  53.387  1
540758  95.452  -59.319  53.369  1
540759  95.485  -59.330  53.351  1
540760  95.518  -59.341  53.336  1
540761  95.551  -59.352  53.326  1
540762  95.584  -59.363  53.319  1
540763  95.617  -59.374  53.316  1
540764  95.650  -59.385  53.313  1
540765  95.680  -59.394  53.308  1
540766  95.709  -59.403  53.301  1
540767  95.738  -59.411  53.297  1
540768  95.770  -59.419  53.286  1
540769  95.801  -59.428  53.278  1
540770  95.832  -59.436  53.269  1
540771  95.865  -59.444  53.258  1
540772  95.900  -59.450  53.242  1
540773  95.935  -59.457  53.223  1
540774  95.970  -59.463  53.204  1
540775  96.006  -59.468  53.186  1
540776  96.041  -59.474  53.170  1
540777  96.076  -59.480  53.157  1
540778  96.111  -59.485  53.141  1
540779  96.146  -59.491  53.120  1
540780  96.179  -59.498  53.095  1
540781  96.213  -59.505  53.065  1
540782  96.246  -59.512  53.030  1
540783  96.282  -59.516  52.996  1
540784  96.317  -59.519  52.969  1
540785  96.352  -59.522  52.942  1
540786  96.388  -59.526  52.918  1
540787  96.423  -59.530  52.893  1
540788  96.458  -59.534  52.867  1
540789  96.494  -59.538  52.841  1
540790  96.529  -59.541  52.815  1
540791  96.565  -59.545  52.789  1
540792  96.595  -59.544  52.764  1
540793  96.624  -59.540  52.739  1
540794  96.653  -59.537  52.712  1
540795  96.682  -59.534  52.682  1
540796  96.712  -59.531  52.648  1
540797  96.743  -59.529  52.609  1
540798  96.775  -59.528  52.571  1
540799  96.807  -59.527  52.532  1
540800  96.840  -59.529  52.490  1
540801  96.875  -59.531  52.450  1
540802  96.908  -59.533  52.410  1
540803  96.942  -59.535  52.369  1
540804  96.976  -59.538  52.328  1
540805  97.010  -59.540  52.286  1
540806  97.043  -59.542  52.240  1
540807  97.077  -59.544  52.195  1
540808  97.111  -59.547  52.155  1
540809  97.145  -59.549  52.123  1
540810  97.178  -59.552  52.097  1
540811  97.215  -59.554  52.072  1
540812  97.251  -59.557  52.042  1
540813  97.288  -59.560  52.008  1
540814  97.322  -59.564  51.970  1
540815  97.355  -59.567  51.926  1
540816  97.388  -59.573  51.879  1
540817  97.428  -59.584  51.828  1
540818  97.467  -59.595  51.775  1
540819  97.507  -59.607  51.721  1
540820  97.547  -59.617  51.666  1
540821  97.587  -59.629  51.611  1
540822  97.627  -59.640  51.555  1
540823  97.666  -59.651  51.500  1
540824  97.706  -59.662  51.446  1
540825  97.746  -59.673  51.393  1
540826  97.786  -59.684  51.339  1
540827  97.825  -59.695  51.281  1
540828  97.865  -59.706  51.223  1
540829  97.905  -59.717  51.164  1
540830  97.945  -59.729  51.107  1
540831  97.985  -59.738  51.052  1
540832  98.027  -59.741  50.999  1
540833  98.069  -59.745  50.951  1
540834  98.111  -59.748  50.905  1
540835  98.153  -59.751  50.862  1
540836  98.182  -59.739  50.821  1
540837  98.212  -59.725  50.782  1
540838  98.239  -59.716  50.744  1
540839  98.261  -59.723  50.708  1
540840  98.282  -59.729  50.672  1
540841  98.303  -59.735  50.639  1
540842  98.325  -59.742  50.608  1
540843  98.374  -59.750  50.579  1
540844  98.423  -59.759  50.550  1
540845  98.462  -59.748  50.521  1
540846  98.500  -59.732  50.489  1
540847  98.538  -59.717  50.454  1
540848  98.576  -59.701  50.415  1
540849  98.615  -59.686  50.374  1
540850  98.660  -59.692  50.333  1
540851  98.707  -59.702  50.290  1
540852  98.754  -59.708  50.245  1
540853  98.796  -59.701  50.198  1
540854  98.830  -59.683  50.151  1
540855  98.863  -59.660  50.103  1
540856  98.896  -59.638  50.057  1
540857  98.938  -59.622  50.011  1
540858  98.986  -59.623  49.967  1
540859  99.014  -59.626  49.922  1
540860  99.043  -59.630  49.879  1
540861  99.072  -59.634  49.836  1
540862  99.100  -59.638  49.795  1
540863  99.129  -59.642  49.754  1
540864  99.158  -59.646  49.712  1
540865  99.187  -59.650  49.672  1
540866  99.215  -59.654  49.633  1
540867  99.244  -59.657  49.596  1
541292  89.123  -57.273  56.088  1
541293  89.147  -57.297  56.070  1
541294  89.172  -57.321  56.053  1
541295  89.196  -57.345  56.035  1
541296  89.232  -57.361  56.018  1
541297  89.273  -57.372  56.000  1
541298  89.314  -57.382  55.981  1
541299  89.356  -57.393  55.965  1
541300  89.397  -57.404  55.947  1
541301  89.439  -57.415  55.931  1
541302  89.480  -57.426  55.914  1
541303  89.522  -57.437  55.898  1
541304  89.563  -57.448  55.881  1
541305  89.604  -57.458  55.867  1
541306  89.646  -57.470  55.855  1
541307  89.687  -57.480  55.845  1
541308  89.736  -57.497  55.835  1
541309  89.785  -57.514  55.826  1
541310  89.834  -57.531  55.817  1
541311  89.883  -57.548  55.810  1
541312  89.928  -57.562  55.804  1
541313  89.964  -57.572  55.797  1
541314  90.001  -57.583  55.790  1
541315  90.037  -57.592  55.783  1
541316  90.073  -57.602  55.775  1
541317  90.110  -57.612  55.765  1
541318  90.146  -57.622  55.754  1
541319  90.182  -57.632  55.741  1
541320  90.219  -57.643  55.728  1
541321  90.253  -57.659  55.711  1
541322  90.288  -57.675  55.692  1
541323  90.322  -57.688  55.669  1
541324  90.355  -57.699  55.645  1
541325  90.389  -57.711  55.617  1
541326  90.422  -57.721  55.590  1
541327  90.456  -57.733  55.564  1
541328  90.489  -57.744  55.538  1
541329  90.523  -57.755  55.514  1
541330  90.558  -57.769  55.493  1
541331  90.596  -57.785  55.473  1
541332  90.633  -57.802  55.448  1
541333  90.673  -57.814  55.421  1
541334  90.718  -57.821  55.395  1
541335  90.763  -57.827  55.372  1
541336  90.808  -57.834  55.351  1
541337  90.853  -57.840  55.331  1
541338  90.898  -57.847  55.310  1
541339  90.943  -57.854  55.295  1
541340  90.988  -57.860  55.282  1
541341  91.033  -57.867  55.268  1
541342  91.074  -57.886  55.252  1
541343  91.113  -57.909  55.239  1
541344  91.153  -57.934  55.228  1
541345  91.192  -57.957  55.218  1
541346  91.232  -57.981  55.212  1
541347  91.272  -58.004  55.209  1
541348  91.311  -58.028  55.206  1
541349  91.351  -58.052  55.197  1
541350  91.390  -58.075  55.182  1
541351  91.430  -58.099  55.164  1
541352  91.470  -58.123  55.146  1
541353  91.509  -58.147  55.138  1
541354  91.550  -58.167  55.132  1
541355  91.594  -58.178  55.130  1
541356  91.638  -58.187  55.128  1
541357  91.681  -58.198  55.124  1
541358  91.725  -58.209  55.116  1
541359  91.769  -58.219  55.106  1
541360  91.800  -58.241  55.094  1
541361  91.831  -58.263  55.079  1
541362  91.861  -58.285  55.062  1
541363  91.892  -58.307  55.043  1
541364  91.920  -58.317  55.022  1
541365  91.953  -58.327  54.999  1
541366  91.990  -58.337  54.975  1
541367  92.028  -58.347  54.950  1
541368  92.065  -58.357  54.927  1
541369  92.102  -58.368  54.905  1
541370  92.145  -58.378  54.886  1
541371  92.187  -58.388  54.866  1
541372  92.229  -58.397  54.846  1
541373  92.272  -58.408  54.830  1
541374  92.313  -58.416  54.819  1
541375  92.352  -58.419  54.807  1
541376  92.391  -58.422  54.791  1
541377  92.430  -58.426  54.769  1
541378  92.469  -58.429  54.745  1
541379  92.506  -58.433  54.723  1
541380  92.535  -58.438  54.706  1
541381  92.565  -58.443  54.705  1
541382  92.595  -58.448  54.710  1
541383  92.624  -58.454  54.720  1
541384  92.654  -58.459  54.732  1
541385  92.684  -58.464  54.742  1
541386  92.713  -58.469  54.749  1
541387  92.742  -58.475  54.774  1
541388  92.788  -58.481  54.802  1
541389  92.834  -58.487  54.826  1
541390  92.879  -58.493  54.842  1
541391  92.925  -58.498  54.854  1
541392  92.971  -58.504  54.855  1
541393  93.011  -58.513  54.857  1
541394  93.049  -58.523  54.857  1
541395  93.087  -58.532  54.850  1
541396  93.125  -58.542  54.837  1
541397  93.163  -58.551  54.824  1
541398  93.201  -58.561  54.812  1
541399  93.239  -58.570  54.797  1
541400  93.277  -58.580  54.780  1
541401  93.315  -58.590  54.761  1
541402  93.353  -58.599  54.739  1
541403  93.392  -58.607  54.719  1
541404  93.430  -58.615  54.698  1
541405  93.469  -58.623  54.675  1
541406  93.507  -58.630  54.655  1
541407  93.546  -58.639  54.648  1
541408  93.582  -58.652  54.645  1
541409  93.619  -58.666  54.637  1
541410  93.655  -58.680  54.625  1
541411  93.691  -58.694  54.610  1
541412  93.727  -58.708  54.590  1
541413  93.764  -58.721  54.568  1
541414  93.800  -58.735  54.551  1
541415  93.836  -58.748  54.538  1
541416  93.872  -58.762  54.529  1
541417  93.909  -58.776  54.521  1
541418  93.945  -58.789  54.513  1
541419  93.982  -58.803  54.503  1
541420  94.018  -58.817  54.487  1
541421  94.054  -58.830  54.469  1
541422  94.090  -58.844  54.449  1
541423  94.127  -58.858  54.425  1
541424  94.163  -58.871  54.394  1
541425  94.199  -58.885  54.354  1
541426  94.236  -58.899  54.320  1
541427  94.272  -58.913  54.292  1
541428  94.308  -58.927  54.271  1
541429  94.344  -58.940  54.253  1
541430  94.381  -58.954  54.235  1
541431  94.417  -58.968  54.216  1
541432  94.452  -58.987  54.191  1
541433  94.487  -59.007  54.162  1
541434  94.523  -59.015  54.131  1
541435  94.561  -59.024  54.095  1
541436  94.600  -59.034  54.056  1
541437  94.639  -59.045  54.022  1
541438  94.678  -59.055  53.988  1
541439  94.717  -59.066  53.951  1
541440  94.756  -59.077  53.911  1
541441  94.795  -59.088  53.871  1
541442  94.834  -59.099  53.833  1
541443  94.873  -59.109  53.793  1
541444  94.913  -59.121  53.753  1
541445  94.954  -59.131  53.715  1
541446  94.995  -59.142  53.679  1
541447  95.036  -59.153  53.648  1
541448  95.076  -59.163  53.618  1
541449  95.117  -59.175  53.592  1
541450  95.155  -59.185  53.569  1
541451  95.192  -59.195  53.546  1
541452  95.229  -59.206  53.524  1
541453  95.265  -59.216  53.501  1
541454  95.298  -59.231  53.480  1
541455  95.330  -59.245  53.460  1
541456  95.363  -59.258  53.442  1
541457  95.396  -59.269  53.424  1
541458  95.429  -59.280  53.406  1
541459  95.462  -59.291  53.388  1
541460  95.495  -59.303  53.371  1
541461  95.528  -59.313  53.354  1
541462  95.561  -59.325  53.340  1
541463  95.594  -59.336  53.330  1
541464  95.627  -59.347  53.326  1
541465  95.657  -59.356  53.325  1
541466  95.686  -59.364  53.322  1
541467  95.714  -59.372  53.314  1
541468  95.743  -59.380  53.306  1
541469  95.772  -59.388  53.295  1
541470  95.804  -59.397  53.283  1
541471  95.835  -59.406  53.271  1
541472  95.871  -59.412  53.257  1
541473  95.906  -59.418  53.238  1
541474  95.941  -59.424  53.222  1
541475  95.976  -59.430  53.207  1
541476  96.012  -59.435  53.193  1
541477  96.047  -59.441  53.179  1
541478  96.082  -59.447  53.165  1
541479  96.117  -59.453  53.148  1
541480  96.152  -59.460  53.124  1
541481  96.185  -59.466  53.097  1
541482  96.218  -59.473  53.067  1
541483  96.251  -59.480  53.035  1
541484  96.285  -59.487  53.006  1
541485  96.320  -59.491  52.981  1
541486  96.355  -59.494  52.956  1
541487  96.390  -59.498  52.931  1
541488  96.426  -59.502  52.907  1
541489  96.461  -59.506  52.882  1
541490  96.497  -59.509  52.856  1
541491  96.532  -59.513  52.828  1
541492  96.566  -59.515  52.800  1
541493  96.595  -59.512  52.774  1
541494  96.624  -59.509  52.750  1
541495  96.653  -59.505  52.724  1
541496  96.682  -59.502  52.691  1
541497  96.711  -59.499  52.658  1
541498  96.740  -59.496  52.621  1
541499  96.771  -59.494  52.582  1
541500  96.804  -59.493  52.544  1
541501  96.837  -59.495  52.503  1
541502  96.871  -59.497  52.461  1
541503  96.905  -59.500  52.420  1
541504  96.939  -59.502  52.379  1
541505  96.972  -59.504  52.337  1
541506  97.006  -59.507  52.293  1
541507  97.040  -59.509  52.246  1
541508  97.077  -59.512  52.202  1
541509  97.113  -59.515  52.164  1
541510  97.150  -59.518  52.132  1
541511  97.186  -59.521  52.106  1
541512  97.223  -59.524  52.080  1
541513  97.259  -59.527  52.049  1
541514  97.294  -59.530  52.015  1
541515  97.326  -59.534  51.975  1
541516  97.358  -59.537  51.930  1
541517  97.390  -59.542  51.881  1
541518  97.424  -59.549  51.828  1
541519  97.464  -59.560  51.774  1
541520  97.504  -59.571  51.719  1
541521  97.543  -59.582  51.665  1
541522  97.583  -59.593  51.611  1
541523  97.623  -59.604  51.557  1
541524  97.663  -59.615  51.505  1
541525  97.703  -59.626  51.456  1
541526  97.743  -59.638  51.406  1
541527  97.783  -59.648  51.354  1
541528  97.822  -59.660  51.297  1
541529  97.862  -59.671  51.237  1
541530  97.902  -59.682  51.177  1
541531  97.942  -59.693  51.117  1
541532  97.983  -59.700  51.060  1
541533  98.024  -59.704  51.007  1
541534  98.067  -59.707  50.957  1
541535  98.108  -59.710  50.911  1
541536  98.150  -59.714  50.867  1
541537  98.182  -59.703  50.825  1
541538  98.211  -59.690  50.785  1
541539  98.240  -59.676  50.747  1
541540  98.263  -59.679  50.711  1
541541  98.285  -59.685  50.674  1
541542  98.306  -59.692  50.639  1
541543  98.331  -59.698  50.607  1
541544  98.379  -59.707  50.576  1
541545  98.428  -59.715  50.546  1
541546  98.471  -59.710  50.518  1
541547  98.509  -59.695  50.488  1
541548  98.547  -59.680  50.455  1
541549  98.585  -59.665  50.418  1
541550  98.623  -59.649  50.379  1
541551  98.659  -59.633  50.339  1
541552  98.704  -59.635  50.297  1
541553  98.751  -59.645  50.254  1
541554  98.798  -59.654  50.208  1
541555  98.836  -59.642  50.160  1
541556  98.868  -59.620  50.112  1
541557  98.902  -59.598  50.066  1
541558  98.946  -59.583  50.021  1
541559  98.984  -59.585  49.976  1
541560  99.013  -59.589  49.932  1
541561  99.042  -59.593  49.888  1
541562  99.070  -59.597  49.846  1
541563  99.099  -59.601  49.805  1
541564  99.128  -59.605  49.764  1
541565  99.156  -59.609  49.723  1
541566  99.185  -59.613  49.683  1
541567  99.214  -59.616  49.645  1
541568  99.242  -59.620  49.607  1
541569  99.271  -59.624  49.570  1
541995  89.191  -57.282  56.042  1
541996  89.215  -57.307  56.025  1
541997  89.251  -57.321  56.009  1
541998  89.293  -57.332  55.992  1
541999  89.334  -57.343  55.974  1
542000  89.375  -57.354  55.958  1
542001  89.417  -57.364  55.942  1
542002  89.458  -57.376  55.926  1
542003  89.499  -57.386  55.910  1
542004  89.541  -57.397  55.894  1
542005  89.582  -57.408  55.877  1
542006  89.624  -57.419  55.864  1
542007  89.665  -57.429  55.852  1
542008  89.706  -57.441  55.840  1
542009  89.749  -57.452  55.830  1
542010  89.798  -57.469  55.820  1
542011  89.847  -57.486  55.811  1
542012  89.896  -57.503  55.803  1
542013  89.943  -57.519  55.795  1
542014  89.980  -57.529  55.788  1
542015  90.016  -57.539  55.780  1
542016  90.052  -57.548  55.771  1
542017  90.089  -57.559  55.761  1
542018  90.125  -57.569  55.750  1
542019  90.162  -57.579  55.737  1
542020  90.198  -57.589  55.723  1
542021  90.233  -57.605  55.707  1
542022  90.267  -57.621  55.688  1
542023  90.302  -57.638  55.666  1
542024  90.335  -57.649  55.644  1
542025  90.369  -57.661  55.620  1
542026  90.402  -57.671  55.593  1
542027  90.436  -57.683  55.566  1
542028  90.469  -57.694  55.540  1
542029  90.503  -57.705  55.514  1
542030  90.538  -57.717  55.490  1
542031  90.575  -57.734  55.468  1
542032  90.612  -57.751  55.448  1
542033  90.650  -57.767  55.425  1
542034  90.687  -57.783  55.402  1
542035  90.732  -57.789  55.379  1
542036  90.778  -57.796  55.359  1
542037  90.822  -57.802  55.340  1
542038  90.867  -57.809  55.323  1
542039  90.912  -57.816  55.305  1
542040  90.957  -57.822  55.290  1
542041  91.002  -57.829  55.277  1
542042  91.047  -57.835  55.265  1
542043  91.088  -57.856  55.253  1
542044  91.127  -57.880  55.243  1
542045  91.167  -57.903  55.236  1
542046  91.207  -57.927  55.229  1
542047  91.246  -57.951  55.224  1
542048  91.286  -57.974  55.220  1
542049  91.325  -57.998  55.220  1
542050  91.365  -58.021  55.215  1
542051  91.404  -58.046  55.204  1
542052  91.444  -58.069  55.187  1
542053  91.484  -58.093  55.165  1
542054  91.523  -58.116  55.148  1
542055  91.567  -58.128  55.136  1
542056  91.610  -58.138  55.131  1
542057  91.654  -58.149  55.130  1
542058  91.698  -58.159  55.130  1
542059  91.742  -58.169  55.126  1
542060  91.786  -58.180  55.119  1
542061  91.820  -58.199  55.107  1
542062  91.851  -58.221  55.092  1
542063  91.882  -58.243  55.074  1
542064  91.912  -58.265  55.053  1
542065  91.943  -58.288  55.027  1
542066  91.970  -58.297  55.000  1
542067  92.007  -58.307  54.973  1
542068  92.044  -58.317  54.948  1
542069  92.082  -58.328  54.924  1
542070  92.122  -58.338  54.904  1
542071  92.164  -58.347  54.889  1
542072  92.207  -58.358  54.876  1
542073  92.249  -58.368  54.865  1
542074  92.292  -58.378  54.856  1
542075  92.334  -58.388  54.845  1
542076  92.373  -58.391  54.829  1
542077  92.412  -58.394  54.807  1
542078  92.450  -58.397  54.783  1
542079  92.489  -58.400  54.759  1
542080  92.521  -58.405  54.734  1
542081  92.551  -58.410  54.710  1
542082  92.580  -58.416  54.703  1
542083  92.610  -58.421  54.706  1
542084  92.639  -58.426  54.713  1
542085  92.669  -58.432  54.722  1
542086  92.699  -58.437  54.731  1
542087  92.728  -58.442  54.746  1
542088  92.758  -58.448  54.776  1
542089  92.799  -58.453  54.807  1
542090  92.845  -58.459  54.830  1
542091  92.890  -58.465  54.846  1
542092  92.936  -58.471  54.860  1
542093  92.981  -58.477  54.862  1
542094  93.019  -58.487  54.863  1
542095  93.057  -58.496  54.863  1
542096  93.095  -58.506  54.858  1
542097  93.133  -58.516  54.850  1
542098  93.171  -58.525  54.841  1
542099  93.209  -58.535  54.831  1
542100  93.247  -58.545  54.817  1
542101  93.285  -58.554  54.799  1
542102  93.323  -58.563  54.780  1
542103  93.361  -58.573  54.760  1
542104  93.399  -58.582  54.743  1
542105  93.438  -58.589  54.723  1
542106  93.477  -58.597  54.699  1
542107  93.515  -58.604  54.675  1
542108  93.554  -58.614  54.658  1
542109  93.590  -58.628  54.657  1
542110  93.626  -58.642  54.651  1
542111  93.662  -58.655  54.639  1
542112  93.699  -58.669  54.621  1
542113  93.735  -58.683  54.603  1
542114  93.771  -58.696  54.583  1
542115  93.807  -58.710  54.564  1
542116  93.844  -58.723  54.553  1
542117  93.880  -58.737  54.545  1
542118  93.916  -58.751  54.538  1
542119  93.953  -58.764  54.530  1
542120  93.989  -58.778  54.521  1
542121  94.026  -58.792  54.509  1
542122  94.062  -58.805  54.494  1
542123  94.098  -58.820  54.473  1
542124  94.134  -58.833  54.447  1
542125  94.171  -58.847  54.414  1
542126  94.207  -58.861  54.373  1
542127  94.243  -58.874  54.333  1
542128  94.279  -58.888  54.299  1
542129  94.316  -58.902  54.274  1
542130  94.352  -58.915  54.259  1
542131  94.388  -58.929  54.244  1
542132  94.424  -58.943  54.225  1
542133  94.461  -58.956  54.203  1
542134  94.497  -58.971  54.177  1
542135  94.536  -58.981  54.144  1
542136  94.574  -58.992  54.105  1
542137  94.614  -59.003  54.066  1
542138  94.653  -59.014  54.030  1
542139  94.692  -59.024  53.995  1
542140  94.731  -59.035  53.960  1
542141  94.770  -59.046  53.924  1
542142  94.809  -59.057  53.888  1
542143  94.848  -59.068  53.850  1
542144  94.887  -59.078  53.810  1
542145  94.926  -59.090  53.770  1
542146  94.965  -59.100  53.732  1
542147  95.006  -59.111  53.696  1
542148  95.047  -59.121  53.665  1
542149  95.088  -59.133  53.636  1
542150  95.128  -59.143  53.608  1
542151  95.168  -59.154  53.583  1
542152  95.204  -59.165  53.561  1
542153  95.241  -59.175  53.541  1
542154  95.277  -59.187  53.518  1
542155  95.309  -59.201  53.497  1
542156  95.341  -59.216  53.479  1
542157  95.373  -59.231  53.462  1
542158  95.406  -59.241  53.443  1
542159  95.440  -59.253  53.425  1
542160  95.472  -59.264  53.407  1
542161  95.506  -59.275  53.390  1
542162  95.539  -59.286  53.374  1
542163  95.572  -59.297  53.357  1
542164  95.605  -59.308  53.342  1
542165  95.634  -59.317  53.336  1
542166  95.663  -59.325  53.335  1
542167  95.692  -59.334  53.333  1
542168  95.720  -59.341  53.326  1
542169  95.749  -59.350  53.315  1
542170  95.777  -59.358  53.305  1
542171  95.807  -59.366  53.288  1
542172  95.841  -59.372  53.272  1
542173  95.877  -59.379  53.257  1
542174  95.912  -59.385  53.237  1
542175  95.947  -59.391  53.223  1
542176  95.982  -59.397  53.211  1
542177  96.018  -59.403  53.198  1
542178  96.053  -59.409  53.185  1
542179  96.088  -59.415  53.171  1
542180  96.123  -59.421  53.152  1
542181  96.157  -59.427  53.127  1
542182  96.190  -59.434  53.101  1
542183  96.224  -59.441  53.072  1
542184  96.257  -59.447  53.041  1
542185  96.290  -59.454  53.014  1
542186  96.323  -59.461  52.990  1
542187  96.358  -59.466  52.966  1
542188  96.393  -59.469  52.942  1
542189  96.429  -59.473  52.919  1
542190  96.464  -59.477  52.893  1
542191  96.500  -59.481  52.866  1
542192  96.535  -59.485  52.838  1
542193  96.566  -59.483  52.811  1
542194  96.595  -59.480  52.785  1
542195  96.624  -59.477  52.760  1
542196  96.653  -59.474  52.734  1
542197  96.682  -59.470  52.701  1
542198  96.711  -59.467  52.667  1
542199  96.740  -59.464  52.630  1
542200  96.769  -59.461  52.591  1
542201  96.800  -59.459  52.553  1
542202  96.834  -59.461  52.513  1
542203  96.868  -59.463  52.469  1
542204  96.902  -59.466  52.427  1
542205  96.939  -59.469  52.383  1
542206  96.975  -59.472  52.337  1
542207  97.012  -59.475  52.292  1
542208  97.048  -59.478  52.249  1
542209  97.085  -59.481  52.212  1
542210  97.121  -59.484  52.179  1
542211  97.158  -59.487  52.148  1
542212  97.194  -59.490  52.119  1
542213  97.231  -59.493  52.089  1
542214  97.264  -59.497  52.055  1
542215  97.297  -59.500  52.018  1
542216  97.329  -59.504  51.975  1
542217  97.361  -59.507  51.927  1
542218  97.393  -59.512  51.877  1
542219  97.425  -59.516  51.823  1
542220  97.461  -59.524  51.768  1
542221  97.501  -59.535  51.713  1
542222  97.540  -59.547  51.659  1
542223  97.580  -59.557  51.607  1
542224  97.620  -59.569  51.556  1
542225  97.660  -59.580  51.509  1
542226  97.700  -59.591  51.464  1
542227  97.739  -59.602  51.417  1
542228  97.779  -59.613  51.366  1
542229  97.819  -59.624  51.309  1
542230  97.859  -59.635  51.248  1
542231  97.898  -59.646  51.188  1
542232  97.938  -59.657  51.127  1
542233  97.980  -59.663  51.068  1
542234  98.022  -59.666  51.015  1
542235  98.064  -59.669  50.965  1
542236  98.106  -59.673  50.918  1
542237  98.148  -59.676  50.873  1
542238  98.181  -59.668  50.830  1
542239  98.211  -59.654  50.789  1
542240  98.239  -59.641  50.750  1
542241  98.266  -59.635  50.712  1
542242  98.287  -59.641  50.676  1
542243  98.309  -59.648  50.640  1
542244  98.336  -59.654  50.606  1
542245  98.385  -59.663  50.573  1
542246  98.433  -59.672  50.542  1
542247  98.474  -59.669  50.513  1
542248  98.511  -59.653  50.484  1
542249  98.548  -59.636  50.453  1
542250  98.585  -59.620  50.419  1
542251  98.622  -59.604  50.382  1
542252  98.660  -59.590  50.342  1
542253  98.703  -59.585  50.302  1
542254  98.745  -59.579  50.260  1
542255  98.791  -59.584  50.214  1
542256  98.838  -59.594  50.167  1
542257  98.874  -59.579  50.120  1
542258  98.907  -59.557  50.076  1
542259  98.954  -59.544  50.030  1
542260  98.983  -59.548  49.985  1
542261  99.011  -59.552  49.941  1
542262  99.040  -59.556  49.898  1
542263  99.069  -59.560  49.856  1
542264  99.097  -59.563  49.814  1
542265  99.126  -59.568  49.774  1
542266  99.155  -59.572  49.734  1
542267  99.184  -59.576  49.695  1
542268  99.212  -59.579  49.656  1
542269  99.241  -59.583  49.618  1
542270  99.270  -59.587  49.582  1
542625  86.443  -56.295  57.556  4
542626  86.484  -56.309  57.538  4
542627  86.524  -56.323  57.516  4
542628  86.564  -56.335  57.491  4
542629  86.605  -56.349  57.466  4
542630  86.645  -56.362  57.438  4
542631  86.686  -56.376  57.411  4
542632  86.726  -56.389  57.382  4
542633  86.766  -56.402  57.351  4
542634  86.807  -56.416  57.317  4
542635  86.847  -56.429  57.283  4
542636  86.887  -56.442  57.249  4
542637  86.928  -56.456  57.216  4
542638  86.969  -56.469  57.183  4
542698  89.270  -57.282  56.000  1
542699  89.312  -57.292  55.983  1
542700  89.353  -57.304  55.966  1
542701  89.395  -57.314  55.951  1
542702  89.436  -57.325  55.936  1
542703  89.477  -57.335  55.920  1
542704  89.519  -57.347  55.905  1
542705  89.560  -57.357  55.891  1
542706  89.602  -57.368  55.875  1
542707  89.643  -57.379  55.861  1
542708  89.685  -57.390  55.848  1
542709  89.726  -57.401  55.836  1
542710  89.767  -57.411  55.825  1
542711  89.811  -57.424  55.815  1
542712  89.860  -57.441  55.806  1
542713  89.909  -57.458  55.796  1
542714  89.958  -57.475  55.788  1
542715  89.996  -57.485  55.779  1
542716  90.032  -57.495  55.770  1
542717  90.068  -57.505  55.759  1
542718  90.105  -57.515  55.747  1
542719  90.141  -57.525  55.734  1
542720  90.177  -57.536  55.720  1
542721  90.212  -57.551  55.704  1
542722  90.247  -57.567  55.687  1
542723  90.281  -57.584  55.667  1
542724  90.316  -57.599  55.645  1
542725  90.349  -57.611  55.621  1
542726  90.383  -57.621  55.598  1
542727  90.416  -57.633  55.572  1
542728  90.450  -57.644  55.545  1
542729  90.483  -57.655  55.519  1
542730  90.517  -57.667  55.493  1
542731  90.554  -57.683  55.469  1
542732  90.592  -57.699  55.446  1
542733  90.629  -57.716  55.426  1
542734  90.667  -57.732  55.405  1
542735  90.705  -57.749  55.384  1
542736  90.747  -57.758  55.365  1
542737  90.792  -57.764  55.346  1
542738  90.836  -57.771  55.330  1
542739  90.882  -57.778  55.317  1
542740  90.927  -57.784  55.302  1
542741  90.971  -57.791  55.288  1
542742  91.017  -57.797  55.276  1
542743  91.062  -57.804  55.268  1
542744  91.101  -57.826  55.263  1
542745  91.141  -57.849  55.260  1
542746  91.181  -57.874  55.258  1
542747  91.220  -57.897  55.255  1
542748  91.260  -57.921  55.250  1
542749  91.300  -57.944  55.242  1
542750  91.339  -57.968  55.233  1
542751  91.379  -57.992  55.226  1
542752  91.419  -58.015  55.219  1
542753  91.458  -58.039  55.209  1
542754  91.498  -58.063  55.194  1
542755  91.540  -58.078  55.174  1
542756  91.584  -58.088  55.153  1
542757  91.628  -58.099  55.135  1
542758  91.671  -58.109  55.126  1
542759  91.715  -58.120  55.127  1
542760  91.759  -58.131  55.128  1
542761  91.803  -58.141  55.128  1
542762  91.841  -58.156  55.120  1
542763  91.871  -58.178  55.105  1
542764  91.902  -58.201  55.085  1
542765  91.933  -58.223  55.062  1
542766  91.963  -58.245  55.033  1
542767  91.994  -58.267  55.005  1
542768  92.024  -58.277  54.978  1
542769  92.062  -58.288  54.952  1
542770  92.100  -58.297  54.927  1
542771  92.142  -58.308  54.905  1
542772  92.184  -58.318  54.888  1
542773  92.227  -58.328  54.876  1
542774  92.269  -58.338  54.866  1
542775  92.311  -58.348  54.858  1
542776  92.354  -58.358  54.848  1
542777  92.393  -58.363  54.834  1
542778  92.432  -58.366  54.814  1
542779  92.471  -58.369  54.792  1
542780  92.507  -58.372  54.767  1
542781  92.536  -58.378  54.744  1
542782  92.566  -58.383  54.727  1
542783  92.595  -58.388  54.710  1
542784  92.625  -58.394  54.702  1
542785  92.654  -58.399  54.704  1
542786  92.684  -58.404  54.712  1
542787  92.714  -58.410  54.719  1
542788  92.743  -58.415  54.744  1
542789  92.773  -58.420  54.774  1
542790  92.810  -58.426  54.802  1
542791  92.855  -58.432  54.824  1
542792  92.901  -58.438  54.841  1
542793  92.946  -58.444  54.857  1
542794  92.989  -58.451  54.860  1
542795  93.027  -58.460  54.861  1
542796  93.065  -58.470  54.860  1
542797  93.103  -58.479  54.856  1
542798  93.141  -58.489  54.853  1
542799  93.179  -58.499  54.848  1
542800  93.217  -58.508  54.841  1
542801  93.255  -58.518  54.828  1
542802  93.293  -58.528  54.811  1
542803  93.331  -58.537  54.792  1
542804  93.369  -58.547  54.772  1
542805  93.407  -58.556  54.757  1
542806  93.446  -58.563  54.739  1
542807  93.485  -58.571  54.717  1
542808  93.523  -58.579  54.691  1
542809  93.561  -58.589  54.668  1
542810  93.597  -58.603  54.666  1
542811  93.634  -58.617  54.661  1
542812  93.670  -58.630  54.649  1
542813  93.706  -58.644  54.631  1
542814  93.743  -58.657  54.609  1
542815  93.779  -58.671  54.585  1
542816  93.815  -58.685  54.569  1
542817  93.851  -58.698  54.563  1
542818  93.888  -58.712  54.561  1
542819  93.924  -58.726  54.556  1
542820  93.960  -58.740  54.550  1
542821  93.996  -58.754  54.540  1
542822  94.033  -58.767  54.526  1
542823  94.069  -58.781  54.510  1
542824  94.106  -58.795  54.490  1
542825  94.142  -58.808  54.461  1
542826  94.178  -58.822  54.427  1
542827  94.214  -58.836  54.387  1
542828  94.251  -58.849  54.344  1
542829  94.287  -58.863  54.305  1
542830  94.323  -58.877  54.276  1
542831  94.359  -58.890  54.263  1
542832  94.396  -58.904  54.250  1
542833  94.431  -58.916  54.232  1
542834  94.465  -58.927  54.212  1
542835  94.498  -58.940  54.186  1
542836  94.540  -58.950  54.153  1
542837  94.582  -58.961  54.113  1
542838  94.625  -58.972  54.076  1
542839  94.667  -58.983  54.039  1
542840  94.706  -58.993  54.006  1
542841  94.745  -59.005  53.975  1
542842  94.784  -59.015  53.942  1
542843  94.823  -59.026  53.906  1
542844  94.862  -59.037  53.868  1
542845  94.901  -59.048  53.828  1
542846  94.940  -59.059  53.788  1
542847  94.979  -59.069  53.750  1
542848  95.018  -59.080  53.715  1
542849  95.058  -59.090  53.684  1
542850  95.099  -59.102  53.655  1
542851  95.139  -59.112  53.627  1
542852  95.180  -59.123  53.603  1
542853  95.217  -59.134  53.580  1
542854  95.254  -59.144  53.560  1
542855  95.288  -59.157  53.537  1
542856  95.320  -59.172  53.515  1
542857  95.352  -59.187  53.496  1
542858  95.384  -59.202  53.479  1
542859  95.417  -59.214  53.462  1
542860  95.450  -59.225  53.445  1
542861  95.483  -59.236  53.427  1
542862  95.516  -59.247  53.411  1
542863  95.549  -59.259  53.396  1
542864  95.582  -59.269  53.381  1
542865  95.612  -59.278  53.366  1
542866  95.640  -59.287  53.354  1
542867  95.669  -59.295  53.344  1
542868  95.697  -59.303  53.338  1
542869  95.726  -59.311  53.336  1
542870  95.754  -59.319  53.324  1
542871  95.783  -59.327  53.312  1
542872  95.812  -59.334  53.292  1
542873  95.847  -59.340  53.273  1
542874  95.883  -59.346  53.259  1
542875  95.918  -59.352  53.239  1
542876  95.954  -59.358  53.226  1
542877  95.989  -59.365  53.214  1
542878  96.024  -59.371  53.203  1
542879  96.059  -59.376  53.190  1
542880  96.095  -59.382  53.174  1
542881  96.129  -59.388  53.153  1
542882  96.163  -59.395  53.129  1
542883  96.196  -59.402  53.105  1
542884  96.229  -59.409  53.078  1
542885  96.262  -59.416  53.048  1
542886  96.295  -59.422  53.021  1
542887  96.328  -59.429  52.996  1
542888  96.362  -59.436  52.974  1
542889  96.396  -59.441  52.952  1
542890  96.431  -59.444  52.929  1
542891  96.467  -59.448  52.904  1
542892  96.502  -59.452  52.875  1
542893  96.536  -59.455  52.847  1
542894  96.566  -59.451  52.822  1
542895  96.595  -59.448  52.796  1
542896  96.623  -59.445  52.769  1
542897  96.653  -59.442  52.742  1
542898  96.682  -59.439  52.708  1
542899  96.711  -59.435  52.674  1
542900  96.740  -59.432  52.637  1
542901  96.769  -59.429  52.597  1
542902  96.800  -59.427  52.557  1
542903  96.836  -59.429  52.516  1
542904  96.873  -59.432  52.471  1
542905  96.910  -59.435  52.426  1
542906  96.947  -59.438  52.381  1
542907  96.983  -59.441  52.338  1
542908  97.020  -59.444  52.298  1
542909  97.056  -59.447  52.261  1
542910  97.093  -59.450  52.227  1
542911  97.130  -59.453  52.194  1
542912  97.166  -59.457  52.162  1
542913  97.203  -59.460  52.130  1
542914  97.236  -59.463  52.095  1
542915  97.268  -59.466  52.057  1
542916  97.300  -59.469  52.015  1
542917  97.332  -59.473  51.969  1
542918  97.365  -59.477  51.920  1
542919  97.396  -59.482  51.870  1
542920  97.428  -59.486  51.817  1
542921  97.460  -59.491  51.762  1
542922  97.497  -59.500  51.706  1
542923  97.537  -59.511  51.652  1
542924  97.577  -59.522  51.602  1
542925  97.617  -59.533  51.556  1
542926  97.657  -59.544  51.512  1
542927  97.697  -59.555  51.467  1
542928  97.736  -59.566  51.420  1
542929  97.776  -59.578  51.368  1
542930  97.816  -59.588  51.311  1
542931  97.856  -59.600  51.251  1
542932  97.895  -59.611  51.191  1
542933  97.935  -59.621  51.132  1
542934  97.978  -59.625  51.078  1
542935  98.019  -59.628  51.026  1
542936  98.061  -59.632  50.977  1
542937  98.103  -59.635  50.928  1
542938  98.145  -59.638  50.882  1
542939  98.181  -59.633  50.837  1
542940  98.210  -59.620  50.794  1
542941  98.239  -59.606  50.754  1
542942  98.268  -59.592  50.715  1
542943  98.290  -59.597  50.679  1
542944  98.312  -59.604  50.642  1
542945  98.342  -59.610  50.607  1
542946  98.390  -59.620  50.573  1
542947  98.436  -59.626  50.541  1
542948  98.473  -59.623  50.509  1
542949  98.510  -59.607  50.478  1
542950  98.547  -59.591  50.447  1
542951  98.584  -59.575  50.413  1
542952  98.621  -59.559  50.377  1
542953  98.661  -59.547  50.339  1
542954  98.704  -59.542  50.300  1
542955  98.746  -59.536  50.259  1
542956  98.789  -59.530  50.215  1
542957  98.831  -59.525  50.171  1
542958  98.878  -59.533  50.129  1
542959  98.913  -59.516  50.087  1
542960  98.952  -59.507  50.040  1
542961  98.981  -59.511  49.994  1
542962  99.010  -59.515  49.950  1
542963  99.039  -59.519  49.906  1
542964  99.067  -59.522  49.865  1
542965  99.096  -59.526  49.824  1
542966  99.125  -59.531  49.784  1
542967  99.153  -59.535  49.745  1
542968  99.182  -59.538  49.706  1
542969  99.211  -59.542  49.668  1
542970  99.239  -59.546  49.631  1
542971  99.278  -59.547  49.594  1
542972  99.350  -59.542  49.558  1
543323  86.339  -56.212  57.610  4
543324  86.379  -56.226  57.596  4
543325  86.420  -56.239  57.581  4
543326  86.460  -56.252  57.565  4
543327  86.500  -56.266  57.547  4
543328  86.541  -56.279  57.526  4
543329  86.581  -56.292  57.503  4
543330  86.622  -56.306  57.477  4
543331  86.662  -56.319  57.451  4
543332  86.702  -56.332  57.424  4
543333  86.743  -56.345  57.395  4
543334  86.783  -56.359  57.364  4
543335  86.824  -56.373  57.329  4
543336  86.864  -56.385  57.295  4
543337  86.905  -56.399  57.261  4
543338  86.945  -56.412  57.227  4
543339  86.985  -56.426  57.194  4
543340  87.025  -56.439  57.160  4
543402  89.414  -57.275  55.945  1
543403  89.456  -57.285  55.931  1
543404  89.497  -57.296  55.916  1
543405  89.538  -57.307  55.902  1
543406  89.580  -57.318  55.887  1
543407  89.621  -57.329  55.871  1
543408  89.663  -57.339  55.858  1
543409  89.704  -57.351  55.845  1
543410  89.745  -57.361  55.834  1
543411  89.787  -57.372  55.822  1
543412  89.828  -57.382  55.811  1
543413  89.873  -57.396  55.801  1
543414  89.922  -57.413  55.791  1
543415  89.971  -57.430  55.781  1
543416  90.011  -57.442  55.770  1
543417  90.047  -57.452  55.759  1
543418  90.084  -57.462  55.747  1
543419  90.120  -57.472  55.734  1
543420  90.157  -57.482  55.719  1
543421  90.191  -57.498  55.703  1
543422  90.226  -57.514  55.687  1
543423  90.261  -57.529  55.669  1
543424  90.295  -57.546  55.648  1
543425  90.329  -57.561  55.625  1
543426  90.363  -57.571  55.601  1
543427  90.396  -57.583  55.577  1
543428  90.430  -57.594  55.552  1
543429  90.463  -57.605  55.526  1
543430  90.497  -57.616  55.501  1
543431  90.534  -57.632  55.476  1
543432  90.572  -57.648  55.451  1
543433  90.609  -57.664  55.429  1
543434  90.647  -57.681  55.409  1
543435  90.684  -57.697  55.389  1
543436  90.721  -57.714  55.370  1
543437  90.761  -57.727  55.352  1
543438  90.806  -57.733  55.335  1
543439  90.851  -57.740  55.323  1
543440  90.896  -57.746  55.314  1
543441  90.941  -57.753  55.301  1
543442  90.986  -57.759  55.288  1
543443  91.031  -57.766  55.278  1
543444  91.076  -57.772  55.273  1
543445  91.115  -57.796  55.275  1
543446  91.155  -57.820  55.277  1
543447  91.194  -57.843  55.277  1
543448  91.234  -57.867  55.276  1
543449  91.274  -57.891  55.272  1
543450  91.313  -57.915  55.263  1
543451  91.353  -57.938  55.249  1
543452  91.393  -57.962  55.240  1
543453  91.432  -57.986  55.236  1
543454  91.472  -58.009  55.232  1
543455  91.513  -58.028  55.220  1
543456  91.557  -58.039  55.201  1
543457  91.600  -58.050  55.178  1
543458  91.644  -58.060  55.155  1
543459  91.688  -58.070  55.135  1
543460  91.732  -58.081  55.128  1
543461  91.776  -58.091  55.134  1
543462  91.819  -58.102  55.134  1
543463  91.861  -58.115  55.126  1
543464  91.891  -58.137  55.109  1
543465  91.922  -58.159  55.088  1
543466  91.953  -58.181  55.066  1
543467  91.984  -58.203  55.044  1
543468  92.014  -58.225  55.020  1
543469  92.044  -58.247  54.991  1
543470  92.079  -58.257  54.961  1
543471  92.120  -58.268  54.934  1
543472  92.162  -58.278  54.908  1
543473  92.204  -58.288  54.886  1
543474  92.247  -58.297  54.870  1
543475  92.289  -58.308  54.859  1
543476  92.332  -58.318  54.849  1
543477  92.374  -58.328  54.840  1
543478  92.414  -58.334  54.827  1
543479  92.453  -58.337  54.812  1
543480  92.492  -58.340  54.792  1
543481  92.522  -58.345  54.771  1
543482  92.552  -58.350  54.749  1
543483  92.581  -58.356  54.735  1
543484  92.611  -58.361  54.717  1
543485  92.640  -58.366  54.703  1
543486  92.670  -58.372  54.696  1
543487  92.699  -58.377  54.698  1
543488  92.729  -58.382  54.704  1
543489  92.759  -58.388  54.725  1
543490  92.788  -58.393  54.749  1
543491  92.820  -58.398  54.774  1
543492  92.866  -58.404  54.798  1
543493  92.912  -58.410  54.820  1
543494  92.957  -58.416  54.837  1
543495  92.997  -58.425  54.844  1
543496  93.036  -58.434  54.847  1
543497  93.073  -58.444  54.845  1
543498  93.111  -58.454  54.842  1
543499  93.149  -58.463  54.843  1
543500  93.187  -58.473  54.844  1
543501  93.225  -58.482  54.840  1
543502  93.263  -58.491  54.831  1
543503  93.301  -58.501  54.816  1
543504  93.339  -58.511  54.797  1
543505  93.377  -58.520  54.776  1
543506  93.415  -58.530  54.762  1
543507  93.454  -58.538  54.746  1
543508  93.492  -58.545  54.726  1
543509  93.531  -58.553  54.700  1
543510  93.568  -58.564  54.675  1
543511  93.605  -58.578  54.671  1
543512  93.641  -58.592  54.666  1
543513  93.677  -58.605  54.655  1
543514  93.714  -58.619  54.637  1
543515  93.750  -58.633  54.614  1
543516  93.786  -58.647  54.588  1
543517  93.823  -58.661  54.571  1
543518  93.859  -58.674  54.565  1
543519  93.895  -58.688  54.563  1
543520  93.931  -58.701  54.561  1
543521  93.968  -58.715  54.558  1
543522  94.004  -58.729  54.550  1
543523  94.040  -58.742  54.536  1
543524  94.076  -58.756  54.518  1
543525  94.113  -58.770  54.495  1
543526  94.149  -58.783  54.464  1
543527  94.186  -58.797  54.428  1
543528  94.222  -58.811  54.388  1
543529  94.258  -58.824  54.348  1
543530  94.294  -58.838  54.310  1
543531  94.330  -58.851  54.280  1
543532  94.364  -58.861  54.262  1
543533  94.398  -58.873  54.251  1
543534  94.432  -58.884  54.236  1
543535  94.467  -58.896  54.215  1
543536  94.499  -58.908  54.187  1
543537  94.536  -58.920  54.156  1
543538  94.578  -58.930  54.121  1
543539  94.621  -58.941  54.087  1
543540  94.664  -58.952  54.053  1
543541  94.706  -58.963  54.022  1
543542  94.749  -58.974  53.995  1
543543  94.791  -58.984  53.962  1
543544  94.834  -58.995  53.926  1
543545  94.876  -59.005  53.886  1
543546  94.915  -59.017  53.846  1
543547  94.954  -59.027  53.807  1
543548  94.993  -59.038  53.769  1
543549  95.032  -59.049  53.734  1
543550  95.071  -59.060  53.703  1
543551  95.110  -59.071  53.674  1
543552  95.150  -59.081  53.647  1
543553  95.191  -59.092  53.623  1
543554  95.230  -59.102  53.600  1
543555  95.267  -59.113  53.578  1
543556  95.299  -59.128  53.556  1
543557  95.331  -59.143  53.534  1
543558  95.363  -59.158  53.515  1
543559  95.395  -59.172  53.498  1
543560  95.427  -59.187  53.481  1
543561  95.460  -59.198  53.466  1
543562  95.493  -59.209  53.450  1
543563  95.527  -59.220  53.434  1
543564  95.559  -59.231  53.419  1
543565  95.589  -59.240  53.405  1
543566  95.617  -59.248  53.387  1
543567  95.646  -59.256  53.371  1
543568  95.675  -59.264  53.356  1
543569  95.703  -59.272  53.343  1
543570  95.732  -59.280  53.334  1
543571  95.760  -59.287  53.323  1
543572  95.789  -59.295  53.310  1
543573  95.818  -59.302  53.289  1
543574  95.853  -59.308  53.270  1
543575  95.889  -59.314  53.255  1
543576  95.924  -59.320  53.237  1
543577  95.960  -59.325  53.226  1
543578  95.995  -59.331  53.215  1
543579  96.030  -59.338  53.204  1
543580  96.065  -59.344  53.190  1
543581  96.101  -59.350  53.173  1
543582  96.135  -59.356  53.152  1
543583  96.168  -59.363  53.131  1
543584  96.201  -59.369  53.107  1
543585  96.234  -59.376  53.080  1
543586  96.267  -59.383  53.052  1
543587  96.301  -59.390  53.025  1
543588  96.334  -59.397  53.000  1
543589  96.367  -59.403  52.977  1
543590  96.400  -59.410  52.958  1
543591  96.434  -59.416  52.937  1
543592  96.469  -59.420  52.912  1
543593  96.505  -59.424  52.885  1
543594  96.536  -59.423  52.857  1
543595  96.566  -59.420  52.832  1
543596  96.594  -59.416  52.806  1
543597  96.623  -59.413  52.777  1
543598  96.652  -59.410  52.749  1
543599  96.682  -59.407  52.714  1
543600  96.713  -59.405  52.677  1
543601  96.743  -59.403  52.640  1
543602  96.773  -59.400  52.600  1
543603  96.805  -59.398  52.556  1
543604  96.839  -59.400  52.512  1
543605  96.876  -59.403  52.467  1
543606  96.913  -59.406  52.420  1
543607  96.950  -59.409  52.377  1
543608  96.987  -59.411  52.341  1
543609  97.025  -59.414  52.309  1
543610  97.062  -59.417  52.276  1
543611  97.099  -59.420  52.242  1
543612  97.136  -59.423  52.208  1
543613  97.173  -59.425  52.173  1
543614  97.207  -59.429  52.136  1
543615  97.239  -59.432  52.098  1
543616  97.271  -59.436  52.055  1
543617  97.303  -59.440  52.009  1
543618  97.336  -59.443  51.961  1
543619  97.368  -59.447  51.911  1
543620  97.400  -59.451  51.860  1
543621  97.432  -59.456  51.808  1
543622  97.463  -59.460  51.755  1
543623  97.495  -59.465  51.699  1
543624  97.534  -59.475  51.645  1
543625  97.574  -59.487  51.595  1
543626  97.613  -59.497  51.550  1
543627  97.653  -59.509  51.507  1
543628  97.693  -59.520  51.463  1
543629  97.733  -59.531  51.416  1
543630  97.773  -59.542  51.364  1
543631  97.812  -59.554  51.308  1
543632  97.852  -59.564  51.249  1
543633  97.892  -59.576  51.191  1
543634  97.933  -59.584  51.136  1
543635  97.974  -59.587  51.085  1
543636  98.017  -59.590  51.037  1
543637  98.059  -59.594  50.989  1
543638  98.100  -59.597  50.939  1
543639  98.143  -59.601  50.891  1
543640  98.180  -59.598  50.845  1
543641  98.209  -59.585  50.801  1
543642  98.238  -59.571  50.759  1
543643  98.268  -59.557  50.720  1
543644  98.293  -59.553  50.682  1
543645  98.314  -59.560  50.645  1
543646  98.347  -59.567  50.609  1
543647  98.395  -59.576  50.574  1
543648  98.435  -59.576  50.540  1
543649  98.473  -59.573  50.505  1
543650  98.510  -59.562  50.473  1
543651  98.547  -59.546  50.441  1
543652  98.584  -59.529  50.407  1
543653  98.621  -59.513  50.371  1
543654  98.662  -59.505  50.335  1
543655  98.705  -59.500  50.298  1
543656  98.747  -59.494  50.259  1
543657  98.790  -59.488  50.218  1
543658  98.832  -59.482  50.177  1
543659  98.875  -59.476  50.137  1
543660  98.918  -59.472  50.096  1
543661  98.950  -59.470  50.050  1
543662  98.980  -59.474  50.003  1
543663  99.008  -59.478  49.958  1
543664  99.037  -59.482  49.915  1
543665  99.066  -59.485  49.874  1
543666  99.094  -59.489  49.833  1
543667  99.123  -59.494  49.794  1
543668  99.152  -59.497  49.755  1
543669  99.181  -59.501  49.716  1
543670  99.209  -59.505  49.678  1
543671  99.238  -59.509  49.642  1
543672  99.286  -59.509  49.606  1
543673  99.358  -59.503  49.570  1
544022  86.275  -56.142  57.640  4
544023  86.315  -56.156  57.630  4
544024  86.356  -56.169  57.617  4
544025  86.396  -56.182  57.604  4
544026  86.436  -56.195  57.589  4
544027  86.477  -56.209  57.574  4
544028  86.517  -56.222  57.556  4
544029  86.558  -56.235  57.536  4
544030  86.598  -56.249  57.514  4
544031  86.638  -56.262  57.490  4
544032  86.679  -56.276  57.464  4
544033  86.719  -56.289  57.437  4
544034  86.760  -56.302  57.409  4
544035  86.800  -56.316  57.378  4
544036  86.841  -56.329  57.344  4
544037  86.881  -56.342  57.310  4
544038  86.921  -56.356  57.275  4
544039  86.962  -56.369  57.241  4
544040  87.002  -56.382  57.206  4
544041  87.043  -56.395  57.171  4
544042  87.083  -56.409  57.136  4
544107  89.599  -57.278  55.884  1
544108  89.640  -57.289  55.869  1
544109  89.682  -57.300  55.855  1
544110  89.724  -57.310  55.843  1
544111  89.765  -57.322  55.832  1
544112  89.806  -57.332  55.820  1
544113  89.848  -57.343  55.808  1
544114  89.889  -57.354  55.796  1
544115  89.935  -57.368  55.785  1
544116  89.984  -57.385  55.775  1
544117  90.027  -57.398  55.763  1
544118  90.063  -57.409  55.751  1
544119  90.099  -57.419  55.737  1
544120  90.136  -57.429  55.722  1
544121  90.171  -57.444  55.705  1
544122  90.205  -57.460  55.688  1
544123  90.240  -57.476  55.671  1
544124  90.274  -57.492  55.651  1
544125  90.309  -57.508  55.630  1
544126  90.343  -57.521  55.607  1
544127  90.377  -57.532  55.583  1
544128  90.410  -57.543  55.559  1
544129  90.444  -57.554  55.534  1
544130  90.477  -57.566  55.508  1
544131  90.514  -57.581  55.484  1
544132  90.551  -57.597  55.459  1
544133  90.589  -57.614  55.435  1
544134  90.626  -57.630  55.414  1
544135  90.663  -57.646  55.395  1
544136  90.701  -57.663  55.375  1
544137  90.738  -57.679  55.357  1
544138  90.776  -57.695  55.341  1
544139  90.820  -57.702  55.324  1
544140  90.866  -57.708  55.312  1
544141  90.910  -57.715  55.304  1
544142  90.955  -57.721  55.296  1
544143  91.000  -57.728  55.288  1
544144  91.045  -57.735  55.282  1
544145  91.090  -57.742  55.279  1
544146  91.130  -57.766  55.281  1
544147  91.169  -57.789  55.284  1
544148  91.209  -57.814  55.287  1
544149  91.248  -57.837  55.288  1
544150  91.288  -57.861  55.286  1
544151  91.327  -57.884  55.280  1
544152  91.367  -57.909  55.266  1
544153  91.406  -57.932  55.257  1
544154  91.446  -57.955  55.253  1
544155  91.486  -57.979  55.250  1
544156  91.530  -57.989  55.240  1
544157  91.574  -57.999  55.222  1
544158  91.617  -58.010  55.200  1
544159  91.661  -58.021  55.175  1
544160  91.705  -58.031  55.152  1
544161  91.749  -58.042  55.139  1
544162  91.793  -58.052  55.136  1
544163  91.837  -58.062  55.133  1
544164  91.880  -58.073  55.126  1
544165  91.912  -58.094  55.113  1
544166  91.942  -58.116  55.093  1
544167  91.973  -58.139  55.070  1
544168  92.004  -58.161  55.048  1
544169  92.034  -58.183  55.024  1
544170  92.065  -58.205  54.997  1
544171  92.097  -58.226  54.969  1
544172  92.140  -58.238  54.937  1
544173  92.182  -58.247  54.906  1
544174  92.224  -58.258  54.880  1
544175  92.267  -58.268  54.860  1
544176  92.309  -58.278  54.844  1
544177  92.351  -58.288  54.831  1
544178  92.394  -58.298  54.820  1
544179  92.435  -58.305  54.809  1
544180  92.474  -58.308  54.797  1
544181  92.507  -58.313  54.785  1
544182  92.537  -58.318  54.770  1
544183  92.567  -58.323  54.752  1
544184  92.596  -58.328  54.736  1
544185  92.626  -58.334  54.721  1
544186  92.655  -58.339  54.704  1
544187  92.685  -58.344  54.691  1
544188  92.714  -58.350  54.688  1
544189  92.744  -58.355  54.692  1
544190  92.774  -58.360  54.706  1
544191  92.803  -58.365  54.724  1
544192  92.833  -58.370  54.745  1
544193  92.877  -58.376  54.767  1
544194  92.922  -58.382  54.789  1
544195  92.968  -58.388  54.806  1
544196  93.005  -58.398  54.816  1
544197  93.044  -58.408  54.820  1
544198  93.081  -58.417  54.818  1
544199  93.119  -58.427  54.814  1
544200  93.157  -58.436  54.815  1
544201  93.195  -58.446  54.817  1
544202  93.233  -58.456  54.818  1
544203  93.271  -58.465  54.814  1
544204  93.309  -58.475  54.804  1
544205  93.347  -58.485  54.788  1
544206  93.385  -58.494  54.769  1
544207  93.423  -58.504  54.750  1
544208  93.462  -58.512  54.735  1
544209  93.500  -58.520  54.720  1
544210  93.539  -58.527  54.700  1
544211  93.576  -58.540  54.676  1
544212  93.612  -58.554  54.670  1
544213  93.648  -58.567  54.663  1
544214  93.685  -58.581  54.653  1
544215  93.721  -58.595  54.637  1
544216  93.758  -58.608  54.616  1
544217  93.794  -58.622  54.590  1
544218  93.830  -58.636  54.571  1
544219  93.866  -58.649  54.560  1
544220  93.903  -58.663  54.558  1
544221  93.939  -58.676  54.559  1
544222  93.975  -58.690  54.558  1
544223  94.011  -58.704  54.552  1
544224  94.048  -58.717  54.540  1
544225  94.084  -58.731  54.522  1
544226  94.120  -58.745  54.498  1
544227  94.156  -58.759  54.467  1
544228  94.193  -58.773  54.430  1
544229  94.228  -58.785  54.391  1
544230  94.262  -58.796  54.351  1
544231  94.297  -58.807  54.315  1
544232  94.331  -58.818  54.284  1
544233  94.365  -58.830  54.261  1
544234  94.400  -58.841  54.250  1
544235  94.434  -58.852  54.235  1
544236  94.468  -58.863  54.216  1
544237  94.499  -58.876  54.190  1
544238  94.533  -58.889  54.162  1
544239  94.575  -58.899  54.130  1
544240  94.618  -58.911  54.097  1
544241  94.661  -58.921  54.066  1
544242  94.703  -58.932  54.038  1
544243  94.746  -58.943  54.011  1
544244  94.788  -58.953  53.980  1
544245  94.831  -58.965  53.944  1
544246  94.873  -58.975  53.905  1
544247  94.916  -58.986  53.865  1
544248  94.959  -58.996  53.826  1
544249  95.001  -59.007  53.787  1
544250  95.044  -59.018  53.755  1
544251  95.085  -59.029  53.721  1
544252  95.124  -59.040  53.691  1
544253  95.163  -59.050  53.666  1
544254  95.202  -59.061  53.644  1
544255  95.243  -59.072  53.619  1
544256  95.278  -59.084  53.597  1
544257  95.310  -59.099  53.575  1
544258  95.342  -59.113  53.553  1
544259  95.374  -59.128  53.534  1
544260  95.406  -59.143  53.519  1
544261  95.438  -59.158  53.500  1
544262  95.471  -59.170  53.486  1
544263  95.504  -59.181  53.473  1
544264  95.537  -59.193  53.458  1
544265  95.566  -59.201  53.441  1
544266  95.595  -59.209  53.426  1
544267  95.623  -59.217  53.406  1
544268  95.652  -59.225  53.388  1
544269  95.680  -59.232  53.369  1
544270  95.708  -59.240  53.349  1
544271  95.737  -59.247  53.330  1
544272  95.765  -59.255  53.317  1
544273  95.794  -59.262  53.302  1
544274  95.824  -59.270  53.282  1
544275  95.860  -59.275  53.263  1
544276  95.895  -59.281  53.247  1
544277  95.931  -59.287  53.230  1
544278  95.966  -59.294  53.221  1
544279  96.001  -59.300  53.210  1
544280  96.036  -59.306  53.199  1
544281  96.072  -59.311  53.186  1
544282  96.107  -59.317  53.168  1
544283  96.140  -59.324  53.149  1
544284  96.173  -59.331  53.127  1
544285  96.206  -59.338  53.104  1
544286  96.240  -59.344  53.079  1
544287  96.273  -59.351  53.052  1
544288  96.306  -59.358  53.026  1
544289  96.339  -59.365  53.001  1
544290  96.372  -59.372  52.977  1
544291  96.405  -59.378  52.958  1
544292  96.439  -59.385  52.939  1
544293  96.472  -59.391  52.914  1
544294  96.507  -59.394  52.889  1
544295  96.536  -59.391  52.862  1
544296  96.566  -59.388  52.835  1
544297  96.596  -59.386  52.808  1
544298  96.626  -59.383  52.778  1
544299  96.656  -59.381  52.746  1
544300  96.687  -59.378  52.710  1
544301  96.717  -59.375  52.671  1
544302  96.747  -59.373  52.628  1
544303  96.778  -59.371  52.583  1
544304  96.810  -59.370  52.538  1
544305  96.843  -59.371  52.497  1
544306  96.879  -59.373  52.455  1
544307  96.916  -59.375  52.417  1
544308  96.953  -59.378  52.383  1
544309  96.991  -59.381  52.351  1
544310  97.028  -59.385  52.320  1
544311  97.065  -59.388  52.284  1
544312  97.102  -59.391  52.248  1
544313  97.139  -59.393  52.213  1
544314  97.176  -59.396  52.175  1
544315  97.209  -59.399  52.134  1
544316  97.242  -59.403  52.092  1
544317  97.275  -59.406  52.045  1
544318  97.307  -59.410  51.997  1
544319  97.339  -59.413  51.947  1
544320  97.371  -59.416  51.897  1
544321  97.403  -59.421  51.846  1
544322  97.435  -59.425  51.794  1
544323  97.466  -59.431  51.742  1
544324  97.498  -59.435  51.689  1
544325  97.531  -59.440  51.635  1
544326  97.571  -59.451  51.584  1
544327  97.610  -59.463  51.536  1
544328  97.650  -59.473  51.493  1
544329  97.690  -59.485  51.448  1
544330  97.730  -59.496  51.403  1
544331  97.770  -59.507  51.353  1
544332  97.809  -59.518  51.299  1
544333  97.849  -59.529  51.243  1
544334  97.889  -59.540  51.187  1
544335  97.930  -59.546  51.138  1
544336  97.972  -59.549  51.092  1
544337  98.014  -59.553  51.046  1
544338  98.056  -59.556  51.001  1
544339  98.098  -59.560  50.951  1
544340  98.140  -59.563  50.901  1
544341  98.179  -59.563  50.854  1
544342  98.209  -59.550  50.808  1
544343  98.238  -59.536  50.765  1
544344  98.267  -59.522  50.725  1
544345  98.296  -59.510  50.686  1
544346  98.317  -59.516  50.649  1
544347  98.353  -59.523  50.612  1
544348  98.397  -59.529  50.575  1
544349  98.435  -59.526  50.539  1
544350  98.472  -59.523  50.503  1
544351  98.509  -59.517  50.469  1
544352  98.546  -59.501  50.435  1
544353  98.583  -59.485  50.400  1
544354  98.620  -59.469  50.365  1
544355  98.663  -59.463  50.332  1
544356  98.705  -59.457  50.296  1
544357  98.748  -59.451  50.260  1
544358  98.790  -59.445  50.221  1
544359  98.833  -59.440  50.182  1
544360  98.875  -59.434  50.145  1
544361  98.913  -59.428  50.104  1
544362  98.949  -59.433  50.059  1
544363  98.978  -59.437  50.013  1
544364  99.007  -59.441  49.967  1
544365  99.035  -59.444  49.923  1
544366  99.064  -59.448  49.882  1
544367  99.093  -59.452  49.842  1
544368  99.122  -59.457  49.803  1
544369  99.150  -59.460  49.765  1
544370  99.179  -59.464  49.727  1
544371  99.208  -59.468  49.688  1
544372  99.236  -59.472  49.653  1
544373  99.293  -59.469  49.618  1
544374  99.365  -59.463  49.583  1
544723  86.292  -56.099  57.645  4
544724  86.332  -56.112  57.635  4
544725  86.372  -56.125  57.623  4
544726  86.413  -56.139  57.611  4
544727  86.453  -56.152  57.598  4
544728  86.494  -56.166  57.582  4
544729  86.534  -56.179  57.566  4
544730  86.574  -56.192  57.547  4
544731  86.615  -56.206  57.525  4
544732  86.655  -56.219  57.502  4
544733  86.696  -56.232  57.478  4
544734  86.736  -56.246  57.451  4
544735  86.777  -56.259  57.422  4
544736  86.817  -56.273  57.392  4
544737  86.857  -56.285  57.358  4
544738  86.898  -56.299  57.324  4
544739  86.938  -56.313  57.289  4
544740  86.979  -56.326  57.254  4
544741  87.019  -56.339  57.219  4
544742  87.059  -56.352  57.185  4
544743  87.099  -56.366  57.149  4
544744  87.140  -56.379  57.114  4
544808  89.619  -57.238  55.882  1
544809  89.660  -57.249  55.867  1
544810  89.701  -57.260  55.854  1
544811  89.743  -57.271  55.842  1
544812  89.785  -57.282  55.830  1
544813  89.826  -57.293  55.818  1
544814  89.867  -57.304  55.806  1
544815  89.908  -57.314  55.793  1
544816  89.950  -57.325  55.781  1
544817  89.996  -57.340  55.770  1
544818  90.042  -57.355  55.757  1
544819  90.079  -57.365  55.743  1
544820  90.115  -57.375  55.728  1
544821  90.150  -57.390  55.712  1
544822  90.185  -57.406  55.694  1
544823  90.220  -57.422  55.676  1
544824  90.254  -57.438  55.656  1
544825  90.289  -57.454  55.636  1
544826  90.323  -57.470  55.613  1
544827  90.357  -57.482  55.590  1
544828  90.391  -57.493  55.566  1
544829  90.424  -57.504  55.542  1
544830  90.458  -57.516  55.518  1
544831  90.493  -57.529  55.492  1
544832  90.531  -57.546  55.467  1
544833  90.568  -57.562  55.444  1
544834  90.605  -57.579  55.420  1
544835  90.643  -57.595  55.400  1
544836  90.680  -57.611  55.381  1
544837  90.718  -57.628  55.362  1
544838  90.755  -57.644  55.345  1
544839  90.793  -57.661  55.330  1
544840  90.835  -57.670  55.314  1
544841  90.880  -57.677  55.302  1
544842  90.925  -57.683  55.294  1
544843  90.970  -57.690  55.287  1
544844  91.015  -57.697  55.281  1
544845  91.060  -57.703  55.276  1
544846  91.104  -57.712  55.276  1
544847  91.144  -57.736  55.277  1
544848  91.183  -57.760  55.280  1
544849  91.223  -57.783  55.283  1
544850  91.262  -57.807  55.285  1
544851  91.302  -57.831  55.287  1
544852  91.342  -57.855  55.287  1
544853  91.381  -57.878  55.281  1
544854  91.421  -57.902  55.273  1
544855  91.460  -57.926  55.265  1
544856  91.503  -57.940  55.257  1
544857  91.546  -57.950  55.249  1
544858  91.590  -57.961  55.234  1
544859  91.634  -57.971  55.213  1
544860  91.678  -57.981  55.192  1
544861  91.722  -57.992  55.174  1
544862  91.766  -58.003  55.160  1
544863  91.809  -58.013  55.140  1
544864  91.853  -58.024  55.130  1
544865  91.897  -58.034  55.122  1
544866  91.932  -58.052  55.112  1
544867  91.963  -58.075  55.095  1
544868  91.994  -58.096  55.072  1
544869  92.024  -58.118  55.047  1
544870  92.055  -58.140  55.022  1
544871  92.085  -58.163  54.996  1
544872  92.121  -58.181  54.971  1
544873  92.162  -58.196  54.941  1
544874  92.204  -58.210  54.908  1
544875  92.245  -58.225  54.879  1
544876  92.287  -58.238  54.855  1
544877  92.329  -58.248  54.838  1
544878  92.371  -58.258  54.821  1
544879  92.414  -58.268  54.807  1
544880  92.455  -58.277  54.794  1
544881  92.493  -58.280  54.782  1
544882  92.522  -58.285  54.769  1
544883  92.552  -58.291  54.757  1
544884  92.582  -58.296  54.744  1
544885  92.611  -58.301  54.728  1
544886  92.641  -58.306  54.713  1
544887  92.670  -58.312  54.700  1
544888  92.700  -58.317  54.690  1
544889  92.729  -58.322  54.684  1
544890  92.759  -58.328  54.685  1
544891  92.789  -58.332  54.689  1
544892  92.818  -58.338  54.699  1
544893  92.848  -58.343  54.715  1
544894  92.887  -58.349  54.734  1
544895  92.933  -58.355  54.753  1
544896  92.976  -58.362  54.768  1
544897  93.013  -58.372  54.779  1
544898  93.052  -58.382  54.784  1
544899  93.089  -58.391  54.782  1
544900  93.128  -58.400  54.778  1
544901  93.165  -58.410  54.779  1
544902  93.203  -58.419  54.784  1
544903  93.241  -58.429  54.789  1
544904  93.279  -58.439  54.791  1
544905  93.318  -58.448  54.785  1
544906  93.355  -58.458  54.773  1
544907  93.393  -58.468  54.757  1
544908  93.431  -58.477  54.740  1
544909  93.470  -58.486  54.724  1
544910  93.508  -58.494  54.706  1
544911  93.547  -58.501  54.686  1
544912  93.583  -58.515  54.664  1
544913  93.620  -58.529  54.653  1
544914  93.656  -58.542  54.644  1
544915  93.692  -58.556  54.635  1
544916  93.728  -58.570  54.621  1
544917  93.765  -58.583  54.603  1
544918  93.801  -58.597  54.580  1
544919  93.838  -58.610  54.562  1
544920  93.874  -58.624  54.551  1
544921  93.910  -58.638  54.548  1
544922  93.946  -58.651  54.548  1
544923  93.983  -58.666  54.548  1
544924  94.019  -58.679  54.542  1
544925  94.055  -58.693  54.533  1
544926  94.091  -58.707  54.520  1
544927  94.127  -58.719  54.500  1
544928  94.161  -58.730  54.472  1
544929  94.195  -58.742  54.435  1
544930  94.229  -58.752  54.394  1
544931  94.264  -58.764  54.355  1
544932  94.298  -58.775  54.319  1
544933  94.333  -58.786  54.287  1
544934  94.367  -58.798  54.260  1
544935  94.401  -58.808  54.246  1
544936  94.435  -58.820  54.232  1
544937  94.470  -58.831  54.214  1
544938  94.500  -58.845  54.191  1
544939  94.531  -58.858  54.165  1
544940  94.572  -58.869  54.135  1
544941  94.614  -58.880  54.105  1
544942  94.657  -58.890  54.078  1
544943  94.699  -58.901  54.053  1
544944  94.742  -58.912  54.026  1
544945  94.784  -58.923  53.997  1
544946  94.827  -58.933  53.962  1
544947  94.870  -58.944  53.923  1
544948  94.912  -58.955  53.883  1
544949  94.955  -58.965  53.844  1
544950  94.997  -58.977  53.805  1
544951  95.040  -58.987  53.771  1
544952  95.083  -58.998  53.738  1
544953  95.125  -59.008  53.709  1
544954  95.168  -59.019  53.685  1
544955  95.210  -59.030  53.663  1
544956  95.253  -59.041  53.640  1
544957  95.289  -59.055  53.618  1
544958  95.321  -59.069  53.595  1
544959  95.353  -59.084  53.573  1
544960  95.385  -59.099  53.554  1
544961  95.417  -59.114  53.535  1
544962  95.449  -59.129  53.518  1
544963  95.481  -59.143  53.502  1
544964  95.514  -59.154  53.488  1
544965  95.543  -59.162  53.473  1
544966  95.571  -59.170  53.456  1
544967  95.600  -59.178  53.440  1
544968  95.628  -59.185  53.419  1
544969  95.657  -59.193  53.400  1
544970  95.686  -59.200  53.379  1
544971  95.714  -59.208  53.355  1
544972  95.743  -59.215  53.329  1
544973  95.771  -59.223  53.306  1
544974  95.800  -59.231  53.287  1
544975  95.831  -59.237  53.270  1
544976  95.866  -59.244  53.252  1
544977  95.901  -59.250  53.235  1
544978  95.937  -59.256  53.220  1
544979  95.972  -59.261  53.211  1
544980  96.007  -59.267  53.200  1
544981  96.042  -59.273  53.189  1
544982  96.078  -59.279  53.177  1
544983  96.111  -59.285  53.160  1
544984  96.145  -59.292  53.142  1
544985  96.178  -59.299  53.120  1
544986  96.212  -59.306  53.097  1
544987  96.245  -59.312  53.074  1
544988  96.278  -59.319  53.049  1
544989  96.311  -59.326  53.024  1
544990  96.344  -59.333  52.999  1
544991  96.377  -59.340  52.975  1
544992  96.410  -59.347  52.956  1
544993  96.444  -59.353  52.937  1
544994  96.477  -59.359  52.913  1
544995  96.509  -59.364  52.889  1
544996  96.539  -59.361  52.864  1
544997  96.570  -59.359  52.835  1
544998  96.600  -59.356  52.806  1
544999  96.630  -59.354  52.776  1
545000  96.661  -59.351  52.740  1
545001  96.691  -59.349  52.702  1
545002  96.722  -59.347  52.661  1
545003  96.752  -59.344  52.616  1
545004  96.782  -59.341  52.570  1
545005  96.815  -59.341  52.526  1
545006  96.849  -59.342  52.485  1
545007  96.882  -59.343  52.447  1
545008  96.920  -59.346  52.414  1
545009  96.957  -59.349  52.384  1
545010  96.994  -59.352  52.354  1
545011  97.031  -59.355  52.321  1
545012  97.068  -59.357  52.284  1
545013  97.105  -59.360  52.246  1
545014  97.142  -59.363  52.207  1
545015  97.178  -59.366  52.166  1
545016  97.211  -59.369  52.122  1
545017  97.244  -59.373  52.076  1
545018  97.277  -59.376  52.027  1
545019  97.310  -59.379  51.976  1
545020  97.343  -59.383  51.924  1
545021  97.375  -59.386  51.871  1
545022  97.406  -59.391  51.820  1
545023  97.438  -59.396  51.769  1
545024  97.470  -59.400  51.717  1
545025  97.502  -59.405  51.665  1
545026  97.533  -59.410  51.613  1
545027  97.567  -59.416  51.562  1
545028  97.607  -59.427  51.511  1
545029  97.647  -59.438  51.466  1
545030  97.686  -59.449  51.420  1
545031  97.726  -59.460  51.375  1
545032  97.766  -59.471  51.330  1
545033  97.806  -59.482  51.281  1
545034  97.846  -59.494  51.229  1
545035  97.886  -59.504  51.179  1
545036  97.928  -59.508  51.136  1
545037  97.969  -59.512  51.095  1
545038  98.011  -59.515  51.053  1
545039  98.054  -59.518  51.008  1
545040  98.095  -59.522  50.960  1
545041  98.137  -59.525  50.911  1
545042  98.179  -59.528  50.864  1
545043  98.208  -59.514  50.818  1
545044  98.237  -59.501  50.775  1
545045  98.266  -59.488  50.733  1
545046  98.295  -59.474  50.695  1
545047  98.320  -59.472  50.656  1
545048  98.358  -59.479  50.617  1
545049  98.397  -59.479  50.577  1
545050  98.434  -59.476  50.540  1
545051  98.472  -59.474  50.503  1
545052  98.508  -59.472  50.467  1
545053  98.546  -59.456  50.432  1
545054  98.582  -59.439  50.398  1
545055  98.621  -59.426  50.365  1
545056  98.664  -59.420  50.333  1
545057  98.706  -59.415  50.298  1
545058  98.749  -59.409  50.263  1
545059  98.791  -59.403  50.225  1
545060  98.833  -59.397  50.187  1
545061  98.869  -59.392  50.151  1
545062  98.905  -59.388  50.111  1
545063  98.947  -59.396  50.067  1
545064  98.976  -59.400  50.021  1
545065  99.005  -59.403  49.976  1
545066  99.033  -59.407  49.931  1
545067  99.062  -59.411  49.890  1
545068  99.091  -59.415  49.851  1
545069  99.120  -59.419  49.812  1
545070  99.149  -59.423  49.774  1
545071  99.178  -59.427  49.736  1
545072  99.206  -59.431  49.699  1
545073  99.235  -59.435  49.664  1
545074  99.301  -59.430  49.630  1
545075  99.373  -59.424  49.595  1
545424  86.308  -56.056  57.650  4
545425  86.349  -56.069  57.641  4
545426  86.389  -56.082  57.629  4
545427  86.430  -56.096  57.617  4
545428  86.470  -56.109  57.604  4
545429  86.510  -56.122  57.590  4
545430  86.551  -56.135  57.575  4
545431  86.591  -56.149  57.557  4
545432  86.632  -56.163  57.536  4
545433  86.672  -56.175  57.514  4
545434  86.713  -56.189  57.490  4
545435  86.753  -56.202  57.464  4
545436  86.793  -56.216  57.436  4
545437  86.834  -56.229  57.407  4
545438  86.874  -56.242  57.373  4
545439  86.915  -56.256  57.338  4
545440  86.955  -56.269  57.303  4
545441  86.995  -56.282  57.268  4
545442  87.036  -56.296  57.233  4
545443  87.076  -56.309  57.199  4
545444  87.117  -56.323  57.162  4
545445  87.157  -56.335  57.126  4
545509  89.638  -57.199  55.883  1
545510  89.680  -57.210  55.868  1
545511  89.721  -57.220  55.855  1
545512  89.762  -57.232  55.843  1
545513  89.804  -57.242  55.830  1
545514  89.845  -57.253  55.817  1
545515  89.887  -57.264  55.805  1
545516  89.928  -57.275  55.791  1
545517  89.969  -57.285  55.778  1
545518  90.011  -57.296  55.765  1
545519  90.058  -57.312  55.752  1
545520  90.094  -57.322  55.737  1
545521  90.129  -57.336  55.721  1
545522  90.164  -57.352  55.703  1
545523  90.199  -57.368  55.684  1
545524  90.234  -57.385  55.665  1
545525  90.268  -57.401  55.644  1
545526  90.303  -57.416  55.622  1
545527  90.337  -57.432  55.599  1
545528  90.371  -57.443  55.575  1
545529  90.404  -57.454  55.550  1
545530  90.438  -57.466  55.526  1
545531  90.473  -57.479  55.502  1
545532  90.510  -57.495  55.478  1
545533  90.547  -57.511  55.454  1
545534  90.585  -57.527  55.431  1
545535  90.622  -57.544  55.408  1
545536  90.660  -57.561  55.388  1
545537  90.697  -57.576  55.369  1
545538  90.735  -57.593  55.351  1
545539  90.772  -57.610  55.334  1
545540  90.810  -57.626  55.319  1
545541  90.849  -57.639  55.305  1
545542  90.894  -57.645  55.292  1
545543  90.939  -57.652  55.283  1
545544  90.984  -57.659  55.276  1
545545  91.029  -57.665  55.271  1
545546  91.074  -57.672  55.265  1
545547  91.118  -57.683  55.265  1
545548  91.157  -57.706  55.266  1
545549  91.197  -57.730  55.268  1
545550  91.236  -57.754  55.271  1
545551  91.276  -57.777  55.274  1
545552  91.316  -57.801  55.280  1
545553  91.355  -57.824  55.286  1
545554  91.395  -57.849  55.289  1
545555  91.435  -57.872  55.286  1
545556  91.476  -57.890  55.281  1
545557  91.520  -57.900  55.274  1
545558  91.564  -57.911  55.265  1
545559  91.607  -57.921  55.249  1
545560  91.651  -57.932  55.229  1
545561  91.695  -57.943  55.210  1
545562  91.739  -57.952  55.198  1
545563  91.783  -57.963  55.186  1
545564  91.826  -57.974  55.164  1
545565  91.870  -57.984  55.139  1
545566  91.914  -57.995  55.116  1
545567  91.952  -58.010  55.099  1
545568  91.983  -58.032  55.087  1
545569  92.014  -58.054  55.067  1
545570  92.044  -58.077  55.041  1
545571  92.075  -58.099  55.013  1
545572  92.105  -58.121  54.988  1
545573  92.145  -58.137  54.968  1
545574  92.186  -58.151  54.944  1
545575  92.227  -58.165  54.912  1
545576  92.269  -58.180  54.881  1
545577  92.310  -58.194  54.855  1
545578  92.351  -58.209  54.836  1
545579  92.392  -58.223  54.818  1
545580  92.434  -58.238  54.803  1
545581  92.476  -58.248  54.789  1
545582  92.508  -58.253  54.777  1
545583  92.537  -58.258  54.765  1
545584  92.567  -58.263  54.754  1
545585  92.597  -58.269  54.744  1
545586  92.626  -58.274  54.732  1
545587  92.656  -58.279  54.721  1
545588  92.686  -58.285  54.712  1
545589  92.715  -58.290  54.705  1
545590  92.744  -58.294  54.697  1
545591  92.774  -58.300  54.690  1
545592  92.804  -58.305  54.687  1
545593  92.834  -58.310  54.689  1
545594  92.863  -58.316  54.695  1
545595  92.898  -58.321  54.706  1
545596  92.944  -58.327  54.716  1
545597  92.984  -58.336  54.724  1
545598  93.021  -58.345  54.730  1
545599  93.060  -58.355  54.733  1
545600  93.097  -58.365  54.734  1
545601  93.136  -58.374  54.734  1
545602  93.174  -58.384  54.736  1
545603  93.211  -58.394  54.744  1
545604  93.250  -58.403  54.754  1
545605  93.287  -58.413  54.760  1
545606  93.326  -58.422  54.759  1
545607  93.363  -58.432  54.754  1
545608  93.401  -58.441  54.743  1
545609  93.439  -58.451  54.729  1
545610  93.478  -58.460  54.711  1
545611  93.516  -58.468  54.689  1
545612  93.555  -58.476  54.670  1
545613  93.591  -58.490  54.651  1
545614  93.627  -58.504  54.635  1
545615  93.663  -58.517  54.624  1
545616  93.700  -58.531  54.614  1
545617  93.736  -58.545  54.603  1
545618  93.772  -58.558  54.586  1
545619  93.808  -58.573  54.569  1
545620  93.845  -58.586  54.553  1
545621  93.881  -58.600  54.543  1
545622  93.918  -58.614  54.538  1
545623  93.954  -58.627  54.537  1
545624  93.990  -58.641  54.539  1
545625  94.026  -58.653  54.536  1
545626  94.060  -58.664  54.528  1
545627  94.094  -58.676  54.513  1
545628  94.128  -58.687  54.493  1
545629  94.163  -58.698  54.467  1
545630  94.197  -58.709  54.434  1
545631  94.231  -58.720  54.397  1
545632  94.266  -58.732  54.359  1
545633  94.300  -58.743  54.323  1
545634  94.334  -58.754  54.290  1
545635  94.368  -58.765  54.263  1
545636  94.403  -58.777  54.242  1
545637  94.437  -58.788  54.227  1
545638  94.470  -58.799  54.211  1
545639  94.501  -58.813  54.187  1
545640  94.532  -58.826  54.162  1
545641  94.568  -58.838  54.135  1
545642  94.611  -58.849  54.111  1
545643  94.653  -58.859  54.089  1
545644  94.696  -58.871  54.066  1
545645  94.739  -58.881  54.041  1
545646  94.781  -58.892  54.012  1
545647  94.824  -58.902  53.978  1
545648  94.866  -58.913  53.940  1
545649  94.909  -58.924  53.900  1
545650  94.952  -58.935  53.860  1
545651  94.994  -58.946  53.821  1
545652  95.037  -58.956  53.786  1
545653  95.079  -58.967  53.754  1
545654  95.122  -58.978  53.727  1
545655  95.164  -58.989  53.703  1
545656  95.207  -58.999  53.680  1
545657  95.251  -59.011  53.659  1
545658  95.295  -59.024  53.637  1
545659  95.327  -59.039  53.613  1
545660  95.360  -59.054  53.591  1
545661  95.393  -59.069  53.571  1
545662  95.425  -59.084  53.549  1
545663  95.458  -59.099  53.533  1
545664  95.491  -59.114  53.515  1
545665  95.520  -59.123  53.499  1
545666  95.549  -59.131  53.482  1
545667  95.577  -59.138  53.464  1
545668  95.606  -59.146  53.445  1
545669  95.634  -59.153  53.423  1
545670  95.663  -59.161  53.402  1
545671  95.691  -59.168  53.380  1
545672  95.720  -59.176  53.354  1
545673  95.748  -59.184  53.326  1
545674  95.776  -59.191  53.300  1
545675  95.805  -59.199  53.276  1
545676  95.837  -59.206  53.255  1
545677  95.872  -59.211  53.235  1
545678  95.907  -59.217  53.217  1
545679  95.943  -59.223  53.204  1
545680  95.978  -59.229  53.194  1
545681  96.013  -59.235  53.184  1
545682  96.048  -59.240  53.174  1
545683  96.083  -59.247  53.161  1
545684  96.114  -59.254  53.144  1
545685  96.149  -59.260  53.127  1
545686  96.183  -59.267  53.107  1
545687  96.216  -59.274  53.086  1
545688  96.249  -59.281  53.064  1
545689  96.283  -59.287  53.041  1
545690  96.316  -59.294  53.018  1
545691  96.349  -59.300  52.993  1
545692  96.382  -59.307  52.969  1
545693  96.415  -59.314  52.950  1
545694  96.449  -59.321  52.931  1
545695  96.482  -59.328  52.908  1
545696  96.513  -59.331  52.885  1
545697  96.544  -59.332  52.860  1
545698  96.574  -59.329  52.830  1
545699  96.604  -59.327  52.800  1
545700  96.635  -59.325  52.769  1
545701  96.665  -59.322  52.730  1
545702  96.695  -59.319  52.690  1
545703  96.726  -59.317  52.647  1
545704  96.756  -59.314  52.603  1
545705  96.787  -59.312  52.560  1
545706  96.820  -59.312  52.517  1
545707  96.854  -59.313  52.477  1
545708  96.887  -59.315  52.441  1
545709  96.923  -59.316  52.410  1
545710  96.960  -59.319  52.381  1
545711  96.997  -59.322  52.351  1
545712  97.034  -59.325  52.317  1
545713  97.071  -59.328  52.277  1
545714  97.108  -59.331  52.237  1
545715  97.145  -59.334  52.195  1
545716  97.180  -59.337  52.150  1
545717  97.213  -59.340  52.103  1
545718  97.246  -59.343  52.054  1
545719  97.279  -59.347  52.004  1
545720  97.312  -59.350  51.951  1
545721  97.346  -59.353  51.897  1
545722  97.378  -59.356  51.842  1
545723  97.410  -59.361  51.790  1
545724  97.442  -59.366  51.740  1
545725  97.473  -59.370  51.688  1
545726  97.505  -59.375  51.636  1
545727  97.537  -59.379  51.585  1
545728  97.569  -59.384  51.534  1
545729  97.604  -59.391  51.483  1
545730  97.644  -59.403  51.437  1
545731  97.683  -59.413  51.391  1
545732  97.723  -59.425  51.347  1
545733  97.763  -59.436  51.303  1
545734  97.803  -59.447  51.259  1
545735  97.843  -59.458  51.213  1
545736  97.883  -59.467  51.170  1
545737  97.925  -59.470  51.132  1
545738  97.967  -59.474  51.095  1
545739  98.009  -59.477  51.056  1
545740  98.051  -59.481  51.013  1
545741  98.093  -59.484  50.966  1
545742  98.135  -59.487  50.919  1
545743  98.176  -59.491  50.872  1
545744  98.208  -59.479  50.826  1
545745  98.236  -59.466  50.783  1
545746  98.266  -59.452  50.741  1
545747  98.295  -59.438  50.704  1
545748  98.322  -59.428  50.665  1
545749  98.359  -59.432  50.625  1
545750  98.396  -59.429  50.584  1
545751  98.433  -59.427  50.544  1
545752  98.471  -59.425  50.505  1
545753  98.508  -59.422  50.468  1
545754  98.545  -59.410  50.433  1
545755  98.582  -59.394  50.398  1
545756  98.622  -59.384  50.365  1
545757  98.664  -59.378  50.333  1
545758  98.707  -59.372  50.300  1
545759  98.749  -59.366  50.265  1
545760  98.789  -59.361  50.229  1
545761  98.825  -59.356  50.192  1
545762  98.861  -59.351  50.155  1
545763  98.897  -59.346  50.116  1
545764  98.934  -59.344  50.072  1
545765  98.975  -59.363  50.028  1
545766  99.003  -59.366  49.983  1
545767  99.032  -59.370  49.939  1
545768  99.061  -59.374  49.898  1
545769  99.089  -59.378  49.859  1
545770  99.119  -59.382  49.821  1
545771  99.147  -59.386  49.783  1
545772  99.176  -59.390  49.746  1
545773  99.205  -59.394  49.709  1
545774  99.237  -59.397  49.675  1
545775  99.309  -59.391  49.641  1
545776  99.381  -59.385  49.606  1
546125  86.326  -56.013  57.655  4
546126  86.366  -56.025  57.646  4
546127  86.406  -56.039  57.634  4
546128  86.446  -56.052  57.623  4
546129  86.487  -56.066  57.610  4
546130  86.527  -56.079  57.597  4
546131  86.568  -56.092  57.583  4
546132  86.608  -56.106  57.567  4
546133  86.649  -56.119  57.547  4
546134  86.689  -56.132  57.527  4
546135  86.729  -56.146  57.505  4
546136  86.770  -56.159  57.480  4
546137  86.810  -56.172  57.451  4
546138  86.851  -56.185  57.423  4
546139  86.891  -56.199  57.389  4
546140  86.931  -56.213  57.354  4
546141  86.972  -56.226  57.318  4
546142  87.012  -56.239  57.283  4
546143  87.053  -56.252  57.248  4
546144  87.093  -56.266  57.213  4
546145  87.133  -56.279  57.177  4
546146  87.174  -56.292  57.140  4
546147  87.214  -56.306  57.104  4
546210  89.658  -57.159  55.884  1
546211  89.699  -57.170  55.870  1
546212  89.741  -57.181  55.857  1
546213  89.782  -57.191  55.845  1
546214  89.823  -57.203  55.831  1
546215  89.865  -57.213  55.818  1
546216  89.906  -57.224  55.805  1
546217  89.948  -57.235  55.791  1
546218  89.989  -57.246  55.777  1
546219  90.030  -57.257  55.764  1
546220  90.072  -57.267  55.749  1
546221  90.109  -57.282  55.733  1
546222  90.144  -57.298  55.715  1
546223  90.178  -57.314  55.696  1
546224  90.213  -57.330  55.675  1
546225  90.248  -57.347  55.655  1
546226  90.283  -57.363  55.633  1
546227  90.317  -57.379  55.610  1
546228  90.351  -57.393  55.586  1
546229  90.385  -57.404  55.562  1
546230  90.418  -57.416  55.536  1
546231  90.452  -57.427  55.512  1
546232  90.489  -57.444  55.488  1
546233  90.527  -57.460  55.465  1
546234  90.565  -57.476  55.441  1
546235  90.602  -57.493  55.419  1
546236  90.640  -57.509  55.396  1
546237  90.677  -57.526  55.377  1
546238  90.714  -57.542  55.359  1
546239  90.752  -57.558  55.342  1
546240  90.789  -57.575  55.325  1
546241  90.826  -57.591  55.309  1
546242  90.864  -57.608  55.296  1
546243  90.908  -57.614  55.283  1
546244  90.954  -57.621  55.273  1
546245  90.999  -57.627  55.265  1
546246  91.043  -57.634  55.257  1
546247  91.088  -57.640  55.250  1
546248  91.132  -57.652  55.247  1
546249  91.171  -57.677  55.246  1
546250  91.211  -57.700  55.247  1
546251  91.250  -57.724  55.249  1
546252  91.290  -57.747  55.253  1
546253  91.329  -57.771  55.264  1
546254  91.369  -57.795  55.280  1
546255  91.409  -57.818  55.290  1
546256  91.449  -57.840  55.294  1
546257  91.493  -57.851  55.294  1
546258  91.536  -57.861  55.290  1
546259  91.580  -57.871  55.279  1
546260  91.624  -57.882  55.263  1
546261  91.668  -57.893  55.244  1
546262  91.712  -57.903  55.227  1
546263  91.755  -57.914  55.217  1
546264  91.799  -57.924  55.205  1
546265  91.843  -57.934  55.184  1
546266  91.887  -57.945  55.157  1
546267  91.931  -57.955  55.127  1
546268  91.973  -57.968  55.101  1
546269  92.003  -57.990  55.081  1
546270  92.034  -58.012  55.065  1
546271  92.065  -58.034  55.040  1
546272  92.095  -58.056  55.010  1
546273  92.127  -58.078  54.980  1
546274  92.168  -58.092  54.958  1
546275  92.209  -58.107  54.935  1
546276  92.250  -58.122  54.910  1
546277  92.292  -58.136  54.884  1
546278  92.333  -58.150  54.860  1
546279  92.374  -58.165  54.840  1
546280  92.416  -58.179  54.825  1
546281  92.457  -58.194  54.810  1
546282  92.485  -58.209  54.796  1
546283  92.511  -58.222  54.782  1
546284  92.544  -58.228  54.771  1
546285  92.577  -58.234  54.761  1
546286  92.611  -58.241  54.753  1
546287  92.642  -58.247  54.747  1
546288  92.671  -58.252  54.740  1
546289  92.701  -58.256  54.732  1
546290  92.730  -58.262  54.725  1
546291  92.760  -58.267  54.715  1
546292  92.789  -58.272  54.702  1
546293  92.819  -58.278  54.692  1
546294  92.849  -58.283  54.687  1
546295  92.878  -58.288  54.686  1
546296  92.909  -58.294  54.689  1
546297  92.954  -58.300  54.692  1
546298  92.992  -58.310  54.697  1
546299  93.029  -58.319  54.700  1
546300  93.068  -58.328  54.701  1
546301  93.106  -58.338  54.702  1
546302  93.144  -58.348  54.703  1
546303  93.182  -58.357  54.704  1
546304  93.220  -58.367  54.709  1
546305  93.258  -58.377  54.717  1
546306  93.295  -58.386  54.725  1
546307  93.334  -58.396  54.729  1
546308  93.371  -58.406  54.730  1
546309  93.410  -58.415  54.725  1
546310  93.447  -58.425  54.714  1
546311  93.485  -58.435  54.695  1
546312  93.524  -58.442  54.672  1
546313  93.562  -58.451  54.654  1
546314  93.599  -58.465  54.636  1
546315  93.635  -58.479  54.619  1
546316  93.671  -58.493  54.604  1
546317  93.707  -58.507  54.592  1
546318  93.744  -58.520  54.581  1
546319  93.780  -58.534  54.569  1
546320  93.816  -58.548  54.556  1
546321  93.852  -58.561  54.545  1
546322  93.889  -58.575  54.535  1
546323  93.924  -58.588  54.529  1
546324  93.959  -58.598  54.527  1
546325  93.993  -58.610  54.528  1
546326  94.027  -58.621  54.528  1
546327  94.061  -58.632  54.521  1
546328  94.096  -58.643  54.508  1
546329  94.130  -58.654  54.488  1
546330  94.164  -58.666  54.464  1
546331  94.199  -58.677  54.433  1
546332  94.233  -58.689  54.398  1
546333  94.267  -58.699  54.361  1
546334  94.301  -58.711  54.325  1
546335  94.336  -58.722  54.293  1
546336  94.370  -58.733  54.265  1
546337  94.404  -58.744  54.240  1
546338  94.438  -58.755  54.223  1
546339  94.471  -58.767  54.207  1
546340  94.502  -58.781  54.185  1
546341  94.533  -58.794  54.158  1
546342  94.565  -58.807  54.130  1
546343  94.607  -58.818  54.108  1
546344  94.650  -58.829  54.089  1
546345  94.692  -58.839  54.068  1
546346  94.735  -58.850  54.044  1
546347  94.777  -58.861  54.018  1
546348  94.820  -58.872  53.985  1
546349  94.863  -58.883  53.949  1
546350  94.905  -58.893  53.910  1
546351  94.948  -58.904  53.871  1
546352  94.990  -58.914  53.834  1
546353  95.033  -58.926  53.799  1
546354  95.075  -58.936  53.769  1
546355  95.118  -58.947  53.743  1
546356  95.161  -58.958  53.718  1
546357  95.204  -58.969  53.695  1
546358  95.251  -58.981  53.675  1
546359  95.298  -58.993  53.653  1
546360  95.333  -59.008  53.629  1
546361  95.366  -59.024  53.606  1
546362  95.399  -59.038  53.584  1
546363  95.431  -59.053  53.561  1
546364  95.464  -59.068  53.544  1
546365  95.496  -59.082  53.525  1
546366  95.526  -59.090  53.506  1
546367  95.554  -59.098  53.487  1
546368  95.583  -59.106  53.467  1
546369  95.611  -59.113  53.445  1
546370  95.640  -59.121  53.422  1
546371  95.668  -59.128  53.399  1
546372  95.697  -59.136  53.375  1
546373  95.725  -59.143  53.348  1
546374  95.754  -59.151  53.320  1
546375  95.782  -59.159  53.293  1
546376  95.811  -59.166  53.265  1
546377  95.843  -59.173  53.239  1
546378  95.878  -59.179  53.218  1
546379  95.913  -59.185  53.200  1
546380  95.949  -59.190  53.185  1
546381  95.984  -59.196  53.175  1
546382  96.020  -59.203  53.166  1
546383  96.055  -59.209  53.156  1
546384  96.086  -59.215  53.143  1
546385  96.118  -59.222  53.126  1
546386  96.153  -59.228  53.110  1
546387  96.188  -59.234  53.092  1
546388  96.221  -59.241  53.070  1
546389  96.254  -59.248  53.046  1
546390  96.287  -59.255  53.024  1
546391  96.320  -59.262  53.002  1
546392  96.354  -59.269  52.978  1
546393  96.387  -59.275  52.954  1
546394  96.420  -59.282  52.933  1
546395  96.453  -59.289  52.916  1
546396  96.486  -59.296  52.894  1
546397  96.517  -59.298  52.871  1
546398  96.548  -59.300  52.845  1
546399  96.579  -59.300  52.817  1
546400  96.609  -59.297  52.788  1
546401  96.639  -59.295  52.755  1
546402  96.670  -59.293  52.714  1
546403  96.700  -59.290  52.673  1
546404  96.730  -59.287  52.630  1
546405  96.761  -59.285  52.587  1
546406  96.792  -59.283  52.545  1
546407  96.825  -59.284  52.502  1
546408  96.859  -59.285  52.461  1
546409  96.892  -59.286  52.428  1
546410  96.926  -59.287  52.398  1
546411  96.963  -59.289  52.369  1
546412  97.000  -59.292  52.337  1
546413  97.037  -59.295  52.302  1
546414  97.074  -59.298  52.260  1
546415  97.111  -59.301  52.217  1
546416  97.149  -59.303  52.172  1
546417  97.182  -59.307  52.126  1
546418  97.215  -59.310  52.077  1
546419  97.248  -59.313  52.027  1
546420  97.281  -59.316  51.975  1
546421  97.314  -59.320  51.921  1
546422  97.348  -59.323  51.868  1
546423  97.382  -59.326  51.815  1
546424  97.413  -59.331  51.760  1
546425  97.445  -59.335  51.707  1
546426  97.476  -59.340  51.653  1
546427  97.508  -59.344  51.600  1
546428  97.540  -59.349  51.550  1
546429  97.572  -59.353  51.501  1
546430  97.603  -59.358  51.453  1
546431  97.640  -59.367  51.407  1
546432  97.680  -59.378  51.363  1
546433  97.720  -59.389  51.319  1
546434  97.760  -59.400  51.275  1
546435  97.800  -59.412  51.233  1
546436  97.840  -59.422  51.192  1
546437  97.880  -59.429  51.158  1
546438  97.922  -59.433  51.126  1
546439  97.964  -59.436  51.093  1
546440  98.006  -59.440  51.057  1
546441  98.048  -59.443  51.014  1
546442  98.090  -59.446  50.969  1
546443  98.132  -59.450  50.924  1
546444  98.174  -59.453  50.878  1
546445  98.207  -59.444  50.833  1
546446  98.236  -59.431  50.789  1
546447  98.265  -59.417  50.748  1
546448  98.294  -59.403  50.712  1
546449  98.323  -59.390  50.674  1
546450  98.359  -59.382  50.634  1
546451  98.395  -59.380  50.592  1
546452  98.433  -59.377  50.549  1
546453  98.470  -59.375  50.508  1
546454  98.507  -59.372  50.470  1
546455  98.545  -59.365  50.435  1
546456  98.581  -59.349  50.400  1
546457  98.623  -59.341  50.366  1
546458  98.665  -59.335  50.333  1
546459  98.708  -59.330  50.301  1
546460  98.744  -59.325  50.266  1
546461  98.780  -59.320  50.231  1
546462  98.816  -59.315  50.196  1
546463  98.852  -59.310  50.160  1
546464  98.888  -59.305  50.119  1
546465  98.924  -59.300  50.077  1
546466  98.973  -59.325  50.034  1
546467  99.002  -59.329  49.990  1
546468  99.030  -59.333  49.946  1
546469  99.059  -59.337  49.905  1
546470  99.088  -59.341  49.867  1
546471  99.117  -59.345  49.830  1
546472  99.146  -59.349  49.792  1
546473  99.174  -59.353  49.756  1
546474  99.203  -59.356  49.720  1
546475  99.244  -59.357  49.685  1
546476  99.316  -59.352  49.651  1
546477  99.389  -59.346  49.617  1
546826  86.342  -55.969  57.658  4
546827  86.382  -55.982  57.651  4
546828  86.423  -55.996  57.640  4
546829  86.463  -56.009  57.629  4
546830  86.504  -56.022  57.617  4
546831  86.544  -56.036  57.604  4
546832  86.585  -56.049  57.590  4
546833  86.625  -56.063  57.577  4
546834  86.665  -56.075  57.557  4
546835  86.706  -56.089  57.539  4
546836  86.746  -56.103  57.519  4
546837  86.787  -56.116  57.495  4
546838  86.827  -56.129  57.466  4
546839  86.867  -56.142  57.438  4
546840  86.908  -56.156  57.404  4
546841  86.948  -56.169  57.370  4
546842  86.989  -56.182  57.334  4
546843  87.029  -56.196  57.298  4
546844  87.069  -56.209  57.263  4
546845  87.110  -56.222  57.228  4
546846  87.150  -56.236  57.191  4
546847  87.191  -56.249  57.154  4
546848  87.231  -56.263  57.117  4
546849  87.271  -56.276  57.082  4
546911  89.677  -57.119  55.884  1
546912  89.719  -57.130  55.871  1
546913  89.760  -57.141  55.859  1
546914  89.802  -57.152  55.847  1
546915  89.843  -57.163  55.834  1
546916  89.884  -57.174  55.820  1
546917  89.925  -57.185  55.806  1
546918  89.967  -57.195  55.792  1
546919  90.009  -57.206  55.777  1
546920  90.050  -57.217  55.763  1
546921  90.086  -57.230  55.748  1
546922  90.123  -57.244  55.731  1
546923  90.158  -57.260  55.712  1
546924  90.192  -57.276  55.691  1
546925  90.227  -57.293  55.669  1
546926  90.262  -57.309  55.648  1
546927  90.296  -57.325  55.625  1
546928  90.331  -57.341  55.601  1
546929  90.365  -57.354  55.576  1
546930  90.398  -57.365  55.551  1
546931  90.432  -57.376  55.525  1
546932  90.469  -57.392  55.500  1
546933  90.507  -57.409  55.476  1
546934  90.544  -57.426  55.453  1
546935  90.582  -57.442  55.430  1
546936  90.619  -57.458  55.408  1
546937  90.656  -57.474  55.386  1
546938  90.694  -57.491  55.367  1
546939  90.731  -57.507  55.350  1
546940  90.768  -57.523  55.333  1
546941  90.806  -57.540  55.317  1
546942  90.844  -57.557  55.302  1
546943  90.881  -57.573  55.288  1
546944  90.923  -57.583  55.276  1
546945  90.968  -57.589  55.266  1
546946  91.013  -57.596  55.256  1
546947  91.058  -57.602  55.247  1
546948  91.103  -57.609  55.241  1
546949  91.146  -57.623  55.236  1
546950  91.185  -57.646  55.234  1
546951  91.225  -57.670  55.233  1
546952  91.264  -57.694  55.233  1
546953  91.304  -57.717  55.237  1
546954  91.344  -57.741  55.244  1
546955  91.383  -57.764  55.257  1
546956  91.423  -57.788  55.271  1
546957  91.466  -57.801  55.282  1
546958  91.510  -57.811  55.288  1
546959  91.554  -57.822  55.287  1
546960  91.597  -57.833  55.283  1
546961  91.641  -57.843  55.273  1
546962  91.685  -57.853  55.259  1
546963  91.729  -57.864  55.244  1
546964  91.773  -57.874  55.233  1
546965  91.816  -57.885  55.219  1
546966  91.860  -57.896  55.200  1
546967  91.904  -57.906  55.175  1
546968  91.948  -57.916  55.145  1
546969  91.992  -57.927  55.111  1
546970  92.024  -57.948  55.083  1
546971  92.054  -57.970  55.065  1
546972  92.085  -57.992  55.041  1
546973  92.116  -58.014  55.013  1
546974  92.150  -58.034  54.985  1
546975  92.192  -58.048  54.964  1
546976  92.233  -58.062  54.943  1
546977  92.274  -58.077  54.924  1
546978  92.315  -58.091  54.905  1
546979  92.357  -58.106  54.888  1
546980  92.398  -58.120  54.873  1
546981  92.439  -58.134  54.855  1
546982  92.463  -58.150  54.839  1
546983  92.486  -58.165  54.824  1
546984  92.509  -58.181  54.812  1
546985  92.536  -58.193  54.804  1
546986  92.569  -58.200  54.797  1
546987  92.602  -58.206  54.789  1
546988  92.636  -58.212  54.780  1
546989  92.669  -58.219  54.770  1
546990  92.702  -58.225  54.760  1
546991  92.735  -58.231  54.750  1
546992  92.769  -58.238  54.739  1
546993  92.802  -58.244  54.722  1
546994  92.834  -58.250  54.705  1
546995  92.864  -58.256  54.693  1
546996  92.893  -58.261  54.686  1
546997  92.923  -58.266  54.681  1
546998  92.962  -58.274  54.679  1
546999  93.000  -58.283  54.680  1
547000  93.038  -58.293  54.680  1
547001  93.076  -58.303  54.680  1
547002  93.114  -58.312  54.679  1
547003  93.152  -58.322  54.680  1
547004  93.190  -58.332  54.681  1
547005  93.228  -58.341  54.683  1
547006  93.266  -58.350  54.688  1
547007  93.303  -58.360  54.695  1
547008  93.342  -58.369  54.700  1
547009  93.379  -58.379  54.702  1
547010  93.418  -58.389  54.701  1
547011  93.455  -58.398  54.692  1
547012  93.493  -58.408  54.676  1
547013  93.532  -58.416  54.657  1
547014  93.569  -58.427  54.641  1
547015  93.606  -58.441  54.623  1
547016  93.642  -58.454  54.608  1
547017  93.679  -58.468  54.596  1
547018  93.715  -58.482  54.585  1
547019  93.751  -58.495  54.576  1
547020  93.787  -58.509  54.563  1
547021  93.823  -58.522  54.552  1
547022  93.857  -58.533  54.541  1
547023  93.892  -58.544  54.530  1
547024  93.926  -58.555  54.520  1
547025  93.960  -58.567  54.514  1
547026  93.994  -58.578  54.512  1
547027  94.029  -58.589  54.513  1
547028  94.063  -58.600  54.511  1
547029  94.097  -58.611  54.503  1
547030  94.131  -58.623  54.487  1
547031  94.166  -58.634  54.462  1
547032  94.200  -58.645  54.430  1
547033  94.235  -58.656  54.397  1
547034  94.269  -58.667  54.362  1
547035  94.303  -58.679  54.327  1
547036  94.337  -58.689  54.297  1
547037  94.371  -58.701  54.269  1
547038  94.406  -58.712  54.242  1
547039  94.440  -58.723  54.220  1
547040  94.472  -58.736  54.201  1
547041  94.502  -58.749  54.181  1
547042  94.533  -58.762  54.153  1
547043  94.564  -58.776  54.124  1
547044  94.604  -58.787  54.102  1
547045  94.646  -58.798  54.084  1
547046  94.689  -58.808  54.065  1
547047  94.732  -58.820  54.044  1
547048  94.774  -58.830  54.018  1
547049  94.817  -58.841  53.988  1
547050  94.859  -58.852  53.954  1
547051  94.902  -58.862  53.917  1
547052  94.945  -58.874  53.879  1
547053  94.987  -58.884  53.846  1
547054  95.030  -58.895  53.813  1
547055  95.072  -58.905  53.784  1
547056  95.115  -58.916  53.757  1
547057  95.158  -58.927  53.730  1
547058  95.204  -58.940  53.708  1
547059  95.251  -58.952  53.685  1
547060  95.298  -58.964  53.662  1
547061  95.339  -58.977  53.638  1
547062  95.372  -58.993  53.613  1
547063  95.404  -59.008  53.589  1
547064  95.437  -59.023  53.567  1
547065  95.470  -59.037  53.549  1
547066  95.500  -59.049  53.529  1
547067  95.530  -59.058  53.509  1
547068  95.560  -59.066  53.487  1
547069  95.588  -59.074  53.464  1
547070  95.617  -59.081  53.441  1
547071  95.645  -59.089  53.417  1
547072  95.674  -59.096  53.390  1
547073  95.702  -59.104  53.363  1
547074  95.731  -59.112  53.336  1
547075  95.759  -59.119  53.308  1
547076  95.788  -59.127  53.280  1
547077  95.816  -59.134  53.251  1
547078  95.849  -59.140  53.224  1
547079  95.884  -59.146  53.201  1
547080  95.919  -59.153  53.182  1
547081  95.955  -59.159  53.165  1
547082  95.990  -59.165  53.154  1
547083  96.026  -59.171  53.145  1
547084  96.059  -59.177  53.135  1
547085  96.089  -59.184  53.123  1
547086  96.121  -59.190  53.107  1
547087  96.157  -59.196  53.092  1
547088  96.191  -59.203  53.074  1
547089  96.226  -59.209  53.051  1
547090  96.259  -59.216  53.026  1
547091  96.292  -59.223  53.002  1
547092  96.325  -59.230  52.981  1
547093  96.359  -59.237  52.958  1
547094  96.392  -59.244  52.934  1
547095  96.425  -59.250  52.913  1
547096  96.458  -59.257  52.894  1
547097  96.490  -59.262  52.873  1
547098  96.521  -59.265  52.851  1
547099  96.552  -59.267  52.825  1
547100  96.583  -59.269  52.799  1
547101  96.613  -59.268  52.771  1
547102  96.644  -59.265  52.736  1
547103  96.674  -59.263  52.693  1
547104  96.704  -59.260  52.652  1
547105  96.735  -59.258  52.609  1
547106  96.765  -59.256  52.568  1
547107  96.797  -59.254  52.527  1
547108  96.830  -59.255  52.485  1
547109  96.864  -59.256  52.444  1
547110  96.898  -59.257  52.412  1
547111  96.932  -59.258  52.381  1
547112  96.966  -59.259  52.350  1
547113  97.003  -59.262  52.318  1
547114  97.040  -59.265  52.282  1
547115  97.077  -59.269  52.240  1
547116  97.114  -59.271  52.195  1
547117  97.151  -59.274  52.149  1
547118  97.184  -59.278  52.100  1
547119  97.217  -59.281  52.048  1
547120  97.250  -59.284  51.997  1
547121  97.283  -59.287  51.942  1
547122  97.316  -59.291  51.887  1
547123  97.351  -59.293  51.834  1
547124  97.385  -59.296  51.782  1
547125  97.418  -59.300  51.729  1
547126  97.449  -59.305  51.675  1
547127  97.480  -59.309  51.623  1
547128  97.512  -59.314  51.572  1
547129  97.543  -59.319  51.523  1
547130  97.575  -59.324  51.476  1
547131  97.607  -59.328  51.429  1
547132  97.639  -59.333  51.385  1
547133  97.677  -59.343  51.342  1
547134  97.717  -59.353  51.300  1
547135  97.756  -59.365  51.258  1
547136  97.796  -59.376  51.217  1
547137  97.836  -59.387  51.179  1
547138  97.878  -59.392  51.146  1
547139  97.920  -59.395  51.113  1
547140  97.961  -59.398  51.080  1
547141  98.004  -59.402  51.044  1
547142  98.045  -59.405  51.005  1
547143  98.087  -59.409  50.963  1
547144  98.130  -59.412  50.921  1
547145  98.171  -59.415  50.878  1
547146  98.206  -59.410  50.834  1
547147  98.235  -59.396  50.791  1
547148  98.265  -59.382  50.749  1
547149  98.294  -59.369  50.711  1
547150  98.324  -59.357  50.673  1
547151  98.359  -59.347  50.633  1
547152  98.395  -59.337  50.591  1
547153  98.432  -59.328  50.549  1
547154  98.469  -59.325  50.510  1
547155  98.507  -59.323  50.473  1
547156  98.544  -59.320  50.438  1
547157  98.581  -59.305  50.403  1
547158  98.624  -59.299  50.368  1
547159  98.664  -59.294  50.334  1
547160  98.700  -59.288  50.302  1
547161  98.736  -59.284  50.267  1
547162  98.772  -59.278  50.233  1
547163  98.808  -59.274  50.200  1
547164  98.844  -59.269  50.164  1
547165  98.880  -59.264  50.124  1
547166  98.916  -59.259  50.082  1
547167  98.968  -59.284  50.041  1
547168  99.000  -59.292  49.998  1
547169  99.029  -59.296  49.954  1
547170  99.058  -59.300  49.913  1
547171  99.086  -59.303  49.875  1
547172  99.115  -59.308  49.837  1
547173  99.144  -59.312  49.801  1
547174  99.172  -59.316  49.765  1
547175  99.202  -59.319  49.729  1
547176  99.253  -59.319  49.695  1
547177  99.324  -59.312  49.662  1
547178  99.396  -59.306  49.628  1
547179  99.468  -59.300  49.594  1
547527  86.359  -55.925  57.662  4
547528  86.400  -55.939  57.654  4
547529  86.440  -55.953  57.644  4
547530  86.480  -55.965  57.633  4
547531  86.521  -55.979  57.622  4
547532  86.561  -55.992  57.609  4
547533  86.601  -56.006  57.597  4
547534  86.642  -56.019  57.584  4
547535  86.682  -56.032  57.567  4
547536  86.723  -56.046  57.550  4
547537  86.763  -56.059  57.531  4
547538  86.803  -56.072  57.509  4
547539  86.844  -56.086  57.482  4
547540  86.884  -56.099  57.452  4
547541  86.925  -56.113  57.420  4
547542  86.965  -56.125  57.386  4
547543  87.005  -56.139  57.351  4
547544  87.046  -56.153  57.314  4
547545  87.086  -56.166  57.279  4
547546  87.127  -56.179  57.243  4
547547  87.167  -56.192  57.206  4
547548  87.207  -56.206  57.169  4
547549  87.248  -56.219  57.132  4
547550  87.288  -56.232  57.095  4
547551  87.329  -56.246  57.061  4
547612  89.697  -57.080  55.887  1
547613  89.738  -57.091  55.875  1
547614  89.779  -57.101  55.862  1
547615  89.821  -57.113  55.850  1
547616  89.862  -57.123  55.836  1
547617  89.904  -57.134  55.823  1
547618  89.945  -57.145  55.809  1
547619  89.986  -57.156  55.794  1
547620  90.028  -57.166  55.778  1
547621  90.067  -57.178  55.762  1
547622  90.097  -57.194  55.747  1
547623  90.134  -57.209  55.729  1
547624  90.171  -57.223  55.709  1
547625  90.206  -57.239  55.687  1
547626  90.241  -57.255  55.664  1
547627  90.276  -57.271  55.642  1
547628  90.310  -57.287  55.618  1
547629  90.345  -57.304  55.593  1
547630  90.379  -57.315  55.568  1
547631  90.412  -57.326  55.543  1
547632  90.449  -57.341  55.516  1
547633  90.486  -57.357  55.491  1
547634  90.524  -57.374  55.467  1
547635  90.561  -57.391  55.443  1
547636  90.598  -57.407  55.420  1
547637  90.636  -57.423  55.399  1
547638  90.673  -57.440  55.377  1
547639  90.711  -57.456  55.359  1
547640  90.748  -57.473  55.341  1
547641  90.786  -57.489  55.325  1
547642  90.823  -57.505  55.310  1
547643  90.860  -57.522  55.296  1
547644  90.898  -57.538  55.281  1
547645  90.937  -57.551  55.270  1
547646  90.982  -57.558  55.260  1
547647  91.027  -57.564  55.249  1
547648  91.072  -57.571  55.241  1
547649  91.117  -57.578  55.234  1
547650  91.160  -57.592  55.229  1
547651  91.199  -57.617  55.226  1
547652  91.239  -57.640  55.224  1
547653  91.278  -57.664  55.224  1
547654  91.318  -57.687  55.229  1
547655  91.358  -57.711  55.233  1
547656  91.397  -57.735  55.241  1
547657  91.439  -57.752  55.252  1
547658  91.483  -57.762  55.264  1
547659  91.526  -57.772  55.271  1
547660  91.570  -57.783  55.272  1
547661  91.614  -57.793  55.271  1
547662  91.658  -57.804  55.265  1
547663  91.702  -57.814  55.255  1
547664  91.745  -57.825  55.241  1
547665  91.789  -57.835  55.228  1
547666  91.833  -57.846  55.217  1
547667  91.877  -57.856  55.201  1
547668  91.921  -57.867  55.181  1
547669  91.964  -57.877  55.157  1
547670  92.008  -57.888  55.130  1
547671  92.044  -57.905  55.096  1
547672  92.075  -57.927  55.068  1
547673  92.105  -57.950  55.043  1
547674  92.136  -57.972  55.021  1
547675  92.174  -57.989  55.000  1
547676  92.215  -58.003  54.982  1
547677  92.257  -58.018  54.963  1
547678  92.298  -58.032  54.947  1
547679  92.339  -58.046  54.934  1
547680  92.380  -58.061  54.924  1
547681  92.418  -58.076  54.912  1
547682  92.441  -58.091  54.892  1
547683  92.464  -58.106  54.874  1
547684  92.488  -58.122  54.858  1
547685  92.511  -58.137  54.848  1
547686  92.533  -58.153  54.842  1
547687  92.561  -58.165  54.837  1
547688  92.594  -58.171  54.828  1
547689  92.627  -58.178  54.818  1
547690  92.660  -58.184  54.806  1
547691  92.694  -58.191  54.792  1
547692  92.727  -58.197  54.779  1
547693  92.761  -58.203  54.764  1
547694  92.794  -58.209  54.745  1
547695  92.828  -58.216  54.725  1
547696  92.864  -58.222  54.705  1
547697  92.901  -58.229  54.691  1
547698  92.937  -58.235  54.685  1
547699  92.974  -58.245  54.680  1
547700  93.010  -58.256  54.674  1
547701  93.047  -58.266  54.670  1
547702  93.084  -58.276  54.668  1
547703  93.122  -58.286  54.668  1
547704  93.160  -58.295  54.669  1
547705  93.198  -58.305  54.668  1
547706  93.236  -58.315  54.667  1
547707  93.274  -58.324  54.668  1
547708  93.311  -58.334  54.671  1
547709  93.350  -58.344  54.674  1
547710  93.388  -58.353  54.676  1
547711  93.426  -58.363  54.676  1
547712  93.464  -58.372  54.671  1
547713  93.502  -58.382  54.661  1
547714  93.540  -58.391  54.647  1
547715  93.577  -58.402  54.635  1
547716  93.613  -58.416  54.619  1
547717  93.650  -58.429  54.606  1
547718  93.686  -58.443  54.596  1
547719  93.721  -58.456  54.586  1
547720  93.756  -58.467  54.575  1
547721  93.790  -58.479  54.563  1
547722  93.825  -58.489  54.552  1
547723  93.859  -58.501  54.540  1
547724  93.893  -58.512  54.528  1
547725  93.927  -58.523  54.516  1
547726  93.962  -58.534  54.507  1
547727  93.996  -58.545  54.500  1
547728  94.030  -58.557  54.497  1
547729  94.064  -58.568  54.496  1
547730  94.099  -58.579  54.493  1
547731  94.133  -58.590  54.481  1
547732  94.168  -58.601  54.460  1
547733  94.202  -58.613  54.433  1
547734  94.236  -58.624  54.399  1
547735  94.270  -58.635  54.364  1
547736  94.305  -58.646  54.329  1
547737  94.339  -58.657  54.300  1
547738  94.373  -58.669  54.276  1
547739  94.408  -58.680  54.250  1
547740  94.442  -58.691  54.221  1
547741  94.473  -58.705  54.194  1
547742  94.503  -58.717  54.173  1
547743  94.534  -58.731  54.149  1
547744  94.565  -58.744  54.118  1
547745  94.600  -58.756  54.093  1
547746  94.643  -58.767  54.075  1
547747  94.685  -58.778  54.059  1
547748  94.728  -58.789  54.040  1
547749  94.771  -58.799  54.016  1
547750  94.813  -58.810  53.988  1
547751  94.856  -58.821  53.956  1
547752  94.898  -58.832  53.921  1
547753  94.941  -58.842  53.886  1
547754  94.983  -58.853  53.854  1
547755  95.026  -58.864  53.824  1
547756  95.068  -58.875  53.796  1
547757  95.111  -58.886  53.768  1
547758  95.157  -58.897  53.740  1
547759  95.204  -58.910  53.717  1
547760  95.251  -58.922  53.691  1
547761  95.298  -58.934  53.667  1
547762  95.344  -58.947  53.642  1
547763  95.377  -58.961  53.617  1
547764  95.410  -58.977  53.592  1
547765  95.443  -58.992  53.569  1
547766  95.475  -59.007  53.548  1
547767  95.505  -59.015  53.528  1
547768  95.535  -59.024  53.506  1
547769  95.565  -59.034  53.481  1
547770  95.594  -59.042  53.458  1
547771  95.622  -59.049  53.434  1
547772  95.651  -59.057  53.409  1
547773  95.679  -59.065  53.381  1
547774  95.708  -59.072  53.353  1
547775  95.736  -59.080  53.325  1
547776  95.765  -59.087  53.297  1
547777  95.794  -59.094  53.267  1
547778  95.822  -59.102  53.240  1
547779  95.855  -59.109  53.212  1
547780  95.890  -59.115  53.187  1
547781  95.926  -59.121  53.167  1
547782  95.961  -59.126  53.149  1
547783  95.996  -59.132  53.136  1
547784  96.032  -59.138  53.125  1
547785  96.062  -59.145  53.112  1
547786  96.093  -59.152  53.099  1
547787  96.125  -59.159  53.083  1
547788  96.160  -59.165  53.068  1
547789  96.195  -59.171  53.050  1
547790  96.230  -59.178  53.029  1
547791  96.263  -59.184  53.005  1
547792  96.297  -59.191  52.979  1
547793  96.330  -59.198  52.954  1
547794  96.363  -59.205  52.933  1
547795  96.396  -59.212  52.910  1
547796  96.430  -59.218  52.887  1
547797  96.463  -59.225  52.865  1
547798  96.495  -59.229  52.844  1
547799  96.525  -59.231  52.825  1
547800  96.556  -59.234  52.800  1
547801  96.587  -59.236  52.776  1
547802  96.617  -59.238  52.750  1
547803  96.648  -59.236  52.713  1
547804  96.678  -59.234  52.669  1
547805  96.709  -59.231  52.628  1
547806  96.739  -59.228  52.586  1
547807  96.769  -59.226  52.545  1
547808  96.802  -59.225  52.505  1
547809  96.835  -59.227  52.467  1
547810  96.869  -59.228  52.427  1
547811  96.903  -59.228  52.394  1
547812  96.937  -59.229  52.360  1
547813  96.970  -59.231  52.327  1
547814  97.006  -59.233  52.295  1
547815  97.043  -59.235  52.258  1
547816  97.081  -59.238  52.216  1
547817  97.117  -59.241  52.171  1
547818  97.153  -59.244  52.123  1
547819  97.186  -59.247  52.073  1
547820  97.219  -59.251  52.019  1
547821  97.252  -59.254  51.966  1
547822  97.286  -59.257  51.912  1
547823  97.320  -59.259  51.857  1
547824  97.355  -59.262  51.804  1
547825  97.389  -59.266  51.753  1
547826  97.422  -59.270  51.701  1
547827  97.454  -59.275  51.648  1
547828  97.485  -59.279  51.598  1
547829  97.516  -59.284  51.548  1
547830  97.546  -59.289  51.500  1
547831  97.578  -59.294  51.454  1
547832  97.610  -59.298  51.409  1
547833  97.642  -59.303  51.368  1
547834  97.674  -59.307  51.326  1
547835  97.714  -59.319  51.284  1
547836  97.753  -59.329  51.243  1
547837  97.793  -59.341  51.204  1
547838  97.833  -59.350  51.167  1
547839  97.875  -59.354  51.135  1
547840  97.917  -59.357  51.101  1
547841  97.959  -59.361  51.065  1
547842  98.001  -59.364  51.028  1
547843  98.043  -59.367  50.990  1
547844  98.085  -59.371  50.950  1
547845  98.127  -59.374  50.911  1
547846  98.169  -59.378  50.871  1
547847  98.206  -59.374  50.830  1
547848  98.235  -59.360  50.790  1
547849  98.264  -59.348  50.749  1
547850  98.294  -59.336  50.711  1
547851  98.324  -59.325  50.672  1
547852  98.359  -59.314  50.632  1
547853  98.396  -59.304  50.591  1
547854  98.433  -59.294  50.549  1
547855  98.469  -59.284  50.512  1
547856  98.506  -59.275  50.475  1
547857  98.543  -59.271  50.440  1
547858  98.582  -59.262  50.406  1
547859  98.620  -59.257  50.371  1
547860  98.656  -59.252  50.337  1
547861  98.692  -59.247  50.303  1
547862  98.728  -59.242  50.269  1
547863  98.764  -59.237  50.235  1
547864  98.799  -59.232  50.203  1
547865  98.836  -59.228  50.168  1
547866  98.871  -59.222  50.128  1
547867  98.907  -59.218  50.088  1
547868  98.953  -59.231  50.048  1
547869  98.999  -59.255  50.006  1
547870  99.027  -59.259  49.962  1
547871  99.056  -59.262  49.921  1
547872  99.085  -59.266  49.882  1
547873  99.114  -59.271  49.845  1
547874  99.142  -59.275  49.809  1
547875  99.171  -59.278  49.773  1
547876  99.200  -59.282  49.738  1
547877  99.260  -59.279  49.704  1
547878  99.332  -59.273  49.671  1
547879  99.404  -59.267  49.638  1
547880  99.471  -59.263  49.604  1
548228  86.376  -55.882  57.665  4
548229  86.416  -55.896  57.658  4
548230  86.456  -55.909  57.647  4
548231  86.497  -55.922  57.637  4
548232  86.538  -55.936  57.626  4
548233  86.578  -55.949  57.615  4
548234  86.618  -55.962  57.603  4
548235  86.659  -55.975  57.591  4
548236  86.699  -55.989  57.576  4
548237  86.739  -56.003  57.560  4
548238  86.780  -56.016  57.544  4
548239  86.820  -56.029  57.525  4
548240  86.861  -56.042  57.496  4
548241  86.901  -56.056  57.467  4
548242  86.941  -56.069  57.435  4
548243  86.982  -56.082  57.402  4
548244  87.022  -56.096  57.367  4
548245  87.063  -56.109  57.331  4
548246  87.103  -56.122  57.295  4
548247  87.143  -56.136  57.260  4
548248  87.184  -56.149  57.222  4
548249  87.224  -56.163  57.184  4
548250  87.265  -56.176  57.148  4
548251  87.305  -56.189  57.110  4
548252  87.345  -56.203  57.076  4
548253  87.386  -56.216  57.042  4
548313  89.716  -57.040  55.889  1
548314  89.757  -57.051  55.878  1
548315  89.799  -57.062  55.866  1
548316  89.840  -57.072  55.854  1
548317  89.882  -57.084  55.841  1
548318  89.923  -57.094  55.827  1
548319  89.965  -57.105  55.813  1
548320  90.006  -57.116  55.798  1
548321  90.047  -57.127  55.781  1
548322  90.074  -57.144  55.765  1
548323  90.108  -57.159  55.748  1
548324  90.146  -57.173  55.729  1
548325  90.183  -57.187  55.708  1
548326  90.220  -57.201  55.685  1
548327  90.255  -57.217  55.661  1
548328  90.290  -57.233  55.638  1
548329  90.324  -57.250  55.614  1
548330  90.359  -57.265  55.588  1
548331  90.393  -57.276  55.563  1
548332  90.428  -57.290  55.537  1
548333  90.466  -57.307  55.509  1
548334  90.503  -57.323  55.484  1
548335  90.540  -57.339  55.460  1
548336  90.578  -57.356  55.436  1
548337  90.615  -57.373  55.412  1
548338  90.653  -57.388  55.391  1
548339  90.690  -57.405  55.371  1
548340  90.728  -57.421  55.352  1
548341  90.765  -57.438  55.336  1
548342  90.802  -57.454  55.320  1
548343  90.840  -57.470  55.306  1
548344  90.877  -57.487  55.293  1
548345  90.915  -57.504  55.278  1
548346  90.952  -57.520  55.267  1
548347  90.997  -57.526  55.257  1
548348  91.042  -57.533  55.247  1
548349  91.087  -57.540  55.238  1
548350  91.132  -57.546  55.231  1
548351  91.173  -57.563  55.226  1
548352  91.213  -57.586  55.223  1
548353  91.253  -57.610  55.223  1
548354  91.292  -57.634  55.225  1
548355  91.332  -57.658  55.230  1
548356  91.371  -57.681  55.233  1
548357  91.412  -57.702  55.232  1
548358  91.456  -57.712  55.236  1
548359  91.500  -57.723  55.245  1
548360  91.543  -57.733  55.251  1
548361  91.587  -57.744  55.253  1
548362  91.631  -57.754  55.254  1
548363  91.675  -57.764  55.251  1
548364  91.719  -57.775  55.244  1
548365  91.763  -57.786  55.233  1
548366  91.806  -57.796  55.223  1
548367  91.850  -57.807  55.214  1
548368  91.894  -57.817  55.203  1
548369  91.938  -57.827  55.188  1
548370  91.982  -57.838  55.169  1
548371  92.025  -57.849  55.146  1
548372  92.064  -57.864  55.119  1
548373  92.095  -57.886  55.096  1
548374  92.126  -57.908  55.074  1
548375  92.156  -57.930  55.054  1
548376  92.197  -57.944  55.035  1
548377  92.238  -57.959  55.016  1
548378  92.280  -57.974  54.997  1
548379  92.321  -57.988  54.980  1
548380  92.362  -58.003  54.970  1
548381  92.397  -58.017  54.965  1
548382  92.420  -58.032  54.952  1
548383  92.442  -58.048  54.933  1
548384  92.465  -58.063  54.912  1
548385  92.489  -58.078  54.897  1
548386  92.512  -58.094  54.888  1
548387  92.535  -58.109  54.883  1
548388  92.558  -58.125  54.878  1
548389  92.592  -58.137  54.867  1
548390  92.629  -58.143  54.855  1
548391  92.665  -58.150  54.840  1
548392  92.702  -58.156  54.823  1
548393  92.738  -58.162  54.806  1
548394  92.775  -58.169  54.785  1
548395  92.811  -58.175  54.764  1
548396  92.848  -58.181  54.741  1
548397  92.884  -58.188  54.718  1
548398  92.921  -58.194  54.698  1
548399  92.957  -58.203  54.689  1
548400  92.994  -58.212  54.682  1
548401  93.030  -58.223  54.675  1
548402  93.067  -58.234  54.668  1
548403  93.103  -58.244  54.664  1
548404  93.140  -58.254  54.662  1
548405  93.177  -58.264  54.662  1
548406  93.213  -58.275  54.662  1
548407  93.250  -58.285  54.662  1
548408  93.286  -58.295  54.663  1
548409  93.323  -58.306  54.665  1
548410  93.359  -58.316  54.666  1
548411  93.396  -58.326  54.666  1
548412  93.434  -58.336  54.666  1
548413  93.472  -58.346  54.663  1
548414  93.510  -58.355  54.656  1
548415  93.548  -58.365  54.648  1
548416  93.584  -58.377  54.639  1
548417  93.620  -58.390  54.627  1
548418  93.654  -58.401  54.616  1
548419  93.689  -58.413  54.605  1
548420  93.723  -58.424  54.594  1
548421  93.757  -58.435  54.581  1
548422  93.792  -58.446  54.569  1
548423  93.826  -58.457  54.556  1
548424  93.860  -58.469  54.543  1
548425  93.895  -58.479  54.529  1
548426  93.929  -58.491  54.514  1
548427  93.963  -58.502  54.503  1
548428  93.997  -58.513  54.493  1
548429  94.032  -58.525  54.486  1
548430  94.066  -58.535  54.483  1
548431  94.101  -58.547  54.480  1
548432  94.135  -58.558  54.472  1
548433  94.169  -58.570  54.454  1
548434  94.203  -58.580  54.430  1
548435  94.238  -58.592  54.398  1
548436  94.272  -58.603  54.363  1
548437  94.306  -58.614  54.328  1
548438  94.340  -58.626  54.299  1
548439  94.375  -58.636  54.277  1
548440  94.409  -58.648  54.252  1
548441  94.443  -58.659  54.224  1
548442  94.474  -58.673  54.193  1
548443  94.504  -58.686  54.163  1
548444  94.535  -58.699  54.137  1
548445  94.566  -58.712  54.108  1
548446  94.597  -58.726  54.081  1
548447  94.639  -58.736  54.060  1
548448  94.682  -58.747  54.044  1
548449  94.724  -58.758  54.029  1
548450  94.767  -58.768  54.008  1
548451  94.810  -58.780  53.984  1
548452  94.852  -58.790  53.956  1
548453  94.895  -58.801  53.923  1
548454  94.937  -58.811  53.887  1
548455  94.980  -58.822  53.855  1
548456  95.023  -58.833  53.827  1
548457  95.065  -58.844  53.802  1
548458  95.110  -58.855  53.775  1
548459  95.157  -58.867  53.747  1
548460  95.203  -58.880  53.721  1
548461  95.250  -58.892  53.693  1
548462  95.297  -58.905  53.668  1
548463  95.344  -58.918  53.643  1
548464  95.383  -58.931  53.618  1
548465  95.415  -58.946  53.594  1
548466  95.448  -58.961  53.569  1
548467  95.480  -58.974  53.546  1
548468  95.510  -58.983  53.524  1
548469  95.540  -58.992  53.500  1
548470  95.569  -59.000  53.475  1
548471  95.599  -59.009  53.452  1
548472  95.628  -59.017  53.426  1
548473  95.657  -59.024  53.399  1
548474  95.685  -59.032  53.373  1
548475  95.713  -59.040  53.346  1
548476  95.742  -59.047  53.316  1
548477  95.770  -59.055  53.287  1
548478  95.799  -59.062  53.258  1
548479  95.827  -59.070  53.231  1
548480  95.862  -59.076  53.203  1
548481  95.897  -59.082  53.175  1
548482  95.932  -59.088  53.152  1
548483  95.967  -59.094  53.133  1
548484  96.003  -59.100  53.117  1
548485  96.035  -59.106  53.104  1
548486  96.065  -59.113  53.090  1
548487  96.096  -59.121  53.075  1
548488  96.129  -59.127  53.060  1
548489  96.164  -59.134  53.042  1
548490  96.198  -59.140  53.021  1
548491  96.234  -59.146  53.001  1
548492  96.268  -59.153  52.980  1
548493  96.302  -59.159  52.953  1
548494  96.335  -59.165  52.927  1
548495  96.368  -59.172  52.904  1
548496  96.401  -59.179  52.881  1
548497  96.434  -59.186  52.858  1
548498  96.467  -59.193  52.835  1
548499  96.499  -59.196  52.814  1
548500  96.529  -59.198  52.794  1
548501  96.560  -59.200  52.769  1
548502  96.591  -59.203  52.744  1
548503  96.621  -59.205  52.716  1
548504  96.653  -59.207  52.679  1
548505  96.683  -59.204  52.640  1
548506  96.713  -59.202  52.604  1
548507  96.743  -59.200  52.563  1
548508  96.774  -59.196  52.521  1
548509  96.807  -59.197  52.479  1
548510  96.840  -59.198  52.440  1
548511  96.874  -59.199  52.403  1
548512  96.908  -59.200  52.369  1
548513  96.942  -59.201  52.334  1
548514  96.975  -59.202  52.299  1
548515  97.009  -59.203  52.266  1
548516  97.046  -59.206  52.231  1
548517  97.084  -59.209  52.190  1
548518  97.121  -59.212  52.144  1
548519  97.155  -59.215  52.095  1
548520  97.188  -59.218  52.044  1
548521  97.221  -59.221  51.991  1
548522  97.254  -59.224  51.941  1
548523  97.290  -59.227  51.890  1
548524  97.324  -59.229  51.838  1
548525  97.359  -59.232  51.785  1
548526  97.392  -59.236  51.731  1
548527  97.426  -59.240  51.677  1
548528  97.459  -59.244  51.627  1
548529  97.490  -59.249  51.577  1
548530  97.521  -59.253  51.528  1
548531  97.551  -59.258  51.480  1
548532  97.583  -59.263  51.436  1
548533  97.613  -59.268  51.396  1
548534  97.645  -59.272  51.357  1
548535  97.677  -59.277  51.315  1
548536  97.710  -59.283  51.273  1
548537  97.750  -59.294  51.232  1
548538  97.790  -59.305  51.193  1
548539  97.830  -59.313  51.158  1
548540  97.872  -59.316  51.125  1
548541  97.915  -59.320  51.088  1
548542  97.956  -59.323  51.048  1
548543  97.998  -59.326  51.010  1
548544  98.040  -59.330  50.970  1
548545  98.082  -59.333  50.933  1
548546  98.124  -59.336  50.895  1
548547  98.166  -59.340  50.858  1
548548  98.205  -59.339  50.822  1
548549  98.235  -59.327  50.785  1
548550  98.265  -59.315  50.745  1
548551  98.295  -59.303  50.709  1
548552  98.325  -59.292  50.671  1
548553  98.360  -59.281  50.631  1
548554  98.396  -59.272  50.590  1
548555  98.433  -59.262  50.550  1
548556  98.469  -59.252  50.513  1
548557  98.506  -59.242  50.477  1
548558  98.543  -59.231  50.442  1
548559  98.577  -59.221  50.407  1
548560  98.613  -59.215  50.373  1
548561  98.648  -59.211  50.339  1
548562  98.684  -59.206  50.305  1
548563  98.719  -59.201  50.271  1
548564  98.756  -59.196  50.238  1
548565  98.791  -59.191  50.205  1
548566  98.827  -59.186  50.171  1
548567  98.863  -59.181  50.132  1
548568  98.899  -59.176  50.094  1
548569  98.939  -59.178  50.055  1
548570  98.997  -59.218  50.013  1
548571  99.026  -59.222  49.969  1
548572  99.055  -59.225  49.927  1
548573  99.083  -59.229  49.889  1
548574  99.112  -59.234  49.852  1
548575  99.141  -59.237  49.817  1
548576  99.169  -59.241  49.781  1
548577  99.198  -59.245  49.746  1
548578  99.268  -59.240  49.713  1
548579  99.340  -59.234  49.681  1
548580  99.412  -59.228  49.647  1
548581  99.472  -59.227  49.614  1
548929  86.392  -55.839  57.667  4
548930  86.433  -55.853  57.660  4
548931  86.474  -55.865  57.651  4
548932  86.514  -55.879  57.641  4
548933  86.554  -55.893  57.630  4
548934  86.595  -55.906  57.620  4
548935  86.635  -55.919  57.608  4
548936  86.675  -55.932  57.597  4
548937  86.716  -55.946  57.583  4
548938  86.756  -55.959  57.569  4
548939  86.797  -55.972  57.554  4
548940  86.837  -55.986  57.537  4
548941  86.877  -55.999  57.510  4
548942  86.918  -56.013  57.481  4
548943  86.958  -56.026  57.450  4
548944  86.999  -56.039  57.417  4
548945  87.039  -56.053  57.384  4
548946  87.079  -56.066  57.349  4
548947  87.120  -56.079  57.313  4
548948  87.160  -56.093  57.278  4
548949  87.201  -56.106  57.241  4
548950  87.241  -56.119  57.202  4
548951  87.281  -56.132  57.165  4
548952  87.322  -56.146  57.127  4
548953  87.362  -56.160  57.092  4
548954  87.403  -56.172  57.057  4
548955  87.443  -56.186  57.021  4
549014  89.736  -57.000  55.892  1
549015  89.777  -57.012  55.881  1
549016  89.818  -57.022  55.869  1
549017  89.860  -57.033  55.859  1
549018  89.901  -57.044  55.847  1
549019  89.943  -57.055  55.833  1
549020  89.984  -57.065  55.819  1
549021  90.025  -57.076  55.803  1
549022  90.056  -57.091  55.786  1
549023  90.083  -57.108  55.770  1
549024  90.120  -57.122  55.752  1
549025  90.157  -57.137  55.732  1
549026  90.194  -57.151  55.710  1
549027  90.231  -57.166  55.687  1
549028  90.268  -57.180  55.663  1
549029  90.304  -57.195  55.640  1
549030  90.338  -57.212  55.615  1
549031  90.373  -57.226  55.589  1
549032  90.408  -57.239  55.561  1
549033  90.445  -57.256  55.534  1
549034  90.482  -57.272  55.506  1
549035  90.520  -57.288  55.479  1
549036  90.557  -57.304  55.454  1
549037  90.595  -57.321  55.430  1
549038  90.633  -57.338  55.406  1
549039  90.670  -57.354  55.386  1
549040  90.707  -57.370  55.365  1
549041  90.744  -57.387  55.348  1
549042  90.782  -57.403  55.331  1
549043  90.819  -57.420  55.316  1
549044  90.857  -57.435  55.303  1
549045  90.894  -57.452  55.290  1
549046  90.932  -57.469  55.277  1
549047  90.969  -57.485  55.267  1
549048  91.011  -57.495  55.257  1
549049  91.056  -57.502  55.248  1
549050  91.101  -57.508  55.239  1
549051  91.146  -57.515  55.233  1
549052  91.187  -57.532  55.228  1
549053  91.227  -57.557  55.225  1
549054  91.266  -57.580  55.224  1
549055  91.306  -57.604  55.227  1
549056  91.346  -57.627  55.232  1
549057  91.385  -57.651  55.234  1
549058  91.429  -57.663  55.233  1
549059  91.472  -57.673  55.232  1
549060  91.516  -57.683  55.234  1
549061  91.560  -57.694  55.235  1
549062  91.604  -57.705  55.236  1
549063  91.648  -57.715  55.236  1
549064  91.692  -57.726  55.233  1
549065  91.735  -57.736  55.227  1
549066  91.779  -57.746  55.220  1
549067  91.823  -57.757  55.218  1
549068  91.867  -57.767  55.214  1
549069  91.911  -57.778  55.208  1
549070  91.954  -57.789  55.198  1
549071  91.998  -57.799  55.185  1
549072  92.042  -57.809  55.167  1
549073  92.085  -57.821  55.148  1
549074  92.115  -57.843  55.128  1
549075  92.146  -57.865  55.107  1
549076  92.179  -57.886  55.089  1
549077  92.221  -57.900  55.073  1
549078  92.262  -57.915  55.054  1
549079  92.303  -57.929  55.035  1
549080  92.345  -57.943  55.016  1
549081  92.374  -57.959  55.001  1
549082  92.398  -57.974  54.991  1
549083  92.421  -57.989  54.983  1
549084  92.444  -58.005  54.964  1
549085  92.467  -58.020  54.942  1
549086  92.490  -58.035  54.926  1
549087  92.516  -58.053  54.916  1
549088  92.546  -58.074  54.912  1
549089  92.576  -58.094  54.904  1
549090  92.612  -58.103  54.893  1
549091  92.648  -58.109  54.881  1
549092  92.685  -58.115  54.866  1
549093  92.721  -58.122  54.847  1
549094  92.758  -58.128  54.827  1
549095  92.795  -58.134  54.802  1
549096  92.831  -58.141  54.778  1
549097  92.868  -58.147  54.754  1
549098  92.904  -58.154  54.730  1
549099  92.941  -58.160  54.710  1
549100  92.977  -58.170  54.695  1
549101  93.014  -58.180  54.687  1
549102  93.050  -58.191  54.678  1
549103  93.087  -58.201  54.670  1
549104  93.124  -58.211  54.664  1
549105  93.160  -58.222  54.662  1
549106  93.197  -58.232  54.664  1
549107  93.233  -58.242  54.666  1
549108  93.270  -58.253  54.668  1
549109  93.306  -58.263  54.670  1
549110  93.343  -58.273  54.671  1
549111  93.379  -58.284  54.670  1
549112  93.416  -58.294  54.668  1
549113  93.452  -58.304  54.667  1
549114  93.488  -58.313  54.666  1
549115  93.522  -58.322  54.666  1
549116  93.556  -58.330  54.664  1
549117  93.591  -58.347  54.657  1
549118  93.622  -58.358  54.647  1
549119  93.656  -58.369  54.636  1
549120  93.690  -58.380  54.627  1
549121  93.724  -58.391  54.619  1
549122  93.759  -58.403  54.608  1
549123  93.793  -58.414  54.593  1
549124  93.828  -58.425  54.576  1
549125  93.862  -58.436  54.557  1
549126  93.896  -58.448  54.536  1
549127  93.930  -58.459  54.517  1
549128  93.965  -58.470  54.502  1
549129  93.999  -58.481  54.493  1
549130  94.034  -58.492  54.483  1
549131  94.068  -58.504  54.473  1
549132  94.102  -58.515  54.465  1
549133  94.136  -58.526  54.460  1
549134  94.171  -58.537  54.445  1
549135  94.205  -58.548  54.422  1
549136  94.239  -58.560  54.393  1
549137  94.273  -58.571  54.360  1
549138  94.308  -58.582  54.324  1
549139  94.342  -58.593  54.295  1
549140  94.377  -58.604  54.273  1
549141  94.411  -58.616  54.250  1
549142  94.443  -58.628  54.224  1
549143  94.474  -58.641  54.192  1
549144  94.505  -58.654  54.155  1
549145  94.536  -58.667  54.126  1
549146  94.566  -58.680  54.096  1
549147  94.597  -58.694  54.067  1
549148  94.636  -58.705  54.044  1
549149  94.679  -58.716  54.026  1
549150  94.721  -58.727  54.013  1
549151  94.764  -58.738  53.995  1
549152  94.806  -58.748  53.974  1
549153  94.849  -58.759  53.949  1
549154  94.891  -58.770  53.919  1
549155  94.934  -58.781  53.885  1
549156  94.976  -58.792  53.854  1
549157  95.019  -58.802  53.824  1
549158  95.062  -58.814  53.797  1
549159  95.109  -58.826  53.771  1
549160  95.156  -58.838  53.743  1
549161  95.203  -58.851  53.715  1
549162  95.250  -58.863  53.691  1
549163  95.297  -58.875  53.666  1
549164  95.344  -58.888  53.642  1
549165  95.389  -58.900  53.618  1
549166  95.421  -58.915  53.593  1
549167  95.454  -58.930  53.569  1
549168  95.484  -58.940  53.543  1
549169  95.514  -58.949  53.520  1
549170  95.544  -58.958  53.497  1
549171  95.574  -58.968  53.471  1
549172  95.604  -58.977  53.446  1
549173  95.633  -58.985  53.419  1
549174  95.662  -58.993  53.392  1
549175  95.690  -59.000  53.367  1
549176  95.719  -59.008  53.341  1
549177  95.747  -59.015  53.309  1
549178  95.776  -59.023  53.280  1
549179  95.805  -59.030  53.251  1
549180  95.833  -59.038  53.225  1
549181  95.868  -59.044  53.196  1
549182  95.903  -59.050  53.164  1
549183  95.938  -59.055  53.136  1
549184  95.973  -59.062  53.116  1
549185  96.008  -59.068  53.097  1
549186  96.038  -59.074  53.082  1
549187  96.068  -59.082  53.069  1
549188  96.099  -59.089  53.052  1
549189  96.132  -59.095  53.036  1
549190  96.167  -59.102  53.015  1
549191  96.202  -59.108  52.991  1
549192  96.237  -59.114  52.971  1
549193  96.272  -59.121  52.952  1
549194  96.306  -59.127  52.927  1
549195  96.339  -59.134  52.900  1
549196  96.373  -59.140  52.874  1
549197  96.406  -59.147  52.850  1
549198  96.439  -59.154  52.827  1
549199  96.472  -59.160  52.803  1
549200  96.503  -59.162  52.780  1
549201  96.533  -59.165  52.760  1
549202  96.564  -59.167  52.734  1
549203  96.595  -59.169  52.708  1
549204  96.626  -59.171  52.679  1
549205  96.657  -59.174  52.644  1
549206  96.687  -59.175  52.609  1
549207  96.718  -59.172  52.575  1
549208  96.748  -59.170  52.535  1
549209  96.779  -59.168  52.493  1
549210  96.812  -59.168  52.451  1
549211  96.846  -59.169  52.411  1
549212  96.879  -59.170  52.372  1
549213  96.913  -59.171  52.337  1
549214  96.947  -59.172  52.302  1
549215  96.980  -59.173  52.267  1
549216  97.014  -59.174  52.234  1
549217  97.049  -59.176  52.199  1
549218  97.087  -59.179  52.158  1
549219  97.123  -59.182  52.114  1
549220  97.157  -59.185  52.067  1
549221  97.190  -59.188  52.017  1
549222  97.224  -59.191  51.967  1
549223  97.258  -59.193  51.916  1
549224  97.293  -59.196  51.865  1
549225  97.328  -59.199  51.814  1
549226  97.363  -59.202  51.763  1
549227  97.396  -59.206  51.711  1
549228  97.429  -59.210  51.659  1
549229  97.462  -59.214  51.611  1
549230  97.495  -59.218  51.562  1
549231  97.526  -59.223  51.513  1
549232  97.557  -59.228  51.465  1
549233  97.588  -59.233  51.419  1
549234  97.618  -59.237  51.378  1
549235  97.649  -59.242  51.342  1
549236  97.680  -59.247  51.303  1
549237  97.712  -59.251  51.263  1
549238  97.747  -59.259  51.222  1
549239  97.787  -59.269  51.182  1
549240  97.828  -59.275  51.144  1
549241  97.870  -59.278  51.108  1
549242  97.912  -59.282  51.069  1
549243  97.954  -59.285  51.028  1
549244  97.996  -59.289  50.987  1
549245  98.037  -59.292  50.946  1
549246  98.080  -59.295  50.909  1
549247  98.122  -59.298  50.874  1
549248  98.164  -59.300  50.838  1
549249  98.205  -59.303  50.802  1
549250  98.235  -59.294  50.767  1
549251  98.266  -59.282  50.731  1
549252  98.296  -59.271  50.698  1
549253  98.326  -59.259  50.662  1
549254  98.360  -59.249  50.625  1
549255  98.397  -59.239  50.585  1
549256  98.433  -59.229  50.546  1
549257  98.470  -59.219  50.511  1
549258  98.507  -59.209  50.476  1
549259  98.541  -59.198  50.442  1
549260  98.575  -59.187  50.408  1
549261  98.608  -59.177  50.376  1
549262  98.643  -59.169  50.341  1
549263  98.678  -59.165  50.306  1
549264  98.714  -59.159  50.273  1
549265  98.749  -59.155  50.240  1
549266  98.785  -59.150  50.206  1
549267  98.820  -59.145  50.171  1
549268  98.856  -59.140  50.135  1
549269  98.891  -59.135  50.099  1
549270  98.927  -59.131  50.059  1
549271  98.987  -59.171  50.017  1
549272  99.024  -59.184  49.975  1
549273  99.053  -59.188  49.933  1
549274  99.082  -59.192  49.895  1
549275  99.111  -59.196  49.859  1
549276  99.139  -59.200  49.823  1
549277  99.168  -59.204  49.788  1
549278  99.204  -59.206  49.754  1
549279  99.275  -59.200  49.721  1
549280  99.347  -59.195  49.689  1
549281  99.419  -59.189  49.657  1
549282  99.473  -59.190  49.624  1
549630  86.410  -55.796  57.668  4
549631  86.450  -55.809  57.662  4
549632  86.490  -55.822  57.653  4
549633  86.531  -55.836  57.643  4
549634  86.571  -55.849  57.634  4
549635  86.612  -55.862  57.624  4
549636  86.652  -55.876  57.613  4
549637  86.692  -55.889  57.602  4
549638  86.733  -55.903  57.589  4
549639  86.773  -55.915  57.576  4
549640  86.813  -55.929  57.561  4
549641  86.854  -55.943  57.544  4
549642  86.895  -55.956  57.523  4
549643  86.935  -55.969  57.494  4
549644  86.975  -55.982  57.464  4
549645  87.015  -55.996  57.432  4
549646  87.056  -56.009  57.400  4
549647  87.096  -56.022  57.366  4
549648  87.137  -56.036  57.331  4
549649  87.177  -56.049  57.296  4
549650  87.217  -56.063  57.259  4
549651  87.258  -56.076  57.221  4
549652  87.298  -56.089  57.183  4
549653  87.339  -56.103  57.146  4
549654  87.379  -56.116  57.109  4
549655  87.419  -56.129  57.073  4
549656  87.460  -56.143  57.037  4
549657  87.500  -56.156  57.000  4
549715  89.755  -56.961  55.896  1
549716  89.797  -56.971  55.888  1
549717  89.838  -56.982  55.878  1
549718  89.879  -56.993  55.867  1
549719  89.920  -57.004  55.854  1
549720  89.962  -57.015  55.841  1
549721  90.004  -57.026  55.826  1
549722  90.038  -57.040  55.810  1
549723  90.063  -57.056  55.792  1
549724  90.094  -57.072  55.776  1
549725  90.131  -57.087  55.757  1
549726  90.168  -57.101  55.737  1
549727  90.205  -57.116  55.715  1
549728  90.243  -57.130  55.691  1
549729  90.280  -57.144  55.667  1
549730  90.317  -57.159  55.647  1
549731  90.353  -57.174  55.623  1
549732  90.387  -57.188  55.595  1
549733  90.425  -57.204  55.565  1
549734  90.462  -57.221  55.534  1
549735  90.500  -57.237  55.504  1
549736  90.537  -57.254  55.477  1
549737  90.575  -57.270  55.451  1
549738  90.612  -57.286  55.427  1
549739  90.649  -57.303  55.403  1
549740  90.686  -57.319  55.382  1
549741  90.724  -57.335  55.362  1
549742  90.761  -57.352  55.344  1
549743  90.799  -57.368  55.329  1
549744  90.836  -57.385  55.314  1
549745  90.874  -57.401  55.301  1
549746  90.911  -57.417  55.289  1
549747  90.949  -57.434  55.278  1
549748  90.986  -57.450  55.269  1
549749  91.025  -57.464  55.260  1
549750  91.071  -57.470  55.250  1
549751  91.115  -57.477  55.243  1
549752  91.160  -57.483  55.237  1
549753  91.202  -57.503  55.233  1
549754  91.241  -57.526  55.229  1
549755  91.281  -57.550  55.228  1
549756  91.320  -57.573  55.230  1
549757  91.360  -57.598  55.235  1
549758  91.402  -57.613  55.238  1
549759  91.446  -57.623  55.238  1
549760  91.490  -57.634  55.239  1
549761  91.533  -57.645  55.243  1
549762  91.577  -57.655  55.244  1
549763  91.621  -57.665  55.244  1
549764  91.665  -57.676  55.243  1
549765  91.709  -57.686  55.241  1
549766  91.752  -57.697  55.239  1
549767  91.796  -57.708  55.237  1
549768  91.840  -57.717  55.237  1
549769  91.884  -57.728  55.234  1
549770  91.928  -57.739  55.228  1
549771  91.971  -57.749  55.220  1
549772  92.015  -57.760  55.210  1
549773  92.059  -57.771  55.199  1
549774  92.103  -57.781  55.184  1
549775  92.136  -57.801  55.163  1
549776  92.166  -57.824  55.142  1
549777  92.203  -57.841  55.125  1
549778  92.244  -57.855  55.113  1
549779  92.286  -57.870  55.093  1
549780  92.327  -57.884  55.074  1
549781  92.353  -57.899  55.053  1
549782  92.376  -57.915  55.032  1
549783  92.399  -57.930  55.016  1
549784  92.422  -57.946  55.008  1
549785  92.445  -57.961  54.990  1
549786  92.474  -57.981  54.972  1
549787  92.504  -58.002  54.955  1
549788  92.533  -58.023  54.941  1
549789  92.563  -58.043  54.931  1
549790  92.596  -58.059  54.919  1
549791  92.632  -58.069  54.903  1
549792  92.668  -58.075  54.887  1
549793  92.705  -58.081  54.870  1
549794  92.741  -58.087  54.851  1
549795  92.778  -58.093  54.830  1
549796  92.814  -58.100  54.806  1
549797  92.851  -58.106  54.786  1
549798  92.887  -58.113  54.769  1
549799  92.924  -58.119  54.753  1
549800  92.960  -58.127  54.736  1
549801  92.997  -58.137  54.714  1
549802  93.034  -58.147  54.695  1
549803  93.070  -58.158  54.682  1
549804  93.107  -58.169  54.674  1
549805  93.143  -58.178  54.669  1
549806  93.180  -58.189  54.669  1
549807  93.216  -58.200  54.675  1
549808  93.253  -58.209  54.680  1
549809  93.289  -58.219  54.686  1
549810  93.324  -58.228  54.688  1
549811  93.358  -58.236  54.686  1
549812  93.393  -58.244  54.682  1
549813  93.427  -58.253  54.678  1
549814  93.462  -58.261  54.675  1
549815  93.496  -58.269  54.675  1
549816  93.531  -58.278  54.677  1
549817  93.565  -58.286  54.679  1
549818  93.603  -58.306  54.674  1
549819  93.639  -58.325  54.667  1
549820  93.666  -58.336  54.660  1
549821  93.693  -58.348  54.654  1
549822  93.726  -58.360  54.649  1
549823  93.761  -58.370  54.639  1
549824  93.795  -58.382  54.625  1
549825  93.829  -58.393  54.605  1
549826  93.863  -58.404  54.582  1
549827  93.898  -58.416  54.558  1
549828  93.932  -58.426  54.534  1
549829  93.966  -58.438  54.511  1
549830  94.001  -58.449  54.494  1
549831  94.035  -58.460  54.480  1
549832  94.069  -58.471  54.466  1
549833  94.104  -58.482  54.451  1
549834  94.138  -58.494  54.440  1
549835  94.172  -58.505  54.428  1
549836  94.206  -58.516  54.408  1
549837  94.241  -58.527  54.381  1
549838  94.275  -58.538  54.350  1
549839  94.310  -58.550  54.316  1
549840  94.344  -58.561  54.286  1
549841  94.378  -58.573  54.261  1
549842  94.412  -58.583  54.241  1
549843  94.445  -58.596  54.218  1
549844  94.475  -58.609  54.189  1
549845  94.506  -58.623  54.153  1
549846  94.537  -58.636  54.116  1
549847  94.567  -58.649  54.081  1
549848  94.598  -58.662  54.051  1
549849  94.632  -58.675  54.025  1
549850  94.675  -58.686  54.004  1
549851  94.717  -58.696  53.992  1
549852  94.760  -58.707  53.977  1
549853  94.803  -58.717  53.959  1
549854  94.845  -58.729  53.937  1
549855  94.888  -58.739  53.910  1
549856  94.930  -58.750  53.881  1
549857  94.973  -58.761  53.851  1
549858  95.016  -58.771  53.820  1
549859  95.062  -58.784  53.790  1
549860  95.109  -58.796  53.763  1
549861  95.156  -58.808  53.737  1
549862  95.203  -58.821  53.708  1
549863  95.250  -58.833  53.686  1
549864  95.297  -58.846  53.664  1
549865  95.343  -58.858  53.640  1
549866  95.390  -58.871  53.617  1
549867  95.427  -58.885  53.589  1
549868  95.459  -58.899  53.564  1
549869  95.489  -58.908  53.538  1
549870  95.519  -58.917  53.513  1
549871  95.549  -58.925  53.487  1
549872  95.579  -58.934  53.462  1
549873  95.608  -58.943  53.436  1
549874  95.638  -58.952  53.409  1
549875  95.668  -58.961  53.382  1
549876  95.696  -58.968  53.357  1
549877  95.725  -58.976  53.332  1
549878  95.753  -58.983  53.301  1
549879  95.781  -58.990  53.272  1
549880  95.810  -58.998  53.242  1
549881  95.838  -59.005  53.211  1
549882  95.874  -59.012  53.180  1
549883  95.909  -59.018  53.149  1
549884  95.944  -59.024  53.119  1
549885  95.979  -59.030  53.097  1
549886  96.011  -59.037  53.077  1
549887  96.041  -59.043  53.061  1
549888  96.072  -59.050  53.046  1
549889  96.102  -59.057  53.029  1
549890  96.136  -59.064  53.011  1
549891  96.171  -59.070  52.992  1
549892  96.206  -59.076  52.967  1
549893  96.241  -59.082  52.943  1
549894  96.276  -59.089  52.922  1
549895  96.311  -59.095  52.901  1
549896  96.344  -59.102  52.873  1
549897  96.377  -59.109  52.844  1
549898  96.410  -59.115  52.817  1
549899  96.444  -59.122  52.793  1
549900  96.476  -59.127  52.768  1
549901  96.507  -59.129  52.741  1
549902  96.537  -59.131  52.720  1
549903  96.568  -59.134  52.695  1
549904  96.599  -59.136  52.668  1
549905  96.630  -59.138  52.639  1
549906  96.661  -59.140  52.607  1
549907  96.691  -59.143  52.577  1
549908  96.722  -59.143  52.542  1
549909  96.752  -59.140  52.503  1
549910  96.784  -59.139  52.463  1
549911  96.817  -59.140  52.422  1
549912  96.851  -59.140  52.382  1
549913  96.885  -59.142  52.338  1
549914  96.918  -59.143  52.301  1
549915  96.952  -59.143  52.267  1
549916  96.985  -59.144  52.233  1
549917  97.019  -59.146  52.199  1
549918  97.053  -59.146  52.165  1
549919  97.090  -59.149  52.125  1
549920  97.125  -59.152  52.083  1
549921  97.159  -59.156  52.038  1
549922  97.193  -59.158  51.990  1
549923  97.228  -59.161  51.941  1
549924  97.262  -59.163  51.890  1
549925  97.297  -59.166  51.839  1
549926  97.332  -59.168  51.789  1
549927  97.366  -59.171  51.740  1
549928  97.399  -59.176  51.691  1
549929  97.433  -59.180  51.643  1
549930  97.466  -59.184  51.595  1
549931  97.499  -59.188  51.547  1
549932  97.531  -59.193  51.498  1
549933  97.562  -59.197  51.450  1
549934  97.593  -59.202  51.403  1
549935  97.624  -59.207  51.361  1
549936  97.654  -59.212  51.326  1
549937  97.685  -59.216  51.289  1
549938  97.716  -59.222  51.251  1
549939  97.747  -59.226  51.211  1
549940  97.783  -59.234  51.171  1
549941  97.825  -59.237  51.132  1
549942  97.867  -59.241  51.092  1
549943  97.910  -59.244  51.050  1
549944  97.952  -59.246  51.007  1
549945  97.994  -59.248  50.965  1
549946  98.036  -59.250  50.924  1
549947  98.079  -59.252  50.886  1
549948  98.121  -59.254  50.849  1
549949  98.162  -59.257  50.813  1
549950  98.202  -59.262  50.778  1
549951  98.236  -59.260  50.745  1
549952  98.266  -59.250  50.712  1
549953  98.296  -59.238  50.680  1
549954  98.326  -59.227  50.647  1
549955  98.361  -59.216  50.612  1
549956  98.397  -59.206  50.576  1
549957  98.434  -59.196  50.541  1
549958  98.471  -59.186  50.508  1
549959  98.505  -59.175  50.475  1
549960  98.538  -59.165  50.441  1
549961  98.572  -59.154  50.407  1
549962  98.606  -59.143  50.374  1
549963  98.640  -59.132  50.339  1
549964  98.673  -59.123  50.305  1
549965  98.709  -59.118  50.273  1
549966  98.744  -59.113  50.240  1
549967  98.780  -59.109  50.206  1
549968  98.815  -59.103  50.172  1
549969  98.851  -59.099  50.136  1
549970  98.886  -59.093  50.100  1
549971  98.924  -59.096  50.061  1
549972  98.973  -59.118  50.020  1
549973  99.023  -59.147  49.979  1
549974  99.052  -59.151  49.939  1
549975  99.080  -59.155  49.902  1
549976  99.109  -59.159  49.866  1
549977  99.138  -59.163  49.830  1
549978  99.166  -59.167  49.796  1
549979  99.211  -59.167  49.762  1
549980  99.283  -59.162  49.729  1
549981  99.355  -59.156  49.696  1
549982  99.427  -59.150  49.664  1
549983  99.474  -59.153  49.632  1
550332  86.467  -55.765  57.662  4
550333  86.507  -55.779  57.655  4
550334  86.548  -55.793  57.646  4
550335  86.588  -55.806  57.636  4
550336  86.628  -55.819  57.627  4
550337  86.669  -55.832  57.617  4
550338  86.709  -55.846  57.607  4
550339  86.750  -55.859  57.595  4
550340  86.790  -55.872  57.581  4
550341  86.831  -55.886  57.566  4
550342  86.871  -55.899  57.550  4
550343  86.911  -55.912  57.529  4
550344  86.951  -55.926  57.504  4
550345  86.992  -55.939  57.476  4
550346  87.033  -55.953  57.446  4
550347  87.073  -55.965  57.415  4
550348  87.113  -55.979  57.382  4
550349  87.153  -55.993  57.349  4
550350  87.194  -56.006  57.314  4
550351  87.234  -56.019  57.278  4
550352  87.275  -56.033  57.240  4
550353  87.315  -56.046  57.202  4
550354  87.355  -56.059  57.165  4
550355  87.396  -56.072  57.128  4
550356  87.436  -56.086  57.090  4
550357  87.477  -56.100  57.053  4
550358  87.517  -56.113  57.015  4
550359  87.564  -56.122  56.978  4
550416  89.774  -56.921  55.902  1
550417  89.816  -56.932  55.896  1
550418  89.858  -56.943  55.888  1
550419  89.899  -56.953  55.878  1
550420  89.940  -56.965  55.866  1
550421  89.981  -56.975  55.853  1
550422  90.019  -56.987  55.838  1
550423  90.045  -57.005  55.822  1
550424  90.071  -57.022  55.803  1
550425  90.105  -57.037  55.786  1
550426  90.143  -57.051  55.766  1
550427  90.180  -57.065  55.745  1
550428  90.217  -57.080  55.723  1
550429  90.254  -57.094  55.699  1
550430  90.291  -57.109  55.677  1
550431  90.328  -57.122  55.659  1
550432  90.366  -57.137  55.636  1
550433  90.404  -57.153  55.607  1
550434  90.442  -57.169  55.572  1
550435  90.479  -57.186  55.536  1
550436  90.516  -57.202  55.504  1
550437  90.554  -57.219  55.475  1
550438  90.591  -57.235  55.449  1
550439  90.628  -57.251  55.424  1
550440  90.666  -57.268  55.401  1
550441  90.704  -57.285  55.379  1
550442  90.741  -57.300  55.359  1
550443  90.779  -57.317  55.342  1
550444  90.816  -57.334  55.327  1
550445  90.853  -57.350  55.313  1
550446  90.891  -57.366  55.300  1
550447  90.928  -57.382  55.288  1
550448  90.965  -57.399  55.279  1
550449  91.003  -57.416  55.271  1
550450  91.040  -57.432  55.263  1
550451  91.085  -57.439  55.255  1
550452  91.130  -57.445  55.251  1
550453  91.175  -57.452  55.246  1
550454  91.215  -57.473  55.242  1
550455  91.255  -57.496  55.239  1
550456  91.295  -57.520  55.238  1
550457  91.334  -57.544  55.238  1
550458  91.375  -57.564  55.240  1
550459  91.419  -57.573  55.243  1
550460  91.463  -57.584  55.248  1
550461  91.507  -57.595  55.253  1
550462  91.551  -57.605  55.259  1
550463  91.594  -57.616  55.260  1
550464  91.638  -57.626  55.257  1
550465  91.682  -57.636  55.253  1
550466  91.726  -57.647  55.249  1
550467  91.770  -57.658  55.247  1
550468  91.813  -57.668  55.245  1
550469  91.857  -57.679  55.245  1
550470  91.901  -57.689  55.242  1
550471  91.945  -57.700  55.237  1
550472  91.989  -57.710  55.230  1
550473  92.032  -57.720  55.225  1
550474  92.076  -57.731  55.220  1
550475  92.120  -57.742  55.206  1
550476  92.156  -57.759  55.186  1
550477  92.187  -57.781  55.166  1
550478  92.226  -57.796  55.152  1
550479  92.268  -57.811  55.146  1
550480  92.308  -57.825  55.128  1
550481  92.331  -57.841  55.108  1
550482  92.354  -57.856  55.089  1
550483  92.377  -57.871  55.068  1
550484  92.403  -57.889  55.046  1
550485  92.432  -57.909  55.026  1
550486  92.461  -57.930  55.012  1
550487  92.491  -57.951  55.000  1
550488  92.521  -57.972  54.985  1
550489  92.551  -57.993  54.964  1
550490  92.580  -58.014  54.946  1
550491  92.616  -58.025  54.930  1
550492  92.652  -58.036  54.910  1
550493  92.689  -58.042  54.891  1
550494  92.725  -58.048  54.872  1
550495  92.762  -58.054  54.854  1
550496  92.798  -58.060  54.834  1
550497  92.835  -58.066  54.816  1
550498  92.871  -58.072  54.803  1
550499  92.908  -58.078  54.792  1
550500  92.944  -58.085  54.780  1
550501  92.981  -58.094  54.763  1
550502  93.017  -58.105  54.738  1
550503  93.054  -58.115  54.714  1
550504  93.090  -58.125  54.694  1
550505  93.125  -58.134  54.681  1
550506  93.159  -58.142  54.677  1
550507  93.194  -58.150  54.680  1
550508  93.228  -58.159  54.691  1
550509  93.263  -58.167  54.700  1
550510  93.297  -58.175  54.706  1
550511  93.332  -58.184  54.708  1
550512  93.366  -58.192  54.707  1
550513  93.401  -58.200  54.700  1
550514  93.435  -58.209  54.697  1
550515  93.470  -58.217  54.692  1
550516  93.504  -58.225  54.686  1
550517  93.539  -58.234  54.685  1
550518  93.574  -58.244  54.685  1
550519  93.612  -58.264  54.686  1
550520  93.650  -58.284  54.687  1
550521  93.688  -58.303  54.687  1
550522  93.714  -58.314  54.685  1
550523  93.741  -58.326  54.682  1
550524  93.768  -58.338  54.673  1
550525  93.796  -58.350  54.660  1
550526  93.831  -58.361  54.638  1
550527  93.865  -58.372  54.613  1
550528  93.899  -58.383  54.587  1
550529  93.933  -58.394  54.559  1
550530  93.968  -58.406  54.529  1
550531  94.002  -58.417  54.502  1
550532  94.037  -58.428  54.481  1
550533  94.071  -58.439  54.461  1
550534  94.105  -58.451  54.440  1
550535  94.139  -58.462  54.425  1
550536  94.174  -58.473  54.411  1
550537  94.208  -58.484  54.391  1
550538  94.242  -58.495  54.365  1
550539  94.277  -58.507  54.334  1
550540  94.311  -58.518  54.302  1
550541  94.345  -58.529  54.273  1
550542  94.380  -58.540  54.249  1
550543  94.414  -58.551  54.228  1
550544  94.445  -58.564  54.206  1
550545  94.476  -58.577  54.180  1
550546  94.506  -58.591  54.147  1
550547  94.537  -58.604  54.109  1
550548  94.568  -58.617  54.070  1
550549  94.599  -58.630  54.036  1
550550  94.629  -58.644  54.008  1
550551  94.672  -58.654  53.985  1
550552  94.714  -58.665  53.968  1
550553  94.757  -58.676  53.952  1
550554  94.799  -58.687  53.935  1
550555  94.842  -58.698  53.917  1
550556  94.884  -58.708  53.897  1
550557  94.927  -58.719  53.874  1
550558  94.970  -58.730  53.846  1
550559  95.015  -58.742  53.814  1
550560  95.062  -58.754  53.782  1
550561  95.109  -58.767  53.754  1
550562  95.156  -58.779  53.728  1
550563  95.202  -58.791  53.701  1
550564  95.249  -58.804  53.680  1
550565  95.296  -58.816  53.659  1
550566  95.343  -58.828  53.638  1
550567  95.390  -58.841  53.613  1
550568  95.432  -58.854  53.582  1
550569  95.464  -58.865  53.557  1
550570  95.493  -58.874  53.530  1
550571  95.524  -58.883  53.502  1
550572  95.553  -58.892  53.474  1
550573  95.583  -58.902  53.448  1
550574  95.613  -58.910  53.423  1
550575  95.643  -58.919  53.396  1
550576  95.673  -58.928  53.369  1
550577  95.701  -58.936  53.343  1
550578  95.730  -58.943  53.317  1
550579  95.758  -58.951  53.287  1
550580  95.787  -58.958  53.258  1
550581  95.816  -58.966  53.227  1
550582  95.844  -58.974  53.194  1
550583  95.880  -58.980  53.161  1
550584  95.915  -58.986  53.130  1
550585  95.950  -58.991  53.099  1
550586  95.984  -58.998  53.076  1
550587  96.014  -59.005  53.055  1
550588  96.044  -59.012  53.037  1
550589  96.075  -59.018  53.020  1
550590  96.105  -59.025  53.000  1
550591  96.139  -59.032  52.982  1
550592  96.175  -59.038  52.961  1
550593  96.209  -59.044  52.937  1
550594  96.244  -59.051  52.914  1
550595  96.279  -59.057  52.891  1
550596  96.314  -59.063  52.866  1
550597  96.349  -59.070  52.840  1
550598  96.382  -59.077  52.811  1
550599  96.415  -59.084  52.783  1
550600  96.448  -59.090  52.758  1
550601  96.480  -59.093  52.734  1
550602  96.511  -59.096  52.704  1
550603  96.541  -59.098  52.678  1
550604  96.572  -59.100  52.652  1
550605  96.603  -59.102  52.626  1
550606  96.634  -59.105  52.602  1
550607  96.665  -59.107  52.576  1
550608  96.695  -59.109  52.544  1
550609  96.726  -59.112  52.510  1
550610  96.757  -59.111  52.472  1
550611  96.789  -59.110  52.433  1
550612  96.822  -59.111  52.394  1
550613  96.856  -59.112  52.355  1
550614  96.890  -59.113  52.308  1
550615  96.924  -59.114  52.267  1
550616  96.957  -59.115  52.231  1
550617  96.991  -59.115  52.197  1
550618  97.024  -59.117  52.164  1
550619  97.058  -59.118  52.130  1
550620  97.093  -59.119  52.090  1
550621  97.127  -59.122  52.049  1
550622  97.162  -59.125  52.006  1
550623  97.197  -59.128  51.960  1
550624  97.232  -59.131  51.913  1
550625  97.266  -59.133  51.864  1
550626  97.301  -59.135  51.813  1
550627  97.336  -59.138  51.764  1
550628  97.370  -59.142  51.718  1
550629  97.403  -59.146  51.672  1
550630  97.436  -59.150  51.628  1
550631  97.469  -59.154  51.580  1
550632  97.503  -59.158  51.532  1
550633  97.536  -59.162  51.483  1
550634  97.567  -59.167  51.434  1
550635  97.598  -59.171  51.388  1
550636  97.629  -59.176  51.346  1
550637  97.659  -59.181  51.309  1
550638  97.690  -59.186  51.273  1
550639  97.721  -59.190  51.237  1
550640  97.752  -59.196  51.199  1
550641  97.786  -59.198  51.160  1
550642  97.825  -59.196  51.119  1
550643  97.866  -59.197  51.076  1
550644  97.909  -59.200  51.031  1
550645  97.951  -59.202  50.987  1
550646  97.994  -59.204  50.944  1
550647  98.036  -59.206  50.902  1
550648  98.078  -59.208  50.862  1
550649  98.120  -59.211  50.824  1
550650  98.160  -59.215  50.786  1
550651  98.200  -59.220  50.751  1
550652  98.236  -59.222  50.719  1
550653  98.267  -59.217  50.689  1
550654  98.297  -59.206  50.660  1
550655  98.327  -59.194  50.629  1
550656  98.361  -59.184  50.596  1
550657  98.397  -59.174  50.565  1
550658  98.434  -59.164  50.534  1
550659  98.469  -59.153  50.505  1
550660  98.503  -59.142  50.472  1
550661  98.536  -59.131  50.439  1
550662  98.570  -59.121  50.405  1
550663  98.603  -59.110  50.370  1
550664  98.637  -59.099  50.336  1
550665  98.671  -59.088  50.304  1
550666  98.705  -59.077  50.271  1
550667  98.740  -59.072  50.239  1
550668  98.775  -59.067  50.206  1
550669  98.811  -59.062  50.171  1
550670  98.846  -59.057  50.136  1
550671  98.882  -59.054  50.099  1
550672  98.921  -59.062  50.061  1
550673  98.960  -59.068  50.023  1
550674  99.021  -59.110  49.983  1
550675  99.050  -59.114  49.944  1
550676  99.079  -59.118  49.908  1
550677  99.108  -59.122  49.873  1
550678  99.136  -59.126  49.838  1
550679  99.165  -59.130  49.803  1
550680  99.219  -59.128  49.769  1
550681  99.291  -59.122  49.736  1
550682  99.363  -59.116  49.704  1
550683  99.435  -59.110  49.672  1
550684  99.474  -59.116  49.640  1
551033  86.484  -55.722  57.663  4
551034  86.524  -55.736  57.656  4
551035  86.564  -55.749  57.647  4
551036  86.605  -55.762  57.638  4
551037  86.645  -55.776  57.630  4
551038  86.686  -55.789  57.621  4
551039  86.726  -55.803  57.611  4
551040  86.767  -55.816  57.599  4
551041  86.807  -55.829  57.586  4
551042  86.847  -55.843  57.571  4
551043  86.887  -55.856  57.554  4
551044  86.928  -55.869  57.535  4
551045  86.969  -55.883  57.513  4
551046  87.009  -55.896  57.489  4
551047  87.049  -55.909  57.462  4
551048  87.089  -55.922  57.431  4
551049  87.130  -55.936  57.399  4
551050  87.170  -55.950  57.366  4
551051  87.211  -55.962  57.332  4
551052  87.251  -55.976  57.297  4
551053  87.291  -55.989  57.260  4
551054  87.332  -56.003  57.223  4
551055  87.372  -56.016  57.184  4
551056  87.413  -56.029  57.147  4
551057  87.453  -56.043  57.109  4
551058  87.493  -56.056  57.070  4
551059  87.535  -56.069  57.031  4
551060  87.589  -56.073  56.995  4
551061  87.645  -56.077  56.958  4
551101  89.184  -56.652  55.992  1
551102  89.222  -56.668  55.983  1
551103  89.260  -56.684  55.974  1
551104  89.299  -56.700  55.967  1
551116  89.753  -56.871  55.914  1
551117  89.794  -56.881  55.910  1
551118  89.835  -56.893  55.906  1
551119  89.877  -56.903  55.899  1
551120  89.918  -56.914  55.891  1
551121  89.960  -56.924  55.880  1
551122  90.001  -56.936  55.867  1
551123  90.027  -56.953  55.852  1
551124  90.052  -56.970  55.836  1
551125  90.080  -56.987  55.817  1
551126  90.117  -57.001  55.798  1
551127  90.154  -57.015  55.777  1
551128  90.191  -57.030  55.755  1
551129  90.228  -57.044  55.733  1
551130  90.265  -57.058  55.708  1
551131  90.303  -57.072  55.690  1
551132  90.339  -57.087  55.671  1
551133  90.385  -57.103  55.647  1
551134  90.428  -57.119  55.615  1
551135  90.462  -57.135  55.579  1
551136  90.498  -57.151  55.541  1
551137  90.533  -57.168  55.507  1
551138  90.571  -57.184  55.477  1
551139  90.608  -57.200  55.449  1
551140  90.646  -57.217  55.423  1
551141  90.683  -57.233  55.399  1
551142  90.721  -57.250  55.378  1
551143  90.758  -57.266  55.358  1
551144  90.795  -57.282  55.340  1
551145  90.833  -57.299  55.325  1
551146  90.870  -57.315  55.312  1
551147  90.907  -57.332  55.299  1
551148  90.945  -57.348  55.288  1
551149  90.982  -57.364  55.279  1
551150  91.020  -57.381  55.271  1
551151  91.058  -57.397  55.264  1
551152  91.099  -57.407  55.258  1
551153  91.144  -57.414  55.256  1
551154  91.189  -57.420  55.255  1
551155  91.229  -57.443  55.255  1
551156  91.269  -57.467  55.257  1
551157  91.308  -57.490  55.259  1
551158  91.348  -57.514  55.262  1
551159  91.392  -57.524  55.265  1
551160  91.436  -57.535  55.268  1
551161  91.480  -57.545  55.271  1
551162  91.523  -57.555  55.271  1
551163  91.567  -57.566  55.271  1
551164  91.611  -57.576  55.269  1
551165  91.655  -57.587  55.266  1
551166  91.699  -57.598  55.262  1
551167  91.742  -57.608  55.255  1
551168  91.786  -57.619  55.249  1
551169  91.830  -57.629  55.247  1
551170  91.874  -57.639  55.246  1
551171  91.918  -57.650  55.245  1
551172  91.961  -57.661  55.243  1
551173  92.005  -57.671  55.240  1
551174  92.049  -57.682  55.240  1
551175  92.093  -57.692  55.239  1
551176  92.137  -57.702  55.228  1
551177  92.176  -57.717  55.211  1
551178  92.209  -57.738  55.193  1
551179  92.250  -57.752  55.179  1
551180  92.286  -57.767  55.173  1
551181  92.309  -57.782  55.157  1
551182  92.333  -57.798  55.139  1
551183  92.360  -57.817  55.119  1
551184  92.390  -57.838  55.098  1
551185  92.420  -57.858  55.076  1
551186  92.449  -57.880  55.059  1
551187  92.479  -57.900  55.041  1
551188  92.509  -57.921  55.024  1
551189  92.538  -57.942  55.007  1
551190  92.568  -57.963  54.990  1
551191  92.599  -57.981  54.972  1
551192  92.636  -57.991  54.951  1
551193  92.672  -58.002  54.930  1
551194  92.708  -58.009  54.907  1
551195  92.745  -58.015  54.882  1
551196  92.781  -58.021  54.859  1
551197  92.818  -58.027  54.843  1
551198  92.854  -58.033  54.836  1
551199  92.891  -58.039  54.830  1
551200  92.927  -58.045  54.821  1
551201  92.962  -58.050  54.808  1
551202  92.996  -58.057  54.788  1
551203  93.030  -58.065  54.762  1
551204  93.065  -58.074  54.734  1
551205  93.099  -58.081  54.708  1
551206  93.134  -58.090  54.689  1
551207  93.168  -58.098  54.683  1
551208  93.202  -58.106  54.688  1
551209  93.237  -58.115  54.700  1
551210  93.271  -58.123  54.712  1
551211  93.306  -58.131  54.721  1
551212  93.340  -58.140  54.725  1
551213  93.375  -58.148  54.725  1
551214  93.409  -58.156  54.718  1
551215  93.443  -58.165  54.714  1
551216  93.478  -58.173  54.708  1
551217  93.512  -58.181  54.703  1
551218  93.547  -58.189  54.702  1
551219  93.583  -58.201  54.703  1
551220  93.621  -58.221  54.704  1
551221  93.659  -58.241  54.708  1
551222  93.698  -58.261  54.711  1
551223  93.735  -58.281  54.710  1
551224  93.762  -58.292  54.706  1
551225  93.789  -58.304  54.698  1
551226  93.816  -58.316  54.686  1
551227  93.843  -58.328  54.669  1
551228  93.869  -58.340  54.647  1
551229  93.901  -58.351  54.623  1
551230  93.935  -58.363  54.594  1
551231  93.970  -58.373  54.559  1
551232  94.004  -58.385  54.522  1
551233  94.038  -58.396  54.487  1
551234  94.072  -58.407  54.457  1
551235  94.107  -58.418  54.432  1
551236  94.141  -58.429  54.415  1
551237  94.175  -58.441  54.395  1
551238  94.210  -58.452  54.372  1
551239  94.244  -58.463  54.346  1
551240  94.278  -58.474  54.316  1
551241  94.313  -58.485  54.285  1
551242  94.347  -58.497  54.258  1
551243  94.381  -58.508  54.235  1
551244  94.415  -58.520  54.213  1
551245  94.446  -58.532  54.190  1
551246  94.477  -58.546  54.166  1
551247  94.507  -58.559  54.136  1
551248  94.538  -58.573  54.099  1
551249  94.569  -58.585  54.058  1
551250  94.600  -58.598  54.021  1
551251  94.630  -58.612  53.991  1
551252  94.668  -58.623  53.966  1
551253  94.710  -58.635  53.946  1
551254  94.753  -58.645  53.927  1
551255  94.795  -58.656  53.911  1
551256  94.838  -58.667  53.895  1
551257  94.881  -58.677  53.878  1
551258  94.923  -58.689  53.856  1
551259  94.968  -58.700  53.833  1
551260  95.015  -58.712  53.803  1
551261  95.061  -58.724  53.772  1
551262  95.108  -58.737  53.742  1
551263  95.155  -58.749  53.717  1
551264  95.202  -58.761  53.692  1
551265  95.249  -58.774  53.670  1
551266  95.296  -58.786  53.648  1
551267  95.343  -58.799  53.625  1
551268  95.390  -58.811  53.599  1
551269  95.438  -58.823  53.569  1
551270  95.468  -58.833  53.540  1
551271  95.498  -58.841  53.512  1
551272  95.528  -58.850  53.483  1
551273  95.558  -58.859  53.453  1
551274  95.588  -58.868  53.427  1
551275  95.618  -58.877  53.401  1
551276  95.648  -58.886  53.376  1
551277  95.677  -58.895  53.349  1
551278  95.707  -58.904  53.322  1
551279  95.736  -58.911  53.294  1
551280  95.764  -58.919  53.265  1
551281  95.793  -58.927  53.236  1
551282  95.821  -58.934  53.207  1
551283  95.850  -58.941  53.175  1
551284  95.886  -58.947  53.141  1
551285  95.921  -58.953  53.109  1
551286  95.957  -58.959  53.078  1
551287  95.987  -58.966  53.053  1
551288  96.017  -58.973  53.031  1
551289  96.047  -58.980  53.011  1
551290  96.078  -58.987  52.992  1
551291  96.108  -58.994  52.970  1
551292  96.143  -59.000  52.950  1
551293  96.178  -59.006  52.926  1
551294  96.213  -59.012  52.903  1
551295  96.248  -59.019  52.881  1
551296  96.283  -59.025  52.857  1
551297  96.318  -59.031  52.830  1
551298  96.353  -59.038  52.807  1
551299  96.387  -59.045  52.779  1
551300  96.420  -59.051  52.750  1
551301  96.453  -59.058  52.723  1
551302  96.484  -59.060  52.699  1
551303  96.515  -59.062  52.668  1
551304  96.545  -59.065  52.639  1
551305  96.576  -59.067  52.612  1
551306  96.607  -59.069  52.588  1
551307  96.638  -59.071  52.565  1
551308  96.669  -59.074  52.541  1
551309  96.699  -59.077  52.508  1
551310  96.730  -59.079  52.476  1
551311  96.761  -59.081  52.438  1
551312  96.794  -59.081  52.401  1
551313  96.827  -59.082  52.364  1
551314  96.861  -59.084  52.324  1
551315  96.895  -59.084  52.274  1
551316  96.929  -59.085  52.232  1
551317  96.962  -59.086  52.194  1
551318  96.996  -59.087  52.158  1
551319  97.029  -59.087  52.126  1
551320  97.063  -59.088  52.094  1
551321  97.097  -59.089  52.056  1
551322  97.132  -59.092  52.017  1
551323  97.166  -59.095  51.975  1
551324  97.201  -59.097  51.931  1
551325  97.236  -59.099  51.886  1
551326  97.271  -59.102  51.839  1
551327  97.305  -59.105  51.790  1
551328  97.340  -59.108  51.743  1
551329  97.373  -59.112  51.697  1
551330  97.406  -59.115  51.651  1
551331  97.440  -59.120  51.608  1
551332  97.473  -59.124  51.562  1
551333  97.506  -59.128  51.515  1
551334  97.539  -59.132  51.467  1
551335  97.572  -59.137  51.420  1
551336  97.603  -59.141  51.375  1
551337  97.634  -59.146  51.335  1
551338  97.664  -59.150  51.300  1
551339  97.696  -59.156  51.260  1
551340  97.727  -59.160  51.219  1
551341  97.758  -59.165  51.180  1
551342  97.794  -59.165  51.141  1
551343  97.833  -59.164  51.100  1
551344  97.873  -59.162  51.058  1
551345  97.913  -59.161  51.015  1
551346  97.952  -59.159  50.971  1
551347  97.993  -59.160  50.928  1
551348  98.035  -59.162  50.885  1
551349  98.077  -59.165  50.842  1
551350  98.117  -59.169  50.799  1
551351  98.157  -59.174  50.759  1
551352  98.197  -59.179  50.724  1
551353  98.236  -59.183  50.693  1
551354  98.267  -59.178  50.667  1
551355  98.298  -59.173  50.640  1
551356  98.328  -59.162  50.612  1
551357  98.361  -59.151  50.583  1
551358  98.398  -59.141  50.554  1
551359  98.433  -59.131  50.527  1
551360  98.466  -59.119  50.497  1
551361  98.500  -59.109  50.467  1
551362  98.534  -59.098  50.434  1
551363  98.567  -59.087  50.402  1
551364  98.601  -59.076  50.369  1
551365  98.635  -59.065  50.336  1
551366  98.668  -59.055  50.303  1
551367  98.702  -59.044  50.270  1
551368  98.736  -59.033  50.236  1
551369  98.770  -59.026  50.203  1
551370  98.806  -59.021  50.170  1
551371  98.841  -59.016  50.136  1
551372  98.879  -59.020  50.098  1
551373  98.918  -59.027  50.061  1
551374  98.957  -59.034  50.024  1
551375  99.007  -59.057  49.986  1
551376  99.049  -59.077  49.949  1
551377  99.077  -59.081  49.915  1
551378  99.106  -59.085  49.880  1
551379  99.135  -59.089  49.845  1
551380  99.163  -59.093  49.810  1
551381  99.226  -59.089  49.776  1
551382  99.298  -59.083  49.745  1
551383  99.370  -59.077  49.713  1
551384  99.439  -59.072  49.681  1
551385  99.475  -59.080  49.648  1
551386  99.511  -59.087  49.616  1
551734  86.500  -55.679  57.663  4
551735  86.541  -55.693  57.657  4
551736  86.581  -55.705  57.649  4
551737  86.622  -55.719  57.640  4
551738  86.662  -55.733  57.632  4
551739  86.702  -55.746  57.623  4
551740  86.743  -55.759  57.614  4
551741  86.783  -55.772  57.602  4
551742  86.824  -55.786  57.590  4
551743  86.864  -55.799  57.575  4
551744  86.905  -55.812  57.559  4
551745  86.945  -55.826  57.541  4
551746  86.985  -55.839  57.522  4
551747  87.025  -55.853  57.501  4
551748  87.066  -55.866  57.477  4
551749  87.107  -55.879  57.446  4
551750  87.147  -55.893  57.415  4
551751  87.187  -55.906  57.383  4
551752  87.227  -55.919  57.350  4
551753  87.268  -55.933  57.317  4
551754  87.308  -55.946  57.281  4
551755  87.349  -55.959  57.243  4
551756  87.389  -55.972  57.205  4
551757  87.429  -55.986  57.167  4
551758  87.470  -56.000  57.129  4
551759  87.510  -56.013  57.090  4
551760  87.560  -56.020  57.050  4
551761  87.615  -56.024  57.012  4
551762  87.670  -56.028  56.975  4
551763  87.721  -56.034  56.937  4
551799  89.087  -56.566  56.025  1
551800  89.125  -56.582  56.011  1
551801  89.163  -56.598  55.997  1
551802  89.201  -56.614  55.985  1
551803  89.240  -56.630  55.976  1
551804  89.278  -56.646  55.968  1
551805  89.316  -56.662  55.962  1
551806  89.354  -56.678  55.955  1
551807  89.393  -56.694  55.949  1
551816  89.731  -56.820  55.925  1
551817  89.772  -56.831  55.924  1
551818  89.814  -56.842  55.923  1
551819  89.855  -56.852  55.920  1
551820  89.896  -56.864  55.914  1
551821  89.938  -56.874  55.906  1
551822  89.979  -56.885  55.896  1
551823  90.009  -56.901  55.883  1
551824  90.034  -56.918  55.868  1
551825  90.059  -56.935  55.852  1
551826  90.091  -56.951  55.832  1
551827  90.128  -56.965  55.811  1
551828  90.165  -56.979  55.790  1
551829  90.202  -56.993  55.768  1
551830  90.240  -57.008  55.744  1
551831  90.276  -57.022  55.718  1
551832  90.314  -57.037  55.700  1
551833  90.358  -57.053  55.680  1
551834  90.404  -57.069  55.653  1
551835  90.451  -57.084  55.620  1
551836  90.486  -57.101  55.585  1
551837  90.521  -57.117  55.548  1
551838  90.556  -57.133  55.511  1
551839  90.591  -57.150  55.478  1
551840  90.626  -57.166  55.450  1
551841  90.663  -57.182  55.424  1
551842  90.700  -57.198  55.400  1
551843  90.737  -57.215  55.378  1
551844  90.775  -57.232  55.358  1
551845  90.812  -57.247  55.340  1
551846  90.850  -57.264  55.325  1
551847  90.887  -57.280  55.312  1
551848  90.925  -57.297  55.299  1
551849  90.962  -57.313  55.288  1
551850  91.000  -57.329  55.279  1
551851  91.037  -57.346  55.271  1
551852  91.074  -57.363  55.265  1
551853  91.113  -57.376  55.260  1
551854  91.159  -57.383  55.259  1
551855  91.204  -57.389  55.263  1
551856  91.243  -57.413  55.268  1
551857  91.283  -57.436  55.275  1
551858  91.322  -57.460  55.281  1
551859  91.365  -57.474  55.285  1
551860  91.409  -57.485  55.288  1
551861  91.453  -57.495  55.291  1
551862  91.497  -57.506  55.291  1
551863  91.540  -57.517  55.287  1
551864  91.584  -57.527  55.284  1
551865  91.628  -57.538  55.276  1
551866  91.672  -57.548  55.269  1
551867  91.716  -57.558  55.263  1
551868  91.759  -57.569  55.260  1
551869  91.803  -57.579  55.265  1
551870  91.847  -57.590  55.268  1
551871  91.891  -57.601  55.268  1
551872  91.935  -57.611  55.266  1
551873  91.979  -57.621  55.265  1
551874  92.022  -57.632  55.265  1
551875  92.066  -57.642  55.266  1
551876  92.110  -57.653  55.260  1
551877  92.154  -57.664  55.251  1
551878  92.196  -57.675  55.238  1
551879  92.232  -57.693  55.223  1
551880  92.264  -57.708  55.207  1
551881  92.289  -57.724  55.195  1
551882  92.318  -57.746  55.181  1
551883  92.348  -57.766  55.164  1
551884  92.378  -57.787  55.144  1
551885  92.407  -57.808  55.122  1
551886  92.437  -57.829  55.101  1
551887  92.466  -57.849  55.087  1
551888  92.496  -57.871  55.067  1
551889  92.526  -57.891  55.046  1
551890  92.556  -57.912  55.026  1
551891  92.585  -57.933  55.005  1
551892  92.620  -57.946  54.985  1
551893  92.656  -57.957  54.961  1
551894  92.692  -57.968  54.935  1
551895  92.728  -57.974  54.908  1
551896  92.765  -57.981  54.883  1
551897  92.801  -57.987  54.862  1
551898  92.838  -57.993  54.850  1
551899  92.874  -57.999  54.844  1
551900  92.911  -58.006  54.837  1
551901  92.947  -58.012  54.827  1
551902  92.974  -58.017  54.814  1
551903  93.005  -58.016  54.796  1
551904  93.039  -58.021  54.774  1
551905  93.073  -58.029  54.748  1
551906  93.108  -58.037  54.720  1
551907  93.142  -58.046  54.697  1
551908  93.177  -58.054  54.687  1
551909  93.211  -58.062  54.691  1
551910  93.245  -58.071  54.702  1
551911  93.280  -58.079  54.715  1
551912  93.314  -58.087  54.729  1
551913  93.349  -58.096  54.738  1
551914  93.383  -58.104  54.740  1
551915  93.418  -58.112  54.735  1
551916  93.452  -58.120  54.730  1
551917  93.486  -58.128  54.723  1
551918  93.521  -58.137  54.719  1
551919  93.555  -58.145  54.720  1
551920  93.591  -58.159  54.722  1
551921  93.630  -58.178  54.723  1
551922  93.668  -58.198  54.727  1
551923  93.706  -58.219  54.730  1
551924  93.745  -58.238  54.728  1
551925  93.783  -58.258  54.723  1
551926  93.811  -58.270  54.715  1
551927  93.837  -58.282  54.705  1
551928  93.864  -58.294  54.690  1
551929  93.891  -58.306  54.672  1
551930  93.918  -58.318  54.650  1
551931  93.944  -58.329  54.621  1
551932  93.971  -58.341  54.587  1
551933  94.005  -58.353  54.547  1
551934  94.040  -58.363  54.505  1
551935  94.074  -58.375  54.465  1
551936  94.108  -58.386  54.430  1
551937  94.142  -58.397  54.406  1
551938  94.177  -58.409  54.379  1
551939  94.211  -58.419  54.353  1
551940  94.246  -58.431  54.325  1
551941  94.280  -58.442  54.297  1
551942  94.314  -58.454  54.267  1
551943  94.348  -58.464  54.239  1
551944  94.383  -58.476  54.216  1
551945  94.416  -58.488  54.193  1
551946  94.447  -58.501  54.169  1
551947  94.477  -58.514  54.145  1
551948  94.508  -58.527  54.117  1
551949  94.539  -58.541  54.083  1
551950  94.569  -58.554  54.044  1
551951  94.600  -58.567  54.007  1
551952  94.631  -58.580  53.976  1
551953  94.665  -58.593  53.948  1
551954  94.707  -58.604  53.925  1
551955  94.750  -58.614  53.905  1
551956  94.792  -58.625  53.887  1
551957  94.835  -58.636  53.872  1
551958  94.877  -58.647  53.857  1
551959  94.920  -58.657  53.837  1
551960  94.967  -58.670  53.817  1
551961  95.014  -58.683  53.791  1
551962  95.061  -58.695  53.760  1
551963  95.108  -58.708  53.729  1
551964  95.155  -58.720  53.703  1
551965  95.202  -58.732  53.678  1
551966  95.249  -58.745  53.656  1
551967  95.296  -58.757  53.632  1
551968  95.346  -58.768  53.607  1
551969  95.399  -58.777  53.581  1
551970  95.440  -58.783  53.553  1
551971  95.471  -58.793  53.524  1
551972  95.502  -58.807  53.496  1
551973  95.533  -58.817  53.465  1
551974  95.562  -58.826  53.435  1
551975  95.592  -58.835  53.408  1
551976  95.622  -58.844  53.380  1
551977  95.652  -58.853  53.353  1
551978  95.682  -58.862  53.326  1
551979  95.712  -58.871  53.298  1
551980  95.741  -58.879  53.268  1
551981  95.770  -58.886  53.238  1
551982  95.798  -58.894  53.209  1
551983  95.827  -58.902  53.181  1
551984  95.856  -58.909  53.151  1
551985  95.892  -58.915  53.119  1
551986  95.927  -58.921  53.087  1
551987  95.960  -58.927  53.055  1
551988  95.990  -58.934  53.029  1
551989  96.021  -58.941  53.008  1
551990  96.051  -58.949  52.989  1
551991  96.081  -58.955  52.968  1
551992  96.112  -58.962  52.944  1
551993  96.147  -58.968  52.919  1
551994  96.182  -58.974  52.892  1
551995  96.217  -58.981  52.868  1
551996  96.252  -58.987  52.845  1
551997  96.287  -58.993  52.822  1
551998  96.322  -59.000  52.795  1
551999  96.357  -59.006  52.776  1
552000  96.391  -59.012  52.749  1
552001  96.425  -59.019  52.719  1
552002  96.457  -59.024  52.689  1
552003  96.488  -59.027  52.663  1
552004  96.519  -59.029  52.634  1
552005  96.549  -59.031  52.602  1
552006  96.580  -59.034  52.577  1
552007  96.611  -59.036  52.552  1
552008  96.642  -59.038  52.527  1
552009  96.673  -59.040  52.503  1
552010  96.704  -59.041  52.471  1
552011  96.735  -59.042  52.439  1
552012  96.766  -59.043  52.403  1
552013  96.799  -59.047  52.367  1
552014  96.832  -59.048  52.332  1
552015  96.866  -59.048  52.290  1
552016  96.899  -59.049  52.239  1
552017  96.933  -59.049  52.196  1
552018  96.967  -59.050  52.157  1
552019  97.001  -59.051  52.120  1
552020  97.034  -59.052  52.089  1
552021  97.068  -59.052  52.058  1
552022  97.101  -59.054  52.022  1
552023  97.135  -59.058  51.984  1
552024  97.170  -59.061  51.943  1
552025  97.205  -59.065  51.901  1
552026  97.240  -59.068  51.860  1
552027  97.275  -59.071  51.814  1
552028  97.309  -59.074  51.769  1
552029  97.344  -59.077  51.723  1
552030  97.377  -59.081  51.677  1
552031  97.410  -59.086  51.630  1
552032  97.443  -59.090  51.589  1
552033  97.476  -59.093  51.542  1
552034  97.510  -59.098  51.496  1
552035  97.543  -59.102  51.451  1
552036  97.576  -59.106  51.406  1
552037  97.608  -59.111  51.361  1
552038  97.639  -59.115  51.321  1
552039  97.670  -59.120  51.285  1
552040  97.701  -59.124  51.243  1
552041  97.732  -59.129  51.200  1
552042  97.764  -59.134  51.158  1
552043  97.802  -59.133  51.118  1
552044  97.842  -59.131  51.076  1
552045  97.881  -59.130  51.034  1
552046  97.921  -59.128  50.993  1
552047  97.960  -59.127  50.950  1
552048  98.000  -59.125  50.907  1
552049  98.039  -59.124  50.864  1
552050  98.075  -59.123  50.820  1
552051  98.114  -59.128  50.776  1
552052  98.154  -59.132  50.735  1
552053  98.194  -59.137  50.698  1
552054  98.233  -59.142  50.667  1
552055  98.267  -59.140  50.642  1
552056  98.298  -59.135  50.618  1
552057  98.329  -59.129  50.593  1
552058  98.362  -59.118  50.567  1
552059  98.397  -59.108  50.540  1
552060  98.430  -59.097  50.512  1
552061  98.464  -59.086  50.483  1
552062  98.498  -59.075  50.454  1
552063  98.531  -59.065  50.423  1
552064  98.565  -59.054  50.392  1
552065  98.599  -59.043  50.361  1
552066  98.632  -59.032  50.331  1
552067  98.666  -59.021  50.299  1
552068  98.700  -59.011  50.267  1
552069  98.733  -58.999  50.235  1
552070  98.767  -58.989  50.202  1
552071  98.801  -58.979  50.170  1
552072  98.838  -58.978  50.137  1
552073  98.876  -58.986  50.100  1
552074  98.915  -58.993  50.064  1
552075  98.954  -58.999  50.029  1
552076  98.993  -59.006  49.993  1
552077  99.047  -59.040  49.956  1
552078  99.076  -59.043  49.922  1
552079  99.104  -59.048  49.888  1
552080  99.133  -59.052  49.853  1
552081  99.162  -59.055  49.817  1
552082  99.234  -59.049  49.783  1
552083  99.306  -59.043  49.753  1
552084  99.378  -59.038  49.720  1
552085  99.440  -59.036  49.688  1
552086  99.476  -59.043  49.657  1
552087  99.512  -59.050  49.624  1
552088  99.548  -59.058  49.592  1
552089  99.583  -59.065  49.560  1
552436  86.558  -55.649  57.657  4
552437  86.598  -55.662  57.649  4
552438  86.638  -55.676  57.641  4
552439  86.679  -55.689  57.633  4
552440  86.719  -55.702  57.625  4
552441  86.760  -55.716  57.616  4
552442  86.800  -55.729  57.606  4
552443  86.841  -55.743  57.593  4
552444  86.881  -55.756  57.579  4
552445  86.921  -55.769  57.564  4
552446  86.962  -55.783  57.547  4
552447  87.002  -55.796  57.530  4
552448  87.043  -55.809  57.510  4
552449  87.083  -55.822  57.486  4
552450  87.123  -55.836  57.458  4
552451  87.163  -55.850  57.429  4
552452  87.204  -55.862  57.399  4
552453  87.245  -55.876  57.368  4
552454  87.285  -55.890  57.336  4
552455  87.325  -55.903  57.301  4
552456  87.365  -55.916  57.263  4
552457  87.406  -55.929  57.226  4
552458  87.446  -55.943  57.189  4
552459  87.487  -55.956  57.150  4
552460  87.530  -55.968  57.111  4
552461  87.585  -55.972  57.071  4
552462  87.640  -55.975  57.032  4
552463  87.695  -55.980  56.993  4
552464  87.741  -55.986  56.955  4
552465  87.786  -55.994  56.917  4
552498  89.028  -56.495  56.050  1
552499  89.066  -56.511  56.034  1
552500  89.105  -56.527  56.020  1
552501  89.143  -56.543  56.005  1
552502  89.181  -56.559  55.992  1
552503  89.219  -56.575  55.981  1
552504  89.258  -56.592  55.971  1
552505  89.296  -56.608  55.963  1
552506  89.334  -56.624  55.957  1
552507  89.373  -56.639  55.951  1
552508  89.410  -56.655  55.945  1
552509  89.446  -56.673  55.939  1
552510  89.470  -56.697  55.934  1
552516  89.709  -56.770  55.931  1
552517  89.750  -56.780  55.933  1
552518  89.792  -56.791  55.935  1
552519  89.833  -56.802  55.936  1
552520  89.874  -56.813  55.934  1
552521  89.916  -56.824  55.930  1
552522  89.957  -56.835  55.924  1
552523  89.990  -56.849  55.914  1
552524  90.016  -56.866  55.902  1
552525  90.041  -56.883  55.888  1
552526  90.067  -56.900  55.870  1
552527  90.102  -56.915  55.850  1
552528  90.140  -56.929  55.828  1
552529  90.177  -56.943  55.807  1
552530  90.214  -56.958  55.783  1
552531  90.251  -56.972  55.756  1
552532  90.288  -56.987  55.729  1
552533  90.331  -57.002  55.706  1
552534  90.378  -57.018  55.682  1
552535  90.424  -57.034  55.654  1
552536  90.470  -57.050  55.621  1
552537  90.509  -57.066  55.590  1
552538  90.544  -57.083  55.554  1
552539  90.579  -57.099  55.515  1
552540  90.614  -57.116  55.480  1
552541  90.649  -57.131  55.451  1
552542  90.684  -57.147  55.424  1
552543  90.719  -57.164  55.400  1
552544  90.754  -57.180  55.378  1
552545  90.792  -57.197  55.358  1
552546  90.829  -57.213  55.341  1
552547  90.867  -57.229  55.325  1
552548  90.904  -57.246  55.312  1
552549  90.942  -57.262  55.301  1
552550  90.979  -57.279  55.290  1
552551  91.016  -57.295  55.280  1
552552  91.054  -57.311  55.273  1
552553  91.091  -57.328  55.268  1
552554  91.129  -57.344  55.265  1
552555  91.173  -57.351  55.266  1
552556  91.218  -57.359  55.272  1
552557  91.257  -57.383  55.282  1
552558  91.297  -57.407  55.291  1
552559  91.338  -57.425  55.300  1
552560  91.382  -57.435  55.305  1
552561  91.426  -57.446  55.310  1
552562  91.469  -57.457  55.310  1
552563  91.513  -57.467  55.306  1
552564  91.557  -57.477  55.300  1
552565  91.601  -57.488  55.293  1
552566  91.645  -57.498  55.280  1
552567  91.688  -57.509  55.269  1
552568  91.732  -57.520  55.262  1
552569  91.776  -57.529  55.262  1
552570  91.820  -57.540  55.273  1
552571  91.864  -57.551  55.278  1
552572  91.908  -57.561  55.278  1
552573  91.951  -57.572  55.277  1
552574  91.995  -57.583  55.276  1
552575  92.039  -57.592  55.276  1
552576  92.083  -57.603  55.278  1
552577  92.127  -57.614  55.275  1
552578  92.170  -57.624  55.269  1
552579  92.214  -57.635  55.259  1
552580  92.246  -57.653  55.245  1
552581  92.276  -57.673  55.230  1
552582  92.306  -57.695  55.217  1
552583  92.336  -57.715  55.200  1
552584  92.365  -57.736  55.179  1
552585  92.395  -57.757  55.156  1
552586  92.425  -57.778  55.135  1
552587  92.454  -57.799  55.118  1
552588  92.484  -57.820  55.106  1
552589  92.513  -57.840  55.088  1
552590  92.543  -57.861  55.066  1
552591  92.573  -57.882  55.041  1
552592  92.603  -57.901  55.014  1
552593  92.640  -57.912  54.992  1
552594  92.676  -57.922  54.966  1
552595  92.712  -57.933  54.937  1
552596  92.748  -57.941  54.910  1
552597  92.785  -57.947  54.887  1
552598  92.821  -57.953  54.867  1
552599  92.858  -57.959  54.855  1
552600  92.895  -57.965  54.844  1
552601  92.931  -57.971  54.832  1
552602  92.960  -57.977  54.819  1
552603  92.986  -57.983  54.805  1
552604  93.017  -57.982  54.790  1
552605  93.049  -57.981  54.772  1
552606  93.081  -57.985  54.749  1
552607  93.116  -57.993  54.726  1
552608  93.150  -58.002  54.707  1
552609  93.185  -58.010  54.696  1
552610  93.219  -58.018  54.696  1
552611  93.254  -58.027  54.704  1
552612  93.288  -58.035  54.716  1
552613  93.323  -58.043  54.728  1
552614  93.357  -58.051  54.735  1
552615  93.392  -58.059  54.745  1
552616  93.426  -58.068  54.747  1
552617  93.460  -58.076  54.745  1
552618  93.495  -58.084  54.739  1
552619  93.529  -58.093  54.733  1
552620  93.564  -58.101  54.736  1
552621  93.601  -58.116  54.740  1
552622  93.639  -58.136  54.741  1
552623  93.677  -58.156  54.743  1
552624  93.715  -58.176  54.743  1
552625  93.754  -58.196  54.741  1
552626  93.792  -58.216  54.734  1
552627  93.830  -58.235  54.726  1
552628  93.859  -58.248  54.717  1
552629  93.886  -58.260  54.704  1
552630  93.912  -58.272  54.688  1
552631  93.939  -58.284  54.668  1
552632  93.966  -58.296  54.641  1
552633  93.992  -58.307  54.608  1
552634  94.019  -58.319  54.567  1
552635  94.046  -58.331  54.522  1
552636  94.075  -58.343  54.476  1
552637  94.110  -58.354  54.434  1
552638  94.144  -58.365  54.402  1
552639  94.179  -58.376  54.370  1
552640  94.213  -58.388  54.339  1
552641  94.247  -58.399  54.310  1
552642  94.281  -58.410  54.282  1
552643  94.316  -58.421  54.253  1
552644  94.350  -58.432  54.225  1
552645  94.384  -58.444  54.200  1
552646  94.417  -58.456  54.176  1
552647  94.448  -58.469  54.152  1
552648  94.478  -58.482  54.129  1
552649  94.509  -58.495  54.099  1
552650  94.540  -58.509  54.067  1
552651  94.570  -58.522  54.032  1
552652  94.601  -58.535  53.996  1
552653  94.632  -58.548  53.962  1
552654  94.663  -58.562  53.932  1
552655  94.703  -58.573  53.909  1
552656  94.746  -58.584  53.889  1
552657  94.788  -58.595  53.871  1
552658  94.831  -58.605  53.854  1
552659  94.874  -58.616  53.840  1
552660  94.920  -58.628  53.823  1
552661  94.967  -58.641  53.801  1
552662  95.014  -58.653  53.776  1
552663  95.061  -58.665  53.747  1
552664  95.108  -58.678  53.715  1
552665  95.155  -58.690  53.683  1
552666  95.201  -58.702  53.659  1
552667  95.254  -58.713  53.636  1
552668  95.307  -58.722  53.610  1
552669  95.360  -58.732  53.583  1
552670  95.413  -58.742  53.558  1
552671  95.442  -58.742  53.534  1
552672  95.472  -58.751  53.507  1
552673  95.503  -58.764  53.479  1
552674  95.535  -58.778  53.449  1
552675  95.566  -58.791  53.418  1
552676  95.597  -58.802  53.390  1
552677  95.627  -58.811  53.359  1
552678  95.657  -58.820  53.331  1
552679  95.687  -58.829  53.303  1
552680  95.716  -58.838  53.275  1
552681  95.746  -58.847  53.246  1
552682  95.775  -58.855  53.215  1
552683  95.804  -58.862  53.186  1
552684  95.832  -58.870  53.159  1
552685  95.863  -58.877  53.129  1
552686  95.898  -58.883  53.099  1
552687  95.933  -58.889  53.067  1
552688  95.963  -58.896  53.035  1
552689  95.993  -58.902  53.007  1
552690  96.024  -58.910  52.983  1
552691  96.054  -58.917  52.962  1
552692  96.084  -58.924  52.941  1
552693  96.115  -58.930  52.918  1
552694  96.151  -58.936  52.894  1
552695  96.185  -58.943  52.867  1
552696  96.220  -58.949  52.840  1
552697  96.255  -58.955  52.815  1
552698  96.290  -58.961  52.791  1
552699  96.325  -58.968  52.766  1
552700  96.360  -58.974  52.746  1
552701  96.395  -58.980  52.718  1
552702  96.430  -58.987  52.686  1
552703  96.461  -58.991  52.655  1
552704  96.492  -58.993  52.628  1
552705  96.523  -58.996  52.597  1
552706  96.553  -58.997  52.564  1
552707  96.585  -58.998  52.537  1
552708  96.616  -58.999  52.513  1
552709  96.647  -58.999  52.486  1
552710  96.678  -59.000  52.460  1
552711  96.709  -59.002  52.426  1
552712  96.740  -59.002  52.395  1
552713  96.771  -59.005  52.363  1
552714  96.803  -59.011  52.328  1
552715  96.837  -59.012  52.292  1
552716  96.871  -59.012  52.250  1
552717  96.904  -59.013  52.206  1
552718  96.938  -59.014  52.164  1
552719  96.971  -59.015  52.123  1
552720  97.005  -59.015  52.084  1
552721  97.039  -59.016  52.050  1
552722  97.073  -59.017  52.020  1
552723  97.106  -59.019  51.986  1
552724  97.140  -59.024  51.950  1
552725  97.174  -59.027  51.910  1
552726  97.209  -59.030  51.868  1
552727  97.243  -59.034  51.831  1
552728  97.278  -59.037  51.791  1
552729  97.313  -59.040  51.749  1
552730  97.347  -59.043  51.704  1
552731  97.380  -59.048  51.656  1
552732  97.413  -59.052  51.610  1
552733  97.446  -59.056  51.571  1
552734  97.479  -59.060  51.523  1
552735  97.513  -59.065  51.476  1
552736  97.546  -59.068  51.433  1
552737  97.579  -59.073  51.392  1
552738  97.613  -59.080  51.346  1
552739  97.645  -59.084  51.304  1
552740  97.676  -59.090  51.265  1
552741  97.707  -59.094  51.222  1
552742  97.738  -59.099  51.177  1
552743  97.771  -59.102  51.134  1
552744  97.811  -59.100  51.092  1
552745  97.850  -59.099  51.049  1
552746  97.890  -59.097  51.007  1
552747  97.929  -59.096  50.966  1
552748  97.968  -59.094  50.926  1
552749  98.008  -59.093  50.883  1
552750  98.049  -59.087  50.840  1
552751  98.085  -59.085  50.796  1
552752  98.118  -59.087  50.753  1
552753  98.151  -59.090  50.711  1
552754  98.191  -59.096  50.672  1
552755  98.231  -59.100  50.640  1
552756  98.267  -59.101  50.616  1
552757  98.298  -59.096  50.595  1
552758  98.329  -59.092  50.573  1
552759  98.361  -59.085  50.549  1
552760  98.395  -59.074  50.523  1
552761  98.429  -59.064  50.493  1
552762  98.463  -59.053  50.465  1
552763  98.497  -59.042  50.437  1
552764  98.531  -59.031  50.407  1
552765  98.565  -59.021  50.378  1
552766  98.599  -59.010  50.350  1
552767  98.633  -58.999  50.321  1
552768  98.667  -58.988  50.291  1
552769  98.701  -58.977  50.261  1
552770  98.735  -58.967  50.231  1
552771  98.769  -58.956  50.201  1
552772  98.802  -58.946  50.169  1
552773  98.835  -58.945  50.138  1
552774  98.873  -58.951  50.104  1
552775  98.913  -58.958  50.069  1
552776  98.951  -58.965  50.036  1
552777  98.990  -58.972  50.001  1
552778  99.041  -58.996  49.965  1
552779  99.074  -59.006  49.929  1
552780  99.103  -59.011  49.895  1
552781  99.132  -59.015  49.860  1
552782  99.170  -59.016  49.824  1
552783  99.242  -59.010  49.791  1
552784  99.314  -59.005  49.760  1
552785  99.386  -58.999  49.728  1
552786  99.441  -58.999  49.696  1
552787  99.477  -59.006  49.664  1
552788  99.513  -59.014  49.632  1
552789  99.548  -59.021  49.600  1
552790  99.584  -59.029  49.569  1
552791  99.620  -59.037  49.536  1
552792  99.655  -59.044  49.503  1
552793  99.691  -59.051  49.470  1
553138  86.615  -55.619  57.649  4
553139  86.655  -55.633  57.642  4
553140  86.696  -55.646  57.634  4
553141  86.736  -55.659  57.626  4
553142  86.777  -55.673  57.619  4
553143  86.817  -55.686  57.609  4
553144  86.857  -55.699  57.596  4
553145  86.898  -55.712  57.583  4
553146  86.938  -55.726  57.568  4
553147  86.979  -55.740  57.554  4
553148  87.019  -55.752  57.537  4
553149  87.059  -55.766  57.519  4
553150  87.099  -55.779  57.496  4
553151  87.140  -55.793  57.471  4
553152  87.181  -55.806  57.444  4
553153  87.221  -55.819  57.416  4
553154  87.261  -55.833  57.387  4
553155  87.301  -55.846  57.356  4
553156  87.342  -55.859  57.322  4
553157  87.382  -55.873  57.285  4
553158  87.423  -55.886  57.249  4
553159  87.463  -55.900  57.212  4
553160  87.503  -55.912  57.173  4
553161  87.555  -55.919  57.134  4
553162  87.610  -55.923  57.093  4
553163  87.666  -55.927  57.053  4
553164  87.717  -55.932  57.013  4
553165  87.761  -55.939  56.973  4
553166  87.802  -55.948  56.934  4
553167  87.836  -55.959  56.898  4
553199  89.046  -56.457  56.046  1
553200  89.084  -56.473  56.030  1
553201  89.122  -56.489  56.015  1
553202  89.161  -56.505  56.001  1
553203  89.199  -56.521  55.987  1
553204  89.237  -56.537  55.976  1
553205  89.275  -56.553  55.966  1
553206  89.314  -56.569  55.959  1
553207  89.352  -56.585  55.952  1
553208  89.390  -56.601  55.946  1
553209  89.428  -56.617  55.940  1
553210  89.464  -56.634  55.934  1
553211  89.488  -56.658  55.931  1
553212  89.521  -56.676  55.929  1
553213  89.562  -56.686  55.929  1
553215  89.646  -56.708  55.934  1
553216  89.687  -56.719  55.934  1
553217  89.728  -56.730  55.939  1
553218  89.769  -56.741  55.943  1
553219  89.811  -56.752  55.946  1
553220  89.852  -56.762  55.948  1
553221  89.894  -56.774  55.949  1
553222  89.935  -56.784  55.947  1
553223  89.972  -56.797  55.943  1
553224  89.998  -56.814  55.935  1
553225  90.023  -56.831  55.924  1
553226  90.049  -56.848  55.910  1
553227  90.077  -56.865  55.891  1
553228  90.114  -56.879  55.871  1
553229  90.151  -56.893  55.849  1
553230  90.188  -56.908  55.825  1
553231  90.225  -56.922  55.799  1
553232  90.262  -56.937  55.769  1
553233  90.305  -56.952  55.739  1
553234  90.351  -56.968  55.710  1
553235  90.397  -56.984  55.681  1
553236  90.444  -57.000  55.651  1
553237  90.490  -57.016  55.618  1
553238  90.533  -57.032  55.591  1
553239  90.568  -57.049  55.557  1
553240  90.603  -57.065  55.518  1
553241  90.638  -57.081  55.482  1
553242  90.673  -57.097  55.452  1
553243  90.708  -57.113  55.425  1
553244  90.743  -57.130  55.401  1
553245  90.778  -57.146  55.379  1
553246  90.813  -57.162  55.359  1
553247  90.848  -57.178  55.342  1
553248  90.884  -57.194  55.327  1
553249  90.921  -57.211  55.313  1
553250  90.958  -57.227  55.302  1
553251  90.996  -57.244  55.292  1
553252  91.033  -57.260  55.282  1
553253  91.071  -57.276  55.275  1
553254  91.108  -57.293  55.270  1
553255  91.146  -57.310  55.268  1
553256  91.187  -57.320  55.268  1
553257  91.231  -57.329  55.274  1
553258  91.271  -57.353  55.284  1
553259  91.311  -57.376  55.296  1
553260  91.355  -57.385  55.305  1
553261  91.399  -57.396  55.309  1
553262  91.443  -57.407  55.311  1
553263  91.487  -57.417  55.308  1
553264  91.530  -57.428  55.303  1
553265  91.574  -57.438  55.296  1
553266  91.618  -57.448  55.289  1
553267  91.662  -57.459  55.278  1
553268  91.706  -57.470  55.266  1
553269  91.749  -57.480  55.259  1
553270  91.793  -57.491  55.263  1
553271  91.837  -57.501  55.272  1
553272  91.881  -57.511  55.278  1
553273  91.925  -57.522  55.280  1
553274  91.968  -57.532  55.280  1
553275  92.012  -57.543  55.279  1
553276  92.055  -57.553  55.280  1
553277  92.098  -57.562  55.283  1
553278  92.141  -57.572  55.282  1
553279  92.184  -57.582  55.278  1
553280  92.226  -57.597  55.270  1
553281  92.264  -57.623  55.257  1
553282  92.294  -57.644  55.243  1
553283  92.323  -57.664  55.226  1
553284  92.353  -57.686  55.207  1
553285  92.382  -57.706  55.184  1
553286  92.412  -57.727  55.160  1
553287  92.442  -57.748  55.138  1
553288  92.472  -57.768  55.120  1
553289  92.501  -57.789  55.103  1
553290  92.531  -57.810  55.088  1
553291  92.561  -57.831  55.071  1
553292  92.590  -57.852  55.050  1
553293  92.624  -57.867  55.025  1
553294  92.660  -57.877  55.000  1
553295  92.696  -57.888  54.974  1
553296  92.732  -57.899  54.948  1
553297  92.768  -57.908  54.924  1
553298  92.805  -57.914  54.902  1
553299  92.841  -57.920  54.879  1
553300  92.878  -57.926  54.857  1
553301  92.914  -57.932  54.836  1
553302  92.948  -57.938  54.817  1
553303  92.973  -57.944  54.800  1
553304  92.998  -57.949  54.789  1
553305  93.029  -57.949  54.779  1
553306  93.060  -57.948  54.767  1
553307  93.091  -57.947  54.752  1
553308  93.124  -57.949  54.736  1
553309  93.158  -57.958  54.724  1
553310  93.193  -57.966  54.716  1
553311  93.227  -57.974  54.710  1
553312  93.262  -57.982  54.711  1
553313  93.296  -57.990  54.720  1
553314  93.331  -57.999  54.731  1
553315  93.365  -58.007  54.738  1
553316  93.400  -58.015  54.746  1
553317  93.434  -58.024  54.752  1
553318  93.469  -58.032  54.754  1
553319  93.503  -58.040  54.751  1
553320  93.538  -58.049  54.745  1
553321  93.572  -58.057  54.742  1
553322  93.609  -58.074  54.746  1
553323  93.647  -58.093  54.750  1
553324  93.686  -58.113  54.751  1
553325  93.724  -58.133  54.748  1
553326  93.762  -58.153  54.743  1
553327  93.800  -58.173  54.734  1
553328  93.839  -58.193  54.724  1
553329  93.877  -58.212  54.714  1
553330  93.907  -58.227  54.705  1
553331  93.934  -58.238  54.693  1
553332  93.961  -58.250  54.675  1
553333  93.987  -58.262  54.650  1
553334  94.014  -58.274  54.618  1
553335  94.041  -58.285  54.581  1
553336  94.067  -58.297  54.536  1
553337  94.094  -58.310  54.488  1
553338  94.121  -58.321  54.444  1
553339  94.148  -58.333  54.405  1
553340  94.180  -58.344  54.367  1
553341  94.214  -58.355  54.331  1
553342  94.249  -58.366  54.299  1
553343  94.283  -58.378  54.270  1
553344  94.317  -58.389  54.241  1
553345  94.351  -58.400  54.212  1
553346  94.386  -58.411  54.185  1
553347  94.417  -58.424  54.160  1
553348  94.448  -58.438  54.136  1
553349  94.479  -58.451  54.113  1
553350  94.509  -58.464  54.083  1
553351  94.540  -58.477  54.051  1
553352  94.571  -58.491  54.018  1
553353  94.602  -58.504  53.985  1
553354  94.632  -58.516  53.951  1
553355  94.663  -58.530  53.920  1
553356  94.700  -58.542  53.895  1
553357  94.743  -58.553  53.875  1
553358  94.785  -58.563  53.857  1
553359  94.828  -58.574  53.839  1
553360  94.873  -58.586  53.822  1
553361  94.920  -58.598  53.805  1
553362  94.967  -58.611  53.782  1
553363  95.014  -58.623  53.756  1
553364  95.060  -58.636  53.726  1
553365  95.108  -58.648  53.694  1
553366  95.162  -58.657  53.663  1
553367  95.215  -58.667  53.634  1
553368  95.268  -58.676  53.607  1
553369  95.321  -58.686  53.582  1
553370  95.375  -58.696  53.557  1
553371  95.416  -58.701  53.533  1
553372  95.444  -58.701  53.511  1
553373  95.473  -58.708  53.486  1
553374  95.505  -58.722  53.460  1
553375  95.536  -58.736  53.433  1
553376  95.567  -58.749  53.403  1
553377  95.599  -58.762  53.371  1
553378  95.631  -58.776  53.341  1
553379  95.661  -58.787  53.311  1
553380  95.691  -58.795  53.284  1
553381  95.721  -58.805  53.257  1
553382  95.751  -58.814  53.229  1
553383  95.781  -58.823  53.200  1
553384  95.809  -58.830  53.170  1
553385  95.838  -58.838  53.142  1
553386  95.869  -58.845  53.112  1
553387  95.904  -58.851  53.080  1
553388  95.936  -58.857  53.049  1
553389  95.966  -58.864  53.018  1
553390  95.996  -58.871  52.988  1
553391  96.027  -58.878  52.958  1
553392  96.057  -58.885  52.934  1
553393  96.087  -58.892  52.913  1
553394  96.119  -58.899  52.892  1
553395  96.154  -58.905  52.867  1
553396  96.189  -58.911  52.842  1
553397  96.224  -58.918  52.814  1
553398  96.259  -58.924  52.785  1
553399  96.294  -58.930  52.759  1
553400  96.329  -58.936  52.734  1
553401  96.364  -58.943  52.713  1
553402  96.399  -58.949  52.687  1
553403  96.434  -58.953  52.657  1
553404  96.465  -58.955  52.625  1
553405  96.497  -58.955  52.596  1
553406  96.528  -58.956  52.563  1
553407  96.559  -58.957  52.529  1
553408  96.590  -58.958  52.501  1
553409  96.621  -58.959  52.475  1
553410  96.652  -58.960  52.445  1
553411  96.683  -58.961  52.417  1
553412  96.714  -58.961  52.384  1
553413  96.745  -58.962  52.353  1
553414  96.777  -58.968  52.321  1
553415  96.809  -58.973  52.286  1
553416  96.841  -58.976  52.248  1
553417  96.875  -58.977  52.206  1
553418  96.909  -58.977  52.166  1
553419  96.943  -58.978  52.126  1
553420  96.976  -58.979  52.086  1
553421  97.010  -58.980  52.047  1
553422  97.044  -58.980  52.011  1
553423  97.077  -58.981  51.979  1
553424  97.111  -58.985  51.947  1
553425  97.144  -58.989  51.913  1
553426  97.177  -58.993  51.875  1
553427  97.212  -58.996  51.834  1
553428  97.247  -58.999  51.796  1
553429  97.282  -59.002  51.755  1
553430  97.317  -59.005  51.715  1
553431  97.350  -59.009  51.673  1
553432  97.383  -59.014  51.628  1
553433  97.416  -59.018  51.581  1
553434  97.449  -59.022  51.542  1
553435  97.483  -59.026  51.499  1
553436  97.516  -59.030  51.453  1
553437  97.549  -59.034  51.410  1
553438  97.582  -59.039  51.368  1
553439  97.617  -59.048  51.323  1
553440  97.651  -59.054  51.280  1
553441  97.682  -59.059  51.239  1
553442  97.713  -59.063  51.195  1
553443  97.744  -59.068  51.151  1
553444  97.780  -59.070  51.110  1
553445  97.819  -59.068  51.068  1
553446  97.859  -59.066  51.025  1
553447  97.898  -59.065  50.983  1
553448  97.938  -59.063  50.940  1
553449  97.976  -59.063  50.896  1
553450  98.015  -59.062  50.853  1
553451  98.060  -59.049  50.810  1
553452  98.096  -59.046  50.767  1
553453  98.128  -59.049  50.724  1
553454  98.160  -59.052  50.684  1
553455  98.193  -59.055  50.646  1
553456  98.228  -59.059  50.615  1
553457  98.267  -59.062  50.590  1
553458  98.298  -59.058  50.570  1
553459  98.332  -59.055  50.551  1
553460  98.368  -59.053  50.527  1
553461  98.402  -59.043  50.500  1
553462  98.436  -59.031  50.472  1
553463  98.470  -59.021  50.444  1
553464  98.504  -59.010  50.416  1
553465  98.538  -58.999  50.388  1
553466  98.572  -58.989  50.360  1
553467  98.606  -58.978  50.332  1
553468  98.640  -58.967  50.306  1
553469  98.674  -58.956  50.278  1
553470  98.708  -58.946  50.249  1
553471  98.742  -58.935  50.222  1
553472  98.775  -58.925  50.195  1
553473  98.805  -58.922  50.165  1
553474  98.839  -58.919  50.137  1
553475  98.872  -58.918  50.106  1
553476  98.910  -58.924  50.075  1
553477  98.948  -58.930  50.044  1
553478  98.987  -58.937  50.010  1
553479  99.026  -58.944  49.974  1
553480  99.073  -58.969  49.937  1
553481  99.101  -58.974  49.901  1
553482  99.130  -58.977  49.866  1
553483  99.178  -58.977  49.831  1
553484  99.250  -58.971  49.798  1
553485  99.322  -58.965  49.766  1
553486  99.394  -58.959  49.735  1
553487  99.442  -58.962  49.704  1
553488  99.478  -58.970  49.672  1
553489  99.513  -58.977  49.639  1
553490  99.549  -58.984  49.608  1
553491  99.585  -58.992  49.576  1
553492  99.621  -58.999  49.544  1
553493  99.656  -59.007  49.512  1
553494  99.692  -59.015  49.478  1
553495  99.727  -59.022  49.443  1
553496  99.763  -59.030  49.407  1
553497  99.799  -59.037  49.372  1
553839  86.632  -55.576  57.648  4
553840  86.672  -55.589  57.643  4
553841  86.713  -55.602  57.635  4
553842  86.753  -55.616  57.628  4
553843  86.793  -55.629  57.621  4
553844  86.834  -55.643  57.612  4
553845  86.874  -55.656  57.599  4
553846  86.915  -55.669  57.586  4
553847  86.955  -55.683  57.574  4
553848  86.995  -55.696  57.559  4
553849  87.036  -55.709  57.544  4
553850  87.076  -55.723  57.528  4
553851  87.117  -55.736  57.506  4
553852  87.157  -55.749  57.483  4
553853  87.197  -55.762  57.458  4
553854  87.237  -55.776  57.433  4
553855  87.278  -55.790  57.407  4
553856  87.319  -55.803  57.376  4
553857  87.359  -55.816  57.342  4
553858  87.399  -55.829  57.307  4
553859  87.439  -55.843  57.271  4
553860  87.480  -55.856  57.234  4
553861  87.526  -55.866  57.196  4
553862  87.580  -55.870  57.158  4
553863  87.635  -55.875  57.117  4
553864  87.691  -55.878  57.075  4
553865  87.737  -55.885  57.034  4
553866  87.781  -55.893  56.994  4
553867  87.815  -55.904  56.954  4
553868  87.848  -55.915  56.916  4
553869  87.882  -55.927  56.878  4
553899  89.026  -56.402  56.059  1
553900  89.064  -56.418  56.041  1
553901  89.102  -56.434  56.025  1
553902  89.140  -56.451  56.010  1
553903  89.178  -56.467  55.995  1
553904  89.216  -56.483  55.982  1
553905  89.255  -56.498  55.970  1
553906  89.293  -56.514  55.961  1
553907  89.331  -56.530  55.954  1
553908  89.370  -56.546  55.948  1
553909  89.408  -56.562  55.942  1
553910  89.446  -56.578  55.935  1
553911  89.483  -56.595  55.929  1
553912  89.507  -56.619  55.928  1
553913  89.541  -56.636  55.927  1
553914  89.582  -56.647  55.929  1
553915  89.623  -56.658  55.932  1
553916  89.665  -56.669  55.936  1
553917  89.706  -56.680  55.940  1
553918  89.748  -56.690  55.946  1
553919  89.789  -56.701  55.952  1
553920  89.830  -56.712  55.957  1
553921  89.872  -56.723  55.962  1
553922  89.913  -56.733  55.964  1
553923  89.954  -56.745  55.964  1
553924  89.979  -56.762  55.963  1
553925  90.005  -56.779  55.958  1
553926  90.030  -56.796  55.949  1
553927  90.056  -56.813  55.934  1
553928  90.088  -56.829  55.917  1
553929  90.125  -56.843  55.895  1
553930  90.162  -56.858  55.872  1
553931  90.199  -56.872  55.846  1
553932  90.237  -56.887  55.816  1
553933  90.278  -56.902  55.785  1
553934  90.324  -56.918  55.751  1
553935  90.371  -56.934  55.716  1
553936  90.417  -56.950  55.683  1
553937  90.463  -56.966  55.650  1
553938  90.510  -56.982  55.618  1
553939  90.556  -56.998  55.591  1
553940  90.591  -57.015  55.557  1
553941  90.626  -57.031  55.519  1
553942  90.661  -57.047  55.482  1
553943  90.696  -57.063  55.452  1
553944  90.731  -57.079  55.426  1
553945  90.766  -57.095  55.404  1
553946  90.801  -57.112  55.382  1
553947  90.836  -57.128  55.362  1
553948  90.871  -57.144  55.344  1
553949  90.906  -57.160  55.328  1
553950  90.941  -57.176  55.315  1
553951  90.976  -57.193  55.304  1
553952  91.013  -57.209  55.294  1
553953  91.050  -57.225  55.285  1
553954  91.088  -57.241  55.277  1
553955  91.125  -57.258  55.271  1
553956  91.163  -57.275  55.269  1
553957  91.202  -57.288  55.270  1
553958  91.245  -57.299  55.274  1
553959  91.285  -57.323  55.282  1
553960  91.328  -57.336  55.293  1
553961  91.372  -57.347  55.300  1
553962  91.416  -57.357  55.302  1
553963  91.459  -57.367  55.301  1
553964  91.503  -57.378  55.296  1
553965  91.547  -57.388  55.289  1
553966  91.591  -57.399  55.282  1
553967  91.635  -57.410  55.276  1
553968  91.678  -57.420  55.268  1
553969  91.722  -57.430  55.259  1
553970  91.766  -57.441  55.254  1
553971  91.809  -57.451  55.259  1
553972  91.852  -57.460  55.264  1
553973  91.895  -57.470  55.269  1
553974  91.938  -57.480  55.272  1
553975  91.981  -57.489  55.272  1
553976  92.024  -57.499  55.271  1
553977  92.067  -57.509  55.276  1
553978  92.110  -57.518  55.278  1
553979  92.153  -57.528  55.278  1
553980  92.196  -57.539  55.276  1
553981  92.236  -57.563  55.270  1
553982  92.276  -57.588  55.262  1
553983  92.311  -57.614  55.247  1
553984  92.341  -57.634  55.227  1
553985  92.370  -57.655  55.207  1
553986  92.400  -57.676  55.183  1
553987  92.430  -57.697  55.158  1
553988  92.459  -57.717  55.136  1
553989  92.489  -57.739  55.117  1
553990  92.518  -57.759  55.099  1
553991  92.548  -57.780  55.083  1
553992  92.578  -57.801  55.068  1
553993  92.607  -57.822  55.049  1
553994  92.644  -57.833  55.027  1
553995  92.680  -57.843  55.004  1
553996  92.716  -57.854  54.981  1
553997  92.752  -57.865  54.956  1
553998  92.788  -57.874  54.930  1
553999  92.825  -57.880  54.902  1
554000  92.861  -57.887  54.879  1
554001  92.898  -57.893  54.859  1
554002  92.934  -57.899  54.839  1
554003  92.959  -57.905  54.819  1
554004  92.984  -57.911  54.800  1
554005  93.009  -57.915  54.786  1
554006  93.041  -57.915  54.779  1
554007  93.072  -57.914  54.773  1
554008  93.103  -57.913  54.767  1
554009  93.135  -57.912  54.761  1
554010  93.167  -57.913  54.756  1
554011  93.201  -57.921  54.750  1
554012  93.236  -57.930  54.736  1
554013  93.270  -57.938  54.725  1
554014  93.304  -57.946  54.726  1
554015  93.339  -57.955  54.736  1
554016  93.373  -57.963  54.745  1
554017  93.408  -57.971  54.745  1
554018  93.442  -57.980  54.754  1
554019  93.477  -57.988  54.761  1
554020  93.511  -57.996  54.762  1
554021  93.546  -58.005  54.757  1
554022  93.580  -58.013  54.749  1
554023  93.618  -58.031  54.749  1
554024  93.656  -58.051  54.751  1
554025  93.695  -58.071  54.751  1
554026  93.733  -58.090  54.748  1
554027  93.771  -58.111  54.740  1
554028  93.809  -58.131  54.729  1
554029  93.848  -58.150  54.718  1
554030  93.886  -58.170  54.708  1
554031  93.924  -58.190  54.699  1
554032  93.956  -58.205  54.687  1
554033  93.982  -58.216  54.671  1
554034  94.009  -58.228  54.648  1
554035  94.036  -58.240  54.620  1
554036  94.062  -58.252  54.587  1
554037  94.089  -58.263  54.549  1
554038  94.116  -58.275  54.508  1
554039  94.142  -58.288  54.464  1
554040  94.169  -58.299  54.421  1
554041  94.196  -58.311  54.378  1
554042  94.222  -58.322  54.338  1
554043  94.250  -58.335  54.299  1
554044  94.284  -58.346  54.264  1
554045  94.319  -58.357  54.233  1
554046  94.353  -58.368  54.201  1
554047  94.388  -58.379  54.173  1
554048  94.418  -58.392  54.147  1
554049  94.449  -58.406  54.121  1
554050  94.480  -58.419  54.095  1
554051  94.510  -58.432  54.068  1
554052  94.541  -58.445  54.035  1
554053  94.572  -58.459  54.003  1
554054  94.603  -58.472  53.972  1
554055  94.633  -58.485  53.941  1
554056  94.664  -58.498  53.911  1
554057  94.696  -58.511  53.884  1
554058  94.739  -58.522  53.862  1
554059  94.781  -58.533  53.843  1
554060  94.826  -58.544  53.825  1
554061  94.873  -58.557  53.804  1
554062  94.919  -58.569  53.784  1
554063  94.967  -58.581  53.761  1
554064  95.016  -58.592  53.733  1
554065  95.069  -58.602  53.702  1
554066  95.123  -58.612  53.671  1
554067  95.176  -58.621  53.641  1
554068  95.229  -58.631  53.612  1
554069  95.282  -58.641  53.585  1
554070  95.336  -58.650  53.560  1
554071  95.389  -58.660  53.536  1
554072  95.418  -58.661  53.512  1
554073  95.446  -58.661  53.488  1
554074  95.474  -58.666  53.465  1
554075  95.506  -58.679  53.441  1
554076  95.537  -58.693  53.413  1
554077  95.569  -58.707  53.381  1
554078  95.600  -58.720  53.351  1
554079  95.632  -58.733  53.325  1
554080  95.664  -58.747  53.298  1
554081  95.695  -58.761  53.272  1
554082  95.726  -58.772  53.246  1
554083  95.755  -58.780  53.221  1
554084  95.785  -58.789  53.194  1
554085  95.815  -58.798  53.164  1
554086  95.843  -58.805  53.132  1
554087  95.875  -58.812  53.100  1
554088  95.909  -58.818  53.068  1
554089  95.939  -58.826  53.039  1
554090  95.969  -58.833  53.008  1
554091  96.000  -58.839  52.972  1
554092  96.030  -58.846  52.940  1
554093  96.060  -58.853  52.912  1
554094  96.090  -58.860  52.887  1
554095  96.123  -58.867  52.859  1
554096  96.158  -58.874  52.834  1
554097  96.192  -58.880  52.810  1
554098  96.228  -58.886  52.782  1
554099  96.262  -58.892  52.752  1
554100  96.298  -58.899  52.723  1
554101  96.332  -58.903  52.697  1
554102  96.367  -58.906  52.677  1
554103  96.402  -58.909  52.656  1
554104  96.437  -58.912  52.630  1
554105  96.471  -58.914  52.601  1
554106  96.502  -58.915  52.570  1
554107  96.533  -58.917  52.533  1
554108  96.564  -58.918  52.499  1
554109  96.595  -58.918  52.469  1
554110  96.626  -58.919  52.438  1
554111  96.657  -58.920  52.405  1
554112  96.688  -58.921  52.375  1
554113  96.719  -58.922  52.343  1
554114  96.750  -58.924  52.312  1
554115  96.783  -58.930  52.278  1
554116  96.814  -58.935  52.241  1
554117  96.847  -58.940  52.202  1
554118  96.880  -58.941  52.161  1
554119  96.914  -58.942  52.124  1
554120  96.947  -58.943  52.086  1
554121  96.981  -58.943  52.047  1
554122  97.015  -58.944  52.009  1
554123  97.048  -58.944  51.973  1
554124  97.082  -58.946  51.938  1
554125  97.115  -58.950  51.907  1
554126  97.149  -58.954  51.874  1
554127  97.182  -58.958  51.838  1
554128  97.216  -58.961  51.800  1
554129  97.251  -58.965  51.761  1
554130  97.286  -58.968  51.720  1
554131  97.320  -58.971  51.680  1
554132  97.353  -58.975  51.639  1
554133  97.386  -58.980  51.596  1
554134  97.419  -58.984  51.551  1
554135  97.452  -58.988  51.510  1
554136  97.485  -58.993  51.470  1
554137  97.518  -58.996  51.426  1
554138  97.551  -59.001  51.383  1
554139  97.586  -59.006  51.342  1
554140  97.621  -59.015  51.297  1
554141  97.656  -59.023  51.252  1
554142  97.687  -59.028  51.209  1
554143  97.719  -59.033  51.164  1
554144  97.750  -59.037  51.120  1
554145  97.788  -59.037  51.078  1
554146  97.827  -59.035  51.037  1
554147  97.867  -59.034  50.994  1
554148  97.906  -59.033  50.952  1
554149  97.944  -59.032  50.909  1
554150  97.983  -59.032  50.865  1
554151  98.025  -59.024  50.821  1
554152  98.070  -59.012  50.777  1
554153  98.107  -59.008  50.734  1
554154  98.139  -59.012  50.693  1
554155  98.171  -59.014  50.654  1
554156  98.203  -59.017  50.618  1
554157  98.235  -59.020  50.588  1
554158  98.268  -59.022  50.564  1
554159  98.302  -59.021  50.543  1
554160  98.338  -59.020  50.521  1
554161  98.374  -59.018  50.497  1
554162  98.409  -59.010  50.471  1
554163  98.443  -58.999  50.444  1
554164  98.477  -58.989  50.417  1
554165  98.511  -58.978  50.392  1
554166  98.545  -58.968  50.367  1
554167  98.579  -58.956  50.342  1
554168  98.613  -58.946  50.316  1
554169  98.647  -58.935  50.290  1
554170  98.680  -58.924  50.264  1
554171  98.715  -58.914  50.238  1
554172  98.748  -58.903  50.213  1
554173  98.777  -58.901  50.188  1
554174  98.808  -58.898  50.162  1
554175  98.843  -58.894  50.136  1
554176  98.876  -58.893  50.108  1
554177  98.910  -58.892  50.079  1
554178  98.945  -58.896  50.048  1
554179  98.984  -58.903  50.016  1
554180  99.023  -58.910  49.980  1
554181  99.071  -58.932  49.943  1
554182  99.100  -58.936  49.907  1
554183  99.129  -58.940  49.872  1
554184  99.186  -58.938  49.837  1
554185  99.258  -58.932  49.805  1
554186  99.329  -58.926  49.773  1
554187  99.401  -58.920  49.742  1
554188  99.443  -58.925  49.710  1
554189  99.479  -58.933  49.679  1
554190  99.514  -58.940  49.647  1
554191  99.550  -58.948  49.615  1
554192  99.586  -58.955  49.584  1
554193  99.622  -58.963  49.553  1
554194  99.657  -58.971  49.521  1
554195  99.693  -58.978  49.488  1
554196  99.728  -58.985  49.453  1
554197  99.764  -58.993  49.417  1
554198  99.800  -59.000  49.382  1
554541  86.690  -55.546  57.643  4
554542  86.729  -55.559  57.636  4
554543  86.770  -55.573  57.629  4
554544  86.810  -55.586  57.622  4
554545  86.851  -55.599  57.613  4
554546  86.891  -55.612  57.602  4
554547  86.931  -55.626  57.591  4
554548  86.972  -55.640  57.578  4
554549  87.012  -55.652  57.564  4
554550  87.053  -55.666  57.551  4
554551  87.093  -55.679  57.536  4
554552  87.133  -55.693  57.515  4
554553  87.174  -55.706  57.494  4
554554  87.214  -55.719  57.472  4
554555  87.255  -55.733  57.450  4
554556  87.295  -55.746  57.427  4
554557  87.335  -55.759  57.396  4
554558  87.375  -55.773  57.362  4
554559  87.416  -55.786  57.328  4
554560  87.457  -55.799  57.293  4
554561  87.497  -55.813  57.257  4
554562  87.551  -55.818  57.220  4
554563  87.606  -55.821  57.181  4
554564  87.660  -55.825  57.140  4
554565  87.712  -55.831  57.099  4
554566  87.757  -55.838  57.057  4
554567  87.793  -55.849  57.016  4
554568  87.827  -55.860  56.976  4
554569  87.860  -55.872  56.937  4
554570  87.896  -55.884  56.898  4
554571  87.934  -55.900  56.858  4
554600  89.043  -56.364  56.055  1
554601  89.082  -56.380  56.037  1
554602  89.120  -56.396  56.021  1
554603  89.158  -56.412  56.005  1
554604  89.196  -56.428  55.991  1
554605  89.235  -56.444  55.978  1
554606  89.273  -56.460  55.966  1
554607  89.311  -56.476  55.956  1
554608  89.349  -56.492  55.948  1
554609  89.388  -56.508  55.942  1
554610  89.426  -56.523  55.936  1
554611  89.464  -56.539  55.930  1
554612  89.502  -56.556  55.925  1
554613  89.526  -56.580  55.926  1
554614  89.560  -56.596  55.926  1
554615  89.602  -56.608  55.928  1
554616  89.643  -56.618  55.932  1
554617  89.684  -56.629  55.938  1
554618  89.726  -56.640  55.944  1
554619  89.767  -56.651  55.952  1
554620  89.809  -56.661  55.960  1
554621  89.850  -56.672  55.968  1
554622  89.891  -56.683  55.975  1
554623  89.933  -56.694  55.980  1
554624  89.961  -56.710  55.983  1
554625  89.986  -56.727  55.985  1
554626  90.012  -56.744  55.983  1
554627  90.038  -56.762  55.977  1
554628  90.063  -56.778  55.965  1
554629  90.099  -56.793  55.955  1
554630  90.136  -56.808  55.934  1
554631  90.174  -56.822  55.904  1
554632  90.211  -56.836  55.870  1
554633  90.251  -56.851  55.837  1
554634  90.298  -56.868  55.802  1
554635  90.344  -56.884  55.764  1
554636  90.390  -56.899  55.726  1
554637  90.437  -56.915  55.689  1
554638  90.483  -56.932  55.653  1
554639  90.529  -56.948  55.621  1
554640  90.573  -56.960  55.592  1
554641  90.613  -56.975  55.557  1
554642  90.648  -56.991  55.519  1
554643  90.683  -57.009  55.483  1
554644  90.719  -57.026  55.454  1
554645  90.754  -57.044  55.429  1
554646  90.790  -57.061  55.407  1
554647  90.825  -57.078  55.386  1
554648  90.860  -57.094  55.365  1
554649  90.895  -57.109  55.347  1
554650  90.930  -57.126  55.332  1
554651  90.965  -57.142  55.319  1
554652  91.000  -57.159  55.308  1
554653  91.034  -57.175  55.298  1
554654  91.070  -57.191  55.289  1
554655  91.105  -57.207  55.281  1
554656  91.142  -57.223  55.276  1
554657  91.179  -57.240  55.273  1
554658  91.217  -57.257  55.273  1
554659  91.259  -57.269  55.274  1
554660  91.301  -57.286  55.276  1
554661  91.345  -57.297  55.279  1
554662  91.389  -57.307  55.282  1
554663  91.433  -57.318  55.284  1
554664  91.476  -57.329  55.281  1
554665  91.520  -57.339  55.276  1
554666  91.564  -57.349  55.271  1
554667  91.607  -57.359  55.267  1
554668  91.650  -57.369  55.266  1
554669  91.693  -57.378  55.261  1
554670  91.735  -57.388  55.256  1
554671  91.779  -57.398  55.253  1
554672  91.821  -57.407  55.258  1
554673  91.864  -57.416  55.262  1
554674  91.907  -57.426  55.267  1
554675  91.950  -57.435  55.270  1
554676  91.993  -57.445  55.271  1
554677  92.036  -57.455  55.271  1
554678  92.079  -57.464  55.273  1
554679  92.122  -57.474  55.279  1
554680  92.165  -57.484  55.284  1
554681  92.206  -57.505  55.286  1
554682  92.247  -57.528  55.281  1
554683  92.287  -57.553  55.270  1
554684  92.323  -57.579  55.251  1
554685  92.358  -57.605  55.227  1
554686  92.387  -57.625  55.201  1
554687  92.417  -57.646  55.175  1
554688  92.447  -57.667  55.150  1
554689  92.477  -57.688  55.127  1
554690  92.506  -57.708  55.109  1
554691  92.536  -57.730  55.094  1
554692  92.565  -57.750  55.076  1
554693  92.595  -57.771  55.057  1
554694  92.628  -57.788  55.040  1
554695  92.663  -57.799  55.022  1
554696  92.700  -57.809  55.003  1
554697  92.736  -57.820  54.982  1
554698  92.772  -57.830  54.958  1
554699  92.808  -57.840  54.929  1
554700  92.845  -57.846  54.899  1
554701  92.881  -57.852  54.878  1
554702  92.918  -57.858  54.859  1
554703  92.947  -57.865  54.842  1
554704  92.972  -57.871  54.825  1
554705  92.996  -57.877  54.810  1
554706  93.021  -57.881  54.799  1
554707  93.053  -57.880  54.797  1
554708  93.084  -57.880  54.797  1
554709  93.116  -57.880  54.797  1
554710  93.147  -57.879  54.796  1
554711  93.178  -57.878  54.795  1
554712  93.210  -57.877  54.788  1
554713  93.244  -57.886  54.776  1
554714  93.279  -57.894  54.758  1
554715  93.313  -57.902  54.743  1
554716  93.347  -57.911  54.738  1
554717  93.382  -57.919  54.745  1
554718  93.416  -57.927  54.753  1
554719  93.451  -57.936  54.758  1
554720  93.485  -57.944  54.765  1
554721  93.520  -57.952  54.771  1
554722  93.554  -57.960  54.770  1
554723  93.589  -57.969  54.761  1
554724  93.627  -57.989  54.749  1
554725  93.665  -58.009  54.745  1
554726  93.704  -58.028  54.745  1
554727  93.742  -58.048  54.741  1
554728  93.780  -58.068  54.734  1
554729  93.819  -58.088  54.720  1
554730  93.857  -58.108  54.710  1
554731  93.895  -58.128  54.700  1
554732  93.933  -58.147  54.689  1
554733  93.972  -58.167  54.676  1
554734  94.003  -58.183  54.661  1
554735  94.030  -58.194  54.640  1
554736  94.057  -58.206  54.617  1
554737  94.084  -58.218  54.588  1
554738  94.111  -58.230  54.556  1
554739  94.137  -58.242  54.521  1
554740  94.164  -58.253  54.480  1
554741  94.191  -58.266  54.437  1
554742  94.217  -58.277  54.393  1
554743  94.244  -58.289  54.348  1
554744  94.271  -58.300  54.306  1
554745  94.297  -58.313  54.267  1
554746  94.324  -58.325  54.234  1
554747  94.355  -58.336  54.203  1
554748  94.388  -58.347  54.173  1
554749  94.419  -58.360  54.143  1
554750  94.450  -58.374  54.113  1
554751  94.480  -58.387  54.087  1
554752  94.511  -58.400  54.060  1
554753  94.542  -58.413  54.030  1
554754  94.572  -58.427  53.996  1
554755  94.603  -58.440  53.962  1
554756  94.634  -58.454  53.932  1
554757  94.665  -58.466  53.905  1
554758  94.695  -58.480  53.877  1
554759  94.736  -58.491  53.851  1
554760  94.779  -58.502  53.829  1
554761  94.826  -58.514  53.809  1
554762  94.873  -58.527  53.786  1
554763  94.924  -58.537  53.763  1
554764  94.977  -58.547  53.735  1
554765  95.031  -58.557  53.707  1
554766  95.084  -58.567  53.677  1
554767  95.137  -58.576  53.647  1
554768  95.190  -58.585  53.617  1
554769  95.244  -58.595  53.592  1
554770  95.297  -58.604  53.568  1
554771  95.350  -58.614  53.544  1
554772  95.392  -58.620  53.519  1
554773  95.420  -58.620  53.494  1
554774  95.447  -58.620  53.466  1
554775  95.476  -58.624  53.443  1
554776  95.507  -58.637  53.420  1
554777  95.539  -58.651  53.392  1
554778  95.570  -58.664  53.360  1
554779  95.602  -58.678  53.334  1
554780  95.633  -58.691  53.311  1
554781  95.665  -58.705  53.287  1
554782  95.696  -58.718  53.262  1
554783  95.728  -58.732  53.239  1
554784  95.759  -58.745  53.215  1
554785  95.790  -58.757  53.188  1
554786  95.820  -58.765  53.158  1
554787  95.849  -58.773  53.125  1
554788  95.881  -58.780  53.092  1
554789  95.912  -58.787  53.060  1
554790  95.942  -58.794  53.032  1
554791  95.972  -58.801  52.998  1
554792  96.003  -58.808  52.962  1
554793  96.033  -58.814  52.930  1
554794  96.063  -58.822  52.901  1
554795  96.093  -58.829  52.872  1
554796  96.126  -58.835  52.843  1
554797  96.161  -58.842  52.818  1
554798  96.196  -58.848  52.789  1
554799  96.231  -58.852  52.760  1
554800  96.266  -58.855  52.732  1
554801  96.301  -58.858  52.707  1
554802  96.335  -58.861  52.679  1
554803  96.370  -58.864  52.651  1
554804  96.404  -58.867  52.624  1
554805  96.439  -58.871  52.596  1
554806  96.474  -58.874  52.568  1
554807  96.507  -58.876  52.537  1
554808  96.538  -58.877  52.504  1
554809  96.569  -58.877  52.471  1
554810  96.600  -58.879  52.436  1
554811  96.631  -58.880  52.399  1
554812  96.662  -58.880  52.363  1
554813  96.693  -58.881  52.331  1
554814  96.724  -58.882  52.302  1
554815  96.756  -58.886  52.269  1
554816  96.788  -58.892  52.233  1
554817  96.820  -58.897  52.197  1
554818  96.852  -58.902  52.159  1
554819  96.885  -58.905  52.121  1
554820  96.919  -58.906  52.083  1
554821  96.952  -58.907  52.045  1
554822  96.986  -58.908  52.007  1
554823  97.020  -58.908  51.971  1
554824  97.053  -58.908  51.934  1
554825  97.087  -58.911  51.898  1
554826  97.120  -58.915  51.864  1
554827  97.153  -58.920  51.832  1
554828  97.186  -58.924  51.800  1
554829  97.220  -58.927  51.766  1
554830  97.254  -58.930  51.728  1
554831  97.289  -58.934  51.687  1
554832  97.324  -58.937  51.644  1
554833  97.357  -58.942  51.602  1
554834  97.389  -58.946  51.561  1
554835  97.422  -58.950  51.519  1
554836  97.455  -58.954  51.474  1
554837  97.488  -58.958  51.434  1
554838  97.521  -58.962  51.394  1
554839  97.555  -58.967  51.354  1
554840  97.589  -58.974  51.312  1
554841  97.624  -58.982  51.268  1
554842  97.659  -58.990  51.221  1
554843  97.693  -58.997  51.175  1
554844  97.725  -59.002  51.129  1
554845  97.757  -59.006  51.084  1
554846  97.796  -59.004  51.042  1
554847  97.836  -59.002  51.002  1
554848  97.875  -59.002  50.958  1
554849  97.913  -59.002  50.918  1
554850  97.951  -59.002  50.877  1
554851  97.992  -58.998  50.833  1
554852  98.036  -58.986  50.789  1
554853  98.080  -58.974  50.743  1
554854  98.118  -58.971  50.701  1
554855  98.150  -58.974  50.661  1
554856  98.182  -58.976  50.624  1
554857  98.214  -58.979  50.590  1
554858  98.246  -58.981  50.561  1
554859  98.277  -58.984  50.537  1
554860  98.308  -58.987  50.514  1
554861  98.344  -58.985  50.490  1
554862  98.380  -58.983  50.465  1
554863  98.416  -58.978  50.440  1
554864  98.450  -58.968  50.415  1
554865  98.484  -58.957  50.390  1
554866  98.518  -58.946  50.367  1
554867  98.552  -58.935  50.344  1
554868  98.585  -58.924  50.322  1
554869  98.620  -58.914  50.299  1
554870  98.653  -58.903  50.274  1
554871  98.688  -58.892  50.250  1
554872  98.721  -58.882  50.227  1
554873  98.750  -58.879  50.204  1
554874  98.779  -58.877  50.181  1
554875  98.812  -58.874  50.158  1
554876  98.847  -58.870  50.135  1
554877  98.880  -58.867  50.109  1
554878  98.914  -58.867  50.080  1
554879  98.946  -58.867  50.050  1
554880  98.982  -58.868  50.018  1
554881  99.020  -58.875  49.985  1
554882  99.060  -58.883  49.948  1
554883  99.098  -58.899  49.912  1
554884  99.127  -58.903  49.877  1
554885  99.193  -58.899  49.843  1
554886  99.265  -58.892  49.810  1
554887  99.337  -58.886  49.779  1
554888  99.408  -58.881  49.748  1
554889  99.444  -58.889  49.717  1
554890  99.480  -58.896  49.686  1
554891  99.515  -58.904  49.655  1
554892  99.551  -58.911  49.623  1
554893  99.586  -58.918  49.592  1
554894  99.622  -58.926  49.561  1
554895  99.658  -58.933  49.529  1
554896  99.694  -58.941  49.497  1
554897  99.729  -58.949  49.462  1
554898  99.765  -58.956  49.427  1
554899  99.800  -58.964  49.393  1
555242  86.720  -55.495  57.643  4
555243  86.755  -55.511  57.636  4
555244  86.790  -55.527  57.630  4
555245  86.827  -55.542  57.623  4
555246  86.867  -55.556  57.615  4
555247  86.908  -55.569  57.605  4
555248  86.948  -55.583  57.594  4
555249  86.989  -55.596  57.582  4
555250  87.029  -55.609  57.570  4
555251  87.069  -55.623  57.557  4
555252  87.110  -55.636  57.543  4
555253  87.150  -55.649  57.524  4
555254  87.191  -55.663  57.505  4
555255  87.231  -55.676  57.484  4
555256  87.271  -55.690  57.463  4
555257  87.311  -55.702  57.441  4
555258  87.352  -55.716  57.414  4
555259  87.393  -55.730  57.383  4
555260  87.433  -55.743  57.349  4
555261  87.473  -55.756  57.315  4
555262  87.521  -55.765  57.280  4
555263  87.576  -55.769  57.243  4
555264  87.631  -55.773  57.205  4
555265  87.686  -55.777  57.164  4
555266  87.732  -55.784  57.123  4
555267  87.772  -55.793  57.082  4
555268  87.805  -55.804  57.039  4
555269  87.839  -55.816  57.000  4
555270  87.875  -55.830  56.959  4
555271  87.913  -55.846  56.919  4
555272  87.952  -55.862  56.878  4
555273  87.990  -55.878  56.839  4
555301  89.061  -56.326  56.052  1
555302  89.099  -56.342  56.033  1
555303  89.137  -56.357  56.016  1
555304  89.176  -56.373  56.001  1
555305  89.214  -56.389  55.987  1
555306  89.252  -56.405  55.973  1
555307  89.291  -56.421  55.962  1
555308  89.329  -56.437  55.952  1
555309  89.367  -56.453  55.944  1
555310  89.405  -56.469  55.937  1
555311  89.444  -56.485  55.932  1
555312  89.482  -56.501  55.927  1
555313  89.520  -56.517  55.923  1
555314  89.544  -56.541  55.923  1
555315  89.580  -56.557  55.925  1
555316  89.621  -56.567  55.928  1
555317  89.663  -56.579  55.933  1
555318  89.704  -56.589  55.940  1
555319  89.745  -56.600  55.948  1
555320  89.787  -56.611  55.957  1
555321  89.828  -56.622  55.967  1
555322  89.870  -56.633  55.977  1
555323  89.911  -56.643  55.987  1
555324  89.943  -56.658  55.996  1
555325  89.968  -56.675  56.002  1
555326  89.994  -56.693  56.007  1
555327  90.020  -56.709  56.010  1
555328  90.045  -56.727  56.009  1
555329  90.074  -56.743  56.005  1
555330  90.111  -56.758  56.001  1
555331  90.148  -56.771  55.978  1
555332  90.185  -56.786  55.942  1
555333  90.225  -56.801  55.901  1
555334  90.271  -56.817  55.860  1
555335  90.317  -56.833  55.820  1
555336  90.364  -56.849  55.778  1
555337  90.410  -56.865  55.737  1
555338  90.456  -56.881  55.697  1
555339  90.501  -56.895  55.659  1
555340  90.544  -56.907  55.623  1
555341  90.587  -56.919  55.588  1
555342  90.630  -56.931  55.553  1
555343  90.669  -56.947  55.518  1
555344  90.704  -56.965  55.485  1
555345  90.739  -56.982  55.457  1
555346  90.775  -56.999  55.434  1
555347  90.810  -57.016  55.412  1
555348  90.845  -57.034  55.390  1
555349  90.881  -57.051  55.370  1
555350  90.916  -57.069  55.352  1
555351  90.951  -57.086  55.337  1
555352  90.987  -57.103  55.325  1
555353  91.022  -57.120  55.313  1
555354  91.057  -57.138  55.303  1
555355  91.093  -57.155  55.294  1
555356  91.128  -57.172  55.286  1
555357  91.163  -57.189  55.281  1
555358  91.198  -57.205  55.277  1
555359  91.234  -57.222  55.276  1
555360  91.274  -57.237  55.276  1
555361  91.318  -57.247  55.275  1
555362  91.361  -57.257  55.275  1
555363  91.404  -57.267  55.275  1
555364  91.447  -57.276  55.276  1
555365  91.490  -57.286  55.275  1
555366  91.533  -57.296  55.273  1
555367  91.576  -57.305  55.272  1
555368  91.618  -57.315  55.272  1
555369  91.662  -57.325  55.272  1
555370  91.705  -57.334  55.269  1
555371  91.747  -57.344  55.263  1
555372  91.790  -57.354  55.260  1
555373  91.834  -57.363  55.261  1
555374  91.876  -57.373  55.267  1
555375  91.919  -57.382  55.271  1
555376  91.962  -57.391  55.275  1
555377  92.005  -57.401  55.278  1
555378  92.048  -57.411  55.279  1
555379  92.091  -57.420  55.280  1
555380  92.134  -57.430  55.285  1
555381  92.176  -57.447  55.292  1
555382  92.217  -57.470  55.295  1
555383  92.258  -57.494  55.292  1
555384  92.298  -57.517  55.281  1
555385  92.335  -57.545  55.261  1
555386  92.371  -57.571  55.238  1
555387  92.405  -57.595  55.211  1
555388  92.434  -57.616  55.186  1
555389  92.464  -57.637  55.162  1
555390  92.494  -57.658  55.137  1
555391  92.523  -57.679  55.115  1
555392  92.553  -57.699  55.096  1
555393  92.583  -57.720  55.075  1
555394  92.613  -57.741  55.054  1
555395  92.647  -57.753  55.033  1
555396  92.684  -57.764  55.012  1
555397  92.720  -57.774  54.990  1
555398  92.756  -57.785  54.967  1
555399  92.792  -57.796  54.943  1
555400  92.828  -57.806  54.918  1
555401  92.864  -57.813  54.894  1
555402  92.901  -57.819  54.875  1
555403  92.934  -57.825  54.858  1
555404  92.959  -57.831  54.844  1
555405  92.983  -57.837  54.834  1
555406  93.007  -57.843  54.827  1
555407  93.034  -57.848  54.824  1
555408  93.065  -57.847  54.826  1
555409  93.096  -57.846  54.829  1
555410  93.127  -57.846  54.830  1
555411  93.159  -57.845  54.829  1
555412  93.190  -57.844  54.828  1
555413  93.221  -57.843  54.823  1
555414  93.253  -57.843  54.811  1
555415  93.287  -57.850  54.790  1
555416  93.322  -57.858  54.767  1
555417  93.356  -57.867  54.749  1
555418  93.390  -57.875  54.744  1
555419  93.425  -57.883  54.754  1
555420  93.459  -57.891  54.760  1
555421  93.494  -57.899  54.765  1
555422  93.528  -57.908  54.769  1
555423  93.562  -57.916  54.771  1
555424  93.597  -57.927  54.764  1
555425  93.636  -57.946  54.752  1
555426  93.674  -57.966  54.741  1
555427  93.712  -57.986  54.734  1
555428  93.751  -58.006  54.728  1
555429  93.789  -58.025  54.718  1
555430  93.827  -58.045  54.707  1
555431  93.865  -58.065  54.697  1
555432  93.904  -58.085  54.686  1
555433  93.942  -58.105  54.673  1
555434  93.980  -58.125  54.659  1
555435  94.018  -58.144  54.644  1
555436  94.052  -58.161  54.626  1
555437  94.078  -58.172  54.606  1
555438  94.105  -58.184  54.582  1
555439  94.132  -58.196  54.556  1
555440  94.158  -58.208  54.528  1
555441  94.186  -58.220  54.492  1
555442  94.212  -58.231  54.452  1
555443  94.239  -58.244  54.407  1
555444  94.266  -58.255  54.361  1
555445  94.292  -58.267  54.315  1
555446  94.319  -58.278  54.272  1
555447  94.346  -58.291  54.238  1
555448  94.372  -58.303  54.207  1
555449  94.400  -58.315  54.176  1
555450  94.429  -58.328  54.143  1
555451  94.458  -58.342  54.110  1
555452  94.486  -58.355  54.080  1
555453  94.515  -58.369  54.053  1
555454  94.544  -58.382  54.024  1
555455  94.573  -58.395  53.991  1
555456  94.604  -58.409  53.955  1
555457  94.635  -58.422  53.924  1
555458  94.666  -58.435  53.897  1
555459  94.696  -58.448  53.869  1
555460  94.732  -58.460  53.840  1
555461  94.779  -58.473  53.812  1
555462  94.832  -58.482  53.790  1
555463  94.885  -58.491  53.766  1
555464  94.938  -58.501  53.740  1
555465  94.992  -58.511  53.713  1
555466  95.045  -58.520  53.685  1
555467  95.098  -58.530  53.656  1
555468  95.151  -58.540  53.624  1
555469  95.205  -58.549  53.599  1
555470  95.258  -58.559  53.575  1
555471  95.312  -58.569  53.551  1
555472  95.365  -58.579  53.527  1
555473  95.394  -58.579  53.502  1
555474  95.421  -58.580  53.478  1
555475  95.449  -58.580  53.451  1
555476  95.477  -58.582  53.422  1
555477  95.509  -58.595  53.396  1
555478  95.540  -58.608  53.372  1
555479  95.571  -58.622  53.349  1
555480  95.603  -58.636  53.326  1
555481  95.634  -58.649  53.300  1
555482  95.666  -58.662  53.277  1
555483  95.697  -58.676  53.256  1
555484  95.729  -58.689  53.234  1
555485  95.760  -58.703  53.212  1
555486  95.792  -58.716  53.182  1
555487  95.823  -58.730  53.153  1
555488  95.854  -58.741  53.121  1
555489  95.885  -58.748  53.088  1
555490  95.915  -58.755  53.056  1
555491  95.945  -58.762  53.029  1
555492  95.975  -58.769  52.990  1
555493  96.006  -58.776  52.955  1
555494  96.036  -58.783  52.924  1
555495  96.066  -58.790  52.894  1
555496  96.096  -58.797  52.862  1
555497  96.130  -58.802  52.834  1
555498  96.165  -58.805  52.805  1
555499  96.199  -58.808  52.773  1
555500  96.234  -58.811  52.743  1
555501  96.268  -58.814  52.718  1
555502  96.303  -58.817  52.693  1
555503  96.338  -58.820  52.663  1
555504  96.373  -58.824  52.630  1
555505  96.407  -58.827  52.598  1
555506  96.442  -58.830  52.568  1
555507  96.477  -58.833  52.539  1
555508  96.512  -58.836  52.508  1
555509  96.543  -58.837  52.476  1
555510  96.574  -58.838  52.443  1
555511  96.605  -58.839  52.406  1
555512  96.637  -58.839  52.367  1
555513  96.667  -58.840  52.331  1
555514  96.698  -58.842  52.297  1
555515  96.730  -58.842  52.266  1
555516  96.761  -58.848  52.231  1
555517  96.794  -58.854  52.195  1
555518  96.825  -58.859  52.159  1
555519  96.858  -58.864  52.123  1
555520  96.890  -58.870  52.087  1
555521  96.923  -58.871  52.049  1
555522  96.957  -58.871  52.009  1
555523  96.991  -58.871  51.971  1
555524  97.024  -58.872  51.935  1
555525  97.058  -58.874  51.901  1
555526  97.091  -58.877  51.863  1
555527  97.124  -58.881  51.827  1
555528  97.158  -58.885  51.793  1
555529  97.191  -58.889  51.761  1
555530  97.225  -58.892  51.728  1
555531  97.258  -58.896  51.692  1
555532  97.293  -58.900  51.654  1
555533  97.327  -58.903  51.612  1
555534  97.360  -58.908  51.567  1
555535  97.392  -58.911  51.523  1
555536  97.425  -58.916  51.483  1
555537  97.457  -58.920  51.442  1
555538  97.491  -58.924  51.400  1
555539  97.524  -58.928  51.359  1
555540  97.557  -58.933  51.318  1
555541  97.592  -58.940  51.276  1
555542  97.628  -58.949  51.236  1
555543  97.663  -58.957  51.193  1
555544  97.698  -58.966  51.150  1
555545  97.730  -58.971  51.105  1
555546  97.765  -58.974  51.060  1
555547  97.805  -58.971  51.016  1
555548  97.843  -58.971  50.972  1
555549  97.881  -58.971  50.929  1
555550  97.920  -58.971  50.885  1
555551  97.958  -58.971  50.841  1
555552  98.002  -58.960  50.798  1
555553  98.046  -58.948  50.753  1
555554  98.091  -58.936  50.710  1
555555  98.128  -58.933  50.671  1
555556  98.160  -58.935  50.633  1
555557  98.193  -58.938  50.598  1
555558  98.224  -58.940  50.565  1
555559  98.255  -58.943  50.534  1
555560  98.287  -58.946  50.509  1
555561  98.318  -58.948  50.485  1
555562  98.350  -58.949  50.461  1
555563  98.386  -58.948  50.436  1
555564  98.422  -58.946  50.412  1
555565  98.456  -58.936  50.390  1
555566  98.490  -58.924  50.366  1
555567  98.524  -58.914  50.341  1
555568  98.558  -58.903  50.319  1
555569  98.592  -58.892  50.299  1
555570  98.626  -58.882  50.279  1
555571  98.660  -58.871  50.257  1
555572  98.694  -58.860  50.238  1
555573  98.723  -58.858  50.218  1
555574  98.751  -58.855  50.196  1
555575  98.781  -58.852  50.175  1
555576  98.816  -58.849  50.155  1
555577  98.850  -58.845  50.131  1
555578  98.884  -58.842  50.106  1
555579  98.918  -58.842  50.078  1
555580  98.950  -58.841  50.048  1
555581  98.984  -58.841  50.017  1
555582  99.017  -58.841  49.985  1
555583  99.056  -58.848  49.951  1
555584  99.097  -58.862  49.916  1
555585  99.129  -58.865  49.881  1
555586  99.201  -58.859  49.847  1
555587  99.273  -58.853  49.815  1
555588  99.345  -58.848  49.784  1
555589  99.409  -58.845  49.753  1
555590  99.445  -58.852  49.723  1
555591  99.481  -58.859  49.692  1
555592  99.516  -58.867  49.661  1
555593  99.552  -58.874  49.630  1
555594  99.587  -58.882  49.600  1
555595  99.623  -58.889  49.569  1
555596  99.659  -58.897  49.538  1
555597  99.695  -58.905  49.505  1
555598  99.730  -58.912  49.472  1
555599  99.766  -58.919  49.436  1
555600  99.801  -58.927  49.402  1
555944  86.785  -55.461  57.636  4
555945  86.820  -55.477  57.630  4
555946  86.855  -55.493  57.624  4
555947  86.890  -55.510  57.618  4
555948  86.925  -55.526  57.609  4
555949  86.965  -55.539  57.598  4
555950  87.005  -55.552  57.587  4
555951  87.046  -55.566  57.575  4
555952  87.086  -55.580  57.563  4
555953  87.127  -55.593  57.550  4
555954  87.167  -55.606  57.533  4
555955  87.207  -55.619  57.515  4
555956  87.248  -55.633  57.496  4
555957  87.288  -55.646  57.476  4
555958  87.329  -55.659  57.455  4
555959  87.369  -55.673  57.430  4
555960  87.409  -55.686  57.400  4
555961  87.450  -55.699  57.369  4
555962  87.491  -55.712  57.336  4
555963  87.546  -55.716  57.303  4
555964  87.601  -55.720  57.266  4
555965  87.656  -55.724  57.229  4
555966  87.708  -55.729  57.189  4
555967  87.750  -55.737  57.148  4
555968  87.784  -55.749  57.107  4
555969  87.818  -55.760  57.064  4
555970  87.855  -55.775  57.023  4
555971  87.893  -55.791  56.982  4
555972  87.931  -55.807  56.940  4
555973  87.970  -55.824  56.899  4
555974  88.008  -55.840  56.859  4
556001  89.041  -56.271  56.068  1
556002  89.079  -56.287  56.049  1
556003  89.117  -56.303  56.031  1
556004  89.156  -56.319  56.013  1
556005  89.194  -56.335  55.996  1
556006  89.232  -56.351  55.982  1
556007  89.270  -56.367  55.969  1
556008  89.308  -56.382  55.957  1
556009  89.346  -56.398  55.948  1
556010  89.385  -56.415  55.940  1
556011  89.423  -56.431  55.934  1
556012  89.461  -56.447  55.929  1
556013  89.499  -56.463  55.925  1
556014  89.538  -56.479  55.921  1
556015  89.563  -56.502  55.921  1
556016  89.599  -56.517  55.923  1
556017  89.640  -56.528  55.926  1
556018  89.682  -56.539  55.932  1
556019  89.723  -56.550  55.941  1
556020  89.765  -56.561  55.950  1
556021  89.806  -56.571  55.961  1
556022  89.847  -56.583  55.973  1
556023  89.889  -56.593  55.986  1
556024  89.924  -56.606  56.000  1
556025  89.950  -56.624  56.011  1
556026  89.976  -56.640  56.021  1
556027  90.002  -56.658  56.029  1
556028  90.027  -56.674  56.039  1
556029  90.052  -56.692  56.050  1
556030  90.085  -56.707  56.055  1
556031  90.122  -56.721  56.056  1
556032  90.159  -56.736  56.030  1
556033  90.198  -56.751  55.986  1
556034  90.244  -56.767  55.937  1
556035  90.291  -56.783  55.885  1
556036  90.337  -56.799  55.838  1
556037  90.383  -56.815  55.792  1
556038  90.429  -56.830  55.748  1
556039  90.472  -56.842  55.705  1
556040  90.515  -56.854  55.665  1
556041  90.558  -56.866  55.626  1
556042  90.602  -56.878  55.589  1
556043  90.645  -56.891  55.554  1
556044  90.688  -56.903  55.520  1
556045  90.724  -56.920  55.488  1
556046  90.759  -56.937  55.461  1
556047  90.795  -56.955  55.439  1
556048  90.830  -56.972  55.417  1
556049  90.866  -56.990  55.395  1
556050  90.901  -57.006  55.376  1
556051  90.936  -57.024  55.358  1
556052  90.971  -57.041  55.344  1
556053  91.007  -57.059  55.331  1
556054  91.042  -57.076  55.320  1
556055  91.078  -57.094  55.310  1
556056  91.113  -57.110  55.300  1
556057  91.148  -57.128  55.291  1
556058  91.183  -57.145  55.286  1
556059  91.219  -57.163  55.282  1
556060  91.254  -57.180  55.280  1
556061  91.288  -57.194  55.279  1
556062  91.330  -57.203  55.277  1
556063  91.373  -57.213  55.277  1
556064  91.416  -57.222  55.276  1
556065  91.459  -57.232  55.278  1
556066  91.502  -57.242  55.280  1
556067  91.545  -57.252  55.281  1
556068  91.588  -57.261  55.283  1
556069  91.631  -57.271  55.284  1
556070  91.673  -57.281  55.283  1
556071  91.717  -57.290  55.278  1
556072  91.759  -57.300  55.273  1
556073  91.802  -57.310  55.271  1
556074  91.845  -57.319  55.276  1
556075  91.888  -57.329  55.284  1
556076  91.931  -57.338  55.292  1
556077  91.974  -57.348  55.299  1
556078  92.017  -57.357  55.305  1
556079  92.060  -57.367  55.308  1
556080  92.103  -57.376  55.306  1
556081  92.145  -57.389  55.304  1
556082  92.187  -57.413  55.304  1
556083  92.227  -57.436  55.303  1
556084  92.269  -57.459  55.300  1
556085  92.309  -57.482  55.292  1
556086  92.346  -57.510  55.276  1
556087  92.383  -57.536  55.253  1
556088  92.420  -57.563  55.228  1
556089  92.452  -57.586  55.204  1
556090  92.482  -57.607  55.181  1
556091  92.511  -57.628  55.156  1
556092  92.541  -57.648  55.135  1
556093  92.570  -57.670  55.114  1
556094  92.600  -57.690  55.093  1
556095  92.631  -57.708  55.070  1
556096  92.667  -57.719  55.046  1
556097  92.704  -57.730  55.023  1
556098  92.739  -57.740  55.001  1
556099  92.776  -57.751  54.978  1
556100  92.812  -57.761  54.956  1
556101  92.848  -57.772  54.933  1
556102  92.884  -57.780  54.917  1
556103  92.921  -57.786  54.902  1
556104  92.946  -57.792  54.890  1
556105  92.971  -57.798  54.879  1
556106  92.995  -57.804  54.870  1
556107  93.019  -57.810  54.865  1
556108  93.045  -57.814  54.864  1
556109  93.076  -57.813  54.863  1
556110  93.108  -57.812  54.863  1
556111  93.139  -57.811  54.860  1
556112  93.170  -57.811  54.855  1
556113  93.202  -57.810  54.851  1
556114  93.233  -57.809  54.851  1
556115  93.265  -57.809  54.841  1
556116  93.296  -57.808  54.821  1
556117  93.330  -57.814  54.795  1
556118  93.364  -57.822  54.766  1
556119  93.399  -57.830  54.746  1
556120  93.433  -57.839  54.751  1
556121  93.468  -57.847  54.758  1
556122  93.502  -57.855  54.763  1
556123  93.537  -57.864  54.764  1
556124  93.571  -57.872  54.767  1
556125  93.607  -57.884  54.763  1
556126  93.645  -57.904  54.753  1
556127  93.683  -57.924  54.739  1
556128  93.721  -57.943  54.728  1
556129  93.760  -57.963  54.721  1
556130  93.798  -57.983  54.712  1
556131  93.836  -58.003  54.701  1
556132  93.874  -58.023  54.688  1
556133  93.913  -58.043  54.674  1
556134  93.951  -58.062  54.658  1
556135  93.989  -58.082  54.642  1
556136  94.028  -58.102  54.625  1
556137  94.066  -58.122  54.606  1
556138  94.100  -58.139  54.587  1
556139  94.127  -58.150  54.567  1
556140  94.153  -58.162  54.544  1
556141  94.180  -58.175  54.517  1
556142  94.207  -58.186  54.486  1
556143  94.234  -58.198  54.450  1
556144  94.260  -58.209  54.412  1
556145  94.287  -58.222  54.370  1
556146  94.314  -58.233  54.324  1
556147  94.341  -58.245  54.276  1
556148  94.367  -58.256  54.240  1
556149  94.394  -58.269  54.208  1
556150  94.423  -58.282  54.178  1
556151  94.452  -58.295  54.146  1
556152  94.480  -58.309  54.112  1
556153  94.509  -58.322  54.076  1
556154  94.537  -58.335  54.048  1
556155  94.566  -58.349  54.018  1
556156  94.595  -58.363  53.986  1
556157  94.623  -58.375  53.951  1
556158  94.652  -58.389  53.916  1
556159  94.681  -58.403  53.889  1
556160  94.708  -58.416  53.860  1
556161  94.735  -58.428  53.828  1
556162  94.791  -58.437  53.797  1
556163  94.846  -58.446  53.771  1
556164  94.900  -58.456  53.745  1
556165  94.953  -58.466  53.718  1
556166  95.006  -58.475  53.691  1
556167  95.059  -58.485  53.664  1
556168  95.113  -58.495  53.633  1
556169  95.166  -58.504  53.602  1
556170  95.219  -58.513  53.577  1
556171  95.273  -58.523  53.554  1
556172  95.326  -58.532  53.530  1
556173  95.368  -58.538  53.505  1
556174  95.396  -58.539  53.479  1
556175  95.423  -58.539  53.455  1
556176  95.451  -58.540  53.429  1
556177  95.478  -58.540  53.400  1
556178  95.510  -58.553  53.372  1
556179  95.541  -58.567  53.349  1
556180  95.572  -58.579  53.331  1
556181  95.604  -58.593  53.314  1
556182  95.635  -58.607  53.292  1
556183  95.667  -58.620  53.271  1
556184  95.699  -58.633  53.250  1
556185  95.732  -58.647  53.229  1
556186  95.764  -58.661  53.206  1
556187  95.796  -58.674  53.176  1
556188  95.829  -58.688  53.149  1
556189  95.861  -58.701  53.124  1
556190  95.891  -58.708  53.095  1
556191  95.921  -58.715  53.060  1
556192  95.952  -58.722  53.026  1
556193  95.982  -58.729  52.983  1
556194  96.013  -58.735  52.946  1
556195  96.043  -58.742  52.915  1
556196  96.073  -58.748  52.886  1
556197  96.105  -58.757  52.855  1
556198  96.137  -58.767  52.825  1
556199  96.169  -58.766  52.789  1
556200  96.202  -58.767  52.758  1
556201  96.237  -58.770  52.732  1
556202  96.271  -58.773  52.707  1
556203  96.306  -58.777  52.678  1
556204  96.341  -58.780  52.646  1
556205  96.376  -58.783  52.614  1
556206  96.410  -58.786  52.581  1
556207  96.445  -58.789  52.548  1
556208  96.480  -58.792  52.516  1
556209  96.515  -58.795  52.484  1
556210  96.548  -58.797  52.450  1
556211  96.579  -58.798  52.416  1
556212  96.610  -58.799  52.378  1
556213  96.642  -58.800  52.342  1
556214  96.672  -58.801  52.308  1
556215  96.703  -58.802  52.272  1
556216  96.735  -58.805  52.233  1
556217  96.767  -58.810  52.197  1
556218  96.799  -58.816  52.161  1
556219  96.831  -58.821  52.126  1
556220  96.863  -58.827  52.091  1
556221  96.895  -58.832  52.057  1
556222  96.928  -58.834  52.018  1
556223  96.962  -58.835  51.978  1
556224  96.996  -58.836  51.938  1
556225  97.029  -58.836  51.902  1
556226  97.063  -58.839  51.870  1
556227  97.096  -58.842  51.830  1
556228  97.129  -58.846  51.792  1
556229  97.163  -58.850  51.757  1
556230  97.196  -58.855  51.725  1
556231  97.229  -58.858  51.693  1
556232  97.262  -58.862  51.658  1
556233  97.297  -58.866  51.622  1
556234  97.330  -58.869  51.581  1
556235  97.363  -58.874  51.537  1
556236  97.395  -58.878  51.492  1
556237  97.428  -58.882  51.450  1
556238  97.460  -58.886  51.410  1
556239  97.494  -58.890  51.367  1
556240  97.527  -58.895  51.326  1
556241  97.561  -58.899  51.286  1
556242  97.596  -58.908  51.245  1
556243  97.631  -58.916  51.207  1
556244  97.666  -58.924  51.167  1
556245  97.702  -58.933  51.125  1
556246  97.736  -58.941  51.081  1
556247  97.773  -58.941  51.036  1
556248  97.812  -58.941  50.992  1
556249  97.850  -58.940  50.946  1
556250  97.888  -58.940  50.904  1
556251  97.927  -58.940  50.861  1
556252  97.968  -58.934  50.816  1
556253  98.012  -58.922  50.772  1
556254  98.057  -58.911  50.728  1
556255  98.101  -58.899  50.687  1
556256  98.139  -58.894  50.649  1
556257  98.171  -58.897  50.613  1
556258  98.203  -58.899  50.579  1
556259  98.234  -58.902  50.547  1
556260  98.265  -58.905  50.516  1
556261  98.296  -58.907  50.490  1
556262  98.327  -58.909  50.463  1
556263  98.359  -58.912  50.438  1
556264  98.392  -58.912  50.414  1
556265  98.428  -58.911  50.390  1
556266  98.463  -58.903  50.369  1
556267  98.497  -58.892  50.344  1
556268  98.531  -58.882  50.319  1
556269  98.565  -58.871  50.296  1
556270  98.599  -58.861  50.276  1
556271  98.633  -58.849  50.257  1
556272  98.667  -58.839  50.240  1
556273  98.696  -58.836  50.224  1
556274  98.725  -58.833  50.205  1
556275  98.754  -58.831  50.186  1
556276  98.785  -58.828  50.166  1
556277  98.819  -58.824  50.147  1
556278  98.854  -58.820  50.124  1
556279  98.888  -58.817  50.099  1
556280  98.922  -58.816  50.072  1
556281  98.954  -58.816  50.044  1
556282  98.988  -58.815  50.015  1
556283  99.021  -58.814  49.985  1
556284  99.054  -58.814  49.952  1
556285  99.094  -58.823  49.918  1
556286  99.137  -58.826  49.883  1
556287  99.209  -58.820  49.850  1
556288  99.280  -58.814  49.818  1
556289  99.352  -58.808  49.787  1
556290  99.410  -58.808  49.757  1
556291  99.446  -58.815  49.728  1
556292  99.481  -58.823  49.698  1
556293  99.517  -58.830  49.668  1
556294  99.553  -58.838  49.637  1
556295  99.588  -58.846  49.607  1
556296  99.624  -58.852  49.577  1
556297  99.660  -58.860  49.546  1
556298  99.695  -58.867  49.513  1
556299  99.731  -58.875  49.479  1
556300  99.767  -58.883  49.445  1
556301  99.802  -58.890  49.411  1
556646  86.850  -55.427  57.631  4
556647  86.885  -55.443  57.624  4
556648  86.920  -55.460  57.619  4
556649  86.955  -55.476  57.611  4
556650  86.990  -55.492  57.601  4
556651  87.025  -55.508  57.591  4
556652  87.063  -55.523  57.580  4
556653  87.103  -55.536  57.569  4
556654  87.143  -55.549  57.556  4
556655  87.184  -55.563  57.541  4
556656  87.224  -55.576  57.524  4
556657  87.265  -55.589  57.507  4
556658  87.305  -55.603  57.489  4
556659  87.345  -55.616  57.468  4
556660  87.386  -55.630  57.444  4
556661  87.426  -55.643  57.417  4
556662  87.467  -55.656  57.388  4
556663  87.516  -55.664  57.357  4
556664  87.571  -55.668  57.325  4
556665  87.626  -55.671  57.289  4
556666  87.681  -55.675  57.253  4
556667  87.728  -55.682  57.214  4
556668  87.762  -55.693  57.173  4
556669  87.796  -55.705  57.132  4
556670  87.834  -55.721  57.090  4
556671  87.872  -55.737  57.048  4
556672  87.911  -55.753  57.006  4
556673  87.949  -55.769  56.964  4
556674  87.987  -55.785  56.922  4
556675  88.026  -55.801  56.880  4
556676  88.064  -55.817  56.840  4
556702  89.058  -56.232  56.065  1
556703  89.097  -56.248  56.047  1
556704  89.135  -56.264  56.028  1
556705  89.173  -56.280  56.010  1
556706  89.211  -56.296  55.994  1
556707  89.250  -56.312  55.979  1
556708  89.288  -56.328  55.966  1
556709  89.326  -56.345  55.954  1
556710  89.365  -56.360  55.945  1
556711  89.403  -56.376  55.937  1
556712  89.441  -56.392  55.930  1
556713  89.479  -56.408  55.925  1
556714  89.518  -56.424  55.921  1
556715  89.556  -56.440  55.919  1
556716  89.582  -56.463  55.919  1
556717  89.618  -56.477  55.920  1
556718  89.660  -56.489  55.924  1
556719  89.701  -56.499  55.931  1
556720  89.743  -56.510  55.940  1
556721  89.784  -56.521  55.951  1
556722  89.826  -56.532  55.964  1
556723  89.867  -56.542  55.978  1
556724  89.906  -56.555  55.993  1
556725  89.932  -56.571  56.009  1
556726  89.957  -56.589  56.023  1
556727  89.983  -56.605  56.036  1
556728  90.009  -56.623  56.048  1
556729  90.034  -56.639  56.062  1
556730  90.060  -56.657  56.080  1
556731  90.096  -56.671  56.089  1
556732  90.133  -56.686  56.090  1
556733  90.171  -56.700  56.068  1
556734  90.218  -56.716  56.028  1
556735  90.264  -56.733  55.978  1
556736  90.310  -56.749  55.914  1
556737  90.357  -56.765  55.857  1
556738  90.400  -56.777  55.806  1
556739  90.443  -56.789  55.758  1
556740  90.486  -56.801  55.712  1
556741  90.530  -56.813  55.670  1
556742  90.573  -56.826  55.630  1
556743  90.616  -56.838  55.592  1
556744  90.660  -56.850  55.557  1
556745  90.703  -56.862  55.524  1
556746  90.744  -56.876  55.493  1
556747  90.780  -56.893  55.467  1
556748  90.815  -56.910  55.445  1
556749  90.851  -56.928  55.423  1
556750  90.886  -56.945  55.402  1
556751  90.921  -56.962  55.383  1
556752  90.956  -56.980  55.366  1
556753  90.992  -56.997  55.352  1
556754  91.027  -57.014  55.339  1
556755  91.063  -57.031  55.328  1
556756  91.098  -57.049  55.317  1
556757  91.133  -57.066  55.308  1
556758  91.168  -57.084  55.299  1
556759  91.204  -57.101  55.292  1
556760  91.239  -57.118  55.288  1
556761  91.275  -57.135  55.286  1
556762  91.307  -57.148  55.284  1
556763  91.342  -57.160  55.284  1
556764  91.385  -57.169  55.284  1
556765  91.428  -57.178  55.285  1
556766  91.471  -57.188  55.290  1
556767  91.514  -57.198  55.295  1
556768  91.557  -57.207  55.298  1
556769  91.600  -57.217  55.300  1
556770  91.643  -57.227  55.297  1
556771  91.685  -57.236  55.292  1
556772  91.728  -57.246  55.286  1
556773  91.772  -57.256  55.282  1
556774  91.814  -57.265  55.282  1
556775  91.857  -57.275  55.289  1
556776  91.900  -57.285  55.295  1
556777  91.943  -57.294  55.300  1
556778  91.986  -57.304  55.305  1
556779  92.029  -57.313  55.310  1
556780  92.072  -57.323  55.314  1
556781  92.115  -57.332  55.316  1
556782  92.156  -57.354  55.315  1
556783  92.197  -57.378  55.316  1
556784  92.238  -57.401  55.316  1
556785  92.279  -57.425  55.312  1
556786  92.320  -57.448  55.303  1
556787  92.358  -57.474  55.284  1
556788  92.394  -57.501  55.263  1
556789  92.431  -57.528  55.243  1
556790  92.467  -57.554  55.224  1
556791  92.499  -57.576  55.204  1
556792  92.528  -57.598  55.184  1
556793  92.558  -57.618  55.169  1
556794  92.588  -57.639  55.151  1
556795  92.618  -57.660  55.128  1
556796  92.651  -57.674  55.101  1
556797  92.688  -57.685  55.075  1
556798  92.723  -57.695  55.049  1
556799  92.760  -57.706  55.025  1
556800  92.796  -57.717  55.002  1
556801  92.832  -57.727  54.979  1
556802  92.868  -57.738  54.959  1
556803  92.905  -57.746  54.946  1
556804  92.933  -57.752  54.933  1
556805  92.958  -57.758  54.921  1
556806  92.982  -57.764  54.911  1
556807  93.006  -57.770  54.902  1
556808  93.030  -57.776  54.896  1
556809  93.057  -57.780  54.894  1
556810  93.088  -57.780  54.891  1
556811  93.120  -57.779  54.887  1
556812  93.151  -57.778  54.881  1
556813  93.183  -57.777  54.874  1
556814  93.214  -57.777  54.866  1
556815  93.245  -57.776  54.862  1
556816  93.277  -57.775  54.852  1
556817  93.308  -57.774  54.838  1
556818  93.339  -57.774  54.817  1
556819  93.372  -57.778  54.791  1
556820  93.407  -57.786  54.760  1
556821  93.441  -57.795  54.746  1
556822  93.476  -57.803  54.750  1
556823  93.510  -57.811  54.757  1
556824  93.545  -57.820  54.758  1
556825  93.579  -57.828  54.758  1
556826  93.615  -57.841  54.755  1
556827  93.653  -57.861  54.749  1
556828  93.692  -57.881  54.739  1
556829  93.730  -57.901  54.728  1
556830  93.768  -57.921  54.721  1
556831  93.806  -57.940  54.714  1
556832  93.845  -57.960  54.701  1
556833  93.883  -57.980  54.684  1
556834  93.921  -58.000  54.666  1
556835  93.960  -58.020  54.647  1
556836  93.998  -58.040  54.629  1
556837  94.036  -58.059  54.610  1
556838  94.074  -58.079  54.590  1
556839  94.113  -58.099  54.571  1
556840  94.148  -58.117  54.551  1
556841  94.175  -58.128  54.529  1
556842  94.202  -58.140  54.504  1
556843  94.228  -58.153  54.475  1
556844  94.255  -58.164  54.442  1
556845  94.282  -58.176  54.405  1
556846  94.309  -58.187  54.366  1
556847  94.335  -58.200  54.324  1
556848  94.362  -58.211  54.278  1
556849  94.389  -58.223  54.241  1
556850  94.417  -58.236  54.208  1
556851  94.445  -58.249  54.177  1
556852  94.474  -58.263  54.145  1
556853  94.502  -58.276  54.113  1
556854  94.531  -58.289  54.077  1
556855  94.560  -58.303  54.045  1
556856  94.589  -58.316  54.013  1
556857  94.617  -58.329  53.979  1
556858  94.646  -58.343  53.942  1
556859  94.674  -58.356  53.907  1
556860  94.699  -58.368  53.876  1
556861  94.724  -58.380  53.846  1
556862  94.749  -58.392  53.815  1
556863  94.795  -58.402  53.784  1
556864  94.851  -58.412  53.753  1
556865  94.907  -58.421  53.726  1
556866  94.963  -58.430  53.697  1
556867  95.019  -58.439  53.669  1
556868  95.074  -58.448  53.640  1
556869  95.127  -58.458  53.610  1
556870  95.181  -58.468  53.580  1
556871  95.234  -58.478  53.553  1
556872  95.287  -58.487  53.530  1
556873  95.340  -58.497  53.506  1
556874  95.370  -58.498  53.480  1
556875  95.398  -58.498  53.453  1
556876  95.425  -58.499  53.429  1
556877  95.454  -58.500  53.404  1
556878  95.483  -58.501  53.376  1
556879  95.515  -58.511  53.349  1
556880  95.547  -58.525  53.326  1
556881  95.579  -58.538  53.311  1
556882  95.611  -58.551  53.298  1
556883  95.643  -58.565  53.280  1
556884  95.676  -58.579  53.262  1
556885  95.708  -58.592  53.243  1
556886  95.741  -58.606  53.222  1
556887  95.773  -58.620  53.200  1
556888  95.805  -58.633  53.170  1
556889  95.837  -58.647  53.145  1
556890  95.869  -58.658  53.119  1
556891  95.899  -58.664  53.087  1
556892  95.930  -58.671  53.050  1
556893  95.960  -58.678  53.018  1
556894  95.990  -58.685  52.974  1
556895  96.021  -58.691  52.939  1
556896  96.051  -58.698  52.907  1
556897  96.082  -58.706  52.876  1
556898  96.115  -58.717  52.844  1
556899  96.148  -58.728  52.817  1
556900  96.180  -58.736  52.783  1
556901  96.211  -58.734  52.754  1
556902  96.242  -58.733  52.728  1
556903  96.274  -58.733  52.703  1
556904  96.309  -58.736  52.673  1
556905  96.344  -58.739  52.644  1
556906  96.379  -58.742  52.614  1
556907  96.413  -58.745  52.583  1
556908  96.448  -58.748  52.551  1
556909  96.483  -58.751  52.517  1
556910  96.518  -58.754  52.479  1
556911  96.552  -58.757  52.441  1
556912  96.585  -58.758  52.405  1
556913  96.615  -58.759  52.370  1
556914  96.647  -58.760  52.334  1
556915  96.678  -58.761  52.296  1
556916  96.709  -58.762  52.256  1
556917  96.740  -58.767  52.213  1
556918  96.772  -58.772  52.173  1
556919  96.805  -58.777  52.136  1
556920  96.836  -58.783  52.101  1
556921  96.869  -58.789  52.065  1
556922  96.900  -58.794  52.028  1
556923  96.933  -58.799  51.991  1
556924  96.966  -58.799  51.953  1
556925  97.000  -58.800  51.914  1
556926  97.034  -58.801  51.877  1
556927  97.067  -58.804  51.839  1
556928  97.100  -58.808  51.799  1
556929  97.134  -58.812  51.760  1
556930  97.167  -58.816  51.723  1
556931  97.201  -58.820  51.692  1
556932  97.234  -58.824  51.663  1
556933  97.267  -58.827  51.629  1
556934  97.301  -58.831  51.591  1
556935  97.333  -58.836  51.553  1
556936  97.366  -58.839  51.514  1
556937  97.399  -58.844  51.470  1
556938  97.431  -58.848  51.421  1
556939  97.464  -58.852  51.377  1
556940  97.497  -58.856  51.337  1
556941  97.530  -58.861  51.296  1
556942  97.564  -58.867  51.255  1
556943  97.599  -58.875  51.217  1
556944  97.634  -58.883  51.180  1
556945  97.669  -58.892  51.142  1
556946  97.705  -58.899  51.102  1
556947  97.741  -58.905  51.059  1
556948  97.780  -58.911  51.014  1
556949  97.818  -58.910  50.969  1
556950  97.857  -58.910  50.923  1
556951  97.895  -58.909  50.882  1
556952  97.934  -58.908  50.840  1
556953  97.979  -58.897  50.796  1
556954  98.023  -58.885  50.752  1
556955  98.067  -58.873  50.710  1
556956  98.112  -58.861  50.671  1
556957  98.150  -58.856  50.633  1
556958  98.181  -58.858  50.599  1
556959  98.212  -58.861  50.566  1
556960  98.243  -58.864  50.534  1
556961  98.275  -58.866  50.504  1
556962  98.306  -58.869  50.477  1
556963  98.337  -58.871  50.446  1
556964  98.368  -58.874  50.419  1
556965  98.400  -58.876  50.394  1
556966  98.434  -58.875  50.370  1
556967  98.470  -58.871  50.348  1
556968  98.504  -58.861  50.323  1
556969  98.538  -58.850  50.298  1
556970  98.572  -58.839  50.275  1
556971  98.606  -58.828  50.254  1
556972  98.640  -58.817  50.235  1
556973  98.669  -58.814  50.221  1
556974  98.698  -58.812  50.207  1
556975  98.726  -58.809  50.190  1
556976  98.755  -58.807  50.173  1
556977  98.789  -58.803  50.155  1
556978  98.823  -58.799  50.136  1
556979  98.857  -58.796  50.114  1
556980  98.892  -58.792  50.089  1
556981  98.926  -58.791  50.064  1
556982  98.958  -58.790  50.038  1
556983  98.992  -58.789  50.012  1
556984  99.025  -58.789  49.984  1
556985  99.058  -58.789  49.952  1
556986  99.091  -58.789  49.919  1
556987  99.144  -58.786  49.886  1
556988  99.216  -58.781  49.853  1
556989  99.288  -58.775  49.821  1
556990  99.360  -58.769  49.791  1
556991  99.411  -58.771  49.761  1
556992  99.446  -58.779  49.732  1
556993  99.482  -58.786  49.703  1
556994  99.518  -58.793  49.673  1
556995  99.554  -58.801  49.643  1
556996  99.589  -58.808  49.614  1
556997  99.625  -58.816  49.585  1
556998  99.660  -58.824  49.553  1
556999  99.696  -58.831  49.521  1
557000  99.732  -58.839  49.487  1
557001  99.768  -58.846  49.454  1
557002  99.803  -58.853  49.420  1
557347  86.880  -55.377  57.631  4
557348  86.915  -55.393  57.625  4
557349  86.950  -55.410  57.620  4
557350  86.985  -55.426  57.612  4
557351  87.020  -55.442  57.604  4
557352  87.055  -55.458  57.594  4
557353  87.090  -55.474  57.584  4
557354  87.125  -55.490  57.573  4
557355  87.160  -55.506  57.562  4
557356  87.201  -55.520  57.548  4
557357  87.241  -55.533  57.534  4
557358  87.281  -55.546  57.519  4
557359  87.322  -55.559  57.504  4
557360  87.362  -55.573  57.482  4
557361  87.403  -55.586  57.459  4
557362  87.443  -55.599  57.434  4
557363  87.487  -55.611  57.406  4
557364  87.542  -55.614  57.376  4
557365  87.597  -55.619  57.346  4
557366  87.651  -55.623  57.312  4
557367  87.703  -55.628  57.277  4
557368  87.741  -55.638  57.239  4
557369  87.776  -55.650  57.199  4
557370  87.814  -55.666  57.158  4
557371  87.852  -55.683  57.116  4
557372  87.891  -55.699  57.074  4
557373  87.929  -55.715  57.032  4
557374  87.967  -55.730  56.989  4
557375  88.005  -55.746  56.946  4
557376  88.043  -55.762  56.904  4
557377  88.081  -55.778  56.863  4
557378  88.120  -55.794  56.823  4
557403  89.076  -56.194  56.064  1
557404  89.114  -56.210  56.045  1
557405  89.153  -56.226  56.026  1
557406  89.191  -56.241  56.008  1
557407  89.229  -56.257  55.992  1
557408  89.267  -56.274  55.976  1
557409  89.306  -56.290  55.963  1
557410  89.344  -56.306  55.951  1
557411  89.382  -56.322  55.941  1
557412  89.420  -56.338  55.933  1
557413  89.459  -56.354  55.926  1
557414  89.497  -56.370  55.920  1
557415  89.535  -56.385  55.917  1
557416  89.574  -56.401  55.914  1
557417  89.600  -56.424  55.915  1
557418  89.638  -56.438  55.917  1
557419  89.679  -56.448  55.921  1
557420  89.721  -56.460  55.928  1
557421  89.762  -56.470  55.939  1
557422  89.804  -56.481  55.950  1
557423  89.845  -56.492  55.964  1
557424  89.886  -56.503  55.981  1
557425  89.913  -56.520  55.998  1
557426  89.939  -56.536  56.015  1
557427  89.965  -56.554  56.032  1
557428  89.990  -56.570  56.048  1
557429  90.016  -56.588  56.064  1
557430  90.042  -56.605  56.082  1
557431  90.071  -56.621  56.102  1
557432  90.107  -56.636  56.110  1
557433  90.145  -56.650  56.110  1
557434  90.191  -56.666  56.091  1
557435  90.237  -56.682  56.055  1
557436  90.284  -56.699  56.006  1
557437  90.328  -56.711  55.937  1
557438  90.371  -56.724  55.872  1
557439  90.414  -56.736  55.816  1
557440  90.458  -56.748  55.766  1
557441  90.501  -56.761  55.718  1
557442  90.544  -56.773  55.675  1
557443  90.588  -56.785  55.635  1
557444  90.631  -56.797  55.597  1
557445  90.674  -56.809  55.562  1
557446  90.718  -56.821  55.530  1
557447  90.761  -56.834  55.499  1
557448  90.800  -56.849  55.474  1
557449  90.835  -56.866  55.452  1
557450  90.871  -56.884  55.431  1
557451  90.906  -56.900  55.410  1
557452  90.942  -56.918  55.391  1
557453  90.977  -56.935  55.374  1
557454  91.012  -56.953  55.361  1
557455  91.047  -56.970  55.348  1
557456  91.083  -56.987  55.336  1
557457  91.118  -57.004  55.326  1
557458  91.154  -57.022  55.316  1
557459  91.189  -57.039  55.307  1
557460  91.224  -57.056  55.300  1
557461  91.259  -57.074  55.295  1
557462  91.294  -57.090  55.293  1
557463  91.326  -57.102  55.292  1
557464  91.359  -57.114  55.291  1
557465  91.397  -57.125  55.293  1
557466  91.440  -57.134  55.297  1
557467  91.483  -57.144  55.306  1
557468  91.526  -57.154  55.313  1
557469  91.569  -57.163  55.316  1
557470  91.611  -57.173  55.312  1
557471  91.655  -57.183  55.303  1
557472  91.698  -57.192  55.294  1
557473  91.740  -57.202  55.289  1
557474  91.783  -57.212  55.290  1
557475  91.826  -57.221  55.294  1
557476  91.869  -57.231  55.300  1
557477  91.912  -57.241  55.303  1
557478  91.955  -57.250  55.304  1
557479  91.998  -57.260  55.305  1
557480  92.041  -57.269  55.309  1
557481  92.084  -57.279  55.313  1
557482  92.126  -57.297  55.317  1
557483  92.166  -57.320  55.320  1
557484  92.208  -57.344  55.324  1
557485  92.248  -57.367  55.327  1
557486  92.290  -57.390  55.325  1
557487  92.331  -57.413  55.317  1
557488  92.369  -57.439  55.303  1
557489  92.406  -57.466  55.287  1
557490  92.442  -57.493  55.272  1
557491  92.479  -57.520  55.256  1
557492  92.515  -57.546  55.236  1
557493  92.546  -57.567  55.217  1
557494  92.575  -57.589  55.198  1
557495  92.605  -57.609  55.179  1
557496  92.635  -57.630  55.157  1
557497  92.671  -57.640  55.133  1
557498  92.707  -57.651  55.109  1
557499  92.743  -57.661  55.083  1
557500  92.780  -57.672  55.057  1
557501  92.816  -57.683  55.032  1
557502  92.852  -57.693  55.010  1
557503  92.888  -57.704  54.994  1
557504  92.921  -57.712  54.980  1
557505  92.945  -57.718  54.965  1
557506  92.970  -57.724  54.952  1
557507  92.994  -57.730  54.940  1
557508  93.018  -57.736  54.930  1
557509  93.042  -57.742  54.922  1
557510  93.069  -57.746  54.917  1
557511  93.100  -57.746  54.912  1
557512  93.132  -57.745  54.905  1
557513  93.163  -57.744  54.897  1
557514  93.194  -57.743  54.888  1
557515  93.226  -57.742  54.877  1
557516  93.257  -57.742  54.868  1
557517  93.288  -57.741  54.860  1
557518  93.320  -57.740  54.849  1
557519  93.351  -57.739  54.833  1
557520  93.382  -57.739  54.811  1
557521  93.415  -57.742  54.781  1
557522  93.449  -57.751  54.756  1
557523  93.484  -57.759  54.744  1
557524  93.518  -57.767  54.744  1
557525  93.553  -57.776  54.750  1
557526  93.587  -57.784  54.754  1
557527  93.624  -57.799  54.753  1
557528  93.662  -57.818  54.750  1
557529  93.701  -57.839  54.744  1
557530  93.739  -57.858  54.737  1
557531  93.777  -57.878  54.731  1
557532  93.816  -57.898  54.723  1
557533  93.854  -57.918  54.708  1
557534  93.892  -57.937  54.690  1
557535  93.930  -57.958  54.669  1
557536  93.969  -57.977  54.647  1
557537  94.007  -57.997  54.626  1
557538  94.045  -58.017  54.605  1
557539  94.083  -58.037  54.581  1
557540  94.122  -58.056  54.558  1
557541  94.160  -58.076  54.537  1
557542  94.196  -58.095  54.514  1
557543  94.223  -58.106  54.489  1
557544  94.250  -58.118  54.460  1
557545  94.277  -58.131  54.429  1
557546  94.303  -58.142  54.394  1
557547  94.330  -58.154  54.357  1
557548  94.357  -58.165  54.322  1
557549  94.384  -58.178  54.281  1
557550  94.410  -58.190  54.246  1
557551  94.439  -58.203  54.214  1
557552  94.468  -58.216  54.183  1
557553  94.496  -58.229  54.152  1
557554  94.525  -58.243  54.121  1
557555  94.554  -58.256  54.088  1
557556  94.582  -58.269  54.055  1
557557  94.611  -58.283  54.020  1
557558  94.638  -58.296  53.984  1
557559  94.664  -58.308  53.945  1
557560  94.689  -58.320  53.909  1
557561  94.714  -58.332  53.875  1
557562  94.740  -58.344  53.841  1
557563  94.765  -58.357  53.806  1
557564  94.799  -58.368  53.773  1
557565  94.854  -58.377  53.740  1
557566  94.910  -58.386  53.709  1
557567  94.966  -58.395  53.678  1
557568  95.022  -58.405  53.649  1
557569  95.078  -58.414  53.619  1
557570  95.134  -58.423  53.590  1
557571  95.190  -58.432  53.560  1
557572  95.246  -58.442  53.534  1
557573  95.302  -58.451  53.510  1
557574  95.344  -58.457  53.484  1
557575  95.374  -58.459  53.456  1
557576  95.404  -58.460  53.430  1
557577  95.433  -58.462  53.405  1
557578  95.463  -58.463  53.378  1
557579  95.493  -58.465  53.350  1
557580  95.523  -58.469  53.324  1
557581  95.556  -58.483  53.303  1
557582  95.588  -58.497  53.291  1
557583  95.620  -58.510  53.278  1
557584  95.653  -58.524  53.263  1
557585  95.685  -58.538  53.248  1
557586  95.717  -58.551  53.232  1
557587  95.749  -58.565  53.213  1
557588  95.781  -58.578  53.192  1
557589  95.814  -58.592  53.165  1
557590  95.846  -58.605  53.140  1
557591  95.877  -58.614  53.106  1
557592  95.907  -58.621  53.068  1
557593  95.938  -58.627  53.034  1
557594  95.968  -58.634  53.008  1
557595  95.998  -58.641  52.967  1
557596  96.028  -58.648  52.935  1
557597  96.059  -58.654  52.903  1
557598  96.092  -58.666  52.868  1
557599  96.125  -58.676  52.836  1
557600  96.158  -58.688  52.811  1
557601  96.190  -58.698  52.779  1
557602  96.223  -58.705  52.752  1
557603  96.253  -58.703  52.727  1
557604  96.285  -58.701  52.699  1
557605  96.316  -58.699  52.669  1
557606  96.347  -58.698  52.644  1
557607  96.382  -58.701  52.616  1
557608  96.416  -58.704  52.586  1
557609  96.451  -58.707  52.553  1
557610  96.486  -58.710  52.518  1
557611  96.521  -58.713  52.478  1
557612  96.555  -58.716  52.438  1
557613  96.590  -58.719  52.402  1
557614  96.620  -58.720  52.367  1
557615  96.652  -58.720  52.329  1
557616  96.683  -58.721  52.288  1
557617  96.714  -58.723  52.245  1
557618  96.746  -58.729  52.202  1
557619  96.778  -58.734  52.161  1
557620  96.810  -58.739  52.121  1
557621  96.842  -58.745  52.082  1
557622  96.874  -58.751  52.044  1
557623  96.906  -58.756  52.004  1
557624  96.938  -58.762  51.967  1
557625  96.971  -58.764  51.929  1
557626  97.005  -58.764  51.892  1
557627  97.038  -58.765  51.854  1
557628  97.072  -58.770  51.816  1
557629  97.105  -58.773  51.776  1
557630  97.139  -58.777  51.736  1
557631  97.172  -58.781  51.697  1
557632  97.205  -58.785  51.662  1
557633  97.238  -58.789  51.631  1
557634  97.272  -58.793  51.603  1
557635  97.304  -58.797  51.567  1
557636  97.337  -58.802  51.529  1
557637  97.369  -58.805  51.489  1
557638  97.402  -58.810  51.448  1
557639  97.435  -58.814  51.404  1
557640  97.467  -58.818  51.360  1
557641  97.500  -58.822  51.317  1
557642  97.532  -58.827  51.273  1
557643  97.567  -58.833  51.231  1
557644  97.602  -58.842  51.193  1
557645  97.638  -58.849  51.158  1
557646  97.673  -58.855  51.121  1
557647  97.708  -58.861  51.080  1
557648  97.746  -58.867  51.038  1
557649  97.786  -58.872  50.994  1
557650  97.825  -58.877  50.951  1
557651  97.864  -58.879  50.905  1
557652  97.902  -58.879  50.861  1
557653  97.945  -58.871  50.819  1
557654  97.989  -58.859  50.778  1
557655  98.033  -58.847  50.737  1
557656  98.076  -58.835  50.699  1
557657  98.118  -58.824  50.662  1
557658  98.154  -58.820  50.627  1
557659  98.189  -58.821  50.593  1
557660  98.222  -58.823  50.560  1
557661  98.253  -58.825  50.529  1
557662  98.284  -58.828  50.498  1
557663  98.315  -58.830  50.467  1
557664  98.347  -58.833  50.435  1
557665  98.378  -58.835  50.404  1
557666  98.409  -58.838  50.375  1
557667  98.440  -58.840  50.350  1
557668  98.477  -58.838  50.327  1
557669  98.511  -58.828  50.302  1
557670  98.545  -58.817  50.279  1
557671  98.579  -58.807  50.256  1
557672  98.613  -58.796  50.233  1
557673  98.642  -58.793  50.214  1
557674  98.670  -58.790  50.198  1
557675  98.700  -58.788  50.185  1
557676  98.728  -58.786  50.172  1
557677  98.758  -58.783  50.158  1
557678  98.792  -58.779  50.140  1
557679  98.827  -58.775  50.122  1
557680  98.861  -58.771  50.101  1
557681  98.896  -58.767  50.078  1
557682  98.930  -58.765  50.056  1
557683  98.962  -58.764  50.032  1
557684  98.996  -58.764  50.006  1
557685  99.029  -58.764  49.980  1
557686  99.068  -58.758  49.951  1
557687  99.109  -58.753  49.919  1
557688  99.152  -58.748  49.887  1
557689  99.224  -58.742  49.855  1
557690  99.296  -58.736  49.823  1
557691  99.368  -58.730  49.794  1
557692  99.412  -58.734  49.765  1
557693  99.447  -58.742  49.737  1
557694  99.483  -58.749  49.708  1
557695  99.519  -58.757  49.678  1
557696  99.555  -58.764  49.649  1
557697  99.590  -58.772  49.621  1
557698  99.626  -58.780  49.591  1
557699  99.661  -58.786  49.560  1
557700  99.697  -58.794  49.529  1
557701  99.733  -58.802  49.496  1
557702  99.769  -58.809  49.462  1
557703  99.804  -58.817  49.430  1
558048  86.910  -55.327  57.631  4
558049  86.945  -55.344  57.626  4
558050  86.980  -55.360  57.620  4
558051  87.015  -55.376  57.614  4
558052  87.050  -55.392  57.605  4
558053  87.085  -55.408  57.596  4
558054  87.120  -55.424  57.588  4
558055  87.155  -55.440  57.578  4
558056  87.190  -55.456  57.567  4
558057  87.225  -55.473  57.555  4
558058  87.260  -55.489  57.542  4
558059  87.298  -55.503  57.530  4
558060  87.339  -55.516  57.515  4
558061  87.379  -55.530  57.496  4
558062  87.419  -55.542  57.474  4
558063  87.460  -55.556  57.451  4
558064  87.512  -55.562  57.425  4
558065  87.567  -55.566  57.397  4
558066  87.622  -55.570  57.367  4
558067  87.677  -55.574  57.335  4
558068  87.719  -55.583  57.301  4
558069  87.755  -55.596  57.265  4
558070  87.793  -55.612  57.225  4
558071  87.832  -55.628  57.185  4
558072  87.870  -55.644  57.142  4
558073  87.908  -55.660  57.101  4
558074  87.946  -55.676  57.059  4
558075  87.985  -55.692  57.016  4
558076  88.023  -55.708  56.972  4
558077  88.061  -55.724  56.928  4
558078  88.100  -55.740  56.887  4
558079  88.138  -55.756  56.846  4
558104  89.094  -56.155  56.064  1
558105  89.132  -56.171  56.043  1
558106  89.171  -56.187  56.024  1
558107  89.209  -56.204  56.007  1
558108  89.247  -56.219  55.990  1
558109  89.285  -56.235  55.974  1
558110  89.324  -56.251  55.960  1
558111  89.362  -56.267  55.948  1
558112  89.400  -56.283  55.937  1
558113  89.438  -56.299  55.928  1
558114  89.476  -56.315  55.921  1
558115  89.515  -56.331  55.915  1
558116  89.553  -56.347  55.912  1
558117  89.591  -56.363  55.909  1
558118  89.619  -56.385  55.909  1
558119  89.658  -56.398  55.912  1
558120  89.699  -56.409  55.917  1
558121  89.740  -56.420  55.924  1
558122  89.781  -56.431  55.935  1
558123  89.823  -56.442  55.947  1
558124  89.865  -56.452  55.961  1
558125  89.895  -56.467  55.979  1
558126  89.921  -56.485  55.996  1
558127  89.947  -56.501  56.016  1
558128  89.972  -56.519  56.037  1
558129  89.998  -56.536  56.059  1
558130  90.023  -56.553  56.081  1
558131  90.049  -56.570  56.099  1
558132  90.082  -56.586  56.113  1
558133  90.119  -56.600  56.117  1
558134  90.164  -56.616  56.115  1
558135  90.211  -56.632  56.101  1
558136  90.255  -56.646  56.070  1
558137  90.299  -56.658  56.022  1
558138  90.342  -56.671  55.951  1
558139  90.386  -56.683  55.883  1
558140  90.429  -56.696  55.823  1
558141  90.472  -56.708  55.770  1
558142  90.516  -56.720  55.722  1
558143  90.559  -56.732  55.679  1
558144  90.602  -56.744  55.639  1
558145  90.646  -56.756  55.601  1
558146  90.689  -56.768  55.567  1
558147  90.732  -56.780  55.535  1
558148  90.776  -56.793  55.505  1
558149  90.819  -56.805  55.481  1
558150  90.856  -56.821  55.459  1
558151  90.891  -56.839  55.438  1
558152  90.927  -56.856  55.419  1
558153  90.962  -56.874  55.401  1
558154  90.997  -56.890  55.385  1
558155  91.032  -56.908  55.371  1
558156  91.068  -56.925  55.358  1
558157  91.103  -56.943  55.346  1
558158  91.139  -56.960  55.335  1
558159  91.174  -56.978  55.325  1
558160  91.209  -56.995  55.315  1
558161  91.244  -57.012  55.308  1
558162  91.280  -57.029  55.303  1
558163  91.313  -57.044  55.300  1
558164  91.346  -57.056  55.298  1
558165  91.378  -57.069  55.298  1
558166  91.410  -57.081  55.301  1
558167  91.452  -57.091  55.308  1
558168  91.495  -57.100  55.318  1
558169  91.538  -57.110  55.326  1
558170  91.581  -57.119  55.327  1
558171  91.624  -57.129  55.318  1
558172  91.666  -57.139  55.306  1
558173  91.710  -57.148  55.300  1
558174  91.752  -57.158  55.303  1
558175  91.795  -57.168  55.315  1
558176  91.838  -57.177  55.329  1
558177  91.881  -57.187  55.341  1
558178  91.924  -57.197  55.344  1
558179  91.967  -57.206  55.341  1
558180  92.010  -57.216  55.334  1
558181  92.053  -57.225  55.324  1
558182  92.095  -57.238  55.316  1
558183  92.136  -57.262  55.313  1
558184  92.177  -57.285  55.319  1
558185  92.218  -57.309  55.328  1
558186  92.260  -57.332  55.336  1
558187  92.300  -57.356  55.339  1
558188  92.342  -57.379  55.333  1
558189  92.380  -57.404  55.326  1
558190  92.417  -57.431  55.317  1
558191  92.454  -57.457  55.303  1
558192  92.490  -57.485  55.286  1
558193  92.527  -57.511  55.265  1
558194  92.563  -57.538  55.242  1
558195  92.593  -57.558  55.218  1
558196  92.622  -57.579  55.196  1
558197  92.655  -57.595  55.173  1
558198  92.691  -57.605  55.151  1
558199  92.727  -57.616  55.129  1
558200  92.764  -57.626  55.104  1
558201  92.800  -57.637  55.076  1
558202  92.836  -57.648  55.050  1
558203  92.868  -57.659  55.028  1
558204  92.902  -57.670  55.009  1
558205  92.931  -57.679  54.994  1
558206  92.957  -57.685  54.977  1
558207  92.981  -57.691  54.963  1
558208  93.005  -57.697  54.952  1
558209  93.029  -57.703  54.942  1
558210  93.054  -57.709  54.932  1
558211  93.081  -57.712  54.925  1
558212  93.112  -57.711  54.918  1
558213  93.144  -57.711  54.912  1
558214  93.175  -57.710  54.904  1
558215  93.206  -57.710  54.895  1
558216  93.237  -57.709  54.883  1
558217  93.269  -57.708  54.872  1
558218  93.300  -57.708  54.865  1
558219  93.332  -57.707  54.856  1
558220  93.363  -57.706  54.843  1
558221  93.395  -57.705  54.826  1
558222  93.426  -57.705  54.800  1
558223  93.458  -57.707  54.769  1
558224  93.492  -57.715  54.742  1
558225  93.527  -57.724  54.731  1
558226  93.561  -57.731  54.737  1
558227  93.596  -57.739  54.745  1
558228  93.633  -57.756  54.748  1
558229  93.672  -57.776  54.748  1
558230  93.710  -57.796  54.746  1
558231  93.748  -57.816  54.742  1
558232  93.786  -57.836  54.736  1
558233  93.825  -57.855  54.728  1
558234  93.863  -57.875  54.713  1
558235  93.901  -57.895  54.696  1
558236  93.939  -57.915  54.677  1
558237  93.978  -57.935  54.657  1
558238  94.016  -57.955  54.637  1
558239  94.054  -57.974  54.613  1
558240  94.092  -57.994  54.587  1
558241  94.131  -58.014  54.562  1
558242  94.169  -58.034  54.536  1
558243  94.207  -58.053  54.508  1
558244  94.245  -58.073  54.481  1
558245  94.271  -58.085  54.451  1
558246  94.298  -58.096  54.420  1
558247  94.325  -58.109  54.387  1
558248  94.352  -58.120  54.355  1
558249  94.379  -58.132  54.323  1
558250  94.405  -58.144  54.291  1
558251  94.433  -58.156  54.262  1
558252  94.462  -58.170  54.231  1
558253  94.490  -58.183  54.200  1
558254  94.519  -58.197  54.170  1
558255  94.547  -58.210  54.141  1
558256  94.576  -58.223  54.109  1
558257  94.604  -58.236  54.075  1
558258  94.629  -58.248  54.038  1
558259  94.654  -58.260  53.999  1
558260  94.680  -58.272  53.959  1
558261  94.705  -58.285  53.920  1
558262  94.730  -58.297  53.882  1
558263  94.755  -58.309  53.844  1
558264  94.780  -58.321  53.805  1
558265  94.806  -58.333  53.766  1
558266  94.858  -58.343  53.730  1
558267  94.914  -58.352  53.696  1
558268  94.970  -58.361  53.662  1
558269  95.026  -58.370  53.630  1
558270  95.082  -58.379  53.599  1
558271  95.138  -58.389  53.570  1
558272  95.194  -58.398  53.542  1
558273  95.250  -58.407  53.514  1
558274  95.306  -58.416  53.487  1
558275  95.352  -58.421  53.459  1
558276  95.384  -58.422  53.432  1
558277  95.413  -58.423  53.406  1
558278  95.443  -58.425  53.379  1
558279  95.473  -58.427  53.351  1
558280  95.502  -58.429  53.324  1
558281  95.532  -58.430  53.298  1
558282  95.564  -58.442  53.278  1
558283  95.597  -58.456  53.266  1
558284  95.629  -58.469  53.257  1
558285  95.661  -58.483  53.245  1
558286  95.693  -58.496  53.230  1
558287  95.726  -58.510  53.216  1
558288  95.758  -58.523  53.203  1
558289  95.790  -58.537  53.181  1
558290  95.822  -58.551  53.153  1
558291  95.854  -58.563  53.128  1
558292  95.885  -58.570  53.097  1
558293  95.915  -58.577  53.064  1
558294  95.945  -58.583  53.034  1
558295  95.976  -58.590  53.012  1
558296  96.006  -58.597  52.973  1
558297  96.036  -58.604  52.939  1
558298  96.069  -58.614  52.905  1
558299  96.102  -58.626  52.871  1
558300  96.135  -58.636  52.843  1
558301  96.168  -58.648  52.814  1
558302  96.200  -58.658  52.779  1
558303  96.233  -58.670  52.752  1
558304  96.265  -58.673  52.726  1
558305  96.296  -58.671  52.695  1
558306  96.327  -58.670  52.663  1
558307  96.359  -58.668  52.642  1
558308  96.390  -58.667  52.618  1
558309  96.420  -58.664  52.587  1
558310  96.454  -58.666  52.552  1
558311  96.488  -58.669  52.518  1
558312  96.523  -58.672  52.480  1
558313  96.558  -58.675  52.441  1
558314  96.593  -58.678  52.404  1
558315  96.626  -58.679  52.367  1
558316  96.657  -58.680  52.327  1
558317  96.688  -58.682  52.284  1
558318  96.720  -58.685  52.240  1
558319  96.751  -58.691  52.198  1
558320  96.784  -58.696  52.156  1
558321  96.815  -58.701  52.112  1
558322  96.848  -58.708  52.070  1
558323  96.879  -58.713  52.030  1
558324  96.911  -58.718  51.987  1
558325  96.943  -58.724  51.948  1
558326  96.976  -58.728  51.911  1
558327  97.010  -58.729  51.872  1
558328  97.043  -58.731  51.834  1
558329  97.077  -58.735  51.796  1
558330  97.110  -58.739  51.756  1
558331  97.143  -58.742  51.717  1
558332  97.176  -58.747  51.677  1
558333  97.209  -58.751  51.639  1
558334  97.242  -58.755  51.605  1
558335  97.275  -58.759  51.578  1
558336  97.307  -58.764  51.546  1
558337  97.340  -58.767  51.507  1
558338  97.373  -58.772  51.466  1
558339  97.405  -58.776  51.425  1
558340  97.438  -58.780  51.384  1
558341  97.470  -58.784  51.343  1
558342  97.503  -58.789  51.300  1
558343  97.535  -58.792  51.256  1
558344  97.571  -58.799  51.213  1
558345  97.605  -58.805  51.173  1
558346  97.641  -58.811  51.137  1
558347  97.676  -58.817  51.099  1
558348  97.712  -58.823  51.060  1
558349  97.751  -58.828  51.019  1
558350  97.791  -58.833  50.975  1
558351  97.830  -58.838  50.930  1
558352  97.870  -58.843  50.886  1
558353  97.909  -58.846  50.843  1
558354  97.951  -58.834  50.802  1
558355  97.993  -58.822  50.762  1
558356  98.035  -58.811  50.722  1
558357  98.077  -58.799  50.685  1
558358  98.119  -58.787  50.649  1
558359  98.152  -58.787  50.614  1
558360  98.185  -58.788  50.580  1
558361  98.221  -58.789  50.547  1
558362  98.256  -58.789  50.515  1
558363  98.291  -58.790  50.484  1
558364  98.325  -58.792  50.451  1
558365  98.356  -58.794  50.419  1
558366  98.387  -58.797  50.388  1
558367  98.419  -58.799  50.359  1
558368  98.450  -58.802  50.332  1
558369  98.483  -58.803  50.307  1
558370  98.517  -58.796  50.282  1
558371  98.552  -58.786  50.258  1
558372  98.585  -58.775  50.235  1
558373  98.615  -58.771  50.213  1
558374  98.644  -58.769  50.193  1
558375  98.672  -58.766  50.178  1
558376  98.701  -58.764  50.164  1
558377  98.730  -58.761  50.152  1
558378  98.762  -58.758  50.140  1
558379  98.796  -58.755  50.124  1
558380  98.830  -58.751  50.107  1
558381  98.865  -58.747  50.087  1
558382  98.899  -58.743  50.066  1
558383  98.934  -58.739  50.045  1
558384  98.971  -58.736  50.023  1
558385  99.011  -58.730  49.999  1
558386  99.051  -58.725  49.974  1
558387  99.091  -58.720  49.947  1
558388  99.132  -58.714  49.917  1
558389  99.172  -58.708  49.886  1
558390  99.231  -58.702  49.855  1
558391  99.303  -58.696  49.823  1
558392  99.375  -58.691  49.794  1
558393  99.413  -58.698  49.766  1
558394  99.448  -58.705  49.738  1
558395  99.484  -58.713  49.711  1
558396  99.519  -58.720  49.682  1
558397  99.555  -58.727  49.654  1
558398  99.591  -58.735  49.625  1
558399  99.627  -58.742  49.596  1
558400  99.662  -58.750  49.566  1
558401  99.698  -58.758  49.535  1
558402  99.734  -58.765  49.503  1
558403  99.769  -58.773  49.469  1
558404  99.805  -58.780  49.437  1
558749  86.940  -55.277  57.631  4
558750  86.975  -55.294  57.626  4
558751  87.010  -55.310  57.621  4
558752  87.045  -55.326  57.614  4
558753  87.080  -55.342  57.607  4
558754  87.115  -55.358  57.599  4
558755  87.150  -55.374  57.590  4
558756  87.185  -55.390  57.581  4
558757  87.220  -55.406  57.572  4
558758  87.255  -55.423  57.562  4
558759  87.290  -55.439  57.550  4
558760  87.325  -55.455  57.539  4
558761  87.360  -55.470  57.525  4
558762  87.396  -55.486  57.509  4
558763  87.436  -55.499  57.490  4
558764  87.482  -55.509  57.468  4
558765  87.537  -55.514  57.445  4
558766  87.592  -55.517  57.419  4
558767  87.647  -55.521  57.390  4
558768  87.698  -55.527  57.358  4
558769  87.734  -55.542  57.325  4
558770  87.773  -55.558  57.290  4
558771  87.811  -55.574  57.252  4
558772  87.849  -55.589  57.213  4
558773  87.888  -55.605  57.172  4
558774  87.926  -55.621  57.130  4
558775  87.964  -55.637  57.087  4
558776  88.002  -55.653  57.043  4
558777  88.041  -55.669  56.999  4
558778  88.079  -55.685  56.954  4
558779  88.117  -55.701  56.911  4
558780  88.155  -55.717  56.870  4
558781  88.194  -55.734  56.829  4
558805  89.112  -56.117  56.063  1
558806  89.150  -56.133  56.042  1
558807  89.188  -56.149  56.022  1
558808  89.227  -56.165  56.004  1
558809  89.265  -56.181  55.987  1
558810  89.303  -56.197  55.972  1
558811  89.341  -56.213  55.956  1
558812  89.380  -56.229  55.944  1
558813  89.418  -56.244  55.933  1
558814  89.456  -56.260  55.924  1
558815  89.494  -56.276  55.916  1
558816  89.533  -56.292  55.910  1
558817  89.571  -56.308  55.906  1
558818  89.609  -56.325  55.903  1
558819  89.637  -56.346  55.904  1
558820  89.677  -56.359  55.906  1
558821  89.719  -56.370  55.911  1
558822  89.760  -56.380  55.918  1
558823  89.801  -56.391  55.928  1
558824  89.842  -56.402  55.941  1
558825  89.877  -56.416  55.955  1
558826  89.903  -56.432  55.973  1
558827  89.929  -56.450  55.992  1
558828  89.954  -56.467  56.014  1
558829  89.979  -56.484  56.041  1
558830  90.005  -56.501  56.070  1
558831  90.031  -56.518  56.096  1
558832  90.056  -56.536  56.114  1
558833  90.093  -56.550  56.120  1
558834  90.138  -56.565  56.116  1
558835  90.183  -56.581  56.110  1
558836  90.227  -56.593  56.094  1
558837  90.270  -56.605  56.061  1
558838  90.313  -56.617  56.013  1
558839  90.357  -56.630  55.949  1
558840  90.400  -56.642  55.882  1
558841  90.443  -56.655  55.823  1
558842  90.487  -56.667  55.771  1
558843  90.530  -56.679  55.723  1
558844  90.574  -56.691  55.681  1
558845  90.617  -56.703  55.642  1
558846  90.660  -56.715  55.606  1
558847  90.704  -56.728  55.572  1
558848  90.747  -56.740  55.541  1
558849  90.790  -56.752  55.512  1
558850  90.833  -56.765  55.489  1
558851  90.876  -56.777  55.467  1
558852  90.911  -56.794  55.448  1
558853  90.947  -56.812  55.429  1
558854  90.982  -56.829  55.413  1
558855  91.017  -56.846  55.396  1
558856  91.053  -56.864  55.382  1
558857  91.088  -56.881  55.370  1
558858  91.123  -56.898  55.358  1
558859  91.159  -56.915  55.346  1
558860  91.194  -56.933  55.336  1
558861  91.229  -56.950  55.326  1
558862  91.264  -56.968  55.317  1
558863  91.300  -56.985  55.311  1
558864  91.333  -56.998  55.306  1
558865  91.365  -57.010  55.303  1
558866  91.397  -57.022  55.304  1
558867  91.430  -57.035  55.308  1
558868  91.464  -57.047  55.316  1
558869  91.507  -57.056  55.326  1
558870  91.549  -57.066  55.333  1
558871  91.593  -57.075  55.331  1
558872  91.636  -57.085  55.320  1
558873  91.678  -57.095  55.308  1
558874  91.721  -57.104  55.307  1
558875  91.764  -57.114  55.318  1
558876  91.807  -57.124  55.338  1
558877  91.850  -57.133  55.359  1
558878  91.893  -57.143  55.370  1
558879  91.936  -57.153  55.375  1
558880  91.979  -57.162  55.373  1
558881  92.022  -57.172  55.366  1
558882  92.065  -57.181  55.356  1
558883  92.106  -57.204  55.347  1
558884  92.147  -57.228  55.336  1
558885  92.188  -57.251  55.332  1
558886  92.229  -57.275  55.336  1
558887  92.270  -57.298  55.346  1
558888  92.311  -57.321  55.354  1
558889  92.352  -57.344  55.352  1
558890  92.392  -57.369  55.346  1
558891  92.428  -57.396  55.335  1
558892  92.465  -57.423  55.321  1
558893  92.502  -57.449  55.304  1
558894  92.538  -57.476  55.282  1
558895  92.575  -57.503  55.254  1
558896  92.610  -57.529  55.227  1
558897  92.640  -57.549  55.201  1
558898  92.675  -57.561  55.178  1
558899  92.711  -57.571  55.159  1
558900  92.747  -57.582  55.138  1
558901  92.780  -57.593  55.114  1
558902  92.813  -57.604  55.087  1
558903  92.846  -57.615  55.061  1
558904  92.879  -57.626  55.038  1
558905  92.912  -57.637  55.017  1
558906  92.940  -57.644  55.001  1
558907  92.969  -57.651  54.984  1
558908  92.993  -57.658  54.969  1
558909  93.017  -57.664  54.956  1
558910  93.041  -57.669  54.946  1
558911  93.066  -57.675  54.934  1
558912  93.093  -57.679  54.923  1
558913  93.124  -57.678  54.913  1
558914  93.155  -57.677  54.905  1
558915  93.187  -57.677  54.896  1
558916  93.218  -57.676  54.887  1
558917  93.250  -57.675  54.874  1
558918  93.281  -57.674  54.862  1
558919  93.312  -57.673  54.856  1
558920  93.344  -57.673  54.850  1
558921  93.375  -57.672  54.839  1
558922  93.406  -57.671  54.823  1
558923  93.437  -57.670  54.798  1
558924  93.469  -57.670  54.770  1
558925  93.501  -57.670  54.743  1
558926  93.535  -57.679  54.722  1
558927  93.570  -57.687  54.716  1
558928  93.604  -57.695  54.728  1
558929  93.642  -57.714  54.737  1
558930  93.680  -57.733  54.742  1
558931  93.718  -57.753  54.744  1
558932  93.757  -57.774  54.743  1
558933  93.795  -57.793  54.736  1
558934  93.833  -57.813  54.728  1
558935  93.871  -57.833  54.715  1
558936  93.910  -57.852  54.700  1
558937  93.948  -57.872  54.685  1
558938  93.986  -57.892  54.669  1
558939  94.025  -57.912  54.649  1
558940  94.063  -57.932  54.625  1
558941  94.101  -57.952  54.599  1
558942  94.139  -57.971  54.571  1
558943  94.178  -57.991  54.543  1
558944  94.216  -58.011  54.514  1
558945  94.254  -58.031  54.487  1
558946  94.292  -58.051  54.458  1
558947  94.320  -58.063  54.428  1
558948  94.346  -58.075  54.397  1
558949  94.373  -58.087  54.366  1
558950  94.400  -58.098  54.335  1
558951  94.426  -58.110  54.307  1
558952  94.455  -58.124  54.283  1
558953  94.484  -58.137  54.256  1
558954  94.512  -58.150  54.227  1
558955  94.541  -58.163  54.198  1
558956  94.569  -58.177  54.168  1
558957  94.594  -58.189  54.141  1
558958  94.619  -58.201  54.108  1
558959  94.644  -58.212  54.072  1
558960  94.670  -58.225  54.033  1
558961  94.695  -58.237  53.989  1
558962  94.720  -58.249  53.943  1
558963  94.746  -58.261  53.900  1
558964  94.771  -58.273  53.861  1
558965  94.796  -58.285  53.818  1
558966  94.821  -58.297  53.772  1
558967  94.862  -58.308  53.726  1
558968  94.918  -58.317  53.688  1
558969  94.974  -58.327  53.650  1
558970  95.030  -58.336  53.613  1
558971  95.086  -58.345  53.579  1
558972  95.141  -58.354  53.550  1
558973  95.197  -58.363  53.523  1
558974  95.253  -58.373  53.494  1
558975  95.309  -58.382  53.463  1
558976  95.355  -58.387  53.433  1
558977  95.393  -58.386  53.407  1
558978  95.423  -58.387  53.381  1
558979  95.453  -58.388  53.352  1
558980  95.482  -58.390  53.322  1
558981  95.512  -58.391  53.296  1
558982  95.542  -58.393  53.272  1
558983  95.573  -58.400  53.251  1
558984  95.605  -58.414  53.238  1
558985  95.637  -58.428  53.233  1
558986  95.670  -58.441  53.226  1
558987  95.702  -58.455  53.212  1
558988  95.734  -58.469  53.198  1
558989  95.766  -58.482  53.190  1
558990  95.799  -58.496  53.171  1
558991  95.831  -58.510  53.141  1
558992  95.863  -58.520  53.117  1
558993  95.893  -58.526  53.092  1
558994  95.923  -58.533  53.065  1
558995  95.953  -58.540  53.039  1
558996  95.983  -58.546  53.010  1
558997  96.014  -58.553  52.971  1
558998  96.046  -58.563  52.941  1
558999  96.079  -58.574  52.909  1
559000  96.112  -58.585  52.876  1
559001  96.145  -58.596  52.852  1
559002  96.178  -58.607  52.820  1
559003  96.210  -58.618  52.787  1
559004  96.243  -58.629  52.762  1
559005  96.276  -58.640  52.736  1
559006  96.308  -58.642  52.703  1
559007  96.338  -58.640  52.670  1
559008  96.370  -58.639  52.649  1
559009  96.401  -58.636  52.625  1
559010  96.432  -58.635  52.591  1
559011  96.463  -58.633  52.555  1
559012  96.495  -58.631  52.523  1
559013  96.526  -58.630  52.487  1
559014  96.561  -58.633  52.449  1
559015  96.596  -58.636  52.411  1
559016  96.630  -58.639  52.372  1
559017  96.662  -58.641  52.331  1
559018  96.693  -58.642  52.290  1
559019  96.725  -58.647  52.248  1
559020  96.757  -58.653  52.205  1
559021  96.789  -58.658  52.160  1
559022  96.821  -58.664  52.115  1
559023  96.853  -58.670  52.071  1
559024  96.885  -58.675  52.029  1
559025  96.917  -58.680  51.987  1
559026  96.949  -58.686  51.946  1
559027  96.981  -58.692  51.902  1
559028  97.014  -58.693  51.859  1
559029  97.048  -58.696  51.818  1
559030  97.081  -58.700  51.778  1
559031  97.114  -58.705  51.740  1
559032  97.147  -58.708  51.704  1
559033  97.180  -58.713  51.665  1
559034  97.213  -58.717  51.624  1
559035  97.245  -58.721  51.588  1
559036  97.278  -58.725  51.556  1
559037  97.311  -58.730  51.526  1
559038  97.343  -58.733  51.489  1
559039  97.376  -58.738  51.445  1
559040  97.408  -58.742  51.401  1
559041  97.441  -58.746  51.362  1
559042  97.473  -58.750  51.325  1
559043  97.506  -58.755  51.286  1
559044  97.542  -58.755  51.244  1
559045  97.574  -58.761  51.199  1
559046  97.608  -58.767  51.155  1
559047  97.644  -58.773  51.117  1
559048  97.679  -58.779  51.078  1
559049  97.717  -58.784  51.040  1
559050  97.756  -58.789  51.000  1
559051  97.796  -58.795  50.955  1
559052  97.835  -58.799  50.909  1
559053  97.873  -58.802  50.867  1
559054  97.911  -58.805  50.827  1
559055  97.952  -58.797  50.786  1
559056  97.994  -58.786  50.747  1
559057  98.035  -58.774  50.708  1
559058  98.077  -58.762  50.672  1
559059  98.118  -58.753  50.636  1
559060  98.150  -58.754  50.600  1
559061  98.183  -58.755  50.567  1
559062  98.217  -58.756  50.534  1
559063  98.252  -58.757  50.500  1
559064  98.288  -58.758  50.469  1
559065  98.323  -58.758  50.436  1
559066  98.358  -58.759  50.404  1
559067  98.393  -58.760  50.375  1
559068  98.428  -58.761  50.345  1
559069  98.459  -58.763  50.316  1
559070  98.491  -58.766  50.289  1
559071  98.524  -58.764  50.263  1
559072  98.558  -58.754  50.239  1
559073  98.588  -58.750  50.215  1
559074  98.617  -58.747  50.194  1
559075  98.645  -58.745  50.174  1
559076  98.674  -58.742  50.158  1
559077  98.703  -58.739  50.144  1
559078  98.732  -58.737  50.132  1
559079  98.765  -58.733  50.120  1
559080  98.799  -58.730  50.107  1
559081  98.834  -58.726  50.090  1
559082  98.868  -58.723  50.072  1
559083  98.903  -58.714  50.053  1
559084  98.941  -58.699  50.034  1
559085  98.988  -58.695  50.013  1
559086  99.034  -58.691  49.991  1
559087  99.074  -58.686  49.968  1
559088  99.115  -58.680  49.941  1
559089  99.154  -58.674  49.914  1
559090  99.195  -58.669  49.885  1
559091  99.239  -58.663  49.854  1
559092  99.311  -58.657  49.823  1
559093  99.378  -58.653  49.794  1
559094  99.414  -58.661  49.766  1
559095  99.449  -58.668  49.739  1
559096  99.485  -58.676  49.712  1
559097  99.520  -58.683  49.684  1
559098  99.556  -58.691  49.657  1
559099  99.592  -58.698  49.629  1
559100  99.628  -58.706  49.601  1
559101  99.663  -58.714  49.571  1
559102  99.699  -58.720  49.541  1
559103  99.734  -58.728  49.509  1
559104  99.770  -58.736  49.476  1
559105  99.806  -58.743  49.444  1
559450  86.970  -55.227  57.630  4
559451  87.005  -55.244  57.626  4
559452  87.040  -55.260  57.622  4
559453  87.075  -55.276  57.615  4
559454  87.110  -55.292  57.608  4
559455  87.145  -55.308  57.601  4
559456  87.180  -55.324  57.593  4
559457  87.215  -55.340  57.585  4
559458  87.250  -55.356  57.577  4
559459  87.285  -55.373  57.568  4
559460  87.320  -55.389  57.557  4
559461  87.355  -55.405  57.548  4
559462  87.390  -55.420  57.542  4
559463  87.425  -55.437  57.527  4
559464  87.457  -55.454  57.508  4
559465  87.500  -55.461  57.486  4
559466  87.556  -55.464  57.466  4
559467  87.612  -55.469  57.444  4
559468  87.668  -55.473  57.413  4
559469  87.715  -55.486  57.382  4
559470  87.753  -55.503  57.349  4
559471  87.791  -55.519  57.315  4
559472  87.829  -55.535  57.279  4
559473  87.867  -55.551  57.241  4
559474  87.906  -55.567  57.200  4
559475  87.944  -55.583  57.159  4
559476  87.982  -55.599  57.116  4
559477  88.021  -55.614  57.072  4
559478  88.059  -55.630  57.027  4
559479  88.097  -55.646  56.982  4
559480  88.135  -55.663  56.937  4
559481  88.173  -55.679  56.894  4
559482  88.211  -55.695  56.853  4
559483  88.250  -55.711  56.812  4
559506  89.130  -56.078  56.062  1
559507  89.168  -56.094  56.040  1
559508  89.206  -56.110  56.020  1
559509  89.244  -56.126  56.002  1
559510  89.282  -56.142  55.985  1
559511  89.321  -56.158  55.968  1
559512  89.359  -56.174  55.953  1
559513  89.397  -56.190  55.940  1
559514  89.436  -56.206  55.929  1
559515  89.474  -56.222  55.919  1
559516  89.512  -56.238  55.911  1
559517  89.550  -56.254  55.904  1
559518  89.589  -56.270  55.899  1
559519  89.627  -56.286  55.896  1
559520  89.656  -56.307  55.896  1
559521  89.696  -56.319  55.898  1
559522  89.738  -56.330  55.902  1
559523  89.779  -56.341  55.909  1
559524  89.821  -56.351  55.918  1
559525  89.859  -56.364  55.929  1
559526  89.884  -56.381  55.944  1
559527  89.910  -56.398  55.964  1
559528  89.936  -56.415  55.984  1
559529  89.961  -56.432  56.009  1
559530  89.987  -56.449  56.042  1
559531  90.013  -56.466  56.077  1
559532  90.038  -56.483  56.104  1
559533  90.068  -56.499  56.121  1
559534  90.111  -56.515  56.120  1
559535  90.155  -56.528  56.110  1
559536  90.198  -56.540  56.097  1
559537  90.241  -56.552  56.077  1
559538  90.285  -56.565  56.041  1
559539  90.328  -56.577  55.993  1
559540  90.371  -56.589  55.934  1
559541  90.414  -56.602  55.874  1
559542  90.458  -56.614  55.818  1
559543  90.501  -56.626  55.769  1
559544  90.544  -56.638  55.723  1
559545  90.588  -56.650  55.683  1
559546  90.632  -56.663  55.646  1
559547  90.675  -56.675  55.611  1
559548  90.718  -56.687  55.579  1
559549  90.761  -56.699  55.549  1
559550  90.805  -56.711  55.521  1
559551  90.848  -56.724  55.498  1
559552  90.891  -56.736  55.478  1
559553  90.932  -56.750  55.459  1
559554  90.967  -56.768  55.441  1
559555  91.003  -56.784  55.425  1
559556  91.038  -56.802  55.409  1
559557  91.073  -56.819  55.395  1
559558  91.108  -56.837  55.383  1
559559  91.144  -56.854  55.371  1
559560  91.179  -56.871  55.359  1
559561  91.214  -56.889  55.348  1
559562  91.250  -56.906  55.337  1
559563  91.285  -56.923  55.327  1
559564  91.320  -56.940  55.320  1
559565  91.352  -56.953  55.313  1
559566  91.384  -56.965  55.309  1
559567  91.417  -56.977  55.308  1
559568  91.449  -56.989  55.310  1
559569  91.482  -57.001  55.316  1
559570  91.519  -57.012  55.323  1
559571  91.562  -57.022  55.328  1
559572  91.604  -57.031  55.327  1
559573  91.647  -57.041  55.317  1
559574  91.690  -57.050  55.311  1
559575  91.733  -57.060  55.317  1
559576  91.776  -57.070  55.333  1
559577  91.819  -57.080  55.358  1
559578  91.862  -57.089  55.378  1
559579  91.905  -57.099  55.390  1
559580  91.948  -57.109  55.396  1
559581  91.991  -57.118  55.397  1
559582  92.034  -57.128  55.394  1
559583  92.075  -57.147  55.390  1
559584  92.117  -57.169  55.382  1
559585  92.157  -57.193  55.366  1
559586  92.199  -57.216  55.354  1
559587  92.239  -57.240  55.350  1
559588  92.281  -57.263  55.355  1
559589  92.321  -57.287  55.364  1
559590  92.363  -57.310  55.362  1
559591  92.403  -57.334  55.354  1
559592  92.440  -57.361  55.342  1
559593  92.477  -57.388  55.327  1
559594  92.513  -57.414  55.311  1
559595  92.550  -57.442  55.293  1
559596  92.586  -57.468  55.272  1
559597  92.623  -57.495  55.248  1
559598  92.658  -57.516  55.223  1
559599  92.692  -57.527  55.195  1
559600  92.724  -57.538  55.165  1
559601  92.758  -57.549  55.139  1
559602  92.790  -57.561  55.113  1
559603  92.824  -57.571  55.086  1
559604  92.856  -57.583  55.061  1
559605  92.889  -57.593  55.040  1
559606  92.921  -57.603  55.020  1
559607  92.949  -57.610  55.002  1
559608  92.978  -57.617  54.985  1
559609  93.004  -57.623  54.969  1
559610  93.028  -57.630  54.955  1
559611  93.053  -57.636  54.944  1
559612  93.077  -57.642  54.931  1
559613  93.105  -57.645  54.916  1
559614  93.136  -57.644  54.903  1
559615  93.167  -57.643  54.893  1
559616  93.199  -57.642  54.883  1
559617  93.230  -57.642  54.872  1
559618  93.262  -57.641  54.859  1
559619  93.293  -57.640  54.848  1
559620  93.324  -57.639  54.841  1
559621  93.355  -57.639  54.835  1
559622  93.387  -57.639  54.826  1
559623  93.418  -57.638  54.813  1
559624  93.449  -57.637  54.790  1
559625  93.481  -57.636  54.765  1
559626  93.512  -57.636  54.739  1
559627  93.544  -57.635  54.717  1
559628  93.578  -57.643  54.703  1
559629  93.613  -57.651  54.707  1
559630  93.651  -57.671  54.715  1
559631  93.689  -57.691  54.723  1
559632  93.727  -57.711  54.727  1
559633  93.766  -57.730  54.727  1
559634  93.804  -57.751  54.725  1
559635  93.842  -57.771  54.718  1
559636  93.880  -57.790  54.709  1
559637  93.919  -57.810  54.699  1
559638  93.957  -57.830  54.689  1
559639  93.995  -57.849  54.677  1
559640  94.034  -57.870  54.660  1
559641  94.072  -57.890  54.638  1
559642  94.110  -57.909  54.614  1
559643  94.148  -57.929  54.587  1
559644  94.187  -57.949  54.558  1
559645  94.225  -57.968  54.530  1
559646  94.263  -57.988  54.503  1
559647  94.301  -58.009  54.476  1
559648  94.340  -58.028  54.446  1
559649  94.368  -58.041  54.415  1
559650  94.395  -58.053  54.384  1
559651  94.421  -58.065  54.351  1
559652  94.449  -58.077  54.326  1
559653  94.478  -58.090  54.305  1
559654  94.506  -58.104  54.282  1
559655  94.534  -58.117  54.255  1
559656  94.559  -58.129  54.226  1
559657  94.584  -58.141  54.195  1
559658  94.610  -58.153  54.168  1
559659  94.635  -58.165  54.136  1
559660  94.660  -58.178  54.100  1
559661  94.685  -58.189  54.060  1
559662  94.710  -58.201  54.014  1
559663  94.736  -58.213  53.964  1
559664  94.761  -58.225  53.917  1
559665  94.786  -58.238  53.874  1
559666  94.812  -58.250  53.831  1
559667  94.837  -58.262  53.785  1
559668  94.865  -58.274  53.734  1
559669  94.921  -58.283  53.686  1
559670  94.977  -58.292  53.643  1
559671  95.033  -58.301  53.603  1
559672  95.089  -58.311  53.566  1
559673  95.145  -58.320  53.533  1
559674  95.201  -58.329  53.504  1
559675  95.257  -58.338  53.472  1
559676  95.313  -58.347  53.440  1
559677  95.359  -58.352  53.408  1
559678  95.396  -58.351  53.378  1
559679  95.432  -58.350  53.351  1
559680  95.462  -58.352  53.320  1
559681  95.492  -58.354  53.291  1
559682  95.522  -58.355  53.266  1
559683  95.552  -58.357  53.244  1
559684  95.582  -58.360  53.224  1
559685  95.614  -58.373  53.209  1
559686  95.646  -58.387  53.207  1
559687  95.678  -58.400  53.205  1
559688  95.710  -58.414  53.193  1
559689  95.743  -58.428  53.180  1
559690  95.775  -58.441  53.174  1
559691  95.808  -58.454  53.161  1
559692  95.840  -58.468  53.128  1
559693  95.870  -58.476  53.106  1
559694  95.901  -58.482  53.088  1
559695  95.931  -58.489  53.069  1
559696  95.961  -58.496  53.045  1
559697  95.991  -58.502  53.006  1
559698  96.024  -58.513  52.966  1
559699  96.056  -58.523  52.941  1
559700  96.089  -58.534  52.915  1
559701  96.122  -58.545  52.883  1
559702  96.155  -58.556  52.862  1
559703  96.188  -58.567  52.828  1
559704  96.221  -58.578  52.796  1
559705  96.253  -58.589  52.772  1
559706  96.286  -58.600  52.747  1
559707  96.319  -58.611  52.715  1
559708  96.350  -58.610  52.681  1
559709  96.381  -58.608  52.659  1
559710  96.412  -58.607  52.632  1
559711  96.444  -58.605  52.597  1
559712  96.475  -58.603  52.560  1
559713  96.506  -58.601  52.529  1
559714  96.537  -58.600  52.496  1
559715  96.568  -58.598  52.459  1
559716  96.599  -58.596  52.420  1
559717  96.633  -58.598  52.379  1
559718  96.667  -58.601  52.336  1
559719  96.698  -58.604  52.295  1
559720  96.731  -58.609  52.255  1
559721  96.762  -58.615  52.210  1
559722  96.795  -58.620  52.165  1
559723  96.826  -58.626  52.119  1
559724  96.859  -58.632  52.074  1
559725  96.890  -58.637  52.033  1
559726  96.923  -58.642  51.994  1
559727  96.954  -58.648  51.954  1
559728  96.986  -58.654  51.911  1
559729  97.019  -58.657  51.868  1
559730  97.052  -58.662  51.828  1
559731  97.085  -58.666  51.788  1
559732  97.117  -58.670  51.748  1
559733  97.150  -58.675  51.708  1
559734  97.183  -58.679  51.667  1
559735  97.216  -58.683  51.626  1
559736  97.248  -58.687  51.589  1
559737  97.281  -58.692  51.553  1
559738  97.314  -58.695  51.515  1
559739  97.347  -58.700  51.475  1
559740  97.379  -58.704  51.432  1
559741  97.412  -58.708  51.388  1
559742  97.444  -58.712  51.348  1
559743  97.477  -58.716  51.310  1
559744  97.513  -58.716  51.271  1
559745  97.548  -58.717  51.230  1
559746  97.580  -58.723  51.186  1
559747  97.612  -58.729  51.144  1
559748  97.647  -58.735  51.102  1
559749  97.682  -58.741  51.061  1
559750  97.722  -58.745  51.020  1
559751  97.761  -58.751  50.979  1
559752  97.800  -58.753  50.936  1
559753  97.838  -58.756  50.892  1
559754  97.876  -58.759  50.850  1
559755  97.914  -58.761  50.810  1
559756  97.953  -58.761  50.773  1
559757  97.995  -58.749  50.736  1
559758  98.036  -58.738  50.699  1
559759  98.078  -58.726  50.663  1
559760  98.116  -58.720  50.626  1
559761  98.149  -58.721  50.593  1
559762  98.181  -58.722  50.559  1
559763  98.214  -58.723  50.525  1
559764  98.249  -58.723  50.492  1
559765  98.285  -58.724  50.459  1
559766  98.319  -58.725  50.427  1
559767  98.355  -58.726  50.396  1
559768  98.390  -58.727  50.365  1
559769  98.425  -58.728  50.334  1
559770  98.460  -58.729  50.304  1
559771  98.496  -58.730  50.277  1
559772  98.531  -58.730  50.250  1
559773  98.561  -58.728  50.223  1
559774  98.589  -58.726  50.199  1
559775  98.618  -58.723  50.178  1
559776  98.647  -58.720  50.158  1
559777  98.676  -58.718  50.139  1
559778  98.705  -58.715  50.125  1
559779  98.734  -58.713  50.112  1
559780  98.769  -58.709  50.100  1
559781  98.803  -58.705  50.087  1
559782  98.838  -58.700  50.072  1
559783  98.873  -58.683  50.056  1
559784  98.909  -58.667  50.038  1
559785  98.949  -58.655  50.020  1
559786  98.996  -58.651  50.001  1
559787  99.044  -58.648  49.980  1
559788  99.090  -58.645  49.959  1
559789  99.137  -58.641  49.935  1
559790  99.178  -58.635  49.909  1
559791  99.218  -58.629  49.881  1
559792  99.258  -58.623  49.852  1
559793  99.319  -58.618  49.823  1
559794  99.379  -58.617  49.792  1
559795  99.414  -58.624  49.765  1
559796  99.450  -58.632  49.739  1
559797  99.486  -58.639  49.712  1
559798  99.521  -58.647  49.685  1
559799  99.557  -58.654  49.659  1
559800  99.593  -58.661  49.632  1
559801  99.629  -58.669  49.604  1
559802  99.664  -58.676  49.575  1
559803  99.700  -58.684  49.545  1
559804  99.735  -58.692  49.515  1
559805  99.771  -58.699  49.483  1
559806  99.807  -58.707  49.451  1
560151  87.000  -55.177  57.629  4
560152  87.035  -55.194  57.625  4
560153  87.070  -55.210  57.621  4
560154  87.105  -55.226  57.616  4
560155  87.140  -55.242  57.609  4
560156  87.175  -55.258  57.603  4
560157  87.210  -55.274  57.595  4
560158  87.245  -55.290  57.589  4
560159  87.280  -55.306  57.582  4
560160  87.315  -55.323  57.573  4
560161  87.350  -55.339  57.563  4
560162  87.385  -55.354  57.556  4
560163  87.416  -55.371  57.551  4
560164  87.446  -55.389  57.538  4
560165  87.477  -55.406  57.522  4
560166  87.511  -55.419  57.506  4
560167  87.561  -55.416  57.489  4
560168  87.616  -55.420  57.471  4
560169  87.677  -55.429  57.440  4
560170  87.734  -55.443  57.406  4
560171  87.775  -55.460  57.373  4
560172  87.813  -55.477  57.341  4
560173  87.850  -55.493  57.305  4
560174  87.888  -55.510  57.268  4
560175  87.925  -55.527  57.229  4
560176  87.963  -55.542  57.187  4
560177  88.001  -55.559  57.144  4
560178  88.038  -55.576  57.101  4
560179  88.076  -55.593  57.055  4
560180  88.115  -55.608  57.010  4
560181  88.153  -55.624  56.964  4
560182  88.191  -55.640  56.920  4
560183  88.229  -55.656  56.877  4
560184  88.268  -55.672  56.836  4
560185  88.306  -55.688  56.794  4
560208  89.186  -56.056  56.040  1
560209  89.224  -56.072  56.019  1
560210  89.262  -56.088  56.000  1
560211  89.301  -56.103  55.982  1
560212  89.339  -56.119  55.965  1
560213  89.377  -56.135  55.949  1
560214  89.415  -56.151  55.936  1
560215  89.454  -56.168  55.925  1
560216  89.492  -56.184  55.914  1
560217  89.530  -56.200  55.905  1
560218  89.568  -56.216  55.898  1
560219  89.606  -56.232  55.892  1
560220  89.645  -56.248  55.889  1
560221  89.675  -56.268  55.888  1
560222  89.716  -56.279  55.890  1
560223  89.757  -56.290  55.894  1
560224  89.799  -56.301  55.899  1
560225  89.840  -56.312  55.907  1
560226  89.866  -56.329  55.917  1
560227  89.892  -56.346  55.930  1
560228  89.917  -56.363  55.949  1
560229  89.943  -56.380  55.969  1
560230  89.969  -56.397  55.997  1
560231  89.994  -56.414  56.034  1
560232  90.020  -56.431  56.068  1
560233  90.045  -56.448  56.093  1
560234  90.083  -56.463  56.111  1
560235  90.126  -56.475  56.108  1
560236  90.169  -56.487  56.095  1
560237  90.213  -56.500  56.077  1
560238  90.256  -56.512  56.052  1
560239  90.299  -56.524  56.014  1
560240  90.342  -56.536  55.966  1
560241  90.386  -56.548  55.915  1
560242  90.429  -56.561  55.862  1
560243  90.472  -56.573  55.811  1
560244  90.516  -56.585  55.765  1
560245  90.559  -56.598  55.722  1
560246  90.602  -56.610  55.684  1
560247  90.646  -56.622  55.649  1
560248  90.689  -56.634  55.616  1
560249  90.733  -56.646  55.585  1
560250  90.776  -56.658  55.558  1
560251  90.819  -56.671  55.531  1
560252  90.863  -56.683  55.509  1
560253  90.906  -56.696  55.489  1
560254  90.949  -56.708  55.471  1
560255  90.988  -56.723  55.454  1
560256  91.023  -56.740  55.439  1
560257  91.058  -56.758  55.425  1
560258  91.093  -56.775  55.411  1
560259  91.129  -56.792  55.398  1
560260  91.164  -56.809  55.386  1
560261  91.200  -56.827  55.374  1
560262  91.235  -56.844  55.361  1
560263  91.270  -56.862  55.348  1
560264  91.305  -56.879  55.338  1
560265  91.340  -56.894  55.329  1
560266  91.372  -56.906  55.321  1
560267  91.404  -56.918  55.315  1
560268  91.436  -56.931  55.312  1
560269  91.468  -56.943  55.311  1
560270  91.501  -56.956  55.314  1
560271  91.533  -56.968  55.318  1
560272  91.574  -56.978  55.321  1
560273  91.616  -56.987  55.320  1
560274  91.659  -56.997  55.316  1
560275  91.702  -57.006  55.315  1
560276  91.745  -57.016  55.322  1
560277  91.788  -57.026  55.337  1
560278  91.831  -57.035  55.357  1
560279  91.874  -57.045  55.374  1
560280  91.917  -57.055  55.383  1
560281  91.960  -57.064  55.391  1
560282  92.003  -57.074  55.398  1
560283  92.045  -57.088  55.405  1
560284  92.086  -57.112  55.410  1
560285  92.127  -57.135  55.408  1
560286  92.168  -57.159  55.399  1
560287  92.209  -57.182  55.385  1
560288  92.250  -57.206  55.371  1
560289  92.291  -57.229  55.362  1
560290  92.333  -57.252  55.369  1
560291  92.373  -57.275  55.366  1
560292  92.415  -57.299  55.355  1
560293  92.451  -57.326  55.342  1
560294  92.488  -57.353  55.327  1
560295  92.524  -57.379  55.312  1
560296  92.561  -57.406  55.298  1
560297  92.598  -57.433  55.282  1
560298  92.634  -57.459  55.262  1
560299  92.668  -57.479  55.237  1
560300  92.702  -57.494  55.210  1
560301  92.735  -57.505  55.181  1
560302  92.768  -57.517  55.154  1
560303  92.801  -57.527  55.128  1
560304  92.834  -57.539  55.101  1
560305  92.867  -57.549  55.073  1
560306  92.900  -57.561  55.048  1
560307  92.929  -57.568  55.023  1
560308  92.958  -57.576  55.001  1
560309  92.986  -57.583  54.983  1
560310  93.015  -57.590  54.967  1
560311  93.041  -57.596  54.952  1
560312  93.065  -57.602  54.937  1
560313  93.089  -57.608  54.924  1
560314  93.117  -57.611  54.907  1
560315  93.148  -57.611  54.891  1
560316  93.179  -57.610  54.877  1
560317  93.211  -57.609  54.865  1
560318  93.242  -57.608  54.851  1
560319  93.273  -57.608  54.837  1
560320  93.304  -57.607  54.828  1
560321  93.336  -57.606  54.819  1
560322  93.367  -57.605  54.811  1
560323  93.399  -57.605  54.806  1
560324  93.430  -57.604  54.798  1
560325  93.462  -57.603  54.779  1
560326  93.493  -57.602  54.756  1
560327  93.524  -57.601  54.733  1
560328  93.555  -57.601  54.711  1
560329  93.587  -57.600  54.693  1
560330  93.621  -57.609  54.688  1
560331  93.659  -57.629  54.693  1
560332  93.698  -57.648  54.699  1
560333  93.736  -57.668  54.704  1
560334  93.774  -57.688  54.705  1
560335  93.813  -57.708  54.706  1
560336  93.851  -57.728  54.702  1
560337  93.889  -57.748  54.695  1
560338  93.927  -57.767  54.688  1
560339  93.966  -57.787  54.680  1
560340  94.004  -57.807  54.671  1
560341  94.042  -57.827  54.659  1
560342  94.080  -57.847  54.642  1
560343  94.119  -57.867  54.623  1
560344  94.157  -57.887  54.600  1
560345  94.195  -57.906  54.575  1
560346  94.234  -57.926  54.549  1
560347  94.272  -57.946  54.521  1
560348  94.310  -57.966  54.494  1
560349  94.348  -57.986  54.464  1
560350  94.387  -58.006  54.434  1
560351  94.416  -58.019  54.404  1
560352  94.443  -58.031  54.375  1
560353  94.472  -58.044  54.350  1
560354  94.499  -58.057  54.328  1
560355  94.524  -58.069  54.306  1
560356  94.549  -58.081  54.282  1
560357  94.575  -58.093  54.253  1
560358  94.600  -58.106  54.221  1
560359  94.625  -58.118  54.191  1
560360  94.650  -58.130  54.159  1
560361  94.676  -58.142  54.124  1
560362  94.701  -58.154  54.082  1
560363  94.726  -58.166  54.035  1
560364  94.752  -58.178  53.985  1
560365  94.777  -58.190  53.934  1
560366  94.802  -58.202  53.886  1
560367  94.827  -58.214  53.841  1
560368  94.852  -58.226  53.795  1
560369  94.878  -58.238  53.742  1
560370  94.925  -58.248  53.688  1
560371  94.981  -58.258  53.640  1
560372  95.037  -58.267  53.597  1
560373  95.093  -58.276  53.557  1
560374  95.149  -58.285  53.519  1
560375  95.205  -58.295  53.485  1
560376  95.261  -58.304  53.452  1
560377  95.317  -58.313  53.418  1
560378  95.363  -58.317  53.384  1
560379  95.400  -58.317  53.351  1
560380  95.437  -58.316  53.323  1
560381  95.472  -58.316  53.293  1
560382  95.502  -58.317  53.265  1
560383  95.532  -58.319  53.239  1
560384  95.561  -58.320  53.217  1
560385  95.591  -58.322  53.200  1
560386  95.622  -58.332  53.189  1
560387  95.655  -58.345  53.186  1
560388  95.687  -58.359  53.179  1
560389  95.720  -58.372  53.167  1
560390  95.752  -58.386  53.155  1
560391  95.784  -58.400  53.148  1
560392  95.816  -58.413  53.142  1
560393  95.848  -58.426  53.114  1
560394  95.878  -58.432  53.091  1
560395  95.908  -58.438  53.072  1
560396  95.939  -58.445  53.054  1
560397  95.969  -58.452  53.033  1
560398  96.001  -58.461  53.002  1
560399  96.034  -58.473  52.968  1
560400  96.066  -58.483  52.945  1
560401  96.099  -58.494  52.922  1
560402  96.132  -58.505  52.893  1
560403  96.165  -58.516  52.868  1
560404  96.198  -58.527  52.833  1
560405  96.231  -58.538  52.804  1
560406  96.263  -58.549  52.779  1
560407  96.296  -58.560  52.755  1
560408  96.329  -58.571  52.728  1
560409  96.362  -58.580  52.694  1
560410  96.393  -58.579  52.671  1
560411  96.424  -58.577  52.641  1
560412  96.455  -58.576  52.604  1
560413  96.486  -58.573  52.567  1
560414  96.517  -58.572  52.535  1
560415  96.548  -58.570  52.504  1
560416  96.580  -58.568  52.468  1
560417  96.611  -58.567  52.429  1
560418  96.642  -58.565  52.386  1
560419  96.673  -58.563  52.341  1
560420  96.705  -58.567  52.300  1
560421  96.737  -58.573  52.260  1
560422  96.769  -58.579  52.214  1
560423  96.802  -58.585  52.169  1
560424  96.834  -58.592  52.123  1
560425  96.867  -58.598  52.078  1
560426  96.899  -58.604  52.039  1
560427  96.932  -58.610  52.001  1
560428  96.964  -58.616  51.963  1
560429  96.996  -58.622  51.922  1
560430  97.025  -58.625  51.881  1
560431  97.055  -58.628  51.842  1
560432  97.088  -58.632  51.800  1
560433  97.120  -58.636  51.759  1
560434  97.153  -58.641  51.717  1
560435  97.186  -58.645  51.675  1
560436  97.219  -58.649  51.636  1
560437  97.251  -58.653  51.599  1
560438  97.284  -58.657  51.559  1
560439  97.317  -58.662  51.516  1
560440  97.350  -58.666  51.473  1
560441  97.382  -58.670  51.429  1
560442  97.415  -58.674  51.385  1
560443  97.448  -58.678  51.343  1
560444  97.484  -58.678  51.303  1
560445  97.519  -58.677  51.263  1
560446  97.555  -58.679  51.221  1
560447  97.586  -58.685  51.178  1
560448  97.617  -58.691  51.136  1
560449  97.650  -58.697  51.092  1
560450  97.687  -58.702  51.050  1
560451  97.726  -58.705  51.009  1
560452  97.764  -58.708  50.966  1
560453  97.802  -58.711  50.923  1
560454  97.840  -58.713  50.882  1
560455  97.878  -58.716  50.841  1
560456  97.916  -58.718  50.802  1
560457  97.954  -58.721  50.765  1
560458  97.996  -58.713  50.728  1
560459  98.037  -58.701  50.692  1
560460  98.079  -58.689  50.656  1
560461  98.114  -58.687  50.622  1
560462  98.147  -58.688  50.589  1
560463  98.180  -58.689  50.555  1
560464  98.213  -58.690  50.521  1
560465  98.246  -58.691  50.487  1
560466  98.281  -58.692  50.454  1
560467  98.316  -58.692  50.422  1
560468  98.352  -58.693  50.390  1
560469  98.387  -58.694  50.358  1
560470  98.422  -58.695  50.327  1
560471  98.457  -58.695  50.296  1
560472  98.492  -58.696  50.267  1
560473  98.526  -58.698  50.240  1
560474  98.557  -58.698  50.213  1
560475  98.589  -58.699  50.188  1
560476  98.620  -58.699  50.166  1
560477  98.649  -58.696  50.145  1
560478  98.677  -58.694  50.126  1
560479  98.706  -58.692  50.110  1
560480  98.738  -58.688  50.095  1
560481  98.772  -58.685  50.081  1
560482  98.808  -58.670  50.069  1
560483  98.843  -58.654  50.054  1
560484  98.879  -58.637  50.039  1
560485  98.915  -58.620  50.023  1
560486  98.957  -58.612  50.006  1
560487  99.005  -58.608  49.988  1
560488  99.052  -58.604  49.969  1
560489  99.098  -58.601  49.949  1
560490  99.146  -58.597  49.926  1
560491  99.193  -58.593  49.902  1
560492  99.239  -58.590  49.876  1
560493  99.281  -58.585  49.849  1
560494  99.327  -58.579  49.821  1
560495  99.379  -58.580  49.790  1
560496  99.415  -58.588  49.763  1
560497  99.451  -58.595  49.736  1
560498  99.487  -58.602  49.710  1
560499  99.522  -58.610  49.685  1
560500  99.558  -58.617  49.658  1
560501  99.593  -58.625  49.632  1
560502  99.628  -58.633  49.605  1
560503  99.663  -58.642  49.577  1
560504  99.697  -58.651  49.548  1
560505  99.732  -58.660  49.518  1
560506  99.766  -58.668  49.487  1
560507  99.801  -58.677  49.456  1
560852  87.030  -55.127  57.626  4
560853  87.065  -55.144  57.624  4
560854  87.100  -55.160  57.620  4
560855  87.135  -55.176  57.616  4
560856  87.170  -55.191  57.609  4
560857  87.205  -55.208  57.603  4
560858  87.240  -55.224  57.597  4
560859  87.275  -55.240  57.591  4
560860  87.310  -55.256  57.585  4
560861  87.345  -55.273  57.577  4
560862  87.375  -55.289  57.568  4
560863  87.406  -55.307  57.562  4
560864  87.436  -55.324  57.554  4
560865  87.466  -55.341  57.543  4
560866  87.496  -55.358  57.532  4
560867  87.527  -55.376  57.522  4
560868  87.573  -55.376  57.509  4
560869  87.625  -55.376  57.492  4
560870  87.687  -55.386  57.463  4
560871  87.745  -55.401  57.429  4
560872  87.798  -55.417  57.396  4
560873  87.836  -55.433  57.365  4
560874  87.873  -55.450  57.331  4
560875  87.911  -55.467  57.294  4
560876  87.948  -55.483  57.255  4
560877  87.986  -55.500  57.215  4
560878  88.024  -55.516  57.172  4
560879  88.061  -55.533  57.129  4
560880  88.099  -55.549  57.083  4
560881  88.136  -55.566  57.037  4
560882  88.174  -55.583  56.992  4
560883  88.211  -55.599  56.946  4
560884  88.249  -55.616  56.902  4
560885  88.287  -55.633  56.860  4
560886  88.324  -55.649  56.817  4
560909  89.203  -56.017  56.039  1
560910  89.242  -56.033  56.018  1
560911  89.280  -56.049  55.998  1
560912  89.318  -56.065  55.980  1
560913  89.356  -56.081  55.962  1
560914  89.395  -56.097  55.947  1
560915  89.433  -56.113  55.933  1
560916  89.471  -56.129  55.920  1
560917  89.510  -56.145  55.909  1
560918  89.548  -56.161  55.900  1
560919  89.586  -56.177  55.892  1
560920  89.624  -56.193  55.887  1
560921  89.663  -56.209  55.883  1
560922  89.694  -56.229  55.881  1
560923  89.735  -56.240  55.882  1
560924  89.777  -56.251  55.885  1
560925  89.818  -56.261  55.888  1
560926  89.848  -56.277  55.895  1
560927  89.874  -56.294  55.904  1
560928  89.899  -56.311  55.916  1
560929  89.924  -56.328  55.933  1
560930  89.950  -56.345  55.953  1
560931  89.976  -56.362  55.980  1
560932  90.002  -56.379  56.013  1
560933  90.029  -56.398  56.043  1
560934  90.061  -56.413  56.064  1
560935  90.096  -56.425  56.077  1
560936  90.140  -56.436  56.076  1
560937  90.184  -56.447  56.063  1
560938  90.227  -56.459  56.043  1
560939  90.270  -56.471  56.019  1
560940  90.314  -56.483  55.983  1
560941  90.357  -56.495  55.939  1
560942  90.400  -56.508  55.894  1
560943  90.444  -56.520  55.847  1
560944  90.487  -56.533  55.802  1
560945  90.530  -56.545  55.759  1
560946  90.574  -56.557  55.721  1
560947  90.617  -56.569  55.685  1
560948  90.660  -56.581  55.652  1
560949  90.704  -56.593  55.621  1
560950  90.747  -56.605  55.593  1
560951  90.791  -56.617  55.566  1
560952  90.834  -56.630  55.541  1
560953  90.877  -56.642  55.520  1
560954  90.921  -56.655  55.502  1
560955  90.964  -56.667  55.485  1
560956  91.007  -56.679  55.469  1
560957  91.043  -56.696  55.456  1
560958  91.078  -56.713  55.444  1
560959  91.113  -56.730  55.431  1
560960  91.149  -56.748  55.418  1
560961  91.184  -56.765  55.404  1
560962  91.220  -56.783  55.390  1
560963  91.255  -56.799  55.376  1
560964  91.290  -56.817  55.362  1
560965  91.325  -56.834  55.350  1
560966  91.359  -56.848  55.340  1
560967  91.391  -56.860  55.330  1
560968  91.423  -56.873  55.323  1
560969  91.456  -56.885  55.316  1
560970  91.488  -56.897  55.312  1
560971  91.520  -56.909  55.311  1
560972  91.553  -56.921  55.311  1
560973  91.585  -56.934  55.313  1
560974  91.629  -56.943  55.315  1
560975  91.671  -56.953  55.317  1
560976  91.714  -56.962  55.322  1
560977  91.757  -56.972  55.331  1
560978  91.800  -56.982  55.344  1
560979  91.843  -56.991  55.364  1
560980  91.886  -57.001  55.380  1
560981  91.929  -57.011  55.388  1
560982  91.972  -57.020  55.393  1
560983  92.015  -57.031  55.401  1
560984  92.056  -57.054  55.411  1
560985  92.097  -57.078  55.419  1
560986  92.138  -57.100  55.421  1
560987  92.179  -57.124  55.415  1
560988  92.220  -57.147  55.404  1
560989  92.261  -57.171  55.389  1
560990  92.302  -57.194  55.375  1
560991  92.343  -57.218  55.373  1
560992  92.384  -57.241  55.365  1
560993  92.425  -57.265  55.352  1
560994  92.462  -57.291  55.336  1
560995  92.499  -57.317  55.320  1
560996  92.536  -57.344  55.305  1
560997  92.573  -57.371  55.294  1
560998  92.609  -57.398  55.282  1
560999  92.643  -57.419  55.265  1
561000  92.678  -57.440  55.244  1
561001  92.712  -57.461  55.222  1
561002  92.745  -57.473  55.200  1
561003  92.778  -57.483  55.175  1
561004  92.811  -57.495  55.148  1
561005  92.844  -57.505  55.119  1
561006  92.877  -57.517  55.089  1
561007  92.910  -57.527  55.059  1
561008  92.938  -57.534  55.031  1
561009  92.967  -57.542  55.007  1
561010  92.995  -57.548  54.987  1
561011  93.023  -57.555  54.968  1
561012  93.052  -57.563  54.951  1
561013  93.076  -57.569  54.933  1
561014  93.100  -57.574  54.917  1
561015  93.128  -57.577  54.898  1
561016  93.160  -57.576  54.880  1
561017  93.191  -57.576  54.864  1
561018  93.222  -57.575  54.850  1
561019  93.254  -57.574  54.837  1
561020  93.285  -57.573  54.822  1
561021  93.317  -57.573  54.811  1
561022  93.348  -57.572  54.802  1
561023  93.379  -57.571  54.793  1
561024  93.411  -57.570  54.787  1
561025  93.442  -57.570  54.778  1
561026  93.473  -57.569  54.762  1
561027  93.504  -57.568  54.742  1
561028  93.536  -57.568  54.720  1
561029  93.567  -57.567  54.700  1
561030  93.600  -57.570  54.684  1
561031  93.632  -57.572  54.673  1
561032  93.670  -57.589  54.670  1
561033  93.708  -57.608  54.673  1
561034  93.746  -57.628  54.677  1
561035  93.784  -57.648  54.678  1
561036  93.823  -57.667  54.681  1
561037  93.861  -57.687  54.680  1
561038  93.899  -57.707  54.676  1
561039  93.937  -57.727  54.671  1
561040  93.975  -57.746  54.666  1
561041  94.013  -57.766  54.660  1
561042  94.052  -57.786  54.653  1
561043  94.090  -57.805  54.641  1
561044  94.128  -57.825  54.627  1
561045  94.166  -57.845  54.608  1
561046  94.204  -57.864  54.586  1
561047  94.243  -57.883  54.562  1
561048  94.281  -57.903  54.535  1
561049  94.319  -57.923  54.507  1
561050  94.357  -57.943  54.479  1
561051  94.396  -57.963  54.450  1
561052  94.434  -57.983  54.423  1
561053  94.464  -57.997  54.396  1
561054  94.489  -58.009  54.371  1
561055  94.514  -58.021  54.348  1
561056  94.540  -58.034  54.325  1
561057  94.565  -58.046  54.302  1
561058  94.591  -58.058  54.274  1
561059  94.616  -58.070  54.243  1
561060  94.641  -58.082  54.211  1
561061  94.666  -58.094  54.179  1
561062  94.691  -58.106  54.143  1
561063  94.716  -58.118  54.102  1
561064  94.742  -58.131  54.056  1
561065  94.767  -58.143  54.004  1
561066  94.792  -58.155  53.952  1
561067  94.818  -58.166  53.900  1
561068  94.843  -58.178  53.848  1
561069  94.868  -58.191  53.797  1
561070  94.893  -58.203  53.747  1
561071  94.929  -58.214  53.693  1
561072  94.985  -58.223  53.643  1
561073  95.041  -58.232  53.595  1
561074  95.097  -58.242  53.549  1
561075  95.153  -58.251  53.506  1
561076  95.208  -58.260  53.469  1
561077  95.264  -58.269  53.434  1
561078  95.320  -58.279  53.397  1
561079  95.367  -58.283  53.361  1
561080  95.403  -58.282  53.327  1
561081  95.440  -58.281  53.297  1
561082  95.477  -58.281  53.268  1
561083  95.512  -58.281  53.241  1
561084  95.541  -58.282  53.214  1
561085  95.571  -58.284  53.191  1
561086  95.601  -58.285  53.175  1
561087  95.631  -58.291  53.168  1
561088  95.664  -58.304  53.161  1
561089  95.696  -58.318  53.151  1
561090  95.728  -58.332  53.141  1
561091  95.760  -58.345  53.131  1
561092  95.793  -58.359  53.121  1
561093  95.825  -58.372  53.118  1
561094  95.856  -58.382  53.097  1
561095  95.886  -58.388  53.078  1
561096  95.916  -58.394  53.059  1
561097  95.947  -58.401  53.040  1
561098  95.978  -58.410  53.024  1
561099  96.011  -58.421  52.995  1
561100  96.044  -58.432  52.968  1
561101  96.077  -58.443  52.947  1
561102  96.109  -58.454  52.924  1
561103  96.142  -58.465  52.892  1
561104  96.175  -58.476  52.865  1
561105  96.208  -58.487  52.833  1
561106  96.241  -58.498  52.805  1
561107  96.273  -58.509  52.782  1
561108  96.306  -58.520  52.760  1
561109  96.339  -58.531  52.734  1
561110  96.372  -58.542  52.700  1
561111  96.404  -58.549  52.675  1
561112  96.435  -58.548  52.648  1
561113  96.466  -58.545  52.612  1
561114  96.498  -58.544  52.572  1
561115  96.529  -58.542  52.538  1
561116  96.560  -58.540  52.499  1
561117  96.591  -58.538  52.463  1
561118  96.622  -58.537  52.425  1
561119  96.653  -58.535  52.386  1
561120  96.684  -58.533  52.345  1
561121  96.717  -58.538  52.304  1
561122  96.749  -58.544  52.262  1
561123  96.781  -58.550  52.217  1
561124  96.813  -58.556  52.172  1
561125  96.846  -58.562  52.128  1
561126  96.878  -58.568  52.083  1
561127  96.910  -58.574  52.040  1
561128  96.943  -58.580  52.002  1
561129  96.975  -58.586  51.966  1
561130  97.005  -58.590  51.929  1
561131  97.034  -58.592  51.891  1
561132  97.063  -58.595  51.851  1
561133  97.091  -58.598  51.809  1
561134  97.124  -58.603  51.769  1
561135  97.157  -58.607  51.729  1
561136  97.189  -58.611  51.691  1
561137  97.222  -58.615  51.654  1
561138  97.255  -58.620  51.618  1
561139  97.288  -58.623  51.575  1
561140  97.320  -58.628  51.529  1
561141  97.353  -58.632  51.483  1
561142  97.385  -58.636  51.437  1
561143  97.419  -58.639  51.392  1
561144  97.454  -58.639  51.346  1
561145  97.490  -58.639  51.303  1
561146  97.526  -58.639  51.261  1
561147  97.561  -58.641  51.218  1
561148  97.593  -58.647  51.174  1
561149  97.624  -58.653  51.131  1
561150  97.655  -58.659  51.088  1
561151  97.690  -58.661  51.046  1
561152  97.728  -58.662  51.003  1
561153  97.767  -58.665  50.960  1
561154  97.805  -58.667  50.917  1
561155  97.843  -58.670  50.876  1
561156  97.881  -58.673  50.836  1
561157  97.919  -58.676  50.798  1
561158  97.957  -58.678  50.761  1
561159  97.996  -58.676  50.724  1
561160  98.038  -58.664  50.688  1
561161  98.080  -58.653  50.652  1
561162  98.112  -58.654  50.620  1
561163  98.145  -58.655  50.586  1
561164  98.178  -58.656  50.553  1
561165  98.211  -58.657  50.519  1
561166  98.244  -58.657  50.485  1
561167  98.278  -58.658  50.452  1
561168  98.313  -58.659  50.420  1
561169  98.348  -58.661  50.388  1
561170  98.383  -58.661  50.355  1
561171  98.419  -58.662  50.323  1
561172  98.454  -58.663  50.292  1
561173  98.488  -58.664  50.261  1
561174  98.520  -58.665  50.232  1
561175  98.552  -58.666  50.204  1
561176  98.583  -58.667  50.179  1
561177  98.615  -58.667  50.156  1
561178  98.646  -58.667  50.135  1
561179  98.678  -58.668  50.116  1
561180  98.708  -58.667  50.099  1
561181  98.742  -58.657  50.082  1
561182  98.778  -58.641  50.066  1
561183  98.813  -58.624  50.053  1
561184  98.849  -58.607  50.039  1
561185  98.885  -58.591  50.024  1
561186  98.920  -58.574  50.009  1
561187  98.966  -58.569  49.992  1
561188  99.013  -58.565  49.975  1
561189  99.060  -58.561  49.957  1
561190  99.107  -58.557  49.938  1
561191  99.154  -58.554  49.917  1
561192  99.201  -58.550  49.894  1
561193  99.248  -58.546  49.870  1
561194  99.295  -58.542  49.844  1
561195  99.342  -58.538  49.817  1
561196  99.379  -58.545  49.787  1
561197  99.414  -58.553  49.760  1
561198  99.448  -58.562  49.733  1
561199  99.483  -58.570  49.708  1
561200  99.517  -58.579  49.683  1
561201  99.552  -58.588  49.657  1
561202  99.586  -58.597  49.632  1
561203  99.621  -58.606  49.606  1
561204  99.655  -58.614  49.579  1
561205  99.690  -58.623  49.551  1
561206  99.724  -58.632  49.521  1
561207  99.759  -58.641  49.491  1
561208  99.793  -58.649  49.460  1
561554  87.095  -55.094  57.622  4
561555  87.130  -55.110  57.620  4
561556  87.165  -55.126  57.616  4
561557  87.200  -55.141  57.609  4
561558  87.235  -55.158  57.604  4
561559  87.270  -55.174  57.599  4
561560  87.304  -55.190  57.593  4
561561  87.335  -55.207  57.587  4
561562  87.365  -55.225  57.580  4
561563  87.395  -55.242  57.572  4
561564  87.425  -55.259  57.564  4
561565  87.456  -55.276  57.557  4
561566  87.486  -55.293  57.548  4
561567  87.516  -55.311  57.539  4
561568  87.547  -55.328  57.532  4
561569  87.586  -55.336  57.522  4
561570  87.635  -55.333  57.507  4
561571  87.697  -55.344  57.482  4
561572  87.755  -55.358  57.451  4
561573  87.809  -55.373  57.417  4
561574  87.858  -55.390  57.387  4
561575  87.896  -55.407  57.354  4
561576  87.933  -55.423  57.319  4
561577  87.971  -55.440  57.281  4
561578  88.008  -55.457  57.242  4
561579  88.046  -55.473  57.201  4
561580  88.084  -55.489  57.158  4
561581  88.121  -55.506  57.112  4
561582  88.159  -55.523  57.066  4
561583  88.197  -55.539  57.019  4
561584  88.234  -55.556  56.973  4
561585  88.272  -55.573  56.929  4
561586  88.310  -55.589  56.885  4
561587  88.347  -55.606  56.842  4
561588  88.385  -55.622  56.799  4
561610  89.222  -55.978  56.038  1
561611  89.260  -55.994  56.017  1
561612  89.298  -56.010  55.996  1
561613  89.336  -56.027  55.977  1
561614  89.374  -56.043  55.960  1
561615  89.412  -56.059  55.944  1
561616  89.451  -56.075  55.929  1
561617  89.489  -56.091  55.916  1
561618  89.527  -56.107  55.904  1
561619  89.565  -56.122  55.895  1
561620  89.604  -56.138  55.887  1
561621  89.642  -56.154  55.881  1
561622  89.680  -56.170  55.876  1
561623  89.713  -56.189  55.874  1
561624  89.755  -56.200  55.874  1
561625  89.796  -56.211  55.876  1
561626  89.830  -56.225  55.880  1
561627  89.856  -56.242  55.885  1
561628  89.881  -56.259  55.893  1
561629  89.906  -56.276  55.903  1
561630  89.932  -56.293  55.918  1
561631  89.958  -56.310  55.936  1
561632  89.986  -56.329  55.959  1
561633  90.015  -56.347  55.984  1
561634  90.046  -56.363  56.008  1
561635  90.081  -56.375  56.027  1
561636  90.116  -56.388  56.037  1
561637  90.152  -56.400  56.038  1
561638  90.196  -56.410  56.026  1
561639  90.240  -56.420  56.007  1
561640  90.285  -56.431  55.987  1
561641  90.328  -56.442  55.955  1
561642  90.372  -56.454  55.916  1
561643  90.415  -56.467  55.876  1
561644  90.458  -56.479  55.835  1
561645  90.502  -56.492  55.793  1
561646  90.545  -56.504  55.755  1
561647  90.588  -56.516  55.719  1
561648  90.632  -56.528  55.687  1
561649  90.675  -56.540  55.657  1
561650  90.718  -56.552  55.628  1
561651  90.761  -56.565  55.600  1
561652  90.805  -56.577  55.574  1
561653  90.849  -56.589  55.551  1
561654  90.892  -56.602  55.532  1
561655  90.935  -56.614  55.515  1
561656  90.978  -56.626  55.500  1
561657  91.022  -56.638  55.485  1
561658  91.063  -56.652  55.473  1
561659  91.099  -56.669  55.464  1
561660  91.134  -56.686  55.454  1
561661  91.169  -56.703  55.441  1
561662  91.205  -56.721  55.426  1
561663  91.240  -56.738  55.410  1
561664  91.275  -56.755  55.393  1
561665  91.311  -56.773  55.377  1
561666  91.346  -56.790  55.363  1
561667  91.378  -56.802  55.350  1
561668  91.411  -56.815  55.340  1
561669  91.443  -56.827  55.331  1
561670  91.475  -56.839  55.324  1
561671  91.507  -56.851  55.319  1
561672  91.539  -56.864  55.316  1
561673  91.572  -56.876  55.316  1
561674  91.604  -56.888  55.319  1
561675  91.640  -56.899  55.327  1
561676  91.683  -56.909  55.331  1
561677  91.726  -56.918  55.336  1
561678  91.769  -56.928  55.345  1
561679  91.812  -56.938  55.361  1
561680  91.855  -56.947  55.383  1
561681  91.898  -56.957  55.398  1
561682  91.941  -56.967  55.403  1
561683  91.984  -56.976  55.404  1
561684  92.025  -56.996  55.408  1
561685  92.066  -57.019  55.417  1
561686  92.107  -57.043  55.424  1
561687  92.148  -57.066  55.426  1
561688  92.190  -57.090  55.423  1
561689  92.230  -57.113  55.415  1
561690  92.272  -57.137  55.402  1
561691  92.312  -57.160  55.388  1
561692  92.354  -57.183  55.381  1
561693  92.394  -57.206  55.371  1
561694  92.436  -57.230  55.359  1
561695  92.474  -57.256  55.345  1
561696  92.511  -57.282  55.329  1
561697  92.547  -57.309  55.311  1
561698  92.584  -57.336  55.294  1
561699  92.619  -57.357  55.277  1
561700  92.653  -57.379  55.259  1
561701  92.687  -57.400  55.240  1
561702  92.722  -57.421  55.222  1
561703  92.756  -57.439  55.206  1
561704  92.789  -57.451  55.185  1
561705  92.821  -57.462  55.160  1
561706  92.855  -57.473  55.132  1
561707  92.888  -57.484  55.102  1
561708  92.918  -57.493  55.073  1
561709  92.947  -57.500  55.048  1
561710  92.975  -57.507  55.022  1
561711  93.004  -57.514  54.996  1
561712  93.032  -57.521  54.973  1
561713  93.061  -57.528  54.953  1
561714  93.088  -57.535  54.934  1
561715  93.112  -57.541  54.912  1
561716  93.140  -57.543  54.892  1
561717  93.171  -57.542  54.874  1
561718  93.203  -57.542  54.857  1
561719  93.234  -57.541  54.841  1
561720  93.266  -57.540  54.827  1
561721  93.297  -57.540  54.812  1
561722  93.329  -57.539  54.798  1
561723  93.360  -57.539  54.788  1
561724  93.391  -57.538  54.778  1
561725  93.422  -57.537  54.769  1
561726  93.454  -57.537  54.760  1
561727  93.487  -57.539  54.745  1
561728  93.519  -57.542  54.727  1
561729  93.552  -57.544  54.706  1
561730  93.584  -57.547  54.685  1
561731  93.617  -57.549  54.669  1
561732  93.649  -57.551  54.655  1
561733  93.682  -57.554  54.646  1
561734  93.720  -57.573  54.645  1
561735  93.758  -57.592  54.648  1
561736  93.796  -57.612  54.651  1
561737  93.834  -57.632  54.654  1
561738  93.872  -57.651  54.656  1
561739  93.911  -57.671  54.653  1
561740  93.949  -57.691  54.649  1
561741  93.987  -57.711  54.645  1
561742  94.026  -57.730  54.644  1
561743  94.063  -57.750  54.639  1
561744  94.102  -57.770  54.635  1
561745  94.140  -57.789  54.625  1
561746  94.178  -57.809  54.610  1
561747  94.216  -57.828  54.591  1
561748  94.255  -57.848  54.569  1
561749  94.292  -57.868  54.544  1
561750  94.331  -57.887  54.517  1
561751  94.369  -57.907  54.490  1
561752  94.407  -57.927  54.463  1
561753  94.445  -57.950  54.437  1
561754  94.477  -57.963  54.413  1
561755  94.505  -57.974  54.388  1
561756  94.530  -57.986  54.363  1
561757  94.555  -57.998  54.340  1
561758  94.580  -58.010  54.317  1
561759  94.606  -58.022  54.291  1
561760  94.631  -58.034  54.261  1
561761  94.657  -58.046  54.229  1
561762  94.682  -58.059  54.197  1
561763  94.707  -58.071  54.161  1
561764  94.732  -58.083  54.120  1
561765  94.757  -58.095  54.076  1
561766  94.782  -58.107  54.026  1
561767  94.808  -58.119  53.974  1
561768  94.833  -58.131  53.920  1
561769  94.858  -58.143  53.867  1
561770  94.884  -58.155  53.814  1
561771  94.909  -58.167  53.761  1
561772  94.934  -58.179  53.707  1
561773  94.988  -58.189  53.654  1
561774  95.044  -58.198  53.603  1
561775  95.100  -58.207  53.554  1
561776  95.156  -58.216  53.509  1
561777  95.212  -58.226  53.466  1
561778  95.268  -58.235  53.423  1
561779  95.324  -58.244  53.381  1
561780  95.370  -58.248  53.342  1
561781  95.407  -58.247  53.307  1
561782  95.444  -58.247  53.275  1
561783  95.480  -58.247  53.247  1
561784  95.517  -58.246  53.219  1
561785  95.551  -58.246  53.191  1
561786  95.581  -58.247  53.166  1
561787  95.610  -58.249  53.149  1
561788  95.640  -58.250  53.140  1
561789  95.672  -58.263  53.128  1
561790  95.704  -58.277  53.121  1
561791  95.737  -58.291  53.115  1
561792  95.769  -58.303  53.108  1
561793  95.801  -58.317  53.094  1
561794  95.833  -58.331  53.087  1
561795  95.864  -58.338  53.077  1
561796  95.894  -58.344  53.063  1
561797  95.924  -58.350  53.046  1
561798  95.956  -58.359  53.027  1
561799  95.988  -58.370  53.013  1
561800  96.021  -58.381  52.987  1
561801  96.054  -58.392  52.965  1
561802  96.087  -58.403  52.946  1
561803  96.119  -58.414  52.922  1
561804  96.152  -58.425  52.888  1
561805  96.185  -58.435  52.860  1
561806  96.218  -58.447  52.832  1
561807  96.251  -58.457  52.805  1
561808  96.284  -58.469  52.782  1
561809  96.316  -58.479  52.761  1
561810  96.349  -58.491  52.736  1
561811  96.382  -58.501  52.704  1
561812  96.414  -58.513  52.677  1
561813  96.447  -58.517  52.650  1
561814  96.478  -58.516  52.618  1
561815  96.509  -58.514  52.579  1
561816  96.540  -58.512  52.539  1
561817  96.571  -58.510  52.499  1
561818  96.602  -58.509  52.462  1
561819  96.633  -58.507  52.423  1
561820  96.665  -58.505  52.383  1
561821  96.696  -58.504  52.345  1
561822  96.728  -58.508  52.304  1
561823  96.760  -58.514  52.262  1
561824  96.793  -58.520  52.217  1
561825  96.825  -58.526  52.173  1
561826  96.857  -58.532  52.129  1
561827  96.890  -58.538  52.086  1
561828  96.922  -58.545  52.044  1
561829  96.954  -58.551  52.006  1
561830  96.984  -58.554  51.967  1
561831  97.013  -58.557  51.930  1
561832  97.042  -58.560  51.894  1
561833  97.071  -58.563  51.856  1
561834  97.100  -58.567  51.818  1
561835  97.129  -58.570  51.782  1
561836  97.160  -58.573  51.748  1
561837  97.192  -58.577  51.714  1
561838  97.225  -58.581  51.678  1
561839  97.258  -58.585  51.642  1
561840  97.291  -58.590  51.601  1
561841  97.323  -58.594  51.557  1
561842  97.356  -58.598  51.510  1
561843  97.389  -58.601  51.462  1
561844  97.425  -58.601  51.413  1
561845  97.461  -58.601  51.361  1
561846  97.497  -58.601  51.313  1
561847  97.533  -58.601  51.268  1
561848  97.568  -58.603  51.224  1
561849  97.599  -58.608  51.181  1
561850  97.631  -58.614  51.138  1
561851  97.658  -58.624  51.095  1
561852  97.694  -58.626  51.051  1
561853  97.732  -58.626  51.007  1
561854  97.770  -58.626  50.963  1
561855  97.807  -58.626  50.920  1
561856  97.845  -58.627  50.877  1
561857  97.883  -58.630  50.839  1
561858  97.921  -58.632  50.800  1
561859  97.959  -58.636  50.762  1
561860  97.998  -58.638  50.725  1
561861  98.039  -58.628  50.688  1
561862  98.078  -58.620  50.654  1
561863  98.111  -58.621  50.621  1
561864  98.144  -58.622  50.587  1
561865  98.176  -58.623  50.553  1
561866  98.209  -58.624  50.519  1
561867  98.242  -58.625  50.486  1
561868  98.275  -58.626  50.455  1
561869  98.310  -58.626  50.421  1
561870  98.345  -58.627  50.390  1
561871  98.380  -58.628  50.359  1
561872  98.415  -58.629  50.327  1
561873  98.449  -58.630  50.293  1
561874  98.482  -58.632  50.258  1
561875  98.514  -58.632  50.227  1
561876  98.546  -58.633  50.198  1
561877  98.578  -58.634  50.172  1
561878  98.609  -58.635  50.148  1
561879  98.641  -58.635  50.126  1
561880  98.679  -58.634  50.107  1
561881  98.717  -58.632  50.090  1
561882  98.756  -58.620  50.073  1
561883  98.791  -58.601  50.057  1
561884  98.825  -58.582  50.042  1
561885  98.858  -58.563  50.027  1
561886  98.891  -58.545  50.012  1
561887  98.927  -58.529  49.995  1
561888  98.974  -58.526  49.979  1
561889  99.017  -58.525  49.963  1
561890  99.061  -58.524  49.945  1
561891  99.105  -58.523  49.926  1
561892  99.149  -58.523  49.907  1
561893  99.193  -58.523  49.886  1
561894  99.236  -58.522  49.863  1
561895  99.280  -58.521  49.838  1
561896  99.324  -58.513  49.813  1
561897  99.372  -58.516  49.784  1
561898  99.406  -58.526  49.756  1
561899  99.441  -58.534  49.730  1
561900  99.475  -58.543  49.705  1
561901  99.510  -58.551  49.681  1
561902  99.544  -58.560  49.655  1
561903  99.579  -58.569  49.631  1
561904  99.613  -58.578  49.606  1
561905  99.648  -58.587  49.579  1
561906  99.682  -58.595  49.552  1
561907  99.717  -58.604  49.523  1
561908  99.751  -58.613  49.493  1
562255  87.125  -55.044  57.620  4
562256  87.160  -55.060  57.618  4
562257  87.195  -55.075  57.615  4
562258  87.230  -55.092  57.610  4
562259  87.263  -55.108  57.605  4
562260  87.293  -55.126  57.600  4
562261  87.324  -55.143  57.595  4
562262  87.354  -55.160  57.589  4
562263  87.385  -55.177  57.582  4
562264  87.415  -55.195  57.575  4
562265  87.445  -55.211  57.566  4
562266  87.475  -55.229  57.559  4
562267  87.506  -55.246  57.551  4
562268  87.536  -55.263  57.543  4
562269  87.566  -55.280  57.537  4
562270  87.599  -55.295  57.528  4
562271  87.648  -55.293  57.514  4
562272  87.707  -55.301  57.494  4
562273  87.765  -55.315  57.467  4
562274  87.819  -55.331  57.436  4
562275  87.873  -55.347  57.407  4
562276  87.919  -55.364  57.375  4
562277  87.956  -55.380  57.342  4
562278  87.994  -55.397  57.307  4
562279  88.032  -55.414  57.269  4
562280  88.069  -55.430  57.229  4
562281  88.107  -55.446  57.186  4
562282  88.144  -55.463  57.141  4
562283  88.182  -55.480  57.094  4
562284  88.219  -55.496  57.048  4
562285  88.257  -55.513  57.001  4
562286  88.294  -55.530  56.956  4
562287  88.332  -55.546  56.912  4
562288  88.370  -55.563  56.868  4
562289  88.407  -55.579  56.825  4
562290  88.445  -55.596  56.783  4
562311  89.239  -55.940  56.039  1
562312  89.277  -55.956  56.018  1
562313  89.316  -55.972  55.996  1
562314  89.354  -55.988  55.977  1
562315  89.392  -56.004  55.958  1
562316  89.430  -56.020  55.942  1
562317  89.469  -56.036  55.926  1
562318  89.507  -56.052  55.911  1
562319  89.545  -56.068  55.900  1
562320  89.584  -56.084  55.891  1
562321  89.622  -56.100  55.882  1
562322  89.660  -56.116  55.875  1
562323  89.698  -56.132  55.870  1
562324  89.733  -56.150  55.866  1
562325  89.774  -56.160  55.866  1
562326  89.812  -56.173  55.867  1
562327  89.837  -56.190  55.869  1
562328  89.863  -56.207  55.873  1
562329  89.888  -56.224  55.879  1
562330  89.914  -56.241  55.887  1
562331  89.943  -56.260  55.900  1
562332  89.972  -56.278  55.913  1
562333  90.000  -56.297  55.929  1
562334  90.031  -56.312  55.946  1
562335  90.066  -56.325  55.965  1
562336  90.101  -56.338  55.981  1
562337  90.136  -56.350  55.992  1
562338  90.171  -56.363  55.994  1
562339  90.208  -56.374  55.985  1
562340  90.252  -56.385  55.970  1
562341  90.297  -56.395  55.955  1
562342  90.341  -56.406  55.928  1
562343  90.385  -56.417  55.894  1
562344  90.429  -56.427  55.859  1
562345  90.473  -56.439  55.822  1
562346  90.516  -56.451  55.784  1
562347  90.559  -56.463  55.749  1
562348  90.603  -56.475  55.717  1
562349  90.646  -56.487  55.688  1
562350  90.689  -56.500  55.661  1
562351  90.733  -56.512  55.635  1
562352  90.776  -56.524  55.609  1
562353  90.819  -56.536  55.585  1
562354  90.863  -56.548  55.563  1
562355  90.906  -56.561  55.544  1
562356  90.950  -56.573  55.528  1
562357  90.993  -56.585  55.515  1
562358  91.036  -56.597  55.502  1
562359  91.080  -56.610  55.495  1
562360  91.119  -56.624  55.488  1
562361  91.154  -56.642  55.480  1
562362  91.189  -56.659  55.469  1
562363  91.225  -56.677  55.454  1
562364  91.260  -56.693  55.433  1
562365  91.296  -56.711  55.412  1
562366  91.331  -56.728  55.393  1
562367  91.365  -56.744  55.377  1
562368  91.397  -56.756  55.362  1
562369  91.430  -56.768  55.351  1
562370  91.462  -56.781  55.340  1
562371  91.495  -56.793  55.332  1
562372  91.527  -56.805  55.326  1
562373  91.559  -56.818  55.324  1
562374  91.591  -56.830  55.326  1
562375  91.624  -56.842  55.331  1
562376  91.656  -56.855  55.342  1
562377  91.695  -56.865  55.351  1
562378  91.738  -56.874  55.359  1
562379  91.781  -56.884  55.367  1
562380  91.824  -56.894  55.377  1
562381  91.867  -56.903  55.397  1
562382  91.910  -56.913  55.412  1
562383  91.953  -56.923  55.419  1
562384  91.995  -56.938  55.423  1
562385  92.036  -56.962  55.425  1
562386  92.077  -56.985  55.428  1
562387  92.118  -57.009  55.426  1
562388  92.159  -57.031  55.425  1
562389  92.200  -57.055  55.422  1
562390  92.241  -57.078  55.417  1
562391  92.282  -57.102  55.409  1
562392  92.323  -57.125  55.398  1
562393  92.364  -57.149  55.389  1
562394  92.406  -57.172  55.380  1
562395  92.446  -57.196  55.369  1
562396  92.486  -57.221  55.355  1
562397  92.522  -57.247  55.340  1
562398  92.559  -57.274  55.321  1
562399  92.593  -57.297  55.300  1
562400  92.628  -57.318  55.281  1
562401  92.662  -57.338  55.262  1
562402  92.697  -57.360  55.243  1
562403  92.731  -57.381  55.224  1
562404  92.766  -57.402  55.208  1
562405  92.799  -57.418  55.189  1
562406  92.832  -57.429  55.166  1
562407  92.865  -57.440  55.142  1
562408  92.898  -57.451  55.117  1
562409  92.927  -57.458  55.091  1
562410  92.955  -57.466  55.065  1
562411  92.984  -57.473  55.038  1
562412  93.012  -57.479  55.012  1
562413  93.041  -57.487  54.987  1
562414  93.069  -57.494  54.965  1
562415  93.098  -57.501  54.941  1
562416  93.124  -57.507  54.919  1
562417  93.152  -57.510  54.899  1
562418  93.184  -57.509  54.879  1
562419  93.215  -57.508  54.859  1
562420  93.246  -57.507  54.840  1
562421  93.278  -57.507  54.823  1
562422  93.309  -57.506  54.805  1
562423  93.341  -57.507  54.790  1
562424  93.373  -57.509  54.777  1
562425  93.406  -57.511  54.767  1
562426  93.438  -57.514  54.755  1
562427  93.471  -57.517  54.745  1
562428  93.503  -57.519  54.731  1
562429  93.536  -57.521  54.714  1
562430  93.568  -57.523  54.694  1
562431  93.601  -57.526  54.674  1
562432  93.633  -57.529  54.658  1
562433  93.666  -57.531  54.644  1
562434  93.699  -57.533  54.631  1
562435  93.731  -57.537  54.624  1
562436  93.770  -57.557  54.623  1
562437  93.808  -57.576  54.625  1
562438  93.846  -57.596  54.628  1
562439  93.885  -57.616  54.632  1
562440  93.922  -57.636  54.631  1
562441  93.961  -57.655  54.627  1
562442  93.999  -57.675  54.626  1
562443  94.037  -57.695  54.625  1
562444  94.075  -57.714  54.624  1
562445  94.114  -57.734  54.621  1
562446  94.152  -57.754  54.614  1
562447  94.190  -57.774  54.603  1
562448  94.228  -57.793  54.586  1
562449  94.266  -57.812  54.566  1
562450  94.305  -57.832  54.543  1
562451  94.342  -57.852  54.519  1
562452  94.380  -57.875  54.493  1
562453  94.417  -57.899  54.468  1
562454  94.452  -57.916  54.444  1
562455  94.484  -57.928  54.421  1
562456  94.516  -57.940  54.397  1
562457  94.546  -57.950  54.373  1
562458  94.571  -57.962  54.349  1
562459  94.596  -57.974  54.327  1
562460  94.621  -57.987  54.303  1
562461  94.647  -57.999  54.276  1
562462  94.672  -58.011  54.245  1
562463  94.697  -58.023  54.213  1
562464  94.722  -58.035  54.177  1
562465  94.748  -58.047  54.137  1
562466  94.773  -58.059  54.095  1
562467  94.798  -58.071  54.047  1
562468  94.824  -58.084  53.996  1
562469  94.849  -58.096  53.943  1
562470  94.874  -58.108  53.889  1
562471  94.899  -58.120  53.835  1
562472  94.924  -58.131  53.780  1
562473  94.950  -58.144  53.724  1
562474  94.992  -58.154  53.669  1
562475  95.048  -58.163  53.615  1
562476  95.104  -58.173  53.564  1
562477  95.160  -58.182  53.517  1
562478  95.216  -58.191  53.469  1
562479  95.272  -58.200  53.421  1
562480  95.328  -58.210  53.375  1
562481  95.374  -58.214  53.332  1
562482  95.410  -58.213  53.292  1
562483  95.447  -58.212  53.257  1
562484  95.484  -58.212  53.226  1
562485  95.521  -58.211  53.196  1
562486  95.558  -58.210  53.168  1
562487  95.590  -58.211  53.141  1
562488  95.620  -58.212  53.122  1
562489  95.650  -58.214  53.114  1
562490  95.681  -58.222  53.104  1
562491  95.713  -58.235  53.098  1
562492  95.745  -58.249  53.089  1
562493  95.777  -58.263  53.075  1
562494  95.810  -58.276  53.060  1
562495  95.841  -58.287  53.051  1
562496  95.872  -58.294  53.042  1
562497  95.902  -58.300  53.033  1
562498  95.933  -58.308  53.022  1
562499  95.966  -58.319  53.010  1
562500  95.999  -58.330  52.995  1
562501  96.031  -58.341  52.973  1
562502  96.064  -58.352  52.953  1
562503  96.097  -58.363  52.933  1
562504  96.129  -58.374  52.912  1
562505  96.162  -58.385  52.886  1
562506  96.195  -58.395  52.857  1
562507  96.228  -58.407  52.833  1
562508  96.261  -58.417  52.807  1
562509  96.294  -58.429  52.782  1
562510  96.326  -58.439  52.759  1
562511  96.359  -58.451  52.734  1
562512  96.392  -58.461  52.705  1
562513  96.425  -58.473  52.677  1
562514  96.457  -58.483  52.650  1
562515  96.489  -58.486  52.621  1
562516  96.520  -58.485  52.586  1
562517  96.551  -58.482  52.541  1
562518  96.583  -58.481  52.501  1
562519  96.614  -58.479  52.463  1
562520  96.645  -58.477  52.422  1
562521  96.676  -58.476  52.381  1
562522  96.707  -58.474  52.343  1
562523  96.739  -58.479  52.302  1
562524  96.771  -58.485  52.260  1
562525  96.804  -58.491  52.217  1
562526  96.836  -58.497  52.174  1
562527  96.869  -58.503  52.131  1
562528  96.901  -58.509  52.090  1
562529  96.934  -58.515  52.050  1
562530  96.964  -58.520  52.013  1
562531  96.993  -58.523  51.974  1
562532  97.022  -58.526  51.937  1
562533  97.050  -58.529  51.903  1
562534  97.079  -58.532  51.868  1
562535  97.108  -58.534  51.834  1
562536  97.137  -58.537  51.801  1
562537  97.166  -58.540  51.770  1
562538  97.195  -58.543  51.739  1
562539  97.228  -58.548  51.705  1
562540  97.261  -58.551  51.668  1
562541  97.294  -58.556  51.628  1
562542  97.326  -58.560  51.584  1
562543  97.360  -58.563  51.537  1
562544  97.396  -58.563  51.487  1
562545  97.432  -58.563  51.434  1
562546  97.468  -58.563  51.378  1
562547  97.504  -58.563  51.327  1
562548  97.540  -58.562  51.280  1
562549  97.574  -58.564  51.235  1
562550  97.605  -58.570  51.191  1
562551  97.634  -58.579  51.146  1
562552  97.662  -58.589  51.102  1
562553  97.698  -58.590  51.057  1
562554  97.735  -58.590  51.013  1
562555  97.773  -58.590  50.970  1
562556  97.811  -58.590  50.928  1
562557  97.849  -58.589  50.887  1
562558  97.886  -58.589  50.846  1
562559  97.924  -58.590  50.806  1
562560  97.962  -58.592  50.768  1
562561  98.000  -58.595  50.731  1
562562  98.040  -58.592  50.694  1
562563  98.077  -58.587  50.659  1
562564  98.109  -58.588  50.624  1
562565  98.142  -58.589  50.590  1
562566  98.175  -58.590  50.556  1
562567  98.208  -58.591  50.524  1
562568  98.240  -58.592  50.493  1
562569  98.273  -58.592  50.464  1
562570  98.306  -58.594  50.433  1
562571  98.342  -58.595  50.401  1
562572  98.377  -58.595  50.369  1
562573  98.411  -58.596  50.334  1
562574  98.444  -58.598  50.297  1
562575  98.477  -58.599  50.261  1
562576  98.509  -58.600  50.227  1
562577  98.540  -58.601  50.195  1
562578  98.578  -58.599  50.167  1
562579  98.616  -58.598  50.143  1
562580  98.654  -58.597  50.120  1
562581  98.692  -58.595  50.101  1
562582  98.729  -58.594  50.084  1
562583  98.768  -58.587  50.067  1
562584  98.807  -58.570  50.051  1
562585  98.846  -58.551  50.036  1
562586  98.881  -58.533  50.022  1
562587  98.914  -58.514  50.007  1
562588  98.932  -58.505  49.990  1
562589  98.955  -58.507  49.973  1
562590  98.999  -58.507  49.955  1
562591  99.043  -58.506  49.936  1
562592  99.087  -58.505  49.916  1
562593  99.131  -58.504  49.895  1
562594  99.174  -58.504  49.875  1
562595  99.218  -58.503  49.852  1
562596  99.262  -58.502  49.829  1
562597  99.305  -58.479  49.804  1
562598  99.362  -58.489  49.779  1
562599  99.399  -58.498  49.753  1
562600  99.433  -58.507  49.727  1
562601  99.468  -58.515  49.701  1
562602  99.502  -58.524  49.677  1
562603  99.537  -58.532  49.653  1
562604  99.571  -58.542  49.629  1
562605  99.606  -58.550  49.604  1
562606  99.640  -58.559  49.578  1
562607  99.675  -58.567  49.551  1
562608  99.709  -58.576  49.523  1
562609  99.744  -58.585  49.493  1
562957  87.190  -55.010  57.616  4
562958  87.222  -55.026  57.614  4
562959  87.253  -55.044  57.610  4
562960  87.283  -55.060  57.605  4
562961  87.314  -55.078  57.600  4
562962  87.344  -55.095  57.595  4
562963  87.374  -55.112  57.590  4
562964  87.404  -55.129  57.584  4
562965  87.434  -55.147  57.576  4
562966  87.465  -55.163  57.568  4
562967  87.495  -55.181  57.561  4
562968  87.526  -55.198  57.553  4
562969  87.556  -55.215  57.546  4
562970  87.586  -55.232  57.541  4
562971  87.616  -55.250  57.532  4
562972  87.660  -55.253  57.521  4
562973  87.718  -55.258  57.504  4
562974  87.775  -55.272  57.480  4
562975  87.830  -55.288  57.451  4
562976  87.884  -55.304  57.423  4
562977  87.938  -55.320  57.394  4
562978  87.979  -55.337  57.363  4
562979  88.016  -55.354  57.330  4
562980  88.054  -55.370  57.295  4
562981  88.092  -55.387  57.255  4
562982  88.129  -55.403  57.214  4
562983  88.167  -55.420  57.169  4
562984  88.204  -55.436  57.123  4
562985  88.242  -55.453  57.077  4
562986  88.280  -55.470  57.031  4
562987  88.317  -55.486  56.984  4
562988  88.355  -55.503  56.940  4
562989  88.393  -55.520  56.895  4
562990  88.430  -55.536  56.851  4
562991  88.468  -55.552  56.808  4
562992  88.505  -55.569  56.766  4
563013  89.295  -55.918  56.017  1
563014  89.333  -55.934  55.996  1
563015  89.372  -55.950  55.976  1
563016  89.410  -55.965  55.957  1
563017  89.448  -55.981  55.939  1
563018  89.486  -55.997  55.923  1
563019  89.525  -56.013  55.908  1
563020  89.563  -56.029  55.895  1
563021  89.601  -56.045  55.885  1
563022  89.639  -56.061  55.876  1
563023  89.678  -56.078  55.869  1
563024  89.716  -56.094  55.863  1
563025  89.752  -56.110  55.858  1
563026  89.793  -56.121  55.858  1
563027  89.819  -56.138  55.858  1
563028  89.844  -56.155  55.859  1
563029  89.872  -56.173  55.861  1
563030  89.900  -56.191  55.865  1
563031  89.929  -56.210  55.871  1
563032  89.957  -56.228  55.881  1
563033  89.986  -56.246  55.891  1
563034  90.017  -56.262  55.901  1
563035  90.051  -56.275  55.914  1
563036  90.086  -56.287  55.927  1
563037  90.121  -56.300  55.938  1
563038  90.156  -56.312  55.949  1
563039  90.191  -56.325  55.952  1
563040  90.226  -56.337  55.946  1
563041  90.264  -56.349  55.934  1
563042  90.309  -56.360  55.921  1
563043  90.353  -56.370  55.896  1
563044  90.397  -56.380  55.867  1
563045  90.441  -56.391  55.836  1
563046  90.485  -56.401  55.806  1
563047  90.530  -56.412  55.774  1
563048  90.574  -56.423  55.744  1
563049  90.617  -56.435  55.716  1
563050  90.661  -56.447  55.690  1
563051  90.704  -56.459  55.665  1
563052  90.747  -56.471  55.641  1
563053  90.791  -56.483  55.618  1
563054  90.834  -56.495  55.596  1
563055  90.877  -56.508  55.575  1
563056  90.921  -56.520  55.557  1
563057  90.964  -56.533  55.542  1
563058  91.008  -56.545  55.530  1
563059  91.051  -56.557  55.518  1
563060  91.094  -56.569  55.514  1
563061  91.138  -56.581  55.508  1
563062  91.174  -56.597  55.502  1
563063  91.210  -56.614  55.493  1
563064  91.245  -56.632  55.479  1
563065  91.281  -56.649  55.458  1
563066  91.316  -56.667  55.435  1
563067  91.351  -56.683  55.412  1
563068  91.385  -56.698  55.392  1
563069  91.417  -56.711  55.376  1
563070  91.449  -56.723  55.361  1
563071  91.482  -56.735  55.350  1
563072  91.514  -56.747  55.341  1
563073  91.546  -56.759  55.335  1
563074  91.578  -56.772  55.334  1
563075  91.610  -56.784  55.338  1
563076  91.643  -56.796  55.346  1
563077  91.675  -56.809  55.359  1
563078  91.707  -56.821  55.372  1
563079  91.750  -56.830  55.380  1
563080  91.793  -56.840  55.385  1
563081  91.836  -56.849  55.389  1
563082  91.879  -56.859  55.403  1
563083  91.922  -56.869  55.415  1
563084  91.964  -56.880  55.425  1
563085  92.006  -56.903  55.432  1
563086  92.047  -56.927  55.437  1
563087  92.088  -56.950  55.439  1
563088  92.129  -56.974  55.433  1
563089  92.170  -56.997  55.424  1
563090  92.211  -57.021  55.413  1
563091  92.252  -57.044  55.400  1
563092  92.293  -57.068  55.389  1
563093  92.334  -57.091  55.384  1
563094  92.375  -57.114  55.380  1
563095  92.416  -57.138  55.376  1
563096  92.457  -57.161  55.368  1
563097  92.497  -57.185  55.356  1
563098  92.533  -57.213  55.343  1
563099  92.569  -57.235  55.329  1
563100  92.603  -57.257  55.313  1
563101  92.637  -57.278  55.295  1
563102  92.672  -57.299  55.274  1
563103  92.706  -57.320  55.252  1
563104  92.740  -57.341  55.229  1
563105  92.775  -57.362  55.212  1
563106  92.809  -57.383  55.194  1
563107  92.843  -57.396  55.176  1
563108  92.876  -57.407  55.157  1
563109  92.908  -57.417  55.139  1
563110  92.936  -57.424  55.118  1
563111  92.965  -57.431  55.092  1
563112  92.993  -57.438  55.066  1
563113  93.021  -57.445  55.039  1
563114  93.050  -57.452  55.013  1
563115  93.078  -57.460  54.989  1
563116  93.107  -57.467  54.966  1
563117  93.135  -57.473  54.942  1
563118  93.164  -57.476  54.920  1
563119  93.196  -57.475  54.898  1
563120  93.227  -57.476  54.877  1
563121  93.260  -57.479  54.856  1
563122  93.293  -57.481  54.837  1
563123  93.325  -57.484  54.819  1
563124  93.358  -57.486  54.802  1
563125  93.390  -57.489  54.786  1
563126  93.423  -57.491  54.772  1
563127  93.455  -57.493  54.757  1
563128  93.488  -57.496  54.742  1
563129  93.520  -57.498  54.725  1
563130  93.553  -57.501  54.707  1
563131  93.585  -57.503  54.688  1
563132  93.618  -57.505  54.671  1
563133  93.650  -57.508  54.654  1
563134  93.683  -57.510  54.641  1
563135  93.715  -57.513  54.625  1
563136  93.748  -57.515  54.610  1
563137  93.782  -57.521  54.601  1
563138  93.820  -57.541  54.602  1
563139  93.858  -57.561  54.605  1
563140  93.896  -57.580  54.609  1
563141  93.934  -57.600  54.608  1
563142  93.973  -57.620  54.607  1
563143  94.011  -57.639  54.606  1
563144  94.049  -57.659  54.607  1
563145  94.087  -57.679  54.609  1
563146  94.125  -57.699  54.608  1
563147  94.164  -57.718  54.603  1
563148  94.202  -57.738  54.594  1
563149  94.240  -57.757  54.579  1
563150  94.278  -57.777  54.559  1
563151  94.315  -57.800  54.538  1
563152  94.352  -57.823  54.515  1
563153  94.390  -57.846  54.491  1
563154  94.427  -57.869  54.467  1
563155  94.460  -57.882  54.443  1
563156  94.492  -57.894  54.420  1
563157  94.525  -57.906  54.396  1
563158  94.555  -57.918  54.374  1
563159  94.585  -57.927  54.351  1
563160  94.612  -57.939  54.328  1
563161  94.637  -57.951  54.306  1
563162  94.663  -57.963  54.281  1
563163  94.688  -57.975  54.254  1
563164  94.713  -57.987  54.224  1
563165  94.738  -57.999  54.190  1
563166  94.763  -58.012  54.153  1
563167  94.788  -58.024  54.112  1
563168  94.814  -58.036  54.065  1
563169  94.839  -58.048  54.017  1
563170  94.864  -58.060  53.967  1
563171  94.890  -58.072  53.915  1
563172  94.915  -58.084  53.860  1
563173  94.940  -58.096  53.804  1
563174  94.965  -58.109  53.746  1
563175  94.996  -58.120  53.689  1
563176  95.052  -58.129  53.633  1
563177  95.108  -58.138  53.579  1
563178  95.164  -58.147  53.530  1
563179  95.219  -58.157  53.478  1
563180  95.275  -58.166  53.425  1
563181  95.331  -58.175  53.375  1
563182  95.377  -58.179  53.328  1
563183  95.414  -58.178  53.282  1
563184  95.451  -58.178  53.242  1
563185  95.487  -58.177  53.207  1
563186  95.525  -58.176  53.175  1
563187  95.561  -58.175  53.145  1
563188  95.598  -58.175  53.118  1
563189  95.630  -58.176  53.095  1
563190  95.660  -58.178  53.085  1
563191  95.689  -58.181  53.078  1
563192  95.722  -58.194  53.071  1
563193  95.754  -58.208  53.059  1
563194  95.787  -58.222  53.041  1
563195  95.819  -58.235  53.025  1
563196  95.849  -58.243  53.015  1
563197  95.880  -58.250  53.006  1
563198  95.910  -58.256  52.999  1
563199  95.943  -58.268  52.992  1
563200  95.976  -58.278  52.984  1
563201  96.009  -58.290  52.970  1
563202  96.041  -58.300  52.956  1
563203  96.074  -58.312  52.937  1
563204  96.107  -58.322  52.915  1
563205  96.139  -58.334  52.893  1
563206  96.172  -58.344  52.873  1
563207  96.205  -58.356  52.843  1
563208  96.238  -58.366  52.820  1
563209  96.271  -58.377  52.793  1
563210  96.304  -58.388  52.768  1
563211  96.336  -58.399  52.746  1
563212  96.369  -58.410  52.722  1
563213  96.402  -58.421  52.698  1
563214  96.435  -58.432  52.672  1
563215  96.467  -58.443  52.644  1
563216  96.500  -58.454  52.616  1
563217  96.532  -58.454  52.584  1
563218  96.563  -58.453  52.541  1
563219  96.594  -58.451  52.505  1
563220  96.625  -58.449  52.464  1
563221  96.656  -58.448  52.423  1
563222  96.687  -58.446  52.383  1
563223  96.719  -58.444  52.342  1
563224  96.751  -58.450  52.299  1
563225  96.783  -58.456  52.258  1
563226  96.815  -58.462  52.218  1
563227  96.848  -58.468  52.179  1
563228  96.880  -58.474  52.141  1
563229  96.912  -58.480  52.103  1
563230  96.944  -58.485  52.063  1
563231  96.972  -58.488  52.028  1
563232  97.001  -58.491  51.994  1
563233  97.030  -58.494  51.958  1
563234  97.059  -58.496  51.924  1
563235  97.088  -58.499  51.892  1
563236  97.117  -58.502  51.859  1
563237  97.146  -58.505  51.828  1
563238  97.174  -58.508  51.798  1
563239  97.203  -58.510  51.768  1
563240  97.232  -58.513  51.735  1
563241  97.264  -58.518  51.696  1
563242  97.297  -58.522  51.656  1
563243  97.330  -58.525  51.613  1
563244  97.367  -58.525  51.565  1
563245  97.402  -58.525  51.512  1
563246  97.439  -58.524  51.454  1
563247  97.474  -58.524  51.396  1
563248  97.511  -58.524  51.345  1
563249  97.546  -58.524  51.295  1
563250  97.580  -58.526  51.249  1
563251  97.610  -58.534  51.203  1
563252  97.638  -58.544  51.156  1
563253  97.665  -58.554  51.109  1
563254  97.702  -58.554  51.065  1
563255  97.739  -58.554  51.022  1
563256  97.777  -58.554  50.980  1
563257  97.814  -58.554  50.939  1
563258  97.852  -58.554  50.900  1
563259  97.890  -58.554  50.856  1
563260  97.928  -58.554  50.815  1
563261  97.965  -58.554  50.777  1
563262  98.003  -58.554  50.740  1
563263  98.040  -58.555  50.703  1
563264  98.075  -58.554  50.666  1
563265  98.108  -58.555  50.630  1
563266  98.141  -58.556  50.595  1
563267  98.173  -58.557  50.562  1
563268  98.206  -58.557  50.532  1
563269  98.239  -58.559  50.501  1
563270  98.272  -58.560  50.474  1
563271  98.304  -58.560  50.444  1
563272  98.339  -58.561  50.412  1
563273  98.372  -58.563  50.378  1
563274  98.406  -58.563  50.342  1
563275  98.439  -58.565  50.302  1
563276  98.473  -58.564  50.266  1
563277  98.515  -58.563  50.229  1
563278  98.553  -58.563  50.195  1
563279  98.590  -58.561  50.165  1
563280  98.629  -58.560  50.139  1
563281  98.666  -58.558  50.115  1
563282  98.704  -58.557  50.096  1
563283  98.742  -58.556  50.079  1
563284  98.780  -58.554  50.063  1
563285  98.819  -58.536  50.048  1
563286  98.858  -58.519  50.033  1
563287  98.897  -58.501  50.019  1
563288  98.936  -58.483  50.004  1
563289  98.942  -58.483  49.988  1
563290  98.939  -58.488  49.970  1
563291  98.981  -58.488  49.950  1
563292  99.025  -58.488  49.930  1
563293  99.069  -58.487  49.909  1
563294  99.113  -58.486  49.887  1
563295  99.156  -58.485  49.865  1
563296  99.200  -58.485  49.842  1
563297  99.244  -58.480  49.819  1
563298  99.286  -58.443  49.796  1
563299  99.341  -58.460  49.774  1
563300  99.391  -58.469  49.748  1
563301  99.426  -58.479  49.723  1
563302  99.460  -58.488  49.698  1
563303  99.495  -58.496  49.674  1
563304  99.529  -58.505  49.650  1
563305  99.564  -58.513  49.626  1
563306  99.598  -58.523  49.601  1
563307  99.633  -58.531  49.576  1
563308  99.667  -58.540  49.549  1
563309  99.702  -58.548  49.522  1
563310  99.736  -58.557  49.493  1
563659  87.242  -54.978  57.612  4
563660  87.273  -54.996  57.609  4
563661  87.303  -55.013  57.604  4
563662  87.333  -55.030  57.600  4
563663  87.363  -55.047  57.595  4
563664  87.394  -55.065  57.591  4
563665  87.424  -55.082  57.586  4
563666  87.454  -55.099  57.578  4
563667  87.485  -55.116  57.571  4
563668  87.515  -55.133  57.564  4
563669  87.545  -55.151  57.557  4
563670  87.575  -55.168  57.550  4
563671  87.606  -55.185  57.544  4
563672  87.636  -55.202  57.537  4
563673  87.673  -55.213  57.527  4
563674  87.728  -55.215  57.512  4
563675  87.785  -55.229  57.491  4
563676  87.840  -55.245  57.464  4
563677  87.894  -55.261  57.439  4
563678  87.948  -55.278  57.412  4
563679  88.002  -55.294  57.383  4
563680  88.039  -55.311  57.353  4
563681  88.077  -55.327  57.320  4
563682  88.115  -55.344  57.282  4
563683  88.152  -55.360  57.242  4
563684  88.190  -55.376  57.198  4
563685  88.227  -55.393  57.152  4
563686  88.265  -55.410  57.106  4
563687  88.303  -55.426  57.060  4
563688  88.340  -55.443  57.013  4
563689  88.378  -55.460  56.968  4
563690  88.415  -55.477  56.923  4
563691  88.453  -55.493  56.878  4
563692  88.490  -55.509  56.834  4
563693  88.528  -55.526  56.791  4
563694  88.566  -55.542  56.750  4
563714  89.318  -55.875  56.017  1
563715  89.355  -55.891  55.995  1
563716  89.393  -55.908  55.974  1
563717  89.430  -55.925  55.955  1
563718  89.468  -55.941  55.936  1
563719  89.506  -55.957  55.919  1
563720  89.543  -55.974  55.903  1
563721  89.581  -55.991  55.890  1
563722  89.619  -56.007  55.879  1
563723  89.657  -56.023  55.869  1
563724  89.695  -56.039  55.862  1
563725  89.734  -56.055  55.856  1
563726  89.772  -56.070  55.851  1
563727  89.801  -56.086  55.849  1
563728  89.829  -56.104  55.848  1
563729  89.858  -56.122  55.848  1
563730  89.886  -56.141  55.849  1
563731  89.914  -56.159  55.850  1
563732  89.943  -56.177  55.855  1
563733  89.971  -56.196  55.862  1
563734  90.002  -56.212  55.869  1
563735  90.037  -56.225  55.876  1
563736  90.072  -56.237  55.884  1
563737  90.106  -56.250  55.893  1
563738  90.142  -56.262  55.900  1
563739  90.176  -56.275  55.908  1
563740  90.211  -56.287  55.911  1
563741  90.246  -56.300  55.907  1
563742  90.281  -56.312  55.898  1
563743  90.321  -56.323  55.886  1
563744  90.365  -56.334  55.864  1
563745  90.409  -56.345  55.841  1
563746  90.453  -56.355  55.817  1
563747  90.498  -56.366  55.792  1
563748  90.542  -56.376  55.766  1
563749  90.586  -56.387  55.740  1
563750  90.630  -56.397  55.716  1
563751  90.674  -56.407  55.692  1
563752  90.719  -56.418  55.670  1
563753  90.762  -56.430  55.648  1
563754  90.805  -56.442  55.627  1
563755  90.849  -56.454  55.607  1
563756  90.892  -56.467  55.587  1
563757  90.935  -56.479  55.571  1
563758  90.978  -56.492  55.557  1
563759  91.022  -56.504  55.546  1
563760  91.065  -56.516  55.535  1
563761  91.109  -56.528  55.531  1
563762  91.152  -56.540  55.527  1
563763  91.195  -56.553  55.521  1
563764  91.230  -56.570  55.513  1
563765  91.265  -56.587  55.500  1
563766  91.301  -56.605  55.480  1
563767  91.336  -56.622  55.456  1
563768  91.372  -56.639  55.431  1
563769  91.404  -56.652  55.408  1
563770  91.436  -56.664  55.389  1
563771  91.469  -56.677  55.374  1
563772  91.501  -56.689  55.361  1
563773  91.533  -56.702  55.350  1
563774  91.566  -56.714  55.344  1
563775  91.598  -56.726  55.343  1
563776  91.630  -56.738  55.349  1
563777  91.662  -56.750  55.360  1
563778  91.695  -56.763  55.373  1
563779  91.727  -56.775  55.385  1
563780  91.762  -56.787  55.392  1
563781  91.805  -56.796  55.392  1
563782  91.848  -56.805  55.392  1
563783  91.891  -56.815  55.400  1
563784  91.934  -56.825  55.410  1
563785  91.975  -56.846  55.423  1
563786  92.016  -56.869  55.435  1
563787  92.057  -56.893  55.444  1
563788  92.098  -56.916  55.445  1
563789  92.139  -56.940  55.435  1
563790  92.180  -56.962  55.420  1
563791  92.221  -56.986  55.400  1
563792  92.263  -57.009  55.382  1
563793  92.303  -57.033  55.374  1
563794  92.345  -57.056  55.372  1
563795  92.385  -57.080  55.370  1
563796  92.427  -57.103  55.368  1
563797  92.467  -57.127  55.365  1
563798  92.508  -57.150  55.359  1
563799  92.544  -57.174  55.352  1
563800  92.578  -57.195  55.341  1
563801  92.613  -57.216  55.324  1
563802  92.647  -57.238  55.305  1
563803  92.682  -57.259  55.286  1
563804  92.716  -57.280  55.268  1
563805  92.750  -57.301  55.248  1
563806  92.785  -57.322  55.230  1
563807  92.819  -57.344  55.215  1
563808  92.853  -57.363  55.203  1
563809  92.886  -57.374  55.190  1
563810  92.916  -57.382  55.175  1
563811  92.945  -57.390  55.157  1
563812  92.973  -57.397  55.133  1
563813  93.002  -57.404  55.106  1
563814  93.030  -57.411  55.077  1
563815  93.059  -57.418  55.048  1
563816  93.087  -57.425  55.020  1
563817  93.116  -57.432  54.996  1
563818  93.145  -57.438  54.970  1
563819  93.177  -57.448  54.944  1
563820  93.210  -57.451  54.919  1
563821  93.244  -57.455  54.897  1
563822  93.277  -57.458  54.875  1
563823  93.309  -57.460  54.857  1
563824  93.342  -57.464  54.839  1
563825  93.374  -57.466  54.822  1
563826  93.407  -57.468  54.806  1
563827  93.439  -57.470  54.791  1
563828  93.472  -57.473  54.774  1
563829  93.504  -57.476  54.757  1
563830  93.537  -57.478  54.738  1
563831  93.570  -57.480  54.720  1
563832  93.602  -57.482  54.701  1
563833  93.635  -57.485  54.681  1
563834  93.667  -57.488  54.660  1
563835  93.700  -57.490  54.642  1
563836  93.732  -57.492  54.624  1
563837  93.765  -57.495  54.606  1
563838  93.797  -57.497  54.591  1
563839  93.832  -57.505  54.579  1
563840  93.870  -57.525  54.582  1
563841  93.908  -57.545  54.585  1
563842  93.946  -57.564  54.587  1
563843  93.984  -57.584  54.586  1
563844  94.023  -57.604  54.586  1
563845  94.061  -57.623  54.591  1
563846  94.099  -57.643  54.596  1
563847  94.137  -57.663  54.598  1
563848  94.176  -57.683  54.594  1
563849  94.213  -57.702  54.583  1
563850  94.251  -57.725  54.568  1
563851  94.288  -57.748  54.549  1
563852  94.325  -57.771  54.530  1
563853  94.363  -57.794  54.509  1
563854  94.400  -57.817  54.486  1
563855  94.435  -57.835  54.463  1
563856  94.467  -57.847  54.438  1
563857  94.500  -57.859  54.416  1
563858  94.532  -57.872  54.392  1
563859  94.564  -57.884  54.371  1
563860  94.595  -57.895  54.350  1
563861  94.625  -57.905  54.327  1
563862  94.652  -57.915  54.307  1
563863  94.678  -57.927  54.284  1
563864  94.703  -57.940  54.259  1
563865  94.729  -57.952  54.230  1
563866  94.754  -57.964  54.198  1
563867  94.779  -57.976  54.164  1
563868  94.804  -57.988  54.124  1
563869  94.829  -58.000  54.080  1
563870  94.854  -58.012  54.034  1
563871  94.880  -58.024  53.986  1
563872  94.905  -58.037  53.936  1
563873  94.930  -58.049  53.882  1
563874  94.956  -58.061  53.826  1
563875  94.981  -58.073  53.770  1
563876  95.006  -58.085  53.715  1
563877  95.055  -58.095  53.660  1
563878  95.111  -58.104  53.604  1
563879  95.168  -58.113  53.548  1
563880  95.224  -58.122  53.491  1
563881  95.279  -58.131  53.438  1
563882  95.335  -58.141  53.385  1
563883  95.381  -58.145  53.333  1
563884  95.417  -58.144  53.282  1
563885  95.454  -58.144  53.236  1
563886  95.491  -58.143  53.194  1
563887  95.528  -58.142  53.158  1
563888  95.565  -58.141  53.126  1
563889  95.602  -58.140  53.097  1
563890  95.638  -58.140  53.070  1
563891  95.669  -58.141  53.053  1
563892  95.699  -58.143  53.047  1
563893  95.731  -58.153  53.038  1
563894  95.763  -58.166  53.025  1
563895  95.795  -58.180  53.008  1
563896  95.827  -58.193  52.990  1
563897  95.857  -58.199  52.980  1
563898  95.888  -58.206  52.969  1
563899  95.920  -58.216  52.962  1
563900  95.953  -58.228  52.958  1
563901  95.986  -58.238  52.952  1
563902  96.019  -58.250  52.941  1
563903  96.051  -58.260  52.934  1
563904  96.084  -58.272  52.918  1
563905  96.117  -58.282  52.894  1
563906  96.150  -58.294  52.871  1
563907  96.182  -58.304  52.856  1
563908  96.215  -58.316  52.827  1
563909  96.248  -58.326  52.802  1
563910  96.281  -58.337  52.777  1
563911  96.314  -58.348  52.752  1
563912  96.346  -58.359  52.729  1
563913  96.379  -58.370  52.707  1
563914  96.412  -58.381  52.685  1
563915  96.445  -58.392  52.659  1
563916  96.477  -58.403  52.631  1
563917  96.510  -58.414  52.603  1
563918  96.543  -58.425  52.574  1
563919  96.574  -58.423  52.535  1
563920  96.605  -58.421  52.503  1
563921  96.637  -58.419  52.462  1
563922  96.668  -58.418  52.422  1
563923  96.699  -58.416  52.384  1
563924  96.730  -58.414  52.345  1
563925  96.762  -58.420  52.305  1
563926  96.795  -58.426  52.270  1
563927  96.827  -58.432  52.233  1
563928  96.859  -58.438  52.196  1
563929  96.892  -58.444  52.159  1
563930  96.923  -58.450  52.121  1
563931  96.952  -58.453  52.084  1
563932  96.981  -58.455  52.050  1
563933  97.010  -58.458  52.018  1
563934  97.038  -58.461  51.987  1
563935  97.068  -58.464  51.955  1
563936  97.096  -58.467  51.922  1
563937  97.125  -58.470  51.891  1
563938  97.154  -58.473  51.863  1
563939  97.183  -58.476  51.834  1
563940  97.212  -58.479  51.805  1
563941  97.241  -58.482  51.774  1
563942  97.270  -58.485  51.739  1
563943  97.301  -58.486  51.698  1
563944  97.337  -58.486  51.650  1
563945  97.373  -58.486  51.597  1
563946  97.409  -58.486  51.539  1
563947  97.445  -58.486  51.478  1
563948  97.481  -58.485  51.421  1
563949  97.517  -58.485  51.369  1
563950  97.553  -58.485  51.320  1
563951  97.586  -58.489  51.270  1
563952  97.613  -58.499  51.220  1
563953  97.641  -58.508  51.172  1
563954  97.668  -58.518  51.124  1
563955  97.705  -58.519  51.079  1
563956  97.743  -58.519  51.038  1
563957  97.781  -58.519  50.998  1
563958  97.818  -58.519  50.956  1
563959  97.856  -58.519  50.914  1
563960  97.893  -58.519  50.870  1
563961  97.931  -58.518  50.827  1
563962  97.969  -58.518  50.788  1
563963  98.006  -58.519  50.751  1
563964  98.041  -58.520  50.714  1
563965  98.075  -58.522  50.675  1
563966  98.107  -58.523  50.639  1
563967  98.140  -58.523  50.604  1
563968  98.173  -58.524  50.572  1
563969  98.206  -58.525  50.540  1
563970  98.238  -58.526  50.510  1
563971  98.271  -58.527  50.483  1
563972  98.303  -58.528  50.453  1
563973  98.337  -58.527  50.419  1
563974  98.370  -58.526  50.383  1
563975  98.405  -58.525  50.347  1
563976  98.439  -58.525  50.309  1
563977  98.473  -58.524  50.273  1
563978  98.509  -58.524  50.235  1
563979  98.560  -58.523  50.198  1
563980  98.603  -58.523  50.166  1
563981  98.641  -58.521  50.138  1
563982  98.679  -58.520  50.115  1
563983  98.717  -58.519  50.094  1
563984  98.755  -58.517  50.078  1
563985  98.793  -58.516  50.062  1
563986  98.832  -58.503  50.047  1
563987  98.870  -58.485  50.033  1
563988  98.909  -58.468  50.018  1
563989  98.943  -58.454  50.004  1
563990  98.952  -58.460  49.987  1
563991  98.949  -58.466  49.969  1
563992  98.963  -58.469  49.950  1
563993  99.007  -58.469  49.929  1
563994  99.051  -58.468  49.905  1
563995  99.094  -58.467  49.882  1
563996  99.138  -58.466  49.857  1
563997  99.182  -58.466  49.832  1
563998  99.225  -58.445  49.809  1
563999  99.268  -58.408  49.788  1
564000  99.320  -58.431  49.767  1
564001  99.383  -58.442  49.744  1
564002  99.418  -58.451  49.718  1
564003  99.452  -58.460  49.694  1
564004  99.487  -58.469  49.671  1
564005  99.521  -58.477  49.646  1
564006  99.556  -58.486  49.623  1
564007  99.590  -58.495  49.598  1
564008  99.625  -58.504  49.573  1
564009  99.659  -58.512  49.547  1
564010  99.694  -58.521  49.519  1
564011  99.728  -58.529  49.491  1
564360  87.262  -54.931  57.611  4
564361  87.292  -54.948  57.607  4
564362  87.323  -54.966  57.603  4
564363  87.353  -54.982  57.599  4
564364  87.383  -55.000  57.595  4
564365  87.414  -55.017  57.592  4
564366  87.444  -55.034  57.588  4
564367  87.474  -55.051  57.580  4
564368  87.504  -55.069  57.573  4
564369  87.535  -55.085  57.567  4
564370  87.565  -55.103  57.561  4
564371  87.596  -55.120  57.554  4
564372  87.626  -55.137  57.548  4
564373  87.656  -55.154  57.540  4
564374  87.686  -55.172  57.529  4
564375  87.738  -55.173  57.516  4
564376  87.796  -55.186  57.498  4
564377  87.850  -55.202  57.476  4
564378  87.904  -55.219  57.454  4
564379  87.959  -55.235  57.429  4
564380  88.012  -55.251  57.402  4
564381  88.062  -55.267  57.374  4
564382  88.100  -55.284  57.343  4
564383  88.137  -55.301  57.308  4
564384  88.175  -55.317  57.269  4
564385  88.212  -55.333  57.227  4
564386  88.250  -55.350  57.182  4
564387  88.288  -55.367  57.136  4
564388  88.325  -55.383  57.090  4
564389  88.363  -55.400  57.044  4
564390  88.401  -55.417  56.998  4
564391  88.438  -55.433  56.952  4
564392  88.476  -55.450  56.906  4
564393  88.514  -55.466  56.861  4
564394  88.551  -55.483  56.817  4
564395  88.589  -55.499  56.774  4
564396  88.626  -55.516  56.733  4
564416  89.378  -55.848  55.994  1
564417  89.416  -55.865  55.972  1
564418  89.453  -55.881  55.952  1
564419  89.491  -55.898  55.934  1
564420  89.529  -55.914  55.915  1
564421  89.566  -55.931  55.898  1
564422  89.604  -55.947  55.886  1
564423  89.641  -55.964  55.873  1
564424  89.679  -55.981  55.863  1
564425  89.716  -55.995  55.855  1
564426  89.753  -56.013  55.848  1
564427  89.787  -56.034  55.844  1
564428  89.814  -56.054  55.842  1
564429  89.843  -56.072  55.840  1
564430  89.872  -56.091  55.838  1
564431  89.900  -56.109  55.837  1
564432  89.929  -56.127  55.837  1
564433  89.957  -56.145  55.840  1
564434  89.987  -56.162  55.844  1
564435  90.022  -56.175  55.848  1
564436  90.057  -56.187  55.853  1
564437  90.092  -56.200  55.858  1
564438  90.126  -56.212  55.864  1
564439  90.162  -56.225  55.866  1
564440  90.196  -56.237  55.870  1
564441  90.231  -56.250  55.871  1
564442  90.266  -56.262  55.868  1
564443  90.301  -56.275  55.861  1
564444  90.336  -56.287  55.851  1
564445  90.377  -56.298  55.835  1
564446  90.421  -56.309  55.817  1
564447  90.465  -56.320  55.799  1
564448  90.510  -56.330  55.780  1
564449  90.554  -56.340  55.760  1
564450  90.598  -56.351  55.738  1
564451  90.642  -56.361  55.716  1
564452  90.686  -56.372  55.696  1
564453  90.731  -56.382  55.676  1
564454  90.775  -56.393  55.656  1
564455  90.819  -56.404  55.637  1
564456  90.863  -56.414  55.619  1
564457  90.906  -56.426  55.601  1
564458  90.950  -56.439  55.586  1
564459  90.993  -56.451  55.573  1
564460  91.036  -56.463  55.562  1
564461  91.080  -56.475  55.551  1
564462  91.123  -56.487  55.545  1
564463  91.166  -56.499  55.540  1
564464  91.210  -56.512  55.535  1
564465  91.250  -56.526  55.527  1
564466  91.286  -56.543  55.514  1
564467  91.321  -56.561  55.498  1
564468  91.357  -56.577  55.477  1
564469  91.391  -56.594  55.451  1
564470  91.424  -56.606  55.425  1
564471  91.456  -56.619  55.403  1
564472  91.488  -56.631  55.387  1
564473  91.520  -56.643  55.372  1
564474  91.553  -56.655  55.360  1
564475  91.585  -56.668  55.353  1
564476  91.617  -56.680  55.350  1
564477  91.649  -56.693  55.354  1
564478  91.681  -56.705  55.364  1
564479  91.714  -56.717  55.375  1
564480  91.746  -56.729  55.386  1
564481  91.779  -56.741  55.393  1
564482  91.817  -56.752  55.394  1
564483  91.860  -56.762  55.401  1
564484  91.903  -56.771  55.411  1
564485  91.945  -56.788  55.419  1
564486  91.986  -56.811  55.429  1
564487  92.027  -56.834  55.439  1
564488  92.068  -56.858  55.444  1
564489  92.109  -56.881  55.440  1
564490  92.150  -56.905  55.425  1
564491  92.191  -56.928  55.405  1
564492  92.232  -56.952  55.382  1
564493  92.273  -56.975  55.364  1
564494  92.314  -56.999  55.364  1
564495  92.355  -57.022  55.364  1
564496  92.396  -57.045  55.361  1
564497  92.437  -57.067  55.361  1
564498  92.478  -57.087  55.362  1
564499  92.517  -57.115  55.362  1
564500  92.552  -57.135  55.360  1
564501  92.586  -57.156  55.348  1
564502  92.621  -57.177  55.332  1
564503  92.656  -57.198  55.317  1
564504  92.691  -57.219  55.304  1
564505  92.725  -57.240  55.292  1
564506  92.760  -57.261  55.275  1
564507  92.794  -57.282  55.257  1
564508  92.829  -57.304  55.244  1
564509  92.863  -57.325  55.234  1
564510  92.897  -57.341  55.223  1
564511  92.925  -57.348  55.210  1
564512  92.953  -57.355  55.191  1
564513  92.983  -57.362  55.166  1
564514  93.011  -57.369  55.136  1
564515  93.041  -57.375  55.104  1
564516  93.069  -57.382  55.074  1
564517  93.098  -57.388  55.045  1
564518  93.127  -57.395  55.018  1
564519  93.156  -57.401  54.991  1
564520  93.188  -57.412  54.963  1
564521  93.221  -57.423  54.936  1
564522  93.254  -57.427  54.913  1
564523  93.288  -57.431  54.896  1
564524  93.322  -57.435  54.881  1
564525  93.355  -57.438  54.865  1
564526  93.389  -57.442  54.849  1
564527  93.423  -57.446  54.833  1
564528  93.457  -57.450  54.817  1
564529  93.489  -57.452  54.800  1
564530  93.521  -57.455  54.781  1
564531  93.554  -57.457  54.761  1
564532  93.586  -57.460  54.740  1
564533  93.619  -57.462  54.719  1
564534  93.651  -57.464  54.697  1
564535  93.684  -57.467  54.671  1
564536  93.716  -57.470  54.648  1
564537  93.749  -57.472  54.625  1
564538  93.781  -57.474  54.604  1
564539  93.814  -57.476  54.583  1
564540  93.847  -57.479  54.563  1
564541  93.882  -57.489  54.561  1
564542  93.920  -57.509  54.562  1
564543  93.958  -57.529  54.564  1
564544  93.996  -57.548  54.564  1
564545  94.035  -57.568  54.564  1
564546  94.073  -57.588  54.571  1
564547  94.111  -57.608  54.577  1
564548  94.149  -57.627  54.580  1
564549  94.186  -57.650  54.578  1
564550  94.223  -57.673  54.570  1
564551  94.261  -57.695  54.556  1
564552  94.298  -57.718  54.539  1
564553  94.335  -57.742  54.521  1
564554  94.373  -57.764  54.500  1
564555  94.410  -57.787  54.478  1
564556  94.443  -57.800  54.455  1
564557  94.475  -57.813  54.430  1
564558  94.507  -57.825  54.408  1
564559  94.540  -57.837  54.386  1
564560  94.572  -57.850  54.365  1
564561  94.604  -57.861  54.345  1
564562  94.634  -57.871  54.325  1
564563  94.664  -57.882  54.305  1
564564  94.693  -57.892  54.284  1
564565  94.719  -57.904  54.260  1
564566  94.744  -57.916  54.233  1
564567  94.769  -57.928  54.202  1
564568  94.794  -57.940  54.169  1
564569  94.820  -57.952  54.133  1
564570  94.845  -57.965  54.092  1
564571  94.870  -57.977  54.048  1
564572  94.896  -57.989  54.001  1
564573  94.921  -58.001  53.953  1
564574  94.946  -58.013  53.901  1
564575  94.971  -58.025  53.847  1
564576  94.996  -58.037  53.791  1
564577  95.022  -58.050  53.736  1
564578  95.059  -58.060  53.680  1
564579  95.115  -58.069  53.623  1
564580  95.171  -58.079  53.562  1
564581  95.227  -58.088  53.504  1
564582  95.283  -58.097  53.448  1
564583  95.339  -58.106  53.393  1
564584  95.384  -58.110  53.338  1
564585  95.421  -58.109  53.285  1
564586  95.458  -58.109  53.234  1
564587  95.495  -58.108  53.186  1
564588  95.532  -58.107  53.145  1
564589  95.568  -58.106  53.109  1
564590  95.605  -58.106  53.077  1
564591  95.642  -58.105  53.047  1
564592  95.679  -58.105  53.027  1
564593  95.708  -58.106  53.013  1
564594  95.739  -58.112  53.003  1
564595  95.771  -58.125  52.993  1
564596  95.804  -58.139  52.981  1
564597  95.835  -58.149  52.963  1
564598  95.865  -58.156  52.949  1
564599  95.897  -58.165  52.937  1
564600  95.930  -58.176  52.928  1
564601  95.963  -58.187  52.921  1
564602  95.996  -58.198  52.913  1
564603  96.029  -58.209  52.909  1
564604  96.061  -58.220  52.904  1
564605  96.094  -58.231  52.891  1
564606  96.127  -58.242  52.871  1
564607  96.160  -58.253  52.850  1
564608  96.192  -58.264  52.837  1
564609  96.225  -58.275  52.811  1
564610  96.258  -58.286  52.783  1
564611  96.291  -58.297  52.760  1
564612  96.324  -58.308  52.736  1
564613  96.357  -58.319  52.709  1
564614  96.389  -58.330  52.688  1
564615  96.422  -58.341  52.664  1
564616  96.455  -58.352  52.638  1
564617  96.487  -58.363  52.611  1
564618  96.520  -58.374  52.583  1
564619  96.553  -58.385  52.556  1
564620  96.586  -58.394  52.524  1
564621  96.617  -58.391  52.496  1
564622  96.648  -58.390  52.458  1
564623  96.679  -58.388  52.420  1
564624  96.710  -58.386  52.385  1
564625  96.741  -58.385  52.348  1
564626  96.773  -58.391  52.313  1
564627  96.806  -58.397  52.284  1
564628  96.838  -58.403  52.251  1
564629  96.871  -58.409  52.215  1
564630  96.903  -58.415  52.178  1
564631  96.932  -58.417  52.142  1
564632  96.960  -58.420  52.106  1
564633  96.990  -58.423  52.074  1
564634  97.018  -58.426  52.044  1
564635  97.047  -58.429  52.015  1
564636  97.076  -58.432  51.985  1
564637  97.105  -58.435  51.954  1
564638  97.134  -58.438  51.927  1
564639  97.162  -58.441  51.900  1
564640  97.191  -58.444  51.872  1
564641  97.220  -58.447  51.842  1
564642  97.245  -58.451  51.811  1
564643  97.272  -58.455  51.778  1
564644  97.304  -58.454  51.736  1
564645  97.340  -58.453  51.686  1
564646  97.376  -58.452  51.629  1
564647  97.413  -58.452  51.567  1
564648  97.449  -58.451  51.505  1
564649  97.485  -58.451  51.449  1
564650  97.521  -58.450  51.396  1
564651  97.558  -58.450  51.346  1
564652  97.590  -58.454  51.295  1
564653  97.617  -58.463  51.243  1
564654  97.644  -58.473  51.193  1
564655  97.672  -58.482  51.145  1
564656  97.709  -58.483  51.100  1
564657  97.746  -58.483  51.059  1
564658  97.784  -58.483  51.020  1
564659  97.822  -58.483  50.979  1
564660  97.859  -58.483  50.934  1
564661  97.897  -58.483  50.889  1
564662  97.935  -58.483  50.845  1
564663  97.970  -58.485  50.804  1
564664  98.006  -58.486  50.765  1
564665  98.041  -58.488  50.726  1
564666  98.076  -58.489  50.686  1
564667  98.108  -58.490  50.650  1
564668  98.141  -58.491  50.614  1
564669  98.173  -58.491  50.580  1
564670  98.206  -58.493  50.547  1
564671  98.239  -58.494  50.514  1
564672  98.272  -58.495  50.483  1
564673  98.307  -58.495  50.451  1
564674  98.341  -58.493  50.416  1
564675  98.372  -58.487  50.380  1
564676  98.405  -58.485  50.342  1
564677  98.439  -58.485  50.303  1
564678  98.474  -58.484  50.265  1
564679  98.508  -58.484  50.228  1
564680  98.552  -58.483  50.194  1
564681  98.602  -58.483  50.164  1
564682  98.653  -58.483  50.137  1
564683  98.692  -58.482  50.114  1
564684  98.729  -58.480  50.094  1
564685  98.768  -58.479  50.076  1
564686  98.805  -58.478  50.060  1
564687  98.844  -58.469  50.046  1
564688  98.882  -58.452  50.032  1
564689  98.922  -58.435  50.018  1
564690  98.946  -58.431  50.003  1
564691  98.959  -58.435  49.987  1
564692  98.960  -58.444  49.970  1
564693  98.956  -58.450  49.951  1
564694  98.989  -58.451  49.928  1
564695  99.032  -58.450  49.904  1
564696  99.076  -58.449  49.878  1
564697  99.120  -58.448  49.852  1
564698  99.164  -58.447  49.827  1
564699  99.207  -58.410  49.803  1
564700  99.250  -58.372  49.779  1
564701  99.299  -58.401  49.759  1
564702  99.369  -58.415  49.737  1
564703  99.411  -58.423  49.712  1
564704  99.445  -58.432  49.688  1
564705  99.480  -58.441  49.665  1
564706  99.514  -58.449  49.641  1
564707  99.549  -58.458  49.618  1
564708  99.583  -58.467  49.594  1
564709  99.618  -58.476  49.568  1
564710  99.652  -58.485  49.542  1
564711  99.687  -58.493  49.516  1
564712  99.721  -58.502  49.488  1
565062  87.312  -54.900  57.606  4
565063  87.342  -54.918  57.603  4
565064  87.372  -54.935  57.600  4
565065  87.403  -54.952  57.596  4
565066  87.433  -54.969  57.592  4
565067  87.464  -54.987  57.588  4
565068  87.494  -55.003  57.582  4
565069  87.524  -55.021  57.576  4
565070  87.555  -55.038  57.570  4
565071  87.585  -55.055  57.564  4
565072  87.615  -55.072  57.558  4
565073  87.645  -55.090  57.551  4
565074  87.676  -55.107  57.543  4
565075  87.706  -55.124  57.533  4
565076  87.748  -55.130  57.520  4
565077  87.806  -55.144  57.505  4
565078  87.860  -55.160  57.486  4
565079  87.914  -55.176  57.466  4
565080  87.969  -55.191  57.444  4
565081  88.023  -55.208  57.419  4
565082  88.077  -55.224  57.393  4
565083  88.122  -55.241  57.363  4
565084  88.160  -55.257  57.331  4
565085  88.198  -55.274  57.294  4
565086  88.235  -55.290  57.254  4
565087  88.273  -55.307  57.212  4
565088  88.311  -55.323  57.168  4
565089  88.348  -55.340  57.121  4
565090  88.386  -55.357  57.074  4
565091  88.423  -55.373  57.028  4
565092  88.461  -55.390  56.982  4
565093  88.498  -55.407  56.935  4
565094  88.536  -55.423  56.889  4
565095  88.573  -55.439  56.844  4
565096  88.611  -55.456  56.800  4
565097  88.649  -55.473  56.757  4
565117  89.401  -55.805  55.993  1
565118  89.439  -55.821  55.970  1
565119  89.476  -55.838  55.949  1
565120  89.513  -55.853  55.929  1
565121  89.549  -55.866  55.911  1
565122  89.585  -55.881  55.895  1
565123  89.621  -55.895  55.881  1
565124  89.658  -55.912  55.868  1
565125  89.697  -55.934  55.857  1
565126  89.736  -55.958  55.848  1
565127  89.774  -55.981  55.841  1
565128  89.806  -56.001  55.838  1
565129  89.832  -56.019  55.836  1
565130  89.859  -56.038  55.832  1
565131  89.886  -56.057  55.829  1
565132  89.914  -56.077  55.827  1
565133  89.943  -56.095  55.826  1
565134  89.972  -56.112  55.826  1
565135  90.007  -56.125  55.827  1
565136  90.042  -56.137  55.829  1
565137  90.077  -56.150  55.832  1
565138  90.112  -56.162  55.835  1
565139  90.147  -56.175  55.838  1
565140  90.182  -56.187  55.840  1
565141  90.217  -56.200  55.842  1
565142  90.251  -56.212  55.843  1
565143  90.286  -56.225  55.840  1
565144  90.321  -56.237  55.835  1
565145  90.356  -56.250  55.826  1
565146  90.391  -56.262  55.815  1
565147  90.433  -56.273  55.801  1
565148  90.477  -56.283  55.787  1
565149  90.522  -56.294  55.772  1
565150  90.566  -56.304  55.756  1
565151  90.610  -56.315  55.737  1
565152  90.654  -56.326  55.718  1
565153  90.698  -56.336  55.700  1
565154  90.743  -56.347  55.683  1
565155  90.787  -56.357  55.666  1
565156  90.831  -56.367  55.649  1
565157  90.875  -56.378  55.632  1
565158  90.920  -56.389  55.616  1
565159  90.964  -56.399  55.602  1
565160  91.008  -56.410  55.589  1
565161  91.051  -56.422  55.579  1
565162  91.094  -56.434  55.568  1
565163  91.138  -56.447  55.559  1
565164  91.181  -56.459  55.552  1
565165  91.224  -56.471  55.546  1
565166  91.267  -56.483  55.539  1
565167  91.306  -56.498  55.526  1
565168  91.342  -56.516  55.510  1
565169  91.377  -56.533  55.491  1
565170  91.411  -56.548  55.468  1
565171  91.443  -56.561  55.443  1
565172  91.475  -56.573  55.420  1
565173  91.508  -56.585  55.400  1
565174  91.540  -56.597  55.384  1
565175  91.572  -56.610  55.371  1
565176  91.604  -56.622  55.361  1
565177  91.637  -56.634  55.355  1
565178  91.669  -56.646  55.354  1
565179  91.701  -56.658  55.361  1
565180  91.733  -56.671  55.371  1
565181  91.766  -56.683  55.381  1
565182  91.798  -56.696  55.389  1
565183  91.830  -56.708  55.394  1
565184  91.872  -56.718  55.408  1
565185  91.914  -56.730  55.419  1
565186  91.955  -56.753  55.426  1
565187  91.996  -56.777  55.430  1
565188  92.037  -56.800  55.434  1
565189  92.078  -56.824  55.434  1
565190  92.120  -56.847  55.423  1
565191  92.161  -56.871  55.402  1
565192  92.202  -56.892  55.379  1
565193  92.242  -56.912  55.359  1
565194  92.283  -56.934  55.348  1
565195  92.323  -56.954  55.353  1
565196  92.364  -56.975  55.356  1
565197  92.405  -56.996  55.360  1
565198  92.446  -57.016  55.363  1
565199  92.485  -57.048  55.365  1
565200  92.522  -57.078  55.365  1
565201  92.558  -57.099  55.359  1
565202  92.593  -57.120  55.347  1
565203  92.627  -57.141  55.336  1
565204  92.662  -57.162  55.330  1
565205  92.697  -57.182  55.328  1
565206  92.731  -57.203  55.321  1
565207  92.766  -57.224  55.306  1
565208  92.801  -57.245  55.287  1
565209  92.836  -57.266  55.273  1
565210  92.870  -57.287  55.263  1
565211  92.907  -57.305  55.252  1
565212  92.936  -57.312  55.238  1
565213  92.965  -57.319  55.216  1
565214  92.994  -57.325  55.189  1
565215  93.022  -57.332  55.158  1
565216  93.052  -57.338  55.125  1
565217  93.080  -57.344  55.095  1
565218  93.110  -57.351  55.067  1
565219  93.138  -57.357  55.040  1
565220  93.167  -57.364  55.013  1
565221  93.200  -57.375  54.986  1
565222  93.232  -57.387  54.961  1
565223  93.265  -57.399  54.938  1
565224  93.298  -57.404  54.916  1
565225  93.332  -57.407  54.898  1
565226  93.366  -57.410  54.883  1
565227  93.399  -57.414  54.869  1
565228  93.433  -57.418  54.856  1
565229  93.467  -57.422  54.842  1
565230  93.500  -57.426  54.827  1
565231  93.534  -57.429  54.809  1
565232  93.568  -57.433  54.789  1
565233  93.602  -57.437  54.767  1
565234  93.635  -57.441  54.743  1
565235  93.669  -57.444  54.717  1
565236  93.701  -57.446  54.688  1
565237  93.733  -57.449  54.659  1
565238  93.766  -57.451  54.630  1
565239  93.798  -57.454  54.602  1
565240  93.831  -57.456  54.578  1
565241  93.863  -57.458  54.554  1
565242  93.896  -57.461  54.544  1
565243  93.932  -57.473  54.541  1
565244  93.970  -57.493  54.540  1
565245  94.008  -57.513  54.540  1
565246  94.046  -57.532  54.542  1
565247  94.084  -57.552  54.548  1
565248  94.122  -57.575  54.554  1
565249  94.159  -57.598  54.557  1
565250  94.196  -57.620  54.557  1
565251  94.234  -57.643  54.552  1
565252  94.271  -57.666  54.541  1
565253  94.308  -57.689  54.525  1
565254  94.346  -57.712  54.507  1
565255  94.383  -57.735  54.488  1
565256  94.418  -57.753  54.467  1
565257  94.451  -57.766  54.445  1
565258  94.483  -57.778  54.421  1
565259  94.515  -57.790  54.396  1
565260  94.547  -57.803  54.374  1
565261  94.580  -57.815  54.354  1
565262  94.612  -57.828  54.335  1
565263  94.643  -57.839  54.318  1
565264  94.673  -57.849  54.300  1
565265  94.703  -57.859  54.280  1
565266  94.734  -57.869  54.256  1
565267  94.760  -57.880  54.230  1
565268  94.785  -57.893  54.200  1
565269  94.810  -57.905  54.169  1
565270  94.835  -57.917  54.134  1
565271  94.860  -57.929  54.096  1
565272  94.886  -57.941  54.056  1
565273  94.911  -57.953  54.012  1
565274  94.936  -57.965  53.966  1
565275  94.962  -57.977  53.916  1
565276  94.987  -57.990  53.863  1
565277  95.012  -58.002  53.808  1
565278  95.037  -58.014  53.751  1
565279  95.063  -58.026  53.694  1
565280  95.119  -58.035  53.634  1
565281  95.175  -58.044  53.575  1
565282  95.231  -58.053  53.517  1
565283  95.286  -58.063  53.457  1
565284  95.342  -58.072  53.399  1
565285  95.388  -58.076  53.343  1
565286  95.425  -58.075  53.288  1
565287  95.462  -58.075  53.234  1
565288  95.498  -58.074  53.182  1
565289  95.535  -58.073  53.136  1
565290  95.572  -58.072  53.095  1
565291  95.609  -58.071  53.059  1
565292  95.645  -58.071  53.026  1
565293  95.682  -58.070  53.002  1
565294  95.718  -58.069  52.983  1
565295  95.748  -58.071  52.969  1
565296  95.780  -58.084  52.959  1
565297  95.812  -58.097  52.949  1
565298  95.843  -58.105  52.933  1
565299  95.875  -58.115  52.915  1
565300  95.907  -58.125  52.902  1
565301  95.940  -58.136  52.891  1
565302  95.973  -58.147  52.882  1
565303  96.006  -58.158  52.875  1
565304  96.039  -58.169  52.871  1
565305  96.072  -58.180  52.865  1
565306  96.104  -58.191  52.857  1
565307  96.137  -58.202  52.843  1
565308  96.170  -58.213  52.827  1
565309  96.202  -58.224  52.814  1
565310  96.235  -58.235  52.792  1
565311  96.268  -58.246  52.766  1
565312  96.301  -58.257  52.744  1
565313  96.334  -58.268  52.720  1
565314  96.367  -58.278  52.692  1
565315  96.399  -58.290  52.667  1
565316  96.432  -58.300  52.642  1
565317  96.465  -58.312  52.615  1
565318  96.498  -58.322  52.588  1
565319  96.530  -58.334  52.560  1
565320  96.563  -58.344  52.533  1
565321  96.596  -58.356  52.507  1
565322  96.628  -58.362  52.481  1
565323  96.659  -58.360  52.450  1
565324  96.690  -58.358  52.418  1
565325  96.722  -58.357  52.385  1
565326  96.753  -58.355  52.351  1
565327  96.785  -58.361  52.322  1
565328  96.817  -58.367  52.296  1
565329  96.850  -58.373  52.265  1
565330  96.882  -58.379  52.231  1
565331  96.911  -58.382  52.196  1
565332  96.940  -58.385  52.162  1
565333  96.969  -58.388  52.128  1
565334  96.998  -58.391  52.097  1
565335  97.027  -58.394  52.068  1
565336  97.055  -58.397  52.040  1
565337  97.084  -58.400  52.012  1
565338  97.113  -58.403  51.986  1
565339  97.142  -58.406  51.965  1
565340  97.169  -58.410  51.939  1
565341  97.194  -58.415  51.911  1
565342  97.219  -58.420  51.880  1
565343  97.244  -58.425  51.846  1
565344  97.273  -58.423  51.812  1
565345  97.305  -58.421  51.769  1
565346  97.342  -58.421  51.719  1
565347  97.378  -58.420  51.661  1
565348  97.414  -58.419  51.599  1
565349  97.450  -58.419  51.536  1
565350  97.487  -58.419  51.481  1
565351  97.523  -58.418  51.426  1
565352  97.558  -58.419  51.374  1
565353  97.590  -58.422  51.322  1
565354  97.620  -58.428  51.269  1
565355  97.648  -58.438  51.218  1
565356  97.675  -58.448  51.170  1
565357  97.712  -58.448  51.125  1
565358  97.750  -58.448  51.083  1
565359  97.788  -58.448  51.044  1
565360  97.825  -58.448  51.003  1
565361  97.863  -58.448  50.957  1
565362  97.899  -58.448  50.911  1
565363  97.935  -58.451  50.866  1
565364  97.970  -58.452  50.823  1
565365  98.006  -58.454  50.780  1
565366  98.041  -58.455  50.738  1
565367  98.076  -58.457  50.698  1
565368  98.109  -58.458  50.660  1
565369  98.142  -58.459  50.623  1
565370  98.174  -58.460  50.587  1
565371  98.207  -58.460  50.552  1
565372  98.241  -58.461  50.516  1
565373  98.276  -58.462  50.481  1
565374  98.311  -58.462  50.446  1
565375  98.344  -58.459  50.411  1
565376  98.375  -58.453  50.374  1
565377  98.406  -58.446  50.335  1
565378  98.440  -58.444  50.296  1
565379  98.474  -58.444  50.258  1
565380  98.508  -58.444  50.222  1
565381  98.544  -58.443  50.190  1
565382  98.594  -58.443  50.162  1
565383  98.645  -58.443  50.136  1
565384  98.695  -58.442  50.114  1
565385  98.742  -58.442  50.093  1
565386  98.780  -58.441  50.075  1
565387  98.818  -58.439  50.059  1
565388  98.856  -58.436  50.045  1
565389  98.895  -58.419  50.032  1
565390  98.930  -58.405  50.018  1
565391  98.949  -58.407  50.002  1
565392  98.966  -58.409  49.987  1
565393  98.967  -58.419  49.969  1
565394  98.968  -58.428  49.950  1
565395  98.971  -58.432  49.927  1
565396  99.014  -58.432  49.902  1
565397  99.058  -58.431  49.875  1
565398  99.102  -58.430  49.848  1
565399  99.145  -58.412  49.822  1
565400  99.188  -58.375  49.797  1
565401  99.231  -58.338  49.772  1
565402  99.278  -58.372  49.751  1
565403  99.348  -58.385  49.729  1
565404  99.403  -58.395  49.706  1
565405  99.437  -58.404  49.682  1
565406  99.472  -58.413  49.659  1
565407  99.506  -58.422  49.635  1
565408  99.541  -58.430  49.612  1
565409  99.575  -58.439  49.588  1
565410  99.610  -58.448  49.563  1
565411  99.644  -58.457  49.537  1
565412  99.679  -58.466  49.512  1
565413  99.713  -58.474  49.484  1
565763  87.332  -54.853  57.605  4
565764  87.362  -54.870  57.602  4
565765  87.393  -54.887  57.600  4
565766  87.423  -54.904  57.596  4
565767  87.453  -54.922  57.593  4
565768  87.483  -54.939  57.589  4
565769  87.513  -54.956  57.584  4
565770  87.544  -54.973  57.578  4
565771  87.574  -54.991  57.573  4
565772  87.605  -55.007  57.567  4
565773  87.635  -55.025  57.561  4
565774  87.665  -55.042  57.555  4
565775  87.695  -55.059  57.547  4
565776  87.726  -55.076  57.537  4
565777  87.760  -55.089  57.525  4
565778  87.817  -55.101  57.513  4
565779  87.870  -55.116  57.496  4
565780  87.925  -55.133  57.478  4
565781  87.979  -55.149  57.458  4
565782  88.033  -55.165  57.436  4
565783  88.087  -55.182  57.410  4
565784  88.141  -55.198  57.382  4
565785  88.183  -55.214  57.352  4
565786  88.220  -55.231  57.319  4
565787  88.258  -55.247  57.281  4
565788  88.295  -55.263  57.240  4
565789  88.333  -55.280  57.196  4
565790  88.371  -55.297  57.150  4
565791  88.408  -55.314  57.104  4
565792  88.446  -55.330  57.058  4
565793  88.484  -55.347  57.012  4
565794  88.521  -55.364  56.964  4
565795  88.559  -55.380  56.917  4
565796  88.597  -55.396  56.871  4
565797  88.634  -55.413  56.826  4
565798  88.672  -55.430  56.782  4
565799  88.709  -55.446  56.738  4
565819  89.455  -55.766  55.968  1
565820  89.491  -55.781  55.946  1
565821  89.527  -55.794  55.926  1
565822  89.564  -55.809  55.908  1
565823  89.602  -55.833  55.891  1
565824  89.641  -55.856  55.876  1
565825  89.680  -55.880  55.863  1
565826  89.718  -55.903  55.851  1
565827  89.757  -55.926  55.841  1
565828  89.796  -55.950  55.832  1
565829  89.825  -55.968  55.827  1
565830  89.849  -55.984  55.823  1
565831  89.877  -56.003  55.819  1
565832  89.904  -56.022  55.817  1
565833  89.932  -56.041  55.816  1
565834  89.959  -56.061  55.816  1
565835  89.992  -56.075  55.814  1
565836  90.027  -56.087  55.812  1
565837  90.062  -56.099  55.811  1
565838  90.097  -56.112  55.812  1
565839  90.132  -56.125  55.815  1
565840  90.167  -56.137  55.817  1
565841  90.202  -56.150  55.818  1
565842  90.237  -56.162  55.820  1
565843  90.271  -56.175  55.820  1
565844  90.306  -56.187  55.817  1
565845  90.341  -56.200  55.815  1
565846  90.376  -56.212  55.808  1
565847  90.411  -56.225  55.800  1
565848  90.446  -56.237  55.791  1
565849  90.489  -56.248  55.780  1
565850  90.534  -56.258  55.769  1
565851  90.578  -56.269  55.755  1
565852  90.622  -56.279  55.739  1
565853  90.666  -56.290  55.724  1
565854  90.711  -56.300  55.708  1
565855  90.755  -56.310  55.693  1
565856  90.799  -56.321  55.678  1
565857  90.843  -56.332  55.663  1
565858  90.887  -56.342  55.647  1
565859  90.932  -56.353  55.632  1
565860  90.976  -56.364  55.618  1
565861  91.020  -56.373  55.606  1
565862  91.064  -56.384  55.596  1
565863  91.108  -56.395  55.585  1
565864  91.152  -56.406  55.574  1
565865  91.195  -56.418  55.565  1
565866  91.239  -56.430  55.558  1
565867  91.282  -56.442  55.553  1
565868  91.325  -56.454  55.541  1
565869  91.362  -56.471  55.527  1
565870  91.397  -56.489  55.509  1
565871  91.430  -56.502  55.488  1
565872  91.462  -56.514  55.463  1
565873  91.495  -56.527  55.439  1
565874  91.527  -56.539  55.416  1
565875  91.559  -56.552  55.397  1
565876  91.591  -56.564  55.382  1
565877  91.624  -56.576  55.369  1
565878  91.656  -56.588  55.359  1
565879  91.688  -56.601  55.354  1
565880  91.720  -56.613  55.355  1
565881  91.753  -56.625  55.360  1
565882  91.785  -56.637  55.368  1
565883  91.817  -56.649  55.379  1
565884  91.850  -56.662  55.393  1
565885  91.884  -56.674  55.413  1
565886  91.925  -56.696  55.425  1
565887  91.966  -56.717  55.429  1
565888  92.007  -56.738  55.428  1
565889  92.048  -56.758  55.424  1
565890  92.088  -56.779  55.418  1
565891  92.129  -56.800  55.400  1
565892  92.169  -56.821  55.377  1
565893  92.210  -56.842  55.356  1
565894  92.251  -56.862  55.343  1
565895  92.292  -56.883  55.340  1
565896  92.333  -56.904  55.345  1
565897  92.373  -56.924  55.348  1
565898  92.414  -56.946  55.349  1
565899  92.452  -56.979  55.350  1
565900  92.489  -57.015  55.350  1
565901  92.527  -57.042  55.351  1
565902  92.564  -57.062  55.349  1
565903  92.599  -57.083  55.341  1
565904  92.634  -57.104  55.341  1
565905  92.668  -57.125  55.346  1
565906  92.703  -57.146  55.348  1
565907  92.737  -57.166  55.343  1
565908  92.772  -57.188  55.329  1
565909  92.807  -57.208  55.310  1
565910  92.842  -57.229  55.292  1
565911  92.876  -57.250  55.279  1
565912  92.916  -57.267  55.269  1
565913  92.947  -57.275  55.253  1
565914  92.976  -57.282  55.230  1
565915  93.005  -57.288  55.202  1
565916  93.034  -57.294  55.172  1
565917  93.063  -57.301  55.143  1
565918  93.091  -57.307  55.115  1
565919  93.121  -57.314  55.088  1
565920  93.149  -57.321  55.062  1
565921  93.179  -57.327  55.037  1
565922  93.211  -57.338  55.014  1
565923  93.243  -57.351  54.990  1
565924  93.276  -57.363  54.965  1
565925  93.309  -57.374  54.938  1
565926  93.342  -57.379  54.917  1
565927  93.376  -57.383  54.899  1
565928  93.410  -57.387  54.884  1
565929  93.443  -57.390  54.872  1
565930  93.477  -57.394  54.861  1
565931  93.511  -57.398  54.847  1
565932  93.544  -57.401  54.831  1
565933  93.578  -57.405  54.812  1
565934  93.612  -57.409  54.789  1
565935  93.645  -57.413  54.764  1
565936  93.679  -57.416  54.737  1
565937  93.713  -57.420  54.708  1
565938  93.746  -57.424  54.677  1
565939  93.780  -57.428  54.645  1
565940  93.814  -57.432  54.613  1
565941  93.847  -57.435  54.583  1
565942  93.880  -57.438  54.553  1
565943  93.913  -57.441  54.533  1
565944  93.945  -57.443  54.522  1
565945  93.982  -57.457  54.516  1
565946  94.020  -57.477  54.514  1
565947  94.057  -57.500  54.518  1
565948  94.095  -57.523  54.523  1
565949  94.132  -57.545  54.526  1
565950  94.169  -57.568  54.529  1
565951  94.206  -57.591  54.532  1
565952  94.244  -57.614  54.530  1
565953  94.281  -57.637  54.522  1
565954  94.319  -57.660  54.507  1
565955  94.356  -57.683  54.491  1
565956  94.393  -57.705  54.474  1
565957  94.426  -57.719  54.455  1
565958  94.458  -57.731  54.433  1
565959  94.490  -57.744  54.409  1
565960  94.523  -57.756  54.384  1
565961  94.555  -57.768  54.361  1
565962  94.588  -57.781  54.340  1
565963  94.620  -57.793  54.324  1
565964  94.652  -57.806  54.309  1
565965  94.682  -57.816  54.292  1
565966  94.712  -57.826  54.273  1
565967  94.743  -57.836  54.250  1
565968  94.773  -57.846  54.225  1
565969  94.801  -57.857  54.196  1
565970  94.826  -57.869  54.165  1
565971  94.851  -57.881  54.130  1
565972  94.876  -57.893  54.094  1
565973  94.901  -57.905  54.056  1
565974  94.926  -57.918  54.014  1
565975  94.952  -57.930  53.970  1
565976  94.977  -57.942  53.922  1
565977  95.002  -57.954  53.871  1
565978  95.028  -57.966  53.817  1
565979  95.053  -57.978  53.762  1
565980  95.078  -57.990  53.705  1
565981  95.123  -58.000  53.647  1
565982  95.179  -58.010  53.587  1
565983  95.235  -58.019  53.529  1
565984  95.290  -58.028  53.468  1
565985  95.346  -58.037  53.407  1
565986  95.392  -58.041  53.348  1
565987  95.428  -58.040  53.289  1
565988  95.465  -58.040  53.236  1
565989  95.502  -58.039  53.184  1
565990  95.539  -58.038  53.133  1
565991  95.576  -58.037  53.086  1
565992  95.612  -58.037  53.045  1
565993  95.649  -58.036  53.008  1
565994  95.686  -58.035  52.981  1
565995  95.723  -58.034  52.958  1
565996  95.758  -58.034  52.938  1
565997  95.789  -58.043  52.923  1
565998  95.820  -58.054  52.913  1
565999  95.852  -58.063  52.899  1
566000  95.885  -58.075  52.880  1
566001  95.917  -58.085  52.864  1
566002  95.950  -58.096  52.852  1
566003  95.983  -58.107  52.843  1
566004  96.016  -58.118  52.837  1
566005  96.049  -58.129  52.830  1
566006  96.082  -58.140  52.824  1
566007  96.114  -58.151  52.818  1
566008  96.147  -58.162  52.811  1
566009  96.180  -58.173  52.800  1
566010  96.213  -58.184  52.786  1
566011  96.245  -58.195  52.769  1
566012  96.278  -58.206  52.746  1
566013  96.311  -58.217  52.725  1
566014  96.344  -58.228  52.702  1
566015  96.377  -58.238  52.676  1
566016  96.409  -58.250  52.648  1
566017  96.442  -58.260  52.623  1
566018  96.475  -58.272  52.597  1
566019  96.508  -58.282  52.570  1
566020  96.540  -58.294  52.544  1
566021  96.573  -58.304  52.517  1
566022  96.606  -58.316  52.491  1
566023  96.639  -58.326  52.466  1
566024  96.671  -58.331  52.438  1
566025  96.702  -58.328  52.408  1
566026  96.733  -58.327  52.379  1
566027  96.764  -58.325  52.351  1
566028  96.797  -58.332  52.325  1
566029  96.829  -58.338  52.300  1
566030  96.861  -58.344  52.271  1
566031  96.891  -58.347  52.240  1
566032  96.920  -58.350  52.207  1
566033  96.949  -58.354  52.175  1
566034  96.977  -58.357  52.142  1
566035  97.006  -58.359  52.112  1
566036  97.035  -58.362  52.083  1
566037  97.064  -58.365  52.057  1
566038  97.092  -58.369  52.034  1
566039  97.117  -58.373  52.012  1
566040  97.142  -58.379  51.992  1
566041  97.167  -58.384  51.968  1
566042  97.192  -58.388  51.941  1
566043  97.217  -58.394  51.909  1
566044  97.245  -58.394  51.875  1
566045  97.275  -58.391  51.838  1
566046  97.307  -58.389  51.795  1
566047  97.343  -58.388  51.748  1
566048  97.379  -58.388  51.694  1
566049  97.416  -58.387  51.636  1
566050  97.452  -58.387  51.575  1
566051  97.488  -58.386  51.518  1
566052  97.523  -58.387  51.462  1
566053  97.556  -58.389  51.407  1
566054  97.589  -58.392  51.354  1
566055  97.622  -58.395  51.302  1
566056  97.651  -58.403  51.251  1
566057  97.678  -58.412  51.203  1
566058  97.716  -58.412  51.156  1
566059  97.754  -58.412  51.112  1
566060  97.791  -58.412  51.069  1
566061  97.828  -58.413  51.025  1
566062  97.864  -58.414  50.980  1
566063  97.899  -58.416  50.934  1
566064  97.935  -58.418  50.887  1
566065  97.970  -58.419  50.842  1
566066  98.006  -58.421  50.798  1
566067  98.041  -58.422  50.753  1
566068  98.077  -58.425  50.710  1
566069  98.109  -58.426  50.668  1
566070  98.142  -58.426  50.629  1
566071  98.175  -58.427  50.591  1
566072  98.210  -58.428  50.553  1
566073  98.245  -58.429  50.516  1
566074  98.281  -58.429  50.476  1
566075  98.316  -58.429  50.439  1
566076  98.348  -58.425  50.401  1
566077  98.379  -58.419  50.364  1
566078  98.410  -58.412  50.326  1
566079  98.441  -58.406  50.288  1
566080  98.474  -58.404  50.252  1
566081  98.508  -58.404  50.219  1
566082  98.543  -58.403  50.189  1
566083  98.586  -58.403  50.161  1
566084  98.637  -58.403  50.135  1
566085  98.687  -58.402  50.112  1
566086  98.737  -58.402  50.092  1
566087  98.788  -58.402  50.075  1
566088  98.831  -58.401  50.060  1
566089  98.868  -58.400  50.045  1
566090  98.907  -58.385  50.031  1
566091  98.932  -58.381  50.018  1
566092  98.951  -58.382  50.002  1
566093  98.971  -58.384  49.985  1
566094  98.974  -58.393  49.967  1
566095  98.975  -58.402  49.947  1
566096  98.975  -58.410  49.924  1
566097  98.997  -58.413  49.899  1
566098  99.041  -58.412  49.872  1
566099  99.084  -58.411  49.845  1
566100  99.127  -58.376  49.818  1
566101  99.169  -58.339  49.792  1
566102  99.212  -58.303  49.767  1
566103  99.258  -58.329  49.744  1
566104  99.327  -58.357  49.721  1
566105  99.392  -58.368  49.699  1
566106  99.430  -58.376  49.676  1
566107  99.465  -58.385  49.652  1
566108  99.499  -58.394  49.629  1
566109  99.534  -58.403  49.606  1
566110  99.568  -58.411  49.582  1
566111  99.603  -58.420  49.557  1
566112  99.637  -58.429  49.532  1
566113  99.671  -58.438  49.507  1
566114  99.706  -58.447  49.479  1
566465  87.382  -54.822  57.602  4
566466  87.412  -54.840  57.600  4
566467  87.442  -54.857  57.596  4
566468  87.473  -54.874  57.594  4
566469  87.503  -54.891  57.591  4
566470  87.534  -54.909  57.586  4
566471  87.564  -54.925  57.581  4
566472  87.594  -54.943  57.576  4
566473  87.624  -54.960  57.571  4
566474  87.654  -54.977  57.566  4
566475  87.685  -54.994  57.560  4
566476  87.715  -55.012  57.552  4
566477  87.746  -55.028  57.543  4
566478  87.776  -55.046  57.532  4
566479  87.827  -55.057  57.521  4
566480  87.881  -55.074  57.506  4
566481  87.935  -55.090  57.491  4
566482  87.989  -55.106  57.473  4
566483  88.044  -55.123  57.453  4
566484  88.098  -55.138  57.428  4
566485  88.152  -55.154  57.401  4
566486  88.205  -55.171  57.373  4
566487  88.243  -55.188  57.342  4
566488  88.281  -55.204  57.308  4
566489  88.318  -55.220  57.268  4
566490  88.356  -55.237  57.224  4
566491  88.394  -55.254  57.180  4
566492  88.431  -55.270  57.134  4
566493  88.469  -55.287  57.088  4
566494  88.506  -55.304  57.041  4
566495  88.544  -55.320  56.992  4
566496  88.581  -55.337  56.945  4
566497  88.619  -55.353  56.898  4
566498  88.657  -55.370  56.852  4
566499  88.694  -55.386  56.806  4
566500  88.732  -55.403  56.762  4
566501  88.769  -55.420  56.718  4
566520  89.469  -55.709  55.967  1
566521  89.508  -55.730  55.945  1
566522  89.546  -55.754  55.924  1
566523  89.585  -55.777  55.905  1
566524  89.624  -55.801  55.888  1
566525  89.662  -55.824  55.871  1
566526  89.701  -55.847  55.857  1
566527  89.739  -55.871  55.845  1
566528  89.778  -55.894  55.834  1
566529  89.817  -55.918  55.824  1
566530  89.844  -55.934  55.817  1
566531  89.867  -55.948  55.811  1
566532  89.894  -55.968  55.807  1
566533  89.921  -55.987  55.804  1
566534  89.949  -56.006  55.802  1
566535  89.976  -56.025  55.800  1
566536  90.004  -56.041  55.798  1
566537  90.043  -56.051  55.796  1
566538  90.083  -56.062  55.796  1
566539  90.117  -56.074  55.797  1
566540  90.152  -56.087  55.799  1
566541  90.187  -56.099  55.800  1
566542  90.222  -56.112  55.801  1
566543  90.257  -56.124  55.802  1
566544  90.292  -56.137  55.802  1
566545  90.326  -56.149  55.800  1
566546  90.362  -56.162  55.799  1
566547  90.396  -56.175  55.795  1
566548  90.431  -56.187  55.789  1
566549  90.466  -56.200  55.783  1
566550  90.502  -56.212  55.776  1
566551  90.546  -56.222  55.767  1
566552  90.590  -56.233  55.756  1
566553  90.634  -56.243  55.743  1
566554  90.678  -56.254  55.731  1
566555  90.723  -56.264  55.718  1
566556  90.767  -56.275  55.705  1
566557  90.811  -56.285  55.691  1
566558  90.855  -56.296  55.678  1
566559  90.899  -56.307  55.664  1
566560  90.944  -56.317  55.649  1
566561  90.988  -56.327  55.636  1
566562  91.032  -56.338  55.625  1
566563  91.076  -56.348  55.615  1
566564  91.120  -56.359  55.603  1
566565  91.165  -56.370  55.591  1
566566  91.209  -56.379  55.581  1
566567  91.253  -56.390  55.574  1
566568  91.297  -56.401  55.570  1
566569  91.340  -56.414  55.560  1
566570  91.382  -56.427  55.547  1
566571  91.417  -56.444  55.530  1
566572  91.449  -56.457  55.509  1
566573  91.482  -56.469  55.484  1
566574  91.514  -56.481  55.459  1
566575  91.546  -56.493  55.433  1
566576  91.579  -56.505  55.411  1
566577  91.611  -56.518  55.392  1
566578  91.643  -56.530  55.377  1
566579  91.675  -56.542  55.364  1
566580  91.707  -56.555  55.356  1
566581  91.737  -56.567  55.352  1
566582  91.768  -56.580  55.353  1
566583  91.798  -56.593  55.358  1
566584  91.829  -56.606  55.368  1
566585  91.859  -56.619  55.385  1
566586  91.894  -56.627  55.400  1
566587  91.934  -56.646  55.410  1
566588  91.975  -56.667  55.415  1
566589  92.015  -56.687  55.415  1
566590  92.056  -56.708  55.408  1
566591  92.097  -56.729  55.397  1
566592  92.138  -56.749  55.374  1
566593  92.178  -56.771  55.354  1
566594  92.219  -56.791  55.342  1
566595  92.260  -56.812  55.339  1
566596  92.301  -56.833  55.342  1
566597  92.342  -56.853  55.343  1
566598  92.382  -56.874  55.342  1
566599  92.420  -56.910  55.339  1
566600  92.457  -56.946  55.336  1
566601  92.494  -56.984  55.336  1
566602  92.533  -57.006  55.340  1
566603  92.570  -57.025  55.344  1
566604  92.605  -57.047  55.344  1
566605  92.640  -57.067  55.352  1
566606  92.674  -57.088  55.361  1
566607  92.709  -57.109  55.365  1
566608  92.743  -57.130  55.360  1
566609  92.778  -57.151  55.346  1
566610  92.813  -57.172  55.327  1
566611  92.848  -57.193  55.310  1
566612  92.882  -57.213  55.297  1
566613  92.924  -57.228  55.287  1
566614  92.958  -57.238  55.273  1
566615  92.987  -57.244  55.253  1
566616  93.016  -57.251  55.228  1
566617  93.045  -57.257  55.201  1
566618  93.074  -57.264  55.173  1
566619  93.103  -57.270  55.145  1
566620  93.132  -57.277  55.117  1
566621  93.160  -57.284  55.093  1
566622  93.190  -57.290  55.071  1
566623  93.222  -57.302  55.048  1
566624  93.255  -57.314  55.022  1
566625  93.288  -57.326  54.993  1
566626  93.321  -57.338  54.963  1
566627  93.353  -57.350  54.936  1
566628  93.387  -57.355  54.913  1
566629  93.420  -57.359  54.894  1
566630  93.454  -57.363  54.882  1
566631  93.487  -57.366  54.873  1
566632  93.521  -57.370  54.861  1
566633  93.555  -57.373  54.847  1
566634  93.588  -57.377  54.828  1
566635  93.622  -57.381  54.806  1
566636  93.656  -57.385  54.781  1
566637  93.689  -57.388  54.754  1
566638  93.723  -57.392  54.725  1
566639  93.757  -57.396  54.694  1
566640  93.790  -57.400  54.660  1
566641  93.824  -57.404  54.625  1
566642  93.858  -57.407  54.592  1
566643  93.891  -57.411  54.557  1
566644  93.925  -57.415  54.529  1
566645  93.959  -57.418  54.509  1
566646  93.993  -57.425  54.497  1
566647  94.030  -57.448  54.491  1
566648  94.067  -57.470  54.493  1
566649  94.105  -57.493  54.495  1
566650  94.142  -57.516  54.497  1
566651  94.179  -57.539  54.500  1
566652  94.216  -57.562  54.503  1
566653  94.254  -57.585  54.502  1
566654  94.291  -57.608  54.496  1
566655  94.329  -57.630  54.482  1
566656  94.366  -57.653  54.468  1
566657  94.401  -57.672  54.453  1
566658  94.433  -57.684  54.436  1
566659  94.466  -57.697  54.417  1
566660  94.498  -57.709  54.394  1
566661  94.531  -57.722  54.370  1
566662  94.563  -57.734  54.346  1
566663  94.595  -57.746  54.326  1
566664  94.627  -57.759  54.310  1
566665  94.660  -57.771  54.296  1
566666  94.692  -57.783  54.282  1
566667  94.721  -57.793  54.264  1
566668  94.752  -57.803  54.242  1
566669  94.782  -57.813  54.218  1
566670  94.812  -57.824  54.189  1
566671  94.841  -57.833  54.158  1
566672  94.866  -57.846  54.124  1
566673  94.892  -57.858  54.089  1
566674  94.917  -57.870  54.052  1
566675  94.942  -57.882  54.011  1
566676  94.968  -57.894  53.969  1
566677  94.993  -57.906  53.924  1
566678  95.018  -57.918  53.873  1
566679  95.043  -57.930  53.820  1
566680  95.068  -57.943  53.766  1
566681  95.094  -57.955  53.711  1
566682  95.126  -57.966  53.653  1
566683  95.182  -57.975  53.595  1
566684  95.238  -57.984  53.535  1
566685  95.294  -57.994  53.475  1
566686  95.350  -58.003  53.415  1
566687  95.395  -58.007  53.354  1
566688  95.432  -58.006  53.292  1
566689  95.469  -58.006  53.237  1
566690  95.506  -58.005  53.184  1
566691  95.542  -58.004  53.131  1
566692  95.579  -58.003  53.079  1
566693  95.616  -58.003  53.034  1
566694  95.653  -58.002  52.996  1
566695  95.690  -58.001  52.964  1
566696  95.727  -58.000  52.935  1
566697  95.763  -57.999  52.911  1
566698  95.798  -58.002  52.892  1
566699  95.829  -58.012  52.874  1
566700  95.862  -58.023  52.856  1
566701  95.895  -58.034  52.839  1
566702  95.927  -58.045  52.824  1
566703  95.960  -58.056  52.812  1
566704  95.993  -58.067  52.802  1
566705  96.026  -58.078  52.793  1
566706  96.059  -58.089  52.788  1
566707  96.092  -58.100  52.781  1
566708  96.124  -58.111  52.776  1
566709  96.157  -58.122  52.771  1
566710  96.190  -58.133  52.762  1
566711  96.223  -58.144  52.752  1
566712  96.255  -58.155  52.740  1
566713  96.288  -58.165  52.721  1
566714  96.321  -58.177  52.702  1
566715  96.354  -58.187  52.681  1
566716  96.387  -58.198  52.658  1
566717  96.419  -58.209  52.633  1
566718  96.452  -58.220  52.608  1
566719  96.485  -58.231  52.584  1
566720  96.518  -58.242  52.558  1
566721  96.550  -58.253  52.532  1
566722  96.583  -58.264  52.506  1
566723  96.616  -58.275  52.478  1
566724  96.649  -58.286  52.452  1
566725  96.682  -58.297  52.425  1
566726  96.713  -58.299  52.398  1
566727  96.744  -58.297  52.372  1
566728  96.776  -58.296  52.350  1
566729  96.808  -58.302  52.326  1
566730  96.840  -58.308  52.301  1
566731  96.871  -58.313  52.274  1
566732  96.899  -58.316  52.245  1
566733  96.928  -58.318  52.215  1
566734  96.957  -58.321  52.185  1
566735  96.986  -58.324  52.154  1
566736  97.015  -58.327  52.125  1
566737  97.040  -58.332  52.098  1
566738  97.065  -58.337  52.074  1
566739  97.090  -58.342  52.055  1
566740  97.115  -58.347  52.035  1
566741  97.141  -58.352  52.015  1
566742  97.165  -58.357  51.992  1
566743  97.190  -58.363  51.965  1
566744  97.218  -58.364  51.935  1
566745  97.247  -58.361  51.901  1
566746  97.277  -58.359  51.863  1
566747  97.308  -58.357  51.821  1
566748  97.345  -58.356  51.776  1
566749  97.381  -58.356  51.727  1
566750  97.417  -58.355  51.673  1
566751  97.453  -58.354  51.614  1
566752  97.490  -58.354  51.557  1
566753  97.522  -58.357  51.500  1
566754  97.555  -58.360  51.444  1
566755  97.588  -58.363  51.391  1
566756  97.621  -58.365  51.339  1
566757  97.654  -58.368  51.288  1
566758  97.682  -58.376  51.239  1
566759  97.720  -58.376  51.191  1
566760  97.757  -58.377  51.143  1
566761  97.792  -58.379  51.096  1
566762  97.828  -58.380  51.047  1
566763  97.863  -58.382  50.998  1
566764  97.899  -58.384  50.951  1
566765  97.935  -58.385  50.903  1
566766  97.970  -58.387  50.857  1
566767  98.006  -58.388  50.812  1
566768  98.041  -58.391  50.767  1
566769  98.077  -58.392  50.723  1
566770  98.110  -58.393  50.679  1
566771  98.144  -58.394  50.638  1
566772  98.179  -58.394  50.598  1
566773  98.214  -58.395  50.557  1
566774  98.249  -58.395  50.517  1
566775  98.285  -58.396  50.475  1
566776  98.320  -58.396  50.435  1
566777  98.352  -58.391  50.396  1
566778  98.382  -58.385  50.358  1
566779  98.414  -58.378  50.321  1
566780  98.444  -58.372  50.286  1
566781  98.475  -58.365  50.253  1
566782  98.509  -58.363  50.220  1
566783  98.543  -58.363  50.190  1
566784  98.578  -58.363  50.163  1
566785  98.629  -58.363  50.138  1
566786  98.679  -58.362  50.114  1
566787  98.729  -58.362  50.094  1
566788  98.780  -58.362  50.077  1
566789  98.830  -58.362  50.061  1
566790  98.880  -58.361  50.046  1
566791  98.916  -58.356  50.032  1
566792  98.935  -58.357  50.018  1
566793  98.954  -58.359  50.001  1
566794  98.974  -58.360  49.984  1
566795  98.980  -58.367  49.965  1
566796  98.981  -58.376  49.944  1
566797  98.982  -58.386  49.921  1
566798  98.982  -58.394  49.896  1
566799  99.022  -58.394  49.869  1
566800  99.066  -58.378  49.843  1
566801  99.109  -58.341  49.816  1
566802  99.151  -58.304  49.789  1
566803  99.212  -58.265  49.763  1
566804  99.238  -58.266  49.740  1
566805  99.306  -58.327  49.717  1
566806  99.376  -58.341  49.694  1
566807  99.422  -58.349  49.670  1
566808  99.457  -58.357  49.647  1
566809  99.491  -58.366  49.623  1
566810  99.526  -58.375  49.599  1
566811  99.560  -58.384  49.576  1
566812  99.595  -58.392  49.551  1
566813  99.629  -58.401  49.526  1
566814  99.664  -58.410  49.500  1
566815  99.698  -58.419  49.473  1
567167  87.432  -54.792  57.599  4
567168  87.462  -54.809  57.596  4
567169  87.493  -54.826  57.594  4
567170  87.523  -54.844  57.592  4
567171  87.553  -54.861  57.588  4
567172  87.583  -54.878  57.584  4
567173  87.614  -54.895  57.579  4
567174  87.644  -54.913  57.576  4
567175  87.675  -54.929  57.571  4
567176  87.705  -54.947  57.565  4
567177  87.735  -54.964  57.558  4
567178  87.765  -54.981  57.549  4
567179  87.795  -54.998  57.539  4
567180  87.837  -55.015  57.529  4
567181  87.891  -55.031  57.516  4
567182  87.945  -55.047  57.502  4
567183  87.999  -55.063  57.486  4
567184  88.054  -55.079  57.467  4
567185  88.108  -55.096  57.444  4
567186  88.162  -55.112  57.420  4
567187  88.216  -55.128  57.393  4
567188  88.266  -55.144  57.364  4
567189  88.304  -55.161  57.333  4
567190  88.341  -55.177  57.294  4
567191  88.379  -55.194  57.251  4
567192  88.416  -55.210  57.208  4
567193  88.454  -55.227  57.163  4
567194  88.491  -55.244  57.117  4
567195  88.529  -55.260  57.071  4
567196  88.567  -55.277  57.021  4
567197  88.604  -55.294  56.973  4
567198  88.642  -55.311  56.925  4
567199  88.680  -55.326  56.878  4
567200  88.717  -55.343  56.831  4
567201  88.755  -55.360  56.785  4
567202  88.792  -55.376  56.740  4
567203  88.830  -55.393  56.697  4
567222  89.529  -55.699  55.944  1
567223  89.567  -55.722  55.923  1
567224  89.606  -55.746  55.902  1
567225  89.645  -55.769  55.884  1
567226  89.683  -55.793  55.867  1
567227  89.722  -55.815  55.852  1
567228  89.761  -55.839  55.839  1
567229  89.799  -55.862  55.827  1
567230  89.838  -55.886  55.817  1
567231  89.863  -55.901  55.808  1
567232  89.886  -55.915  55.801  1
567233  89.911  -55.932  55.796  1
567234  89.939  -55.952  55.791  1
567235  89.966  -55.971  55.787  1
567236  89.993  -55.991  55.785  1
567237  90.021  -56.008  55.782  1
567238  90.055  -56.018  55.781  1
567239  90.095  -56.028  55.781  1
567240  90.134  -56.038  55.783  1
567241  90.172  -56.049  55.785  1
567242  90.207  -56.062  55.786  1
567243  90.242  -56.074  55.787  1
567244  90.277  -56.087  55.789  1
567245  90.312  -56.099  55.790  1
567246  90.346  -56.112  55.790  1
567247  90.382  -56.124  55.789  1
567248  90.416  -56.137  55.787  1
567249  90.451  -56.149  55.783  1
567250  90.486  -56.162  55.778  1
567251  90.521  -56.174  55.774  1
567252  90.557  -56.186  55.768  1
567253  90.602  -56.197  55.760  1
567254  90.646  -56.207  55.750  1
567255  90.690  -56.218  55.739  1
567256  90.735  -56.229  55.729  1
567257  90.779  -56.239  55.718  1
567258  90.823  -56.250  55.707  1
567259  90.867  -56.260  55.695  1
567260  90.911  -56.270  55.682  1
567261  90.956  -56.281  55.669  1
567262  91.000  -56.291  55.655  1
567263  91.044  -56.302  55.644  1
567264  91.088  -56.313  55.633  1
567265  91.133  -56.323  55.621  1
567266  91.177  -56.333  55.609  1
567267  91.221  -56.344  55.597  1
567268  91.265  -56.354  55.587  1
567269  91.309  -56.365  55.582  1
567270  91.354  -56.376  55.575  1
567271  91.398  -56.386  55.564  1
567272  91.437  -56.398  55.548  1
567273  91.468  -56.410  55.528  1
567274  91.499  -56.423  55.504  1
567275  91.529  -56.436  55.478  1
567276  91.560  -56.449  55.450  1
567277  91.590  -56.462  55.425  1
567278  91.621  -56.475  55.404  1
567279  91.651  -56.487  55.385  1
567280  91.681  -56.500  55.370  1
567281  91.712  -56.513  55.359  1
567282  91.742  -56.526  55.351  1
567283  91.773  -56.539  55.347  1
567284  91.803  -56.552  55.349  1
567285  91.834  -56.564  55.356  1
567286  91.868  -56.573  55.370  1
567287  91.904  -56.580  55.380  1
567288  91.943  -56.595  55.387  1
567289  91.984  -56.616  55.392  1
567290  92.024  -56.637  55.392  1
567291  92.065  -56.658  55.384  1
567292  92.106  -56.678  55.372  1
567293  92.147  -56.699  55.354  1
567294  92.188  -56.720  55.342  1
567295  92.228  -56.741  55.341  1
567296  92.269  -56.762  55.347  1
567297  92.309  -56.782  55.354  1
567298  92.350  -56.804  55.359  1
567299  92.387  -56.841  55.360  1
567300  92.425  -56.877  55.359  1
567301  92.462  -56.915  55.355  1
567302  92.499  -56.950  55.349  1
567303  92.538  -56.969  55.346  1
567304  92.576  -56.989  55.355  1
567305  92.611  -57.010  55.364  1
567306  92.646  -57.031  55.371  1
567307  92.681  -57.052  55.375  1
567308  92.715  -57.072  55.377  1
567309  92.749  -57.094  55.372  1
567310  92.784  -57.114  55.359  1
567311  92.819  -57.135  55.341  1
567312  92.854  -57.156  55.327  1
567313  92.889  -57.177  55.316  1
567314  92.932  -57.190  55.305  1
567315  92.969  -57.201  55.290  1
567316  92.998  -57.207  55.272  1
567317  93.027  -57.214  55.249  1
567318  93.056  -57.220  55.223  1
567319  93.085  -57.227  55.195  1
567320  93.114  -57.234  55.166  1
567321  93.143  -57.240  55.137  1
567322  93.172  -57.247  55.112  1
567323  93.201  -57.254  55.087  1
567324  93.234  -57.266  55.061  1
567325  93.267  -57.278  55.035  1
567326  93.299  -57.289  55.010  1
567327  93.332  -57.301  54.982  1
567328  93.364  -57.313  54.954  1
567329  93.397  -57.325  54.927  1
567330  93.430  -57.331  54.902  1
567331  93.464  -57.335  54.882  1
567332  93.498  -57.338  54.871  1
567333  93.532  -57.342  54.862  1
567334  93.565  -57.346  54.851  1
567335  93.599  -57.350  54.836  1
567336  93.632  -57.353  54.815  1
567337  93.666  -57.357  54.792  1
567338  93.700  -57.360  54.766  1
567339  93.733  -57.364  54.737  1
567340  93.767  -57.368  54.707  1
567341  93.801  -57.372  54.675  1
567342  93.834  -57.376  54.639  1
567343  93.868  -57.379  54.603  1
567344  93.902  -57.383  54.565  1
567345  93.935  -57.387  54.530  1
567346  93.969  -57.391  54.504  1
567347  94.003  -57.395  54.484  1
567348  94.040  -57.418  54.470  1
567349  94.077  -57.441  54.467  1
567350  94.115  -57.464  54.468  1
567351  94.152  -57.486  54.468  1
567352  94.189  -57.510  54.469  1
567353  94.226  -57.532  54.471  1
567354  94.264  -57.555  54.470  1
567355  94.301  -57.578  54.464  1
567356  94.339  -57.601  54.453  1
567357  94.376  -57.623  54.439  1
567358  94.409  -57.638  54.425  1
567359  94.441  -57.650  54.410  1
567360  94.474  -57.662  54.395  1
567361  94.506  -57.675  54.374  1
567362  94.538  -57.687  54.352  1
567363  94.570  -57.699  54.332  1
567364  94.603  -57.712  54.314  1
567365  94.635  -57.724  54.300  1
567366  94.668  -57.737  54.286  1
567367  94.700  -57.749  54.270  1
567368  94.731  -57.760  54.251  1
567369  94.761  -57.771  54.230  1
567370  94.791  -57.780  54.205  1
567371  94.821  -57.790  54.178  1
567372  94.851  -57.800  54.147  1
567373  94.882  -57.811  54.114  1
567374  94.907  -57.822  54.079  1
567375  94.932  -57.834  54.043  1
567376  94.958  -57.846  54.004  1
567377  94.983  -57.858  53.963  1
567378  95.008  -57.871  53.919  1
567379  95.034  -57.883  53.871  1
567380  95.059  -57.895  53.819  1
567381  95.084  -57.907  53.766  1
567382  95.109  -57.919  53.711  1
567383  95.134  -57.931  53.655  1
567384  95.186  -57.941  53.597  1
567385  95.242  -57.950  53.537  1
567386  95.298  -57.959  53.478  1
567387  95.353  -57.968  53.420  1
567388  95.399  -57.972  53.359  1
567389  95.436  -57.971  53.296  1
567390  95.472  -57.971  53.239  1
567391  95.509  -57.970  53.185  1
567392  95.546  -57.969  53.130  1
567393  95.583  -57.968  53.076  1
567394  95.619  -57.968  53.027  1
567395  95.657  -57.967  52.984  1
567396  95.693  -57.966  52.948  1
567397  95.730  -57.965  52.916  1
567398  95.767  -57.965  52.889  1
567399  95.806  -57.966  52.866  1
567400  95.835  -57.974  52.843  1
567401  95.869  -57.985  52.823  1
567402  95.903  -57.995  52.806  1
567403  95.937  -58.006  52.791  1
567404  95.970  -58.016  52.778  1
567405  96.003  -58.027  52.767  1
567406  96.036  -58.037  52.756  1
567407  96.069  -58.049  52.748  1
567408  96.102  -58.059  52.740  1
567409  96.134  -58.071  52.735  1
567410  96.167  -58.081  52.732  1
567411  96.200  -58.093  52.726  1
567412  96.233  -58.103  52.719  1
567413  96.265  -58.115  52.709  1
567414  96.298  -58.125  52.695  1
567415  96.331  -58.137  52.678  1
567416  96.364  -58.147  52.659  1
567417  96.397  -58.159  52.637  1
567418  96.430  -58.169  52.616  1
567419  96.462  -58.180  52.594  1
567420  96.495  -58.191  52.573  1
567421  96.528  -58.202  52.550  1
567422  96.560  -58.213  52.525  1
567423  96.593  -58.224  52.500  1
567424  96.626  -58.235  52.474  1
567425  96.659  -58.246  52.447  1
567426  96.691  -58.257  52.421  1
567427  96.725  -58.268  52.394  1
567428  96.756  -58.267  52.368  1
567429  96.787  -58.267  52.345  1
567430  96.819  -58.273  52.323  1
567431  96.850  -58.278  52.299  1
567432  96.879  -58.280  52.274  1
567433  96.908  -58.283  52.248  1
567434  96.937  -58.286  52.221  1
567435  96.963  -58.291  52.193  1
567436  96.988  -58.296  52.165  1
567437  97.013  -58.300  52.138  1
567438  97.038  -58.306  52.113  1
567439  97.064  -58.311  52.092  1
567440  97.089  -58.316  52.073  1
567441  97.114  -58.321  52.056  1
567442  97.139  -58.326  52.035  1
567443  97.164  -58.331  52.011  1
567444  97.190  -58.335  51.986  1
567445  97.220  -58.332  51.957  1
567446  97.249  -58.329  51.924  1
567447  97.279  -58.326  51.888  1
567448  97.310  -58.325  51.847  1
567449  97.346  -58.324  51.804  1
567450  97.382  -58.323  51.758  1
567451  97.419  -58.322  51.708  1
567452  97.455  -58.322  51.652  1
567453  97.489  -58.325  51.595  1
567454  97.521  -58.327  51.538  1
567455  97.554  -58.330  51.483  1
567456  97.587  -58.333  51.430  1
567457  97.620  -58.335  51.377  1
567458  97.653  -58.338  51.325  1
567459  97.685  -58.341  51.276  1
567460  97.721  -58.343  51.226  1
567461  97.757  -58.344  51.174  1
567462  97.793  -58.346  51.121  1
567463  97.828  -58.347  51.068  1
567464  97.864  -58.350  51.015  1
567465  97.899  -58.351  50.965  1
567466  97.935  -58.353  50.916  1
567467  97.971  -58.354  50.869  1
567468  98.006  -58.357  50.824  1
567469  98.042  -58.358  50.778  1
567470  98.078  -58.360  50.734  1
567471  98.113  -58.360  50.691  1
567472  98.148  -58.361  50.648  1
567473  98.183  -58.362  50.606  1
567474  98.219  -58.362  50.563  1
567475  98.254  -58.363  50.519  1
567476  98.289  -58.363  50.475  1
567477  98.324  -58.363  50.432  1
567478  98.355  -58.357  50.392  1
567479  98.386  -58.350  50.354  1
567480  98.417  -58.344  50.318  1
567481  98.448  -58.338  50.284  1
567482  98.479  -58.331  50.252  1
567483  98.510  -58.325  50.220  1
567484  98.544  -58.323  50.191  1
567485  98.578  -58.322  50.165  1
567486  98.621  -58.322  50.140  1
567487  98.671  -58.322  50.117  1
567488  98.721  -58.322  50.097  1
567489  98.772  -58.322  50.079  1
567490  98.822  -58.322  50.063  1
567491  98.873  -58.321  50.048  1
567492  98.903  -58.324  50.032  1
567493  98.928  -58.328  50.016  1
567494  98.952  -58.332  49.999  1
567495  98.976  -58.336  49.982  1
567496  98.987  -58.341  49.962  1
567497  98.988  -58.350  49.940  1
567498  98.989  -58.360  49.917  1
567499  98.990  -58.369  49.892  1
567500  99.004  -58.375  49.865  1
567501  99.047  -58.343  49.839  1
567502  99.126  -58.300  49.813  1
567503  99.172  -58.285  49.787  1
567504  99.199  -58.286  49.762  1
567505  99.226  -58.288  49.738  1
567506  99.285  -58.297  49.715  1
567507  99.355  -58.311  49.691  1
567508  99.414  -58.321  49.667  1
567509  99.449  -58.330  49.642  1
567510  99.484  -58.338  49.618  1
567511  99.518  -58.347  49.594  1
567512  99.553  -58.356  49.570  1
567513  99.587  -58.365  49.546  1
567514  99.622  -58.373  49.521  1
567515  99.656  -58.382  49.495  1
567516  99.691  -58.391  49.468  1
567868  87.451  -54.744  57.598  4
567869  87.482  -54.762  57.597  4
567870  87.512  -54.779  57.595  4
567871  87.543  -54.796  57.594  4
567872  87.573  -54.813  57.591  4
567873  87.603  -54.831  57.586  4
567874  87.634  -54.847  57.583  4
567875  87.664  -54.865  57.579  4
567876  87.694  -54.882  57.574  4
567877  87.724  -54.899  57.570  4
567878  87.755  -54.918  57.564  4
567879  87.786  -54.941  57.556  4
567880  87.818  -54.964  57.547  4
567881  87.857  -54.969  57.537  4
567882  87.911  -54.981  57.525  4
567883  87.962  -55.000  57.512  4
567884  88.012  -55.019  57.498  4
567885  88.064  -55.037  57.480  4
567886  88.118  -55.053  57.459  4
567887  88.173  -55.069  57.436  4
567888  88.226  -55.085  57.411  4
567889  88.281  -55.101  57.385  4
567890  88.326  -55.118  57.356  4
567891  88.364  -55.134  57.321  4
567892  88.401  -55.151  57.278  4
567893  88.439  -55.167  57.235  4
567894  88.477  -55.184  57.191  4
567895  88.514  -55.201  57.146  4
567896  88.552  -55.217  57.099  4
567897  88.590  -55.234  57.050  4
567898  88.627  -55.251  57.001  4
567899  88.664  -55.265  56.953  4
567900  88.700  -55.279  56.905  4
567901  88.737  -55.294  56.857  4
567902  88.773  -55.308  56.809  4
567903  88.809  -55.322  56.763  4
567904  88.845  -55.336  56.719  4
567924  89.589  -55.690  55.921  1
567925  89.627  -55.714  55.899  1
567926  89.666  -55.737  55.880  1
567927  89.705  -55.760  55.863  1
567928  89.743  -55.784  55.847  1
567929  89.782  -55.807  55.832  1
567930  89.821  -55.831  55.820  1
567931  89.859  -55.853  55.809  1
567932  89.882  -55.868  55.799  1
567933  89.905  -55.882  55.791  1
567934  89.929  -55.897  55.785  1
567935  89.957  -55.916  55.780  1
567936  89.984  -55.936  55.776  1
567937  90.011  -55.955  55.772  1
567938  90.038  -55.974  55.769  1
567939  90.067  -55.984  55.767  1
567940  90.107  -55.994  55.768  1
567941  90.146  -56.005  55.770  1
567942  90.186  -56.015  55.772  1
567943  90.226  -56.025  55.775  1
567944  90.262  -56.037  55.776  1
567945  90.297  -56.049  55.778  1
567946  90.332  -56.062  55.781  1
567947  90.367  -56.074  55.782  1
567948  90.402  -56.087  55.783  1
567949  90.437  -56.099  55.782  1
567950  90.471  -56.112  55.780  1
567951  90.506  -56.124  55.778  1
567952  90.541  -56.137  55.776  1
567953  90.576  -56.149  55.773  1
567954  90.614  -56.161  55.768  1
567955  90.658  -56.172  55.760  1
567956  90.702  -56.182  55.752  1
567957  90.747  -56.193  55.743  1
567958  90.791  -56.203  55.734  1
567959  90.835  -56.213  55.724  1
567960  90.879  -56.224  55.713  1
567961  90.924  -56.235  55.701  1
567962  90.968  -56.245  55.689  1
567963  91.012  -56.256  55.676  1
567964  91.056  -56.266  55.665  1
567965  91.100  -56.276  55.653  1
567966  91.145  -56.287  55.641  1
567967  91.189  -56.298  55.627  1
567968  91.233  -56.308  55.614  1
567969  91.277  -56.319  55.602  1
567970  91.321  -56.329  55.595  1
567971  91.366  -56.339  55.588  1
567972  91.410  -56.350  55.578  1
567973  91.442  -56.356  55.563  1
567974  91.473  -56.369  55.543  1
567975  91.503  -56.382  55.519  1
567976  91.534  -56.395  55.492  1
567977  91.564  -56.407  55.465  1
567978  91.595  -56.420  55.439  1
567979  91.625  -56.432  55.416  1
567980  91.656  -56.445  55.395  1
567981  91.686  -56.458  55.375  1
567982  91.717  -56.471  55.361  1
567983  91.747  -56.484  55.350  1
567984  91.777  -56.497  55.344  1
567985  91.808  -56.510  55.340  1
567986  91.842  -56.519  55.340  1
567987  91.878  -56.526  55.346  1
567988  91.914  -56.533  55.350  1
567989  91.952  -56.545  55.356  1
567990  91.993  -56.566  55.362  1
567991  92.033  -56.586  55.363  1
567992  92.074  -56.608  55.357  1
567993  92.115  -56.628  55.349  1
567994  92.155  -56.649  55.340  1
567995  92.196  -56.670  55.338  1
567996  92.237  -56.690  55.344  1
567997  92.278  -56.711  55.355  1
567998  92.318  -56.735  55.365  1
567999  92.355  -56.772  55.372  1
568000  92.392  -56.809  55.373  1
568001  92.429  -56.846  55.371  1
568002  92.466  -56.883  55.367  1
568003  92.505  -56.914  55.363  1
568004  92.544  -56.933  55.362  1
568005  92.582  -56.953  55.369  1
568006  92.617  -56.973  55.378  1
568007  92.652  -56.994  55.384  1
568008  92.687  -57.015  55.385  1
568009  92.721  -57.036  55.384  1
568010  92.756  -57.056  55.378  1
568011  92.790  -57.078  55.369  1
568012  92.825  -57.099  55.357  1
568013  92.860  -57.119  55.346  1
568014  92.897  -57.138  55.335  1
568015  92.940  -57.152  55.321  1
568016  92.980  -57.164  55.304  1
568017  93.009  -57.170  55.286  1
568018  93.038  -57.177  55.263  1
568019  93.067  -57.184  55.237  1
568020  93.096  -57.190  55.211  1
568021  93.125  -57.197  55.180  1
568022  93.154  -57.203  55.151  1
568023  93.183  -57.210  55.126  1
568024  93.212  -57.217  55.100  1
568025  93.245  -57.229  55.072  1
568026  93.278  -57.241  55.046  1
568027  93.310  -57.253  55.023  1
568028  93.343  -57.265  54.996  1
568029  93.376  -57.276  54.967  1
568030  93.409  -57.288  54.937  1
568031  93.441  -57.301  54.908  1
568032  93.475  -57.307  54.884  1
568033  93.508  -57.310  54.867  1
568034  93.542  -57.314  54.855  1
568035  93.575  -57.318  54.844  1
568036  93.609  -57.322  54.828  1
568037  93.643  -57.326  54.809  1
568038  93.677  -57.329  54.787  1
568039  93.710  -57.333  54.763  1
568040  93.744  -57.336  54.736  1
568041  93.777  -57.340  54.709  1
568042  93.811  -57.344  54.679  1
568043  93.845  -57.348  54.646  1
568044  93.878  -57.351  54.611  1
568045  93.912  -57.355  54.576  1
568046  93.946  -57.359  54.541  1
568047  93.979  -57.363  54.509  1
568048  94.013  -57.366  54.480  1
568049  94.050  -57.388  54.455  1
568050  94.087  -57.411  54.442  1
568051  94.125  -57.434  54.440  1
568052  94.162  -57.457  54.439  1
568053  94.199  -57.480  54.439  1
568054  94.237  -57.503  54.438  1
568055  94.274  -57.526  54.434  1
568056  94.312  -57.548  54.428  1
568057  94.349  -57.571  54.419  1
568058  94.384  -57.591  54.405  1
568059  94.417  -57.603  54.392  1
568060  94.449  -57.615  54.381  1
568061  94.481  -57.628  54.368  1
568062  94.513  -57.640  54.351  1
568063  94.546  -57.653  54.331  1
568064  94.578  -57.665  54.313  1
568065  94.611  -57.677  54.299  1
568066  94.643  -57.690  54.288  1
568067  94.675  -57.702  54.274  1
568068  94.707  -57.714  54.257  1
568069  94.740  -57.727  54.238  1
568070  94.770  -57.737  54.216  1
568071  94.801  -57.748  54.192  1
568072  94.830  -57.758  54.164  1
568073  94.860  -57.767  54.133  1
568074  94.891  -57.777  54.101  1
568075  94.921  -57.788  54.067  1
568076  94.948  -57.799  54.031  1
568077  94.973  -57.811  53.993  1
568078  94.998  -57.823  53.952  1
568079  95.024  -57.835  53.910  1
568080  95.049  -57.847  53.863  1
568081  95.074  -57.859  53.812  1
568082  95.100  -57.871  53.759  1
568083  95.125  -57.883  53.704  1
568084  95.150  -57.896  53.648  1
568085  95.190  -57.906  53.592  1
568086  95.246  -57.915  53.532  1
568087  95.302  -57.925  53.474  1
568088  95.357  -57.934  53.417  1
568089  95.402  -57.938  53.359  1
568090  95.439  -57.937  53.302  1
568091  95.476  -57.937  53.244  1
568092  95.513  -57.936  53.187  1
568093  95.549  -57.935  53.132  1
568094  95.586  -57.934  53.078  1
568095  95.623  -57.934  53.025  1
568096  95.660  -57.933  52.975  1
568097  95.697  -57.932  52.935  1
568098  95.734  -57.931  52.901  1
568099  95.773  -57.933  52.871  1
568100  95.811  -57.937  52.843  1
568101  95.835  -57.944  52.818  1
568102  95.866  -57.952  52.798  1
568103  95.899  -57.962  52.778  1
568104  95.933  -57.973  52.762  1
568105  95.967  -57.984  52.748  1
568106  96.001  -57.993  52.736  1
568107  96.035  -58.004  52.724  1
568108  96.069  -58.014  52.714  1
568109  96.103  -58.024  52.705  1
568110  96.136  -58.035  52.699  1
568111  96.170  -58.045  52.696  1
568112  96.204  -58.056  52.693  1
568113  96.238  -58.066  52.687  1
568114  96.272  -58.076  52.678  1
568115  96.306  -58.087  52.667  1
568116  96.340  -58.097  52.653  1
568117  96.374  -58.107  52.636  1
568118  96.407  -58.118  52.616  1
568119  96.440  -58.129  52.598  1
568120  96.472  -58.140  52.579  1
568121  96.505  -58.151  52.559  1
568122  96.538  -58.162  52.537  1
568123  96.571  -58.173  52.514  1
568124  96.603  -58.184  52.492  1
568125  96.636  -58.195  52.467  1
568126  96.669  -58.206  52.441  1
568127  96.701  -58.217  52.416  1
568128  96.735  -58.228  52.391  1
568129  96.767  -58.238  52.367  1
568130  96.799  -58.238  52.346  1
568131  96.830  -58.242  52.325  1
568132  96.859  -58.245  52.303  1
568133  96.886  -58.249  52.279  1
568134  96.911  -58.254  52.256  1
568135  96.936  -58.260  52.233  1
568136  96.961  -58.264  52.208  1
568137  96.986  -58.269  52.184  1
568138  97.012  -58.275  52.161  1
568139  97.037  -58.279  52.139  1
568140  97.062  -58.285  52.118  1
568141  97.087  -58.290  52.097  1
568142  97.112  -58.294  52.076  1
568143  97.137  -58.300  52.054  1
568144  97.162  -58.304  52.031  1
568145  97.192  -58.302  52.005  1
568146  97.222  -58.300  51.978  1
568147  97.251  -58.297  51.950  1
568148  97.281  -58.294  51.915  1
568149  97.311  -58.292  51.875  1
568150  97.348  -58.291  51.832  1
568151  97.384  -58.291  51.786  1
568152  97.420  -58.291  51.737  1
568153  97.454  -58.292  51.683  1
568154  97.488  -58.294  51.628  1
568155  97.520  -58.297  51.571  1
568156  97.553  -58.300  51.517  1
568157  97.586  -58.303  51.465  1
568158  97.619  -58.306  51.415  1
568159  97.653  -58.306  51.362  1
568160  97.688  -58.306  51.309  1
568161  97.726  -58.310  51.255  1
568162  97.762  -58.312  51.199  1
568163  97.798  -58.313  51.142  1
568164  97.833  -58.316  51.086  1
568165  97.869  -58.317  51.030  1
568166  97.905  -58.319  50.978  1
568167  97.940  -58.320  50.928  1
568168  97.976  -58.322  50.880  1
568169  98.012  -58.324  50.832  1
568170  98.048  -58.325  50.785  1
568171  98.083  -58.327  50.744  1
568172  98.118  -58.328  50.703  1
568173  98.153  -58.328  50.661  1
568174  98.188  -58.328  50.617  1
568175  98.223  -58.329  50.570  1
568176  98.258  -58.329  50.524  1
568177  98.294  -58.330  50.477  1
568178  98.328  -58.328  50.431  1
568179  98.359  -58.322  50.389  1
568180  98.390  -58.316  50.350  1
568181  98.421  -58.310  50.315  1
568182  98.451  -58.303  50.282  1
568183  98.483  -58.297  50.248  1
568184  98.513  -58.291  50.218  1
568185  98.544  -58.284  50.191  1
568186  98.578  -58.282  50.166  1
568187  98.613  -58.282  50.142  1
568188  98.663  -58.281  50.122  1
568189  98.714  -58.281  50.100  1
568190  98.764  -58.281  50.082  1
568191  98.814  -58.281  50.066  1
568192  98.853  -58.283  50.049  1
568193  98.878  -58.287  50.031  1
568194  98.903  -58.291  50.013  1
568195  98.927  -58.295  49.997  1
568196  98.954  -58.309  49.980  1
568197  98.962  -58.319  49.960  1
568198  98.966  -58.328  49.937  1
568199  98.970  -58.338  49.913  1
568200  98.973  -58.347  49.886  1
568201  99.024  -58.331  49.860  1
568202  99.107  -58.299  49.835  1
568203  99.138  -58.290  49.810  1
568204  99.169  -58.280  49.786  1
568205  99.200  -58.271  49.762  1
568206  99.231  -58.262  49.737  1
568207  99.265  -58.269  49.714  1
568208  99.334  -58.282  49.689  1
568209  99.400  -58.294  49.664  1
568210  99.442  -58.302  49.640  1
568211  99.476  -58.310  49.615  1
568212  99.511  -58.319  49.590  1
568213  99.545  -58.328  49.566  1
568214  99.580  -58.337  49.541  1
568215  99.614  -58.346  49.516  1
568216  99.648  -58.354  49.490  1
568217  99.683  -58.363  49.463  1
568570  87.502  -54.714  57.597  4
568571  87.532  -54.731  57.596  4
568572  87.562  -54.748  57.595  4
568573  87.592  -54.765  57.593  4
568574  87.623  -54.783  57.589  4
568575  87.653  -54.800  57.586  4
568576  87.684  -54.818  57.582  4
568577  87.715  -54.842  57.578  4
568578  87.746  -54.866  57.574  4
568579  87.777  -54.888  57.569  4
568580  87.808  -54.912  57.562  4
568581  87.842  -54.929  57.554  4
568582  87.877  -54.944  57.545  4
568583  87.933  -54.934  57.534  4
568584  87.986  -54.947  57.522  4
568585  88.037  -54.966  57.509  4
568586  88.088  -54.984  57.493  4
568587  88.139  -55.002  57.473  4
568588  88.190  -55.021  57.451  4
568589  88.241  -55.039  57.428  4
568590  88.292  -55.058  57.403  4
568591  88.345  -55.075  57.377  4
568592  88.387  -55.091  57.344  4
568593  88.424  -55.107  57.303  4
568594  88.461  -55.123  57.261  4
568595  88.497  -55.136  57.218  4
568596  88.533  -55.151  57.174  4
568597  88.570  -55.165  57.129  4
568598  88.606  -55.179  57.079  4
568599  88.642  -55.193  57.029  4
568600  88.679  -55.207  56.980  4
568601  88.715  -55.222  56.931  4
568602  88.751  -55.236  56.882  4
568603  88.787  -55.250  56.835  4
568604  88.824  -55.264  56.788  4
568605  88.860  -55.279  56.742  4
568625  89.610  -55.658  55.918  1
568626  89.649  -55.682  55.897  1
568627  89.687  -55.705  55.877  1
568628  89.726  -55.728  55.858  1
568629  89.765  -55.752  55.842  1
568630  89.803  -55.775  55.827  1
568631  89.842  -55.799  55.813  1
568632  89.878  -55.821  55.801  1
568633  89.901  -55.834  55.791  1
568634  89.924  -55.849  55.783  1
568635  89.947  -55.862  55.776  1
568636  89.974  -55.881  55.771  1
568637  90.002  -55.900  55.766  1
568638  90.029  -55.920  55.762  1
568639  90.056  -55.940  55.759  1
568640  90.082  -55.951  55.758  1
568641  90.118  -55.961  55.759  1
568642  90.158  -55.972  55.760  1
568643  90.198  -55.981  55.763  1
568644  90.237  -55.991  55.766  1
568645  90.277  -56.002  55.767  1
568646  90.317  -56.012  55.769  1
568647  90.352  -56.024  55.773  1
568648  90.387  -56.037  55.776  1
568649  90.422  -56.049  55.779  1
568650  90.457  -56.062  55.780  1
568651  90.492  -56.074  55.780  1
568652  90.526  -56.087  55.780  1
568653  90.561  -56.099  55.780  1
568654  90.596  -56.112  55.780  1
568655  90.631  -56.124  55.777  1
568656  90.670  -56.136  55.773  1
568657  90.715  -56.146  55.767  1
568658  90.758  -56.157  55.760  1
568659  90.803  -56.167  55.752  1
568660  90.847  -56.178  55.744  1
568661  90.891  -56.188  55.734  1
568662  90.936  -56.199  55.724  1
568663  90.980  -56.210  55.712  1
568664  91.024  -56.219  55.699  1
568665  91.068  -56.230  55.688  1
568666  91.112  -56.241  55.676  1
568667  91.157  -56.251  55.662  1
568668  91.201  -56.262  55.647  1
568669  91.245  -56.273  55.633  1
568670  91.289  -56.282  55.619  1
568671  91.333  -56.293  55.611  1
568672  91.378  -56.304  55.602  1
568673  91.414  -56.311  55.592  1
568674  91.446  -56.317  55.576  1
568675  91.477  -56.327  55.555  1
568676  91.508  -56.340  55.530  1
568677  91.538  -56.353  55.504  1
568678  91.569  -56.366  55.478  1
568679  91.599  -56.378  55.452  1
568680  91.630  -56.391  55.427  1
568681  91.660  -56.404  55.404  1
568682  91.690  -56.417  55.381  1
568683  91.721  -56.429  55.364  1
568684  91.751  -56.442  55.351  1
568685  91.782  -56.455  55.341  1
568686  91.815  -56.465  55.334  1
568687  91.852  -56.472  55.330  1
568688  91.887  -56.479  55.330  1
568689  91.924  -56.486  55.333  1
568690  91.960  -56.495  55.335  1
568691  92.001  -56.515  55.338  1
568692  92.042  -56.536  55.340  1
568693  92.083  -56.557  55.339  1
568694  92.124  -56.578  55.338  1
568695  92.164  -56.599  55.339  1
568696  92.205  -56.619  55.344  1
568697  92.246  -56.640  55.352  1
568698  92.285  -56.666  55.363  1
568699  92.322  -56.703  55.373  1
568700  92.360  -56.740  55.382  1
568701  92.397  -56.777  55.382  1
568702  92.434  -56.814  55.379  1
568703  92.472  -56.850  55.377  1
568704  92.510  -56.877  55.378  1
568705  92.549  -56.897  55.381  1
568706  92.588  -56.916  55.385  1
568707  92.623  -56.937  55.391  1
568708  92.658  -56.958  55.394  1
568709  92.693  -56.978  55.393  1
568710  92.727  -57.000  55.390  1
568711  92.762  -57.020  55.384  1
568712  92.797  -57.041  55.376  1
568713  92.831  -57.062  55.366  1
568714  92.866  -57.083  55.354  1
568715  92.905  -57.100  55.339  1
568716  92.948  -57.113  55.322  1
568717  92.991  -57.127  55.302  1
568718  93.020  -57.134  55.283  1
568719  93.049  -57.140  55.262  1
568720  93.078  -57.147  55.239  1
568721  93.107  -57.153  55.213  1
568722  93.136  -57.160  55.186  1
568723  93.165  -57.166  55.161  1
568724  93.194  -57.172  55.139  1
568725  93.224  -57.181  55.116  1
568726  93.257  -57.193  55.091  1
568727  93.289  -57.204  55.061  1
568728  93.322  -57.216  55.034  1
568729  93.355  -57.228  55.003  1
568730  93.388  -57.240  54.974  1
568731  93.420  -57.252  54.945  1
568732  93.452  -57.264  54.915  1
568733  93.485  -57.275  54.888  1
568734  93.518  -57.282  54.865  1
568735  93.552  -57.286  54.848  1
568736  93.586  -57.290  54.833  1
568737  93.620  -57.294  54.816  1
568738  93.653  -57.297  54.797  1
568739  93.687  -57.301  54.776  1
568740  93.720  -57.305  54.754  1
568741  93.754  -57.309  54.730  1
568742  93.788  -57.313  54.704  1
568743  93.822  -57.316  54.676  1
568744  93.855  -57.319  54.647  1
568745  93.889  -57.323  54.616  1
568746  93.922  -57.327  54.585  1
568747  93.956  -57.331  54.553  1
568748  93.990  -57.335  54.521  1
568749  94.024  -57.338  54.489  1
568750  94.060  -57.359  54.457  1
568751  94.098  -57.382  54.433  1
568752  94.135  -57.405  54.420  1
568753  94.172  -57.428  54.416  1
568754  94.209  -57.451  54.414  1
568755  94.247  -57.473  54.409  1
568756  94.284  -57.496  54.401  1
568757  94.322  -57.519  54.390  1
568758  94.359  -57.542  54.378  1
568759  94.392  -57.556  54.365  1
568760  94.424  -57.569  54.355  1
568761  94.457  -57.581  54.346  1
568762  94.489  -57.593  54.336  1
568763  94.522  -57.606  54.322  1
568764  94.554  -57.618  54.304  1
568765  94.586  -57.630  54.289  1
568766  94.618  -57.643  54.279  1
568767  94.650  -57.655  54.271  1
568768  94.683  -57.668  54.259  1
568769  94.715  -57.680  54.243  1
568770  94.748  -57.692  54.223  1
568771  94.779  -57.705  54.201  1
568772  94.810  -57.714  54.176  1
568773  94.840  -57.724  54.149  1
568774  94.870  -57.735  54.118  1
568775  94.900  -57.745  54.085  1
568776  94.930  -57.755  54.052  1
568777  94.960  -57.764  54.017  1
568778  94.989  -57.775  53.980  1
568779  95.014  -57.787  53.939  1
568780  95.039  -57.799  53.899  1
568781  95.065  -57.811  53.853  1
568782  95.090  -57.824  53.805  1
568783  95.115  -57.836  53.752  1
568784  95.140  -57.848  53.697  1
568785  95.166  -57.860  53.640  1
568786  95.193  -57.872  53.584  1
568787  95.249  -57.881  53.526  1
568788  95.305  -57.890  53.468  1
568789  95.361  -57.899  53.410  1
568790  95.406  -57.903  53.353  1
568791  95.443  -57.902  53.298  1
568792  95.479  -57.902  53.243  1
568793  95.516  -57.901  53.189  1
568794  95.553  -57.900  53.136  1
568795  95.590  -57.899  53.084  1
568796  95.627  -57.899  53.030  1
568797  95.664  -57.898  52.980  1
568798  95.700  -57.897  52.934  1
568799  95.740  -57.899  52.893  1
568800  95.784  -57.904  52.856  1
568801  95.816  -57.909  52.825  1
568802  95.837  -57.915  52.797  1
568803  95.867  -57.922  52.774  1
568804  95.896  -57.930  52.755  1
568805  95.930  -57.940  52.739  1
568806  95.964  -57.950  52.725  1
568807  95.997  -57.961  52.713  1
568808  96.032  -57.971  52.701  1
568809  96.065  -57.981  52.690  1
568810  96.099  -57.992  52.681  1
568811  96.133  -58.003  52.674  1
568812  96.167  -58.012  52.669  1
568813  96.201  -58.023  52.664  1
568814  96.235  -58.034  52.653  1
568815  96.269  -58.043  52.645  1
568816  96.303  -58.054  52.637  1
568817  96.336  -58.065  52.626  1
568818  96.371  -58.075  52.612  1
568819  96.404  -58.085  52.597  1
568820  96.438  -58.095  52.579  1
568821  96.472  -58.106  52.562  1
568822  96.506  -58.116  52.543  1
568823  96.540  -58.126  52.522  1
568824  96.574  -58.137  52.502  1
568825  96.608  -58.147  52.481  1
568826  96.642  -58.157  52.458  1
568827  96.675  -58.168  52.434  1
568828  96.710  -58.178  52.410  1
568829  96.743  -58.188  52.387  1
568830  96.777  -58.199  52.367  1
568831  96.809  -58.208  52.348  1
568832  96.834  -58.212  52.329  1
568833  96.859  -58.218  52.309  1
568834  96.884  -58.223  52.288  1
568835  96.909  -58.228  52.268  1
568836  96.935  -58.233  52.247  1
568837  96.960  -58.238  52.226  1
568838  96.985  -58.243  52.206  1
568839  97.010  -58.248  52.186  1
568840  97.035  -58.253  52.166  1
568841  97.060  -58.258  52.146  1
568842  97.085  -58.263  52.123  1
568843  97.110  -58.269  52.100  1
568844  97.136  -58.273  52.077  1
568845  97.164  -58.272  52.053  1
568846  97.194  -58.270  52.027  1
568847  97.224  -58.267  52.001  1
568848  97.253  -58.265  51.974  1
568849  97.283  -58.262  51.940  1
568850  97.313  -58.259  51.901  1
568851  97.349  -58.259  51.858  1
568852  97.385  -58.259  51.812  1
568853  97.421  -58.259  51.763  1
568854  97.453  -58.262  51.710  1
568855  97.486  -58.265  51.655  1
568856  97.519  -58.268  51.598  1
568857  97.552  -58.270  51.544  1
568858  97.587  -58.271  51.492  1
568859  97.621  -58.271  51.442  1
568860  97.656  -58.272  51.389  1
568861  97.690  -58.272  51.334  1
568862  97.728  -58.275  51.276  1
568863  97.768  -58.280  51.218  1
568864  97.803  -58.281  51.159  1
568865  97.839  -58.283  51.101  1
568866  97.874  -58.285  51.044  1
568867  97.910  -58.286  50.990  1
568868  97.946  -58.288  50.938  1
568869  97.982  -58.290  50.887  1
568870  98.017  -58.291  50.838  1
568871  98.053  -58.293  50.791  1
568872  98.088  -58.294  50.749  1
568873  98.123  -58.295  50.708  1
568874  98.157  -58.295  50.665  1
568875  98.193  -58.296  50.621  1
568876  98.228  -58.296  50.575  1
568877  98.263  -58.297  50.526  1
568878  98.298  -58.297  50.477  1
568879  98.332  -58.294  50.431  1
568880  98.363  -58.288  50.388  1
568881  98.393  -58.281  50.349  1
568882  98.424  -58.275  50.313  1
568883  98.455  -58.269  50.280  1
568884  98.486  -58.263  50.250  1
568885  98.517  -58.256  50.220  1
568886  98.548  -58.250  50.193  1
568887  98.579  -58.243  50.168  1
568888  98.613  -58.242  50.144  1
568889  98.655  -58.241  50.124  1
568890  98.706  -58.241  50.103  1
568891  98.756  -58.241  50.085  1
568892  98.803  -58.241  50.067  1
568893  98.828  -58.246  50.048  1
568894  98.853  -58.250  50.029  1
568895  98.878  -58.259  50.010  1
568896  98.906  -58.275  49.994  1
568897  98.928  -58.289  49.977  1
568898  98.932  -58.298  49.956  1
568899  98.935  -58.307  49.933  1
568900  98.938  -58.316  49.909  1
568901  98.976  -58.308  49.883  1
568902  99.060  -58.275  49.858  1
568903  99.102  -58.268  49.834  1
568904  99.144  -58.261  49.812  1
568905  99.175  -58.252  49.789  1
568906  99.207  -58.243  49.764  1
568907  99.237  -58.233  49.739  1
568908  99.251  -58.239  49.714  1
568909  99.313  -58.253  49.688  1
568910  99.382  -58.266  49.663  1
568911  99.434  -58.274  49.638  1
568912  99.469  -58.283  49.612  1
568913  99.503  -58.291  49.587  1
568914  99.538  -58.300  49.562  1
568915  99.572  -58.310  49.537  1
568916  99.607  -58.318  49.512  1
568917  99.641  -58.327  49.486  1
568918  99.676  -58.335  49.459  1
569272  87.552  -54.684  57.596  4
569273  87.582  -54.701  57.596  4
569274  87.613  -54.718  57.595  4
569275  87.643  -54.742  57.593  4
569276  87.675  -54.765  57.588  4
569277  87.705  -54.789  57.585  4
569278  87.737  -54.812  57.582  4
569279  87.767  -54.835  57.578  4
569280  87.798  -54.859  57.575  4
569281  87.831  -54.878  57.568  4
569282  87.867  -54.894  57.561  4
569283  87.902  -54.909  57.552  4
569284  87.953  -54.894  57.542  4
569285  88.009  -54.898  57.532  4
569286  88.062  -54.912  57.520  4
569287  88.113  -54.931  57.504  4
569288  88.164  -54.949  57.486  4
569289  88.215  -54.968  57.466  4
569290  88.266  -54.986  57.444  4
569291  88.317  -55.005  57.420  4
569292  88.363  -55.022  57.394  4
569293  88.403  -55.036  57.363  4
569294  88.439  -55.050  57.326  4
569295  88.476  -55.064  57.287  4
569296  88.512  -55.079  57.245  4
569297  88.548  -55.093  57.201  4
569298  88.585  -55.107  57.156  4
569299  88.621  -55.121  57.106  4
569300  88.657  -55.135  57.057  4
569301  88.693  -55.150  57.007  4
569302  88.730  -55.164  56.957  4
569303  88.766  -55.178  56.908  4
569304  88.803  -55.192  56.859  4
569305  88.839  -55.207  56.811  4
569306  88.875  -55.221  56.764  4
569307  88.911  -55.235  56.718  4
569327  89.670  -55.650  55.894  1
569328  89.709  -55.673  55.874  1
569329  89.747  -55.696  55.855  1
569330  89.786  -55.720  55.837  1
569331  89.825  -55.743  55.822  1
569332  89.863  -55.767  55.808  1
569333  89.897  -55.787  55.795  1
569334  89.920  -55.801  55.785  1
569335  89.943  -55.815  55.776  1
569336  89.966  -55.830  55.769  1
569337  89.991  -55.846  55.763  1
569338  90.019  -55.865  55.758  1
569339  90.046  -55.885  55.754  1
569340  90.074  -55.904  55.751  1
569341  90.100  -55.918  55.750  1
569342  90.130  -55.928  55.750  1
569343  90.170  -55.937  55.752  1
569344  90.210  -55.948  55.756  1
569345  90.249  -55.958  55.759  1
569346  90.289  -55.969  55.762  1
569347  90.328  -55.978  55.765  1
569348  90.368  -55.988  55.770  1
569349  90.407  -55.999  55.774  1
569350  90.442  -56.012  55.778  1
569351  90.477  -56.024  55.781  1
569352  90.512  -56.037  55.783  1
569353  90.546  -56.049  55.785  1
569354  90.581  -56.062  55.787  1
569355  90.616  -56.074  55.790  1
569356  90.651  -56.087  55.789  1
569357  90.686  -56.099  55.787  1
569358  90.727  -56.110  55.784  1
569359  90.770  -56.121  55.778  1
569360  90.815  -56.132  55.773  1
569361  90.859  -56.142  55.766  1
569362  90.903  -56.153  55.758  1
569363  90.948  -56.163  55.748  1
569364  90.992  -56.173  55.737  1
569365  91.036  -56.184  55.726  1
569366  91.080  -56.194  55.715  1
569367  91.124  -56.205  55.700  1
569368  91.169  -56.216  55.685  1
569369  91.213  -56.226  55.669  1
569370  91.257  -56.236  55.652  1
569371  91.301  -56.247  55.635  1
569372  91.346  -56.257  55.622  1
569373  91.385  -56.266  55.610  1
569374  91.418  -56.272  55.598  1
569375  91.450  -56.277  55.582  1
569376  91.483  -56.285  55.561  1
569377  91.513  -56.298  55.538  1
569378  91.543  -56.311  55.516  1
569379  91.574  -56.323  55.491  1
569380  91.604  -56.336  55.465  1
569381  91.635  -56.349  55.438  1
569382  91.665  -56.362  55.411  1
569383  91.696  -56.375  55.387  1
569384  91.726  -56.388  55.367  1
569385  91.756  -56.400  55.352  1
569386  91.789  -56.410  55.340  1
569387  91.825  -56.417  55.330  1
569388  91.861  -56.424  55.324  1
569389  91.897  -56.432  55.321  1
569390  91.934  -56.439  55.322  1
569391  91.969  -56.445  55.326  1
569392  92.010  -56.465  55.331  1
569393  92.051  -56.486  55.336  1
569394  92.092  -56.507  55.340  1
569395  92.132  -56.527  55.347  1
569396  92.173  -56.548  55.358  1
569397  92.214  -56.569  55.369  1
569398  92.253  -56.597  55.379  1
569399  92.290  -56.634  55.387  1
569400  92.328  -56.671  55.392  1
569401  92.365  -56.708  55.395  1
569402  92.402  -56.745  55.395  1
569403  92.439  -56.781  55.395  1
569404  92.477  -56.818  55.396  1
569405  92.515  -56.841  55.398  1
569406  92.554  -56.861  55.400  1
569407  92.593  -56.880  55.402  1
569408  92.630  -56.900  55.404  1
569409  92.664  -56.921  55.403  1
569410  92.699  -56.942  55.398  1
569411  92.733  -56.962  55.392  1
569412  92.768  -56.984  55.387  1
569413  92.803  -57.004  55.379  1
569414  92.838  -57.025  55.370  1
569415  92.872  -57.046  55.357  1
569416  92.914  -57.061  55.341  1
569417  92.956  -57.075  55.324  1
569418  93.000  -57.088  55.306  1
569419  93.031  -57.097  55.288  1
569420  93.060  -57.103  55.268  1
569421  93.089  -57.109  55.248  1
569422  93.118  -57.116  55.226  1
569423  93.147  -57.122  55.206  1
569424  93.176  -57.129  55.189  1
569425  93.205  -57.136  55.171  1
569426  93.235  -57.144  55.151  1
569427  93.268  -57.156  55.128  1
569428  93.301  -57.168  55.099  1
569429  93.334  -57.180  55.069  1
569430  93.366  -57.191  55.037  1
569431  93.399  -57.203  55.003  1
569432  93.431  -57.216  54.968  1
569433  93.464  -57.227  54.933  1
569434  93.497  -57.239  54.902  1
569435  93.530  -57.251  54.873  1
569436  93.563  -57.258  54.847  1
569437  93.596  -57.262  54.824  1
569438  93.630  -57.266  54.802  1
569439  93.663  -57.269  54.780  1
569440  93.697  -57.273  54.761  1
569441  93.731  -57.277  54.739  1
569442  93.765  -57.281  54.717  1
569443  93.798  -57.285  54.693  1
569444  93.832  -57.288  54.669  1
569445  93.865  -57.292  54.644  1
569446  93.899  -57.296  54.618  1
569447  93.933  -57.299  54.593  1
569448  93.967  -57.303  54.564  1
569449  94.000  -57.307  54.534  1
569450  94.034  -57.310  54.502  1
569451  94.070  -57.330  54.466  1
569452  94.108  -57.353  54.433  1
569453  94.145  -57.376  54.408  1
569454  94.182  -57.398  54.395  1
569455  94.219  -57.421  54.389  1
569456  94.257  -57.444  54.383  1
569457  94.294  -57.467  54.370  1
569458  94.332  -57.489  54.356  1
569459  94.367  -57.509  54.341  1
569460  94.400  -57.522  54.328  1
569461  94.432  -57.534  54.317  1
569462  94.464  -57.546  54.309  1
569463  94.497  -57.559  54.298  1
569464  94.529  -57.571  54.284  1
569465  94.561  -57.584  54.269  1
569466  94.594  -57.596  54.258  1
569467  94.626  -57.608  54.252  1
569468  94.659  -57.621  54.247  1
569469  94.691  -57.633  54.237  1
569470  94.723  -57.646  54.223  1
569471  94.755  -57.658  54.205  1
569472  94.787  -57.670  54.184  1
569473  94.819  -57.682  54.159  1
569474  94.849  -57.692  54.131  1
569475  94.879  -57.702  54.101  1
569476  94.909  -57.712  54.068  1
569477  94.939  -57.722  54.034  1
569478  94.969  -57.732  54.000  1
569479  94.999  -57.742  53.964  1
569480  95.030  -57.752  53.926  1
569481  95.055  -57.764  53.886  1
569482  95.080  -57.776  53.842  1
569483  95.106  -57.788  53.796  1
569484  95.131  -57.800  53.746  1
569485  95.156  -57.812  53.691  1
569486  95.181  -57.824  53.632  1
569487  95.206  -57.836  53.575  1
569488  95.253  -57.847  53.518  1
569489  95.309  -57.856  53.460  1
569490  95.365  -57.865  53.401  1
569491  95.409  -57.868  53.343  1
569492  95.446  -57.868  53.289  1
569493  95.483  -57.867  53.237  1
569494  95.520  -57.867  53.187  1
569495  95.557  -57.866  53.139  1
569496  95.594  -57.865  53.089  1
569497  95.630  -57.865  53.036  1
569498  95.667  -57.864  52.985  1
569499  95.707  -57.865  52.936  1
569500  95.751  -57.870  52.891  1
569501  95.795  -57.875  52.850  1
569502  95.822  -57.880  52.813  1
569503  95.842  -57.886  52.781  1
569504  95.869  -57.893  52.755  1
569505  95.898  -57.900  52.735  1
569506  95.927  -57.908  52.719  1
569507  95.961  -57.918  52.706  1
569508  95.994  -57.928  52.694  1
569509  96.028  -57.939  52.683  1
569510  96.062  -57.949  52.675  1
569511  96.096  -57.959  52.668  1
569512  96.130  -57.970  52.659  1
569513  96.164  -57.980  52.648  1
569514  96.198  -57.990  52.634  1
569515  96.232  -58.001  52.620  1
569516  96.265  -58.011  52.611  1
569517  96.299  -58.021  52.605  1
569518  96.333  -58.031  52.599  1
569519  96.367  -58.042  52.590  1
569520  96.401  -58.053  52.578  1
569521  96.435  -58.062  52.562  1
569522  96.469  -58.073  52.546  1
569523  96.503  -58.084  52.529  1
569524  96.537  -58.093  52.511  1
569525  96.571  -58.104  52.491  1
569526  96.604  -58.115  52.468  1
569527  96.638  -58.125  52.445  1
569528  96.672  -58.135  52.423  1
569529  96.706  -58.146  52.401  1
569530  96.740  -58.156  52.381  1
569531  96.774  -58.166  52.366  1
569532  96.805  -58.177  52.351  1
569533  96.832  -58.187  52.334  1
569534  96.858  -58.191  52.318  1
569535  96.883  -58.197  52.301  1
569536  96.908  -58.202  52.284  1
569537  96.933  -58.206  52.265  1
569538  96.958  -58.212  52.249  1
569539  96.983  -58.217  52.230  1
569540  97.009  -58.222  52.212  1
569541  97.033  -58.227  52.194  1
569542  97.058  -58.232  52.174  1
569543  97.084  -58.237  52.152  1
569544  97.109  -58.242  52.128  1
569545  97.137  -58.243  52.102  1
569546  97.166  -58.241  52.078  1
569547  97.196  -58.238  52.051  1
569548  97.225  -58.235  52.023  1
569549  97.255  -58.232  51.997  1
569550  97.285  -58.230  51.963  1
569551  97.314  -58.228  51.925  1
569552  97.351  -58.227  51.882  1
569553  97.387  -58.227  51.836  1
569554  97.420  -58.229  51.787  1
569555  97.452  -58.232  51.734  1
569556  97.486  -58.234  51.679  1
569557  97.520  -58.235  51.621  1
569558  97.555  -58.236  51.566  1
569559  97.589  -58.236  51.514  1
569560  97.624  -58.237  51.462  1
569561  97.658  -58.238  51.409  1
569562  97.692  -58.238  51.352  1
569563  97.729  -58.240  51.293  1
569564  97.770  -58.245  51.233  1
569565  97.808  -58.249  51.174  1
569566  97.844  -58.250  51.115  1
569567  97.880  -58.252  51.057  1
569568  97.916  -58.254  51.000  1
569569  97.951  -58.256  50.945  1
569570  97.987  -58.257  50.893  1
569571  98.022  -58.259  50.843  1
569572  98.058  -58.261  50.795  1
569573  98.093  -58.262  50.751  1
569574  98.128  -58.262  50.708  1
569575  98.162  -58.263  50.666  1
569576  98.197  -58.263  50.622  1
569577  98.232  -58.263  50.576  1
569578  98.268  -58.263  50.526  1
569579  98.303  -58.264  50.477  1
569580  98.336  -58.260  50.432  1
569581  98.366  -58.254  50.389  1
569582  98.397  -58.247  50.349  1
569583  98.428  -58.241  50.313  1
569584  98.459  -58.234  50.280  1
569585  98.490  -58.228  50.250  1
569586  98.520  -58.222  50.222  1
569587  98.552  -58.216  50.195  1
569588  98.582  -58.209  50.170  1
569589  98.613  -58.203  50.147  1
569590  98.647  -58.201  50.125  1
569591  98.698  -58.201  50.105  1
569592  98.748  -58.201  50.085  1
569593  98.778  -58.204  50.066  1
569594  98.802  -58.209  50.046  1
569595  98.830  -58.225  50.027  1
569596  98.858  -58.241  50.008  1
569597  98.885  -58.256  49.992  1
569598  98.898  -58.268  49.974  1
569599  98.901  -58.277  49.953  1
569600  98.904  -58.286  49.930  1
569601  98.928  -58.285  49.905  1
569602  99.013  -58.252  49.881  1
569603  99.055  -58.244  49.856  1
569604  99.096  -58.238  49.834  1
569605  99.138  -58.231  49.813  1
569606  99.181  -58.223  49.791  1
569607  99.213  -58.215  49.766  1
569608  99.244  -58.205  49.740  1
569609  99.259  -58.209  49.714  1
569610  99.292  -58.224  49.688  1
569611  99.362  -58.237  49.662  1
569612  99.422  -58.247  49.637  1
569613  99.461  -58.255  49.610  1
569614  99.495  -58.264  49.585  1
569615  99.530  -58.272  49.559  1
569616  99.564  -58.281  49.534  1
569617  99.599  -58.290  49.508  1
569618  99.633  -58.299  49.482  1
569619  99.668  -58.308  49.455  1
569973  87.572  -54.643  57.596  4
569974  87.603  -54.666  57.596  4
569975  87.634  -54.689  57.596  4
569976  87.666  -54.712  57.594  4
569977  87.696  -54.736  57.592  4
569978  87.727  -54.759  57.589  4
569979  87.758  -54.783  57.586  4
569980  87.789  -54.806  57.583  4
569981  87.821  -54.828  57.579  4
569982  87.856  -54.844  57.574  4
569983  87.892  -54.859  57.567  4
569984  87.927  -54.875  57.559  4
569985  87.971  -54.862  57.550  4
569986  88.029  -54.859  57.540  4
569987  88.085  -54.862  57.530  4
569988  88.138  -54.878  57.515  4
569989  88.189  -54.896  57.499  4
569990  88.240  -54.915  57.480  4
569991  88.290  -54.933  57.459  4
569992  88.335  -54.948  57.436  4
569993  88.379  -54.963  57.412  4
569994  88.418  -54.978  57.382  4
569995  88.454  -54.992  57.349  4
569996  88.490  -55.007  57.312  4
569997  88.527  -55.021  57.271  4
569998  88.563  -55.035  57.226  4
569999  88.600  -55.049  57.181  4
570000  88.636  -55.063  57.133  4
570001  88.672  -55.078  57.083  4
570002  88.708  -55.092  57.033  4
570003  88.745  -55.107  56.982  4
570004  88.781  -55.120  56.932  4
570005  88.817  -55.135  56.883  4
570006  88.853  -55.149  56.833  4
570007  88.890  -55.163  56.785  4
570008  88.926  -55.177  56.739  4
570029  89.730  -55.641  55.871  1
570030  89.769  -55.665  55.852  1
570031  89.807  -55.688  55.834  1
570032  89.846  -55.712  55.817  1
570033  89.885  -55.735  55.803  1
570034  89.915  -55.754  55.791  1
570035  89.939  -55.768  55.779  1
570036  89.962  -55.782  55.769  1
570037  89.985  -55.796  55.762  1
570038  90.009  -55.811  55.756  1
570039  90.036  -55.831  55.751  1
570040  90.063  -55.850  55.746  1
570041  90.091  -55.869  55.743  1
570042  90.117  -55.884  55.742  1
570043  90.143  -55.894  55.743  1
570044  90.182  -55.904  55.745  1
570045  90.222  -55.915  55.750  1
570046  90.261  -55.925  55.754  1
570047  90.301  -55.934  55.757  1
570048  90.340  -55.945  55.762  1
570049  90.380  -55.955  55.768  1
570050  90.419  -55.965  55.774  1
570051  90.459  -55.975  55.780  1
570052  90.497  -55.987  55.784  1
570053  90.532  -55.999  55.789  1
570054  90.567  -56.012  55.794  1
570055  90.601  -56.024  55.798  1
570056  90.637  -56.037  55.803  1
570057  90.671  -56.049  55.806  1
570058  90.706  -56.062  55.807  1
570059  90.741  -56.074  55.806  1
570060  90.783  -56.085  55.801  1
570061  90.827  -56.096  55.797  1
570062  90.871  -56.106  55.792  1
570063  90.916  -56.116  55.784  1
570064  90.959  -56.127  55.775  1
570065  91.004  -56.138  55.765  1
570066  91.048  -56.148  55.755  1
570067  91.092  -56.159  55.745  1
570068  91.137  -56.169  55.728  1
570069  91.181  -56.179  55.710  1
570070  91.225  -56.190  55.692  1
570071  91.269  -56.201  55.673  1
570072  91.313  -56.211  55.653  1
570073  91.357  -56.221  55.636  1
570074  91.389  -56.227  55.620  1
570075  91.422  -56.232  55.605  1
570076  91.454  -56.238  55.588  1
570077  91.487  -56.244  55.568  1
570078  91.517  -56.257  55.548  1
570079  91.548  -56.269  55.527  1
570080  91.578  -56.282  55.503  1
570081  91.609  -56.295  55.475  1
570082  91.639  -56.307  55.447  1
570083  91.670  -56.320  55.419  1
570084  91.700  -56.333  55.391  1
570085  91.731  -56.345  55.371  1
570086  91.763  -56.357  55.354  1
570087  91.799  -56.364  55.340  1
570088  91.835  -56.370  55.329  1
570089  91.871  -56.377  55.321  1
570090  91.908  -56.384  55.316  1
570091  91.943  -56.391  55.318  1
570092  91.980  -56.398  55.324  1
570093  92.019  -56.414  55.334  1
570094  92.060  -56.436  55.345  1
570095  92.100  -56.456  55.352  1
570096  92.141  -56.477  55.364  1
570097  92.182  -56.498  55.378  1
570098  92.221  -56.528  55.390  1
570099  92.258  -56.565  55.398  1
570100  92.295  -56.602  55.401  1
570101  92.333  -56.639  55.402  1
570102  92.370  -56.676  55.401  1
570103  92.407  -56.712  55.400  1
570104  92.444  -56.749  55.401  1
570105  92.482  -56.786  55.405  1
570106  92.520  -56.805  55.408  1
570107  92.560  -56.824  55.408  1
570108  92.599  -56.843  55.408  1
570109  92.636  -56.863  55.404  1
570110  92.670  -56.884  55.396  1
570111  92.705  -56.905  55.388  1
570112  92.739  -56.926  55.381  1
570113  92.774  -56.947  55.376  1
570114  92.809  -56.968  55.372  1
570115  92.844  -56.989  55.365  1
570116  92.878  -57.009  55.354  1
570117  92.922  -57.023  55.341  1
570118  92.965  -57.037  55.332  1
570119  93.008  -57.050  55.318  1
570120  93.043  -57.059  55.303  1
570121  93.072  -57.066  55.283  1
570122  93.100  -57.072  55.263  1
570123  93.129  -57.079  55.246  1
570124  93.158  -57.086  55.234  1
570125  93.187  -57.092  55.224  1
570126  93.216  -57.099  55.209  1
570127  93.247  -57.107  55.189  1
570128  93.279  -57.119  55.165  1
570129  93.312  -57.131  55.136  1
570130  93.345  -57.143  55.103  1
570131  93.377  -57.155  55.068  1
570132  93.410  -57.167  55.032  1
570133  93.443  -57.178  54.993  1
570134  93.476  -57.191  54.954  1
570135  93.508  -57.203  54.920  1
570136  93.541  -57.215  54.888  1
570137  93.573  -57.226  54.859  1
570138  93.607  -57.234  54.832  1
570139  93.640  -57.238  54.806  1
570140  93.674  -57.241  54.779  1
570141  93.708  -57.245  54.754  1
570142  93.742  -57.249  54.729  1
570143  93.775  -57.253  54.705  1
570144  93.808  -57.257  54.682  1
570145  93.842  -57.260  54.658  1
570146  93.876  -57.264  54.635  1
570147  93.910  -57.268  54.615  1
570148  93.943  -57.272  54.595  1
570149  93.977  -57.275  54.572  1
570150  94.010  -57.279  54.545  1
570151  94.044  -57.282  54.515  1
570152  94.080  -57.301  54.480  1
570153  94.118  -57.323  54.442  1
570154  94.155  -57.346  54.405  1
570155  94.192  -57.369  54.378  1
570156  94.230  -57.391  54.364  1
570157  94.267  -57.414  54.358  1
570158  94.305  -57.437  54.342  1
570159  94.342  -57.460  54.323  1
570160  94.375  -57.475  54.307  1
570161  94.407  -57.487  54.292  1
570162  94.439  -57.500  54.280  1
570163  94.472  -57.512  54.271  1
570164  94.504  -57.524  54.261  1
570165  94.537  -57.537  54.249  1
570166  94.569  -57.549  54.238  1
570167  94.601  -57.561  54.230  1
570168  94.634  -57.574  54.225  1
570169  94.666  -57.586  54.220  1
570170  94.698  -57.599  54.211  1
570171  94.731  -57.611  54.200  1
570172  94.763  -57.623  54.184  1
570173  94.795  -57.636  54.164  1
570174  94.828  -57.648  54.141  1
570175  94.858  -57.659  54.113  1
570176  94.888  -57.669  54.084  1
570177  94.918  -57.679  54.052  1
570178  94.949  -57.689  54.018  1
570179  94.978  -57.699  53.982  1
570180  95.008  -57.709  53.946  1
570181  95.039  -57.719  53.910  1
570182  95.069  -57.729  53.870  1
570183  95.096  -57.741  53.828  1
570184  95.121  -57.752  53.784  1
570185  95.146  -57.764  53.736  1
570186  95.172  -57.777  53.683  1
570187  95.197  -57.789  53.625  1
570188  95.222  -57.801  53.568  1
570189  95.257  -57.812  53.508  1
570190  95.313  -57.821  53.448  1
570191  95.369  -57.830  53.389  1
570192  95.413  -57.834  53.331  1
570193  95.450  -57.833  53.279  1
570194  95.487  -57.833  53.228  1
570195  95.524  -57.832  53.181  1
570196  95.560  -57.831  53.137  1
570197  95.597  -57.830  53.092  1
570198  95.634  -57.830  53.042  1
570199  95.674  -57.832  52.989  1
570200  95.718  -57.836  52.941  1
570201  95.762  -57.841  52.895  1
570202  95.806  -57.846  52.850  1
570203  95.827  -57.852  52.807  1
570204  95.848  -57.857  52.767  1
570205  95.871  -57.863  52.738  1
570206  95.900  -57.871  52.717  1
570207  95.929  -57.878  52.701  1
570208  95.958  -57.886  52.689  1
570209  95.991  -57.896  52.677  1
570210  96.025  -57.906  52.668  1
570211  96.059  -57.916  52.662  1
570212  96.093  -57.927  52.654  1
570213  96.126  -57.937  52.641  1
570214  96.161  -57.947  52.625  1
570215  96.194  -57.958  52.603  1
570216  96.228  -57.968  52.588  1
570217  96.262  -57.978  52.578  1
570218  96.296  -57.989  52.572  1
570219  96.330  -57.999  52.568  1
570220  96.364  -58.009  52.563  1
570221  96.398  -58.020  52.553  1
570222  96.432  -58.030  52.541  1
570223  96.465  -58.040  52.527  1
570224  96.500  -58.051  52.512  1
570225  96.533  -58.061  52.495  1
570226  96.567  -58.071  52.474  1
570227  96.601  -58.082  52.452  1
570228  96.635  -58.092  52.429  1
570229  96.669  -58.103  52.407  1
570230  96.702  -58.112  52.388  1
570231  96.737  -58.123  52.372  1
570232  96.770  -58.134  52.358  1
570233  96.800  -58.144  52.344  1
570234  96.828  -58.155  52.331  1
570235  96.856  -58.165  52.318  1
570236  96.881  -58.170  52.306  1
570237  96.906  -58.175  52.293  1
570238  96.932  -58.180  52.279  1
570239  96.957  -58.185  52.264  1
570240  96.982  -58.191  52.248  1
570241  97.007  -58.196  52.231  1
570242  97.032  -58.200  52.213  1
570243  97.057  -58.206  52.192  1
570244  97.082  -58.211  52.171  1
570245  97.109  -58.213  52.150  1
570246  97.139  -58.210  52.126  1
570247  97.168  -58.208  52.103  1
570248  97.197  -58.206  52.077  1
570249  97.227  -58.203  52.049  1
570250  97.257  -58.200  52.022  1
570251  97.287  -58.197  51.987  1
570252  97.316  -58.195  51.949  1
570253  97.352  -58.194  51.905  1
570254  97.385  -58.197  51.858  1
570255  97.419  -58.200  51.809  1
570256  97.453  -58.200  51.756  1
570257  97.488  -58.200  51.699  1
570258  97.522  -58.201  51.640  1
570259  97.557  -58.201  51.583  1
570260  97.591  -58.202  51.528  1
570261  97.626  -58.202  51.475  1
570262  97.660  -58.203  51.421  1
570263  97.695  -58.203  51.364  1
570264  97.730  -58.205  51.306  1
570265  97.771  -58.209  51.247  1
570266  97.811  -58.215  51.187  1
570267  97.850  -58.218  51.126  1
570268  97.885  -58.220  51.065  1
570269  97.921  -58.222  51.006  1
570270  97.956  -58.223  50.949  1
570271  97.992  -58.225  50.896  1
570272  98.028  -58.227  50.846  1
570273  98.064  -58.228  50.796  1
570274  98.098  -58.229  50.750  1
570275  98.133  -58.229  50.705  1
570276  98.167  -58.229  50.662  1
570277  98.202  -58.230  50.618  1
570278  98.236  -58.230  50.572  1
570279  98.272  -58.231  50.524  1
570280  98.307  -58.231  50.478  1
570281  98.339  -58.226  50.433  1
570282  98.370  -58.220  50.389  1
570283  98.401  -58.213  50.349  1
570284  98.432  -58.207  50.314  1
570285  98.462  -58.200  50.280  1
570286  98.493  -58.194  50.249  1
570287  98.524  -58.187  50.223  1
570288  98.555  -58.181  50.197  1
570289  98.586  -58.175  50.172  1
570290  98.617  -58.169  50.149  1
570291  98.648  -58.162  50.126  1
570292  98.690  -58.161  50.104  1
570293  98.728  -58.162  50.083  1
570294  98.755  -58.175  50.063  1
570295  98.782  -58.191  50.043  1
570296  98.809  -58.206  50.025  1
570297  98.837  -58.222  50.007  1
570298  98.863  -58.238  49.991  1
570299  98.867  -58.247  49.972  1
570300  98.870  -58.256  49.951  1
570301  98.879  -58.262  49.927  1
570302  98.966  -58.228  49.902  1
570303  99.007  -58.221  49.878  1
570304  99.050  -58.214  49.856  1
570305  99.091  -58.207  49.835  1
570306  99.133  -58.200  49.814  1
570307  99.175  -58.193  49.792  1
570308  99.217  -58.186  49.768  1
570309  99.251  -58.177  49.742  1
570310  99.267  -58.180  49.715  1
570311  99.271  -58.194  49.688  1
570312  99.341  -58.208  49.662  1
570313  99.407  -58.220  49.635  1
570314  99.453  -58.228  49.609  1
570315  99.488  -58.236  49.584  1
570316  99.522  -58.245  49.557  1
570317  99.557  -58.253  49.530  1
570318  99.591  -58.263  49.505  1
570319  99.626  -58.271  49.478  1
570320  99.660  -58.280  49.452  1
570675  87.625  -54.636  57.596  4
570676  87.656  -54.659  57.597  4
570677  87.687  -54.683  57.596  4
570678  87.718  -54.706  57.594  4
570679  87.749  -54.730  57.591  4
570680  87.780  -54.753  57.589  4
570681  87.811  -54.776  57.586  4
570682  87.845  -54.793  57.584  4
570683  87.881  -54.809  57.578  4
570684  87.916  -54.824  57.572  4
570685  87.952  -54.839  57.564  4
570686  87.987  -54.855  57.557  4
570687  88.048  -54.819  57.549  4
570688  88.105  -54.822  57.538  4
570689  88.162  -54.826  57.525  4
570690  88.213  -54.843  57.510  4
570691  88.262  -54.860  57.494  4
570692  88.306  -54.875  57.475  4
570693  88.350  -54.891  57.455  4
570694  88.395  -54.906  57.429  4
570695  88.432  -54.920  57.401  4
570696  88.469  -54.934  57.370  4
570697  88.505  -54.949  57.334  4
570698  88.542  -54.963  57.294  4
570699  88.578  -54.977  57.250  4
570700  88.614  -54.991  57.205  4
570701  88.650  -55.006  57.157  4
570702  88.687  -55.020  57.107  4
570703  88.723  -55.035  57.056  4
570704  88.760  -55.048  57.005  4
570705  88.796  -55.063  56.955  4
570706  88.832  -55.077  56.905  4
570707  88.869  -55.091  56.855  4
570708  88.905  -55.105  56.806  4
570709  88.941  -55.119  56.759  4
570732  89.829  -55.656  55.831  1
570733  89.867  -55.680  55.815  1
570734  89.906  -55.703  55.800  1
570735  89.935  -55.721  55.787  1
570736  89.958  -55.735  55.775  1
570737  89.981  -55.749  55.764  1
570738  90.005  -55.763  55.757  1
570739  90.028  -55.777  55.751  1
570740  90.054  -55.795  55.745  1
570741  90.081  -55.815  55.741  1
570742  90.108  -55.834  55.739  1
570743  90.135  -55.850  55.738  1
570744  90.161  -55.861  55.739  1
570745  90.193  -55.871  55.742  1
570746  90.233  -55.881  55.747  1
570747  90.273  -55.891  55.751  1
570748  90.312  -55.901  55.755  1
570749  90.352  -55.912  55.760  1
570750  90.392  -55.922  55.768  1
570751  90.432  -55.931  55.776  1
570752  90.471  -55.942  55.783  1
570753  90.511  -55.952  55.790  1
570754  90.550  -55.962  55.797  1
570755  90.587  -55.974  55.804  1
570756  90.621  -55.987  55.812  1
570757  90.657  -55.999  55.819  1
570758  90.691  -56.012  55.825  1
570759  90.726  -56.024  55.829  1
570760  90.761  -56.037  55.831  1
570761  90.796  -56.049  55.829  1
570762  90.839  -56.059  55.826  1
570763  90.883  -56.070  55.821  1
570764  90.928  -56.081  55.814  1
570765  90.971  -56.091  55.806  1
570766  91.016  -56.102  55.798  1
570767  91.060  -56.113  55.791  1
570768  91.104  -56.122  55.780  1
570769  91.149  -56.133  55.761  1
570770  91.192  -56.144  55.740  1
570771  91.237  -56.154  55.717  1
570772  91.281  -56.165  55.695  1
570773  91.325  -56.175  55.673  1
570774  91.361  -56.182  55.653  1
570775  91.393  -56.188  55.633  1
570776  91.426  -56.194  55.613  1
570777  91.458  -56.199  55.594  1
570778  91.491  -56.205  55.575  1
570779  91.522  -56.214  55.557  1
570780  91.553  -56.227  55.536  1
570781  91.583  -56.240  55.511  1
570782  91.613  -56.253  55.483  1
570783  91.644  -56.266  55.454  1
570784  91.674  -56.279  55.426  1
570785  91.705  -56.291  55.398  1
570786  91.737  -56.302  55.375  1
570787  91.773  -56.310  55.357  1
570788  91.809  -56.317  55.343  1
570789  91.845  -56.323  55.330  1
570790  91.881  -56.330  55.320  1
570791  91.917  -56.337  55.316  1
570792  91.953  -56.344  55.318  1
570793  91.990  -56.351  55.328  1
570794  92.028  -56.364  55.343  1
570795  92.069  -56.385  55.357  1
570796  92.109  -56.406  55.368  1
570797  92.150  -56.426  55.381  1
570798  92.189  -56.459  55.393  1
570799  92.226  -56.496  55.401  1
570800  92.263  -56.533  55.404  1
570801  92.300  -56.570  55.402  1
570802  92.337  -56.607  55.400  1
570803  92.374  -56.643  55.399  1
570804  92.412  -56.680  55.398  1
570805  92.449  -56.718  55.400  1
570806  92.487  -56.749  55.405  1
570807  92.526  -56.769  55.409  1
570808  92.565  -56.788  55.409  1
570809  92.604  -56.807  55.405  1
570810  92.642  -56.827  55.396  1
570811  92.676  -56.848  55.384  1
570812  92.711  -56.868  55.373  1
570813  92.745  -56.890  55.371  1
570814  92.780  -56.910  55.370  1
570815  92.815  -56.931  55.370  1
570816  92.850  -56.952  55.367  1
570817  92.887  -56.971  55.362  1
570818  92.930  -56.984  55.357  1
570819  92.973  -56.998  55.352  1
570820  93.016  -57.012  55.342  1
570821  93.054  -57.022  55.328  1
570822  93.083  -57.029  55.311  1
570823  93.112  -57.036  55.294  1
570824  93.141  -57.042  55.279  1
570825  93.169  -57.049  55.268  1
570826  93.199  -57.055  55.259  1
570827  93.227  -57.062  55.244  1
570828  93.258  -57.071  55.223  1
570829  93.291  -57.083  55.196  1
570830  93.324  -57.095  55.167  1
570831  93.356  -57.106  55.132  1
570832  93.389  -57.119  55.096  1
570833  93.422  -57.131  55.059  1
570834  93.454  -57.142  55.019  1
570835  93.487  -57.154  54.977  1
570836  93.519  -57.166  54.941  1
570837  93.552  -57.178  54.908  1
570838  93.585  -57.190  54.878  1
570839  93.618  -57.202  54.848  1
570840  93.651  -57.210  54.818  1
570841  93.685  -57.214  54.787  1
570842  93.718  -57.217  54.759  1
570843  93.752  -57.221  54.732  1
570844  93.785  -57.225  54.707  1
570845  93.819  -57.228  54.682  1
570846  93.853  -57.232  54.657  1
570847  93.887  -57.236  54.631  1
570848  93.920  -57.240  54.609  1
570849  93.954  -57.244  54.588  1
570850  93.987  -57.247  54.567  1
570851  94.021  -57.251  54.545  1
570852  94.055  -57.255  54.518  1
570853  94.090  -57.271  54.486  1
570854  94.128  -57.294  54.448  1
570855  94.165  -57.316  54.409  1
570856  94.202  -57.339  54.372  1
570857  94.240  -57.362  54.343  1
570858  94.277  -57.385  54.326  1
570859  94.315  -57.407  54.312  1
570860  94.350  -57.428  54.293  1
570861  94.383  -57.440  54.276  1
570862  94.415  -57.453  54.260  1
570863  94.448  -57.465  54.247  1
570864  94.480  -57.477  54.238  1
570865  94.512  -57.490  54.226  1
570866  94.544  -57.502  54.219  1
570867  94.577  -57.515  54.212  1
570868  94.609  -57.527  54.205  1
570869  94.641  -57.539  54.198  1
570870  94.674  -57.552  54.190  1
570871  94.706  -57.564  54.183  1
570872  94.739  -57.577  54.173  1
570873  94.771  -57.589  54.159  1
570874  94.803  -57.601  54.142  1
570875  94.835  -57.614  54.121  1
570876  94.867  -57.626  54.095  1
570877  94.897  -57.636  54.067  1
570878  94.927  -57.646  54.035  1
570879  94.958  -57.656  54.001  1
570880  94.988  -57.666  53.965  1
570881  95.018  -57.677  53.928  1
570882  95.048  -57.686  53.892  1
570883  95.078  -57.696  53.853  1
570884  95.108  -57.706  53.813  1
570885  95.137  -57.717  53.770  1
570886  95.162  -57.729  53.723  1
570887  95.187  -57.741  53.673  1
570888  95.212  -57.753  53.617  1
570889  95.238  -57.765  53.561  1
570890  95.263  -57.777  53.501  1
570891  95.316  -57.787  53.441  1
570892  95.372  -57.796  53.380  1
570893  95.416  -57.799  53.322  1
570894  95.454  -57.799  53.267  1
570895  95.490  -57.798  53.218  1
570896  95.527  -57.797  53.171  1
570897  95.564  -57.796  53.125  1
570898  95.601  -57.796  53.081  1
570899  95.641  -57.798  53.034  1
570900  95.685  -57.803  52.984  1
570901  95.729  -57.808  52.937  1
570902  95.772  -57.812  52.889  1
570903  95.811  -57.818  52.841  1
570904  95.832  -57.823  52.794  1
570905  95.853  -57.828  52.752  1
570906  95.874  -57.834  52.721  1
570907  95.902  -57.841  52.700  1
570908  95.932  -57.849  52.685  1
570909  95.961  -57.856  52.672  1
570910  95.989  -57.864  52.662  1
570911  96.022  -57.874  52.657  1
570912  96.055  -57.883  52.645  1
570913  96.090  -57.894  52.629  1
570914  96.123  -57.905  52.611  1
570915  96.157  -57.915  52.592  1
570916  96.191  -57.925  52.571  1
570917  96.225  -57.935  52.557  1
570918  96.259  -57.946  52.545  1
570919  96.293  -57.956  52.537  1
570920  96.327  -57.966  52.533  1
570921  96.361  -57.977  52.529  1
570922  96.394  -57.987  52.523  1
570923  96.429  -57.997  52.515  1
570924  96.462  -58.008  52.506  1
570925  96.496  -58.018  52.493  1
570926  96.530  -58.028  52.474  1
570927  96.564  -58.039  52.454  1
570928  96.598  -58.049  52.433  1
570929  96.631  -58.059  52.411  1
570930  96.666  -58.070  52.389  1
570931  96.699  -58.080  52.372  1
570932  96.733  -58.090  52.359  1
570933  96.767  -58.101  52.345  1
570934  96.795  -58.112  52.334  1
570935  96.824  -58.123  52.324  1
570936  96.852  -58.134  52.314  1
570937  96.880  -58.144  52.304  1
570938  96.905  -58.149  52.295  1
570939  96.930  -58.154  52.286  1
570940  96.955  -58.159  52.274  1
570941  96.980  -58.164  52.261  1
570942  97.005  -58.169  52.246  1
570943  97.030  -58.174  52.229  1
570944  97.055  -58.179  52.209  1
570945  97.081  -58.184  52.189  1
570946  97.111  -58.181  52.169  1
570947  97.141  -58.178  52.148  1
570948  97.170  -58.176  52.125  1
570949  97.199  -58.173  52.100  1
570950  97.229  -58.171  52.074  1
570951  97.259  -58.168  52.048  1
570952  97.288  -58.165  52.013  1
570953  97.318  -58.163  51.973  1
570954  97.352  -58.164  51.928  1
570955  97.386  -58.165  51.880  1
570956  97.421  -58.165  51.830  1
570957  97.455  -58.165  51.775  1
570958  97.490  -58.165  51.718  1
570959  97.524  -58.166  51.659  1
570960  97.559  -58.167  51.601  1
570961  97.593  -58.167  51.544  1
570962  97.628  -58.168  51.486  1
570963  97.662  -58.169  51.430  1
570964  97.697  -58.169  51.374  1
570965  97.731  -58.169  51.318  1
570966  97.772  -58.175  51.259  1
570967  97.812  -58.179  51.198  1
570968  97.853  -58.184  51.135  1
570969  97.890  -58.187  51.073  1
570970  97.926  -58.189  51.011  1
570971  97.962  -58.191  50.954  1
570972  97.998  -58.193  50.900  1
570973  98.033  -58.194  50.849  1
570974  98.069  -58.196  50.797  1
570975  98.103  -58.197  50.748  1
570976  98.138  -58.197  50.702  1
570977  98.172  -58.197  50.658  1
570978  98.207  -58.197  50.615  1
570979  98.241  -58.197  50.572  1
570980  98.276  -58.198  50.526  1
570981  98.311  -58.198  50.480  1
570982  98.343  -58.192  50.434  1
570983  98.373  -58.186  50.391  1
570984  98.405  -58.179  50.351  1
570985  98.435  -58.173  50.315  1
570986  98.466  -58.166  50.280  1
570987  98.497  -58.160  50.250  1
570988  98.528  -58.153  50.222  1
570989  98.559  -58.147  50.195  1
570990  98.589  -58.140  50.171  1
570991  98.621  -58.134  50.148  1
570992  98.651  -58.128  50.124  1
570993  98.679  -58.125  50.102  1
570994  98.706  -58.140  50.081  1
570995  98.733  -58.156  50.061  1
570996  98.761  -58.172  50.042  1
570997  98.789  -58.188  50.023  1
570998  98.816  -58.204  50.006  1
570999  98.833  -58.216  49.989  1
571000  98.836  -58.226  49.972  1
571001  98.839  -58.235  49.951  1
571002  98.919  -58.205  49.927  1
571003  98.960  -58.197  49.902  1
571004  99.002  -58.191  49.878  1
571005  99.044  -58.184  49.857  1
571006  99.086  -58.176  49.837  1
571007  99.128  -58.169  49.816  1
571008  99.170  -58.162  49.794  1
571009  99.212  -58.156  49.770  1
571010  99.254  -58.148  49.744  1
571011  99.276  -58.150  49.716  1
571012  99.278  -58.165  49.689  1
571013  99.320  -58.178  49.662  1
571014  99.390  -58.192  49.635  1
571015  99.444  -58.200  49.608  1
571016  99.480  -58.209  49.582  1
571017  99.515  -58.217  49.555  1
571018  99.549  -58.226  49.528  1
571019  99.584  -58.234  49.502  1
571020  99.618  -58.244  49.475  1
571021  99.653  -58.252  49.448  1
571377  87.678  -54.630  57.598  4
571378  87.709  -54.653  57.596  4
571379  87.740  -54.677  57.595  4
571380  87.771  -54.700  57.594  4
571381  87.801  -54.724  57.592  4
571382  87.835  -54.743  57.590  4
571383  87.870  -54.759  57.587  4
571384  87.905  -54.774  57.583  4
571385  87.941  -54.789  57.576  4
571386  87.976  -54.804  57.570  4
571387  88.011  -54.819  57.563  4
571388  88.068  -54.780  57.556  4
571389  88.124  -54.783  57.545  4
571390  88.181  -54.787  57.533  4
571391  88.233  -54.787  57.520  4
571392  88.277  -54.802  57.508  4
571393  88.322  -54.818  57.495  4
571394  88.366  -54.833  57.475  4
571395  88.410  -54.848  57.447  4
571396  88.448  -54.862  57.420  4
571397  88.484  -54.877  57.390  4
571398  88.520  -54.891  57.355  4
571399  88.556  -54.905  57.314  4
571400  88.593  -54.919  57.271  4
571401  88.629  -54.934  57.226  4
571402  88.666  -54.948  57.178  4
571403  88.702  -54.963  57.128  4
571404  88.738  -54.976  57.077  4
571405  88.774  -54.991  57.026  4
571406  88.811  -55.005  56.976  4
571407  88.847  -55.019  56.925  4
571408  88.885  -55.039  56.875  4
571409  88.923  -55.063  56.825  4
571410  88.962  -55.086  56.777  4
571434  89.888  -55.648  55.813  1
571435  89.927  -55.671  55.798  1
571436  89.954  -55.687  55.784  1
571437  89.977  -55.702  55.772  1
571438  90.000  -55.715  55.761  1
571439  90.023  -55.730  55.752  1
571440  90.047  -55.744  55.746  1
571441  90.072  -55.760  55.741  1
571442  90.099  -55.779  55.737  1
571443  90.126  -55.799  55.735  1
571444  90.153  -55.817  55.735  1
571445  90.179  -55.827  55.736  1
571446  90.205  -55.837  55.740  1
571447  90.245  -55.847  55.745  1
571448  90.285  -55.858  55.750  1
571449  90.324  -55.868  55.756  1
571450  90.364  -55.878  55.762  1
571451  90.403  -55.888  55.771  1
571452  90.443  -55.898  55.780  1
571453  90.483  -55.909  55.789  1
571454  90.523  -55.919  55.798  1
571455  90.562  -55.928  55.807  1
571456  90.602  -55.939  55.816  1
571457  90.642  -55.949  55.827  1
571458  90.677  -55.961  55.838  1
571459  90.712  -55.974  55.847  1
571460  90.746  -55.986  55.855  1
571461  90.781  -55.999  55.859  1
571462  90.816  -56.011  55.860  1
571463  90.851  -56.024  55.858  1
571464  90.895  -56.034  55.853  1
571465  90.939  -56.045  55.847  1
571466  90.983  -56.056  55.839  1
571467  91.028  -56.066  55.831  1
571468  91.072  -56.076  55.826  1
571469  91.116  -56.087  55.817  1
571470  91.160  -56.097  55.797  1
571471  91.205  -56.108  55.770  1
571472  91.249  -56.119  55.743  1
571473  91.293  -56.128  55.719  1
571474  91.332  -56.138  55.695  1
571475  91.365  -56.143  55.674  1
571476  91.397  -56.149  55.652  1
571477  91.430  -56.154  55.628  1
571478  91.462  -56.160  55.603  1
571479  91.495  -56.166  55.582  1
571480  91.527  -56.172  55.562  1
571481  91.558  -56.185  55.540  1
571482  91.588  -56.198  55.515  1
571483  91.618  -56.211  55.487  1
571484  91.649  -56.224  55.459  1
571485  91.679  -56.236  55.432  1
571486  91.711  -56.248  55.405  1
571487  91.746  -56.255  55.382  1
571488  91.783  -56.262  55.364  1
571489  91.819  -56.269  55.348  1
571490  91.855  -56.276  55.333  1
571491  91.891  -56.283  55.321  1
571492  91.927  -56.290  55.315  1
571493  91.963  -56.297  55.317  1
571494  92.000  -56.304  55.326  1
571495  92.037  -56.313  55.341  1
571496  92.077  -56.335  55.355  1
571497  92.118  -56.355  55.368  1
571498  92.156  -56.390  55.380  1
571499  92.193  -56.426  55.388  1
571500  92.230  -56.464  55.391  1
571501  92.268  -56.501  55.388  1
571502  92.305  -56.538  55.380  1
571503  92.342  -56.574  55.380  1
571504  92.379  -56.611  55.382  1
571505  92.417  -56.649  55.383  1
571506  92.454  -56.685  55.385  1
571507  92.492  -56.713  55.390  1
571508  92.531  -56.733  55.396  1
571509  92.570  -56.752  55.397  1
571510  92.609  -56.771  55.390  1
571511  92.648  -56.790  55.379  1
571512  92.683  -56.811  55.367  1
571513  92.717  -56.832  55.355  1
571514  92.752  -56.852  55.363  1
571515  92.786  -56.874  55.368  1
571516  92.821  -56.894  55.371  1
571517  92.856  -56.915  55.372  1
571518  92.895  -56.932  55.372  1
571519  92.938  -56.946  55.372  1
571520  92.981  -56.959  55.369  1
571521  93.024  -56.973  55.361  1
571522  93.065  -56.985  55.349  1
571523  93.094  -56.992  55.334  1
571524  93.123  -56.999  55.320  1
571525  93.152  -57.005  55.305  1
571526  93.181  -57.012  55.295  1
571527  93.210  -57.018  55.285  1
571528  93.238  -57.025  55.269  1
571529  93.270  -57.034  55.247  1
571530  93.302  -57.047  55.219  1
571531  93.335  -57.058  55.189  1
571532  93.368  -57.070  55.153  1
571533  93.401  -57.082  55.115  1
571534  93.433  -57.094  55.076  1
571535  93.466  -57.106  55.039  1
571536  93.498  -57.118  55.002  1
571537  93.531  -57.129  54.968  1
571538  93.564  -57.141  54.934  1
571539  93.596  -57.153  54.902  1
571540  93.629  -57.165  54.871  1
571541  93.662  -57.177  54.840  1
571542  93.695  -57.186  54.807  1
571543  93.728  -57.190  54.778  1
571544  93.762  -57.194  54.749  1
571545  93.796  -57.197  54.721  1
571546  93.830  -57.200  54.693  1
571547  93.863  -57.204  54.664  1
571548  93.897  -57.208  54.631  1
571549  93.930  -57.212  54.605  1
571550  93.964  -57.216  54.581  1
571551  93.998  -57.219  54.560  1
571552  94.032  -57.223  54.539  1
571553  94.065  -57.227  54.514  1
571554  94.101  -57.241  54.486  1
571555  94.138  -57.264  54.450  1
571556  94.175  -57.287  54.412  1
571557  94.213  -57.310  54.371  1
571558  94.250  -57.332  54.333  1
571559  94.287  -57.356  54.304  1
571560  94.325  -57.379  54.286  1
571561  94.358  -57.393  54.268  1
571562  94.391  -57.406  54.250  1
571563  94.423  -57.418  54.233  1
571564  94.455  -57.431  54.217  1
571565  94.487  -57.443  54.206  1
571566  94.520  -57.455  54.195  1
571567  94.552  -57.468  54.188  1
571568  94.584  -57.480  54.180  1
571569  94.617  -57.493  54.172  1
571570  94.649  -57.505  54.166  1
571571  94.681  -57.517  54.160  1
571572  94.714  -57.530  54.153  1
571573  94.746  -57.542  54.145  1
571574  94.778  -57.554  54.133  1
571575  94.811  -57.567  54.118  1
571576  94.843  -57.579  54.100  1
571577  94.876  -57.592  54.077  1
571578  94.906  -57.603  54.050  1
571579  94.936  -57.613  54.019  1
571580  94.967  -57.623  53.985  1
571581  94.997  -57.633  53.948  1
571582  95.027  -57.643  53.910  1
571583  95.057  -57.653  53.871  1
571584  95.087  -57.664  53.835  1
571585  95.117  -57.673  53.797  1
571586  95.147  -57.683  53.755  1
571587  95.178  -57.694  53.709  1
571588  95.203  -57.706  53.659  1
571589  95.228  -57.717  53.608  1
571590  95.253  -57.730  53.552  1
571591  95.278  -57.742  53.494  1
571592  95.320  -57.752  53.434  1
571593  95.376  -57.762  53.373  1
571594  95.420  -57.765  53.314  1
571595  95.457  -57.764  53.256  1
571596  95.494  -57.764  53.207  1
571597  95.531  -57.763  53.158  1
571598  95.567  -57.762  53.111  1
571599  95.608  -57.764  53.066  1
571600  95.652  -57.769  53.021  1
571601  95.696  -57.774  52.974  1
571602  95.740  -57.779  52.929  1
571603  95.783  -57.783  52.881  1
571604  95.817  -57.789  52.831  1
571605  95.838  -57.794  52.782  1
571606  95.859  -57.799  52.739  1
571607  95.880  -57.805  52.705  1
571608  95.905  -57.811  52.680  1
571609  95.934  -57.819  52.661  1
571610  95.963  -57.827  52.645  1
571611  95.992  -57.834  52.632  1
571612  96.021  -57.842  52.623  1
571613  96.052  -57.851  52.610  1
571614  96.086  -57.861  52.594  1
571615  96.120  -57.872  52.577  1
571616  96.154  -57.882  52.560  1
571617  96.188  -57.893  52.542  1
571618  96.222  -57.902  52.527  1
571619  96.256  -57.913  52.515  1
571620  96.290  -57.924  52.507  1
571621  96.323  -57.934  52.501  1
571622  96.357  -57.944  52.495  1
571623  96.391  -57.955  52.491  1
571624  96.425  -57.965  52.484  1
571625  96.459  -57.975  52.473  1
571626  96.493  -57.986  52.461  1
571627  96.527  -57.996  52.448  1
571628  96.560  -58.006  52.434  1
571629  96.594  -58.016  52.414  1
571630  96.628  -58.027  52.391  1
571631  96.662  -58.037  52.370  1
571632  96.696  -58.047  52.352  1
571633  96.730  -58.058  52.339  1
571634  96.762  -58.068  52.329  1
571635  96.791  -58.079  52.319  1
571636  96.819  -58.090  52.311  1
571637  96.847  -58.101  52.301  1
571638  96.875  -58.112  52.294  1
571639  96.903  -58.122  52.289  1
571640  96.928  -58.128  52.285  1
571641  96.953  -58.133  52.278  1
571642  96.978  -58.137  52.269  1
571643  97.004  -58.143  52.257  1
571644  97.029  -58.148  52.243  1
571645  97.054  -58.153  52.225  1
571646  97.083  -58.151  52.205  1
571647  97.113  -58.149  52.185  1
571648  97.142  -58.146  52.166  1
571649  97.172  -58.144  52.144  1
571650  97.202  -58.141  52.121  1
571651  97.231  -58.138  52.100  1
571652  97.260  -58.136  52.074  1
571653  97.290  -58.132  52.037  1
571654  97.320  -58.128  51.997  1
571655  97.354  -58.131  51.951  1
571656  97.389  -58.130  51.902  1
571657  97.423  -58.131  51.851  1
571658  97.458  -58.131  51.794  1
571659  97.492  -58.131  51.737  1
571660  97.527  -58.132  51.679  1
571661  97.561  -58.132  51.620  1
571662  97.596  -58.133  51.560  1
571663  97.630  -58.134  51.498  1
571664  97.665  -58.134  51.439  1
571665  97.699  -58.134  51.384  1
571666  97.734  -58.135  51.329  1
571667  97.773  -58.139  51.271  1
571668  97.813  -58.144  51.208  1
571669  97.854  -58.149  51.142  1
571670  97.894  -58.154  51.079  1
571671  97.932  -58.156  51.016  1
571672  97.967  -58.159  50.958  1
571673  98.003  -58.160  50.904  1
571674  98.038  -58.162  50.851  1
571675  98.074  -58.163  50.797  1
571676  98.108  -58.163  50.747  1
571677  98.143  -58.164  50.700  1
571678  98.177  -58.164  50.656  1
571679  98.211  -58.164  50.614  1
571680  98.246  -58.165  50.574  1
571681  98.281  -58.165  50.528  1
571682  98.315  -58.164  50.482  1
571683  98.346  -58.158  50.436  1
571684  98.377  -58.152  50.394  1
571685  98.408  -58.145  50.354  1
571686  98.439  -58.139  50.317  1
571687  98.469  -58.132  50.281  1
571688  98.501  -58.126  50.251  1
571689  98.531  -58.119  50.223  1
571690  98.563  -58.117  50.196  1
571691  98.593  -58.116  50.172  1
571692  98.625  -58.115  50.149  1
571693  98.656  -58.115  50.124  1
571694  98.672  -58.115  50.102  1
571695  98.686  -58.122  50.080  1
571696  98.713  -58.138  50.060  1
571697  98.740  -58.154  50.041  1
571698  98.768  -58.170  50.023  1
571699  98.795  -58.186  50.005  1
571700  98.801  -58.196  49.988  1
571701  98.805  -58.205  49.970  1
571702  98.871  -58.181  49.949  1
571703  98.913  -58.174  49.926  1
571704  98.955  -58.167  49.903  1
571705  98.997  -58.160  49.880  1
571706  99.039  -58.153  49.860  1
571707  99.081  -58.146  49.840  1
571708  99.123  -58.139  49.819  1
571709  99.165  -58.131  49.797  1
571710  99.206  -58.125  49.773  1
571711  99.246  -58.121  49.747  1
571712  99.284  -58.120  49.718  1
571713  99.286  -58.134  49.691  1
571714  99.299  -58.150  49.663  1
571715  99.368  -58.162  49.635  1
571716  99.430  -58.173  49.608  1
571717  99.473  -58.181  49.581  1
571718  99.507  -58.190  49.554  1
571719  99.542  -58.198  49.526  1
571720  99.576  -58.207  49.500  1
571721  99.611  -58.216  49.472  1
571722  99.645  -58.225  49.444  1
571723  99.680  -58.233  49.418  1
572078  87.699  -54.600  57.598  4
572079  87.730  -54.624  57.597  4
572080  87.761  -54.647  57.597  4
572081  87.792  -54.671  57.596  4
572082  87.824  -54.693  57.594  4
572083  87.859  -54.708  57.592  4
572084  87.895  -54.723  57.589  4
572085  87.930  -54.739  57.586  4
572086  87.965  -54.754  57.581  4
572087  88.001  -54.769  57.574  4
572088  88.036  -54.784  57.568  4
572089  88.084  -54.762  57.561  4
572090  88.144  -54.743  57.552  4
572091  88.200  -54.747  57.540  4
572092  88.255  -54.750  57.529  4
572093  88.292  -54.744  57.518  4
572094  88.337  -54.760  57.506  4
572095  88.382  -54.775  57.488  4
572096  88.426  -54.790  57.461  4
572097  88.462  -54.805  57.434  4
572098  88.499  -54.819  57.403  4
572099  88.535  -54.833  57.369  4
572100  88.571  -54.847  57.330  4
572101  88.608  -54.862  57.289  4
572102  88.644  -54.876  57.245  4
572103  88.680  -54.891  57.198  4
572104  88.716  -54.904  57.148  4
572105  88.753  -54.919  57.097  4
572106  88.790  -54.937  57.046  4
572107  88.829  -54.960  56.995  4
572108  88.868  -54.984  56.945  4
572109  88.906  -55.007  56.894  4
572110  88.945  -55.031  56.844  4
572111  88.983  -55.054  56.795  4
572137  89.973  -55.654  55.784  1
572138  89.996  -55.668  55.772  1
572139  90.019  -55.682  55.761  1
572140  90.042  -55.696  55.752  1
572141  90.065  -55.711  55.745  1
572142  90.089  -55.724  55.740  1
572143  90.116  -55.744  55.736  1
572144  90.144  -55.763  55.733  1
572145  90.171  -55.783  55.732  1
572146  90.196  -55.793  55.735  1
572147  90.222  -55.804  55.741  1
572148  90.257  -55.814  55.745  1
572149  90.297  -55.824  55.751  1
572150  90.336  -55.834  55.757  1
572151  90.376  -55.844  55.765  1
572152  90.415  -55.855  55.776  1
572153  90.455  -55.865  55.786  1
572154  90.495  -55.875  55.797  1
572155  90.534  -55.885  55.809  1
572156  90.574  -55.895  55.821  1
572157  90.614  -55.906  55.834  1
572158  90.653  -55.915  55.850  1
572159  90.693  -55.925  55.864  1
572160  90.732  -55.936  55.875  1
572161  90.766  -55.949  55.884  1
572162  90.801  -55.961  55.892  1
572163  90.836  -55.974  55.895  1
572164  90.871  -55.986  55.895  1
572165  90.907  -55.999  55.889  1
572166  90.951  -56.009  55.882  1
572167  90.996  -56.019  55.874  1
572168  91.040  -56.030  55.865  1
572169  91.084  -56.041  55.861  1
572170  91.129  -56.051  55.854  1
572171  91.172  -56.062  55.832  1
572172  91.217  -56.072  55.802  1
572173  91.261  -56.082  55.771  1
572174  91.304  -56.093  55.744  1
572175  91.336  -56.098  55.718  1
572176  91.369  -56.103  55.697  1
572177  91.401  -56.110  55.675  1
572178  91.434  -56.115  55.649  1
572179  91.466  -56.121  55.620  1
572180  91.499  -56.126  55.596  1
572181  91.531  -56.132  55.569  1
572182  91.562  -56.144  55.542  1
572183  91.592  -56.157  55.515  1
572184  91.623  -56.169  55.487  1
572185  91.653  -56.182  55.460  1
572186  91.684  -56.194  55.434  1
572187  91.720  -56.201  55.411  1
572188  91.756  -56.208  55.394  1
572189  91.793  -56.215  55.378  1
572190  91.829  -56.222  55.358  1
572191  91.865  -56.229  55.339  1
572192  91.901  -56.235  55.325  1
572193  91.937  -56.242  55.315  1
572194  91.974  -56.250  55.313  1
572195  92.009  -56.257  55.319  1
572196  92.046  -56.263  55.331  1
572197  92.086  -56.284  55.343  1
572198  92.124  -56.321  55.356  1
572199  92.161  -56.357  55.366  1
572200  92.198  -56.395  55.371  1
572201  92.235  -56.432  55.370  1
572202  92.273  -56.469  55.365  1
572203  92.310  -56.505  55.357  1
572204  92.347  -56.542  55.358  1
572205  92.384  -56.580  55.362  1
572206  92.422  -56.616  55.364  1
572207  92.459  -56.653  55.366  1
572208  92.497  -56.677  55.372  1
572209  92.536  -56.696  55.375  1
572210  92.576  -56.715  55.373  1
572211  92.615  -56.734  55.368  1
572212  92.654  -56.753  55.360  1
572213  92.689  -56.774  55.353  1
572214  92.723  -56.795  55.359  1
572215  92.758  -56.816  55.369  1
572216  92.793  -56.837  55.375  1
572217  92.827  -56.858  55.380  1
572218  92.862  -56.879  55.381  1
572219  92.903  -56.894  55.381  1
572220  92.946  -56.908  55.383  1
572221  92.989  -56.921  55.380  1
572222  93.032  -56.934  55.373  1
572223  93.075  -56.948  55.363  1
572224  93.105  -56.955  55.352  1
572225  93.134  -56.962  55.341  1
572226  93.163  -56.968  55.327  1
572227  93.192  -56.975  55.317  1
572228  93.221  -56.981  55.304  1
572229  93.250  -56.987  55.286  1
572230  93.281  -56.998  55.264  1
572231  93.314  -57.010  55.236  1
572232  93.346  -57.022  55.206  1
572233  93.379  -57.034  55.171  1
572234  93.412  -57.046  55.134  1
572235  93.444  -57.057  55.097  1
572236  93.477  -57.069  55.062  1
572237  93.510  -57.081  55.027  1
572238  93.543  -57.093  54.993  1
572239  93.575  -57.105  54.958  1
572240  93.608  -57.117  54.926  1
572241  93.640  -57.128  54.895  1
572242  93.673  -57.141  54.864  1
572243  93.706  -57.153  54.831  1
572244  93.739  -57.162  54.799  1
572245  93.773  -57.166  54.768  1
572246  93.806  -57.169  54.740  1
572247  93.840  -57.173  54.712  1
572248  93.873  -57.177  54.683  1
572249  93.907  -57.180  54.650  1
572250  93.941  -57.184  54.618  1
572251  93.975  -57.188  54.587  1
572252  94.008  -57.191  54.556  1
572253  94.042  -57.195  54.527  1
572254  94.075  -57.199  54.500  1
572255  94.111  -57.212  54.477  1
572256  94.148  -57.235  54.448  1
572257  94.186  -57.257  54.414  1
572258  94.223  -57.280  54.375  1
572259  94.260  -57.304  54.333  1
572260  94.297  -57.326  54.290  1
572261  94.334  -57.347  54.264  1
572262  94.366  -57.359  54.246  1
572263  94.398  -57.371  54.227  1
572264  94.430  -57.384  54.208  1
572265  94.463  -57.396  54.190  1
572266  94.495  -57.409  54.175  1
572267  94.528  -57.421  54.164  1
572268  94.560  -57.433  54.155  1
572269  94.592  -57.446  54.146  1
572270  94.624  -57.458  54.138  1
572271  94.657  -57.470  54.132  1
572272  94.689  -57.483  54.127  1
572273  94.721  -57.495  54.120  1
572274  94.754  -57.508  54.114  1
572275  94.786  -57.520  54.104  1
572276  94.819  -57.532  54.090  1
572277  94.851  -57.545  54.074  1
572278  94.883  -57.558  54.054  1
572279  94.915  -57.570  54.029  1
572280  94.946  -57.580  54.000  1
572281  94.976  -57.590  53.969  1
572282  95.006  -57.600  53.934  1
572283  95.036  -57.611  53.896  1
572284  95.066  -57.620  53.856  1
572285  95.097  -57.630  53.816  1
572286  95.127  -57.641  53.776  1
572287  95.157  -57.651  53.734  1
572288  95.187  -57.661  53.690  1
572289  95.217  -57.670  53.643  1
572290  95.244  -57.683  53.592  1
572291  95.269  -57.695  53.538  1
572292  95.294  -57.706  53.482  1
572293  95.324  -57.718  53.425  1
572294  95.380  -57.727  53.366  1
572295  95.424  -57.730  53.306  1
572296  95.461  -57.730  53.247  1
572297  95.497  -57.729  53.194  1
572298  95.534  -57.728  53.144  1
572299  95.576  -57.731  53.095  1
572300  95.619  -57.736  53.048  1
572301  95.663  -57.740  53.004  1
572302  95.706  -57.746  52.961  1
572303  95.750  -57.750  52.917  1
572304  95.794  -57.755  52.870  1
572305  95.822  -57.760  52.821  1
572306  95.843  -57.765  52.772  1
572307  95.864  -57.771  52.728  1
572308  95.885  -57.777  52.690  1
572309  95.907  -57.783  52.660  1
572310  95.936  -57.790  52.636  1
572311  95.965  -57.798  52.615  1
572312  95.994  -57.805  52.599  1
572313  96.023  -57.813  52.585  1
572314  96.052  -57.821  52.572  1
572315  96.083  -57.829  52.557  1
572316  96.117  -57.839  52.542  1
572317  96.151  -57.849  52.527  1
572318  96.184  -57.860  52.511  1
572319  96.219  -57.870  52.496  1
572320  96.252  -57.880  52.484  1
572321  96.286  -57.891  52.475  1
572322  96.320  -57.901  52.468  1
572323  96.354  -57.912  52.463  1
572324  96.388  -57.922  52.458  1
572325  96.421  -57.932  52.451  1
572326  96.456  -57.943  52.442  1
572327  96.489  -57.952  52.433  1
572328  96.523  -57.963  52.423  1
572329  96.557  -57.974  52.409  1
572330  96.591  -57.984  52.391  1
572331  96.625  -57.994  52.370  1
572332  96.659  -58.005  52.350  1
572333  96.693  -58.015  52.332  1
572334  96.727  -58.025  52.318  1
572335  96.757  -58.036  52.309  1
572336  96.786  -58.046  52.300  1
572337  96.814  -58.058  52.291  1
572338  96.842  -58.068  52.285  1
572339  96.871  -58.080  52.281  1
572340  96.899  -58.090  52.279  1
572341  96.927  -58.101  52.277  1
572342  96.952  -58.106  52.275  1
572343  96.977  -58.112  52.268  1
572344  97.002  -58.116  52.259  1
572345  97.027  -58.122  52.246  1
572346  97.055  -58.122  52.231  1
572347  97.085  -58.119  52.215  1
572348  97.114  -58.116  52.197  1
572349  97.144  -58.114  52.179  1
572350  97.174  -58.112  52.159  1
572351  97.204  -58.108  52.139  1
572352  97.233  -58.104  52.119  1
572353  97.262  -58.100  52.092  1
572354  97.292  -58.096  52.054  1
572355  97.322  -58.092  52.014  1
572356  97.354  -58.095  51.970  1
572357  97.389  -58.099  51.923  1
572358  97.425  -58.098  51.873  1
572359  97.460  -58.096  51.818  1
572360  97.495  -58.097  51.762  1
572361  97.529  -58.097  51.702  1
572362  97.564  -58.098  51.640  1
572363  97.598  -58.099  51.577  1
572364  97.633  -58.099  51.513  1
572365  97.667  -58.100  51.452  1
572366  97.702  -58.100  51.397  1
572367  97.736  -58.100  51.341  1
572368  97.774  -58.103  51.282  1
572369  97.814  -58.109  51.217  1
572370  97.855  -58.114  51.148  1
572371  97.895  -58.118  51.083  1
572372  97.936  -58.124  51.020  1
572373  97.972  -58.126  50.961  1
572374  98.008  -58.128  50.905  1
572375  98.044  -58.129  50.851  1
572376  98.079  -58.131  50.797  1
572377  98.113  -58.131  50.746  1
572378  98.148  -58.131  50.700  1
572379  98.182  -58.131  50.657  1
572380  98.216  -58.131  50.617  1
572381  98.251  -58.131  50.577  1
572382  98.285  -58.132  50.531  1
572383  98.319  -58.130  50.484  1
572384  98.350  -58.124  50.440  1
572385  98.381  -58.117  50.397  1
572386  98.412  -58.111  50.357  1
572387  98.443  -58.109  50.320  1
572388  98.474  -58.109  50.285  1
572389  98.505  -58.108  50.254  1
572390  98.536  -58.107  50.225  1
572391  98.567  -58.106  50.200  1
572392  98.598  -58.106  50.175  1
572393  98.629  -58.106  50.151  1
572394  98.660  -58.105  50.126  1
572395  98.666  -58.104  50.102  1
572396  98.664  -58.104  50.081  1
572397  98.692  -58.120  50.060  1
572398  98.720  -58.136  50.041  1
572399  98.747  -58.152  50.023  1
572400  98.767  -58.165  50.005  1
572401  98.771  -58.175  49.987  1
572402  98.824  -58.157  49.968  1
572403  98.866  -58.150  49.947  1
572404  98.908  -58.144  49.925  1
572405  98.950  -58.137  49.904  1
572406  98.992  -58.129  49.882  1
572407  99.034  -58.122  49.863  1
572408  99.076  -58.115  49.844  1
572409  99.116  -58.110  49.824  1
572410  99.156  -58.105  49.801  1
572411  99.196  -58.100  49.776  1
572412  99.235  -58.096  49.751  1
572413  99.275  -58.093  49.722  1
572414  99.295  -58.105  49.693  1
572415  99.297  -58.120  49.665  1
572416  99.348  -58.134  49.637  1
572417  99.415  -58.147  49.609  1
572418  99.465  -58.153  49.580  1
572419  99.500  -58.162  49.552  1
572420  99.534  -58.171  49.525  1
572421  99.569  -58.179  49.497  1
572422  99.603  -58.188  49.469  1
572423  99.638  -58.197  49.441  1
572424  99.672  -58.206  49.415  1
572779  87.721  -54.571  57.598  4
572780  87.752  -54.594  57.598  4
572781  87.783  -54.618  57.598  4
572782  87.814  -54.641  57.597  4
572783  87.849  -54.658  57.595  4
572784  87.884  -54.673  57.595  4
572785  87.919  -54.688  57.592  4
572786  87.955  -54.703  57.589  4
572787  87.990  -54.719  57.584  4
572788  88.026  -54.734  57.578  4
572789  88.061  -54.750  57.572  4
572790  88.100  -54.756  57.565  4
572791  88.163  -54.704  57.557  4
572792  88.220  -54.708  57.547  4
572793  88.276  -54.712  57.536  4
572794  88.314  -54.703  57.525  4
572795  88.353  -54.703  57.513  4
572796  88.397  -54.718  57.495  4
572797  88.441  -54.733  57.471  4
572798  88.477  -54.747  57.445  4
572799  88.514  -54.761  57.415  4
572800  88.550  -54.775  57.381  4
572801  88.586  -54.790  57.344  4
572802  88.623  -54.804  57.304  4
572803  88.659  -54.818  57.261  4
572804  88.696  -54.834  57.214  4
572805  88.735  -54.858  57.165  4
572806  88.773  -54.881  57.115  4
572807  88.812  -54.905  57.064  4
572808  88.850  -54.928  57.012  4
572809  88.889  -54.952  56.962  4
572810  88.927  -54.975  56.912  4
572811  88.966  -54.999  56.862  4
572812  89.004  -55.022  56.813  4
572843  90.108  -55.691  55.740  1
572844  90.133  -55.709  55.736  1
572845  90.161  -55.728  55.734  1
572846  90.188  -55.747  55.734  1
572847  90.214  -55.760  55.737  1
572848  90.240  -55.771  55.742  1
572849  90.268  -55.781  55.747  1
572850  90.308  -55.790  55.753  1
572851  90.348  -55.801  55.760  1
572852  90.388  -55.811  55.770  1
572853  90.427  -55.821  55.782  1
572854  90.467  -55.831  55.794  1
572855  90.507  -55.841  55.807  1
572856  90.546  -55.852  55.821  1
572857  90.586  -55.862  55.837  1
572858  90.625  -55.872  55.854  1
572859  90.665  -55.882  55.875  1
572860  90.705  -55.892  55.894  1
572861  90.744  -55.903  55.910  1
572862  90.784  -55.912  55.923  1
572863  90.821  -55.924  55.936  1
572864  90.857  -55.936  55.946  1
572865  90.891  -55.949  55.950  1
572866  90.926  -55.961  55.939  1
572867  90.963  -55.973  55.924  1
572868  91.008  -55.984  55.914  1
572869  91.052  -55.994  55.902  1
572870  91.096  -56.005  55.898  1
572871  91.140  -56.016  55.887  1
572872  91.184  -56.025  55.864  1
572873  91.229  -56.036  55.833  1
572874  91.273  -56.047  55.800  1
572875  91.308  -56.053  55.770  1
572876  91.341  -56.059  55.741  1
572877  91.373  -56.065  55.723  1
572878  91.405  -56.070  55.702  1
572879  91.438  -56.076  55.675  1
572880  91.470  -56.081  55.642  1
572881  91.503  -56.088  55.614  1
572882  91.535  -56.093  55.580  1
572883  91.567  -56.102  55.549  1
572884  91.597  -56.115  55.519  1
572885  91.628  -56.127  55.490  1
572886  91.658  -56.140  55.462  1
572887  91.694  -56.147  55.438  1
572888  91.730  -56.154  55.420  1
572889  91.767  -56.161  55.408  1
572890  91.803  -56.168  55.395  1
572891  91.839  -56.175  55.377  1
572892  91.875  -56.182  55.355  1
572893  91.911  -56.188  55.336  1
572894  91.947  -56.195  55.319  1
572895  91.983  -56.202  55.308  1
572896  92.019  -56.209  55.307  1
572897  92.056  -56.220  55.313  1
572898  92.091  -56.252  55.323  1
572899  92.129  -56.288  55.330  1
572900  92.166  -56.326  55.337  1
572901  92.203  -56.363  55.340  1
572902  92.240  -56.400  55.339  1
572903  92.278  -56.436  55.335  1
572904  92.315  -56.473  55.333  1
572905  92.352  -56.511  55.334  1
572906  92.389  -56.547  55.339  1
572907  92.427  -56.584  55.342  1
572908  92.464  -56.621  55.346  1
572909  92.503  -56.641  55.353  1
572910  92.542  -56.660  55.354  1
572911  92.581  -56.679  55.350  1
572912  92.620  -56.698  55.345  1
572913  92.659  -56.718  55.342  1
572914  92.695  -56.738  55.342  1
572915  92.729  -56.758  55.360  1
572916  92.764  -56.780  55.372  1
572917  92.799  -56.800  55.378  1
572918  92.834  -56.821  55.378  1
572919  92.868  -56.842  55.376  1
572920  92.912  -56.855  55.377  1
572921  92.954  -56.869  55.380  1
572922  92.998  -56.883  55.380  1
572923  93.041  -56.896  55.376  1
572924  93.084  -56.910  55.370  1
572925  93.116  -56.918  55.362  1
572926  93.145  -56.924  55.353  1
572927  93.174  -56.931  55.340  1
572928  93.203  -56.937  55.327  1
572929  93.232  -56.944  55.312  1
572930  93.261  -56.951  55.293  1
572931  93.292  -56.962  55.272  1
572932  93.325  -56.973  55.246  1
572933  93.358  -56.985  55.219  1
572934  93.391  -56.997  55.187  1
572935  93.423  -57.009  55.154  1
572936  93.456  -57.021  55.121  1
572937  93.489  -57.033  55.087  1
572938  93.521  -57.044  55.051  1
572939  93.554  -57.056  55.016  1
572940  93.586  -57.069  54.981  1
572941  93.619  -57.080  54.948  1
572942  93.652  -57.092  54.917  1
572943  93.685  -57.104  54.886  1
572944  93.717  -57.116  54.853  1
572945  93.750  -57.128  54.820  1
572946  93.783  -57.138  54.790  1
572947  93.817  -57.141  54.761  1
572948  93.850  -57.145  54.733  1
572949  93.884  -57.149  54.704  1
572950  93.918  -57.153  54.670  1
572951  93.951  -57.156  54.636  1
572952  93.985  -57.160  54.601  1
572953  94.018  -57.163  54.567  1
572954  94.052  -57.167  54.534  1
572955  94.086  -57.171  54.502  1
572956  94.121  -57.182  54.470  1
572957  94.158  -57.205  54.438  1
572958  94.196  -57.228  54.406  1
572959  94.233  -57.251  54.368  1
572960  94.270  -57.274  54.326  1
572961  94.308  -57.297  54.286  1
572962  94.341  -57.312  54.252  1
572963  94.373  -57.325  54.227  1
572964  94.406  -57.337  54.205  1
572965  94.438  -57.349  54.185  1
572966  94.471  -57.362  54.166  1
572967  94.503  -57.374  54.146  1
572968  94.535  -57.386  54.131  1
572969  94.567  -57.399  54.120  1
572970  94.600  -57.411  54.111  1
572971  94.632  -57.424  54.103  1
572972  94.665  -57.436  54.097  1
572973  94.697  -57.448  54.092  1
572974  94.729  -57.461  54.086  1
572975  94.761  -57.473  54.080  1
572976  94.794  -57.485  54.072  1
572977  94.826  -57.498  54.060  1
572978  94.858  -57.510  54.046  1
572979  94.891  -57.523  54.028  1
572980  94.923  -57.536  54.006  1
572981  94.955  -57.548  53.980  1
572982  94.985  -57.558  53.951  1
572983  95.015  -57.567  53.919  1
572984  95.045  -57.577  53.883  1
572985  95.075  -57.588  53.841  1
572986  95.106  -57.598  53.800  1
572987  95.136  -57.608  53.757  1
572988  95.166  -57.617  53.713  1
572989  95.196  -57.628  53.670  1
572990  95.226  -57.638  53.622  1
572991  95.256  -57.648  53.572  1
572992  95.284  -57.659  53.521  1
572993  95.310  -57.671  53.469  1
572994  95.335  -57.683  53.414  1
572995  95.383  -57.693  53.358  1
572996  95.427  -57.696  53.299  1
572997  95.464  -57.695  53.239  1
572998  95.501  -57.695  53.182  1
572999  95.542  -57.697  53.129  1
573000  95.586  -57.702  53.079  1
573001  95.630  -57.707  53.032  1
573002  95.674  -57.711  52.988  1
573003  95.718  -57.716  52.947  1
573004  95.761  -57.721  52.904  1
573005  95.805  -57.726  52.859  1
573006  95.827  -57.731  52.812  1
573007  95.848  -57.736  52.764  1
573008  95.870  -57.742  52.717  1
573009  95.890  -57.748  52.678  1
573010  95.911  -57.753  52.645  1
573011  95.939  -57.761  52.616  1
573012  95.967  -57.768  52.592  1
573013  95.996  -57.776  52.571  1
573014  96.026  -57.783  52.552  1
573015  96.054  -57.791  52.536  1
573016  96.084  -57.799  52.521  1
573017  96.113  -57.806  52.507  1
573018  96.148  -57.817  52.492  1
573019  96.181  -57.827  52.477  1
573020  96.215  -57.837  52.464  1
573021  96.249  -57.848  52.452  1
573022  96.283  -57.858  52.443  1
573023  96.317  -57.868  52.437  1
573024  96.350  -57.879  52.431  1
573025  96.385  -57.890  52.426  1
573026  96.418  -57.899  52.418  1
573027  96.452  -57.910  52.413  1
573028  96.486  -57.920  52.407  1
573029  96.520  -57.930  52.397  1
573030  96.554  -57.941  52.383  1
573031  96.588  -57.951  52.365  1
573032  96.622  -57.962  52.347  1
573033  96.656  -57.972  52.328  1
573034  96.689  -57.982  52.311  1
573035  96.723  -57.993  52.297  1
573036  96.753  -58.003  52.287  1
573037  96.781  -58.015  52.279  1
573038  96.809  -58.025  52.271  1
573039  96.837  -58.036  52.267  1
573040  96.866  -58.047  52.266  1
573041  96.894  -58.058  52.266  1
573042  96.922  -58.069  52.266  1
573043  96.950  -58.080  52.267  1
573044  96.975  -58.085  52.264  1
573045  97.001  -58.090  52.257  1
573046  97.028  -58.092  52.247  1
573047  97.058  -58.090  52.235  1
573048  97.087  -58.087  52.223  1
573049  97.116  -58.084  52.208  1
573050  97.146  -58.080  52.192  1
573051  97.176  -58.076  52.174  1
573052  97.206  -58.071  52.155  1
573053  97.235  -58.068  52.134  1
573054  97.264  -58.064  52.107  1
573055  97.294  -58.060  52.070  1
573056  97.324  -58.056  52.034  1
573057  97.354  -58.053  51.993  1
573058  97.388  -58.068  51.946  1
573059  97.424  -58.068  51.895  1
573060  97.460  -58.066  51.841  1
573061  97.495  -58.065  51.785  1
573062  97.531  -58.064  51.723  1
573063  97.566  -58.063  51.658  1
573064  97.600  -58.064  51.591  1
573065  97.635  -58.065  51.526  1
573066  97.669  -58.065  51.465  1
573067  97.704  -58.065  51.409  1
573068  97.738  -58.066  51.352  1
573069  97.775  -58.068  51.290  1
573070  97.815  -58.073  51.223  1
573071  97.856  -58.078  51.155  1
573072  97.896  -58.084  51.089  1
573073  97.937  -58.088  51.026  1
573074  97.978  -58.093  50.967  1
573075  98.013  -58.095  50.911  1
573076  98.049  -58.097  50.856  1
573077  98.084  -58.097  50.801  1
573078  98.118  -58.098  50.750  1
573079  98.153  -58.098  50.703  1
573080  98.187  -58.098  50.661  1
573081  98.221  -58.099  50.622  1
573082  98.255  -58.099  50.583  1
573083  98.290  -58.099  50.541  1
573084  98.323  -58.100  50.495  1
573085  98.354  -58.101  50.448  1
573086  98.385  -58.100  50.404  1
573087  98.416  -58.100  50.363  1
573088  98.447  -58.099  50.327  1
573089  98.478  -58.098  50.291  1
573090  98.509  -58.097  50.259  1
573091  98.541  -58.096  50.230  1
573092  98.571  -58.096  50.204  1
573093  98.602  -58.096  50.179  1
573094  98.634  -58.095  50.155  1
573095  98.660  -58.094  50.131  1
573096  98.659  -58.094  50.107  1
573097  98.658  -58.093  50.085  1
573098  98.671  -58.102  50.064  1
573099  98.699  -58.118  50.045  1
573100  98.726  -58.133  50.026  1
573101  98.736  -58.144  50.006  1
573102  98.777  -58.134  49.989  1
573103  98.819  -58.127  49.970  1
573104  98.861  -58.120  49.951  1
573105  98.903  -58.113  49.931  1
573106  98.945  -58.106  49.909  1
573107  98.986  -58.100  49.888  1
573108  99.026  -58.094  49.869  1
573109  99.066  -58.090  49.850  1
573110  99.106  -58.085  49.829  1
573111  99.145  -58.081  49.806  1
573112  99.185  -58.076  49.780  1
573113  99.225  -58.071  49.754  1
573114  99.265  -58.067  49.726  1
573115  99.302  -58.075  49.696  1
573116  99.305  -58.090  49.668  1
573117  99.327  -58.104  49.639  1
573118  99.397  -58.118  49.611  1
573119  99.452  -58.126  49.582  1
573120  99.492  -58.134  49.553  1
573121  99.526  -58.143  49.525  1
573122  99.561  -58.151  49.496  1
573123  99.595  -58.160  49.468  1
573124  99.630  -58.169  49.439  1
573125  99.664  -58.178  49.411  1
573126  99.699  -58.187  49.383  1
573481  87.774  -54.565  57.599  4
573482  87.805  -54.588  57.599  4
573483  87.838  -54.607  57.598  4
573484  87.873  -54.623  57.596  4
573485  87.909  -54.638  57.597  4
573486  87.944  -54.653  57.594  4
573487  87.979  -54.668  57.592  4
573488  88.014  -54.684  57.587  4
573489  88.050  -54.699  57.582  4
573490  88.085  -54.715  57.576  4
573491  88.121  -54.730  57.570  4
573492  88.182  -54.668  57.562  4
573493  88.239  -54.668  57.552  4
573494  88.296  -54.672  57.541  4
573495  88.336  -54.665  57.530  4
573496  88.372  -54.656  57.517  4
573497  88.413  -54.660  57.499  4
573498  88.456  -54.675  57.478  4
573499  88.492  -54.689  57.453  4
573500  88.529  -54.703  57.425  4
573501  88.565  -54.718  57.393  4
573502  88.601  -54.733  57.357  4
573503  88.640  -54.756  57.318  4
573504  88.679  -54.779  57.276  4
573505  88.717  -54.803  57.230  4
573506  88.756  -54.826  57.181  4
573507  88.794  -54.850  57.132  4
573508  88.833  -54.873  57.081  4
573509  88.872  -54.897  57.030  4
573510  88.910  -54.920  56.980  4
573511  88.949  -54.944  56.930  4
573512  88.987  -54.967  56.879  4
573513  89.026  -54.990  56.830  4
573547  90.206  -55.712  55.735  1
573548  90.232  -55.727  55.739  1
573549  90.257  -55.737  55.744  1
573550  90.283  -55.747  55.750  1
573551  90.320  -55.757  55.757  1
573552  90.360  -55.768  55.766  1
573553  90.399  -55.777  55.776  1
573554  90.439  -55.787  55.790  1
573555  90.479  -55.798  55.805  1
573556  90.518  -55.808  55.820  1
573557  90.558  -55.818  55.837  1
573558  90.598  -55.828  55.855  1
573559  90.637  -55.838  55.877  1
573560  90.677  -55.849  55.903  1
573561  90.717  -55.859  55.928  1
573562  90.756  -55.868  55.950  1
573563  90.796  -55.879  55.970  1
573564  90.835  -55.889  55.989  1
573565  90.875  -55.900  56.006  1
573566  90.911  -55.911  56.009  1
573567  90.946  -55.924  55.991  1
573568  90.981  -55.936  55.969  1
573569  91.020  -55.948  55.959  1
573570  91.064  -55.959  55.941  1
573571  91.108  -55.969  55.936  1
573572  91.152  -55.979  55.924  1
573573  91.196  -55.990  55.900  1
573574  91.241  -56.000  55.866  1
573575  91.279  -56.009  55.834  1
573576  91.312  -56.014  55.797  1
573577  91.344  -56.020  55.767  1
573578  91.377  -56.025  55.746  1
573579  91.410  -56.031  55.726  1
573580  91.442  -56.037  55.699  1
573581  91.474  -56.042  55.668  1
573582  91.507  -56.048  55.637  1
573583  91.539  -56.053  55.601  1
573584  91.572  -56.060  55.565  1
573585  91.602  -56.072  55.531  1
573586  91.633  -56.085  55.498  1
573587  91.668  -56.093  55.467  1
573588  91.704  -56.100  55.443  1
573589  91.740  -56.107  55.429  1
573590  91.777  -56.113  55.420  1
573591  91.812  -56.121  55.411  1
573592  91.849  -56.128  55.395  1
573593  91.885  -56.137  55.373  1
573594  91.922  -56.147  55.350  1
573595  91.958  -56.158  55.327  1
573596  91.995  -56.169  55.308  1
573597  92.032  -56.179  55.297  1
573598  92.065  -56.200  55.294  1
573599  92.097  -56.223  55.297  1
573600  92.134  -56.257  55.303  1
573601  92.171  -56.294  55.308  1
573602  92.208  -56.331  55.313  1
573603  92.245  -56.367  55.317  1
573604  92.282  -56.404  55.318  1
573605  92.319  -56.442  55.319  1
573606  92.357  -56.478  55.318  1
573607  92.394  -56.515  55.318  1
573608  92.431  -56.552  55.319  1
573609  92.469  -56.586  55.326  1
573610  92.508  -56.605  55.338  1
573611  92.547  -56.624  55.339  1
573612  92.586  -56.642  55.332  1
573613  92.625  -56.661  55.325  1
573614  92.664  -56.681  55.324  1
573615  92.701  -56.701  55.333  1
573616  92.735  -56.722  55.357  1
573617  92.770  -56.743  55.372  1
573618  92.805  -56.764  55.376  1
573619  92.840  -56.784  55.373  1
573620  92.876  -56.803  55.371  1
573621  92.920  -56.817  55.377  1
573622  92.963  -56.830  55.382  1
573623  93.006  -56.844  55.382  1
573624  93.049  -56.858  55.379  1
573625  93.092  -56.871  55.374  1
573626  93.127  -56.881  55.367  1
573627  93.156  -56.887  55.359  1
573628  93.185  -56.894  55.347  1
573629  93.214  -56.901  55.332  1
573630  93.243  -56.907  55.315  1
573631  93.272  -56.914  55.296  1
573632  93.304  -56.924  55.275  1
573633  93.337  -56.937  55.251  1
573634  93.369  -56.949  55.227  1
573635  93.402  -56.960  55.200  1
573636  93.435  -56.972  55.171  1
573637  93.468  -56.984  55.140  1
573638  93.500  -56.997  55.106  1
573639  93.533  -57.008  55.070  1
573640  93.565  -57.020  55.035  1
573641  93.598  -57.032  55.001  1
573642  93.631  -57.044  54.968  1
573643  93.663  -57.056  54.936  1
573644  93.696  -57.068  54.905  1
573645  93.729  -57.079  54.872  1
573646  93.761  -57.091  54.841  1
573647  93.794  -57.103  54.812  1
573648  93.827  -57.113  54.784  1
573649  93.860  -57.117  54.756  1
573650  93.894  -57.121  54.727  1
573651  93.928  -57.125  54.690  1
573652  93.962  -57.128  54.654  1
573653  93.995  -57.132  54.618  1
573654  94.029  -57.136  54.582  1
573655  94.063  -57.140  54.547  1
573656  94.096  -57.143  54.511  1
573657  94.131  -57.153  54.473  1
573658  94.169  -57.175  54.439  1
573659  94.206  -57.199  54.405  1
573660  94.243  -57.222  54.369  1
573661  94.280  -57.244  54.330  1
573662  94.317  -57.265  54.293  1
573663  94.349  -57.278  54.254  1
573664  94.381  -57.290  54.219  1
573665  94.414  -57.302  54.190  1
573666  94.446  -57.315  54.167  1
573667  94.478  -57.327  54.146  1
573668  94.510  -57.340  54.124  1
573669  94.543  -57.352  54.106  1
573670  94.575  -57.364  54.090  1
573671  94.608  -57.377  54.079  1
573672  94.640  -57.389  54.070  1
573673  94.672  -57.401  54.063  1
573674  94.704  -57.414  54.055  1
573675  94.737  -57.426  54.049  1
573676  94.769  -57.439  54.044  1
573677  94.802  -57.451  54.036  1
573678  94.834  -57.464  54.026  1
573679  94.866  -57.476  54.015  1
573680  94.899  -57.489  53.998  1
573681  94.931  -57.501  53.981  1
573682  94.963  -57.514  53.959  1
573683  94.994  -57.524  53.933  1
573684  95.024  -57.535  53.903  1
573685  95.054  -57.545  53.868  1
573686  95.085  -57.554  53.827  1
573687  95.115  -57.564  53.785  1
573688  95.145  -57.575  53.740  1
573689  95.175  -57.585  53.694  1
573690  95.205  -57.595  53.647  1
573691  95.235  -57.605  53.600  1
573692  95.265  -57.615  53.551  1
573693  95.296  -57.625  53.504  1
573694  95.325  -57.636  53.455  1
573695  95.350  -57.648  53.404  1
573696  95.387  -57.658  53.349  1
573697  95.431  -57.661  53.292  1
573698  95.468  -57.661  53.232  1
573699  95.510  -57.664  53.173  1
573700  95.553  -57.668  53.117  1
573701  95.597  -57.673  53.065  1
573702  95.640  -57.678  53.017  1
573703  95.684  -57.683  52.973  1
573704  95.728  -57.687  52.931  1
573705  95.772  -57.692  52.888  1
573706  95.812  -57.697  52.844  1
573707  95.833  -57.702  52.799  1
573708  95.854  -57.708  52.754  1
573709  95.875  -57.714  52.708  1
573710  95.896  -57.719  52.667  1
573711  95.916  -57.725  52.630  1
573712  95.941  -57.731  52.599  1
573713  95.970  -57.739  52.573  1
573714  95.999  -57.746  52.549  1
573715  96.028  -57.754  52.528  1
573716  96.057  -57.761  52.509  1
573717  96.086  -57.769  52.493  1
573718  96.115  -57.777  52.478  1
573719  96.144  -57.784  52.462  1
573720  96.178  -57.795  52.448  1
573721  96.212  -57.805  52.436  1
573722  96.246  -57.815  52.424  1
573723  96.279  -57.826  52.415  1
573724  96.313  -57.836  52.409  1
573725  96.347  -57.846  52.404  1
573726  96.381  -57.856  52.401  1
573727  96.415  -57.867  52.394  1
573728  96.449  -57.877  52.388  1
573729  96.483  -57.887  52.380  1
573730  96.517  -57.898  52.369  1
573731  96.550  -57.909  52.354  1
573732  96.585  -57.918  52.340  1
573733  96.618  -57.929  52.325  1
573734  96.652  -57.940  52.306  1
573735  96.686  -57.949  52.288  1
573736  96.720  -57.960  52.274  1
573737  96.748  -57.971  52.265  1
573738  96.777  -57.982  52.256  1
573739  96.805  -57.993  52.251  1
573740  96.833  -58.004  52.248  1
573741  96.861  -58.015  52.248  1
573742  96.889  -58.026  52.250  1
573743  96.918  -58.037  52.252  1
573744  96.946  -58.047  52.255  1
573745  96.974  -58.059  52.255  1
573746  97.000  -58.062  52.252  1
573747  97.030  -58.059  52.247  1
573748  97.059  -58.056  52.238  1
573749  97.089  -58.052  52.229  1
573750  97.118  -58.047  52.218  1
573751  97.148  -58.043  52.204  1
573752  97.178  -58.040  52.187  1
573753  97.208  -58.036  52.168  1
573754  97.237  -58.032  52.145  1
573755  97.267  -58.028  52.120  1
573756  97.296  -58.024  52.086  1
573757  97.326  -58.020  52.054  1
573758  97.356  -58.016  52.016  1
573759  97.389  -58.025  51.969  1
573760  97.424  -58.037  51.917  1
573761  97.459  -58.037  51.863  1
573762  97.495  -58.035  51.806  1
573763  97.530  -58.034  51.742  1
573764  97.566  -58.032  51.674  1
573765  97.602  -58.031  51.605  1
573766  97.637  -58.030  51.538  1
573767  97.671  -58.031  51.478  1
573768  97.706  -58.031  51.421  1
573769  97.740  -58.031  51.362  1
573770  97.776  -58.033  51.300  1
573771  97.816  -58.037  51.233  1
573772  97.857  -58.043  51.166  1
573773  97.897  -58.048  51.100  1
573774  97.938  -58.053  51.037  1
573775  97.979  -58.058  50.977  1
573776  98.019  -58.063  50.920  1
573777  98.054  -58.065  50.864  1
573778  98.089  -58.065  50.808  1
573779  98.123  -58.065  50.757  1
573780  98.157  -58.065  50.710  1
573781  98.192  -58.066  50.667  1
573782  98.225  -58.068  50.627  1
573783  98.260  -58.068  50.588  1
573784  98.294  -58.070  50.547  1
573785  98.327  -58.071  50.502  1
573786  98.359  -58.073  50.455  1
573787  98.390  -58.075  50.411  1
573788  98.421  -58.078  50.371  1
573789  98.452  -58.080  50.336  1
573790  98.483  -58.082  50.300  1
573791  98.514  -58.084  50.267  1
573792  98.545  -58.086  50.238  1
573793  98.576  -58.086  50.211  1
573794  98.607  -58.085  50.186  1
573795  98.638  -58.084  50.162  1
573796  98.654  -58.084  50.137  1
573797  98.652  -58.084  50.113  1
573798  98.651  -58.083  50.091  1
573799  98.651  -58.084  50.071  1
573800  98.678  -58.099  50.052  1
573801  98.702  -58.114  50.032  1
573802  98.729  -58.111  50.012  1
573803  98.772  -58.103  49.995  1
573804  98.814  -58.096  49.977  1
573805  98.856  -58.089  49.958  1
573806  98.896  -58.084  49.937  1
573807  98.936  -58.079  49.915  1
573808  98.976  -58.075  49.895  1
573809  99.015  -58.070  49.876  1
573810  99.055  -58.065  49.856  1
573811  99.095  -58.061  49.835  1
573812  99.135  -58.056  49.811  1
573813  99.174  -58.051  49.785  1
573814  99.214  -58.046  49.759  1
573815  99.254  -58.042  49.731  1
573816  99.292  -58.048  49.700  1
573817  99.314  -58.060  49.670  1
573818  99.316  -58.075  49.641  1
573819  99.375  -58.089  49.612  1
573820  99.437  -58.099  49.583  1
573821  99.485  -58.106  49.554  1
573822  99.519  -58.115  49.525  1
573823  99.554  -58.124  49.496  1
573824  99.588  -58.132  49.466  1
573825  99.623  -58.141  49.437  1
573826  99.657  -58.150  49.408  1
573827  99.692  -58.159  49.380  1
573828  99.726  -58.168  49.351  1
574182  87.795  -54.535  57.598  4
574183  87.827  -54.557  57.598  4
574184  87.862  -54.572  57.599  4
574185  87.898  -54.588  57.598  4
574186  87.933  -54.603  57.598  4
574187  87.969  -54.618  57.596  4
574188  88.004  -54.634  57.593  4
574189  88.039  -54.649  57.590  4
574190  88.075  -54.665  57.585  4
574191  88.110  -54.680  57.580  4
574192  88.145  -54.695  57.573  4
574193  88.197  -54.661  57.566  4
574194  88.259  -54.629  57.557  4
574195  88.316  -54.633  57.546  4
574196  88.359  -54.627  57.534  4
574197  88.395  -54.618  57.520  4
574198  88.431  -54.609  57.503  4
574199  88.471  -54.617  57.485  4
574200  88.507  -54.631  57.464  4
574201  88.545  -54.654  57.440  4
574202  88.584  -54.678  57.407  4
574203  88.623  -54.701  57.369  4
574204  88.661  -54.724  57.331  4
574205  88.700  -54.747  57.290  4
574206  88.739  -54.771  57.244  4
574207  88.777  -54.794  57.196  4
574208  88.816  -54.818  57.148  4
574209  88.854  -54.841  57.097  4
574210  88.893  -54.865  57.046  4
574211  88.931  -54.888  56.996  4
574212  88.970  -54.912  56.945  4
574213  89.009  -54.935  56.894  4
574214  89.047  -54.958  56.845  4
574247  90.196  -55.658  55.738  1
574248  90.223  -55.677  55.737  1
574249  90.250  -55.693  55.742  1
574250  90.275  -55.703  55.747  1
574251  90.301  -55.714  55.753  1
574252  90.332  -55.724  55.762  1
574253  90.372  -55.734  55.773  1
574254  90.411  -55.744  55.784  1
574255  90.451  -55.754  55.800  1
574256  90.490  -55.765  55.818  1
574257  90.530  -55.774  55.838  1
574258  90.570  -55.784  55.860  1
574259  90.609  -55.795  55.879  1
574260  90.649  -55.805  55.900  1
574261  90.689  -55.815  55.928  1
574262  90.728  -55.825  55.959  1
574263  90.768  -55.835  55.994  1
574264  90.808  -55.846  56.029  1
574265  90.848  -55.856  56.064  1
574266  90.887  -55.865  56.077  1
574267  90.927  -55.876  56.068  1
574268  90.966  -55.886  56.041  1
574269  91.001  -55.899  56.016  1
574270  91.036  -55.911  56.008  1
574271  91.076  -55.922  55.983  1
574272  91.120  -55.933  55.975  1
574273  91.164  -55.944  55.965  1
574274  91.209  -55.954  55.939  1
574275  91.251  -55.964  55.900  1
574276  91.283  -55.969  55.867  1
574277  91.316  -55.975  55.825  1
574278  91.348  -55.981  55.792  1
574279  91.381  -55.986  55.768  1
574280  91.413  -55.992  55.745  1
574281  91.446  -55.997  55.717  1
574282  91.478  -56.003  55.685  1
574283  91.511  -56.009  55.654  1
574284  91.543  -56.015  55.619  1
574285  91.576  -56.020  55.581  1
574286  91.607  -56.031  55.544  1
574287  91.642  -56.039  55.507  1
574288  91.678  -56.046  55.474  1
574289  91.714  -56.053  55.449  1
574290  91.751  -56.064  55.433  1
574291  91.788  -56.075  55.424  1
574292  91.824  -56.085  55.417  1
574293  91.861  -56.096  55.405  1
574294  91.897  -56.107  55.387  1
574295  91.934  -56.118  55.365  1
574296  91.971  -56.128  55.339  1
574297  92.008  -56.139  55.312  1
574298  92.042  -56.157  55.290  1
574299  92.074  -56.180  55.276  1
574300  92.106  -56.204  55.273  1
574301  92.139  -56.227  55.276  1
574302  92.175  -56.261  55.282  1
574303  92.213  -56.298  55.289  1
574304  92.250  -56.335  55.296  1
574305  92.287  -56.373  55.301  1
574306  92.324  -56.409  55.303  1
574307  92.362  -56.446  55.302  1
574308  92.399  -56.483  55.300  1
574309  92.436  -56.520  55.302  1
574310  92.475  -56.549  55.309  1
574311  92.513  -56.568  55.318  1
574312  92.553  -56.587  55.316  1
574313  92.591  -56.606  55.309  1
574314  92.631  -56.626  55.308  1
574315  92.670  -56.645  55.319  1
574316  92.707  -56.664  55.336  1
574317  92.741  -56.686  55.353  1
574318  92.776  -56.706  55.361  1
574319  92.811  -56.727  55.363  1
574320  92.846  -56.748  55.369  1
574321  92.885  -56.765  55.382  1
574322  92.928  -56.778  55.391  1
574323  92.971  -56.792  55.395  1
574324  93.014  -56.805  55.391  1
574325  93.057  -56.819  55.383  1
574326  93.100  -56.833  55.375  1
574327  93.138  -56.844  55.368  1
574328  93.167  -56.851  55.361  1
574329  93.196  -56.857  55.350  1
574330  93.225  -56.864  55.334  1
574331  93.254  -56.870  55.315  1
574332  93.283  -56.877  55.296  1
574333  93.315  -56.888  55.276  1
574334  93.348  -56.900  55.254  1
574335  93.381  -56.912  55.232  1
574336  93.413  -56.924  55.206  1
574337  93.446  -56.936  55.178  1
574338  93.479  -56.948  55.150  1
574339  93.511  -56.959  55.117  1
574340  93.544  -56.971  55.082  1
574341  93.577  -56.984  55.045  1
574342  93.610  -56.995  55.010  1
574343  93.642  -57.007  54.977  1
574344  93.675  -57.019  54.948  1
574345  93.707  -57.031  54.918  1
574346  93.740  -57.043  54.886  1
574347  93.773  -57.055  54.855  1
574348  93.805  -57.066  54.827  1
574349  93.838  -57.078  54.799  1
574350  93.871  -57.089  54.770  1
574351  93.905  -57.093  54.742  1
574352  93.938  -57.097  54.706  1
574353  93.972  -57.100  54.671  1
574354  94.005  -57.104  54.635  1
574355  94.039  -57.108  54.599  1
574356  94.073  -57.112  54.563  1
574357  94.107  -57.116  54.528  1
574358  94.141  -57.123  54.490  1
574359  94.179  -57.147  54.452  1
574360  94.216  -57.169  54.414  1
574361  94.253  -57.192  54.377  1
574362  94.290  -57.215  54.342  1
574363  94.324  -57.231  54.306  1
574364  94.356  -57.243  54.264  1
574365  94.389  -57.256  54.218  1
574366  94.421  -57.268  54.179  1
574367  94.454  -57.280  54.151  1
574368  94.486  -57.293  54.128  1
574369  94.518  -57.305  54.105  1
574370  94.551  -57.317  54.083  1
574371  94.583  -57.330  54.065  1
574372  94.615  -57.342  54.050  1
574373  94.647  -57.355  54.038  1
574374  94.680  -57.367  54.028  1
574375  94.712  -57.379  54.019  1
574376  94.745  -57.392  54.012  1
574377  94.777  -57.404  54.007  1
574378  94.809  -57.417  54.001  1
574379  94.841  -57.429  53.993  1
574380  94.874  -57.442  53.983  1
574381  94.906  -57.454  53.970  1
574382  94.938  -57.467  53.954  1
574383  94.971  -57.479  53.935  1
574384  95.003  -57.492  53.911  1
574385  95.034  -57.501  53.883  1
574386  95.064  -57.512  53.852  1
574387  95.094  -57.522  53.813  1
574388  95.124  -57.532  53.771  1
574389  95.154  -57.542  53.727  1
574390  95.184  -57.552  53.680  1
574391  95.214  -57.562  53.632  1
574392  95.245  -57.572  53.581  1
574393  95.275  -57.582  53.531  1
574394  95.305  -57.592  53.487  1
574395  95.335  -57.602  53.441  1
574396  95.365  -57.612  53.392  1
574397  95.391  -57.624  53.340  1
574398  95.435  -57.627  53.284  1
574399  95.476  -57.630  53.225  1
574400  95.520  -57.635  53.166  1
574401  95.564  -57.639  53.108  1
574402  95.608  -57.645  53.054  1
574403  95.652  -57.649  53.003  1
574404  95.695  -57.654  52.959  1
574405  95.739  -57.658  52.913  1
574406  95.783  -57.664  52.869  1
574407  95.817  -57.668  52.826  1
574408  95.838  -57.674  52.784  1
574409  95.859  -57.680  52.742  1
574410  95.880  -57.685  52.700  1
574411  95.901  -57.690  52.655  1
574412  95.922  -57.696  52.617  1
574413  95.943  -57.702  52.584  1
574414  95.972  -57.709  52.555  1
574415  96.001  -57.717  52.529  1
574416  96.030  -57.724  52.506  1
574417  96.059  -57.732  52.485  1
574418  96.088  -57.739  52.468  1
574419  96.117  -57.747  52.452  1
574420  96.147  -57.755  52.435  1
574421  96.175  -57.762  52.422  1
574422  96.208  -57.772  52.410  1
574423  96.242  -57.783  52.399  1
574424  96.276  -57.793  52.391  1
574425  96.310  -57.803  52.386  1
574426  96.344  -57.814  52.382  1
574427  96.378  -57.824  52.380  1
574428  96.412  -57.834  52.374  1
574429  96.446  -57.845  52.366  1
574430  96.479  -57.855  52.355  1
574431  96.514  -57.865  52.343  1
574432  96.547  -57.876  52.328  1
574433  96.581  -57.886  52.313  1
574434  96.615  -57.896  52.297  1
574435  96.649  -57.907  52.278  1
574436  96.683  -57.917  52.262  1
574437  96.715  -57.927  52.248  1
574438  96.743  -57.938  52.240  1
574439  96.771  -57.949  52.233  1
574440  96.800  -57.960  52.230  1
574441  96.828  -57.971  52.229  1
574442  96.856  -57.982  52.228  1
574443  96.884  -57.993  52.228  1
574444  96.912  -58.004  52.228  1
574445  96.941  -58.015  52.232  1
574446  96.970  -58.025  52.236  1
574447  97.004  -58.026  52.239  1
574448  97.032  -58.023  52.240  1
574449  97.062  -58.019  52.237  1
574450  97.091  -58.015  52.231  1
574451  97.120  -58.012  52.223  1
574452  97.150  -58.008  52.210  1
574453  97.180  -58.003  52.193  1
574454  97.210  -57.999  52.174  1
574455  97.239  -57.996  52.154  1
574456  97.269  -57.992  52.132  1
574457  97.298  -57.988  52.103  1
574458  97.328  -57.984  52.073  1
574459  97.358  -57.980  52.036  1
574460  97.389  -57.983  51.991  1
574461  97.424  -57.998  51.939  1
574462  97.459  -58.006  51.884  1
574463  97.495  -58.005  51.824  1
574464  97.530  -58.003  51.758  1
574465  97.566  -58.003  51.689  1
574466  97.601  -58.001  51.618  1
574467  97.637  -57.999  51.551  1
574468  97.672  -57.998  51.493  1
574469  97.708  -57.997  51.433  1
574470  97.743  -57.997  51.374  1
574471  97.777  -57.997  51.313  1
574472  97.817  -58.003  51.248  1
574473  97.858  -58.007  51.184  1
574474  97.898  -58.012  51.120  1
574475  97.939  -58.018  51.055  1
574476  97.980  -58.022  50.992  1
574477  98.018  -58.028  50.933  1
574478  98.057  -58.032  50.877  1
574479  98.093  -58.034  50.820  1
574480  98.127  -58.035  50.768  1
574481  98.161  -58.036  50.720  1
574482  98.195  -58.037  50.675  1
574483  98.229  -58.038  50.632  1
574484  98.263  -58.040  50.592  1
574485  98.297  -58.040  50.549  1
574486  98.331  -58.042  50.505  1
574487  98.364  -58.043  50.460  1
574488  98.394  -58.046  50.418  1
574489  98.426  -58.047  50.380  1
574490  98.456  -58.050  50.345  1
574491  98.488  -58.052  50.310  1
574492  98.519  -58.054  50.278  1
574493  98.550  -58.056  50.249  1
574494  98.581  -58.059  50.221  1
574495  98.612  -58.061  50.195  1
574496  98.642  -58.059  50.171  1
574497  98.657  -58.062  50.146  1
574498  98.646  -58.073  50.122  1
574499  98.645  -58.073  50.100  1
574500  98.643  -58.072  50.080  1
574501  98.657  -58.081  50.061  1
574502  98.681  -58.088  50.041  1
574503  98.725  -58.080  50.021  1
574504  98.766  -58.074  50.004  1
574505  98.806  -58.068  49.986  1
574506  98.846  -58.064  49.966  1
574507  98.885  -58.059  49.944  1
574508  98.925  -58.055  49.923  1
574509  98.965  -58.050  49.903  1
574510  99.005  -58.046  49.883  1
574511  99.045  -58.040  49.863  1
574512  99.084  -58.036  49.842  1
574513  99.124  -58.031  49.817  1
574514  99.164  -58.027  49.792  1
574515  99.204  -58.022  49.765  1
574516  99.243  -58.018  49.736  1
574517  99.282  -58.021  49.705  1
574518  99.319  -58.031  49.674  1
574519  99.325  -58.045  49.643  1
574520  99.355  -58.059  49.614  1
574521  99.423  -58.072  49.584  1
574522  99.474  -58.079  49.554  1
574523  99.511  -58.087  49.525  1
574524  99.546  -58.096  49.495  1
574525  99.580  -58.105  49.465  1
574526  99.615  -58.113  49.435  1
574527  99.649  -58.122  49.406  1
574528  99.684  -58.131  49.376  1
574529  99.718  -58.140  49.347  1
574530  99.753  -58.149  49.317  1
574884  87.852  -54.522  57.598  4
574885  87.887  -54.537  57.598  4
574886  87.922  -54.552  57.599  4
574887  87.958  -54.568  57.598  4
574888  87.993  -54.583  57.597  4
574889  88.029  -54.599  57.594  4
574890  88.064  -54.614  57.591  4
574891  88.100  -54.629  57.588  4
574892  88.135  -54.645  57.582  4
574893  88.170  -54.660  57.576  4
574894  88.212  -54.655  57.569  4
574895  88.278  -54.590  57.561  4
574896  88.335  -54.593  57.551  4
574897  88.381  -54.590  57.538  4
574898  88.417  -54.581  57.524  4
574899  88.453  -54.571  57.509  4
574900  88.489  -54.577  57.493  4
574901  88.528  -54.599  57.476  4
574902  88.566  -54.622  57.456  4
574903  88.605  -54.646  57.422  4
574904  88.644  -54.669  57.383  4
574905  88.682  -54.692  57.344  4
574906  88.721  -54.715  57.303  4
574907  88.760  -54.739  57.258  4
574908  88.798  -54.762  57.210  4
574909  88.837  -54.786  57.161  4
574910  88.876  -54.809  57.111  4
574911  88.914  -54.833  57.061  4
574912  88.953  -54.856  57.010  4
574913  88.991  -54.880  56.960  4
574914  89.030  -54.903  56.909  4
574915  89.068  -54.926  56.860  4
574947  90.188  -55.605  55.744  1
574948  90.214  -55.622  55.742  1
574949  90.241  -55.642  55.743  1
574950  90.268  -55.659  55.746  1
574951  90.293  -55.670  55.751  1
574952  90.319  -55.680  55.759  1
574953  90.344  -55.690  55.768  1
574954  90.383  -55.700  55.779  1
574955  90.423  -55.711  55.792  1
574956  90.463  -55.721  55.811  1
574957  90.502  -55.731  55.833  1
574958  90.542  -55.741  55.858  1
574959  90.582  -55.751  55.886  1
574960  90.621  -55.762  55.906  1
574961  90.661  -55.771  55.925  1
574962  90.700  -55.781  55.953  1
574963  90.740  -55.792  55.992  1
574964  90.780  -55.802  56.037  1
574965  90.819  -55.812  56.084  1
574966  90.859  -55.822  56.117  1
574967  90.899  -55.832  56.120  1
574968  90.939  -55.843  56.105  1
574969  90.978  -55.853  56.082  1
574970  91.018  -55.862  56.060  1
574971  91.056  -55.874  56.051  1
574972  91.091  -55.886  56.023  1
574973  91.132  -55.897  56.021  1
574974  91.176  -55.908  56.011  1
574975  91.221  -55.919  55.982  1
574976  91.255  -55.925  55.938  1
574977  91.287  -55.930  55.897  1
574978  91.320  -55.936  55.852  1
574979  91.352  -55.941  55.817  1
574980  91.385  -55.947  55.790  1
574981  91.417  -55.953  55.763  1
574982  91.450  -55.959  55.730  1
574983  91.482  -55.964  55.696  1
574984  91.515  -55.969  55.666  1
574985  91.548  -55.975  55.631  1
574986  91.584  -55.983  55.592  1
574987  91.616  -55.992  55.553  1
574988  91.653  -56.003  55.513  1
574989  91.690  -56.013  55.479  1
574990  91.727  -56.024  55.453  1
574991  91.764  -56.034  55.435  1
574992  91.800  -56.045  55.423  1
574993  91.837  -56.056  55.414  1
574994  91.873  -56.066  55.403  1
574995  91.910  -56.077  55.387  1
574996  91.947  -56.088  55.366  1
574997  91.983  -56.098  55.342  1
574998  92.019  -56.113  55.315  1
574999  92.051  -56.137  55.288  1
575000  92.083  -56.160  55.267  1
575001  92.116  -56.183  55.258  1
575002  92.148  -56.207  55.257  1
575003  92.180  -56.230  55.261  1
575004  92.218  -56.266  55.268  1
575005  92.255  -56.304  55.276  1
575006  92.292  -56.340  55.284  1
575007  92.330  -56.377  55.287  1
575008  92.367  -56.414  55.286  1
575009  92.404  -56.451  55.287  1
575010  92.441  -56.488  55.290  1
575011  92.480  -56.513  55.296  1
575012  92.519  -56.532  55.297  1
575013  92.558  -56.551  55.292  1
575014  92.597  -56.570  55.287  1
575015  92.636  -56.589  55.293  1
575016  92.675  -56.608  55.311  1
575017  92.713  -56.628  55.331  1
575018  92.747  -56.649  55.345  1
575019  92.782  -56.670  55.352  1
575020  92.817  -56.690  55.362  1
575021  92.852  -56.711  55.377  1
575022  92.893  -56.727  55.393  1
575023  92.936  -56.740  55.401  1
575024  92.979  -56.754  55.403  1
575025  93.022  -56.768  55.399  1
575026  93.065  -56.781  55.390  1
575027  93.109  -56.795  55.380  1
575028  93.149  -56.807  55.370  1
575029  93.179  -56.814  55.361  1
575030  93.207  -56.820  55.349  1
575031  93.236  -56.827  55.332  1
575032  93.265  -56.834  55.312  1
575033  93.294  -56.840  55.291  1
575034  93.327  -56.852  55.273  1
575035  93.359  -56.864  55.254  1
575036  93.392  -56.875  55.232  1
575037  93.425  -56.887  55.206  1
575038  93.458  -56.899  55.179  1
575039  93.490  -56.911  55.152  1
575040  93.523  -56.923  55.122  1
575041  93.556  -56.935  55.087  1
575042  93.588  -56.946  55.049  1
575043  93.621  -56.959  55.013  1
575044  93.653  -56.971  54.980  1
575045  93.686  -56.982  54.952  1
575046  93.719  -56.994  54.924  1
575047  93.752  -57.006  54.893  1
575048  93.784  -57.018  54.863  1
575049  93.817  -57.030  54.835  1
575050  93.850  -57.042  54.807  1
575051  93.883  -57.054  54.778  1
575052  93.915  -57.065  54.750  1
575053  93.948  -57.069  54.716  1
575054  93.982  -57.072  54.682  1
575055  94.016  -57.076  54.647  1
575056  94.050  -57.080  54.613  1
575057  94.083  -57.084  54.579  1
575058  94.117  -57.087  54.546  1
575059  94.151  -57.094  54.509  1
575060  94.189  -57.117  54.473  1
575061  94.226  -57.140  54.435  1
575062  94.263  -57.163  54.397  1
575063  94.299  -57.184  54.359  1
575064  94.332  -57.196  54.319  1
575065  94.364  -57.209  54.275  1
575066  94.397  -57.221  54.227  1
575067  94.429  -57.233  54.180  1
575068  94.461  -57.246  54.140  1
575069  94.494  -57.258  54.112  1
575070  94.526  -57.271  54.088  1
575071  94.558  -57.283  54.064  1
575072  94.591  -57.295  54.043  1
575073  94.623  -57.308  54.024  1
575074  94.655  -57.320  54.008  1
575075  94.688  -57.333  53.994  1
575076  94.720  -57.345  53.984  1
575077  94.752  -57.357  53.976  1
575078  94.784  -57.370  53.971  1
575079  94.817  -57.382  53.967  1
575080  94.849  -57.395  53.961  1
575081  94.882  -57.407  53.950  1
575082  94.914  -57.420  53.939  1
575083  94.946  -57.432  53.924  1
575084  94.979  -57.445  53.907  1
575085  95.011  -57.457  53.887  1
575086  95.043  -57.469  53.861  1
575087  95.073  -57.479  53.832  1
575088  95.103  -57.489  53.796  1
575089  95.133  -57.499  53.755  1
575090  95.163  -57.509  53.711  1
575091  95.193  -57.519  53.664  1
575092  95.224  -57.529  53.615  1
575093  95.254  -57.539  53.564  1
575094  95.284  -57.549  53.514  1
575095  95.314  -57.559  53.469  1
575096  95.344  -57.570  53.425  1
575097  95.374  -57.579  53.379  1
575098  95.404  -57.589  53.328  1
575099  95.444  -57.597  53.274  1
575100  95.487  -57.601  53.217  1
575101  95.531  -57.606  53.159  1
575102  95.574  -57.611  53.102  1
575103  95.618  -57.616  53.045  1
575104  95.662  -57.620  52.989  1
575105  95.706  -57.625  52.939  1
575106  95.750  -57.630  52.892  1
575107  95.794  -57.634  52.848  1
575108  95.823  -57.639  52.807  1
575109  95.843  -57.645  52.765  1
575110  95.865  -57.651  52.725  1
575111  95.886  -57.656  52.684  1
575112  95.906  -57.662  52.643  1
575113  95.927  -57.667  52.605  1
575114  95.948  -57.673  52.571  1
575115  95.974  -57.680  52.538  1
575116  96.004  -57.687  52.511  1
575117  96.033  -57.695  52.487  1
575118  96.061  -57.702  52.465  1
575119  96.091  -57.710  52.446  1
575120  96.120  -57.717  52.428  1
575121  96.149  -57.725  52.412  1
575122  96.178  -57.733  52.398  1
575123  96.207  -57.740  52.386  1
575124  96.239  -57.750  52.377  1
575125  96.273  -57.760  52.370  1
575126  96.307  -57.771  52.365  1
575127  96.341  -57.781  52.363  1
575128  96.375  -57.791  52.362  1
575129  96.408  -57.802  52.356  1
575130  96.442  -57.812  52.345  1
575131  96.476  -57.822  52.331  1
575132  96.510  -57.833  52.318  1
575133  96.544  -57.843  52.303  1
575134  96.578  -57.853  52.285  1
575135  96.612  -57.864  52.268  1
575136  96.646  -57.874  52.251  1
575137  96.679  -57.884  52.235  1
575138  96.711  -57.895  52.223  1
575139  96.739  -57.906  52.214  1
575140  96.767  -57.917  52.209  1
575141  96.795  -57.928  52.207  1
575142  96.823  -57.939  52.206  1
575143  96.852  -57.949  52.204  1
575144  96.880  -57.961  52.202  1
575145  96.908  -57.971  52.200  1
575146  96.938  -57.981  52.205  1
575147  96.975  -57.986  52.213  1
575148  97.009  -57.989  52.222  1
575149  97.037  -57.985  52.228  1
575150  97.066  -57.982  52.231  1
575151  97.094  -57.978  52.228  1
575152  97.123  -57.975  52.223  1
575153  97.152  -57.971  52.213  1
575154  97.182  -57.968  52.198  1
575155  97.212  -57.964  52.180  1
575156  97.241  -57.959  52.161  1
575157  97.271  -57.955  52.141  1
575158  97.300  -57.952  52.115  1
575159  97.330  -57.948  52.085  1
575160  97.360  -57.944  52.050  1
575161  97.389  -57.940  52.006  1
575162  97.424  -57.955  51.956  1
575163  97.459  -57.971  51.901  1
575164  97.494  -57.974  51.839  1
575165  97.530  -57.974  51.772  1
575166  97.566  -57.972  51.701  1
575167  97.601  -57.971  51.630  1
575168  97.637  -57.969  51.565  1
575169  97.672  -57.968  51.507  1
575170  97.708  -57.967  51.451  1
575171  97.743  -57.965  51.394  1
575172  97.779  -57.964  51.334  1
575173  97.815  -57.967  51.271  1
575174  97.853  -57.972  51.205  1
575175  97.891  -57.977  51.140  1
575176  97.929  -57.983  51.074  1
575177  97.967  -57.988  51.011  1
575178  98.005  -57.993  50.951  1
575179  98.043  -57.999  50.894  1
575180  98.083  -58.001  50.839  1
575181  98.124  -58.004  50.786  1
575182  98.163  -58.006  50.736  1
575183  98.199  -58.008  50.688  1
575184  98.232  -58.009  50.642  1
575185  98.267  -58.010  50.598  1
575186  98.300  -58.011  50.555  1
575187  98.335  -58.012  50.513  1
575188  98.368  -58.013  50.473  1
575189  98.400  -58.015  50.434  1
575190  98.431  -58.018  50.397  1
575191  98.461  -58.020  50.361  1
575192  98.493  -58.022  50.325  1
575193  98.523  -58.024  50.291  1
575194  98.555  -58.027  50.260  1
575195  98.584  -58.025  50.231  1
575196  98.614  -58.023  50.205  1
575197  98.644  -58.021  50.181  1
575198  98.673  -58.018  50.157  1
575199  98.671  -58.027  50.132  1
575200  98.658  -58.040  50.111  1
575201  98.646  -58.053  50.091  1
575202  98.637  -58.062  50.071  1
575203  98.676  -58.059  50.052  1
575204  98.716  -58.053  50.032  1
575205  98.756  -58.049  50.014  1
575206  98.795  -58.044  49.996  1
575207  98.835  -58.040  49.975  1
575208  98.875  -58.035  49.953  1
575209  98.915  -58.031  49.931  1
575210  98.954  -58.025  49.910  1
575211  98.994  -58.021  49.890  1
575212  99.034  -58.016  49.870  1
575213  99.074  -58.012  49.847  1
575214  99.114  -58.007  49.822  1
575215  99.153  -58.003  49.796  1
575216  99.193  -57.997  49.769  1
575217  99.233  -57.993  49.740  1
575218  99.272  -57.993  49.709  1
575219  99.308  -58.003  49.677  1
575220  99.333  -58.015  49.645  1
575221  99.336  -58.030  49.615  1
575222  99.403  -58.043  49.585  1
575223  99.460  -58.052  49.554  1
575224  99.504  -58.059  49.524  1
575225  99.539  -58.068  49.494  1
575226  99.573  -58.077  49.463  1
575227  99.608  -58.086  49.431  1
575228  99.642  -58.094  49.402  1
575229  99.677  -58.103  49.373  1
575230  99.711  -58.112  49.342  1
575231  99.746  -58.121  49.312  1
575584  87.841  -54.472  57.596  4
575585  87.876  -54.487  57.597  4
575586  87.912  -54.502  57.598  4
575587  87.947  -54.518  57.599  4
575588  87.983  -54.533  57.598  4
575589  88.018  -54.549  57.597  4
575590  88.053  -54.564  57.595  4
575591  88.088  -54.579  57.592  4
575592  88.124  -54.594  57.589  4
575593  88.160  -54.609  57.584  4
575594  88.195  -54.625  57.579  4
575595  88.230  -54.640  57.572  4
575596  88.295  -54.567  57.564  4
575597  88.354  -54.554  57.555  4
575598  88.404  -54.552  57.543  4
575599  88.440  -54.543  57.530  4
575600  88.476  -54.534  57.515  4
575601  88.511  -54.554  57.501  4
575602  88.550  -54.571  57.488  4
575603  88.588  -54.590  57.471  4
575604  88.626  -54.614  57.437  4
575605  88.665  -54.637  57.396  4
575606  88.704  -54.660  57.356  4
575607  88.742  -54.684  57.315  4
575608  88.781  -54.707  57.270  4
575609  88.820  -54.731  57.222  4
575610  88.858  -54.754  57.173  4
575611  88.897  -54.778  57.123  4
575612  88.935  -54.801  57.073  4
575613  88.974  -54.825  57.023  4
575614  89.013  -54.848  56.973  4
575615  89.051  -54.871  56.922  4
575616  89.090  -54.894  56.873  4
575648  90.207  -55.573  55.748  1
575649  90.231  -55.587  55.746  1
575650  90.258  -55.607  55.748  1
575651  90.286  -55.626  55.751  1
575652  90.311  -55.636  55.757  1
575653  90.336  -55.646  55.765  1
575654  90.362  -55.657  55.775  1
575655  90.395  -55.667  55.787  1
575656  90.435  -55.677  55.802  1
575657  90.474  -55.687  55.823  1
575658  90.514  -55.697  55.850  1
575659  90.554  -55.708  55.881  1
575660  90.593  -55.718  55.913  1
575661  90.633  -55.728  55.936  1
575662  90.673  -55.738  55.952  1
575663  90.713  -55.748  55.981  1
575664  90.752  -55.759  56.025  1
575665  90.792  -55.768  56.080  1
575666  90.831  -55.778  56.135  1
575667  90.871  -55.789  56.156  1
575668  90.910  -55.799  56.151  1
575669  90.950  -55.809  56.134  1
575670  90.990  -55.819  56.115  1
575671  91.029  -55.829  56.098  1
575672  91.069  -55.840  56.084  1
575673  91.109  -55.850  56.056  1
575674  91.146  -55.861  56.054  1
575675  91.188  -55.872  56.045  1
575676  91.226  -55.880  56.014  1
575677  91.259  -55.885  55.963  1
575678  91.291  -55.891  55.917  1
575679  91.324  -55.897  55.873  1
575680  91.357  -55.903  55.843  1
575681  91.393  -55.909  55.816  1
575682  91.429  -55.917  55.782  1
575683  91.464  -55.924  55.740  1
575684  91.500  -55.931  55.701  1
575685  91.536  -55.937  55.669  1
575686  91.572  -55.945  55.633  1
575687  91.604  -55.953  55.594  1
575688  91.635  -55.963  55.556  1
575689  91.666  -55.972  55.516  1
575690  91.703  -55.984  55.481  1
575691  91.739  -55.994  55.455  1
575692  91.776  -56.005  55.435  1
575693  91.812  -56.016  55.419  1
575694  91.849  -56.026  55.408  1
575695  91.886  -56.037  55.396  1
575696  91.922  -56.047  55.382  1
575697  91.959  -56.058  55.363  1
575698  91.995  -56.069  55.341  1
575699  92.028  -56.093  55.314  1
575700  92.060  -56.116  55.286  1
575701  92.093  -56.140  55.262  1
575702  92.125  -56.163  55.250  1
575703  92.157  -56.187  55.246  1
575704  92.190  -56.210  55.249  1
575705  92.223  -56.235  55.257  1
575706  92.260  -56.271  55.267  1
575707  92.297  -56.308  55.274  1
575708  92.335  -56.345  55.281  1
575709  92.372  -56.382  55.285  1
575710  92.409  -56.419  55.288  1
575711  92.446  -56.456  55.289  1
575712  92.485  -56.476  55.286  1
575713  92.524  -56.495  55.277  1
575714  92.563  -56.514  55.271  1
575715  92.602  -56.534  55.270  1
575716  92.641  -56.553  55.279  1
575717  92.681  -56.572  55.299  1
575718  92.719  -56.591  55.321  1
575719  92.754  -56.612  55.332  1
575720  92.788  -56.633  55.344  1
575721  92.823  -56.654  55.364  1
575722  92.858  -56.674  55.385  1
575723  92.901  -56.688  55.400  1
575724  92.944  -56.702  55.408  1
575725  92.987  -56.715  55.410  1
575726  93.030  -56.729  55.408  1
575727  93.073  -56.743  55.401  1
575728  93.117  -56.756  55.392  1
575729  93.160  -56.770  55.382  1
575730  93.190  -56.777  55.368  1
575731  93.218  -56.783  55.353  1
575732  93.248  -56.790  55.334  1
575733  93.276  -56.796  55.312  1
575734  93.305  -56.803  55.290  1
575735  93.338  -56.815  55.270  1
575736  93.371  -56.827  55.250  1
575737  93.404  -56.839  55.228  1
575738  93.436  -56.851  55.202  1
575739  93.469  -56.863  55.175  1
575740  93.502  -56.874  55.146  1
575741  93.535  -56.887  55.117  1
575742  93.567  -56.899  55.082  1
575743  93.600  -56.910  55.046  1
575744  93.632  -56.922  55.010  1
575745  93.665  -56.934  54.976  1
575746  93.698  -56.946  54.947  1
575747  93.730  -56.958  54.921  1
575748  93.763  -56.970  54.892  1
575749  93.796  -56.981  54.864  1
575750  93.828  -56.993  54.836  1
575751  93.861  -57.006  54.808  1
575752  93.894  -57.017  54.780  1
575753  93.926  -57.029  54.752  1
575754  93.959  -57.041  54.720  1
575755  93.993  -57.044  54.688  1
575756  94.027  -57.048  54.656  1
575757  94.060  -57.052  54.625  1
575758  94.094  -57.056  54.593  1
575759  94.127  -57.059  54.560  1
575760  94.161  -57.065  54.525  1
575761  94.199  -57.087  54.489  1
575762  94.236  -57.110  54.451  1
575763  94.273  -57.133  54.412  1
575764  94.308  -57.149  54.373  1
575765  94.340  -57.162  54.333  1
575766  94.372  -57.174  54.288  1
575767  94.404  -57.187  54.241  1
575768  94.436  -57.199  54.192  1
575769  94.469  -57.211  54.143  1
575770  94.501  -57.224  54.100  1
575771  94.534  -57.236  54.070  1
575772  94.566  -57.249  54.044  1
575773  94.598  -57.261  54.022  1
575774  94.631  -57.273  54.001  1
575775  94.663  -57.286  53.983  1
575776  94.695  -57.298  53.966  1
575777  94.728  -57.310  53.953  1
575778  94.760  -57.323  53.943  1
575779  94.792  -57.335  53.937  1
575780  94.825  -57.348  53.933  1
575781  94.857  -57.360  53.926  1
575782  94.889  -57.373  53.913  1
575783  94.921  -57.385  53.901  1
575784  94.954  -57.398  53.889  1
575785  94.986  -57.410  53.875  1
575786  95.019  -57.423  53.859  1
575787  95.051  -57.435  53.838  1
575788  95.082  -57.446  53.810  1
575789  95.112  -57.456  53.777  1
575790  95.142  -57.466  53.738  1
575791  95.172  -57.476  53.694  1
575792  95.202  -57.486  53.646  1
575793  95.233  -57.496  53.596  1
575794  95.263  -57.506  53.547  1
575795  95.293  -57.517  53.497  1
575796  95.323  -57.526  53.450  1
575797  95.353  -57.536  53.406  1
575798  95.384  -57.546  53.363  1
575799  95.419  -57.557  53.314  1
575800  95.456  -57.567  53.262  1
575801  95.498  -57.573  53.206  1
575802  95.542  -57.577  53.151  1
575803  95.586  -57.582  53.095  1
575804  95.629  -57.586  53.037  1
575805  95.673  -57.592  52.978  1
575806  95.717  -57.596  52.925  1
575807  95.761  -57.601  52.874  1
575808  95.805  -57.605  52.830  1
575809  95.828  -57.611  52.789  1
575810  95.849  -57.617  52.749  1
575811  95.870  -57.622  52.710  1
575812  95.891  -57.627  52.669  1
575813  95.912  -57.633  52.630  1
575814  95.933  -57.639  52.594  1
575815  95.954  -57.644  52.561  1
575816  95.977  -57.650  52.529  1
575817  96.006  -57.658  52.500  1
575818  96.035  -57.665  52.471  1
575819  96.064  -57.673  52.447  1
575820  96.093  -57.680  52.426  1
575821  96.122  -57.688  52.408  1
575822  96.151  -57.696  52.392  1
575823  96.180  -57.704  52.377  1
575824  96.209  -57.711  52.365  1
575825  96.238  -57.719  52.356  1
575826  96.269  -57.727  52.348  1
575827  96.304  -57.738  52.343  1
575828  96.337  -57.749  52.339  1
575829  96.371  -57.758  52.336  1
575830  96.405  -57.769  52.331  1
575831  96.439  -57.780  52.321  1
575832  96.473  -57.789  52.308  1
575833  96.507  -57.800  52.294  1
575834  96.541  -57.811  52.277  1
575835  96.575  -57.821  52.260  1
575836  96.608  -57.831  52.244  1
575837  96.643  -57.841  52.228  1
575838  96.676  -57.852  52.213  1
575839  96.705  -57.862  52.201  1
575840  96.734  -57.874  52.192  1
575841  96.762  -57.884  52.185  1
575842  96.790  -57.896  52.182  1
575843  96.818  -57.906  52.179  1
575844  96.847  -57.918  52.175  1
575845  96.875  -57.928  52.171  1
575846  96.906  -57.937  52.169  1
575847  96.943  -57.942  52.174  1
575848  96.979  -57.947  52.185  1
575849  97.014  -57.951  52.199  1
575850  97.043  -57.947  52.211  1
575851  97.071  -57.944  52.219  1
575852  97.100  -57.941  52.223  1
575853  97.128  -57.937  52.220  1
575854  97.157  -57.934  52.212  1
575855  97.185  -57.930  52.199  1
575856  97.214  -57.927  52.184  1
575857  97.243  -57.924  52.167  1
575858  97.273  -57.920  52.146  1
575859  97.303  -57.915  52.121  1
575860  97.332  -57.912  52.092  1
575861  97.362  -57.908  52.057  1
575862  97.391  -57.904  52.016  1
575863  97.425  -57.913  51.970  1
575864  97.459  -57.928  51.914  1
575865  97.494  -57.943  51.853  1
575866  97.530  -57.943  51.784  1
575867  97.565  -57.942  51.712  1
575868  97.601  -57.940  51.642  1
575869  97.636  -57.940  51.578  1
575870  97.672  -57.938  51.520  1
575871  97.708  -57.937  51.467  1
575872  97.742  -57.936  51.412  1
575873  97.774  -57.936  51.354  1
575874  97.805  -57.936  51.291  1
575875  97.840  -57.938  51.225  1
575876  97.878  -57.943  51.159  1
575877  97.916  -57.949  51.093  1
575878  97.954  -57.954  51.031  1
575879  97.992  -57.959  50.971  1
575880  98.030  -57.964  50.913  1
575881  98.070  -57.968  50.858  1
575882  98.110  -57.970  50.805  1
575883  98.150  -57.973  50.754  1
575884  98.190  -57.975  50.705  1
575885  98.230  -57.978  50.658  1
575886  98.270  -57.981  50.612  1
575887  98.304  -57.982  50.568  1
575888  98.338  -57.983  50.527  1
575889  98.372  -57.984  50.488  1
575890  98.405  -57.986  50.450  1
575891  98.435  -57.988  50.413  1
575892  98.466  -57.990  50.376  1
575893  98.497  -57.992  50.339  1
575894  98.527  -57.990  50.306  1
575895  98.557  -57.988  50.274  1
575896  98.586  -57.986  50.245  1
575897  98.616  -57.984  50.218  1
575898  98.645  -57.981  50.193  1
575899  98.675  -57.979  50.167  1
575900  98.698  -57.979  50.143  1
575901  98.685  -57.992  50.122  1
575902  98.672  -58.004  50.102  1
575903  98.660  -58.017  50.083  1
575904  98.680  -58.024  50.063  1
575905  98.705  -58.029  50.043  1
575906  98.745  -58.024  50.024  1
575907  98.785  -58.020  50.005  1
575908  98.825  -58.015  49.984  1
575909  98.864  -58.010  49.962  1
575910  98.904  -58.006  49.940  1
575911  98.944  -58.001  49.918  1
575912  98.984  -57.996  49.896  1
575913  99.023  -57.992  49.874  1
575914  99.063  -57.987  49.850  1
575915  99.103  -57.982  49.824  1
575916  99.143  -57.977  49.798  1
575917  99.183  -57.973  49.772  1
575918  99.222  -57.968  49.742  1
575919  99.262  -57.966  49.711  1
575920  99.298  -57.976  49.679  1
575921  99.336  -57.987  49.646  1
575922  99.344  -58.000  49.615  1
575923  99.382  -58.015  49.584  1
575924  99.445  -58.025  49.553  1
575925  99.496  -58.031  49.522  1
575926  99.531  -58.040  49.491  1
575927  99.565  -58.050  49.460  1
575928  99.600  -58.058  49.428  1
575929  99.634  -58.067  49.398  1
575930  99.669  -58.075  49.367  1
575931  99.703  -58.084  49.337  1
575932  99.738  -58.093  49.306  1
575933  99.772  -58.102  49.276  1
576285  87.866  -54.436  57.596  4
576286  87.901  -54.452  57.596  4
576287  87.936  -54.467  57.597  4
576288  87.972  -54.483  57.598  4
576289  88.007  -54.498  57.598  4
576290  88.043  -54.513  57.598  4
576291  88.078  -54.529  57.596  4
576292  88.113  -54.544  57.593  4
576293  88.149  -54.559  57.590  4
576294  88.184  -54.574  57.585  4
576295  88.219  -54.590  57.581  4
576296  88.255  -54.605  57.575  4
576297  88.311  -54.561  57.568  4
576298  88.374  -54.515  57.560  4
576299  88.426  -54.515  57.550  4
576300  88.462  -54.506  57.539  4
576301  88.498  -54.497  57.526  4
576302  88.534  -54.530  57.512  4
576303  88.571  -54.548  57.498  4
576304  88.610  -54.565  57.480  4
576305  88.648  -54.582  57.446  4
576306  88.686  -54.605  57.407  4
576307  88.725  -54.628  57.367  4
576308  88.764  -54.652  57.325  4
576309  88.802  -54.675  57.281  4
576310  88.841  -54.699  57.233  4
576311  88.880  -54.722  57.184  4
576312  88.918  -54.746  57.135  4
576313  88.957  -54.769  57.085  4
576314  88.995  -54.793  57.035  4
576315  89.034  -54.815  56.985  4
576316  89.072  -54.839  56.936  4
576317  89.111  -54.862  56.887  4
576348  90.203  -55.525  55.758  1
576349  90.226  -55.539  55.753  1
576350  90.250  -55.553  55.751  1
576351  90.276  -55.571  55.752  1
576352  90.303  -55.591  55.757  1
576353  90.329  -55.603  55.763  1
576354  90.355  -55.613  55.771  1
576355  90.380  -55.624  55.782  1
576356  90.407  -55.633  55.795  1
576357  90.447  -55.644  55.812  1
576358  90.486  -55.654  55.835  1
576359  90.526  -55.664  55.864  1
576360  90.566  -55.674  55.897  1
576361  90.605  -55.684  55.931  1
576362  90.645  -55.694  55.957  1
576363  90.684  -55.705  55.975  1
576364  90.724  -55.715  56.005  1
576365  90.764  -55.725  56.051  1
576366  90.804  -55.735  56.107  1
576367  90.843  -55.745  56.162  1
576368  90.883  -55.756  56.175  1
576369  90.923  -55.765  56.171  1
576370  90.962  -55.775  56.157  1
576371  91.002  -55.786  56.141  1
576372  91.041  -55.796  56.126  1
576373  91.081  -55.806  56.106  1
576374  91.120  -55.816  56.082  1
576375  91.160  -55.826  56.078  1
576376  91.202  -55.837  56.069  1
576377  91.238  -55.843  56.038  1
576378  91.274  -55.850  55.984  1
576379  91.309  -55.858  55.933  1
576380  91.345  -55.865  55.895  1
576381  91.381  -55.872  55.869  1
576382  91.417  -55.878  55.843  1
576383  91.452  -55.886  55.804  1
576384  91.488  -55.893  55.754  1
576385  91.524  -55.900  55.706  1
576386  91.560  -55.906  55.668  1
576387  91.592  -55.915  55.628  1
576388  91.623  -55.925  55.587  1
576389  91.653  -55.934  55.547  1
576390  91.684  -55.944  55.508  1
576391  91.715  -55.953  55.475  1
576392  91.751  -55.964  55.449  1
576393  91.788  -55.975  55.427  1
576394  91.825  -55.986  55.409  1
576395  91.861  -55.997  55.396  1
576396  91.898  -56.007  55.384  1
576397  91.935  -56.018  55.372  1
576398  91.971  -56.028  55.356  1
576399  92.005  -56.050  55.335  1
576400  92.037  -56.073  55.310  1
576401  92.069  -56.097  55.283  1
576402  92.102  -56.119  55.257  1
576403  92.134  -56.143  55.244  1
576404  92.167  -56.166  55.239  1
576405  92.199  -56.190  55.241  1
576406  92.231  -56.213  55.248  1
576407  92.265  -56.239  55.258  1
576408  92.302  -56.276  55.267  1
576409  92.339  -56.313  55.276  1
576410  92.376  -56.350  55.283  1
576411  92.414  -56.387  55.285  1
576412  92.451  -56.421  55.281  1
576413  92.490  -56.440  55.273  1
576414  92.529  -56.459  55.268  1
576415  92.569  -56.478  55.271  1
576416  92.607  -56.498  55.280  1
576417  92.647  -56.517  55.290  1
576418  92.686  -56.536  55.301  1
576419  92.725  -56.555  55.309  1
576420  92.760  -56.576  55.321  1
576421  92.795  -56.596  55.342  1
576422  92.829  -56.617  55.365  1
576423  92.866  -56.636  55.385  1
576424  92.910  -56.649  55.400  1
576425  92.952  -56.663  55.410  1
576426  92.996  -56.677  55.415  1
576427  93.039  -56.690  55.418  1
576428  93.082  -56.704  55.417  1
576429  93.125  -56.718  55.411  1
576430  93.168  -56.731  55.401  1
576431  93.201  -56.740  55.382  1
576432  93.229  -56.746  55.363  1
576433  93.259  -56.752  55.342  1
576434  93.287  -56.759  55.321  1
576435  93.317  -56.767  55.298  1
576436  93.350  -56.779  55.275  1
576437  93.382  -56.790  55.251  1
576438  93.415  -56.802  55.226  1
576439  93.448  -56.815  55.198  1
576440  93.480  -56.826  55.169  1
576441  93.513  -56.838  55.139  1
576442  93.546  -56.850  55.110  1
576443  93.578  -56.862  55.075  1
576444  93.611  -56.874  55.040  1
576445  93.644  -56.886  55.006  1
576446  93.677  -56.897  54.973  1
576447  93.709  -56.909  54.942  1
576448  93.742  -56.921  54.913  1
576449  93.774  -56.933  54.882  1
576450  93.807  -56.945  54.854  1
576451  93.840  -56.957  54.826  1
576452  93.872  -56.968  54.800  1
576453  93.905  -56.981  54.775  1
576454  93.938  -56.993  54.748  1
576455  93.971  -57.005  54.719  1
576456  94.003  -57.016  54.689  1
576457  94.037  -57.021  54.660  1
576458  94.070  -57.024  54.631  1
576459  94.104  -57.028  54.602  1
576460  94.138  -57.031  54.571  1
576461  94.172  -57.035  54.536  1
576462  94.209  -57.058  54.499  1
576463  94.246  -57.081  54.462  1
576464  94.283  -57.103  54.424  1
576465  94.315  -57.115  54.385  1
576466  94.347  -57.127  54.345  1
576467  94.380  -57.140  54.302  1
576468  94.412  -57.152  54.255  1
576469  94.445  -57.165  54.205  1
576470  94.477  -57.177  54.151  1
576471  94.509  -57.189  54.095  1
576472  94.541  -57.202  54.056  1
576473  94.574  -57.214  54.026  1
576474  94.606  -57.226  54.001  1
576475  94.638  -57.239  53.979  1
576476  94.671  -57.251  53.959  1
576477  94.703  -57.264  53.940  1
576478  94.736  -57.276  53.925  1
576479  94.768  -57.288  53.912  1
576480  94.800  -57.301  53.903  1
576481  94.832  -57.313  53.896  1
576482  94.864  -57.326  53.886  1
576483  94.897  -57.338  53.874  1
576484  94.929  -57.351  53.864  1
576485  94.962  -57.363  53.853  1
576486  94.994  -57.376  53.842  1
576487  95.026  -57.388  53.827  1
576488  95.059  -57.401  53.807  1
576489  95.091  -57.413  53.783  1
576490  95.121  -57.423  53.750  1
576491  95.151  -57.433  53.713  1
576492  95.182  -57.443  53.670  1
576493  95.212  -57.453  53.622  1
576494  95.242  -57.464  53.571  1
576495  95.272  -57.473  53.520  1
576496  95.302  -57.483  53.472  1
576497  95.332  -57.494  53.426  1
576498  95.363  -57.504  53.382  1
576499  95.399  -57.514  53.340  1
576500  95.436  -57.523  53.295  1
576501  95.472  -57.534  53.244  1
576502  95.509  -57.544  53.192  1
576503  95.552  -57.548  53.139  1
576504  95.596  -57.553  53.085  1
576505  95.640  -57.558  53.028  1
576506  95.684  -57.563  52.971  1
576507  95.728  -57.567  52.916  1
576508  95.771  -57.572  52.862  1
576509  95.812  -57.576  52.815  1
576510  95.833  -57.583  52.773  1
576511  95.854  -57.588  52.734  1
576512  95.875  -57.593  52.695  1
576513  95.896  -57.599  52.655  1
576514  95.917  -57.605  52.617  1
576515  95.938  -57.610  52.582  1
576516  95.959  -57.616  52.551  1
576517  95.980  -57.621  52.521  1
576518  96.008  -57.629  52.489  1
576519  96.037  -57.636  52.459  1
576520  96.066  -57.644  52.432  1
576521  96.095  -57.651  52.408  1
576522  96.124  -57.659  52.389  1
576523  96.154  -57.667  52.372  1
576524  96.182  -57.674  52.358  1
576525  96.212  -57.682  52.347  1
576526  96.241  -57.689  52.338  1
576527  96.269  -57.697  52.330  1
576528  96.300  -57.705  52.324  1
576529  96.334  -57.716  52.320  1
576530  96.368  -57.726  52.316  1
576531  96.402  -57.736  52.311  1
576532  96.436  -57.747  52.302  1
576533  96.470  -57.757  52.288  1
576534  96.504  -57.767  52.271  1
576535  96.537  -57.777  52.252  1
576536  96.571  -57.788  52.235  1
576537  96.605  -57.799  52.218  1
576538  96.639  -57.808  52.202  1
576539  96.672  -57.819  52.189  1
576540  96.701  -57.830  52.178  1
576541  96.729  -57.841  52.169  1
576542  96.757  -57.852  52.162  1
576543  96.786  -57.863  52.156  1
576544  96.814  -57.874  52.150  1
576545  96.842  -57.885  52.145  1
576546  96.874  -57.893  52.140  1
576547  96.910  -57.898  52.140  1
576548  96.947  -57.903  52.145  1
576549  96.983  -57.908  52.156  1
576550  97.020  -57.913  52.171  1
576551  97.048  -57.909  52.186  1
576552  97.077  -57.906  52.198  1
576553  97.105  -57.903  52.205  1
576554  97.134  -57.899  52.207  1
576555  97.162  -57.896  52.202  1
576556  97.190  -57.893  52.194  1
576557  97.219  -57.890  52.182  1
576558  97.247  -57.887  52.167  1
576559  97.276  -57.883  52.145  1
576560  97.305  -57.880  52.118  1
576561  97.334  -57.876  52.087  1
576562  97.364  -57.872  52.054  1
576563  97.393  -57.868  52.017  1
576564  97.425  -57.871  51.977  1
576565  97.460  -57.886  51.925  1
576566  97.495  -57.900  51.863  1
576567  97.529  -57.913  51.795  1
576568  97.565  -57.912  51.723  1
576569  97.600  -57.911  51.653  1
576570  97.636  -57.909  51.589  1
576571  97.672  -57.908  51.531  1
576572  97.705  -57.907  51.479  1
576573  97.737  -57.907  51.426  1
576574  97.769  -57.907  51.369  1
576575  97.800  -57.908  51.307  1
576576  97.831  -57.908  51.240  1
576577  97.865  -57.909  51.177  1
576578  97.903  -57.914  51.113  1
576579  97.941  -57.919  51.051  1
576580  97.979  -57.924  50.992  1
576581  98.017  -57.930  50.935  1
576582  98.056  -57.934  50.879  1
576583  98.096  -57.937  50.825  1
576584  98.136  -57.939  50.773  1
576585  98.176  -57.942  50.725  1
576586  98.216  -57.944  50.679  1
576587  98.256  -57.947  50.634  1
576588  98.296  -57.949  50.587  1
576589  98.337  -57.952  50.545  1
576590  98.375  -57.955  50.506  1
576591  98.409  -57.955  50.468  1
576592  98.440  -57.958  50.430  1
576593  98.470  -57.956  50.392  1
576594  98.500  -57.954  50.353  1
576595  98.529  -57.951  50.321  1
576596  98.559  -57.949  50.290  1
576597  98.588  -57.946  50.260  1
576598  98.618  -57.944  50.233  1
576599  98.647  -57.942  50.206  1
576600  98.677  -57.940  50.178  1
576601  98.707  -57.937  50.154  1
576602  98.712  -57.943  50.134  1
576603  98.699  -57.956  50.115  1
576604  98.687  -57.968  50.095  1
576605  98.704  -57.976  50.075  1
576606  98.727  -57.982  50.056  1
576607  98.750  -57.989  50.035  1
576608  98.774  -57.995  50.014  1
576609  98.814  -57.990  49.992  1
576610  98.854  -57.986  49.971  1
576611  98.894  -57.981  49.949  1
576612  98.933  -57.977  49.925  1
576613  98.973  -57.971  49.901  1
576614  99.013  -57.967  49.876  1
576615  99.053  -57.962  49.851  1
576616  99.092  -57.958  49.825  1
576617  99.132  -57.953  49.799  1
576618  99.172  -57.949  49.773  1
576619  99.212  -57.943  49.743  1
576620  99.252  -57.939  49.712  1
576621  99.288  -57.949  49.680  1
576622  99.326  -57.959  49.646  1
576623  99.352  -57.971  49.614  1
576624  99.361  -57.985  49.583  1
576625  99.430  -57.998  49.551  1
576626  99.482  -58.005  49.520  1
576627  99.523  -58.012  49.488  1
576628  99.558  -58.021  49.457  1
576629  99.592  -58.031  49.424  1
576630  99.627  -58.039  49.393  1
576631  99.661  -58.048  49.362  1
576632  99.696  -58.056  49.331  1
576633  99.730  -58.065  49.300  1
576634  99.765  -58.074  49.269  1
576635  99.799  -58.083  49.239  1
576985  87.855  -54.386  57.592  4
576986  87.891  -54.402  57.594  4
576987  87.926  -54.417  57.595  4
576988  87.961  -54.433  57.596  4
576989  87.996  -54.448  57.597  4
576990  88.032  -54.463  57.597  4
576991  88.067  -54.478  57.597  4
576992  88.103  -54.494  57.597  4
576993  88.138  -54.509  57.594  4
576994  88.173  -54.524  57.590  4
576995  88.209  -54.540  57.586  4
576996  88.244  -54.555  57.582  4
576997  88.279  -54.571  57.577  4
576998  88.326  -54.554  57.571  4
576999  88.393  -54.475  57.564  4
577000  88.449  -54.478  57.556  4
577001  88.485  -54.468  57.548  4
577002  88.521  -54.471  57.537  4
577003  88.555  -54.507  57.523  4
577004  88.594  -54.524  57.508  4
577005  88.631  -54.541  57.489  4
577006  88.670  -54.558  57.454  4
577007  88.708  -54.574  57.415  4
577008  88.746  -54.596  57.375  4
577009  88.785  -54.620  57.334  4
577010  88.824  -54.643  57.291  4
577011  88.862  -54.667  57.243  4
577012  88.901  -54.690  57.194  4
577013  88.940  -54.714  57.145  4
577014  88.978  -54.737  57.095  4
577015  89.017  -54.761  57.045  4
577016  89.055  -54.784  56.997  4
577017  89.094  -54.807  56.948  4
577018  89.132  -54.831  56.899  4
577048  90.199  -55.478  55.770  1
577049  90.222  -55.492  55.764  1
577050  90.245  -55.506  55.761  1
577051  90.268  -55.520  55.759  1
577052  90.293  -55.536  55.760  1
577053  90.321  -55.555  55.764  1
577054  90.347  -55.569  55.770  1
577055  90.372  -55.580  55.779  1
577056  90.398  -55.589  55.790  1
577057  90.424  -55.600  55.805  1
577058  90.458  -55.610  55.821  1
577059  90.498  -55.621  55.845  1
577060  90.538  -55.630  55.875  1
577061  90.578  -55.641  55.908  1
577062  90.617  -55.651  55.942  1
577063  90.657  -55.661  55.971  1
577064  90.696  -55.671  55.994  1
577065  90.736  -55.681  56.024  1
577066  90.776  -55.691  56.068  1
577067  90.815  -55.702  56.123  1
577068  90.855  -55.712  56.170  1
577069  90.894  -55.722  56.187  1
577070  90.934  -55.732  56.187  1
577071  90.974  -55.742  56.175  1
577072  91.014  -55.752  56.158  1
577073  91.053  -55.762  56.133  1
577074  91.093  -55.772  56.112  1
577075  91.133  -55.783  56.097  1
577076  91.178  -55.793  56.089  1
577077  91.224  -55.805  56.077  1
577078  91.261  -55.812  56.048  1
577079  91.297  -55.820  56.000  1
577080  91.333  -55.827  55.947  1
577081  91.369  -55.834  55.916  1
577082  91.404  -55.840  55.895  1
577083  91.440  -55.848  55.869  1
577084  91.476  -55.855  55.828  1
577085  91.512  -55.862  55.770  1
577086  91.547  -55.868  55.712  1
577087  91.581  -55.877  55.666  1
577088  91.611  -55.887  55.621  1
577089  91.642  -55.897  55.577  1
577090  91.672  -55.906  55.537  1
577091  91.703  -55.915  55.499  1
577092  91.733  -55.925  55.467  1
577093  91.764  -55.934  55.439  1
577094  91.800  -55.945  55.416  1
577095  91.837  -55.956  55.396  1
577096  91.874  -55.966  55.381  1
577097  91.911  -55.977  55.371  1
577098  91.947  -55.987  55.361  1
577099  91.981  -56.006  55.349  1
577100  92.014  -56.029  55.332  1
577101  92.046  -56.053  55.309  1
577102  92.079  -56.076  55.281  1
577103  92.111  -56.100  55.252  1
577104  92.143  -56.123  55.239  1
577105  92.176  -56.147  55.234  1
577106  92.208  -56.170  55.235  1
577107  92.241  -56.193  55.241  1
577108  92.273  -56.216  55.249  1
577109  92.307  -56.244  55.261  1
577110  92.344  -56.281  55.271  1
577111  92.381  -56.318  55.278  1
577112  92.419  -56.354  55.278  1
577113  92.456  -56.385  55.270  1
577114  92.496  -56.404  55.262  1
577115  92.535  -56.423  55.266  1
577116  92.574  -56.442  55.280  1
577117  92.613  -56.461  55.296  1
577118  92.652  -56.480  55.309  1
577119  92.691  -56.499  55.317  1
577120  92.730  -56.518  55.320  1
577121  92.766  -56.539  55.328  1
577122  92.801  -56.560  55.345  1
577123  92.836  -56.580  55.365  1
577124  92.874  -56.598  55.385  1
577125  92.918  -56.611  55.400  1
577126  92.961  -56.625  55.411  1
577127  93.004  -56.639  55.420  1
577128  93.047  -56.652  55.427  1
577129  93.090  -56.665  55.429  1
577130  93.133  -56.679  55.427  1
577131  93.176  -56.693  55.421  1
577132  93.212  -56.702  55.403  1
577133  93.240  -56.709  55.386  1
577134  93.270  -56.716  55.367  1
577135  93.298  -56.722  55.346  1
577136  93.329  -56.730  55.322  1
577137  93.361  -56.742  55.296  1
577138  93.394  -56.754  55.261  1
577139  93.426  -56.766  55.227  1
577140  93.459  -56.777  55.195  1
577141  93.492  -56.790  55.164  1
577142  93.524  -56.802  55.133  1
577143  93.557  -56.814  55.104  1
577144  93.590  -56.825  55.070  1
577145  93.623  -56.837  55.036  1
577146  93.655  -56.849  55.003  1
577147  93.688  -56.861  54.971  1
577148  93.720  -56.873  54.939  1
577149  93.753  -56.885  54.907  1
577150  93.786  -56.896  54.874  1
577151  93.819  -56.909  54.843  1
577152  93.851  -56.921  54.814  1
577153  93.884  -56.932  54.787  1
577154  93.917  -56.944  54.763  1
577155  93.949  -56.956  54.738  1
577156  93.982  -56.968  54.712  1
577157  94.014  -56.980  54.684  1
577158  94.047  -56.992  54.657  1
577159  94.081  -56.997  54.630  1
577160  94.115  -57.000  54.602  1
577161  94.148  -57.004  54.572  1
577162  94.182  -57.007  54.539  1
577163  94.219  -57.028  54.503  1
577164  94.256  -57.051  54.465  1
577165  94.290  -57.068  54.427  1
577166  94.323  -57.081  54.390  1
577167  94.355  -57.093  54.350  1
577168  94.388  -57.105  54.308  1
577169  94.420  -57.118  54.263  1
577170  94.452  -57.130  54.213  1
577171  94.484  -57.142  54.159  1
577172  94.517  -57.155  54.101  1
577173  94.549  -57.167  54.049  1
577174  94.581  -57.180  54.010  1
577175  94.614  -57.192  53.981  1
577176  94.646  -57.204  53.957  1
577177  94.678  -57.217  53.936  1
577178  94.711  -57.229  53.916  1
577179  94.743  -57.241  53.899  1
577180  94.775  -57.254  53.883  1
577181  94.808  -57.266  53.871  1
577182  94.840  -57.279  53.859  1
577183  94.873  -57.291  53.846  1
577184  94.905  -57.304  53.834  1
577185  94.937  -57.316  53.825  1
577186  94.969  -57.329  53.815  1
577187  95.001  -57.341  53.805  1
577188  95.034  -57.354  53.791  1
577189  95.066  -57.366  53.772  1
577190  95.099  -57.379  53.750  1
577191  95.130  -57.390  53.721  1
577192  95.161  -57.401  53.685  1
577193  95.191  -57.410  53.644  1
577194  95.221  -57.420  53.598  1
577195  95.251  -57.430  53.549  1
577196  95.281  -57.441  53.498  1
577197  95.311  -57.451  53.448  1
577198  95.343  -57.460  53.401  1
577199  95.379  -57.470  53.356  1
577200  95.415  -57.481  53.314  1
577201  95.452  -57.491  53.271  1
577202  95.488  -57.501  53.223  1
577203  95.525  -57.511  53.174  1
577204  95.563  -57.520  53.124  1
577205  95.607  -57.524  53.073  1
577206  95.651  -57.529  53.019  1
577207  95.695  -57.534  52.965  1
577208  95.739  -57.539  52.910  1
577209  95.782  -57.543  52.859  1
577210  95.818  -57.548  52.811  1
577211  95.839  -57.554  52.766  1
577212  95.860  -57.559  52.722  1
577213  95.881  -57.565  52.682  1
577214  95.901  -57.570  52.642  1
577215  95.922  -57.576  52.603  1
577216  95.944  -57.581  52.568  1
577217  95.964  -57.587  52.537  1
577218  95.985  -57.592  52.508  1
577219  96.011  -57.599  52.478  1
577220  96.039  -57.607  52.449  1
577221  96.068  -57.614  52.420  1
577222  96.098  -57.622  52.393  1
577223  96.126  -57.630  52.371  1
577224  96.156  -57.637  52.354  1
577225  96.185  -57.645  52.340  1
577226  96.214  -57.652  52.332  1
577227  96.243  -57.660  52.324  1
577228  96.272  -57.667  52.314  1
577229  96.301  -57.675  52.306  1
577230  96.331  -57.683  52.301  1
577231  96.365  -57.693  52.298  1
577232  96.398  -57.704  52.294  1
577233  96.433  -57.714  52.283  1
577234  96.466  -57.724  52.268  1
577235  96.500  -57.735  52.250  1
577236  96.534  -57.745  52.229  1
577237  96.568  -57.755  52.212  1
577238  96.602  -57.766  52.194  1
577239  96.636  -57.776  52.178  1
577240  96.668  -57.786  52.166  1
577241  96.696  -57.798  52.157  1
577242  96.724  -57.808  52.147  1
577243  96.752  -57.820  52.140  1
577244  96.781  -57.830  52.132  1
577245  96.809  -57.841  52.124  1
577246  96.841  -57.849  52.118  1
577247  96.878  -57.854  52.112  1
577248  96.914  -57.859  52.113  1
577249  96.951  -57.864  52.118  1
577250  96.987  -57.869  52.128  1
577251  97.024  -57.874  52.143  1
577252  97.054  -57.872  52.160  1
577253  97.082  -57.868  52.175  1
577254  97.111  -57.865  52.184  1
577255  97.139  -57.861  52.188  1
577256  97.168  -57.858  52.187  1
577257  97.196  -57.855  52.182  1
577258  97.225  -57.852  52.173  1
577259  97.253  -57.849  52.158  1
577260  97.282  -57.845  52.135  1
577261  97.310  -57.842  52.107  1
577262  97.338  -57.839  52.078  1
577263  97.367  -57.835  52.046  1
577264  97.395  -57.832  52.013  1
577265  97.425  -57.828  51.977  1
577266  97.460  -57.843  51.928  1
577267  97.495  -57.858  51.869  1
577268  97.529  -57.873  51.804  1
577269  97.565  -57.882  51.735  1
577270  97.600  -57.880  51.665  1
577271  97.636  -57.879  51.598  1
577272  97.668  -57.879  51.539  1
577273  97.700  -57.879  51.487  1
577274  97.731  -57.879  51.434  1
577275  97.763  -57.879  51.379  1
577276  97.795  -57.879  51.320  1
577277  97.826  -57.879  51.257  1
577278  97.858  -57.879  51.194  1
577279  97.890  -57.880  51.132  1
577280  97.928  -57.885  51.071  1
577281  97.966  -57.890  51.013  1
577282  98.004  -57.896  50.957  1
577283  98.043  -57.900  50.901  1
577284  98.083  -57.903  50.846  1
577285  98.123  -57.905  50.794  1
577286  98.163  -57.909  50.746  1
577287  98.203  -57.911  50.701  1
577288  98.243  -57.913  50.658  1
577289  98.283  -57.916  50.613  1
577290  98.323  -57.918  50.573  1
577291  98.363  -57.921  50.532  1
577292  98.407  -57.924  50.491  1
577293  98.442  -57.921  50.450  1
577294  98.472  -57.917  50.410  1
577295  98.501  -57.915  50.372  1
577296  98.531  -57.912  50.339  1
577297  98.561  -57.910  50.308  1
577298  98.590  -57.907  50.278  1
577299  98.620  -57.905  50.249  1
577300  98.649  -57.902  50.221  1
577301  98.679  -57.900  50.194  1
577302  98.709  -57.898  50.171  1
577303  98.738  -57.896  50.151  1
577304  98.726  -57.908  50.131  1
577305  98.713  -57.921  50.111  1
577306  98.728  -57.928  50.090  1
577307  98.751  -57.935  50.070  1
577308  98.774  -57.941  50.047  1
577309  98.798  -57.948  50.024  1
577310  98.821  -57.954  50.001  1
577311  98.844  -57.961  49.978  1
577312  98.882  -57.956  49.955  1
577313  98.922  -57.952  49.930  1
577314  98.962  -57.947  49.904  1
577315  99.002  -57.943  49.878  1
577316  99.042  -57.938  49.853  1
577317  99.082  -57.934  49.826  1
577318  99.122  -57.928  49.800  1
577319  99.161  -57.924  49.772  1
577320  99.201  -57.919  49.743  1
577321  99.241  -57.915  49.712  1
577322  99.278  -57.921  49.679  1
577323  99.315  -57.931  49.647  1
577324  99.352  -57.942  49.613  1
577325  99.363  -57.955  49.582  1
577326  99.410  -57.969  49.550  1
577327  99.467  -57.978  49.517  1
577328  99.516  -57.985  49.485  1
577329  99.550  -57.993  49.453  1
577330  99.585  -58.003  49.421  1
577331  99.619  -58.011  49.390  1
577332  99.654  -58.020  49.358  1
577333  99.688  -58.029  49.326  1
577334  99.723  -58.037  49.294  1
577335  99.757  -58.046  49.263  1
577336  99.791  -58.055  49.232  1
577337  99.826  -58.064  49.201  1
577686  87.880  -54.352  57.590  4
577687  87.915  -54.367  57.592  4
577688  87.951  -54.382  57.593  4
577689  87.986  -54.397  57.594  4
577690  88.021  -54.413  57.595  4
577691  88.057  -54.428  57.596  4
577692  88.092  -54.443  57.596  4
577693  88.127  -54.458  57.596  4
577694  88.163  -54.474  57.594  4
577695  88.198  -54.489  57.591  4
577696  88.234  -54.505  57.587  4
577697  88.269  -54.520  57.583  4
577698  88.304  -54.535  57.579  4
577699  88.341  -54.547  57.574  4
577700  88.408  -54.466  57.568  4
577701  88.469  -54.439  57.562  4
577702  88.507  -54.431  57.555  4
577703  88.543  -54.446  57.545  4
577704  88.577  -54.482  57.534  4
577705  88.615  -54.501  57.519  4
577706  88.653  -54.518  57.496  4
577707  88.692  -54.534  57.460  4
577708  88.730  -54.552  57.421  4
577709  88.768  -54.568  57.382  4
577710  88.806  -54.588  57.342  4
577711  88.845  -54.612  57.300  4
577712  88.884  -54.635  57.253  4
577713  88.922  -54.659  57.204  4
577714  88.961  -54.682  57.155  4
577715  88.999  -54.706  57.106  4
577716  89.038  -54.728  57.056  4
577717  89.076  -54.752  57.008  4
577718  89.115  -54.775  56.959  4
577719  89.154  -54.799  56.910  4
577748  90.194  -55.430  55.785  1
577749  90.218  -55.445  55.777  1
577750  90.241  -55.458  55.771  1
577751  90.264  -55.473  55.768  1
577752  90.288  -55.487  55.767  1
577753  90.311  -55.501  55.768  1
577754  90.338  -55.520  55.772  1
577755  90.365  -55.536  55.778  1
577756  90.390  -55.546  55.787  1
577757  90.415  -55.556  55.799  1
577758  90.441  -55.567  55.815  1
577759  90.470  -55.577  55.833  1
577760  90.510  -55.587  55.855  1
577761  90.549  -55.597  55.881  1
577762  90.589  -55.607  55.911  1
577763  90.629  -55.618  55.946  1
577764  90.669  -55.627  55.978  1
577765  90.708  -55.638  56.007  1
577766  90.748  -55.648  56.037  1
577767  90.788  -55.658  56.076  1
577768  90.827  -55.668  56.128  1
577769  90.867  -55.678  56.165  1
577770  90.906  -55.688  56.192  1
577771  90.946  -55.699  56.197  1
577772  90.986  -55.709  56.188  1
577773  91.025  -55.719  56.167  1
577774  91.065  -55.729  56.132  1
577775  91.109  -55.740  56.116  1
577776  91.154  -55.751  56.104  1
577777  91.200  -55.762  56.090  1
577778  91.245  -55.773  56.071  1
577779  91.285  -55.781  56.044  1
577780  91.321  -55.789  56.008  1
577781  91.357  -55.796  55.956  1
577782  91.392  -55.803  55.926  1
577783  91.428  -55.809  55.901  1
577784  91.464  -55.817  55.869  1
577785  91.500  -55.824  55.830  1
577786  91.535  -55.831  55.775  1
577787  91.569  -55.839  55.714  1
577788  91.599  -55.848  55.661  1
577789  91.630  -55.858  55.612  1
577790  91.660  -55.868  55.567  1
577791  91.691  -55.877  55.526  1
577792  91.722  -55.887  55.488  1
577793  91.752  -55.897  55.455  1
577794  91.783  -55.906  55.426  1
577795  91.813  -55.915  55.401  1
577796  91.850  -55.926  55.380  1
577797  91.886  -55.937  55.364  1
577798  91.923  -55.947  55.353  1
577799  91.958  -55.962  55.343  1
577800  91.991  -55.986  55.332  1
577801  92.023  -56.009  55.317  1
577802  92.055  -56.033  55.297  1
577803  92.088  -56.056  55.272  1
577804  92.120  -56.079  55.243  1
577805  92.153  -56.103  55.226  1
577806  92.185  -56.126  55.217  1
577807  92.217  -56.150  55.216  1
577808  92.250  -56.173  55.221  1
577809  92.282  -56.197  55.227  1
577810  92.315  -56.220  55.242  1
577811  92.349  -56.249  55.255  1
577812  92.386  -56.285  55.261  1
577813  92.424  -56.323  55.260  1
577814  92.462  -56.348  55.255  1
577815  92.501  -56.367  55.257  1
577816  92.540  -56.386  55.276  1
577817  92.579  -56.406  55.299  1
577818  92.618  -56.425  55.319  1
577819  92.657  -56.444  55.334  1
577820  92.697  -56.463  55.343  1
577821  92.735  -56.482  55.344  1
577822  92.772  -56.502  55.346  1
577823  92.807  -56.523  55.352  1
577824  92.842  -56.544  55.365  1
577825  92.883  -56.559  55.385  1
577826  92.926  -56.573  55.399  1
577827  92.969  -56.586  55.410  1
577828  93.012  -56.600  55.421  1
577829  93.055  -56.614  55.430  1
577830  93.098  -56.627  55.435  1
577831  93.141  -56.641  55.436  1
577832  93.184  -56.655  55.431  1
577833  93.223  -56.666  55.416  1
577834  93.252  -56.672  55.401  1
577835  93.281  -56.679  55.384  1
577836  93.309  -56.685  55.365  1
577837  93.340  -56.694  55.345  1
577838  93.372  -56.705  55.321  1
577839  93.405  -56.718  55.288  1
577840  93.438  -56.730  55.254  1
577841  93.471  -56.741  55.218  1
577842  93.503  -56.753  55.182  1
577843  93.536  -56.765  55.144  1
577844  93.569  -56.777  55.108  1
577845  93.602  -56.789  55.070  1
577846  93.634  -56.801  55.033  1
577847  93.666  -56.812  55.000  1
577848  93.699  -56.824  54.968  1
577849  93.732  -56.837  54.937  1
577850  93.765  -56.848  54.903  1
577851  93.797  -56.860  54.867  1
577852  93.830  -56.872  54.832  1
577853  93.863  -56.884  54.800  1
577854  93.896  -56.896  54.772  1
577855  93.928  -56.908  54.748  1
577856  93.961  -56.919  54.726  1
577857  93.993  -56.931  54.701  1
577858  94.026  -56.943  54.676  1
577859  94.059  -56.955  54.650  1
577860  94.091  -56.967  54.624  1
577861  94.125  -56.972  54.598  1
577862  94.158  -56.976  54.569  1
577863  94.192  -56.980  54.536  1
577864  94.229  -56.999  54.501  1
577865  94.266  -57.021  54.463  1
577866  94.298  -57.034  54.424  1
577867  94.330  -57.046  54.386  1
577868  94.363  -57.058  54.348  1
577869  94.395  -57.071  54.306  1
577870  94.427  -57.083  54.261  1
577871  94.460  -57.096  54.212  1
577872  94.492  -57.108  54.160  1
577873  94.525  -57.120  54.102  1
577874  94.557  -57.133  54.047  1
577875  94.589  -57.145  53.999  1
577876  94.621  -57.157  53.962  1
577877  94.654  -57.170  53.935  1
577878  94.686  -57.182  53.912  1
577879  94.718  -57.195  53.892  1
577880  94.751  -57.207  53.874  1
577881  94.783  -57.219  53.857  1
577882  94.816  -57.232  53.841  1
577883  94.848  -57.244  53.826  1
577884  94.880  -57.257  53.812  1
577885  94.912  -57.269  53.796  1
577886  94.945  -57.282  53.784  1
577887  94.977  -57.294  53.774  1
577888  95.010  -57.307  53.763  1
577889  95.042  -57.319  53.750  1
577890  95.074  -57.332  53.733  1
577891  95.106  -57.344  53.714  1
577892  95.139  -57.357  53.687  1
577893  95.170  -57.367  53.655  1
577894  95.200  -57.377  53.616  1
577895  95.230  -57.388  53.573  1
577896  95.260  -57.398  53.526  1
577897  95.290  -57.407  53.477  1
577898  95.323  -57.417  53.425  1
577899  95.359  -57.428  53.376  1
577900  95.395  -57.438  53.330  1
577901  95.431  -57.448  53.287  1
577902  95.468  -57.458  53.244  1
577903  95.505  -57.468  53.199  1
577904  95.541  -57.479  53.153  1
577905  95.577  -57.489  53.107  1
577906  95.618  -57.495  53.059  1
577907  95.662  -57.500  53.009  1
577908  95.705  -57.504  52.958  1
577909  95.749  -57.510  52.904  1
577910  95.793  -57.514  52.854  1
577911  95.823  -57.520  52.807  1
577912  95.844  -57.525  52.761  1
577913  95.865  -57.530  52.716  1
577914  95.886  -57.536  52.674  1
577915  95.907  -57.542  52.634  1
577916  95.928  -57.547  52.594  1
577917  95.949  -57.553  52.558  1
577918  95.970  -57.558  52.526  1
577919  95.991  -57.564  52.494  1
577920  96.013  -57.570  52.463  1
577921  96.042  -57.577  52.434  1
577922  96.071  -57.585  52.406  1
577923  96.100  -57.592  52.381  1
577924  96.129  -57.600  52.357  1
577925  96.158  -57.608  52.337  1
577926  96.187  -57.615  52.321  1
577927  96.216  -57.623  52.309  1
577928  96.245  -57.630  52.298  1
577929  96.274  -57.638  52.289  1
577930  96.303  -57.645  52.281  1
577931  96.332  -57.653  52.274  1
577932  96.362  -57.661  52.270  1
577933  96.395  -57.671  52.267  1
577934  96.429  -57.681  52.261  1
577935  96.463  -57.692  52.251  1
577936  96.497  -57.702  52.233  1
577937  96.531  -57.712  52.212  1
577938  96.565  -57.723  52.191  1
577939  96.599  -57.733  52.173  1
577940  96.632  -57.743  52.157  1
577941  96.663  -57.754  52.145  1
577942  96.691  -57.765  52.137  1
577943  96.720  -57.776  52.129  1
577944  96.748  -57.787  52.122  1
577945  96.776  -57.798  52.110  1
577946  96.809  -57.805  52.100  1
577947  96.846  -57.810  52.092  1
577948  96.882  -57.815  52.088  1
577949  96.919  -57.820  52.088  1
577950  96.955  -57.825  52.093  1
577951  96.992  -57.830  52.102  1
577952  97.028  -57.835  52.116  1
577953  97.059  -57.834  52.134  1
577954  97.088  -57.830  52.150  1
577955  97.116  -57.827  52.161  1
577956  97.145  -57.824  52.166  1
577957  97.173  -57.821  52.168  1
577958  97.202  -57.818  52.166  1
577959  97.230  -57.814  52.159  1
577960  97.258  -57.811  52.143  1
577961  97.287  -57.808  52.120  1
577962  97.315  -57.804  52.092  1
577963  97.344  -57.801  52.064  1
577964  97.372  -57.797  52.035  1
577965  97.400  -57.794  52.005  1
577966  97.428  -57.791  51.972  1
577967  97.461  -57.802  51.927  1
577968  97.496  -57.817  51.872  1
577969  97.530  -57.830  51.810  1
577970  97.565  -57.846  51.744  1
577971  97.599  -57.851  51.676  1
577972  97.631  -57.851  51.608  1
577973  97.663  -57.851  51.547  1
577974  97.694  -57.851  51.492  1
577975  97.726  -57.851  51.439  1
577976  97.757  -57.851  51.385  1
577977  97.789  -57.851  51.328  1
577978  97.820  -57.851  51.267  1
577979  97.852  -57.851  51.205  1
577980  97.884  -57.851  51.145  1
577981  97.916  -57.851  51.086  1
577982  97.953  -57.856  51.030  1
577983  97.992  -57.861  50.974  1
577984  98.029  -57.866  50.919  1
577985  98.069  -57.869  50.864  1
577986  98.109  -57.872  50.812  1
577987  98.149  -57.874  50.763  1
577988  98.190  -57.877  50.717  1
577989  98.229  -57.880  50.675  1
577990  98.269  -57.883  50.631  1
577991  98.311  -57.885  50.591  1
577992  98.356  -57.888  50.551  1
577993  98.401  -57.890  50.510  1
577994  98.442  -57.891  50.469  1
577995  98.473  -57.886  50.429  1
577996  98.503  -57.880  50.392  1
577997  98.533  -57.874  50.359  1
577998  98.563  -57.871  50.327  1
577999  98.592  -57.868  50.296  1
578000  98.622  -57.866  50.266  1
578001  98.651  -57.864  50.237  1
578002  98.681  -57.861  50.211  1
578003  98.710  -57.858  50.189  1
578004  98.740  -57.856  50.168  1
578005  98.752  -57.860  50.147  1
578006  98.740  -57.873  50.126  1
578007  98.752  -57.881  50.105  1
578008  98.775  -57.887  50.082  1
578009  98.798  -57.894  50.058  1
578010  98.821  -57.900  50.034  1
578011  98.845  -57.906  50.009  1
578012  98.868  -57.913  49.984  1
578013  98.891  -57.919  49.959  1
578014  98.914  -57.926  49.933  1
578015  98.951  -57.923  49.906  1
578016  98.991  -57.918  49.880  1
578017  99.031  -57.913  49.854  1
578018  99.071  -57.909  49.826  1
578019  99.111  -57.904  49.800  1
578020  99.150  -57.899  49.771  1
578021  99.190  -57.895  49.742  1
578022  99.230  -57.890  49.710  1
578023  99.268  -57.894  49.678  1
578024  99.305  -57.904  49.646  1
578025  99.342  -57.915  49.613  1
578026  99.371  -57.926  49.580  1
578027  99.389  -57.940  49.548  1
578028  99.452  -57.951  49.515  1
578029  99.504  -57.958  49.482  1
578030  99.543  -57.966  49.450  1
578031  99.577  -57.974  49.417  1
578032  99.612  -57.984  49.385  1
578033  99.646  -57.992  49.353  1
578034  99.681  -58.001  49.321  1
578035  99.715  -58.010  49.289  1
578036  99.750  -58.018  49.257  1
578037  99.784  -58.028  49.226  1
578038  99.819  -58.036  49.195  1
578039  99.853  -58.045  49.165  1
578387  87.904  -54.317  57.588  4
578388  87.940  -54.332  57.591  4
578389  87.975  -54.347  57.592  4
578390  88.010  -54.362  57.593  4
578391  88.046  -54.378  57.594  4
578392  88.081  -54.393  57.595  4
578393  88.117  -54.408  57.595  4
578394  88.152  -54.424  57.595  4
578395  88.187  -54.439  57.593  4
578396  88.222  -54.455  57.590  4
578397  88.258  -54.470  57.587  4
578398  88.293  -54.485  57.583  4
578399  88.329  -54.500  57.580  4
578400  88.364  -54.515  57.575  4
578401  88.423  -54.460  57.571  4
578402  88.488  -54.399  57.566  4
578403  88.530  -54.393  57.560  4
578404  88.565  -54.421  57.553  4
578405  88.600  -54.457  57.542  4
578406  88.637  -54.477  57.523  4
578407  88.675  -54.494  57.499  4
578408  88.713  -54.511  57.464  4
578409  88.752  -54.528  57.427  4
578410  88.790  -54.545  57.389  4
578411  88.828  -54.562  57.350  4
578412  88.866  -54.580  57.308  4
578413  88.905  -54.603  57.262  4
578414  88.944  -54.627  57.214  4
578415  88.982  -54.650  57.165  4
578416  89.021  -54.674  57.116  4
578417  89.059  -54.696  57.067  4
578418  89.098  -54.720  57.018  4
578419  89.136  -54.743  56.969  4
578420  89.175  -54.767  56.921  4
578449  90.214  -55.397  55.794  1
578450  90.237  -55.411  55.786  1
578451  90.260  -55.426  55.779  1
578452  90.284  -55.439  55.775  1
578453  90.307  -55.454  55.775  1
578454  90.330  -55.467  55.776  1
578455  90.356  -55.485  55.780  1
578456  90.383  -55.502  55.786  1
578457  90.408  -55.513  55.796  1
578458  90.434  -55.523  55.809  1
578459  90.459  -55.533  55.827  1
578460  90.484  -55.543  55.848  1
578461  90.522  -55.553  55.870  1
578462  90.561  -55.564  55.892  1
578463  90.601  -55.574  55.918  1
578464  90.641  -55.584  55.947  1
578465  90.680  -55.594  55.981  1
578466  90.720  -55.604  56.012  1
578467  90.759  -55.614  56.041  1
578468  90.799  -55.624  56.073  1
578469  90.839  -55.635  56.114  1
578470  90.879  -55.645  56.151  1
578471  90.918  -55.655  56.181  1
578472  90.958  -55.665  56.197  1
578473  90.998  -55.675  56.192  1
578474  91.039  -55.686  56.164  1
578475  91.085  -55.696  56.126  1
578476  91.130  -55.708  56.117  1
578477  91.175  -55.718  56.105  1
578478  91.221  -55.730  56.085  1
578479  91.266  -55.740  56.058  1
578480  91.309  -55.751  56.031  1
578481  91.345  -55.758  56.005  1
578482  91.380  -55.765  55.958  1
578483  91.416  -55.771  55.925  1
578484  91.452  -55.779  55.895  1
578485  91.488  -55.786  55.859  1
578486  91.523  -55.793  55.818  1
578487  91.557  -55.800  55.765  1
578488  91.588  -55.810  55.707  1
578489  91.618  -55.820  55.653  1
578490  91.649  -55.829  55.604  1
578491  91.679  -55.839  55.557  1
578492  91.710  -55.849  55.516  1
578493  91.740  -55.858  55.478  1
578494  91.771  -55.868  55.443  1
578495  91.801  -55.878  55.412  1
578496  91.832  -55.887  55.384  1
578497  91.862  -55.897  55.361  1
578498  91.898  -55.907  55.343  1
578499  91.935  -55.919  55.329  1
578500  91.967  -55.943  55.315  1
578501  92.000  -55.965  55.303  1
578502  92.032  -55.989  55.290  1
578503  92.065  -56.013  55.275  1
578504  92.097  -56.036  55.255  1
578505  92.129  -56.059  55.229  1
578506  92.162  -56.083  55.210  1
578507  92.194  -56.107  55.198  1
578508  92.227  -56.130  55.195  1
578509  92.259  -56.153  55.199  1
578510  92.291  -56.176  55.205  1
578511  92.324  -56.200  55.219  1
578512  92.356  -56.223  55.232  1
578513  92.391  -56.254  55.240  1
578514  92.428  -56.291  55.243  1
578515  92.467  -56.312  55.248  1
578516  92.506  -56.331  55.264  1
578517  92.546  -56.350  55.285  1
578518  92.584  -56.370  55.306  1
578519  92.624  -56.389  55.323  1
578520  92.663  -56.407  55.337  1
578521  92.702  -56.426  55.346  1
578522  92.741  -56.446  55.351  1
578523  92.778  -56.466  55.355  1
578524  92.813  -56.486  55.359  1
578525  92.848  -56.507  55.368  1
578526  92.891  -56.520  55.382  1
578527  92.934  -56.534  55.395  1
578528  92.977  -56.548  55.404  1
578529  93.020  -56.561  55.416  1
578530  93.063  -56.575  55.427  1
578531  93.107  -56.589  55.435  1
578532  93.149  -56.602  55.438  1
578533  93.193  -56.616  55.435  1
578534  93.234  -56.629  55.422  1
578535  93.263  -56.635  55.409  1
578536  93.292  -56.642  55.395  1
578537  93.321  -56.649  55.379  1
578538  93.351  -56.657  55.362  1
578539  93.384  -56.669  55.341  1
578540  93.417  -56.681  55.311  1
578541  93.449  -56.693  55.277  1
578542  93.482  -56.705  55.240  1
578543  93.515  -56.717  55.202  1
578544  93.547  -56.728  55.161  1
578545  93.580  -56.740  55.123  1
578546  93.613  -56.752  55.082  1
578547  93.645  -56.764  55.043  1
578548  93.678  -56.776  55.006  1
578549  93.711  -56.788  54.970  1
578550  93.744  -56.800  54.936  1
578551  93.776  -56.812  54.903  1
578552  93.809  -56.824  54.864  1
578553  93.841  -56.836  54.825  1
578554  93.874  -56.847  54.789  1
578555  93.907  -56.859  54.759  1
578556  93.939  -56.871  54.735  1
578557  93.972  -56.883  54.713  1
578558  94.005  -56.895  54.688  1
578559  94.038  -56.907  54.663  1
578560  94.070  -56.918  54.638  1
578561  94.103  -56.931  54.613  1
578562  94.135  -56.943  54.588  1
578563  94.169  -56.948  54.561  1
578564  94.203  -56.952  54.529  1
578565  94.239  -56.969  54.494  1
578566  94.273  -56.987  54.457  1
578567  94.306  -56.999  54.417  1
578568  94.338  -57.012  54.378  1
578569  94.370  -57.024  54.340  1
578570  94.403  -57.036  54.299  1
578571  94.435  -57.049  54.255  1
578572  94.468  -57.061  54.207  1
578573  94.500  -57.073  54.156  1
578574  94.532  -57.086  54.100  1
578575  94.564  -57.098  54.045  1
578576  94.597  -57.111  53.992  1
578577  94.629  -57.123  53.948  1
578578  94.662  -57.135  53.914  1
578579  94.694  -57.148  53.890  1
578580  94.726  -57.160  53.870  1
578581  94.758  -57.173  53.850  1
578582  94.791  -57.185  53.831  1
578583  94.823  -57.197  53.813  1
578584  94.855  -57.210  53.796  1
578585  94.888  -57.222  53.779  1
578586  94.920  -57.235  53.760  1
578587  94.953  -57.247  53.744  1
578588  94.985  -57.260  53.731  1
578589  95.017  -57.272  53.718  1
578590  95.049  -57.285  53.706  1
578591  95.082  -57.297  53.691  1
578592  95.114  -57.310  53.672  1
578593  95.146  -57.322  53.648  1
578594  95.179  -57.334  53.619  1
578595  95.209  -57.344  53.584  1
578596  95.239  -57.354  53.543  1
578597  95.269  -57.365  53.499  1
578598  95.303  -57.375  53.451  1
578599  95.339  -57.385  53.401  1
578600  95.375  -57.395  53.352  1
578601  95.411  -57.405  53.304  1
578602  95.448  -57.415  53.257  1
578603  95.484  -57.426  53.215  1
578604  95.521  -57.435  53.171  1
578605  95.557  -57.445  53.130  1
578606  95.594  -57.456  53.087  1
578607  95.630  -57.466  53.042  1
578608  95.673  -57.471  52.998  1
578609  95.716  -57.476  52.951  1
578610  95.760  -57.481  52.898  1
578611  95.804  -57.485  52.849  1
578612  95.828  -57.491  52.802  1
578613  95.849  -57.496  52.757  1
578614  95.871  -57.502  52.713  1
578615  95.891  -57.507  52.670  1
578616  95.912  -57.513  52.629  1
578617  95.933  -57.518  52.589  1
578618  95.954  -57.524  52.551  1
578619  95.975  -57.529  52.516  1
578620  95.996  -57.535  52.483  1
578621  96.017  -57.541  52.450  1
578622  96.044  -57.548  52.420  1
578623  96.073  -57.555  52.393  1
578624  96.102  -57.563  52.368  1
578625  96.131  -57.570  52.344  1
578626  96.160  -57.578  52.322  1
578627  96.189  -57.586  52.303  1
578628  96.219  -57.593  52.287  1
578629  96.247  -57.601  52.273  1
578630  96.276  -57.608  52.263  1
578631  96.306  -57.616  52.254  1
578632  96.334  -57.623  52.246  1
578633  96.364  -57.631  52.240  1
578634  96.393  -57.639  52.236  1
578635  96.426  -57.648  52.233  1
578636  96.460  -57.659  52.227  1
578637  96.493  -57.670  52.213  1
578638  96.528  -57.680  52.194  1
578639  96.561  -57.690  52.170  1
578640  96.595  -57.701  52.150  1
578641  96.629  -57.711  52.135  1
578642  96.658  -57.722  52.123  1
578643  96.686  -57.733  52.114  1
578644  96.715  -57.743  52.108  1
578645  96.743  -57.755  52.099  1
578646  96.777  -57.761  52.087  1
578647  96.814  -57.766  52.075  1
578648  96.850  -57.771  52.067  1
578649  96.887  -57.776  52.063  1
578650  96.923  -57.781  52.064  1
578651  96.960  -57.786  52.072  1
578652  96.996  -57.791  52.083  1
578653  97.033  -57.796  52.096  1
578654  97.065  -57.796  52.110  1
578655  97.093  -57.793  52.126  1
578656  97.121  -57.789  52.137  1
578657  97.150  -57.786  52.143  1
578658  97.178  -57.783  52.145  1
578659  97.207  -57.780  52.143  1
578660  97.235  -57.776  52.137  1
578661  97.264  -57.773  52.122  1
578662  97.292  -57.770  52.099  1
578663  97.321  -57.766  52.073  1
578664  97.349  -57.763  52.047  1
578665  97.376  -57.760  52.020  1
578666  97.403  -57.756  51.992  1
578667  97.431  -57.753  51.961  1
578668  97.463  -57.763  51.920  1
578669  97.498  -57.777  51.868  1
578670  97.532  -57.792  51.811  1
578671  97.567  -57.806  51.750  1
578672  97.599  -57.817  51.686  1
578673  97.629  -57.819  51.617  1
578674  97.659  -57.821  51.553  1
578675  97.689  -57.822  51.495  1
578676  97.720  -57.822  51.441  1
578677  97.752  -57.822  51.386  1
578678  97.784  -57.822  51.329  1
578679  97.815  -57.822  51.269  1
578680  97.847  -57.823  51.210  1
578681  97.878  -57.823  51.151  1
578682  97.910  -57.823  51.095  1
578683  97.942  -57.823  51.041  1
578684  97.979  -57.827  50.988  1
578685  98.016  -57.832  50.933  1
578686  98.056  -57.836  50.879  1
578687  98.096  -57.838  50.827  1
578688  98.136  -57.841  50.776  1
578689  98.176  -57.843  50.728  1
578690  98.216  -57.846  50.685  1
578691  98.261  -57.849  50.642  1
578692  98.306  -57.852  50.602  1
578693  98.351  -57.855  50.563  1
578694  98.396  -57.858  50.524  1
578695  98.441  -57.860  50.486  1
578696  98.473  -57.855  50.448  1
578697  98.503  -57.850  50.412  1
578698  98.533  -57.844  50.379  1
578699  98.563  -57.838  50.346  1
578700  98.593  -57.833  50.315  1
578701  98.624  -57.827  50.285  1
578702  98.653  -57.824  50.256  1
578703  98.683  -57.822  50.230  1
578704  98.712  -57.820  50.207  1
578705  98.742  -57.817  50.185  1
578706  98.772  -57.814  50.163  1
578707  98.767  -57.824  50.142  1
578708  98.776  -57.833  50.119  1
578709  98.799  -57.840  50.094  1
578710  98.822  -57.846  50.069  1
578711  98.845  -57.852  50.043  1
578712  98.868  -57.859  50.016  1
578713  98.891  -57.865  49.989  1
578714  98.915  -57.872  49.963  1
578715  98.938  -57.878  49.936  1
578716  98.961  -57.884  49.909  1
578717  98.984  -57.891  49.882  1
578718  99.020  -57.889  49.855  1
578719  99.060  -57.884  49.827  1
578720  99.100  -57.880  49.799  1
578721  99.140  -57.874  49.769  1
578722  99.180  -57.870  49.740  1
578723  99.219  -57.865  49.709  1
578724  99.258  -57.867  49.677  1
578725  99.295  -57.877  49.645  1
578726  99.332  -57.887  49.612  1
578727  99.369  -57.897  49.579  1
578728  99.382  -57.911  49.545  1
578729  99.438  -57.924  49.513  1
578730  99.490  -57.931  49.480  1
578731  99.535  -57.938  49.446  1
578732  99.570  -57.947  49.412  1
578733  99.604  -57.955  49.381  1
578734  99.639  -57.965  49.349  1
578735  99.673  -57.973  49.317  1
578736  99.707  -57.982  49.285  1
578737  99.742  -57.990  49.252  1
578738  99.776  -57.999  49.221  1
578739  99.811  -58.009  49.190  1
578740  99.845  -58.017  49.160  1
579088  87.929  -54.282  57.586  4
579089  87.965  -54.297  57.589  4
579090  88.000  -54.312  57.590  4
579091  88.035  -54.327  57.591  4
579092  88.070  -54.342  57.592  4
579093  88.106  -54.358  57.593  4
579094  88.141  -54.373  57.593  4
579095  88.177  -54.389  57.594  4
579096  88.212  -54.404  57.592  4
579097  88.247  -54.419  57.589  4
579098  88.283  -54.435  57.587  4
579099  88.318  -54.450  57.584  4
579100  88.353  -54.465  57.580  4
579101  88.389  -54.480  57.577  4
579102  88.438  -54.453  57.574  4
579103  88.506  -54.372  57.570  4
579104  88.552  -54.361  57.564  4
579105  88.587  -54.396  57.557  4
579106  88.622  -54.431  57.545  4
579107  88.659  -54.454  57.525  4
579108  88.697  -54.471  57.500  4
579109  88.736  -54.488  57.468  4
579110  88.773  -54.505  57.433  4
579111  88.812  -54.521  57.395  4
579112  88.850  -54.538  57.357  4
579113  88.888  -54.555  57.316  4
579114  88.926  -54.572  57.271  4
579115  88.965  -54.595  57.224  4
579116  89.003  -54.618  57.175  4
579117  89.042  -54.641  57.125  4
579118  89.081  -54.665  57.076  4
579119  89.119  -54.688  57.028  4
579120  89.158  -54.712  56.979  4
579121  89.196  -54.735  56.931  4
579149  90.210  -55.350  55.813  1
579150  90.233  -55.364  55.802  1
579151  90.256  -55.378  55.794  1
579152  90.279  -55.392  55.787  1
579153  90.302  -55.406  55.784  1
579154  90.326  -55.420  55.782  1
579155  90.349  -55.435  55.783  1
579156  90.373  -55.450  55.787  1
579157  90.400  -55.469  55.794  1
579158  90.426  -55.479  55.806  1
579159  90.451  -55.489  55.820  1
579160  90.477  -55.499  55.842  1
579161  90.502  -55.510  55.866  1
579162  90.534  -55.520  55.888  1
579163  90.573  -55.530  55.905  1
579164  90.613  -55.540  55.926  1
579165  90.653  -55.550  55.949  1
579166  90.692  -55.561  55.981  1
579167  90.732  -55.571  56.012  1
579168  90.771  -55.581  56.039  1
579169  90.811  -55.591  56.066  1
579170  90.851  -55.601  56.098  1
579171  90.890  -55.611  56.132  1
579172  90.930  -55.621  56.161  1
579173  90.970  -55.632  56.175  1
579174  91.015  -55.643  56.170  1
579175  91.061  -55.654  56.147  1
579176  91.106  -55.665  56.113  1
579177  91.151  -55.676  56.103  1
579178  91.196  -55.687  56.094  1
579179  91.242  -55.698  56.072  1
579180  91.287  -55.709  56.037  1
579181  91.332  -55.720  56.007  1
579182  91.368  -55.727  55.985  1
579183  91.404  -55.734  55.947  1
579184  91.440  -55.740  55.912  1
579185  91.475  -55.748  55.879  1
579186  91.511  -55.755  55.841  1
579187  91.545  -55.762  55.798  1
579188  91.576  -55.772  55.748  1
579189  91.606  -55.781  55.695  1
579190  91.637  -55.791  55.643  1
579191  91.668  -55.801  55.594  1
579192  91.698  -55.810  55.547  1
579193  91.729  -55.820  55.506  1
579194  91.759  -55.830  55.468  1
579195  91.790  -55.839  55.431  1
579196  91.820  -55.849  55.398  1
579197  91.851  -55.858  55.368  1
579198  91.881  -55.868  55.342  1
579199  91.912  -55.878  55.322  1
579200  91.944  -55.899  55.304  1
579201  91.977  -55.922  55.287  1
579202  92.009  -55.946  55.271  1
579203  92.041  -55.969  55.255  1
579204  92.074  -55.993  55.239  1
579205  92.106  -56.016  55.222  1
579206  92.139  -56.039  55.205  1
579207  92.171  -56.063  55.191  1
579208  92.203  -56.086  55.182  1
579209  92.236  -56.110  55.177  1
579210  92.268  -56.133  55.178  1
579211  92.301  -56.157  55.182  1
579212  92.333  -56.180  55.192  1
579213  92.365  -56.204  55.205  1
579214  92.398  -56.226  55.217  1
579215  92.433  -56.257  55.227  1
579216  92.473  -56.276  55.243  1
579217  92.512  -56.295  55.269  1
579218  92.551  -56.314  55.290  1
579219  92.590  -56.333  55.308  1
579220  92.629  -56.352  55.323  1
579221  92.668  -56.371  55.335  1
579222  92.707  -56.390  55.343  1
579223  92.746  -56.410  55.348  1
579224  92.784  -56.429  55.352  1
579225  92.819  -56.450  55.356  1
579226  92.856  -56.469  55.362  1
579227  92.899  -56.483  55.372  1
579228  92.942  -56.496  55.383  1
579229  92.985  -56.510  55.391  1
579230  93.028  -56.523  55.402  1
579231  93.072  -56.536  55.414  1
579232  93.115  -56.550  55.424  1
579233  93.158  -56.564  55.429  1
579234  93.201  -56.577  55.427  1
579235  93.244  -56.591  55.415  1
579236  93.274  -56.599  55.404  1
579237  93.303  -56.605  55.395  1
579238  93.332  -56.611  55.385  1
579239  93.363  -56.620  55.369  1
579240  93.396  -56.633  55.354  1
579241  93.428  -56.645  55.327  1
579242  93.461  -56.656  55.295  1
579243  93.493  -56.668  55.260  1
579244  93.526  -56.680  55.222  1
579245  93.559  -56.692  55.182  1
579246  93.591  -56.704  55.142  1
579247  93.624  -56.716  55.099  1
579248  93.657  -56.727  55.058  1
579249  93.690  -56.740  55.018  1
579250  93.722  -56.752  54.977  1
579251  93.755  -56.763  54.939  1
579252  93.787  -56.775  54.904  1
579253  93.820  -56.787  54.865  1
579254  93.853  -56.799  54.825  1
579255  93.886  -56.811  54.786  1
579256  93.918  -56.823  54.751  1
579257  93.951  -56.834  54.722  1
579258  93.984  -56.846  54.700  1
579259  94.016  -56.859  54.674  1
579260  94.049  -56.870  54.648  1
579261  94.081  -56.882  54.623  1
579262  94.114  -56.894  54.597  1
579263  94.147  -56.906  54.573  1
579264  94.180  -56.918  54.547  1
579265  94.213  -56.924  54.516  1
579266  94.249  -56.940  54.482  1
579267  94.281  -56.952  54.446  1
579268  94.314  -56.965  54.408  1
579269  94.346  -56.977  54.368  1
579270  94.378  -56.989  54.328  1
579271  94.410  -57.002  54.286  1
579272  94.443  -57.014  54.242  1
579273  94.475  -57.027  54.197  1
579274  94.507  -57.039  54.147  1
579275  94.540  -57.051  54.094  1
579276  94.572  -57.064  54.042  1
579277  94.605  -57.076  53.989  1
579278  94.637  -57.089  53.938  1
579279  94.669  -57.101  53.896  1
579280  94.701  -57.113  53.867  1
579281  94.734  -57.126  53.848  1
579282  94.766  -57.138  53.826  1
579283  94.799  -57.150  53.807  1
579284  94.831  -57.163  53.787  1
579285  94.863  -57.175  53.767  1
579286  94.896  -57.188  53.748  1
579287  94.928  -57.200  53.727  1
579288  94.960  -57.213  53.708  1
579289  94.992  -57.225  53.692  1
579290  95.025  -57.238  53.677  1
579291  95.057  -57.250  53.662  1
579292  95.090  -57.263  53.647  1
579293  95.122  -57.275  53.628  1
579294  95.154  -57.288  53.606  1
579295  95.186  -57.300  53.580  1
579296  95.218  -57.312  53.549  1
579297  95.248  -57.322  53.511  1
579298  95.282  -57.332  53.469  1
579299  95.319  -57.342  53.422  1
579300  95.355  -57.352  53.374  1
579301  95.391  -57.362  53.328  1
579302  95.428  -57.373  53.282  1
579303  95.464  -57.382  53.237  1
579304  95.500  -57.392  53.194  1
579305  95.537  -57.403  53.149  1
579306  95.573  -57.413  53.105  1
579307  95.610  -57.423  53.063  1
579308  95.646  -57.433  53.022  1
579309  95.683  -57.442  52.982  1
579310  95.727  -57.447  52.940  1
579311  95.771  -57.452  52.894  1
579312  95.813  -57.457  52.849  1
579313  95.834  -57.462  52.803  1
579314  95.855  -57.467  52.756  1
579315  95.876  -57.473  52.711  1
579316  95.897  -57.479  52.669  1
579317  95.917  -57.484  52.628  1
579318  95.939  -57.490  52.587  1
579319  95.960  -57.495  52.547  1
579320  95.980  -57.501  52.510  1
579321  96.002  -57.507  52.475  1
579322  96.022  -57.512  52.440  1
579323  96.046  -57.518  52.408  1
579324  96.076  -57.526  52.381  1
579325  96.105  -57.533  52.355  1
579326  96.133  -57.541  52.330  1
579327  96.163  -57.548  52.307  1
579328  96.192  -57.556  52.285  1
579329  96.221  -57.564  52.266  1
579330  96.250  -57.571  52.250  1
579331  96.279  -57.579  52.236  1
579332  96.308  -57.586  52.224  1
579333  96.337  -57.594  52.216  1
579334  96.366  -57.601  52.209  1
579335  96.395  -57.609  52.204  1
579336  96.424  -57.617  52.201  1
579337  96.456  -57.626  52.199  1
579338  96.490  -57.637  52.191  1
579339  96.524  -57.647  52.174  1
579340  96.558  -57.658  52.150  1
579341  96.592  -57.668  52.128  1
579342  96.625  -57.678  52.111  1
579343  96.654  -57.689  52.100  1
579344  96.682  -57.700  52.092  1
579345  96.710  -57.711  52.085  1
579346  96.745  -57.717  52.075  1
579347  96.782  -57.722  52.063  1
579348  96.818  -57.727  52.051  1
579349  96.855  -57.732  52.043  1
579350  96.891  -57.737  52.041  1
579351  96.928  -57.742  52.045  1
579352  96.964  -57.747  52.054  1
579353  97.001  -57.752  52.066  1
579354  97.037  -57.757  52.078  1
579355  97.070  -57.758  52.091  1
579356  97.099  -57.755  52.104  1
579357  97.127  -57.752  52.115  1
579358  97.156  -57.749  52.120  1
579359  97.184  -57.745  52.121  1
579360  97.213  -57.742  52.118  1
579361  97.241  -57.739  52.112  1
579362  97.270  -57.735  52.100  1
579363  97.297  -57.732  52.076  1
579364  97.324  -57.729  52.051  1
579365  97.352  -57.725  52.026  1
579366  97.379  -57.722  52.001  1
579367  97.406  -57.719  51.976  1
579368  97.433  -57.716  51.948  1
579369  97.465  -57.724  51.908  1
579370  97.500  -57.739  51.860  1
579371  97.534  -57.753  51.807  1
579372  97.569  -57.767  51.749  1
579373  97.601  -57.777  51.687  1
579374  97.631  -57.783  51.620  1
579375  97.661  -57.785  51.557  1
579376  97.691  -57.786  51.496  1
579377  97.721  -57.789  51.437  1
579378  97.751  -57.790  51.381  1
579379  97.781  -57.792  51.326  1
579380  97.810  -57.793  51.269  1
579381  97.842  -57.794  51.212  1
579382  97.873  -57.794  51.155  1
579383  97.904  -57.794  51.102  1
579384  97.936  -57.794  51.050  1
579385  97.968  -57.794  50.999  1
579386  98.004  -57.798  50.946  1
579387  98.042  -57.802  50.893  1
579388  98.082  -57.805  50.842  1
579389  98.122  -57.807  50.792  1
579390  98.165  -57.810  50.744  1
579391  98.210  -57.813  50.699  1
579392  98.255  -57.815  50.654  1
579393  98.300  -57.818  50.613  1
579394  98.345  -57.821  50.574  1
579395  98.390  -57.824  50.536  1
579396  98.436  -57.827  50.500  1
579397  98.474  -57.826  50.466  1
579398  98.504  -57.820  50.433  1
579399  98.534  -57.814  50.400  1
579400  98.564  -57.808  50.369  1
579401  98.594  -57.802  50.337  1
579402  98.624  -57.797  50.307  1
579403  98.654  -57.791  50.277  1
579404  98.684  -57.786  50.249  1
579405  98.714  -57.780  50.223  1
579406  98.744  -57.778  50.199  1
579407  98.773  -57.776  50.177  1
579408  98.793  -57.777  50.155  1
579409  98.799  -57.786  50.131  1
579410  98.822  -57.793  50.106  1
579411  98.846  -57.799  50.079  1
579412  98.869  -57.805  50.051  1
579413  98.892  -57.811  50.023  1
579414  98.916  -57.818  49.995  1
579415  98.939  -57.824  49.968  1
579416  98.962  -57.830  49.940  1
579417  98.985  -57.837  49.912  1
579418  99.008  -57.843  49.884  1
579419  99.031  -57.850  49.857  1
579420  99.055  -57.856  49.829  1
579421  99.089  -57.855  49.800  1
579422  99.129  -57.850  49.770  1
579423  99.169  -57.846  49.740  1
579424  99.209  -57.841  49.709  1
579425  99.248  -57.840  49.677  1
579426  99.285  -57.849  49.644  1
579427  99.322  -57.860  49.611  1
579428  99.359  -57.870  49.577  1
579429  99.391  -57.880  49.544  1
579430  99.417  -57.895  49.511  1
579431  99.475  -57.904  49.478  1
579432  99.526  -57.911  49.444  1
579433  99.562  -57.919  49.410  1
579434  99.596  -57.928  49.377  1
579435  99.631  -57.937  49.345  1
579436  99.665  -57.946  49.314  1
579437  99.700  -57.954  49.281  1
579438  99.734  -57.963  49.248  1
579439  99.769  -57.971  49.216  1
579440  99.803  -57.981  49.185  1
579441  99.838  -57.990  49.155  1
579442  99.872  -57.998  49.125  1
579789  87.954  -54.246  57.583  4
579790  87.989  -54.262  57.587  4
579791  88.025  -54.277  57.587  4
579792  88.060  -54.292  57.588  4
579793  88.095  -54.308  57.589  4
579794  88.130  -54.323  57.591  4
579795  88.166  -54.339  57.592  4
579796  88.201  -54.354  57.592  4
579797  88.237  -54.369  57.590  4
579798  88.272  -54.384  57.588  4
579799  88.308  -54.400  57.586  4
579800  88.343  -54.415  57.584  4
579801  88.378  -54.430  57.581  4
579802  88.413  -54.446  57.578  4
579803  88.454  -54.446  57.576  4
579804  88.522  -54.366  57.573  4
579805  88.574  -54.336  57.567  4
579806  88.609  -54.371  57.556  4
579807  88.644  -54.406  57.544  4
579808  88.681  -54.431  57.525  4
579809  88.719  -54.448  57.502  4
579810  88.757  -54.464  57.473  4
579811  88.796  -54.481  57.439  4
579812  88.834  -54.498  57.402  4
579813  88.872  -54.515  57.364  4
579814  88.910  -54.532  57.324  4
579815  88.948  -54.549  57.279  4
579816  88.986  -54.565  57.232  4
579817  89.025  -54.587  57.184  4
579818  89.063  -54.609  57.135  4
579819  89.102  -54.633  57.085  4
579820  89.140  -54.656  57.037  4
579821  89.179  -54.680  56.989  4
579822  89.217  -54.703  56.941  4
579849  90.205  -55.302  55.836  1
579850  90.229  -55.317  55.822  1
579851  90.252  -55.331  55.810  1
579852  90.275  -55.345  55.802  1
579853  90.298  -55.359  55.795  1
579854  90.321  -55.373  55.792  1
579855  90.344  -55.387  55.790  1
579856  90.368  -55.401  55.790  1
579857  90.391  -55.415  55.794  1
579858  90.418  -55.434  55.802  1
579859  90.444  -55.445  55.814  1
579860  90.469  -55.456  55.832  1
579861  90.495  -55.466  55.858  1
579862  90.520  -55.477  55.883  1
579863  90.546  -55.486  55.902  1
579864  90.585  -55.497  55.917  1
579865  90.625  -55.507  55.934  1
579866  90.664  -55.517  55.952  1
579867  90.704  -55.527  55.978  1
579868  90.744  -55.537  56.007  1
579869  90.783  -55.547  56.032  1
579870  90.823  -55.558  56.056  1
579871  90.863  -55.568  56.081  1
579872  90.902  -55.578  56.112  1
579873  90.946  -55.589  56.136  1
579874  90.991  -55.599  56.146  1
579875  91.036  -55.611  56.139  1
579876  91.082  -55.621  56.121  1
579877  91.127  -55.633  56.093  1
579878  91.172  -55.643  56.085  1
579879  91.218  -55.655  56.078  1
579880  91.263  -55.665  56.057  1
579881  91.308  -55.677  56.018  1
579882  91.353  -55.687  55.982  1
579883  91.392  -55.696  55.957  1
579884  91.428  -55.702  55.923  1
579885  91.463  -55.709  55.889  1
579886  91.499  -55.717  55.854  1
579887  91.534  -55.724  55.815  1
579888  91.564  -55.734  55.775  1
579889  91.595  -55.743  55.731  1
579890  91.626  -55.753  55.681  1
579891  91.656  -55.762  55.630  1
579892  91.686  -55.772  55.582  1
579893  91.717  -55.781  55.536  1
579894  91.747  -55.791  55.495  1
579895  91.778  -55.801  55.458  1
579896  91.808  -55.810  55.421  1
579897  91.839  -55.821  55.385  1
579898  91.869  -55.833  55.354  1
579899  91.899  -55.844  55.325  1
579900  91.930  -55.856  55.303  1
579901  91.961  -55.875  55.283  1
579902  91.993  -55.900  55.264  1
579903  92.025  -55.923  55.246  1
579904  92.057  -55.947  55.229  1
579905  92.089  -55.970  55.215  1
579906  92.122  -55.994  55.201  1
579907  92.154  -56.017  55.189  1
579908  92.186  -56.041  55.179  1
579909  92.218  -56.064  55.172  1
579910  92.250  -56.088  55.169  1
579911  92.283  -56.111  55.169  1
579912  92.315  -56.135  55.175  1
579913  92.347  -56.158  55.183  1
579914  92.379  -56.182  55.191  1
579915  92.412  -56.205  55.201  1
579916  92.444  -56.226  55.215  1
579917  92.479  -56.240  55.239  1
579918  92.517  -56.258  55.266  1
579919  92.556  -56.278  55.287  1
579920  92.595  -56.297  55.304  1
579921  92.634  -56.316  55.319  1
579922  92.673  -56.335  55.328  1
579923  92.712  -56.354  55.333  1
579924  92.752  -56.373  55.338  1
579925  92.791  -56.392  55.342  1
579926  92.825  -56.414  55.346  1
579927  92.864  -56.430  55.351  1
579928  92.908  -56.444  55.359  1
579929  92.950  -56.458  55.367  1
579930  92.994  -56.471  55.376  1
579931  93.037  -56.485  55.388  1
579932  93.080  -56.498  55.400  1
579933  93.123  -56.512  55.410  1
579934  93.166  -56.526  55.415  1
579935  93.209  -56.539  55.414  1
579936  93.252  -56.553  55.404  1
579937  93.285  -56.561  55.395  1
579938  93.314  -56.567  55.388  1
579939  93.343  -56.574  55.380  1
579940  93.374  -56.584  55.367  1
579941  93.407  -56.596  55.353  1
579942  93.439  -56.608  55.330  1
579943  93.472  -56.620  55.303  1
579944  93.505  -56.632  55.271  1
579945  93.538  -56.643  55.235  1
579946  93.570  -56.655  55.199  1
579947  93.603  -56.668  55.161  1
579948  93.636  -56.679  55.119  1
579949  93.669  -56.691  55.077  1
579950  93.701  -56.703  55.035  1
579951  93.733  -56.714  54.992  1
579952  93.766  -56.727  54.949  1
579953  93.799  -56.739  54.908  1
579954  93.832  -56.750  54.869  1
579955  93.864  -56.762  54.829  1
579956  93.897  -56.774  54.788  1
579957  93.930  -56.787  54.747  1
579958  93.963  -56.798  54.712  1
579959  93.995  -56.810  54.687  1
579960  94.028  -56.822  54.661  1
579961  94.060  -56.834  54.635  1
579962  94.093  -56.846  54.608  1
579963  94.126  -56.858  54.581  1
579964  94.158  -56.869  54.555  1
579965  94.191  -56.881  54.530  1
579966  94.224  -56.893  54.500  1
579967  94.257  -56.905  54.467  1
579968  94.289  -56.918  54.431  1
579969  94.321  -56.930  54.394  1
579970  94.353  -56.943  54.356  1
579971  94.386  -56.955  54.316  1
579972  94.418  -56.967  54.273  1
579973  94.451  -56.980  54.229  1
579974  94.483  -56.992  54.183  1
579975  94.515  -57.005  54.133  1
579976  94.548  -57.017  54.082  1
579977  94.580  -57.029  54.032  1
579978  94.612  -57.042  53.981  1
579979  94.644  -57.054  53.930  1
579980  94.677  -57.066  53.882  1
579981  94.709  -57.079  53.847  1
579982  94.742  -57.091  53.829  1
579983  94.774  -57.104  53.809  1
579984  94.806  -57.116  53.787  1
579985  94.838  -57.129  53.764  1
579986  94.871  -57.141  53.742  1
579987  94.903  -57.154  53.720  1
579988  94.935  -57.166  53.699  1
579989  94.967  -57.179  53.681  1
579990  95.000  -57.191  53.661  1
579991  95.032  -57.204  53.640  1
579992  95.064  -57.216  53.619  1
579993  95.097  -57.229  53.602  1
579994  95.129  -57.241  53.582  1
579995  95.161  -57.254  53.561  1
579996  95.193  -57.266  53.538  1
579997  95.226  -57.279  53.510  1
579998  95.262  -57.289  53.476  1
579999  95.299  -57.299  53.436  1
580000  95.335  -57.309  53.392  1
580001  95.372  -57.319  53.348  1
580002  95.408  -57.329  53.305  1
580003  95.444  -57.339  53.262  1
580004  95.480  -57.350  53.218  1
580005  95.517  -57.360  53.175  1
580006  95.553  -57.369  53.128  1
580007  95.590  -57.380  53.082  1
580008  95.626  -57.390  53.040  1
580009  95.662  -57.400  53.001  1
580010  95.699  -57.410  52.964  1
580011  95.738  -57.418  52.926  1
580012  95.781  -57.423  52.887  1
580013  95.818  -57.428  52.846  1
580014  95.839  -57.433  52.803  1
580015  95.860  -57.439  52.757  1
580016  95.881  -57.445  52.711  1
580017  95.902  -57.450  52.668  1
580018  95.923  -57.456  52.626  1
580019  95.944  -57.461  52.583  1
580020  95.965  -57.467  52.542  1
580021  95.986  -57.472  52.503  1
580022  96.007  -57.478  52.468  1
580023  96.028  -57.483  52.433  1
580024  96.049  -57.489  52.400  1
580025  96.078  -57.496  52.371  1
580026  96.107  -57.504  52.345  1
580027  96.136  -57.511  52.322  1
580028  96.165  -57.519  52.298  1
580029  96.194  -57.526  52.274  1
580030  96.223  -57.534  52.249  1
580031  96.252  -57.542  52.227  1
580032  96.281  -57.550  52.210  1
580033  96.310  -57.558  52.196  1
580034  96.339  -57.565  52.186  1
580035  96.368  -57.573  52.177  1
580036  96.397  -57.580  52.171  1
580037  96.427  -57.588  52.167  1
580038  96.455  -57.595  52.165  1
580039  96.487  -57.605  52.163  1
580040  96.521  -57.614  52.152  1
580041  96.555  -57.625  52.129  1
580042  96.589  -57.636  52.106  1
580043  96.620  -57.645  52.087  1
580044  96.649  -57.657  52.075  1
580045  96.677  -57.667  52.070  1
580046  96.713  -57.673  52.062  1
580047  96.749  -57.678  52.050  1
580048  96.786  -57.683  52.037  1
580049  96.822  -57.688  52.026  1
580050  96.859  -57.693  52.021  1
580051  96.895  -57.698  52.023  1
580052  96.932  -57.703  52.030  1
580053  96.968  -57.708  52.038  1
580054  97.005  -57.713  52.050  1
580055  97.041  -57.717  52.063  1
580056  97.076  -57.720  52.074  1
580057  97.104  -57.717  52.085  1
580058  97.133  -57.714  52.093  1
580059  97.161  -57.711  52.098  1
580060  97.189  -57.707  52.096  1
580061  97.218  -57.704  52.092  1
580062  97.245  -57.701  52.086  1
580063  97.272  -57.698  52.075  1
580064  97.300  -57.694  52.053  1
580065  97.327  -57.691  52.028  1
580066  97.354  -57.688  52.003  1
580067  97.381  -57.685  51.980  1
580068  97.409  -57.681  51.958  1
580069  97.436  -57.678  51.932  1
580070  97.468  -57.686  51.894  1
580071  97.502  -57.700  51.848  1
580072  97.536  -57.714  51.799  1
580073  97.571  -57.728  51.744  1
580074  97.602  -57.737  51.684  1
580075  97.633  -57.745  51.619  1
580076  97.663  -57.749  51.557  1
580077  97.693  -57.752  51.494  1
580078  97.723  -57.753  51.433  1
580079  97.753  -57.755  51.376  1
580080  97.783  -57.756  51.322  1
580081  97.813  -57.758  51.267  1
580082  97.843  -57.759  51.212  1
580083  97.873  -57.761  51.159  1
580084  97.902  -57.763  51.107  1
580085  97.932  -57.764  51.057  1
580086  97.962  -57.766  51.008  1
580087  97.994  -57.766  50.957  1
580088  98.029  -57.768  50.906  1
580089  98.069  -57.771  50.856  1
580090  98.114  -57.774  50.807  1
580091  98.160  -57.777  50.759  1
580092  98.205  -57.780  50.713  1
580093  98.250  -57.782  50.668  1
580094  98.295  -57.785  50.628  1
580095  98.340  -57.788  50.589  1
580096  98.385  -57.791  50.552  1
580097  98.430  -57.793  50.518  1
580098  98.475  -57.796  50.486  1
580099  98.504  -57.790  50.454  1
580100  98.534  -57.784  50.421  1
580101  98.565  -57.778  50.390  1
580102  98.594  -57.773  50.360  1
580103  98.625  -57.767  50.329  1
580104  98.655  -57.761  50.298  1
580105  98.685  -57.755  50.268  1
580106  98.715  -57.749  50.240  1
580107  98.745  -57.744  50.214  1
580108  98.775  -57.738  50.190  1
580109  98.805  -57.734  50.166  1
580110  98.823  -57.739  50.141  1
580111  98.847  -57.745  50.115  1
580112  98.870  -57.751  50.087  1
580113  98.893  -57.758  50.059  1
580114  98.916  -57.764  50.030  1
580115  98.939  -57.771  50.001  1
580116  98.962  -57.777  49.973  1
580117  98.986  -57.783  49.944  1
580118  99.009  -57.789  49.916  1
580119  99.032  -57.796  49.887  1
580120  99.055  -57.802  49.858  1
580121  99.078  -57.808  49.830  1
580122  99.101  -57.815  49.800  1
580123  99.125  -57.821  49.770  1
580124  99.158  -57.821  49.739  1
580125  99.198  -57.816  49.707  1
580126  99.238  -57.812  49.675  1
580127  99.275  -57.822  49.642  1
580128  99.312  -57.833  49.609  1
580129  99.349  -57.843  49.576  1
580130  99.385  -57.852  49.543  1
580131  99.402  -57.866  49.509  1
580132  99.460  -57.877  49.475  1
580133  99.512  -57.883  49.442  1
580134  99.554  -57.892  49.407  1
580135  99.589  -57.900  49.374  1
580136  99.623  -57.909  49.342  1
580137  99.658  -57.918  49.310  1
580138  99.692  -57.927  49.277  1
580139  99.727  -57.935  49.243  1
580140  99.761  -57.944  49.211  1
580141  99.796  -57.952  49.180  1
580142  99.830  -57.962  49.149  1
580143  99.865  -57.970  49.120  1
580144  99.899  -57.979  49.090  1
580490  87.978  -54.211  57.580  4
580491  88.014  -54.226  57.584  4
580492  88.049  -54.242  57.585  4
580493  88.084  -54.258  57.587  4
580494  88.120  -54.273  57.588  4
580495  88.155  -54.288  57.588  4
580496  88.191  -54.303  57.589  4
580497  88.226  -54.319  57.590  4
580498  88.261  -54.334  57.588  4
580499  88.296  -54.349  57.586  4
580500  88.332  -54.364  57.585  4
580501  88.367  -54.380  57.583  4
580502  88.403  -54.395  57.581  4
580503  88.438  -54.411  57.578  4
580504  88.473  -54.426  57.577  4
580505  88.537  -54.359  57.574  4
580506  88.597  -54.311  57.567  4
580507  88.631  -54.346  57.558  4
580508  88.667  -54.381  57.546  4
580509  88.703  -54.408  57.528  4
580510  88.741  -54.424  57.510  4
580511  88.779  -54.441  57.483  4
580512  88.817  -54.458  57.448  4
580513  88.855  -54.475  57.410  4
580514  88.894  -54.492  57.372  4
580515  88.932  -54.508  57.332  4
580516  88.970  -54.525  57.287  4
580517  89.008  -54.542  57.240  4
580518  89.046  -54.559  57.193  4
580519  89.085  -54.577  57.144  4
580520  89.123  -54.601  57.095  4
580521  89.162  -54.624  57.047  4
580522  89.200  -54.648  56.999  4
580523  89.239  -54.671  56.951  4
580549  90.201  -55.255  55.863  1
580550  90.224  -55.269  55.846  1
580551  90.247  -55.283  55.831  1
580552  90.271  -55.298  55.819  1
580553  90.294  -55.311  55.809  1
580554  90.317  -55.326  55.803  1
580555  90.340  -55.340  55.799  1
580556  90.364  -55.354  55.797  1
580557  90.387  -55.368  55.797  1
580558  90.410  -55.382  55.801  1
580559  90.436  -55.398  55.810  1
580560  90.462  -55.412  55.822  1
580561  90.487  -55.422  55.843  1
580562  90.513  -55.433  55.870  1
580563  90.538  -55.442  55.894  1
580564  90.564  -55.453  55.912  1
580565  90.597  -55.463  55.925  1
580566  90.637  -55.474  55.938  1
580567  90.676  -55.483  55.951  1
580568  90.716  -55.494  55.972  1
580569  90.755  -55.504  55.995  1
580570  90.795  -55.514  56.018  1
580571  90.835  -55.524  56.040  1
580572  90.877  -55.535  56.065  1
580573  90.922  -55.546  56.091  1
580574  90.967  -55.557  56.109  1
580575  91.012  -55.568  56.113  1
580576  91.058  -55.579  56.103  1
580577  91.103  -55.589  56.085  1
580578  91.148  -55.601  56.067  1
580579  91.193  -55.611  56.062  1
580580  91.239  -55.623  56.059  1
580581  91.284  -55.633  56.041  1
580582  91.329  -55.645  56.000  1
580583  91.374  -55.655  55.961  1
580584  91.416  -55.665  55.931  1
580585  91.451  -55.671  55.898  1
580586  91.487  -55.679  55.865  1
580587  91.522  -55.686  55.830  1
580588  91.553  -55.696  55.792  1
580589  91.583  -55.705  55.759  1
580590  91.613  -55.715  55.719  1
580591  91.644  -55.724  55.671  1
580592  91.675  -55.734  55.620  1
580593  91.705  -55.743  55.571  1
580594  91.736  -55.753  55.525  1
580595  91.766  -55.765  55.484  1
580596  91.796  -55.776  55.447  1
580597  91.826  -55.788  55.410  1
580598  91.857  -55.799  55.375  1
580599  91.887  -55.812  55.343  1
580600  91.918  -55.823  55.314  1
580601  91.948  -55.835  55.288  1
580602  91.980  -55.850  55.266  1
580603  92.011  -55.875  55.246  1
580604  92.042  -55.900  55.228  1
580605  92.074  -55.924  55.212  1
580606  92.106  -55.947  55.200  1
580607  92.138  -55.971  55.190  1
580608  92.170  -55.994  55.180  1
580609  92.203  -56.018  55.173  1
580610  92.235  -56.041  55.168  1
580611  92.267  -56.065  55.167  1
580612  92.299  -56.088  55.170  1
580613  92.332  -56.112  55.176  1
580614  92.364  -56.135  55.183  1
580615  92.396  -56.159  55.190  1
580616  92.428  -56.182  55.200  1
580617  92.461  -56.201  55.212  1
580618  92.496  -56.215  55.229  1
580619  92.530  -56.229  55.250  1
580620  92.564  -56.244  55.269  1
580621  92.600  -56.260  55.284  1
580622  92.640  -56.279  55.296  1
580623  92.678  -56.298  55.307  1
580624  92.718  -56.318  55.313  1
580625  92.757  -56.337  55.316  1
580626  92.796  -56.356  55.317  1
580627  92.832  -56.376  55.322  1
580628  92.872  -56.392  55.332  1
580629  92.916  -56.405  55.342  1
580630  92.959  -56.419  55.348  1
580631  93.002  -56.432  55.359  1
580632  93.045  -56.446  55.372  1
580633  93.088  -56.460  55.383  1
580634  93.131  -56.473  55.393  1
580635  93.174  -56.487  55.397  1
580636  93.217  -56.501  55.398  1
580637  93.260  -56.514  55.391  1
580638  93.296  -56.524  55.384  1
580639  93.325  -56.531  55.377  1
580640  93.354  -56.537  55.370  1
580641  93.386  -56.548  55.360  1
580642  93.418  -56.559  55.348  1
580643  93.451  -56.571  55.327  1
580644  93.484  -56.583  55.303  1
580645  93.516  -56.595  55.275  1
580646  93.549  -56.607  55.241  1
580647  93.582  -56.619  55.209  1
580648  93.614  -56.631  55.172  1
580649  93.647  -56.642  55.133  1
580650  93.680  -56.655  55.093  1
580651  93.712  -56.667  55.052  1
580652  93.745  -56.678  55.010  1
580653  93.778  -56.690  54.967  1
580654  93.811  -56.702  54.925  1
580655  93.843  -56.714  54.881  1
580656  93.876  -56.726  54.836  1
580657  93.908  -56.738  54.793  1
580658  93.941  -56.749  54.751  1
580659  93.974  -56.762  54.712  1
580660  94.006  -56.774  54.680  1
580661  94.039  -56.785  54.651  1
580662  94.072  -56.797  54.623  1
580663  94.105  -56.809  54.594  1
580664  94.137  -56.821  54.565  1
580665  94.170  -56.833  54.536  1
580666  94.202  -56.849  54.510  1
580667  94.233  -56.866  54.480  1
580668  94.263  -56.877  54.447  1
580669  94.294  -56.890  54.413  1
580670  94.324  -56.905  54.377  1
580671  94.353  -56.920  54.340  1
580672  94.385  -56.933  54.302  1
580673  94.417  -56.946  54.260  1
580674  94.450  -56.958  54.215  1
580675  94.482  -56.971  54.168  1
580676  94.514  -56.983  54.119  1
580677  94.546  -56.996  54.070  1
580678  94.578  -57.008  54.019  1
580679  94.611  -57.021  53.969  1
580680  94.643  -57.033  53.919  1
580681  94.675  -57.046  53.871  1
580682  94.707  -57.058  53.831  1
580683  94.740  -57.071  53.806  1
580684  94.772  -57.083  53.787  1
580685  94.805  -57.096  53.767  1
580686  94.837  -57.108  53.743  1
580687  94.869  -57.121  53.719  1
580688  94.901  -57.133  53.696  1
580689  94.933  -57.145  53.674  1
580690  94.966  -57.158  53.653  1
580691  94.998  -57.170  53.631  1
580692  95.030  -57.183  53.609  1
580693  95.063  -57.195  53.586  1
580694  95.095  -57.208  53.564  1
580695  95.127  -57.220  53.542  1
580696  95.160  -57.233  53.520  1
580697  95.192  -57.245  53.498  1
580698  95.226  -57.255  53.473  1
580699  95.265  -57.260  53.442  1
580700  95.303  -57.270  53.404  1
580701  95.341  -57.279  53.364  1
580702  95.380  -57.289  53.324  1
580703  95.418  -57.298  53.283  1
580704  95.457  -57.307  53.241  1
580705  95.495  -57.317  53.199  1
580706  95.533  -57.327  53.156  1
580707  95.569  -57.337  53.109  1
580708  95.606  -57.347  53.062  1
580709  95.642  -57.357  53.017  1
580710  95.679  -57.367  52.979  1
580711  95.715  -57.377  52.945  1
580712  95.751  -57.388  52.910  1
580713  95.793  -57.394  52.876  1
580714  95.824  -57.399  52.840  1
580715  95.844  -57.405  52.801  1
580716  95.866  -57.410  52.759  1
580717  95.887  -57.416  52.712  1
580718  95.907  -57.421  52.667  1
580719  95.928  -57.427  52.624  1
580720  95.949  -57.432  52.579  1
580721  95.970  -57.438  52.536  1
580722  95.991  -57.444  52.497  1
580723  96.012  -57.449  52.461  1
580724  96.033  -57.454  52.426  1
580725  96.054  -57.460  52.392  1
580726  96.080  -57.467  52.361  1
580727  96.109  -57.475  52.335  1
580728  96.138  -57.482  52.313  1
580729  96.167  -57.490  52.288  1
580730  96.196  -57.498  52.260  1
580731  96.225  -57.505  52.232  1
580732  96.254  -57.513  52.208  1
580733  96.284  -57.520  52.187  1
580734  96.313  -57.528  52.171  1
580735  96.341  -57.536  52.158  1
580736  96.371  -57.543  52.147  1
580737  96.400  -57.551  52.139  1
580738  96.429  -57.558  52.133  1
580739  96.458  -57.566  52.130  1
580740  96.487  -57.573  52.131  1
580741  96.518  -57.582  52.124  1
580742  96.551  -57.592  52.107  1
580743  96.585  -57.602  52.086  1
580744  96.616  -57.614  52.065  1
580745  96.644  -57.624  52.049  1
580746  96.681  -57.629  52.041  1
580747  96.717  -57.634  52.034  1
580748  96.754  -57.639  52.023  1
580749  96.790  -57.644  52.009  1
580750  96.827  -57.649  51.999  1
580751  96.863  -57.654  51.997  1
580752  96.900  -57.659  52.002  1
580753  96.936  -57.664  52.010  1
580754  96.973  -57.669  52.019  1
580755  97.009  -57.673  52.031  1
580756  97.046  -57.679  52.043  1
580757  97.081  -57.683  52.053  1
580758  97.109  -57.680  52.062  1
580759  97.138  -57.676  52.069  1
580760  97.166  -57.673  52.073  1
580761  97.193  -57.670  52.071  1
580762  97.220  -57.667  52.064  1
580763  97.247  -57.663  52.056  1
580764  97.275  -57.660  52.047  1
580765  97.302  -57.657  52.029  1
580766  97.329  -57.654  52.006  1
580767  97.357  -57.650  51.982  1
580768  97.384  -57.647  51.959  1
580769  97.412  -57.644  51.938  1
580770  97.439  -57.641  51.914  1
580771  97.470  -57.647  51.878  1
580772  97.505  -57.661  51.834  1
580773  97.539  -57.675  51.786  1
580774  97.573  -57.689  51.734  1
580775  97.604  -57.698  51.677  1
580776  97.635  -57.705  51.614  1
580777  97.665  -57.712  51.552  1
580778  97.696  -57.716  51.489  1
580779  97.725  -57.717  51.428  1
580780  97.755  -57.719  51.370  1
580781  97.785  -57.720  51.315  1
580782  97.815  -57.722  51.262  1
580783  97.845  -57.724  51.210  1
580784  97.875  -57.726  51.160  1
580785  97.904  -57.727  51.112  1
580786  97.935  -57.729  51.063  1
580787  97.964  -57.730  51.015  1
580788  97.994  -57.732  50.967  1
580789  98.025  -57.734  50.919  1
580790  98.064  -57.738  50.869  1
580791  98.109  -57.740  50.820  1
580792  98.154  -57.743  50.772  1
580793  98.199  -57.746  50.727  1
580794  98.244  -57.749  50.685  1
580795  98.290  -57.752  50.645  1
580796  98.335  -57.755  50.607  1
580797  98.380  -57.758  50.570  1
580798  98.425  -57.760  50.537  1
580799  98.470  -57.763  50.506  1
580800  98.505  -57.760  50.474  1
580801  98.535  -57.755  50.442  1
580802  98.565  -57.749  50.411  1
580803  98.595  -57.742  50.381  1
580804  98.625  -57.737  50.350  1
580805  98.655  -57.731  50.318  1
580806  98.686  -57.726  50.287  1
580807  98.715  -57.720  50.256  1
580808  98.745  -57.714  50.229  1
580809  98.776  -57.708  50.202  1
580810  98.805  -57.702  50.176  1
580811  98.838  -57.704  50.150  1
580812  98.864  -57.710  50.122  1
580813  98.887  -57.714  50.094  1
580814  98.912  -57.720  50.065  1
580815  98.935  -57.724  50.037  1
580816  98.959  -57.730  50.007  1
580817  98.983  -57.735  49.978  1
580818  99.007  -57.739  49.948  1
580819  99.031  -57.745  49.919  1
580820  99.055  -57.750  49.889  1
580821  99.079  -57.755  49.860  1
580822  99.102  -57.761  49.831  1
580823  99.126  -57.767  49.800  1
580824  99.149  -57.774  49.770  1
580825  99.172  -57.780  49.738  1
580826  99.195  -57.786  49.706  1
580827  99.227  -57.787  49.673  1
580828  99.265  -57.795  49.639  1
580829  99.302  -57.805  49.606  1
580830  99.339  -57.815  49.575  1
580831  99.375  -57.825  49.541  1
580832  99.410  -57.836  49.507  1
580833  99.445  -57.850  49.473  1
580834  99.497  -57.857  49.439  1
580835  99.547  -57.864  49.405  1
580836  99.581  -57.872  49.371  1
580837  99.616  -57.881  49.338  1
580838  99.650  -57.890  49.305  1
580839  99.685  -57.899  49.272  1
580840  99.719  -57.908  49.238  1
580841  99.754  -57.916  49.205  1
580842  99.788  -57.925  49.174  1
580843  99.823  -57.934  49.143  1
580844  99.857  -57.943  49.113  1
580845  99.892  -57.951  49.084  1
580846  99.926  -57.960  49.056  1
581192  88.039  -54.192  57.581  4
581193  88.074  -54.207  57.582  4
581194  88.109  -54.223  57.584  4
581195  88.144  -54.238  57.585  4
581196  88.180  -54.253  57.586  4
581197  88.215  -54.268  57.586  4
581198  88.251  -54.284  57.588  4
581199  88.286  -54.299  57.586  4
581200  88.321  -54.314  57.585  4
581201  88.356  -54.330  57.583  4
581202  88.392  -54.345  57.582  4
581203  88.427  -54.361  57.581  4
581204  88.463  -54.376  57.579  4
581205  88.498  -54.391  57.577  4
581206  88.552  -54.352  57.573  4
581207  88.616  -54.292  57.568  4
581208  88.654  -54.321  57.560  4
581209  88.689  -54.356  57.552  4
581210  88.725  -54.384  57.540  4
581211  88.763  -54.401  57.526  4
581212  88.801  -54.417  57.499  4
581213  88.839  -54.435  57.460  4
581214  88.878  -54.452  57.419  4
581215  88.915  -54.468  57.381  4
581216  88.954  -54.485  57.340  4
581217  88.992  -54.502  57.295  4
581218  89.030  -54.519  57.248  4
581219  89.068  -54.536  57.201  4
581220  89.106  -54.552  57.153  4
581221  89.144  -54.569  57.104  4
581222  89.183  -54.593  57.056  4
581223  89.222  -54.616  57.008  4
581224  89.260  -54.640  56.960  4
581225  89.299  -54.663  56.913  4
581249  90.197  -55.207  55.891  1
581250  90.220  -55.222  55.872  1
581251  90.243  -55.236  55.856  1
581252  90.266  -55.250  55.841  1
581253  90.290  -55.264  55.828  1
581254  90.313  -55.278  55.818  1
581255  90.336  -55.292  55.811  1
581256  90.360  -55.307  55.806  1
581257  90.383  -55.320  55.804  1
581258  90.406  -55.335  55.805  1
581259  90.429  -55.349  55.809  1
581260  90.453  -55.364  55.817  1
581261  90.479  -55.379  55.831  1
581262  90.505  -55.389  55.854  1
581263  90.530  -55.399  55.879  1
581264  90.556  -55.409  55.900  1
581265  90.581  -55.420  55.917  1
581266  90.609  -55.430  55.929  1
581267  90.648  -55.440  55.939  1
581268  90.688  -55.450  55.949  1
581269  90.728  -55.460  55.964  1
581270  90.767  -55.470  55.982  1
581271  90.807  -55.480  56.001  1
581272  90.853  -55.492  56.021  1
581273  90.898  -55.502  56.045  1
581274  90.943  -55.514  56.066  1
581275  90.988  -55.524  56.078  1
581276  91.033  -55.536  56.078  1
581277  91.079  -55.546  56.066  1
581278  91.124  -55.558  56.051  1
581279  91.169  -55.568  56.038  1
581280  91.215  -55.580  56.037  1
581281  91.260  -55.590  56.037  1
581282  91.305  -55.602  56.022  1
581283  91.350  -55.612  55.981  1
581284  91.395  -55.624  55.943  1
581285  91.439  -55.633  55.909  1
581286  91.475  -55.640  55.873  1
581287  91.510  -55.648  55.839  1
581288  91.541  -55.657  55.807  1
581289  91.572  -55.667  55.771  1
581290  91.602  -55.677  55.747  1
581291  91.633  -55.686  55.709  1
581292  91.663  -55.696  55.663  1
581293  91.693  -55.708  55.612  1
581294  91.723  -55.720  55.561  1
581295  91.754  -55.732  55.514  1
581296  91.784  -55.743  55.473  1
581297  91.814  -55.756  55.436  1
581298  91.845  -55.767  55.400  1
581299  91.875  -55.779  55.366  1
581300  91.905  -55.790  55.333  1
581301  91.935  -55.803  55.304  1
581302  91.966  -55.814  55.279  1
581303  91.999  -55.827  55.256  1
581304  92.029  -55.850  55.236  1
581305  92.060  -55.875  55.220  1
581306  92.091  -55.901  55.207  1
581307  92.123  -55.925  55.198  1
581308  92.155  -55.948  55.191  1
581309  92.188  -55.972  55.184  1
581310  92.220  -55.995  55.176  1
581311  92.252  -56.019  55.172  1
581312  92.284  -56.042  55.176  1
581313  92.316  -56.065  55.180  1
581314  92.348  -56.088  55.185  1
581315  92.380  -56.112  55.190  1
581316  92.413  -56.135  55.198  1
581317  92.445  -56.159  55.207  1
581318  92.479  -56.176  55.214  1
581319  92.513  -56.191  55.222  1
581320  92.547  -56.205  55.235  1
581321  92.581  -56.219  55.250  1
581322  92.616  -56.234  55.264  1
581323  92.650  -56.248  55.275  1
581324  92.685  -56.263  55.285  1
581325  92.723  -56.282  55.292  1
581326  92.762  -56.301  55.300  1
581327  92.801  -56.320  55.309  1
581328  92.838  -56.340  55.320  1
581329  92.881  -56.354  55.334  1
581330  92.924  -56.367  55.345  1
581331  92.967  -56.380  55.351  1
581332  93.010  -56.394  55.356  1
581333  93.053  -56.407  55.360  1
581334  93.096  -56.421  55.367  1
581335  93.139  -56.435  55.376  1
581336  93.183  -56.448  55.378  1
581337  93.225  -56.462  55.378  1
581338  93.269  -56.476  55.374  1
581339  93.307  -56.487  55.367  1
581340  93.336  -56.494  55.360  1
581341  93.365  -56.501  55.355  1
581342  93.397  -56.511  55.348  1
581343  93.430  -56.523  55.338  1
581344  93.463  -56.535  55.319  1
581345  93.495  -56.547  55.296  1
581346  93.528  -56.558  55.271  1
581347  93.560  -56.570  55.240  1
581348  93.593  -56.583  55.211  1
581349  93.626  -56.594  55.177  1
581350  93.658  -56.606  55.141  1
581351  93.691  -56.618  55.103  1
581352  93.724  -56.630  55.064  1
581353  93.757  -56.642  55.023  1
581354  93.789  -56.654  54.981  1
581355  93.822  -56.665  54.939  1
581356  93.854  -56.677  54.894  1
581357  93.887  -56.689  54.847  1
581358  93.920  -56.701  54.802  1
581359  93.953  -56.713  54.757  1
581360  93.985  -56.725  54.714  1
581361  94.018  -56.736  54.676  1
581362  94.051  -56.749  54.642  1
581363  94.083  -56.761  54.612  1
581364  94.116  -56.775  54.581  1
581365  94.147  -56.793  54.550  1
581366  94.180  -56.809  54.519  1
581367  94.211  -56.825  54.489  1
581368  94.241  -56.841  54.457  1
581369  94.269  -56.851  54.423  1
581370  94.304  -56.861  54.387  1
581371  94.335  -56.874  54.353  1
581372  94.364  -56.889  54.317  1
581373  94.394  -56.904  54.280  1
581374  94.423  -56.918  54.241  1
581375  94.452  -56.934  54.199  1
581376  94.482  -56.948  54.154  1
581377  94.512  -56.962  54.107  1
581378  94.545  -56.975  54.057  1
581379  94.577  -56.987  54.004  1
581380  94.609  -57.000  53.953  1
581381  94.641  -57.012  53.906  1
581382  94.674  -57.025  53.862  1
581383  94.706  -57.037  53.817  1
581384  94.738  -57.050  53.784  1
581385  94.770  -57.062  53.763  1
581386  94.803  -57.075  53.745  1
581387  94.835  -57.087  53.723  1
581388  94.867  -57.100  53.698  1
581389  94.900  -57.112  53.673  1
581390  94.932  -57.125  53.650  1
581391  94.964  -57.137  53.627  1
581392  94.996  -57.150  53.604  1
581393  95.029  -57.162  53.581  1
581394  95.061  -57.175  53.556  1
581395  95.093  -57.187  53.531  1
581396  95.126  -57.200  53.506  1
581397  95.158  -57.212  53.481  1
581398  95.190  -57.225  53.459  1
581399  95.229  -57.228  53.435  1
581400  95.267  -57.232  53.406  1
581401  95.306  -57.242  53.373  1
581402  95.344  -57.251  53.336  1
581403  95.382  -57.261  53.298  1
581404  95.421  -57.270  53.259  1
581405  95.459  -57.279  53.218  1
581406  95.498  -57.289  53.174  1
581407  95.536  -57.298  53.130  1
581408  95.574  -57.308  53.083  1
581409  95.613  -57.317  53.036  1
581410  95.652  -57.326  52.993  1
581411  95.690  -57.336  52.955  1
581412  95.729  -57.345  52.922  1
581413  95.767  -57.355  52.892  1
581414  95.804  -57.365  52.862  1
581415  95.829  -57.370  52.827  1
581416  95.850  -57.376  52.790  1
581417  95.871  -57.382  52.753  1
581418  95.892  -57.387  52.711  1
581419  95.913  -57.393  52.667  1
581420  95.934  -57.398  52.621  1
581421  95.955  -57.404  52.575  1
581422  95.976  -57.409  52.531  1
581423  95.996  -57.415  52.490  1
581424  96.018  -57.420  52.454  1
581425  96.038  -57.426  52.418  1
581426  96.059  -57.432  52.383  1
581427  96.083  -57.438  52.350  1
581428  96.111  -57.445  52.323  1
581429  96.141  -57.453  52.302  1
581430  96.170  -57.460  52.276  1
581431  96.198  -57.468  52.245  1
581432  96.228  -57.476  52.216  1
581433  96.257  -57.483  52.191  1
581434  96.286  -57.491  52.168  1
581435  96.315  -57.498  52.149  1
581436  96.344  -57.506  52.132  1
581437  96.373  -57.514  52.119  1
581438  96.402  -57.521  52.109  1
581439  96.431  -57.529  52.102  1
581440  96.460  -57.536  52.096  1
581441  96.489  -57.544  52.097  1
581442  96.518  -57.551  52.094  1
581443  96.548  -57.560  52.084  1
581444  96.582  -57.570  52.066  1
581445  96.612  -57.580  52.044  1
581446  96.649  -57.585  52.024  1
581447  96.685  -57.590  52.012  1
581448  96.722  -57.595  52.003  1
581449  96.758  -57.600  51.991  1
581450  96.795  -57.605  51.978  1
581451  96.831  -57.610  51.971  1
581452  96.868  -57.615  51.970  1
581453  96.904  -57.620  51.976  1
581454  96.941  -57.625  51.984  1
581455  96.977  -57.630  51.994  1
581456  97.014  -57.635  52.006  1
581457  97.050  -57.640  52.018  1
581458  97.086  -57.645  52.027  1
581459  97.114  -57.642  52.034  1
581460  97.141  -57.639  52.038  1
581461  97.168  -57.635  52.040  1
581462  97.195  -57.632  52.038  1
581463  97.223  -57.629  52.032  1
581464  97.250  -57.626  52.022  1
581465  97.278  -57.623  52.013  1
581466  97.305  -57.619  51.997  1
581467  97.332  -57.616  51.976  1
581468  97.360  -57.613  51.955  1
581469  97.387  -57.610  51.934  1
581470  97.415  -57.606  51.914  1
581471  97.442  -57.603  51.891  1
581472  97.472  -57.608  51.856  1
581473  97.507  -57.622  51.814  1
581474  97.541  -57.636  51.767  1
581475  97.576  -57.651  51.717  1
581476  97.606  -57.658  51.661  1
581477  97.637  -57.665  51.603  1
581478  97.667  -57.673  51.544  1
581479  97.698  -57.680  51.484  1
581480  97.728  -57.682  51.423  1
581481  97.757  -57.683  51.362  1
581482  97.788  -57.685  51.306  1
581483  97.817  -57.687  51.254  1
581484  97.847  -57.689  51.204  1
581485  97.877  -57.690  51.157  1
581486  97.907  -57.692  51.111  1
581487  97.937  -57.693  51.064  1
581488  97.967  -57.695  51.018  1
581489  97.997  -57.697  50.971  1
581490  98.029  -57.699  50.924  1
581491  98.065  -57.704  50.877  1
581492  98.104  -57.707  50.829  1
581493  98.149  -57.710  50.783  1
581494  98.194  -57.713  50.740  1
581495  98.239  -57.716  50.697  1
581496  98.284  -57.718  50.659  1
581497  98.329  -57.721  50.622  1
581498  98.374  -57.724  50.587  1
581499  98.419  -57.727  50.555  1
581500  98.464  -57.730  50.524  1
581501  98.506  -57.730  50.492  1
581502  98.535  -57.724  50.459  1
581503  98.566  -57.719  50.429  1
581504  98.596  -57.713  50.399  1
581505  98.626  -57.707  50.367  1
581506  98.656  -57.702  50.334  1
581507  98.686  -57.695  50.302  1
581508  98.716  -57.690  50.271  1
581509  98.746  -57.684  50.242  1
581510  98.776  -57.678  50.214  1
581511  98.806  -57.673  50.186  1
581512  98.842  -57.676  50.158  1
581513  98.872  -57.683  50.129  1
581514  98.899  -57.690  50.100  1
581515  98.923  -57.695  50.071  1
581516  98.946  -57.700  50.042  1
581517  98.971  -57.705  50.012  1
581518  98.995  -57.710  49.982  1
581519  99.018  -57.715  49.951  1
581520  99.043  -57.720  49.922  1
581521  99.066  -57.725  49.892  1
581522  99.090  -57.730  49.862  1
581523  99.114  -57.735  49.831  1
581524  99.138  -57.740  49.800  1
581525  99.162  -57.746  49.768  1
581526  99.186  -57.750  49.736  1
581527  99.210  -57.755  49.703  1
581528  99.230  -57.761  49.670  1
581529  99.256  -57.768  49.636  1
581530  99.292  -57.778  49.604  1
581531  99.329  -57.788  49.572  1
581532  99.365  -57.798  49.540  1
581533  99.403  -57.808  49.506  1
581534  99.424  -57.821  49.471  1
581535  99.483  -57.830  49.435  1
581536  99.534  -57.836  49.401  1
581537  99.574  -57.845  49.367  1
581538  99.608  -57.853  49.334  1
581539  99.643  -57.862  49.300  1
581540  99.677  -57.871  49.266  1
581541  99.712  -57.880  49.233  1
581542  99.746  -57.889  49.199  1
581543  99.781  -57.897  49.168  1
581544  99.815  -57.906  49.138  1
581545  99.850  -57.915  49.107  1
581546  99.884  -57.924  49.078  1
581547  99.919  -57.932  49.050  1
581548  99.953  -57.941  49.023  1
581893  88.063  -54.157  57.578  4
581894  88.099  -54.172  57.580  4
581895  88.134  -54.188  57.581  4
581896  88.169  -54.203  57.582  4
581897  88.204  -54.218  57.583  4
581898  88.240  -54.233  57.584  4
581899  88.275  -54.248  57.585  4
581900  88.311  -54.264  57.585  4
581901  88.346  -54.279  57.583  4
581902  88.381  -54.295  57.582  4
581903  88.417  -54.310  57.581  4
581904  88.452  -54.325  57.581  4
581905  88.487  -54.341  57.579  4
581906  88.523  -54.356  57.576  4
581907  88.567  -54.345  57.572  4
581908  88.632  -54.276  57.567  4
581909  88.676  -54.296  57.565  4
581910  88.711  -54.331  57.560  4
581911  88.747  -54.361  57.557  4
581912  88.785  -54.378  57.544  4
581913  88.823  -54.395  57.516  4
581914  88.861  -54.411  57.474  4
581915  88.899  -54.428  57.430  4
581916  88.937  -54.445  57.391  4
581917  88.976  -54.461  57.349  4
581918  89.014  -54.479  57.304  4
581919  89.052  -54.496  57.257  4
581920  89.090  -54.512  57.210  4
581921  89.128  -54.529  57.161  4
581922  89.166  -54.546  57.113  4
581923  89.204  -54.562  57.065  4
581924  89.243  -54.584  57.017  4
581925  89.281  -54.608  56.968  4
581926  89.320  -54.631  56.921  4
581948  90.169  -55.146  55.945  1
581949  90.192  -55.160  55.923  1
581950  90.216  -55.175  55.901  1
581951  90.239  -55.188  55.882  1
581952  90.262  -55.203  55.866  1
581953  90.286  -55.217  55.850  1
581954  90.309  -55.231  55.837  1
581955  90.332  -55.245  55.827  1
581956  90.355  -55.259  55.820  1
581957  90.379  -55.273  55.814  1
581958  90.402  -55.287  55.811  1
581959  90.425  -55.301  55.812  1
581960  90.448  -55.316  55.815  1
581961  90.471  -55.329  55.823  1
581962  90.497  -55.345  55.837  1
581963  90.523  -55.355  55.857  1
581964  90.548  -55.366  55.878  1
581965  90.574  -55.376  55.898  1
581966  90.599  -55.386  55.914  1
581967  90.624  -55.396  55.925  1
581968  90.660  -55.407  55.933  1
581969  90.700  -55.417  55.942  1
581970  90.739  -55.426  55.954  1
581971  90.783  -55.437  55.968  1
581972  90.828  -55.448  55.982  1
581973  90.874  -55.459  56.001  1
581974  90.919  -55.470  56.022  1
581975  90.964  -55.481  56.038  1
581976  91.009  -55.492  56.046  1
581977  91.054  -55.503  56.043  1
581978  91.100  -55.514  56.031  1
581979  91.145  -55.525  56.019  1
581980  91.190  -55.536  56.010  1
581981  91.236  -55.547  56.009  1
581982  91.281  -55.558  56.006  1
581983  91.326  -55.569  55.992  1
581984  91.371  -55.580  55.956  1
581985  91.417  -55.591  55.920  1
581986  91.462  -55.602  55.888  1
581987  91.499  -55.610  55.851  1
581988  91.529  -55.619  55.815  1
581989  91.560  -55.629  55.784  1
581990  91.590  -55.640  55.756  1
581991  91.621  -55.652  55.732  1
581992  91.651  -55.664  55.696  1
581993  91.681  -55.675  55.652  1
581994  91.711  -55.687  55.602  1
581995  91.741  -55.699  55.550  1
581996  91.772  -55.711  55.502  1
581997  91.802  -55.722  55.462  1
581998  91.832  -55.734  55.424  1
581999  91.863  -55.746  55.389  1
582000  91.893  -55.758  55.356  1
582001  91.923  -55.769  55.325  1
582002  91.953  -55.781  55.296  1
582003  91.985  -55.793  55.271  1
582004  92.017  -55.806  55.248  1
582005  92.049  -55.824  55.228  1
582006  92.079  -55.850  55.212  1
582007  92.109  -55.875  55.200  1
582008  92.140  -55.901  55.193  1
582009  92.172  -55.925  55.188  1
582010  92.204  -55.948  55.183  1
582011  92.236  -55.972  55.179  1
582012  92.269  -55.995  55.177  1
582013  92.301  -56.019  55.182  1
582014  92.333  -56.042  55.187  1
582015  92.365  -56.066  55.190  1
582016  92.398  -56.089  55.193  1
582017  92.430  -56.113  55.199  1
582018  92.462  -56.136  55.209  1
582019  92.496  -56.151  55.219  1
582020  92.530  -56.166  55.224  1
582021  92.565  -56.180  55.226  1
582022  92.599  -56.194  55.234  1
582023  92.633  -56.209  55.246  1
582024  92.667  -56.223  55.256  1
582025  92.702  -56.238  55.263  1
582026  92.736  -56.252  55.271  1
582027  92.770  -56.267  55.290  1
582028  92.806  -56.283  55.310  1
582029  92.846  -56.301  55.326  1
582030  92.889  -56.315  55.341  1
582031  92.932  -56.329  55.351  1
582032  92.975  -56.342  55.357  1
582033  93.018  -56.356  55.358  1
582034  93.061  -56.370  55.359  1
582035  93.105  -56.383  55.361  1
582036  93.147  -56.397  55.366  1
582037  93.191  -56.410  55.369  1
582038  93.233  -56.423  55.369  1
582039  93.277  -56.437  55.364  1
582040  93.319  -56.450  55.355  1
582041  93.347  -56.457  55.345  1
582042  93.376  -56.464  55.337  1
582043  93.409  -56.474  55.328  1
582044  93.441  -56.486  55.317  1
582045  93.474  -56.498  55.299  1
582046  93.506  -56.510  55.277  1
582047  93.539  -56.522  55.252  1
582048  93.572  -56.534  55.226  1
582049  93.605  -56.545  55.199  1
582050  93.637  -56.558  55.171  1
582051  93.670  -56.570  55.138  1
582052  93.703  -56.581  55.102  1
582053  93.735  -56.593  55.066  1
582054  93.768  -56.605  55.028  1
582055  93.800  -56.617  54.989  1
582056  93.833  -56.629  54.949  1
582057  93.866  -56.641  54.906  1
582058  93.899  -56.653  54.860  1
582059  93.931  -56.664  54.813  1
582060  93.964  -56.677  54.766  1
582061  93.997  -56.689  54.719  1
582062  94.029  -56.702  54.675  1
582063  94.061  -56.718  54.637  1
582064  94.094  -56.735  54.602  1
582065  94.125  -56.752  54.569  1
582066  94.157  -56.769  54.536  1
582067  94.188  -56.785  54.503  1
582068  94.218  -56.801  54.470  1
582069  94.249  -56.817  54.436  1
582070  94.277  -56.826  54.400  1
582071  94.309  -56.835  54.363  1
582072  94.344  -56.844  54.328  1
582073  94.375  -56.859  54.291  1
582074  94.404  -56.873  54.254  1
582075  94.433  -56.888  54.216  1
582076  94.463  -56.903  54.175  1
582077  94.492  -56.918  54.131  1
582078  94.522  -56.932  54.085  1
582079  94.551  -56.947  54.038  1
582080  94.580  -56.962  53.989  1
582081  94.610  -56.977  53.939  1
582082  94.640  -56.991  53.890  1
582083  94.672  -57.003  53.844  1
582084  94.704  -57.016  53.802  1
582085  94.737  -57.028  53.766  1
582086  94.769  -57.041  53.739  1
582087  94.801  -57.053  53.717  1
582088  94.833  -57.066  53.699  1
582089  94.865  -57.078  53.678  1
582090  94.898  -57.091  53.653  1
582091  94.930  -57.103  53.628  1
582092  94.963  -57.116  53.604  1
582093  94.995  -57.128  53.581  1
582094  95.027  -57.141  53.556  1
582095  95.059  -57.153  53.530  1
582096  95.092  -57.166  53.502  1
582097  95.124  -57.178  53.473  1
582098  95.156  -57.191  53.445  1
582099  95.192  -57.198  53.420  1
582100  95.231  -57.202  53.397  1
582101  95.269  -57.205  53.369  1
582102  95.308  -57.214  53.341  1
582103  95.346  -57.223  53.307  1
582104  95.385  -57.233  53.270  1
582105  95.423  -57.242  53.232  1
582106  95.462  -57.251  53.191  1
582107  95.500  -57.261  53.147  1
582108  95.539  -57.270  53.101  1
582109  95.577  -57.280  53.054  1
582110  95.615  -57.289  53.008  1
582111  95.654  -57.298  52.966  1
582112  95.692  -57.308  52.930  1
582113  95.731  -57.316  52.898  1
582114  95.770  -57.325  52.871  1
582115  95.809  -57.333  52.843  1
582116  95.833  -57.340  52.810  1
582117  95.855  -57.347  52.775  1
582118  95.876  -57.353  52.740  1
582119  95.897  -57.358  52.702  1
582120  95.918  -57.364  52.660  1
582121  95.939  -57.369  52.615  1
582122  95.960  -57.375  52.569  1
582123  95.981  -57.381  52.525  1
582124  96.002  -57.386  52.483  1
582125  96.023  -57.391  52.447  1
582126  96.044  -57.398  52.412  1
582127  96.065  -57.403  52.376  1
582128  96.086  -57.408  52.342  1
582129  96.114  -57.416  52.312  1
582130  96.143  -57.423  52.286  1
582131  96.172  -57.431  52.260  1
582132  96.201  -57.438  52.233  1
582133  96.230  -57.446  52.207  1
582134  96.259  -57.454  52.179  1
582135  96.288  -57.461  52.152  1
582136  96.317  -57.469  52.131  1
582137  96.346  -57.476  52.113  1
582138  96.375  -57.484  52.096  1
582139  96.404  -57.492  52.084  1
582140  96.434  -57.499  52.075  1
582141  96.462  -57.507  52.068  1
582142  96.491  -57.514  52.064  1
582143  96.521  -57.522  52.063  1
582144  96.549  -57.529  52.058  1
582145  96.579  -57.536  52.046  1
582146  96.615  -57.542  52.026  1
582147  96.651  -57.547  52.002  1
582148  96.686  -57.552  51.982  1
582149  96.722  -57.558  51.968  1
582150  96.758  -57.563  51.955  1
582151  96.794  -57.568  51.945  1
582152  96.829  -57.573  51.940  1
582153  96.865  -57.578  51.941  1
582154  96.901  -57.583  51.945  1
582155  96.937  -57.589  51.952  1
582156  96.973  -57.594  51.964  1
582157  97.009  -57.599  51.976  1
582158  97.044  -57.605  51.987  1
582159  97.081  -57.606  51.995  1
582160  97.116  -57.604  52.000  1
582161  97.144  -57.601  52.003  1
582162  97.171  -57.598  52.004  1
582163  97.198  -57.595  52.002  1
582164  97.226  -57.591  51.996  1
582165  97.253  -57.588  51.986  1
582166  97.281  -57.585  51.975  1
582167  97.308  -57.582  51.961  1
582168  97.335  -57.579  51.943  1
582169  97.363  -57.575  51.924  1
582170  97.390  -57.572  51.905  1
582171  97.417  -57.569  51.887  1
582172  97.445  -57.566  51.863  1
582173  97.474  -57.569  51.831  1
582174  97.509  -57.583  51.791  1
582175  97.543  -57.598  51.745  1
582176  97.578  -57.611  51.696  1
582177  97.608  -57.618  51.643  1
582178  97.639  -57.626  51.588  1
582179  97.669  -57.633  51.532  1
582180  97.700  -57.640  51.475  1
582181  97.730  -57.646  51.415  1
582182  97.760  -57.648  51.354  1
582183  97.790  -57.650  51.296  1
582184  97.820  -57.651  51.244  1
582185  97.850  -57.653  51.198  1
582186  97.879  -57.655  51.153  1
582187  97.909  -57.656  51.109  1
582188  97.939  -57.658  51.064  1
582189  97.969  -57.660  51.020  1
582190  97.999  -57.661  50.975  1
582191  98.033  -57.664  50.929  1
582192  98.069  -57.669  50.883  1
582193  98.104  -57.673  50.837  1
582194  98.143  -57.677  50.793  1
582195  98.189  -57.680  50.750  1
582196  98.234  -57.683  50.709  1
582197  98.279  -57.685  50.671  1
582198  98.324  -57.688  50.635  1
582199  98.369  -57.691  50.602  1
582200  98.414  -57.693  50.571  1
582201  98.459  -57.696  50.540  1
582202  98.504  -57.699  50.507  1
582203  98.536  -57.695  50.475  1
582204  98.566  -57.689  50.444  1
582205  98.596  -57.683  50.414  1
582206  98.627  -57.677  50.382  1
582207  98.656  -57.671  50.348  1
582208  98.687  -57.666  50.315  1
582209  98.717  -57.660  50.284  1
582210  98.746  -57.654  50.255  1
582211  98.777  -57.648  50.226  1
582212  98.808  -57.645  50.196  1
582213  98.846  -57.648  50.166  1
582214  98.876  -57.655  50.136  1
582215  98.906  -57.664  50.106  1
582216  98.934  -57.670  50.077  1
582217  98.958  -57.676  50.048  1
582218  98.982  -57.680  50.018  1
582219  99.006  -57.686  49.988  1
582220  99.029  -57.691  49.957  1
582221  99.054  -57.695  49.926  1
582222  99.077  -57.701  49.895  1
582223  99.101  -57.705  49.864  1
582224  99.125  -57.711  49.832  1
582225  99.149  -57.716  49.800  1
582226  99.173  -57.720  49.767  1
582227  99.197  -57.726  49.734  1
582228  99.219  -57.731  49.701  1
582229  99.231  -57.738  49.668  1
582230  99.257  -57.745  49.635  1
582231  99.286  -57.752  49.601  1
582232  99.319  -57.761  49.570  1
582233  99.355  -57.771  49.538  1
582234  99.393  -57.781  49.505  1
582235  99.429  -57.791  49.470  1
582236  99.468  -57.803  49.434  1
582237  99.519  -57.810  49.399  1
582238  99.566  -57.817  49.364  1
582239  99.600  -57.826  49.330  1
582240  99.635  -57.834  49.296  1
582241  99.669  -57.843  49.261  1
582242  99.704  -57.852  49.227  1
582243  99.738  -57.861  49.194  1
582244  99.773  -57.870  49.163  1
582245  99.807  -57.878  49.132  1
582246  99.842  -57.887  49.102  1
582247  99.876  -57.896  49.073  1
582248  99.911  -57.905  49.045  1
582249  99.945  -57.913  49.018  1
582250  99.980  -57.922  48.993  1
582594  88.088  -54.122  57.574  4
582595  88.123  -54.137  57.576  4
582596  88.158  -54.152  57.578  4
582597  88.194  -54.168  57.580  4
582598  88.229  -54.183  57.581  4
582599  88.265  -54.198  57.583  4
582600  88.300  -54.214  57.583  4
582601  88.335  -54.229  57.583  4
582602  88.370  -54.245  57.582  4
582603  88.406  -54.260  57.582  4
582604  88.441  -54.275  57.581  4
582605  88.477  -54.290  57.580  4
582606  88.512  -54.306  57.579  4
582607  88.547  -54.321  57.576  4
582608  88.582  -54.336  57.573  4
582609  88.649  -54.261  57.570  4
582610  88.698  -54.270  57.570  4
582611  88.733  -54.306  57.572  4
582612  88.769  -54.338  57.574  4
582613  88.807  -54.355  57.560  4
582614  88.845  -54.371  57.529  4
582615  88.883  -54.388  57.493  4
582616  88.921  -54.405  57.445  4
582617  88.959  -54.421  57.402  4
582618  88.997  -54.439  57.358  4
582619  89.036  -54.455  57.313  4
582620  89.074  -54.472  57.267  4
582621  89.112  -54.489  57.218  4
582622  89.150  -54.505  57.170  4
582623  89.188  -54.523  57.121  4
582624  89.226  -54.540  57.073  4
582625  89.264  -54.556  57.025  4
582626  89.303  -54.576  56.976  4
582627  89.341  -54.599  56.929  4
582628  89.380  -54.623  56.885  4
582648  90.152  -55.091  55.980  1
582649  90.188  -55.113  55.956  1
582650  90.212  -55.127  55.933  1
582651  90.235  -55.141  55.911  1
582652  90.258  -55.155  55.893  1
582653  90.282  -55.169  55.876  1
582654  90.305  -55.183  55.860  1
582655  90.328  -55.198  55.847  1
582656  90.351  -55.212  55.836  1
582657  90.374  -55.226  55.829  1
582658  90.397  -55.240  55.823  1
582659  90.421  -55.254  55.819  1
582660  90.444  -55.268  55.818  1
582661  90.467  -55.282  55.821  1
582662  90.490  -55.296  55.829  1
582663  90.515  -55.311  55.843  1
582664  90.540  -55.322  55.859  1
582665  90.566  -55.332  55.877  1
582666  90.592  -55.342  55.895  1
582667  90.617  -55.352  55.909  1
582668  90.643  -55.363  55.918  1
582669  90.672  -55.373  55.924  1
582670  90.714  -55.383  55.932  1
582671  90.759  -55.395  55.941  1
582672  90.804  -55.405  55.953  1
582673  90.850  -55.417  55.966  1
582674  90.895  -55.427  55.981  1
582675  90.940  -55.439  55.997  1
582676  90.986  -55.449  56.009  1
582677  91.030  -55.461  56.012  1
582678  91.076  -55.471  56.009  1
582679  91.121  -55.483  56.001  1
582680  91.166  -55.493  55.992  1
582681  91.212  -55.505  55.984  1
582682  91.257  -55.515  55.979  1
582683  91.302  -55.527  55.972  1
582684  91.347  -55.538  55.957  1
582685  91.392  -55.549  55.926  1
582686  91.437  -55.561  55.893  1
582687  91.482  -55.571  55.862  1
582688  91.517  -55.583  55.827  1
582689  91.547  -55.596  55.790  1
582690  91.578  -55.607  55.760  1
582691  91.608  -55.619  55.735  1
582692  91.638  -55.630  55.708  1
582693  91.668  -55.643  55.673  1
582694  91.699  -55.655  55.630  1
582695  91.729  -55.666  55.582  1
582696  91.759  -55.678  55.532  1
582697  91.790  -55.690  55.487  1
582698  91.820  -55.702  55.448  1
582699  91.850  -55.713  55.413  1
582700  91.880  -55.725  55.379  1
582701  91.911  -55.737  55.347  1
582702  91.941  -55.749  55.316  1
582703  91.971  -55.760  55.289  1
582704  92.003  -55.772  55.265  1
582705  92.035  -55.785  55.242  1
582706  92.068  -55.798  55.223  1
582707  92.098  -55.824  55.206  1
582708  92.129  -55.850  55.193  1
582709  92.159  -55.875  55.186  1
582710  92.190  -55.901  55.182  1
582711  92.221  -55.925  55.179  1
582712  92.253  -55.949  55.177  1
582713  92.285  -55.972  55.178  1
582714  92.317  -55.996  55.183  1
582715  92.350  -56.019  55.188  1
582716  92.382  -56.043  55.192  1
582717  92.414  -56.066  55.194  1
582718  92.446  -56.090  55.198  1
582719  92.479  -56.112  55.206  1
582720  92.513  -56.126  55.215  1
582721  92.548  -56.141  55.221  1
582722  92.582  -56.155  55.225  1
582723  92.616  -56.169  55.228  1
582724  92.650  -56.185  55.234  1
582725  92.685  -56.199  55.242  1
582726  92.719  -56.213  55.252  1
582727  92.753  -56.228  55.272  1
582728  92.787  -56.242  55.296  1
582729  92.823  -56.257  55.317  1
582730  92.859  -56.269  55.335  1
582731  92.897  -56.276  55.348  1
582732  92.940  -56.290  55.358  1
582733  92.984  -56.304  55.363  1
582734  93.026  -56.317  55.366  1
582735  93.070  -56.331  55.367  1
582736  93.113  -56.345  55.365  1
582737  93.156  -56.358  55.363  1
582738  93.199  -56.372  55.366  1
582739  93.242  -56.385  55.366  1
582740  93.285  -56.399  55.359  1
582741  93.328  -56.413  55.349  1
582742  93.358  -56.420  55.337  1
582743  93.388  -56.426  55.327  1
582744  93.420  -56.438  55.316  1
582745  93.452  -56.450  55.303  1
582746  93.485  -56.462  55.286  1
582747  93.518  -56.473  55.263  1
582748  93.551  -56.486  55.239  1
582749  93.583  -56.498  55.214  1
582750  93.616  -56.509  55.186  1
582751  93.649  -56.521  55.156  1
582752  93.681  -56.533  55.123  1
582753  93.714  -56.545  55.088  1
582754  93.747  -56.557  55.052  1
582755  93.779  -56.569  55.018  1
582756  93.812  -56.580  54.983  1
582757  93.845  -56.592  54.948  1
582758  93.877  -56.605  54.909  1
582759  93.910  -56.616  54.867  1
582760  93.943  -56.628  54.824  1
582761  93.975  -56.644  54.778  1
582762  94.007  -56.661  54.730  1
582763  94.039  -56.678  54.683  1
582764  94.071  -56.695  54.636  1
582765  94.103  -56.712  54.592  1
582766  94.135  -56.729  54.557  1
582767  94.166  -56.745  54.523  1
582768  94.196  -56.761  54.489  1
582769  94.226  -56.776  54.454  1
582770  94.256  -56.791  54.417  1
582771  94.284  -56.800  54.379  1
582772  94.313  -56.809  54.342  1
582773  94.349  -56.818  54.306  1
582774  94.385  -56.828  54.269  1
582775  94.415  -56.842  54.232  1
582776  94.445  -56.857  54.194  1
582777  94.474  -56.872  54.154  1
582778  94.503  -56.887  54.111  1
582779  94.533  -56.902  54.067  1
582780  94.562  -56.916  54.023  1
582781  94.591  -56.931  53.979  1
582782  94.621  -56.946  53.932  1
582783  94.650  -56.961  53.886  1
582784  94.679  -56.975  53.841  1
582785  94.708  -56.990  53.801  1
582786  94.738  -57.005  53.761  1
582787  94.767  -57.020  53.725  1
582788  94.800  -57.033  53.694  1
582789  94.832  -57.045  53.670  1
582790  94.864  -57.058  53.650  1
582791  94.896  -57.070  53.627  1
582792  94.928  -57.082  53.601  1
582793  94.961  -57.095  53.576  1
582794  94.993  -57.107  53.552  1
582795  95.026  -57.120  53.528  1
582796  95.058  -57.132  53.503  1
582797  95.090  -57.145  53.476  1
582798  95.122  -57.157  53.444  1
582799  95.157  -57.168  53.413  1
582800  95.195  -57.172  53.385  1
582801  95.233  -57.175  53.359  1
582802  95.272  -57.178  53.331  1
582803  95.310  -57.186  53.305  1
582804  95.348  -57.195  53.273  1
582805  95.387  -57.205  53.238  1
582806  95.425  -57.214  53.200  1
582807  95.464  -57.223  53.160  1
582808  95.502  -57.233  53.116  1
582809  95.541  -57.242  53.070  1
582810  95.580  -57.251  53.023  1
582811  95.618  -57.260  52.977  1
582812  95.657  -57.268  52.936  1
582813  95.696  -57.276  52.902  1
582814  95.735  -57.285  52.873  1
582815  95.773  -57.293  52.847  1
582816  95.812  -57.301  52.820  1
582817  95.837  -57.308  52.789  1
582818  95.859  -57.315  52.757  1
582819  95.880  -57.322  52.723  1
582820  95.902  -57.329  52.687  1
582821  95.923  -57.335  52.647  1
582822  95.945  -57.341  52.604  1
582823  95.965  -57.347  52.560  1
582824  95.986  -57.352  52.516  1
582825  96.007  -57.357  52.474  1
582826  96.028  -57.363  52.437  1
582827  96.049  -57.369  52.402  1
582828  96.070  -57.374  52.366  1
582829  96.091  -57.379  52.332  1
582830  96.116  -57.386  52.301  1
582831  96.145  -57.394  52.273  1
582832  96.174  -57.401  52.246  1
582833  96.203  -57.409  52.222  1
582834  96.232  -57.416  52.195  1
582835  96.261  -57.424  52.166  1
582836  96.291  -57.432  52.138  1
582837  96.319  -57.439  52.115  1
582838  96.348  -57.447  52.095  1
582839  96.378  -57.454  52.076  1
582840  96.406  -57.462  52.061  1
582841  96.436  -57.470  52.050  1
582842  96.465  -57.477  52.041  1
582843  96.493  -57.484  52.032  1
582844  96.522  -57.491  52.029  1
582845  96.550  -57.497  52.026  1
582846  96.581  -57.502  52.018  1
582847  96.613  -57.507  52.003  1
582848  96.645  -57.511  51.981  1
582849  96.681  -57.517  51.959  1
582850  96.717  -57.522  51.940  1
582851  96.752  -57.527  51.927  1
582852  96.788  -57.532  51.918  1
582853  96.824  -57.538  51.912  1
582854  96.860  -57.543  51.910  1
582855  96.895  -57.548  51.911  1
582856  96.932  -57.553  51.917  1
582857  96.967  -57.558  51.925  1
582858  97.003  -57.564  51.935  1
582859  97.039  -57.569  51.944  1
582860  97.076  -57.568  51.951  1
582861  97.113  -57.566  51.957  1
582862  97.147  -57.564  51.961  1
582863  97.174  -57.560  51.961  1
582864  97.201  -57.557  51.959  1
582865  97.229  -57.554  51.955  1
582866  97.256  -57.551  51.946  1
582867  97.283  -57.548  51.935  1
582868  97.311  -57.544  51.921  1
582869  97.338  -57.541  51.906  1
582870  97.365  -57.538  51.890  1
582871  97.392  -57.535  51.873  1
582872  97.420  -57.531  51.854  1
582873  97.447  -57.528  51.833  1
582874  97.477  -57.530  51.801  1
582875  97.511  -57.545  51.762  1
582876  97.545  -57.558  51.719  1
582877  97.579  -57.571  51.672  1
582878  97.610  -57.579  51.622  1
582879  97.640  -57.586  51.568  1
582880  97.671  -57.593  51.514  1
582881  97.702  -57.601  51.460  1
582882  97.732  -57.608  51.404  1
582883  97.762  -57.613  51.345  1
582884  97.792  -57.614  51.285  1
582885  97.822  -57.616  51.234  1
582886  97.852  -57.617  51.192  1
582887  97.882  -57.619  51.150  1
582888  97.912  -57.620  51.107  1
582889  97.941  -57.622  51.064  1
582890  97.971  -57.624  51.021  1
582891  98.002  -57.626  50.978  1
582892  98.037  -57.630  50.934  1
582893  98.073  -57.634  50.888  1
582894  98.108  -57.638  50.844  1
582895  98.144  -57.642  50.801  1
582896  98.183  -57.646  50.759  1
582897  98.228  -57.649  50.719  1
582898  98.273  -57.651  50.683  1
582899  98.318  -57.655  50.648  1
582900  98.363  -57.658  50.615  1
582901  98.409  -57.660  50.584  1
582902  98.454  -57.663  50.553  1
582903  98.499  -57.666  50.519  1
582904  98.537  -57.664  50.488  1
582905  98.567  -57.659  50.457  1
582906  98.597  -57.653  50.426  1
582907  98.627  -57.647  50.394  1
582908  98.657  -57.642  50.361  1
582909  98.687  -57.636  50.327  1
582910  98.717  -57.630  50.297  1
582911  98.747  -57.624  50.267  1
582912  98.777  -57.618  50.236  1
582913  98.811  -57.617  50.205  1
582914  98.849  -57.620  50.174  1
582915  98.880  -57.627  50.142  1
582916  98.910  -57.636  50.112  1
582917  98.940  -57.643  50.083  1
582918  98.969  -57.651  50.053  1
582919  98.993  -57.656  50.024  1
582920  99.017  -57.661  49.994  1
582921  99.041  -57.666  49.963  1
582922  99.065  -57.671  49.931  1
582923  99.088  -57.677  49.899  1
582924  99.113  -57.681  49.866  1
582925  99.137  -57.686  49.833  1
582926  99.160  -57.691  49.802  1
582927  99.185  -57.696  49.768  1
582928  99.208  -57.702  49.734  1
582929  99.220  -57.708  49.700  1
582930  99.232  -57.714  49.667  1
582931  99.259  -57.721  49.634  1
582932  99.287  -57.729  49.600  1
582933  99.316  -57.736  49.569  1
582934  99.345  -57.743  49.537  1
582935  99.382  -57.754  49.504  1
582936  99.419  -57.764  49.470  1
582937  99.451  -57.776  49.434  1
582938  99.505  -57.783  49.397  1
582939  99.556  -57.789  49.361  1
582940  99.593  -57.798  49.326  1
582941  99.628  -57.807  49.291  1
582942  99.662  -57.815  49.257  1
582943  99.697  -57.824  49.222  1
582944  99.731  -57.833  49.189  1
582945  99.766  -57.842  49.158  1
582946  99.800  -57.851  49.126  1
582947  99.835  -57.859  49.097  1
582948  99.869  -57.868  49.069  1
582949  99.904  -57.877  49.041  1
582950  99.938  -57.886  49.014  1
582951  99.973  -57.894  48.989  1
582952  100.007  -57.903  48.966  1
583295  88.112  -54.087  57.571  4
583296  88.148  -54.102  57.574  4
583297  88.183  -54.117  57.576  4
583298  88.218  -54.132  57.577  4
583299  88.254  -54.148  57.579  4
583300  88.289  -54.164  57.580  4
583301  88.325  -54.179  57.582  4
583302  88.360  -54.194  57.582  4
583303  88.395  -54.209  57.582  4
583304  88.430  -54.225  57.581  4
583305  88.466  -54.240  57.581  4
583306  88.501  -54.255  57.579  4
583307  88.537  -54.270  57.578  4
583308  88.572  -54.286  57.576  4
583309  88.607  -54.301  57.574  4
583310  88.665  -54.251  57.572  4
583311  88.717  -54.251  57.574  4
583312  88.755  -54.281  57.579  4
583313  88.790  -54.314  57.578  4
583314  88.829  -54.331  57.566  4
583315  88.867  -54.348  57.541  4
583316  88.905  -54.364  57.505  4
583317  88.943  -54.382  57.458  4
583318  88.981  -54.399  57.413  4
583319  89.020  -54.415  57.368  4
583320  89.057  -54.432  57.323  4
583321  89.096  -54.449  57.275  4
583322  89.134  -54.465  57.227  4
583323  89.172  -54.483  57.178  4
583324  89.210  -54.499  57.130  4
583325  89.248  -54.516  57.081  4
583326  89.286  -54.533  57.033  4
583327  89.324  -54.549  56.984  4
583328  89.363  -54.568  56.937  4
583329  89.401  -54.590  56.892  4
583347  90.096  -55.012  56.042  1
583348  90.134  -55.035  56.015  1
583349  90.173  -55.059  55.990  1
583350  90.207  -55.080  55.966  1
583351  90.231  -55.094  55.943  1
583352  90.254  -55.108  55.922  1
583353  90.277  -55.122  55.903  1
583354  90.300  -55.136  55.886  1
583355  90.324  -55.151  55.870  1
583356  90.347  -55.164  55.856  1
583357  90.370  -55.179  55.845  1
583358  90.393  -55.192  55.838  1
583359  90.416  -55.207  55.831  1
583360  90.440  -55.221  55.827  1
583361  90.463  -55.235  55.825  1
583362  90.486  -55.249  55.828  1
583363  90.510  -55.263  55.835  1
583364  90.533  -55.277  55.848  1
583365  90.558  -55.289  55.862  1
583366  90.584  -55.298  55.876  1
583367  90.610  -55.309  55.890  1
583368  90.636  -55.319  55.903  1
583369  90.662  -55.329  55.909  1
583370  90.692  -55.342  55.914  1
583371  90.730  -55.357  55.920  1
583372  90.775  -55.368  55.929  1
583373  90.820  -55.379  55.940  1
583374  90.865  -55.390  55.954  1
583375  90.910  -55.401  55.969  1
583376  90.955  -55.413  55.981  1
583377  91.000  -55.424  55.988  1
583378  91.045  -55.436  55.987  1
583379  91.090  -55.447  55.982  1
583380  91.135  -55.458  55.975  1
583381  91.180  -55.469  55.970  1
583382  91.225  -55.480  55.965  1
583383  91.270  -55.492  55.955  1
583384  91.315  -55.503  55.938  1
583385  91.360  -55.514  55.917  1
583386  91.404  -55.526  55.888  1
583387  91.450  -55.537  55.858  1
583388  91.493  -55.549  55.830  1
583389  91.528  -55.561  55.799  1
583390  91.563  -55.574  55.765  1
583391  91.596  -55.586  55.734  1
583392  91.626  -55.598  55.709  1
583393  91.656  -55.610  55.678  1
583394  91.686  -55.621  55.643  1
583395  91.717  -55.633  55.603  1
583396  91.747  -55.645  55.559  1
583397  91.778  -55.657  55.513  1
583398  91.808  -55.668  55.472  1
583399  91.838  -55.680  55.435  1
583400  91.868  -55.692  55.401  1
583401  91.898  -55.704  55.370  1
583402  91.929  -55.716  55.339  1
583403  91.959  -55.727  55.310  1
583404  91.989  -55.740  55.284  1
583405  92.021  -55.752  55.260  1
583406  92.053  -55.765  55.240  1
583407  92.086  -55.777  55.221  1
583408  92.117  -55.797  55.204  1
583409  92.148  -55.824  55.190  1
583410  92.178  -55.850  55.180  1
583411  92.209  -55.875  55.174  1
583412  92.239  -55.901  55.170  1
583413  92.270  -55.926  55.170  1
583414  92.302  -55.950  55.172  1
583415  92.335  -55.973  55.177  1
583416  92.367  -55.997  55.184  1
583417  92.399  -56.020  55.190  1
583418  92.431  -56.044  55.193  1
583419  92.463  -56.067  55.194  1
583420  92.496  -56.088  55.198  1
583421  92.530  -56.102  55.206  1
583422  92.565  -56.116  55.216  1
583423  92.599  -56.131  55.223  1
583424  92.633  -56.145  55.227  1
583425  92.667  -56.160  55.230  1
583426  92.702  -56.174  55.237  1
583427  92.736  -56.188  55.248  1
583428  92.771  -56.204  55.271  1
583429  92.807  -56.219  55.295  1
583430  92.844  -56.235  55.315  1
583431  92.880  -56.246  55.331  1
583432  92.916  -56.251  55.343  1
583433  92.951  -56.255  55.351  1
583434  92.992  -56.265  55.359  1
583435  93.035  -56.279  55.364  1
583436  93.078  -56.292  55.367  1
583437  93.121  -56.306  55.368  1
583438  93.164  -56.320  55.366  1
583439  93.207  -56.333  55.367  1
583440  93.250  -56.347  55.367  1
583441  93.293  -56.360  55.362  1
583442  93.336  -56.374  55.354  1
583443  93.370  -56.383  55.344  1
583444  93.399  -56.389  55.333  1
583445  93.431  -56.401  55.318  1
583446  93.464  -56.414  55.300  1
583447  93.497  -56.425  55.279  1
583448  93.530  -56.437  55.256  1
583449  93.562  -56.449  55.233  1
583450  93.595  -56.461  55.207  1
583451  93.627  -56.473  55.176  1
583452  93.660  -56.485  55.144  1
583453  93.693  -56.496  55.111  1
583454  93.725  -56.508  55.077  1
583455  93.758  -56.520  55.041  1
583456  93.791  -56.532  55.008  1
583457  93.824  -56.544  54.974  1
583458  93.856  -56.556  54.941  1
583459  93.889  -56.570  54.906  1
583460  93.921  -56.587  54.867  1
583461  93.953  -56.604  54.827  1
583462  93.985  -56.621  54.784  1
583463  94.017  -56.638  54.738  1
583464  94.049  -56.655  54.690  1
583465  94.081  -56.672  54.640  1
583466  94.113  -56.689  54.592  1
583467  94.143  -56.705  54.551  1
583468  94.174  -56.720  54.514  1
583469  94.204  -56.736  54.480  1
583470  94.235  -56.752  54.446  1
583471  94.264  -56.765  54.409  1
583472  94.292  -56.774  54.372  1
583473  94.320  -56.783  54.336  1
583474  94.353  -56.793  54.301  1
583475  94.389  -56.802  54.265  1
583476  94.425  -56.812  54.227  1
583477  94.455  -56.826  54.187  1
583478  94.484  -56.841  54.145  1
583479  94.514  -56.855  54.103  1
583480  94.543  -56.871  54.059  1
583481  94.572  -56.886  54.017  1
583482  94.602  -56.900  53.975  1
583483  94.631  -56.915  53.933  1
583484  94.661  -56.930  53.891  1
583485  94.690  -56.945  53.849  1
583486  94.719  -56.959  53.810  1
583487  94.749  -56.975  53.764  1
583488  94.778  -56.989  53.718  1
583489  94.808  -57.004  53.677  1
583490  94.837  -57.018  53.644  1
583491  94.866  -57.034  53.620  1
583492  94.896  -57.049  53.600  1
583493  94.927  -57.062  53.574  1
583494  94.959  -57.074  53.548  1
583495  94.991  -57.087  53.523  1
583496  95.024  -57.099  53.498  1
583497  95.056  -57.112  53.473  1
583498  95.089  -57.124  53.445  1
583499  95.121  -57.137  53.413  1
583500  95.159  -57.141  53.380  1
583501  95.197  -57.144  53.350  1
583502  95.236  -57.148  53.324  1
583503  95.274  -57.152  53.298  1
583504  95.313  -57.158  53.271  1
583505  95.351  -57.167  53.240  1
583506  95.389  -57.177  53.205  1
583507  95.428  -57.185  53.167  1
583508  95.467  -57.194  53.128  1
583509  95.506  -57.203  53.083  1
583510  95.544  -57.211  53.036  1
583511  95.583  -57.219  52.990  1
583512  95.622  -57.228  52.945  1
583513  95.661  -57.236  52.905  1
583514  95.699  -57.244  52.873  1
583515  95.739  -57.253  52.845  1
583516  95.777  -57.261  52.818  1
583517  95.815  -57.269  52.791  1
583518  95.840  -57.276  52.764  1
583519  95.862  -57.283  52.734  1
583520  95.884  -57.290  52.701  1
583521  95.905  -57.297  52.665  1
583522  95.927  -57.304  52.624  1
583523  95.949  -57.310  52.583  1
583524  95.970  -57.317  52.542  1
583525  95.992  -57.323  52.501  1
583526  96.013  -57.329  52.461  1
583527  96.034  -57.335  52.423  1
583528  96.054  -57.340  52.387  1
583529  96.076  -57.345  52.352  1
583530  96.096  -57.351  52.318  1
583531  96.118  -57.357  52.288  1
583532  96.148  -57.364  52.261  1
583533  96.177  -57.372  52.234  1
583534  96.205  -57.379  52.209  1
583535  96.235  -57.387  52.182  1
583536  96.264  -57.395  52.152  1
583537  96.293  -57.402  52.124  1
583538  96.322  -57.410  52.100  1
583539  96.351  -57.417  52.079  1
583540  96.380  -57.425  52.058  1
583541  96.408  -57.432  52.040  1
583542  96.437  -57.438  52.025  1
583543  96.465  -57.445  52.014  1
583544  96.493  -57.451  52.001  1
583545  96.523  -57.457  51.995  1
583546  96.552  -57.463  51.992  1
583547  96.582  -57.468  51.986  1
583548  96.614  -57.473  51.974  1
583549  96.647  -57.477  51.955  1
583550  96.679  -57.482  51.933  1
583551  96.712  -57.486  51.912  1
583552  96.747  -57.492  51.900  1
583553  96.783  -57.497  51.893  1
583554  96.818  -57.502  51.887  1
583555  96.854  -57.507  51.882  1
583556  96.890  -57.513  51.881  1
583557  96.926  -57.518  51.883  1
583558  96.962  -57.523  51.887  1
583559  96.998  -57.528  51.893  1
583560  97.033  -57.532  51.898  1
583561  97.071  -57.529  51.903  1
583562  97.107  -57.527  51.909  1
583563  97.145  -57.525  51.913  1
583564  97.177  -57.523  51.913  1
583565  97.204  -57.520  51.912  1
583566  97.231  -57.516  51.909  1
583567  97.259  -57.513  51.903  1
583568  97.286  -57.510  51.892  1
583569  97.313  -57.507  51.880  1
583570  97.341  -57.504  51.866  1
583571  97.368  -57.500  51.851  1
583572  97.395  -57.497  51.834  1
583573  97.423  -57.494  51.815  1
583574  97.450  -57.491  51.794  1
583575  97.479  -57.492  51.766  1
583576  97.513  -57.505  51.729  1
583577  97.548  -57.520  51.687  1
583578  97.581  -57.532  51.641  1
583579  97.611  -57.539  51.593  1
583580  97.642  -57.546  51.541  1
583581  97.673  -57.554  51.489  1
583582  97.703  -57.561  51.436  1
583583  97.734  -57.568  51.382  1
583584  97.764  -57.576  51.325  1
583585  97.794  -57.579  51.270  1
583586  97.824  -57.580  51.224  1
583587  97.854  -57.582  51.183  1
583588  97.884  -57.583  51.143  1
583589  97.914  -57.585  51.102  1
583590  97.944  -57.587  51.061  1
583591  97.973  -57.589  51.020  1
583592  98.006  -57.591  50.978  1
583593  98.041  -57.595  50.935  1
583594  98.077  -57.599  50.891  1
583595  98.113  -57.604  50.847  1
583596  98.149  -57.608  50.805  1
583597  98.184  -57.612  50.764  1
583598  98.223  -57.616  50.726  1
583599  98.268  -57.618  50.689  1
583600  98.313  -57.621  50.655  1
583601  98.358  -57.624  50.622  1
583602  98.403  -57.626  50.591  1
583603  98.448  -57.630  50.560  1
583604  98.493  -57.633  50.526  1
583605  98.537  -57.635  50.494  1
583606  98.567  -57.629  50.463  1
583607  98.597  -57.623  50.432  1
583608  98.628  -57.617  50.402  1
583609  98.658  -57.611  50.372  1
583610  98.688  -57.606  50.340  1
583611  98.718  -57.600  50.308  1
583612  98.748  -57.595  50.277  1
583613  98.778  -57.589  50.245  1
583614  98.814  -57.590  50.213  1
583615  98.852  -57.592  50.181  1
583616  98.883  -57.600  50.149  1
583617  98.914  -57.608  50.118  1
583618  98.944  -57.615  50.088  1
583619  98.974  -57.623  50.058  1
583620  99.004  -57.631  50.029  1
583621  99.028  -57.636  49.998  1
583622  99.052  -57.642  49.967  1
583623  99.076  -57.647  49.937  1
583624  99.100  -57.651  49.904  1
583625  99.124  -57.657  49.871  1
583626  99.148  -57.661  49.838  1
583627  99.171  -57.667  49.806  1
583628  99.196  -57.672  49.772  1
583629  99.210  -57.678  49.738  1
583630  99.221  -57.685  49.703  1
583631  99.233  -57.691  49.669  1
583632  99.261  -57.699  49.635  1
583633  99.289  -57.705  49.601  1
583634  99.317  -57.713  49.568  1
583635  99.346  -57.720  49.536  1
583636  99.375  -57.727  49.503  1
583637  99.409  -57.736  49.470  1
583638  99.446  -57.746  49.435  1
583639  99.490  -57.756  49.397  1
583640  99.542  -57.763  49.360  1
583641  99.585  -57.771  49.324  1
583642  99.620  -57.779  49.288  1
583643  99.654  -57.788  49.253  1
583644  99.689  -57.796  49.218  1
583645  99.723  -57.805  49.184  1
583646  99.758  -57.814  49.152  1
583647  99.792  -57.823  49.121  1
583648  99.827  -57.831  49.092  1
583649  99.861  -57.840  49.063  1
583650  99.896  -57.849  49.037  1
583651  99.930  -57.858  49.010  1
583652  99.965  -57.867  48.986  1
583653  99.999  -57.875  48.964  1
583654  100.034  -57.884  48.941  1
583997  88.173  -54.067  57.572  4
583998  88.208  -54.082  57.574  4
583999  88.243  -54.098  57.575  4
584000  88.278  -54.113  57.577  4
584001  88.314  -54.129  57.578  4
584002  88.349  -54.144  57.580  4
584003  88.385  -54.159  57.580  4
584004  88.420  -54.174  57.580  4
584005  88.455  -54.190  57.580  4
584006  88.491  -54.205  57.578  4
584007  88.526  -54.220  57.578  4
584008  88.561  -54.236  57.576  4
584009  88.597  -54.251  57.575  4
584010  88.632  -54.267  57.574  4
584011  88.680  -54.245  57.573  4
584012  88.735  -54.235  57.576  4
584013  88.778  -54.255  57.580  4
584014  88.813  -54.291  57.577  4
584015  88.851  -54.308  57.567  4
584016  88.889  -54.324  57.552  4
584017  88.927  -54.342  57.517  4
584018  88.965  -54.358  57.472  4
584019  89.003  -54.375  57.424  4
584020  89.041  -54.392  57.378  4
584021  89.080  -54.408  57.332  4
584022  89.118  -54.425  57.283  4
584023  89.156  -54.442  57.234  4
584024  89.194  -54.459  57.186  4
584025  89.232  -54.476  57.137  4
584026  89.270  -54.493  57.088  4
584027  89.308  -54.509  57.040  4
584028  89.346  -54.527  56.991  4
584029  89.384  -54.543  56.944  4
584030  89.422  -54.560  56.899  4
584047  90.079  -54.957  56.079  1
584048  90.117  -54.980  56.050  1
584049  90.156  -55.003  56.024  1
584050  90.194  -55.027  55.999  1
584051  90.227  -55.047  55.976  1
584052  90.250  -55.060  55.953  1
584053  90.273  -55.075  55.932  1
584054  90.296  -55.089  55.913  1
584055  90.319  -55.103  55.895  1
584056  90.342  -55.117  55.880  1
584057  90.366  -55.131  55.866  1
584058  90.389  -55.145  55.855  1
584059  90.412  -55.160  55.846  1
584060  90.436  -55.173  55.839  1
584061  90.459  -55.188  55.834  1
584062  90.482  -55.201  55.831  1
584063  90.505  -55.216  55.832  1
584064  90.529  -55.230  55.840  1
584065  90.553  -55.244  55.850  1
584066  90.579  -55.255  55.861  1
584067  90.605  -55.265  55.872  1
584068  90.632  -55.276  55.882  1
584069  90.658  -55.285  55.891  1
584070  90.684  -55.296  55.897  1
584071  90.719  -55.312  55.901  1
584072  90.754  -55.328  55.908  1
584073  90.790  -55.343  55.919  1
584074  90.833  -55.356  55.932  1
584075  90.878  -55.367  55.947  1
584076  90.923  -55.378  55.961  1
584077  90.968  -55.389  55.970  1
584078  91.013  -55.401  55.972  1
584079  91.058  -55.412  55.967  1
584080  91.103  -55.423  55.959  1
584081  91.148  -55.435  55.952  1
584082  91.192  -55.446  55.949  1
584083  91.238  -55.457  55.945  1
584084  91.283  -55.468  55.933  1
584085  91.327  -55.480  55.912  1
584086  91.373  -55.491  55.884  1
584087  91.418  -55.502  55.852  1
584088  91.462  -55.514  55.823  1
584089  91.502  -55.526  55.795  1
584090  91.536  -55.539  55.766  1
584091  91.572  -55.551  55.736  1
584092  91.607  -55.564  55.705  1
584093  91.642  -55.577  55.676  1
584094  91.674  -55.589  55.644  1
584095  91.705  -55.601  55.608  1
584096  91.735  -55.612  55.571  1
584097  91.765  -55.624  55.532  1
584098  91.795  -55.636  55.493  1
584099  91.825  -55.648  55.456  1
584100  91.856  -55.659  55.422  1
584101  91.886  -55.671  55.390  1
584102  91.917  -55.683  55.360  1
584103  91.947  -55.695  55.332  1
584104  91.977  -55.706  55.305  1
584105  92.007  -55.718  55.280  1
584106  92.039  -55.730  55.258  1
584107  92.072  -55.743  55.238  1
584108  92.104  -55.756  55.220  1
584109  92.136  -55.771  55.204  1
584110  92.166  -55.797  55.189  1
584111  92.197  -55.823  55.177  1
584112  92.227  -55.850  55.169  1
584113  92.258  -55.875  55.164  1
584114  92.289  -55.901  55.163  1
584115  92.319  -55.927  55.164  1
584116  92.351  -55.950  55.169  1
584117  92.383  -55.974  55.176  1
584118  92.416  -55.997  55.180  1
584119  92.448  -56.021  55.181  1
584120  92.480  -56.044  55.181  1
584121  92.513  -56.063  55.184  1
584122  92.548  -56.077  55.195  1
584123  92.582  -56.091  55.208  1
584124  92.616  -56.106  55.220  1
584125  92.650  -56.120  55.229  1
584126  92.685  -56.135  55.235  1
584127  92.720  -56.150  55.243  1
584128  92.756  -56.165  55.249  1
584129  92.792  -56.181  55.267  1
584130  92.829  -56.196  55.287  1
584131  92.865  -56.212  55.305  1
584132  92.901  -56.224  55.320  1
584133  92.936  -56.229  55.330  1
584134  92.973  -56.233  55.338  1
584135  93.008  -56.238  55.349  1
584136  93.044  -56.241  55.358  1
584137  93.086  -56.254  55.362  1
584138  93.129  -56.267  55.365  1
584139  93.172  -56.281  55.365  1
584140  93.215  -56.295  55.364  1
584141  93.258  -56.308  55.364  1
584142  93.301  -56.322  55.361  1
584143  93.344  -56.335  55.355  1
584144  93.381  -56.346  55.346  1
584145  93.410  -56.353  55.339  1
584146  93.443  -56.365  55.325  1
584147  93.476  -56.376  55.309  1
584148  93.508  -56.389  55.291  1
584149  93.541  -56.401  55.268  1
584150  93.573  -56.413  55.243  1
584151  93.606  -56.424  55.217  1
584152  93.639  -56.436  55.185  1
584153  93.672  -56.448  55.152  1
584154  93.704  -56.460  55.117  1
584155  93.737  -56.472  55.079  1
584156  93.770  -56.484  55.041  1
584157  93.802  -56.496  55.002  1
584158  93.834  -56.513  54.964  1
584159  93.866  -56.530  54.930  1
584160  93.899  -56.547  54.897  1
584161  93.930  -56.564  54.862  1
584162  93.963  -56.581  54.824  1
584163  93.995  -56.598  54.785  1
584164  94.027  -56.614  54.742  1
584165  94.059  -56.631  54.696  1
584166  94.091  -56.649  54.648  1
584167  94.121  -56.664  54.599  1
584168  94.151  -56.680  54.554  1
584169  94.182  -56.696  54.513  1
584170  94.212  -56.711  54.476  1
584171  94.242  -56.727  54.441  1
584172  94.272  -56.740  54.406  1
584173  94.300  -56.749  54.369  1
584174  94.328  -56.758  54.334  1
584175  94.358  -56.767  54.299  1
584176  94.394  -56.777  54.264  1
584177  94.430  -56.786  54.226  1
584178  94.466  -56.796  54.186  1
584179  94.495  -56.810  54.143  1
584180  94.525  -56.825  54.101  1
584181  94.554  -56.840  54.059  1
584182  94.583  -56.855  54.017  1
584183  94.613  -56.869  53.975  1
584184  94.642  -56.884  53.934  1
584185  94.671  -56.899  53.894  1
584186  94.701  -56.914  53.854  1
584187  94.730  -56.929  53.814  1
584188  94.759  -56.943  53.770  1
584189  94.789  -56.959  53.720  1
584190  94.818  -56.973  53.670  1
584191  94.847  -56.988  53.627  1
584192  94.877  -57.003  53.595  1
584193  94.906  -57.018  53.572  1
584194  94.935  -57.032  53.548  1
584195  94.965  -57.047  53.522  1
584196  94.994  -57.062  53.495  1
584197  95.024  -57.077  53.467  1
584198  95.054  -57.091  53.440  1
584199  95.087  -57.103  53.410  1
584200  95.122  -57.111  53.379  1
584201  95.161  -57.114  53.347  1
584202  95.199  -57.118  53.316  1
584203  95.238  -57.122  53.289  1
584204  95.277  -57.125  53.266  1
584205  95.315  -57.128  53.238  1
584206  95.354  -57.137  53.205  1
584207  95.393  -57.145  53.170  1
584208  95.431  -57.154  53.133  1
584209  95.470  -57.163  53.094  1
584210  95.509  -57.171  53.049  1
584211  95.548  -57.179  53.002  1
584212  95.587  -57.188  52.956  1
584213  95.626  -57.196  52.913  1
584214  95.665  -57.204  52.876  1
584215  95.703  -57.213  52.845  1
584216  95.742  -57.222  52.817  1
584217  95.781  -57.230  52.790  1
584218  95.818  -57.238  52.764  1
584219  95.844  -57.244  52.738  1
584220  95.866  -57.251  52.709  1
584221  95.887  -57.258  52.677  1
584222  95.909  -57.265  52.638  1
584223  95.931  -57.272  52.596  1
584224  95.952  -57.278  52.555  1
584225  95.974  -57.285  52.515  1
584226  95.995  -57.291  52.475  1
584227  96.017  -57.298  52.437  1
584228  96.039  -57.305  52.400  1
584229  96.060  -57.311  52.364  1
584230  96.081  -57.316  52.331  1
584231  96.102  -57.322  52.300  1
584232  96.123  -57.328  52.270  1
584233  96.150  -57.335  52.243  1
584234  96.179  -57.342  52.217  1
584235  96.208  -57.350  52.192  1
584236  96.237  -57.357  52.166  1
584237  96.266  -57.365  52.137  1
584238  96.295  -57.373  52.110  1
584239  96.324  -57.379  52.087  1
584240  96.352  -57.386  52.064  1
584241  96.380  -57.392  52.043  1
584242  96.409  -57.398  52.024  1
584243  96.437  -57.405  52.004  1
584244  96.465  -57.411  51.986  1
584245  96.495  -57.417  51.971  1
584246  96.524  -57.423  51.960  1
584247  96.554  -57.428  51.955  1
584248  96.584  -57.434  51.948  1
584249  96.616  -57.438  51.938  1
584250  96.649  -57.443  51.924  1
584251  96.681  -57.448  51.904  1
584252  96.713  -57.452  51.884  1
584253  96.745  -57.457  51.875  1
584254  96.778  -57.461  51.870  1
584255  96.813  -57.467  51.865  1
584256  96.849  -57.472  51.856  1
584257  96.884  -57.477  51.853  1
584258  96.920  -57.482  51.852  1
584259  96.956  -57.488  51.851  1
584260  96.992  -57.493  51.851  1
584261  97.028  -57.494  51.852  1
584262  97.066  -57.492  51.854  1
584263  97.102  -57.489  51.859  1
584264  97.140  -57.487  51.864  1
584265  97.176  -57.485  51.863  1
584266  97.207  -57.482  51.862  1
584267  97.234  -57.479  51.860  1
584268  97.261  -57.476  51.857  1
584269  97.289  -57.472  51.848  1
584270  97.316  -57.469  51.838  1
584271  97.344  -57.466  51.825  1
584272  97.371  -57.463  51.811  1
584273  97.398  -57.460  51.794  1
584274  97.426  -57.456  51.774  1
584275  97.453  -57.453  51.753  1
584276  97.481  -57.452  51.728  1
584277  97.516  -57.467  51.694  1
584278  97.550  -57.481  51.653  1
584279  97.583  -57.492  51.609  1
584280  97.613  -57.499  51.562  1
584281  97.644  -57.507  51.512  1
584282  97.674  -57.514  51.461  1
584283  97.705  -57.521  51.409  1
584284  97.735  -57.529  51.356  1
584285  97.766  -57.536  51.303  1
584286  97.797  -57.543  51.251  1
584287  97.826  -57.545  51.208  1
584288  97.856  -57.546  51.170  1
584289  97.886  -57.548  51.132  1
584290  97.916  -57.550  51.094  1
584291  97.946  -57.551  51.055  1
584292  97.976  -57.553  51.016  1
584293  98.010  -57.556  50.975  1
584294  98.045  -57.561  50.935  1
584295  98.081  -57.564  50.893  1
584296  98.117  -57.569  50.850  1
584297  98.153  -57.573  50.808  1
584298  98.189  -57.577  50.769  1
584299  98.224  -57.581  50.731  1
584300  98.263  -57.585  50.695  1
584301  98.308  -57.588  50.660  1
584302  98.353  -57.591  50.626  1
584303  98.398  -57.593  50.594  1
584304  98.443  -57.596  50.563  1
584305  98.488  -57.599  50.529  1
584306  98.533  -57.602  50.497  1
584307  98.568  -57.599  50.467  1
584308  98.598  -57.593  50.437  1
584309  98.628  -57.587  50.408  1
584310  98.658  -57.582  50.379  1
584311  98.688  -57.576  50.346  1
584312  98.718  -57.570  50.314  1
584313  98.748  -57.564  50.282  1
584314  98.780  -57.560  50.250  1
584315  98.817  -57.563  50.218  1
584316  98.855  -57.565  50.186  1
584317  98.887  -57.572  50.155  1
584318  98.918  -57.579  50.124  1
584319  98.947  -57.588  50.093  1
584320  98.978  -57.595  50.064  1
584321  99.008  -57.604  50.034  1
584322  99.038  -57.611  50.004  1
584323  99.063  -57.617  49.973  1
584324  99.087  -57.622  49.941  1
584325  99.111  -57.627  49.909  1
584326  99.135  -57.632  49.876  1
584327  99.159  -57.637  49.843  1
584328  99.183  -57.642  49.811  1
584329  99.199  -57.648  49.777  1
584330  99.211  -57.655  49.742  1
584331  99.222  -57.661  49.707  1
584332  99.233  -57.668  49.672  1
584333  99.262  -57.675  49.637  1
584334  99.291  -57.683  49.602  1
584335  99.320  -57.689  49.568  1
584336  99.348  -57.697  49.536  1
584337  99.376  -57.704  49.503  1
584338  99.405  -57.711  49.470  1
584339  99.436  -57.719  49.435  1
584340  99.476  -57.730  49.397  1
584341  99.527  -57.736  49.360  1
584342  99.578  -57.742  49.322  1
584343  99.613  -57.752  49.285  1
584344  99.647  -57.760  49.248  1
584345  99.682  -57.769  49.213  1
584346  99.716  -57.777  49.179  1
584347  99.751  -57.786  49.147  1
584348  99.785  -57.795  49.117  1
584349  99.820  -57.804  49.088  1
584350  99.854  -57.812  49.060  1
584351  99.889  -57.821  49.033  1
584352  99.923  -57.830  49.006  1
584353  99.958  -57.839  48.984  1
584354  99.992  -57.848  48.962  1
584355  100.027  -57.856  48.940  1
584356  100.061  -57.865  48.918  1
584698  88.197  -54.032  57.569  4
584699  88.233  -54.048  57.571  4
584700  88.268  -54.063  57.572  4
584701  88.303  -54.078  57.574  4
584702  88.338  -54.094  57.576  4
584703  88.374  -54.109  57.577  4
584704  88.409  -54.124  57.577  4
584705  88.445  -54.139  57.577  4
584706  88.480  -54.154  57.578  4
584707  88.516  -54.170  57.576  4
584708  88.551  -54.185  57.575  4
584709  88.586  -54.201  57.574  4
584710  88.621  -54.216  57.572  4
584711  88.657  -54.231  57.571  4
584712  88.695  -54.239  57.570  4
584713  88.751  -54.220  57.572  4
584714  88.800  -54.230  57.573  4
584715  88.835  -54.266  57.572  4
584716  88.873  -54.284  57.568  4
584717  88.911  -54.301  57.555  4
584718  88.949  -54.318  57.532  4
584719  88.987  -54.335  57.487  4
584720  89.025  -54.352  57.435  4
584721  89.063  -54.368  57.386  4
584722  89.101  -54.385  57.339  4
584723  89.139  -54.402  57.290  4
584724  89.178  -54.419  57.241  4
584725  89.215  -54.436  57.192  4
584726  89.254  -54.452  57.143  4
584727  89.292  -54.469  57.094  4
584728  89.330  -54.486  57.046  4
584729  89.368  -54.503  56.996  4
584730  89.406  -54.520  56.949  4
584731  89.445  -54.536  56.903  4
584732  89.482  -54.553  56.859  4
584747  90.061  -54.902  56.117  1
584748  90.100  -54.925  56.087  1
584749  90.139  -54.948  56.060  1
584750  90.177  -54.972  56.034  1
584751  90.216  -54.995  56.009  1
584752  90.245  -55.013  55.986  1
584753  90.268  -55.027  55.964  1
584754  90.292  -55.041  55.943  1
584755  90.315  -55.056  55.924  1
584756  90.338  -55.069  55.907  1
584757  90.362  -55.084  55.892  1
584758  90.385  -55.098  55.877  1
584759  90.408  -55.112  55.864  1
584760  90.432  -55.126  55.855  1
584761  90.455  -55.140  55.847  1
584762  90.478  -55.154  55.841  1
584763  90.501  -55.169  55.837  1
584764  90.524  -55.182  55.836  1
584765  90.549  -55.197  55.842  1
584766  90.575  -55.210  55.849  1
584767  90.601  -55.222  55.857  1
584768  90.627  -55.232  55.864  1
584769  90.653  -55.242  55.871  1
584770  90.679  -55.253  55.878  1
584771  90.711  -55.267  55.884  1
584772  90.746  -55.282  55.890  1
584773  90.782  -55.298  55.900  1
584774  90.817  -55.314  55.914  1
584775  90.853  -55.329  55.928  1
584776  90.891  -55.344  55.942  1
584777  90.936  -55.354  55.954  1
584778  90.980  -55.366  55.960  1
584779  91.026  -55.377  55.960  1
584780  91.071  -55.389  55.954  1
584781  91.115  -55.400  55.942  1
584782  91.161  -55.411  55.932  1
584783  91.206  -55.423  55.929  1
584784  91.250  -55.433  55.924  1
584785  91.296  -55.445  55.912  1
584786  91.341  -55.456  55.890  1
584787  91.385  -55.467  55.854  1
584788  91.431  -55.479  55.818  1
584789  91.475  -55.490  55.790  1
584790  91.510  -55.503  55.764  1
584791  91.545  -55.515  55.738  1
584792  91.580  -55.528  55.711  1
584793  91.615  -55.541  55.680  1
584794  91.651  -55.554  55.647  1
584795  91.685  -55.567  55.614  1
584796  91.721  -55.579  55.580  1
584797  91.753  -55.591  55.545  1
584798  91.783  -55.603  55.510  1
584799  91.813  -55.615  55.474  1
584800  91.844  -55.627  55.440  1
584801  91.874  -55.639  55.408  1
584802  91.904  -55.650  55.380  1
584803  91.934  -55.662  55.352  1
584804  91.965  -55.674  55.326  1
584805  91.995  -55.686  55.302  1
584806  92.025  -55.697  55.279  1
584807  92.057  -55.710  55.258  1
584808  92.090  -55.722  55.239  1
584809  92.122  -55.735  55.221  1
584810  92.155  -55.748  55.206  1
584811  92.186  -55.771  55.191  1
584812  92.216  -55.797  55.178  1
584813  92.246  -55.823  55.168  1
584814  92.277  -55.849  55.161  1
584815  92.307  -55.875  55.158  1
584816  92.338  -55.901  55.156  1
584817  92.368  -55.927  55.159  1
584818  92.400  -55.950  55.164  1
584819  92.432  -55.974  55.167  1
584820  92.464  -55.997  55.167  1
584821  92.497  -56.021  55.169  1
584822  92.530  -56.038  55.176  1
584823  92.565  -56.052  55.189  1
584824  92.599  -56.066  55.203  1
584825  92.634  -56.081  55.217  1
584826  92.668  -56.096  55.227  1
584827  92.704  -56.111  55.234  1
584828  92.740  -56.127  55.239  1
584829  92.777  -56.142  55.242  1
584830  92.813  -56.158  55.250  1
584831  92.849  -56.173  55.264  1
584832  92.885  -56.188  55.281  1
584833  92.922  -56.201  55.294  1
584834  92.957  -56.206  55.306  1
584835  92.993  -56.210  55.319  1
584836  93.029  -56.215  55.334  1
584837  93.065  -56.219  55.346  1
584838  93.101  -56.224  55.352  1
584839  93.137  -56.229  55.355  1
584840  93.181  -56.243  55.358  1
584841  93.223  -56.257  55.358  1
584842  93.267  -56.270  55.357  1
584843  93.309  -56.284  55.355  1
584844  93.353  -56.298  55.350  1
584845  93.392  -56.309  55.343  1
584846  93.422  -56.317  55.340  1
584847  93.454  -56.329  55.327  1
584848  93.487  -56.340  55.313  1
584849  93.519  -56.352  55.297  1
584850  93.552  -56.364  55.275  1
584851  93.585  -56.376  55.248  1
584852  93.618  -56.388  55.225  1
584853  93.650  -56.400  55.192  1
584854  93.683  -56.411  55.160  1
584855  93.716  -56.423  55.126  1
584856  93.748  -56.439  55.088  1
584857  93.780  -56.456  55.050  1
584858  93.812  -56.473  55.012  1
584859  93.844  -56.489  54.973  1
584860  93.876  -56.507  54.934  1
584861  93.908  -56.523  54.894  1
584862  93.940  -56.540  54.854  1
584863  93.973  -56.558  54.816  1
584864  94.004  -56.574  54.778  1
584865  94.037  -56.591  54.739  1
584866  94.068  -56.608  54.699  1
584867  94.099  -56.624  54.658  1
584868  94.129  -56.639  54.614  1
584869  94.159  -56.655  54.569  1
584870  94.190  -56.671  54.522  1
584871  94.220  -56.686  54.476  1
584872  94.250  -56.702  54.439  1
584873  94.279  -56.714  54.405  1
584874  94.308  -56.723  54.370  1
584875  94.336  -56.732  54.335  1
584876  94.364  -56.741  54.300  1
584877  94.399  -56.751  54.263  1
584878  94.434  -56.760  54.226  1
584879  94.470  -56.770  54.186  1
584880  94.506  -56.780  54.142  1
584881  94.535  -56.794  54.099  1
584882  94.564  -56.809  54.057  1
584883  94.594  -56.824  54.016  1
584884  94.623  -56.839  53.974  1
584885  94.652  -56.853  53.933  1
584886  94.682  -56.868  53.892  1
584887  94.711  -56.883  53.853  1
584888  94.741  -56.898  53.812  1
584889  94.770  -56.913  53.769  1
584890  94.800  -56.928  53.721  1
584891  94.829  -56.943  53.668  1
584892  94.858  -56.957  53.616  1
584893  94.888  -56.972  53.577  1
584894  94.917  -56.987  53.547  1
584895  94.947  -57.002  53.521  1
584896  94.976  -57.016  53.496  1
584897  95.005  -57.031  53.469  1
584898  95.035  -57.046  53.441  1
584899  95.064  -57.061  53.412  1
584900  95.093  -57.075  53.382  1
584901  95.128  -57.081  53.349  1
584902  95.167  -57.084  53.315  1
584903  95.205  -57.087  53.282  1
584904  95.245  -57.091  53.253  1
584905  95.283  -57.094  53.228  1
584906  95.323  -57.097  53.200  1
584907  95.357  -57.106  53.168  1
584908  95.396  -57.114  53.132  1
584909  95.435  -57.122  53.094  1
584910  95.474  -57.131  53.055  1
584911  95.513  -57.139  53.012  1
584912  95.552  -57.147  52.966  1
584913  95.591  -57.156  52.922  1
584914  95.629  -57.164  52.882  1
584915  95.668  -57.172  52.848  1
584916  95.707  -57.181  52.817  1
584917  95.746  -57.190  52.790  1
584918  95.784  -57.198  52.764  1
584919  95.821  -57.206  52.738  1
584920  95.848  -57.213  52.711  1
584921  95.870  -57.219  52.682  1
584922  95.891  -57.226  52.649  1
584923  95.913  -57.232  52.610  1
584924  95.934  -57.239  52.567  1
584925  95.956  -57.246  52.525  1
584926  95.977  -57.253  52.485  1
584927  95.999  -57.260  52.446  1
584928  96.021  -57.266  52.410  1
584929  96.042  -57.273  52.375  1
584930  96.064  -57.280  52.340  1
584931  96.086  -57.287  52.308  1
584932  96.107  -57.294  52.279  1
584933  96.128  -57.299  52.252  1
584934  96.152  -57.305  52.224  1
584935  96.181  -57.313  52.199  1
584936  96.210  -57.321  52.174  1
584937  96.239  -57.327  52.149  1
584938  96.267  -57.333  52.123  1
584939  96.296  -57.340  52.096  1
584940  96.324  -57.346  52.074  1
584941  96.352  -57.352  52.052  1
584942  96.381  -57.359  52.033  1
584943  96.409  -57.365  52.012  1
584944  96.437  -57.371  51.990  1
584945  96.467  -57.377  51.967  1
584946  96.496  -57.382  51.947  1
584947  96.526  -57.388  51.932  1
584948  96.555  -57.394  51.922  1
584949  96.585  -57.399  51.913  1
584950  96.618  -57.404  51.903  1
584951  96.650  -57.409  51.891  1
584952  96.682  -57.413  51.873  1
584953  96.715  -57.418  51.855  1
584954  96.747  -57.423  51.843  1
584955  96.780  -57.427  51.839  1
584956  96.812  -57.432  51.837  1
584957  96.844  -57.436  51.833  1
584958  96.879  -57.442  51.829  1
584959  96.914  -57.447  51.823  1
584960  96.951  -57.452  51.818  1
584961  96.986  -57.457  51.813  1
584962  97.023  -57.455  51.809  1
584963  97.061  -57.453  51.807  1
584964  97.097  -57.451  51.808  1
584965  97.135  -57.448  51.813  1
584966  97.171  -57.446  51.814  1
584967  97.209  -57.444  51.813  1
584968  97.237  -57.441  51.811  1
584969  97.264  -57.438  51.807  1
584970  97.292  -57.435  51.800  1
584971  97.319  -57.432  51.793  1
584972  97.346  -57.428  51.784  1
584973  97.374  -57.425  51.772  1
584974  97.401  -57.422  51.755  1
584975  97.428  -57.419  51.731  1
584976  97.456  -57.416  51.710  1
584977  97.484  -57.413  51.687  1
584978  97.518  -57.428  51.657  1
584979  97.552  -57.442  51.619  1
584980  97.585  -57.452  51.576  1
584981  97.615  -57.460  51.529  1
584982  97.646  -57.467  51.479  1
584983  97.676  -57.474  51.429  1
584984  97.707  -57.482  51.378  1
584985  97.737  -57.489  51.328  1
584986  97.768  -57.496  51.278  1
584987  97.798  -57.503  51.229  1
584988  97.829  -57.509  51.187  1
584989  97.859  -57.510  51.151  1
584990  97.888  -57.513  51.116  1
584991  97.919  -57.514  51.081  1
584992  97.948  -57.516  51.045  1
584993  97.979  -57.517  51.008  1
584994  98.014  -57.522  50.970  1
584995  98.050  -57.526  50.932  1
584996  98.085  -57.530  50.892  1
584997  98.121  -57.534  50.850  1
584998  98.157  -57.539  50.810  1
584999  98.193  -57.542  50.772  1
585000  98.228  -57.547  50.736  1
585001  98.264  -57.551  50.699  1
585002  98.302  -57.554  50.662  1
585003  98.347  -57.558  50.628  1
585004  98.392  -57.561  50.595  1
585005  98.437  -57.563  50.564  1
585006  98.483  -57.566  50.529  1
585007  98.528  -57.569  50.498  1
585008  98.569  -57.569  50.468  1
585009  98.598  -57.564  50.440  1
585010  98.629  -57.558  50.411  1
585011  98.659  -57.551  50.382  1
585012  98.689  -57.546  50.349  1
585013  98.719  -57.540  50.317  1
585014  98.749  -57.535  50.284  1
585015  98.783  -57.532  50.252  1
585016  98.820  -57.536  50.222  1
585017  98.858  -57.538  50.190  1
585018  98.891  -57.544  50.160  1
585019  98.922  -57.551  50.129  1
585020  98.951  -57.560  50.098  1
585021  98.982  -57.567  50.069  1
585022  99.012  -57.576  50.039  1
585023  99.042  -57.583  50.009  1
585024  99.072  -57.592  49.978  1
585025  99.098  -57.598  49.945  1
585026  99.122  -57.603  49.913  1
585027  99.146  -57.608  49.882  1
585028  99.170  -57.613  49.849  1
585029  99.189  -57.618  49.817  1
585030  99.200  -57.625  49.783  1
585031  99.211  -57.632  49.747  1
585032  99.223  -57.639  49.711  1
585033  99.235  -57.645  49.675  1
585034  99.264  -57.652  49.640  1
585035  99.292  -57.659  49.603  1
585036  99.321  -57.667  49.569  1
585037  99.350  -57.673  49.536  1
585038  99.378  -57.681  49.503  1
585039  99.407  -57.688  49.469  1
585040  99.435  -57.695  49.434  1
585041  99.464  -57.702  49.397  1
585042  99.512  -57.709  49.360  1
585043  99.564  -57.716  49.320  1
585044  99.605  -57.724  49.281  1
585045  99.639  -57.733  49.244  1
585046  99.674  -57.741  49.208  1
585047  99.708  -57.750  49.174  1
585048  99.743  -57.758  49.142  1
585049  99.777  -57.767  49.113  1
585050  99.812  -57.776  49.084  1
585051  99.846  -57.785  49.056  1
585052  99.881  -57.793  49.029  1
585053  99.915  -57.802  49.003  1
585054  99.950  -57.811  48.981  1
585055  99.984  -57.820  48.960  1
585056  100.019  -57.829  48.938  1
585057  100.053  -57.837  48.916  1
585400  88.257  -54.013  57.567  4
585401  88.292  -54.028  57.568  4
585402  88.328  -54.043  57.570  4
585403  88.363  -54.058  57.572  4
585404  88.399  -54.074  57.574  4
585405  88.434  -54.089  57.575  4
585406  88.469  -54.104  57.574  4
585407  88.504  -54.120  57.574  4
585408  88.540  -54.135  57.573  4
585409  88.575  -54.151  57.573  4
585410  88.611  -54.166  57.571  4
585411  88.646  -54.181  57.569  4
585412  88.681  -54.196  57.566  4
585413  88.717  -54.212  57.565  4
585414  88.768  -54.204  57.565  4
585415  88.820  -54.210  57.564  4
585416  88.857  -54.241  57.563  4
585417  88.895  -54.261  57.559  4
585418  88.932  -54.278  57.544  4
585419  88.971  -54.295  57.520  4
585420  89.009  -54.311  57.485  4
585421  89.047  -54.328  57.439  4
585422  89.085  -54.345  57.390  4
585423  89.123  -54.362  57.344  4
585424  89.162  -54.379  57.295  4
585425  89.199  -54.395  57.246  4
585426  89.238  -54.412  57.198  4
585427  89.276  -54.429  57.148  4
585428  89.314  -54.446  57.100  4
585429  89.352  -54.463  57.051  4
585430  89.390  -54.480  57.002  4
585431  89.428  -54.496  56.954  4
585432  89.466  -54.513  56.908  4
585433  89.505  -54.530  56.864  4
585447  90.044  -54.847  56.157  1
585448  90.083  -54.870  56.126  1
585449  90.121  -54.893  56.097  1
585450  90.160  -54.916  56.069  1
585451  90.198  -54.940  56.044  1
585452  90.237  -54.963  56.019  1
585453  90.264  -54.980  55.997  1
585454  90.288  -54.994  55.975  1
585455  90.311  -55.008  55.955  1
585456  90.334  -55.022  55.936  1
585457  90.358  -55.036  55.919  1
585458  90.381  -55.050  55.903  1
585459  90.404  -55.065  55.888  1
585460  90.427  -55.079  55.876  1
585461  90.450  -55.093  55.865  1
585462  90.474  -55.107  55.855  1
585463  90.497  -55.121  55.848  1
585464  90.520  -55.135  55.841  1
585465  90.545  -55.149  55.839  1
585466  90.571  -55.163  55.841  1
585467  90.597  -55.176  55.844  1
585468  90.622  -55.188  55.848  1
585469  90.649  -55.199  55.852  1
585470  90.675  -55.209  55.858  1
585471  90.703  -55.220  55.864  1
585472  90.738  -55.236  55.872  1
585473  90.773  -55.252  55.880  1
585474  90.809  -55.268  55.893  1
585475  90.844  -55.283  55.908  1
585476  90.880  -55.299  55.923  1
585477  90.915  -55.315  55.934  1
585478  90.950  -55.331  55.942  1
585479  90.994  -55.342  55.946  1
585480  91.038  -55.354  55.944  1
585481  91.084  -55.365  55.936  1
585482  91.129  -55.376  55.923  1
585483  91.173  -55.388  55.910  1
585484  91.219  -55.399  55.903  1
585485  91.263  -55.411  55.896  1
585486  91.308  -55.421  55.883  1
585487  91.354  -55.433  55.860  1
585488  91.398  -55.444  55.825  1
585489  91.443  -55.455  55.790  1
585490  91.484  -55.467  55.762  1
585491  91.519  -55.480  55.738  1
585492  91.554  -55.492  55.714  1
585493  91.589  -55.505  55.690  1
585494  91.624  -55.518  55.659  1
585495  91.659  -55.531  55.623  1
585496  91.695  -55.544  55.589  1
585497  91.729  -55.556  55.556  1
585498  91.765  -55.569  55.522  1
585499  91.799  -55.582  55.489  1
585500  91.831  -55.594  55.457  1
585501  91.862  -55.605  55.425  1
585502  91.892  -55.618  55.396  1
585503  91.922  -55.629  55.370  1
585504  91.952  -55.641  55.345  1
585505  91.983  -55.652  55.321  1
585506  92.013  -55.665  55.299  1
585507  92.043  -55.677  55.279  1
585508  92.076  -55.689  55.261  1
585509  92.108  -55.702  55.246  1
585510  92.140  -55.715  55.230  1
585511  92.173  -55.727  55.215  1
585512  92.205  -55.746  55.198  1
585513  92.235  -55.771  55.185  1
585514  92.266  -55.797  55.173  1
585515  92.296  -55.823  55.163  1
585516  92.326  -55.849  55.156  1
585517  92.357  -55.875  55.151  1
585518  92.387  -55.901  55.148  1
585519  92.418  -55.927  55.148  1
585520  92.449  -55.951  55.150  1
585521  92.482  -55.975  55.154  1
585522  92.514  -55.998  55.160  1
585523  92.548  -56.013  55.169  1
585524  92.582  -56.028  55.182  1
585525  92.617  -56.042  55.198  1
585526  92.653  -56.057  55.212  1
585527  92.689  -56.073  55.224  1
585528  92.725  -56.088  55.233  1
585529  92.762  -56.104  55.237  1
585530  92.798  -56.119  55.239  1
585531  92.834  -56.135  55.243  1
585532  92.870  -56.150  55.251  1
585533  92.907  -56.166  55.262  1
585534  92.943  -56.179  55.273  1
585535  92.979  -56.184  55.285  1
585536  93.014  -56.188  55.300  1
585537  93.050  -56.193  55.315  1
585538  93.086  -56.197  55.327  1
585539  93.122  -56.201  55.334  1
585540  93.158  -56.206  55.338  1
585541  93.194  -56.210  55.340  1
585542  93.231  -56.218  55.342  1
585543  93.275  -56.232  55.342  1
585544  93.318  -56.245  55.341  1
585545  93.361  -56.259  55.338  1
585546  93.403  -56.272  55.334  1
585547  93.433  -56.280  55.332  1
585548  93.466  -56.291  55.322  1
585549  93.498  -56.304  55.310  1
585550  93.531  -56.316  55.296  1
585551  93.564  -56.327  55.278  1
585552  93.596  -56.339  55.249  1
585553  93.629  -56.351  55.227  1
585554  93.661  -56.365  55.195  1
585555  93.694  -56.382  55.163  1
585556  93.726  -56.398  55.130  1
585557  93.758  -56.416  55.094  1
585558  93.790  -56.432  55.055  1
585559  93.822  -56.449  55.018  1
585560  93.854  -56.467  54.979  1
585561  93.886  -56.483  54.940  1
585562  93.918  -56.500  54.900  1
585563  93.950  -56.517  54.859  1
585564  93.982  -56.534  54.822  1
585565  94.014  -56.551  54.784  1
585566  94.046  -56.567  54.747  1
585567  94.076  -56.583  54.710  1
585568  94.107  -56.599  54.672  1
585569  94.137  -56.615  54.630  1
585570  94.167  -56.630  54.585  1
585571  94.198  -56.646  54.537  1
585572  94.228  -56.662  54.487  1
585573  94.258  -56.677  54.441  1
585574  94.287  -56.689  54.402  1
585575  94.315  -56.698  54.367  1
585576  94.343  -56.707  54.333  1
585577  94.371  -56.716  54.298  1
585578  94.403  -56.725  54.261  1
585579  94.439  -56.734  54.224  1
585580  94.475  -56.744  54.184  1
585581  94.510  -56.754  54.141  1
585582  94.546  -56.764  54.096  1
585583  94.575  -56.778  54.054  1
585584  94.605  -56.793  54.012  1
585585  94.634  -56.808  53.971  1
585586  94.664  -56.823  53.928  1
585587  94.693  -56.837  53.886  1
585588  94.722  -56.852  53.847  1
585589  94.752  -56.867  53.806  1
585590  94.781  -56.882  53.764  1
585591  94.810  -56.896  53.718  1
585592  94.840  -56.912  53.667  1
585593  94.869  -56.927  53.610  1
585594  94.898  -56.941  53.564  1
585595  94.928  -56.956  53.526  1
585596  94.957  -56.971  53.496  1
585597  94.986  -56.986  53.470  1
585598  95.016  -57.000  53.443  1
585599  95.045  -57.015  53.414  1
585600  95.073  -57.028  53.384  1
585601  95.102  -57.041  53.352  1
585602  95.134  -57.050  53.318  1
585603  95.173  -57.053  53.283  1
585604  95.212  -57.056  53.248  1
585605  95.251  -57.059  53.215  1
585606  95.296  -57.060  53.186  1
585607  95.332  -57.064  53.157  1
585608  95.361  -57.074  53.123  1
585609  95.400  -57.082  53.087  1
585610  95.439  -57.091  53.049  1
585611  95.478  -57.099  53.009  1
585612  95.517  -57.107  52.968  1
585613  95.555  -57.116  52.927  1
585614  95.594  -57.124  52.890  1
585615  95.633  -57.133  52.857  1
585616  95.672  -57.141  52.825  1
585617  95.710  -57.150  52.794  1
585618  95.749  -57.158  52.764  1
585619  95.788  -57.166  52.736  1
585620  95.825  -57.173  52.711  1
585621  95.851  -57.180  52.683  1
585622  95.873  -57.187  52.651  1
585623  95.895  -57.194  52.617  1
585624  95.916  -57.200  52.579  1
585625  95.938  -57.207  52.538  1
585626  95.960  -57.214  52.495  1
585627  95.981  -57.221  52.453  1
585628  96.003  -57.228  52.414  1
585629  96.024  -57.235  52.379  1
585630  96.046  -57.241  52.348  1
585631  96.067  -57.248  52.316  1
585632  96.089  -57.255  52.285  1
585633  96.111  -57.262  52.257  1
585634  96.132  -57.269  52.232  1
585635  96.155  -57.276  52.206  1
585636  96.182  -57.282  52.180  1
585637  96.210  -57.288  52.155  1
585638  96.239  -57.294  52.132  1
585639  96.267  -57.300  52.109  1
585640  96.296  -57.307  52.084  1
585641  96.324  -57.313  52.060  1
585642  96.353  -57.319  52.041  1
585643  96.381  -57.326  52.023  1
585644  96.409  -57.332  52.002  1
585645  96.439  -57.337  51.977  1
585646  96.468  -57.343  51.951  1
585647  96.498  -57.348  51.927  1
585648  96.528  -57.354  51.906  1
585649  96.557  -57.360  51.891  1
585650  96.587  -57.365  51.878  1
585651  96.619  -57.369  51.867  1
585652  96.652  -57.375  51.855  1
585653  96.684  -57.379  51.840  1
585654  96.717  -57.384  51.823  1
585655  96.749  -57.388  51.810  1
585656  96.781  -57.393  51.804  1
585657  96.813  -57.398  51.804  1
585658  96.846  -57.402  51.803  1
585659  96.878  -57.407  51.801  1
585660  96.910  -57.412  51.795  1
585661  96.945  -57.416  51.789  1
585662  96.981  -57.419  51.781  1
585663  97.018  -57.416  51.772  1
585664  97.055  -57.414  51.763  1
585665  97.092  -57.413  51.760  1
585666  97.130  -57.410  51.763  1
585667  97.166  -57.408  51.764  1
585668  97.204  -57.406  51.762  1
585669  97.240  -57.404  51.758  1
585670  97.267  -57.401  51.753  1
585671  97.294  -57.397  51.750  1
585672  97.322  -57.394  51.746  1
585673  97.349  -57.391  51.739  1
585674  97.376  -57.388  51.728  1
585675  97.404  -57.385  51.711  1
585676  97.431  -57.381  51.688  1
585677  97.458  -57.378  51.665  1
585678  97.486  -57.375  51.640  1
585679  97.520  -57.388  51.613  1
585680  97.555  -57.403  51.580  1
585681  97.586  -57.413  51.540  1
585682  97.617  -57.420  51.494  1
585683  97.648  -57.427  51.445  1
585684  97.678  -57.435  51.396  1
585685  97.709  -57.442  51.346  1
585686  97.739  -57.449  51.297  1
585687  97.770  -57.457  51.249  1
585688  97.800  -57.464  51.202  1
585689  97.831  -57.471  51.161  1
585690  97.861  -57.476  51.126  1
585691  97.891  -57.477  51.092  1
585692  97.921  -57.479  51.059  1
585693  97.950  -57.480  51.024  1
585694  97.983  -57.482  50.989  1
585695  98.018  -57.487  50.952  1
585696  98.054  -57.491  50.917  1
585697  98.090  -57.495  50.880  1
585698  98.126  -57.499  50.842  1
585699  98.161  -57.504  50.805  1
585700  98.197  -57.507  50.770  1
585701  98.232  -57.512  50.735  1
585702  98.268  -57.516  50.698  1
585703  98.304  -57.520  50.661  1
585704  98.342  -57.524  50.626  1
585705  98.387  -57.527  50.593  1
585706  98.432  -57.529  50.561  1
585707  98.477  -57.532  50.526  1
585708  98.522  -57.536  50.495  1
585709  98.567  -57.538  50.466  1
585710  98.599  -57.533  50.437  1
585711  98.629  -57.528  50.407  1
585712  98.659  -57.522  50.378  1
585713  98.690  -57.516  50.345  1
585714  98.719  -57.510  50.313  1
585715  98.749  -57.504  50.282  1
585716  98.786  -57.505  50.251  1
585717  98.823  -57.508  50.223  1
585718  98.861  -57.510  50.192  1
585719  98.896  -57.516  50.163  1
585720  98.926  -57.523  50.132  1
585721  98.955  -57.532  50.102  1
585722  98.986  -57.539  50.073  1
585723  99.015  -57.548  50.043  1
585724  99.046  -57.555  50.013  1
585725  99.076  -57.564  49.982  1
585726  99.106  -57.571  49.950  1
585727  99.133  -57.578  49.918  1
585728  99.157  -57.583  49.886  1
585729  99.178  -57.589  49.853  1
585730  99.189  -57.595  49.822  1
585731  99.201  -57.601  49.788  1
585732  99.212  -57.608  49.752  1
585733  99.224  -57.615  49.715  1
585734  99.237  -57.622  49.678  1
585735  99.266  -57.629  49.642  1
585736  99.294  -57.636  49.605  1
585737  99.323  -57.643  49.570  1
585738  99.351  -57.651  49.536  1
585739  99.380  -57.658  49.501  1
585740  99.409  -57.665  49.467  1
585741  99.438  -57.670  49.431  1
585742  99.467  -57.677  49.394  1
585743  99.498  -57.682  49.356  1
585744  99.550  -57.689  49.317  1
585745  99.597  -57.695  49.277  1
585746  99.632  -57.705  49.240  1
585747  99.666  -57.713  49.204  1
585748  99.701  -57.722  49.170  1
585749  99.735  -57.731  49.136  1
585750  99.770  -57.739  49.106  1
585751  99.804  -57.749  49.078  1
585752  99.839  -57.757  49.050  1
585753  99.873  -57.766  49.025  1
585754  99.908  -57.774  48.999  1
585755  99.942  -57.783  48.978  1
585756  99.977  -57.792  48.956  1
585757  100.011  -57.801  48.935  1
585758  100.046  -57.810  48.914  1
586102  88.317  -53.993  57.564  4
586103  88.352  -54.008  57.566  4
586104  88.388  -54.023  57.568  4
586105  88.423  -54.038  57.570  4
586106  88.459  -54.054  57.571  4
586107  88.494  -54.070  57.571  4
586108  88.529  -54.085  57.570  4
586109  88.564  -54.100  57.569  4
586110  88.600  -54.115  57.568  4
586111  88.635  -54.131  57.567  4
586112  88.671  -54.146  57.564  4
586113  88.706  -54.161  57.561  4
586114  88.742  -54.176  57.559  4
586115  88.784  -54.189  57.557  4
586116  88.836  -54.194  57.554  4
586117  88.879  -54.215  57.551  4
586118  88.916  -54.238  57.545  4
586119  88.955  -54.254  57.529  4
586120  88.993  -54.271  57.506  4
586121  89.031  -54.288  57.476  4
586122  89.069  -54.305  57.436  4
586123  89.107  -54.322  57.390  4
586124  89.145  -54.339  57.344  4
586125  89.183  -54.355  57.297  4
586126  89.222  -54.372  57.250  4
586127  89.259  -54.389  57.201  4
586128  89.298  -54.406  57.153  4
586129  89.336  -54.423  57.105  4
586130  89.374  -54.439  57.056  4
586131  89.412  -54.456  57.007  4
586132  89.450  -54.473  56.960  4
586133  89.488  -54.490  56.914  4
586134  89.526  -54.507  56.869  4
586146  89.988  -54.768  56.227  1
586147  90.027  -54.791  56.195  1
586148  90.065  -54.815  56.165  1
586149  90.104  -54.837  56.135  1
586150  90.143  -54.861  56.106  1
586151  90.181  -54.884  56.079  1
586152  90.220  -54.908  56.054  1
586153  90.258  -54.931  56.030  1
586154  90.284  -54.947  56.008  1
586155  90.307  -54.961  55.986  1
586156  90.330  -54.975  55.967  1
586157  90.353  -54.989  55.948  1
586158  90.377  -55.003  55.931  1
586159  90.400  -55.017  55.914  1
586160  90.423  -55.032  55.901  1
586161  90.446  -55.045  55.889  1
586162  90.469  -55.060  55.876  1
586163  90.493  -55.074  55.864  1
586164  90.516  -55.088  55.855  1
586165  90.541  -55.101  55.848  1
586166  90.567  -55.116  55.843  1
586167  90.593  -55.129  55.841  1
586168  90.618  -55.143  55.841  1
586169  90.644  -55.155  55.842  1
586170  90.670  -55.166  55.845  1
586171  90.696  -55.176  55.849  1
586172  90.730  -55.191  55.855  1
586173  90.765  -55.206  55.863  1
586174  90.801  -55.222  55.875  1
586175  90.836  -55.238  55.888  1
586176  90.871  -55.254  55.901  1
586177  90.907  -55.269  55.915  1
586178  90.942  -55.285  55.925  1
586179  90.977  -55.301  55.928  1
586180  91.013  -55.317  55.929  1
586181  91.051  -55.330  55.925  1
586182  91.096  -55.342  55.916  1
586183  91.142  -55.353  55.903  1
586184  91.186  -55.364  55.887  1
586185  91.231  -55.376  55.876  1
586186  91.277  -55.387  55.867  1
586187  91.321  -55.398  55.852  1
586188  91.366  -55.409  55.828  1
586189  91.412  -55.420  55.794  1
586190  91.456  -55.432  55.762  1
586191  91.493  -55.445  55.736  1
586192  91.528  -55.457  55.715  1
586193  91.563  -55.470  55.694  1
586194  91.598  -55.483  55.674  1
586195  91.633  -55.495  55.645  1
586196  91.668  -55.508  55.608  1
586197  91.703  -55.520  55.571  1
586198  91.738  -55.533  55.537  1
586199  91.773  -55.546  55.503  1
586200  91.808  -55.559  55.471  1
586201  91.843  -55.572  55.441  1
586202  91.878  -55.584  55.411  1
586203  91.910  -55.596  55.384  1
586204  91.940  -55.608  55.360  1
586205  91.970  -55.620  55.338  1
586206  92.001  -55.632  55.317  1
586207  92.031  -55.643  55.297  1
586208  92.061  -55.655  55.280  1
586209  92.094  -55.668  55.268  1
586210  92.126  -55.680  55.258  1
586211  92.159  -55.693  55.247  1
586212  92.191  -55.706  55.232  1
586213  92.223  -55.720  55.214  1
586214  92.254  -55.746  55.197  1
586215  92.284  -55.771  55.183  1
586216  92.315  -55.797  55.172  1
586217  92.346  -55.823  55.162  1
586218  92.376  -55.849  55.155  1
586219  92.407  -55.875  55.151  1
586220  92.437  -55.901  55.150  1
586221  92.467  -55.927  55.151  1
586222  92.498  -55.952  55.152  1
586223  92.531  -55.974  55.155  1
586224  92.565  -55.988  55.158  1
586225  92.601  -56.003  55.170  1
586226  92.638  -56.019  55.188  1
586227  92.674  -56.034  55.207  1
586228  92.710  -56.050  55.221  1
586229  92.746  -56.066  55.230  1
586230  92.783  -56.081  55.236  1
586231  92.819  -56.097  55.238  1
586232  92.855  -56.112  55.240  1
586233  92.891  -56.128  55.244  1
586234  92.927  -56.143  55.249  1
586235  92.964  -56.157  55.257  1
586236  92.999  -56.161  55.268  1
586237  93.036  -56.166  55.283  1
586238  93.071  -56.170  55.297  1
586239  93.107  -56.175  55.309  1
586240  93.143  -56.179  55.318  1
586241  93.179  -56.184  55.322  1
586242  93.214  -56.188  55.323  1
586243  93.251  -56.193  55.324  1
586244  93.286  -56.197  55.324  1
586245  93.326  -56.207  55.322  1
586246  93.369  -56.220  55.319  1
586247  93.412  -56.234  55.314  1
586248  93.444  -56.244  55.311  1
586249  93.477  -56.255  55.304  1
586250  93.510  -56.267  55.294  1
586251  93.543  -56.279  55.282  1
586252  93.575  -56.291  55.265  1
586253  93.607  -56.307  55.239  1
586254  93.639  -56.325  55.215  1
586255  93.672  -56.342  55.188  1
586256  93.703  -56.358  55.157  1
586257  93.735  -56.376  55.125  1
586258  93.768  -56.392  55.091  1
586259  93.800  -56.409  55.054  1
586260  93.832  -56.426  55.018  1
586261  93.864  -56.443  54.982  1
586262  93.896  -56.460  54.945  1
586263  93.928  -56.477  54.909  1
586264  93.960  -56.494  54.871  1
586265  93.992  -56.511  54.833  1
586266  94.024  -56.527  54.795  1
586267  94.054  -56.543  54.758  1
586268  94.084  -56.559  54.722  1
586269  94.115  -56.574  54.685  1
586270  94.145  -56.590  54.642  1
586271  94.175  -56.606  54.597  1
586272  94.205  -56.621  54.549  1
586273  94.236  -56.637  54.497  1
586274  94.266  -56.653  54.446  1
586275  94.294  -56.663  54.400  1
586276  94.323  -56.672  54.361  1
586277  94.351  -56.681  54.326  1
586278  94.379  -56.690  54.291  1
586279  94.408  -56.699  54.254  1
586280  94.444  -56.708  54.216  1
586281  94.479  -56.718  54.176  1
586282  94.515  -56.728  54.132  1
586283  94.551  -56.737  54.087  1
586284  94.586  -56.747  54.044  1
586285  94.615  -56.762  54.001  1
586286  94.645  -56.777  53.958  1
586287  94.674  -56.792  53.916  1
586288  94.703  -56.807  53.875  1
586289  94.733  -56.821  53.835  1
586290  94.762  -56.837  53.794  1
586291  94.791  -56.851  53.753  1
586292  94.821  -56.866  53.710  1
586293  94.850  -56.881  53.662  1
586294  94.880  -56.896  53.609  1
586295  94.909  -56.910  53.555  1
586296  94.938  -56.925  53.511  1
586297  94.968  -56.940  53.475  1
586298  94.997  -56.955  53.444  1
586299  95.027  -56.969  53.416  1
586300  95.054  -56.982  53.386  1
586301  95.083  -56.995  53.355  1
586302  95.111  -57.008  53.322  1
586303  95.140  -57.019  53.287  1
586304  95.180  -57.022  53.251  1
586305  95.218  -57.026  53.215  1
586306  95.258  -57.028  53.178  1
586307  95.308  -57.025  53.145  1
586308  95.341  -57.032  53.113  1
586309  95.369  -57.041  53.079  1
586310  95.404  -57.050  53.044  1
586311  95.443  -57.059  53.007  1
586312  95.481  -57.067  52.967  1
586313  95.520  -57.075  52.929  1
586314  95.559  -57.084  52.892  1
586315  95.598  -57.093  52.860  1
586316  95.636  -57.101  52.830  1
586317  95.675  -57.109  52.800  1
586318  95.714  -57.118  52.770  1
586319  95.753  -57.126  52.738  1
586320  95.792  -57.134  52.708  1
586321  95.828  -57.141  52.680  1
586322  95.855  -57.148  52.651  1
586323  95.877  -57.155  52.618  1
586324  95.898  -57.162  52.583  1
586325  95.920  -57.169  52.545  1
586326  95.942  -57.175  52.506  1
586327  95.963  -57.182  52.465  1
586328  95.985  -57.189  52.423  1
586329  96.007  -57.196  52.384  1
586330  96.028  -57.203  52.351  1
586331  96.049  -57.210  52.320  1
586332  96.071  -57.216  52.289  1
586333  96.093  -57.223  52.259  1
586334  96.114  -57.230  52.232  1
586335  96.136  -57.237  52.208  1
586336  96.159  -57.247  52.186  1
586337  96.186  -57.254  52.160  1
586338  96.214  -57.259  52.136  1
586339  96.241  -57.264  52.115  1
586340  96.269  -57.269  52.094  1
586341  96.297  -57.275  52.072  1
586342  96.325  -57.280  52.048  1
586343  96.353  -57.285  52.030  1
586344  96.381  -57.291  52.012  1
586345  96.410  -57.297  51.991  1
586346  96.440  -57.303  51.966  1
586347  96.470  -57.309  51.939  1
586348  96.500  -57.314  51.910  1
586349  96.529  -57.319  51.883  1
586350  96.559  -57.326  51.861  1
586351  96.589  -57.331  51.844  1
586352  96.621  -57.335  51.829  1
586353  96.653  -57.340  51.816  1
586354  96.686  -57.344  51.804  1
586355  96.718  -57.350  51.786  1
586356  96.750  -57.354  51.773  1
586357  96.783  -57.359  51.768  1
586358  96.815  -57.363  51.768  1
586359  96.848  -57.368  51.769  1
586360  96.880  -57.373  51.769  1
586361  96.912  -57.377  51.767  1
586362  96.944  -57.383  51.762  1
586363  96.977  -57.382  51.752  1
586364  97.013  -57.379  51.737  1
586365  97.050  -57.376  51.721  1
586366  97.087  -57.374  51.714  1
586367  97.124  -57.372  51.714  1
586368  97.161  -57.369  51.713  1
586369  97.198  -57.367  51.710  1
586370  97.235  -57.365  51.705  1
586371  97.270  -57.363  51.700  1
586372  97.297  -57.360  51.698  1
586373  97.324  -57.357  51.697  1
586374  97.352  -57.353  51.692  1
586375  97.379  -57.350  51.681  1
586376  97.406  -57.347  51.665  1
586377  97.434  -57.344  51.644  1
586378  97.461  -57.341  51.618  1
586379  97.489  -57.337  51.592  1
586380  97.522  -57.350  51.567  1
586381  97.557  -57.364  51.538  1
586382  97.588  -57.373  51.502  1
586383  97.619  -57.380  51.458  1
586384  97.649  -57.388  51.411  1
586385  97.680  -57.395  51.364  1
586386  97.711  -57.402  51.315  1
586387  97.741  -57.410  51.267  1
586388  97.772  -57.416  51.221  1
586389  97.802  -57.424  51.175  1
586390  97.832  -57.431  51.135  1
586391  97.863  -57.438  51.100  1
586392  97.893  -57.442  51.067  1
586393  97.923  -57.443  51.034  1
586394  97.953  -57.445  51.001  1
586395  97.987  -57.448  50.968  1
586396  98.022  -57.452  50.933  1
586397  98.058  -57.457  50.900  1
586398  98.094  -57.460  50.866  1
586399  98.130  -57.465  50.832  1
586400  98.165  -57.469  50.797  1
586401  98.201  -57.473  50.763  1
586402  98.237  -57.477  50.728  1
586403  98.273  -57.482  50.691  1
586404  98.308  -57.485  50.655  1
586405  98.344  -57.489  50.620  1
586406  98.382  -57.494  50.587  1
586407  98.427  -57.496  50.555  1
586408  98.472  -57.499  50.521  1
586409  98.517  -57.502  50.489  1
586410  98.562  -57.504  50.459  1
586411  98.600  -57.504  50.429  1
586412  98.630  -57.498  50.399  1
586413  98.660  -57.492  50.369  1
586414  98.690  -57.486  50.337  1
586415  98.720  -57.480  50.306  1
586416  98.751  -57.476  50.276  1
586417  98.789  -57.478  50.248  1
586418  98.827  -57.481  50.221  1
586419  98.864  -57.483  50.192  1
586420  98.900  -57.488  50.163  1
586421  98.930  -57.495  50.134  1
586422  98.959  -57.504  50.104  1
586423  98.990  -57.511  50.075  1
586424  99.019  -57.520  50.045  1
586425  99.050  -57.527  50.015  1
586426  99.079  -57.536  49.984  1
586427  99.110  -57.543  49.954  1
586428  99.140  -57.551  49.923  1
586429  99.167  -57.559  49.891  1
586430  99.179  -57.565  49.857  1
586431  99.190  -57.572  49.824  1
586432  99.202  -57.579  49.790  1
586433  99.213  -57.586  49.755  1
586434  99.225  -57.592  49.718  1
586435  99.238  -57.598  49.681  1
586436  99.267  -57.606  49.643  1
586437  99.296  -57.613  49.604  1
586438  99.325  -57.620  49.568  1
586439  99.353  -57.627  49.533  1
586440  99.382  -57.633  49.498  1
586441  99.412  -57.639  49.462  1
586442  99.441  -57.645  49.426  1
586443  99.470  -57.651  49.389  1
586444  99.498  -57.656  49.351  1
586445  99.535  -57.662  49.312  1
586446  99.586  -57.668  49.272  1
586447  99.624  -57.677  49.234  1
586448  99.659  -57.686  49.198  1
586449  99.693  -57.694  49.164  1
586450  99.728  -57.703  49.131  1
586451  99.762  -57.712  49.101  1
586452  99.797  -57.720  49.072  1
586453  99.831  -57.730  49.045  1
586454  99.866  -57.738  49.020  1
586455  99.900  -57.747  48.995  1
586456  99.934  -57.755  48.974  1
586457  99.969  -57.764  48.952  1
586458  100.003  -57.773  48.931  1
586459  100.038  -57.782  48.912  1
586460  100.072  -57.790  48.892  1
586803  88.342  -53.958  57.561  4
586804  88.377  -53.973  57.563  4
586805  88.412  -53.988  57.564  4
586806  88.448  -54.004  57.566  4
586807  88.483  -54.019  57.568  4
586808  88.519  -54.035  57.567  4
586809  88.554  -54.050  57.566  4
586810  88.589  -54.065  57.565  4
586811  88.625  -54.080  57.563  4
586812  88.660  -54.096  57.561  4
586813  88.695  -54.111  57.559  4
586814  88.731  -54.126  57.555  4
586815  88.768  -54.145  57.551  4
586816  88.808  -54.166  57.547  4
586817  88.853  -54.179  57.543  4
586818  88.901  -54.190  57.536  4
586819  88.939  -54.214  57.527  4
586820  88.976  -54.231  57.513  4
586821  89.015  -54.248  57.492  4
586822  89.053  -54.265  57.462  4
586823  89.091  -54.282  57.426  4
586824  89.129  -54.298  57.385  4
586825  89.167  -54.315  57.343  4
586826  89.205  -54.332  57.298  4
586827  89.243  -54.348  57.251  4
586828  89.281  -54.366  57.203  4
586829  89.320  -54.383  57.155  4
586830  89.357  -54.399  57.108  4
586831  89.396  -54.416  57.060  4
586832  89.434  -54.433  57.011  4
586833  89.472  -54.450  56.964  4
586834  89.510  -54.467  56.918  4
586846  89.971  -54.712  56.266  1
586847  90.010  -54.736  56.233  1
586848  90.048  -54.759  56.203  1
586849  90.087  -54.783  56.173  1
586850  90.125  -54.806  56.144  1
586851  90.164  -54.829  56.115  1
586852  90.202  -54.853  56.088  1
586853  90.241  -54.876  56.064  1
586854  90.279  -54.900  56.041  1
586855  90.303  -54.913  56.019  1
586856  90.326  -54.928  55.999  1
586857  90.349  -54.941  55.980  1
586858  90.372  -54.956  55.962  1
586859  90.395  -54.970  55.945  1
586860  90.418  -54.984  55.929  1
586861  90.442  -54.998  55.917  1
586862  90.465  -55.013  55.904  1
586863  90.488  -55.026  55.889  1
586864  90.512  -55.041  55.874  1
586865  90.537  -55.054  55.862  1
586866  90.563  -55.068  55.854  1
586867  90.589  -55.082  55.847  1
586868  90.614  -55.095  55.843  1
586869  90.640  -55.109  55.840  1
586870  90.666  -55.122  55.839  1
586871  90.692  -55.132  55.840  1
586872  90.722  -55.144  55.843  1
586873  90.757  -55.160  55.848  1
586874  90.793  -55.176  55.859  1
586875  90.828  -55.192  55.871  1
586876  90.863  -55.207  55.883  1
586877  90.898  -55.223  55.895  1
586878  90.934  -55.239  55.906  1
586879  90.969  -55.255  55.909  1
586880  91.005  -55.270  55.909  1
586881  91.040  -55.286  55.908  1
586882  91.075  -55.302  55.903  1
586883  91.110  -55.318  55.894  1
586884  91.154  -55.329  55.880  1
586885  91.200  -55.341  55.862  1
586886  91.244  -55.352  55.849  1
586887  91.289  -55.364  55.837  1
586888  91.334  -55.375  55.820  1
586889  91.379  -55.386  55.794  1
586890  91.424  -55.397  55.763  1
586891  91.467  -55.409  55.734  1
586892  91.502  -55.422  55.711  1
586893  91.537  -55.434  55.694  1
586894  91.572  -55.447  55.677  1
586895  91.607  -55.460  55.659  1
586896  91.642  -55.473  55.632  1
586897  91.677  -55.485  55.595  1
586898  91.712  -55.498  55.557  1
586899  91.747  -55.511  55.520  1
586900  91.782  -55.524  55.487  1
586901  91.817  -55.536  55.456  1
586902  91.852  -55.549  55.427  1
586903  91.887  -55.561  55.398  1
586904  91.922  -55.574  55.373  1
586905  91.957  -55.587  55.351  1
586906  91.988  -55.599  55.331  1
586907  92.019  -55.611  55.313  1
586908  92.049  -55.623  55.298  1
586909  92.080  -55.634  55.285  1
586910  92.112  -55.647  55.279  1
586911  92.144  -55.660  55.277  1
586912  92.177  -55.672  55.271  1
586913  92.209  -55.685  55.256  1
586914  92.242  -55.698  55.235  1
586915  92.273  -55.720  55.214  1
586916  92.303  -55.746  55.197  1
586917  92.334  -55.771  55.184  1
586918  92.364  -55.797  55.173  1
586919  92.395  -55.823  55.165  1
586920  92.425  -55.849  55.160  1
586921  92.456  -55.875  55.158  1
586922  92.486  -55.900  55.158  1
586923  92.517  -55.927  55.159  1
586924  92.550  -55.947  55.161  1
586925  92.586  -55.965  55.161  1
586926  92.622  -55.981  55.165  1
586927  92.658  -55.997  55.176  1
586928  92.695  -56.012  55.193  1
586929  92.731  -56.028  55.209  1
586930  92.767  -56.043  55.220  1
586931  92.803  -56.059  55.226  1
586932  92.840  -56.074  55.230  1
586933  92.876  -56.089  55.234  1
586934  92.912  -56.105  55.240  1
586935  92.948  -56.120  55.247  1
586936  92.985  -56.135  55.253  1
586937  93.020  -56.139  55.258  1
586938  93.056  -56.144  55.269  1
586939  93.092  -56.148  55.281  1
586940  93.128  -56.153  55.292  1
586941  93.164  -56.157  55.302  1
586942  93.200  -56.162  55.307  1
586943  93.235  -56.166  55.308  1
586944  93.271  -56.170  55.308  1
586945  93.307  -56.175  55.306  1
586946  93.343  -56.179  55.303  1
586947  93.379  -56.184  55.300  1
586948  93.420  -56.195  55.294  1
586949  93.456  -56.207  55.288  1
586950  93.489  -56.219  55.282  1
586951  93.521  -56.234  55.273  1
586952  93.553  -56.251  55.260  1
586953  93.585  -56.267  55.242  1
586954  93.617  -56.285  55.219  1
586955  93.649  -56.301  55.194  1
586956  93.681  -56.318  55.168  1
586957  93.713  -56.335  55.139  1
586958  93.746  -56.352  55.108  1
586959  93.777  -56.369  55.074  1
586960  93.809  -56.386  55.039  1
586961  93.842  -56.403  55.005  1
586962  93.874  -56.420  54.972  1
586963  93.906  -56.437  54.940  1
586964  93.938  -56.454  54.907  1
586965  93.970  -56.470  54.873  1
586966  94.001  -56.487  54.839  1
586967  94.032  -56.503  54.803  1
586968  94.062  -56.518  54.765  1
586969  94.092  -56.534  54.729  1
586970  94.123  -56.550  54.691  1
586971  94.153  -56.566  54.648  1
586972  94.183  -56.581  54.604  1
586973  94.213  -56.597  54.557  1
586974  94.244  -56.613  54.506  1
586975  94.274  -56.628  54.453  1
586976  94.302  -56.637  54.401  1
586977  94.330  -56.646  54.353  1
586978  94.358  -56.655  54.317  1
586979  94.387  -56.664  54.281  1
586980  94.415  -56.674  54.244  1
586981  94.449  -56.683  54.205  1
586982  94.484  -56.693  54.165  1
586983  94.520  -56.702  54.121  1
586984  94.556  -56.711  54.077  1
586985  94.592  -56.721  54.033  1
586986  94.626  -56.731  53.988  1
586987  94.655  -56.746  53.945  1
586988  94.685  -56.761  53.902  1
586989  94.714  -56.776  53.860  1
586990  94.744  -56.791  53.820  1
586991  94.773  -56.805  53.781  1
586992  94.802  -56.821  53.742  1
586993  94.832  -56.835  53.702  1
586994  94.861  -56.850  53.659  1
586995  94.890  -56.865  53.612  1
586996  94.920  -56.880  53.555  1
586997  94.949  -56.894  53.502  1
586998  94.978  -56.909  53.457  1
586999  95.007  -56.924  53.421  1
587000  95.036  -56.936  53.389  1
587001  95.064  -56.949  53.359  1
587002  95.092  -56.962  53.326  1
587003  95.120  -56.975  53.292  1
587004  95.148  -56.987  53.257  1
587005  95.186  -56.992  53.220  1
587006  95.225  -56.995  53.182  1
587007  95.271  -56.994  53.144  1
587008  95.321  -56.991  53.108  1
587009  95.350  -57.000  53.073  1
587010  95.377  -57.009  53.040  1
587011  95.407  -57.018  53.007  1
587012  95.446  -57.027  52.970  1
587013  95.485  -57.035  52.932  1
587014  95.524  -57.044  52.895  1
587015  95.562  -57.053  52.862  1
587016  95.601  -57.061  52.831  1
587017  95.640  -57.069  52.802  1
587018  95.679  -57.078  52.775  1
587019  95.718  -57.086  52.746  1
587020  95.757  -57.094  52.714  1
587021  95.795  -57.103  52.680  1
587022  95.831  -57.109  52.648  1
587023  95.859  -57.116  52.617  1
587024  95.880  -57.123  52.584  1
587025  95.902  -57.130  52.549  1
587026  95.923  -57.137  52.511  1
587027  95.945  -57.144  52.474  1
587028  95.967  -57.150  52.434  1
587029  95.988  -57.157  52.394  1
587030  96.010  -57.164  52.355  1
587031  96.032  -57.171  52.322  1
587032  96.053  -57.178  52.292  1
587033  96.075  -57.185  52.263  1
587034  96.096  -57.191  52.234  1
587035  96.118  -57.197  52.207  1
587036  96.141  -57.207  52.182  1
587037  96.164  -57.217  52.162  1
587038  96.189  -57.225  52.137  1
587039  96.217  -57.231  52.114  1
587040  96.245  -57.236  52.093  1
587041  96.272  -57.241  52.074  1
587042  96.300  -57.247  52.053  1
587043  96.328  -57.252  52.034  1
587044  96.356  -57.257  52.016  1
587045  96.384  -57.261  51.997  1
587046  96.412  -57.264  51.975  1
587047  96.442  -57.269  51.948  1
587048  96.471  -57.274  51.918  1
587049  96.501  -57.280  51.891  1
587050  96.531  -57.285  51.866  1
587051  96.560  -57.291  51.844  1
587052  96.590  -57.297  51.822  1
587053  96.622  -57.301  51.800  1
587054  96.655  -57.306  51.782  1
587055  96.687  -57.310  51.765  1
587056  96.720  -57.315  51.751  1
587057  96.752  -57.320  51.740  1
587058  96.784  -57.325  51.733  1
587059  96.817  -57.329  51.731  1
587060  96.849  -57.334  51.730  1
587061  96.881  -57.340  51.734  1
587062  96.913  -57.347  51.731  1
587063  96.946  -57.354  51.723  1
587064  96.978  -57.353  51.709  1
587065  97.011  -57.344  51.693  1
587066  97.045  -57.338  51.679  1
587067  97.082  -57.335  51.669  1
587068  97.119  -57.333  51.664  1
587069  97.156  -57.332  51.662  1
587070  97.193  -57.329  51.658  1
587071  97.230  -57.327  51.651  1
587072  97.267  -57.325  51.647  1
587073  97.300  -57.322  51.645  1
587074  97.327  -57.319  51.645  1
587075  97.355  -57.316  51.641  1
587076  97.382  -57.313  51.631  1
587077  97.409  -57.309  51.615  1
587078  97.437  -57.306  51.596  1
587079  97.464  -57.303  51.571  1
587080  97.491  -57.300  51.544  1
587081  97.525  -57.311  51.520  1
587082  97.559  -57.326  51.494  1
587083  97.590  -57.333  51.461  1
587084  97.620  -57.341  51.421  1
587085  97.651  -57.348  51.378  1
587086  97.681  -57.355  51.333  1
587087  97.712  -57.363  51.286  1
587088  97.743  -57.369  51.238  1
587089  97.773  -57.377  51.192  1
587090  97.804  -57.385  51.147  1
587091  97.835  -57.391  51.108  1
587092  97.865  -57.399  51.074  1
587093  97.895  -57.406  51.040  1
587094  97.925  -57.407  51.007  1
587095  97.955  -57.409  50.976  1
587096  97.991  -57.413  50.945  1
587097  98.027  -57.417  50.914  1
587098  98.063  -57.422  50.882  1
587099  98.098  -57.426  50.851  1
587100  98.134  -57.430  50.820  1
587101  98.169  -57.434  50.787  1
587102  98.205  -57.438  50.753  1
587103  98.241  -57.442  50.718  1
587104  98.277  -57.447  50.682  1
587105  98.312  -57.451  50.646  1
587106  98.348  -57.455  50.612  1
587107  98.384  -57.459  50.579  1
587108  98.421  -57.463  50.547  1
587109  98.466  -57.466  50.514  1
587110  98.511  -57.469  50.481  1
587111  98.557  -57.471  50.450  1
587112  98.600  -57.473  50.420  1
587113  98.631  -57.468  50.390  1
587114  98.660  -57.462  50.359  1
587115  98.691  -57.456  50.328  1
587116  98.721  -57.451  50.298  1
587117  98.754  -57.448  50.271  1
587118  98.792  -57.451  50.244  1
587119  98.830  -57.454  50.219  1
587120  98.867  -57.456  50.192  1
587121  98.904  -57.460  50.163  1
587122  98.933  -57.467  50.134  1
587123  98.963  -57.476  50.105  1
587124  98.994  -57.483  50.076  1
587125  99.023  -57.492  50.046  1
587126  99.053  -57.499  50.018  1
587127  99.080  -57.507  49.986  1
587128  99.106  -57.515  49.958  1
587129  99.134  -57.523  49.927  1
587130  99.160  -57.535  49.894  1
587131  99.176  -57.542  49.860  1
587132  99.190  -57.549  49.825  1
587133  99.203  -57.555  49.791  1
587134  99.214  -57.562  49.756  1
587135  99.226  -57.569  49.720  1
587136  99.240  -57.576  49.682  1
587137  99.269  -57.583  49.643  1
587138  99.298  -57.589  49.604  1
587139  99.327  -57.595  49.566  1
587140  99.356  -57.601  49.530  1
587141  99.386  -57.607  49.494  1
587142  99.415  -57.613  49.458  1
587143  99.444  -57.619  49.421  1
587144  99.473  -57.625  49.384  1
587145  99.501  -57.630  49.346  1
587146  99.528  -57.636  49.307  1
587147  99.572  -57.642  49.268  1
587148  99.617  -57.649  49.230  1
587149  99.651  -57.658  49.193  1
587150  99.686  -57.667  49.158  1
587151  99.720  -57.675  49.126  1
587152  99.755  -57.684  49.096  1
587153  99.789  -57.692  49.068  1
587154  99.824  -57.702  49.040  1
587155  99.858  -57.711  49.015  1
587156  99.893  -57.719  48.990  1
587157  99.927  -57.728  48.969  1
587158  99.962  -57.736  48.948  1
587159  99.996  -57.746  48.928  1
587160  100.031  -57.754  48.908  1
587161  100.065  -57.763  48.889  1
587504  88.366  -53.922  57.556  4
587505  88.402  -53.938  57.558  4
587506  88.437  -53.954  57.560  4
587507  88.473  -53.969  57.562  4
587508  88.508  -53.984  57.563  4
587509  88.543  -54.000  57.562  4
587510  88.578  -54.015  57.561  4
587511  88.614  -54.030  57.560  4
587512  88.649  -54.045  57.558  4
587513  88.685  -54.060  57.555  4
587514  88.720  -54.076  57.553  4
587515  88.757  -54.095  57.549  4
587516  88.796  -54.113  57.543  4
587517  88.839  -54.134  57.538  4
587518  88.875  -54.158  57.533  4
587519  88.921  -54.169  57.525  4
587520  88.960  -54.191  57.514  4
587521  88.998  -54.207  57.497  4
587522  89.037  -54.225  57.475  4
587523  89.074  -54.242  57.448  4
587524  89.113  -54.258  57.415  4
587525  89.151  -54.275  57.379  4
587526  89.189  -54.292  57.340  4
587527  89.227  -54.309  57.296  4
587528  89.265  -54.326  57.251  4
587529  89.303  -54.342  57.205  4
587530  89.341  -54.359  57.157  4
587531  89.380  -54.376  57.110  4
587532  89.418  -54.392  57.063  4
587533  89.456  -54.410  57.015  4
587534  89.494  -54.427  56.967  4
587535  89.532  -54.443  56.921  4
587546  89.954  -54.657  56.307  1
587547  89.992  -54.681  56.273  1
587548  90.031  -54.704  56.240  1
587549  90.070  -54.728  56.210  1
587550  90.108  -54.750  56.181  1
587551  90.147  -54.774  56.153  1
587552  90.185  -54.797  56.125  1
587553  90.224  -54.821  56.098  1
587554  90.262  -54.844  56.073  1
587555  90.298  -54.866  56.052  1
587556  90.321  -54.880  56.031  1
587557  90.345  -54.894  56.011  1
587558  90.368  -54.909  55.994  1
587559  90.391  -54.922  55.977  1
587560  90.414  -54.937  55.961  1
587561  90.438  -54.950  55.948  1
587562  90.461  -54.965  55.938  1
587563  90.484  -54.979  55.924  1
587564  90.508  -54.993  55.905  1
587565  90.533  -55.007  55.886  1
587566  90.559  -55.020  55.870  1
587567  90.585  -55.035  55.860  1
587568  90.610  -55.048  55.852  1
587569  90.636  -55.062  55.846  1
587570  90.662  -55.075  55.841  1
587571  90.688  -55.088  55.839  1
587572  90.714  -55.099  55.838  1
587573  90.749  -55.115  55.840  1
587574  90.785  -55.131  55.845  1
587575  90.820  -55.146  55.855  1
587576  90.855  -55.162  55.866  1
587577  90.890  -55.178  55.876  1
587578  90.926  -55.194  55.886  1
587579  90.961  -55.209  55.893  1
587580  90.997  -55.225  55.892  1
587581  91.032  -55.241  55.889  1
587582  91.067  -55.256  55.885  1
587583  91.102  -55.272  55.880  1
587584  91.138  -55.288  55.872  1
587585  91.173  -55.304  55.858  1
587586  91.212  -55.317  55.839  1
587587  91.257  -55.329  55.823  1
587588  91.302  -55.340  55.808  1
587589  91.347  -55.351  55.790  1
587590  91.392  -55.363  55.763  1
587591  91.437  -55.373  55.734  1
587592  91.475  -55.386  55.708  1
587593  91.511  -55.398  55.688  1
587594  91.545  -55.411  55.674  1
587595  91.581  -55.424  55.663  1
587596  91.615  -55.437  55.644  1
587597  91.651  -55.450  55.619  1
587598  91.685  -55.462  55.583  1
587599  91.721  -55.475  55.542  1
587600  91.756  -55.488  55.504  1
587601  91.791  -55.501  55.471  1
587602  91.826  -55.514  55.442  1
587603  91.861  -55.526  55.413  1
587604  91.896  -55.539  55.387  1
587605  91.931  -55.552  55.364  1
587606  91.966  -55.564  55.344  1
587607  92.001  -55.577  55.325  1
587608  92.036  -55.589  55.311  1
587609  92.067  -55.602  55.298  1
587610  92.098  -55.614  55.290  1
587611  92.130  -55.627  55.287  1
587612  92.163  -55.639  55.288  1
587613  92.195  -55.652  55.287  1
587614  92.228  -55.665  55.277  1
587615  92.260  -55.677  55.261  1
587616  92.292  -55.694  55.241  1
587617  92.322  -55.720  55.221  1
587618  92.353  -55.746  55.203  1
587619  92.383  -55.771  55.190  1
587620  92.414  -55.797  55.179  1
587621  92.444  -55.823  55.176  1
587622  92.475  -55.849  55.173  1
587623  92.506  -55.871  55.171  1
587624  92.538  -55.890  55.171  1
587625  92.573  -55.909  55.174  1
587626  92.609  -55.928  55.170  1
587627  92.645  -55.948  55.166  1
587628  92.681  -55.967  55.169  1
587629  92.716  -55.987  55.179  1
587630  92.752  -56.005  55.194  1
587631  92.788  -56.020  55.205  1
587632  92.825  -56.036  55.211  1
587633  92.861  -56.051  55.217  1
587634  92.897  -56.066  55.226  1
587635  92.933  -56.082  55.236  1
587636  92.970  -56.097  55.246  1
587637  93.006  -56.113  55.253  1
587638  93.042  -56.117  55.257  1
587639  93.077  -56.121  55.267  1
587640  93.113  -56.125  55.281  1
587641  93.149  -56.130  55.295  1
587642  93.185  -56.135  55.305  1
587643  93.221  -56.139  55.309  1
587644  93.257  -56.144  55.307  1
587645  93.292  -56.148  55.302  1
587646  93.328  -56.153  55.296  1
587647  93.364  -56.157  55.290  1
587648  93.400  -56.161  55.282  1
587649  93.434  -56.164  55.276  1
587650  93.467  -56.176  55.266  1
587651  93.499  -56.194  55.257  1
587652  93.531  -56.210  55.246  1
587653  93.563  -56.227  55.232  1
587654  93.595  -56.244  55.213  1
587655  93.627  -56.261  55.193  1
587656  93.659  -56.278  55.169  1
587657  93.691  -56.295  55.143  1
587658  93.723  -56.312  55.116  1
587659  93.755  -56.329  55.087  1
587660  93.787  -56.345  55.054  1
587661  93.820  -56.363  55.020  1
587662  93.851  -56.379  54.989  1
587663  93.884  -56.396  54.958  1
587664  93.916  -56.414  54.928  1
587665  93.948  -56.430  54.898  1
587666  93.979  -56.447  54.864  1
587667  94.009  -56.462  54.831  1
587668  94.040  -56.478  54.797  1
587669  94.070  -56.494  54.762  1
587670  94.100  -56.510  54.727  1
587671  94.130  -56.525  54.688  1
587672  94.160  -56.541  54.644  1
587673  94.191  -56.557  54.600  1
587674  94.221  -56.572  54.554  1
587675  94.252  -56.588  54.505  1
587676  94.281  -56.602  54.454  1
587677  94.310  -56.611  54.400  1
587678  94.338  -56.620  54.347  1
587679  94.366  -56.630  54.309  1
587680  94.394  -56.639  54.272  1
587681  94.422  -56.648  54.234  1
587682  94.453  -56.657  54.194  1
587683  94.489  -56.667  54.152  1
587684  94.525  -56.677  54.109  1
587685  94.560  -56.686  54.066  1
587686  94.596  -56.696  54.021  1
587687  94.632  -56.705  53.975  1
587688  94.666  -56.715  53.929  1
587689  94.695  -56.730  53.886  1
587690  94.725  -56.745  53.842  1
587691  94.754  -56.760  53.804  1
587692  94.783  -56.774  53.767  1
587693  94.813  -56.790  53.730  1
587694  94.842  -56.805  53.693  1
587695  94.872  -56.819  53.655  1
587696  94.901  -56.834  53.611  1
587697  94.930  -56.849  53.555  1
587698  94.960  -56.864  53.496  1
587699  94.988  -56.877  53.443  1
587700  95.017  -56.890  53.400  1
587701  95.045  -56.903  53.363  1
587702  95.073  -56.915  53.330  1
587703  95.101  -56.928  53.297  1
587704  95.129  -56.941  53.262  1
587705  95.158  -56.954  53.227  1
587706  95.192  -56.961  53.190  1
587707  95.233  -56.963  53.152  1
587708  95.283  -56.960  53.114  1
587709  95.331  -56.958  53.075  1
587710  95.358  -56.968  53.037  1
587711  95.386  -56.978  53.002  1
587712  95.413  -56.987  52.969  1
587713  95.450  -56.996  52.934  1
587714  95.488  -57.004  52.897  1
587715  95.527  -57.012  52.863  1
587716  95.566  -57.021  52.833  1
587717  95.605  -57.029  52.804  1
587718  95.644  -57.037  52.776  1
587719  95.683  -57.046  52.747  1
587720  95.722  -57.054  52.719  1
587721  95.760  -57.062  52.689  1
587722  95.798  -57.071  52.656  1
587723  95.834  -57.078  52.618  1
587724  95.862  -57.084  52.580  1
587725  95.884  -57.091  52.548  1
587726  95.905  -57.098  52.515  1
587727  95.927  -57.105  52.480  1
587728  95.949  -57.112  52.442  1
587729  95.970  -57.119  52.402  1
587730  95.992  -57.125  52.363  1
587731  96.014  -57.132  52.326  1
587732  96.035  -57.139  52.295  1
587733  96.057  -57.146  52.265  1
587734  96.079  -57.152  52.237  1
587735  96.100  -57.159  52.210  1
587736  96.122  -57.168  52.183  1
587737  96.146  -57.178  52.155  1
587738  96.169  -57.188  52.134  1
587739  96.192  -57.197  52.111  1
587740  96.220  -57.203  52.089  1
587741  96.248  -57.208  52.069  1
587742  96.275  -57.213  52.050  1
587743  96.304  -57.219  52.031  1
587744  96.331  -57.224  52.016  1
587745  96.359  -57.227  51.999  1
587746  96.387  -57.231  51.980  1
587747  96.415  -57.234  51.957  1
587748  96.444  -57.237  51.929  1
587749  96.473  -57.240  51.899  1
587750  96.503  -57.246  51.876  1
587751  96.533  -57.251  51.852  1
587752  96.562  -57.257  51.828  1
587753  96.592  -57.263  51.802  1
587754  96.624  -57.267  51.776  1
587755  96.657  -57.272  51.753  1
587756  96.689  -57.276  51.733  1
587757  96.721  -57.281  51.718  1
587758  96.753  -57.285  51.706  1
587759  96.786  -57.290  51.698  1
587760  96.818  -57.297  51.692  1
587761  96.851  -57.304  51.689  1
587762  96.883  -57.310  51.692  1
587763  96.915  -57.316  51.687  1
587764  96.948  -57.323  51.676  1
587765  96.980  -57.325  51.661  1
587766  97.013  -57.316  51.645  1
587767  97.045  -57.307  51.634  1
587768  97.078  -57.298  51.626  1
587769  97.114  -57.295  51.617  1
587770  97.151  -57.293  51.611  1
587771  97.188  -57.291  51.605  1
587772  97.225  -57.288  51.599  1
587773  97.262  -57.286  51.594  1
587774  97.299  -57.284  51.592  1
587775  97.330  -57.282  51.592  1
587776  97.358  -57.278  51.589  1
587777  97.385  -57.275  51.579  1
587778  97.412  -57.272  51.564  1
587779  97.439  -57.269  51.545  1
587780  97.467  -57.265  51.521  1
587781  97.494  -57.262  51.495  1
587782  97.527  -57.272  51.470  1
587783  97.561  -57.286  51.444  1
587784  97.592  -57.294  51.415  1
587785  97.623  -57.301  51.380  1
587786  97.653  -57.308  51.339  1
587787  97.683  -57.316  51.298  1
587788  97.714  -57.322  51.255  1
587789  97.744  -57.330  51.210  1
587790  97.775  -57.338  51.165  1
587791  97.806  -57.344  51.120  1
587792  97.836  -57.352  51.081  1
587793  97.867  -57.359  51.046  1
587794  97.897  -57.366  51.012  1
587795  97.928  -57.372  50.980  1
587796  97.959  -57.375  50.949  1
587797  97.995  -57.379  50.920  1
587798  98.031  -57.383  50.889  1
587799  98.067  -57.387  50.860  1
587800  98.102  -57.391  50.832  1
587801  98.138  -57.395  50.803  1
587802  98.174  -57.400  50.773  1
587803  98.209  -57.404  50.740  1
587804  98.245  -57.407  50.706  1
587805  98.281  -57.412  50.671  1
587806  98.316  -57.416  50.636  1
587807  98.352  -57.420  50.602  1
587808  98.388  -57.424  50.570  1
587809  98.424  -57.429  50.539  1
587810  98.461  -57.432  50.506  1
587811  98.506  -57.435  50.472  1
587812  98.551  -57.438  50.440  1
587813  98.596  -57.441  50.409  1
587814  98.631  -57.438  50.378  1
587815  98.661  -57.432  50.349  1
587816  98.691  -57.426  50.319  1
587817  98.721  -57.420  50.292  1
587818  98.757  -57.421  50.266  1
587819  98.795  -57.423  50.241  1
587820  98.833  -57.426  50.215  1
587821  98.870  -57.429  50.189  1
587822  98.908  -57.432  50.161  1
587823  98.936  -57.439  50.132  1
587824  98.962  -57.447  50.104  1
587825  98.990  -57.455  50.077  1
587826  99.016  -57.463  50.049  1
587827  99.044  -57.470  50.020  1
587828  99.070  -57.478  49.990  1
587829  99.097  -57.485  49.960  1
587830  99.124  -57.497  49.929  1
587831  99.151  -57.509  49.896  1
587832  99.171  -57.519  49.862  1
587833  99.185  -57.526  49.827  1
587834  99.198  -57.532  49.791  1
587835  99.211  -57.539  49.757  1
587836  99.224  -57.545  49.721  1
587837  99.242  -57.551  49.683  1
587838  99.272  -57.558  49.644  1
587839  99.301  -57.564  49.603  1
587840  99.330  -57.570  49.566  1
587841  99.360  -57.575  49.528  1
587842  99.389  -57.581  49.490  1
587843  99.418  -57.587  49.453  1
587844  99.448  -57.593  49.417  1
587845  99.476  -57.598  49.379  1
587846  99.504  -57.604  49.342  1
587847  99.531  -57.609  49.303  1
587848  99.559  -57.615  49.265  1
587849  99.609  -57.621  49.228  1
587850  99.644  -57.630  49.190  1
587851  99.678  -57.639  49.155  1
587852  99.713  -57.648  49.122  1
587853  99.747  -57.656  49.092  1
587854  99.782  -57.665  49.063  1
587855  99.816  -57.673  49.036  1
587856  99.850  -57.683  49.010  1
587857  99.885  -57.692  48.986  1
587858  99.919  -57.700  48.965  1
587859  99.954  -57.709  48.944  1
587860  99.988  -57.717  48.924  1
587861  100.023  -57.727  48.904  1
587862  100.055  -57.739  48.885  1
588205  88.391  -53.888  57.552  4
588206  88.426  -53.903  57.554  4
588207  88.462  -53.919  57.555  4
588208  88.497  -53.934  57.556  4
588209  88.533  -53.949  57.558  4
588210  88.568  -53.964  57.557  4
588211  88.603  -53.980  57.556  4
588212  88.638  -53.995  57.555  4
588213  88.674  -54.010  57.552  4
588214  88.709  -54.026  57.550  4
588215  88.747  -54.044  57.546  4
588216  88.785  -54.063  57.541  4
588217  88.823  -54.083  57.536  4
588218  88.871  -54.103  57.530  4
588219  88.905  -54.127  57.524  4
588220  88.941  -54.151  57.516  4
588221  88.982  -54.167  57.502  4
588222  89.020  -54.185  57.483  4
588223  89.058  -54.201  57.461  4
588224  89.097  -54.218  57.435  4
588225  89.134  -54.235  57.405  4
588226  89.173  -54.251  57.373  4
588227  89.211  -54.269  57.336  4
588228  89.249  -54.286  57.294  4
588229  89.287  -54.302  57.251  4
588230  89.325  -54.319  57.205  4
588231  89.364  -54.336  57.159  4
588232  89.401  -54.352  57.113  4
588233  89.440  -54.370  57.065  4
588234  89.478  -54.386  57.017  4
588235  89.516  -54.403  56.969  4
588246  89.936  -54.602  56.348  1
588247  89.975  -54.625  56.312  1
588248  90.014  -54.649  56.278  1
588249  90.052  -54.672  56.246  1
588250  90.091  -54.695  56.216  1
588251  90.129  -54.718  56.188  1
588252  90.168  -54.742  56.160  1
588253  90.206  -54.765  56.133  1
588254  90.245  -54.789  56.108  1
588255  90.284  -54.812  56.084  1
588256  90.317  -54.833  56.064  1
588257  90.340  -54.847  56.043  1
588258  90.364  -54.861  56.025  1
588259  90.387  -54.875  56.008  1
588260  90.410  -54.889  55.993  1
588261  90.434  -54.903  55.979  1
588262  90.457  -54.918  55.969  1
588263  90.480  -54.931  55.959  1
588264  90.504  -54.946  55.942  1
588265  90.530  -54.960  55.920  1
588266  90.555  -54.973  55.897  1
588267  90.581  -54.987  55.878  1
588268  90.607  -55.000  55.866  1
588269  90.633  -55.014  55.856  1
588270  90.658  -55.028  55.848  1
588271  90.684  -55.041  55.843  1
588272  90.710  -55.056  55.840  1
588273  90.741  -55.069  55.840  1
588274  90.777  -55.085  55.842  1
588275  90.812  -55.101  55.845  1
588276  90.847  -55.116  55.850  1
588277  90.882  -55.132  55.858  1
588278  90.918  -55.148  55.867  1
588279  90.953  -55.163  55.873  1
588280  90.988  -55.179  55.875  1
588281  91.024  -55.195  55.872  1
588282  91.059  -55.210  55.867  1
588283  91.094  -55.226  55.863  1
588284  91.130  -55.242  55.858  1
588285  91.165  -55.257  55.852  1
588286  91.200  -55.273  55.838  1
588287  91.235  -55.289  55.818  1
588288  91.271  -55.305  55.798  1
588289  91.315  -55.317  55.782  1
588290  91.360  -55.328  55.763  1
588291  91.405  -55.339  55.738  1
588292  91.449  -55.351  55.710  1
588293  91.485  -55.363  55.686  1
588294  91.519  -55.376  55.667  1
588295  91.555  -55.389  55.654  1
588296  91.589  -55.401  55.645  1
588297  91.625  -55.414  55.629  1
588298  91.659  -55.426  55.602  1
588299  91.695  -55.439  55.564  1
588300  91.729  -55.452  55.523  1
588301  91.765  -55.465  55.487  1
588302  91.800  -55.478  55.456  1
588303  91.835  -55.490  55.428  1
588304  91.870  -55.503  55.401  1
588305  91.905  -55.516  55.377  1
588306  91.940  -55.529  55.355  1
588307  91.975  -55.542  55.336  1
588308  92.010  -55.554  55.320  1
588309  92.045  -55.566  55.308  1
588310  92.080  -55.577  55.299  1
588311  92.115  -55.591  55.294  1
588312  92.148  -55.605  55.294  1
588313  92.181  -55.618  55.299  1
588314  92.213  -55.630  55.303  1
588315  92.246  -55.643  55.298  1
588316  92.278  -55.656  55.287  1
588317  92.311  -55.668  55.272  1
588318  92.341  -55.694  55.253  1
588319  92.372  -55.720  55.233  1
588320  92.402  -55.746  55.214  1
588321  92.433  -55.771  55.199  1
588322  92.463  -55.794  55.189  1
588323  92.495  -55.813  55.183  1
588324  92.526  -55.833  55.181  1
588325  92.561  -55.852  55.183  1
588326  92.596  -55.872  55.188  1
588327  92.632  -55.891  55.185  1
588328  92.668  -55.910  55.177  1
588329  92.704  -55.930  55.171  1
588330  92.739  -55.949  55.169  1
588331  92.775  -55.969  55.175  1
588332  92.810  -55.987  55.185  1
588333  92.846  -56.007  55.193  1
588334  92.882  -56.026  55.204  1
588335  92.918  -56.044  55.218  1
588336  92.954  -56.059  55.233  1
588337  92.990  -56.075  55.246  1
588338  93.026  -56.090  55.254  1
588339  93.062  -56.094  55.259  1
588340  93.098  -56.099  55.267  1
588341  93.134  -56.103  55.280  1
588342  93.170  -56.108  55.294  1
588343  93.206  -56.113  55.304  1
588344  93.240  -56.115  55.309  1
588345  93.275  -56.118  55.308  1
588346  93.309  -56.120  55.304  1
588347  93.343  -56.123  55.298  1
588348  93.377  -56.125  55.289  1
588349  93.412  -56.128  55.276  1
588350  93.446  -56.131  55.263  1
588351  93.479  -56.143  55.249  1
588352  93.509  -56.165  55.236  1
588353  93.541  -56.187  55.223  1
588354  93.573  -56.204  55.209  1
588355  93.605  -56.221  55.190  1
588356  93.637  -56.238  55.170  1
588357  93.669  -56.254  55.146  1
588358  93.701  -56.272  55.120  1
588359  93.733  -56.288  55.092  1
588360  93.765  -56.305  55.064  1
588361  93.797  -56.323  55.032  1
588362  93.829  -56.339  55.000  1
588363  93.861  -56.356  54.970  1
588364  93.894  -56.373  54.941  1
588365  93.926  -56.390  54.914  1
588366  93.957  -56.406  54.887  1
588367  93.987  -56.422  54.855  1
588368  94.017  -56.438  54.823  1
588369  94.048  -56.454  54.791  1
588370  94.078  -56.469  54.759  1
588371  94.108  -56.485  54.723  1
588372  94.138  -56.501  54.683  1
588373  94.169  -56.517  54.638  1
588374  94.199  -56.532  54.594  1
588375  94.229  -56.548  54.547  1
588376  94.259  -56.564  54.499  1
588377  94.289  -56.577  54.448  1
588378  94.317  -56.586  54.397  1
588379  94.345  -56.595  54.343  1
588380  94.373  -56.604  54.300  1
588381  94.402  -56.613  54.262  1
588382  94.430  -56.622  54.222  1
588383  94.458  -56.631  54.181  1
588384  94.493  -56.641  54.138  1
588385  94.529  -56.650  54.092  1
588386  94.565  -56.660  54.049  1
588387  94.601  -56.670  54.004  1
588388  94.636  -56.679  53.958  1
588389  94.672  -56.689  53.912  1
588390  94.706  -56.699  53.868  1
588391  94.736  -56.714  53.824  1
588392  94.765  -56.729  53.787  1
588393  94.794  -56.744  53.751  1
588394  94.824  -56.758  53.716  1
588395  94.853  -56.774  53.680  1
588396  94.883  -56.788  53.643  1
588397  94.912  -56.803  53.601  1
588398  94.941  -56.818  53.551  1
588399  94.970  -56.831  53.492  1
588400  94.997  -56.844  53.434  1
588401  95.026  -56.857  53.381  1
588402  95.054  -56.869  53.338  1
588403  95.082  -56.882  53.302  1
588404  95.110  -56.895  53.268  1
588405  95.138  -56.908  53.232  1
588406  95.167  -56.921  53.196  1
588407  95.199  -56.930  53.160  1
588408  95.246  -56.929  53.123  1
588409  95.297  -56.925  53.084  1
588410  95.340  -56.926  53.045  1
588411  95.368  -56.936  53.005  1
588412  95.395  -56.945  52.967  1
588413  95.422  -56.955  52.932  1
588414  95.454  -56.964  52.898  1
588415  95.492  -56.972  52.863  1
588416  95.531  -56.981  52.832  1
588417  95.570  -56.989  52.804  1
588418  95.609  -56.997  52.777  1
588419  95.648  -57.006  52.749  1
588420  95.686  -57.014  52.720  1
588421  95.725  -57.023  52.693  1
588422  95.764  -57.031  52.664  1
588423  95.801  -57.038  52.630  1
588424  95.837  -57.046  52.592  1
588425  95.866  -57.053  52.551  1
588426  95.887  -57.059  52.514  1
588427  95.909  -57.066  52.481  1
588428  95.931  -57.073  52.446  1
588429  95.952  -57.080  52.409  1
588430  95.974  -57.087  52.372  1
588431  95.995  -57.094  52.333  1
588432  96.017  -57.100  52.295  1
588433  96.039  -57.106  52.264  1
588434  96.060  -57.113  52.235  1
588435  96.082  -57.120  52.209  1
588436  96.104  -57.128  52.184  1
588437  96.127  -57.138  52.157  1
588438  96.150  -57.148  52.130  1
588439  96.173  -57.158  52.106  1
588440  96.196  -57.168  52.083  1
588441  96.223  -57.174  52.063  1
588442  96.251  -57.179  52.044  1
588443  96.279  -57.185  52.024  1
588444  96.307  -57.190  52.004  1
588445  96.335  -57.194  51.990  1
588446  96.363  -57.197  51.975  1
588447  96.390  -57.200  51.957  1
588448  96.418  -57.204  51.934  1
588449  96.447  -57.207  51.910  1
588450  96.476  -57.210  51.887  1
588451  96.505  -57.213  51.866  1
588452  96.534  -57.217  51.840  1
588453  96.564  -57.222  51.811  1
588454  96.594  -57.228  51.783  1
588455  96.626  -57.233  51.756  1
588456  96.658  -57.238  51.730  1
588457  96.690  -57.242  51.708  1
588458  96.723  -57.247  51.687  1
588459  96.755  -57.254  51.672  1
588460  96.788  -57.260  51.662  1
588461  96.820  -57.266  51.653  1
588462  96.852  -57.273  51.647  1
588463  96.885  -57.280  51.645  1
588464  96.917  -57.286  51.637  1
588465  96.949  -57.293  51.625  1
588466  96.981  -57.296  51.610  1
588467  97.014  -57.287  51.596  1
588468  97.046  -57.279  51.587  1
588469  97.079  -57.269  51.583  1
588470  97.111  -57.260  51.572  1
588471  97.146  -57.254  51.561  1
588472  97.183  -57.252  51.553  1
588473  97.220  -57.250  51.547  1
588474  97.257  -57.248  51.541  1
588475  97.294  -57.246  51.539  1
588476  97.331  -57.244  51.539  1
588477  97.360  -57.241  51.536  1
588478  97.387  -57.238  51.527  1
588479  97.415  -57.234  51.513  1
588480  97.442  -57.231  51.495  1
588481  97.469  -57.228  51.472  1
588482  97.497  -57.225  51.447  1
588483  97.529  -57.233  51.421  1
588484  97.563  -57.247  51.395  1
588485  97.594  -57.254  51.368  1
588486  97.624  -57.261  51.335  1
588487  97.655  -57.269  51.297  1
588488  97.685  -57.275  51.259  1
588489  97.716  -57.283  51.219  1
588490  97.746  -57.291  51.177  1
588491  97.777  -57.297  51.134  1
588492  97.807  -57.305  51.091  1
588493  97.838  -57.312  51.053  1
588494  97.868  -57.319  51.018  1
588495  97.899  -57.327  50.984  1
588496  97.930  -57.334  50.953  1
588497  97.963  -57.340  50.922  1
588498  97.999  -57.344  50.893  1
588499  98.035  -57.348  50.864  1
588500  98.071  -57.352  50.836  1
588501  98.106  -57.357  50.810  1
588502  98.142  -57.360  50.784  1
588503  98.178  -57.365  50.755  1
588504  98.214  -57.369  50.725  1
588505  98.249  -57.373  50.692  1
588506  98.285  -57.377  50.658  1
588507  98.321  -57.382  50.624  1
588508  98.356  -57.385  50.590  1
588509  98.392  -57.390  50.558  1
588510  98.428  -57.394  50.527  1
588511  98.463  -57.398  50.496  1
588512  98.501  -57.402  50.463  1
588513  98.546  -57.405  50.431  1
588514  98.591  -57.407  50.399  1
588515  98.632  -57.408  50.369  1
588516  98.662  -57.402  50.339  1
588517  98.692  -57.396  50.310  1
588518  98.722  -57.391  50.285  1
588519  98.760  -57.394  50.261  1
588520  98.798  -57.396  50.236  1
588521  98.836  -57.399  50.210  1
588522  98.873  -57.401  50.184  1
588523  98.911  -57.406  50.157  1
588524  98.926  -57.410  50.129  1
588525  98.953  -57.418  50.103  1
588526  98.980  -57.426  50.077  1
588527  99.007  -57.433  50.050  1
588528  99.034  -57.442  50.022  1
588529  99.061  -57.449  49.993  1
588530  99.088  -57.459  49.963  1
588531  99.115  -57.471  49.931  1
588532  99.141  -57.484  49.897  1
588533  99.166  -57.496  49.861  1
588534  99.180  -57.502  49.825  1
588535  99.193  -57.509  49.789  1
588536  99.206  -57.516  49.754  1
588537  99.220  -57.522  49.718  1
588538  99.243  -57.528  49.680  1
588539  99.274  -57.532  49.642  1
588540  99.304  -57.538  49.601  1
588541  99.334  -57.543  49.563  1
588542  99.363  -57.549  49.525  1
588543  99.393  -57.555  49.488  1
588544  99.422  -57.561  49.451  1
588545  99.451  -57.567  49.414  1
588546  99.479  -57.573  49.376  1
588547  99.507  -57.578  49.339  1
588548  99.534  -57.583  49.302  1
588549  99.562  -57.589  49.264  1
588550  99.594  -57.595  49.226  1
588551  99.636  -57.602  49.189  1
588552  99.671  -57.611  49.153  1
588553  99.705  -57.620  49.120  1
588554  99.739  -57.629  49.090  1
588555  99.774  -57.637  49.061  1
588556  99.808  -57.646  49.033  1
588557  99.843  -57.655  49.007  1
588558  99.877  -57.664  48.982  1
588559  99.911  -57.673  48.962  1
588560  99.940  -57.690  48.941  1
588561  99.969  -57.708  48.921  1
588562  99.997  -57.725  48.901  1
588563  100.026  -57.742  48.882  1
588906  88.416  -53.853  57.547  4
588907  88.451  -53.868  57.549  4
588908  88.486  -53.884  57.550  4
588909  88.522  -53.899  57.550  4
588910  88.557  -53.914  57.553  4
588911  88.593  -53.929  57.552  4
588912  88.628  -53.944  57.550  4
588913  88.663  -53.960  57.548  4
588914  88.699  -53.976  57.546  4
588915  88.737  -53.994  57.543  4
588916  88.774  -54.013  57.540  4
588917  88.813  -54.033  57.534  4
588918  88.850  -54.052  57.528  4
588919  88.900  -54.073  57.522  4
588920  88.936  -54.096  57.513  4
588921  88.972  -54.120  57.503  4
588922  89.013  -54.136  57.491  4
588923  89.045  -54.159  57.472  4
588924  89.081  -54.178  57.449  4
588925  89.118  -54.195  57.423  4
588926  89.157  -54.211  57.397  4
588927  89.195  -54.229  57.366  4
588928  89.233  -54.245  57.332  4
588929  89.271  -54.262  57.292  4
588930  89.309  -54.279  57.249  4
588931  89.347  -54.295  57.205  4
588932  89.385  -54.312  57.159  4
588933  89.423  -54.330  57.114  4
588934  89.462  -54.346  57.067  4
588935  89.499  -54.363  57.019  4
588936  89.538  -54.380  56.972  4
588946  89.919  -54.548  56.389  1
588947  89.958  -54.570  56.353  1
588948  89.996  -54.593  56.317  1
588949  90.035  -54.617  56.283  1
588950  90.074  -54.640  56.251  1
588951  90.112  -54.663  56.222  1
588952  90.151  -54.687  56.195  1
588953  90.189  -54.710  56.168  1
588954  90.228  -54.734  56.142  1
588955  90.266  -54.757  56.117  1
588956  90.305  -54.781  56.094  1
588957  90.336  -54.800  56.075  1
588958  90.360  -54.814  56.057  1
588959  90.383  -54.828  56.041  1
588960  90.406  -54.842  56.026  1
588961  90.429  -54.856  56.013  1
588962  90.453  -54.870  56.001  1
588963  90.476  -54.884  55.991  1
588964  90.500  -54.898  55.978  1
588965  90.526  -54.912  55.959  1
588966  90.551  -54.925  55.934  1
588967  90.577  -54.939  55.906  1
588968  90.603  -54.953  55.886  1
588969  90.628  -54.967  55.871  1
588970  90.654  -54.981  55.860  1
588971  90.680  -54.994  55.851  1
588972  90.706  -55.008  55.845  1
588973  90.724  -55.025  55.843  1
588974  90.761  -55.041  55.843  1
588975  90.798  -55.057  55.843  1
588976  90.834  -55.072  55.845  1
588977  90.871  -55.087  55.847  1
588978  90.908  -55.102  55.851  1
588979  90.945  -55.118  55.856  1
588980  90.980  -55.133  55.859  1
588981  91.015  -55.149  55.856  1
588982  91.051  -55.165  55.851  1
588983  91.086  -55.181  55.846  1
588984  91.121  -55.196  55.842  1
588985  91.157  -55.212  55.839  1
588986  91.192  -55.228  55.836  1
588987  91.227  -55.244  55.821  1
588988  91.262  -55.259  55.798  1
588989  91.298  -55.275  55.775  1
588990  91.333  -55.291  55.757  1
588991  91.373  -55.304  55.737  1
588992  91.418  -55.316  55.717  1
588993  91.458  -55.328  55.690  1
588994  91.493  -55.340  55.666  1
588995  91.528  -55.353  55.647  1
588996  91.563  -55.366  55.634  1
588997  91.598  -55.379  55.626  1
588998  91.633  -55.392  55.613  1
588999  91.668  -55.404  55.585  1
589000  91.703  -55.417  55.546  1
589001  91.738  -55.430  55.505  1
589002  91.774  -55.440  55.472  1
589003  91.809  -55.451  55.443  1
589004  91.845  -55.462  55.416  1
589005  91.880  -55.473  55.391  1
589006  91.916  -55.483  55.368  1
589007  91.951  -55.494  55.347  1
589008  91.987  -55.505  55.330  1
589009  92.022  -55.516  55.317  1
589010  92.058  -55.527  55.306  1
589011  92.092  -55.541  55.299  1
589012  92.126  -55.558  55.298  1
589013  92.161  -55.574  55.302  1
589014  92.196  -55.591  55.312  1
589015  92.230  -55.608  55.318  1
589016  92.264  -55.623  55.318  1
589017  92.296  -55.635  55.314  1
589018  92.329  -55.648  55.303  1
589019  92.360  -55.668  55.287  1
589020  92.391  -55.694  55.267  1
589021  92.422  -55.718  55.243  1
589022  92.453  -55.737  55.223  1
589023  92.484  -55.756  55.207  1
589024  92.515  -55.776  55.197  1
589025  92.549  -55.795  55.194  1
589026  92.584  -55.815  55.194  1
589027  92.620  -55.834  55.197  1
589028  92.655  -55.853  55.196  1
589029  92.691  -55.872  55.190  1
589030  92.727  -55.892  55.182  1
589031  92.763  -55.911  55.175  1
589032  92.798  -55.931  55.173  1
589033  92.834  -55.950  55.180  1
589034  92.869  -55.969  55.193  1
589035  92.905  -55.988  55.207  1
589036  92.941  -56.008  55.222  1
589037  92.977  -56.027  55.236  1
589038  93.012  -56.047  55.250  1
589039  93.046  -56.066  55.258  1
589040  93.081  -56.069  55.262  1
589041  93.115  -56.072  55.267  1
589042  93.149  -56.074  55.276  1
589043  93.184  -56.077  55.289  1
589044  93.218  -56.079  55.301  1
589045  93.252  -56.082  55.308  1
589046  93.286  -56.085  55.311  1
589047  93.321  -56.088  55.310  1
589048  93.355  -56.090  55.304  1
589049  93.389  -56.092  55.294  1
589050  93.423  -56.095  55.277  1
589051  93.458  -56.097  55.257  1
589052  93.490  -56.110  55.239  1
589053  93.521  -56.132  55.221  1
589054  93.553  -56.154  55.205  1
589055  93.583  -56.176  55.190  1
589056  93.615  -56.197  55.172  1
589057  93.647  -56.214  55.154  1
589058  93.679  -56.232  55.133  1
589059  93.711  -56.248  55.110  1
589060  93.743  -56.265  55.085  1
589061  93.775  -56.282  55.058  1
589062  93.807  -56.299  55.032  1
589063  93.839  -56.316  55.005  1
589064  93.871  -56.333  54.979  1
589065  93.903  -56.350  54.954  1
589066  93.934  -56.366  54.928  1
589067  93.965  -56.382  54.903  1
589068  93.995  -56.398  54.872  1
589069  94.025  -56.413  54.838  1
589070  94.055  -56.429  54.801  1
589071  94.085  -56.445  54.763  1
589072  94.116  -56.461  54.722  1
589073  94.146  -56.476  54.680  1
589074  94.177  -56.492  54.633  1
589075  94.207  -56.508  54.585  1
589076  94.237  -56.523  54.536  1
589077  94.267  -56.539  54.488  1
589078  94.296  -56.551  54.440  1
589079  94.325  -56.560  54.392  1
589080  94.353  -56.569  54.340  1
589081  94.381  -56.578  54.292  1
589082  94.409  -56.587  54.251  1
589083  94.437  -56.596  54.210  1
589084  94.466  -56.605  54.167  1
589085  94.498  -56.615  54.123  1
589086  94.534  -56.624  54.075  1
589087  94.570  -56.634  54.031  1
589088  94.606  -56.644  53.986  1
589089  94.641  -56.653  53.939  1
589090  94.677  -56.663  53.892  1
589091  94.712  -56.672  53.848  1
589092  94.746  -56.683  53.805  1
589093  94.776  -56.699  53.767  1
589094  94.805  -56.713  53.733  1
589095  94.834  -56.728  53.698  1
589096  94.864  -56.743  53.663  1
589097  94.893  -56.758  53.627  1
589098  94.922  -56.772  53.586  1
589099  94.951  -56.785  53.539  1
589100  94.979  -56.798  53.484  1
589101  95.007  -56.811  53.425  1
589102  95.035  -56.824  53.367  1
589103  95.063  -56.836  53.318  1
589104  95.092  -56.849  53.274  1
589105  95.120  -56.862  53.237  1
589106  95.147  -56.874  53.200  1
589107  95.176  -56.887  53.164  1
589108  95.208  -56.897  53.127  1
589109  95.259  -56.894  53.090  1
589110  95.309  -56.891  53.053  1
589111  95.349  -56.894  53.015  1
589112  95.377  -56.903  52.975  1
589113  95.404  -56.913  52.936  1
589114  95.431  -56.922  52.898  1
589115  95.459  -56.932  52.863  1
589116  95.496  -56.940  52.832  1
589117  95.535  -56.949  52.803  1
589118  95.573  -56.957  52.774  1
589119  95.612  -56.965  52.747  1
589120  95.651  -56.975  52.721  1
589121  95.690  -56.983  52.694  1
589122  95.729  -56.991  52.668  1
589123  95.767  -57.000  52.638  1
589124  95.804  -57.006  52.604  1
589125  95.840  -57.014  52.566  1
589126  95.870  -57.021  52.524  1
589127  95.891  -57.028  52.482  1
589128  95.913  -57.034  52.446  1
589129  95.934  -57.041  52.411  1
589130  95.956  -57.048  52.375  1
589131  95.977  -57.054  52.339  1
589132  95.999  -57.061  52.300  1
589133  96.021  -57.068  52.262  1
589134  96.042  -57.075  52.231  1
589135  96.064  -57.081  52.202  1
589136  96.086  -57.088  52.177  1
589137  96.109  -57.099  52.153  1
589138  96.132  -57.109  52.127  1
589139  96.155  -57.119  52.100  1
589140  96.178  -57.128  52.077  1
589141  96.201  -57.138  52.054  1
589142  96.227  -57.146  52.035  1
589143  96.254  -57.151  52.016  1
589144  96.282  -57.156  51.996  1
589145  96.310  -57.160  51.975  1
589146  96.338  -57.163  51.961  1
589147  96.366  -57.167  51.947  1
589148  96.394  -57.171  51.931  1
589149  96.421  -57.174  51.912  1
589150  96.450  -57.177  51.890  1
589151  96.479  -57.180  51.868  1
589152  96.508  -57.183  51.845  1
589153  96.537  -57.185  51.820  1
589154  96.566  -57.188  51.794  1
589155  96.595  -57.194  51.768  1
589156  96.627  -57.198  51.740  1
589157  96.660  -57.203  51.711  1
589158  96.692  -57.210  51.684  1
589159  96.725  -57.217  51.661  1
589160  96.757  -57.223  51.643  1
589161  96.789  -57.230  51.630  1
589162  96.821  -57.237  51.617  1
589163  96.854  -57.243  51.604  1
589164  96.886  -57.250  51.595  1
589165  96.919  -57.257  51.584  1
589166  96.951  -57.263  51.571  1
589167  96.983  -57.268  51.558  1
589168  97.016  -57.259  51.547  1
589169  97.048  -57.250  51.540  1
589170  97.081  -57.241  51.538  1
589171  97.113  -57.232  51.529  1
589172  97.146  -57.223  51.517  1
589173  97.178  -57.214  51.506  1
589174  97.215  -57.212  51.498  1
589175  97.252  -57.210  51.491  1
589176  97.289  -57.207  51.488  1
589177  97.326  -57.205  51.486  1
589178  97.363  -57.203  51.483  1
589179  97.390  -57.200  51.475  1
589180  97.418  -57.197  51.464  1
589181  97.445  -57.194  51.446  1
589182  97.472  -57.190  51.424  1
589183  97.500  -57.187  51.398  1
589184  97.531  -57.194  51.372  1
589185  97.565  -57.207  51.347  1
589186  97.595  -57.214  51.319  1
589187  97.626  -57.222  51.288  1
589188  97.656  -57.229  51.252  1
589189  97.687  -57.236  51.216  1
589190  97.718  -57.244  51.180  1
589191  97.748  -57.250  51.142  1
589192  97.779  -57.258  51.101  1
589193  97.809  -57.266  51.061  1
589194  97.840  -57.272  51.024  1
589195  97.870  -57.280  50.989  1
589196  97.902  -57.290  50.956  1
589197  97.936  -57.303  50.926  1
589198  97.969  -57.311  50.896  1
589199  98.005  -57.315  50.867  1
589200  98.040  -57.317  50.839  1
589201  98.075  -57.319  50.813  1
589202  98.110  -57.322  50.788  1
589203  98.146  -57.326  50.762  1
589204  98.182  -57.330  50.736  1
589205  98.218  -57.334  50.708  1
589206  98.253  -57.338  50.677  1
589207  98.289  -57.342  50.644  1
589208  98.325  -57.347  50.611  1
589209  98.361  -57.351  50.578  1
589210  98.396  -57.355  50.546  1
589211  98.432  -57.359  50.515  1
589212  98.467  -57.363  50.485  1
589213  98.503  -57.367  50.454  1
589214  98.541  -57.372  50.422  1
589215  98.585  -57.374  50.390  1
589216  98.631  -57.377  50.360  1
589217  98.662  -57.373  50.330  1
589218  98.692  -57.366  50.302  1
589219  98.725  -57.363  50.279  1
589220  98.763  -57.366  50.255  1
589221  98.801  -57.369  50.230  1
589222  98.839  -57.372  50.205  1
589223  98.876  -57.376  50.179  1
589224  98.915  -57.380  50.153  1
589225  98.934  -57.385  50.126  1
589226  98.944  -57.389  50.101  1
589227  98.971  -57.397  50.076  1
589228  98.998  -57.404  50.050  1
589229  99.025  -57.412  50.023  1
589230  99.052  -57.421  49.995  1
589231  99.078  -57.433  49.965  1
589232  99.106  -57.446  49.932  1
589233  99.132  -57.459  49.897  1
589234  99.159  -57.471  49.860  1
589235  99.175  -57.479  49.823  1
589236  99.189  -57.485  49.787  1
589237  99.202  -57.492  49.751  1
589238  99.215  -57.499  49.714  1
589239  99.244  -57.504  49.677  1
589240  99.275  -57.508  49.638  1
589241  99.306  -57.514  49.598  1
589242  99.336  -57.518  49.559  1
589243  99.366  -57.523  49.522  1
589244  99.396  -57.529  49.486  1
589245  99.425  -57.536  49.448  1
589246  99.454  -57.541  49.411  1
589247  99.482  -57.547  49.375  1
589248  99.510  -57.552  49.337  1
589249  99.537  -57.558  49.301  1
589250  99.565  -57.563  49.263  1
589251  99.592  -57.568  49.226  1
589252  99.629  -57.574  49.189  1
589253  99.663  -57.583  49.153  1
589254  99.697  -57.592  49.120  1
589255  99.732  -57.601  49.089  1
589256  99.766  -57.610  49.059  1
589257  99.796  -57.625  49.031  1
589258  99.825  -57.642  49.004  1
589259  99.853  -57.660  48.979  1
589260  99.882  -57.677  48.958  1
589261  99.911  -57.694  48.937  1
589262  99.939  -57.711  48.917  1
589263  99.968  -57.728  48.897  1
589264  99.997  -57.746  48.878  1
589607  88.440  -53.818  57.541  4
589608  88.476  -53.833  57.543  4
589609  88.511  -53.848  57.544  4
589610  88.546  -53.864  57.545  4
589611  88.582  -53.879  57.547  4
589612  88.617  -53.894  57.546  4
589613  88.652  -53.910  57.544  4
589614  88.688  -53.925  57.542  4
589615  88.726  -53.944  57.539  4
589616  88.764  -53.964  57.536  4
589617  88.802  -53.983  57.533  4
589618  88.840  -54.002  57.527  4
589619  88.878  -54.022  57.520  4
589620  88.928  -54.041  57.512  4
589621  88.968  -54.064  57.503  4
589622  89.003  -54.088  57.492  4
589623  89.050  -54.098  57.479  4
589624  89.093  -54.110  57.461  4
589625  89.125  -54.132  57.440  4
589626  89.157  -54.155  57.416  4
589627  89.190  -54.177  57.390  4
589628  89.222  -54.200  57.360  4
589629  89.255  -54.222  57.327  4
589630  89.293  -54.239  57.289  4
589631  89.331  -54.255  57.247  4
589632  89.369  -54.273  57.203  4
589633  89.407  -54.289  57.159  4
589634  89.445  -54.306  57.114  4
589635  89.483  -54.323  57.069  4
589636  89.522  -54.339  57.022  4
589637  89.560  -54.356  56.974  4
589638  89.598  -54.373  56.928  4
589647  89.941  -54.524  56.393  1
589648  89.979  -54.541  56.357  1
589649  90.018  -54.562  56.322  1
589650  90.056  -54.585  56.288  1
589651  90.095  -54.608  56.257  1
589652  90.133  -54.631  56.228  1
589653  90.172  -54.655  56.202  1
589654  90.211  -54.678  56.176  1
589655  90.249  -54.702  56.150  1
589656  90.288  -54.725  56.126  1
589657  90.326  -54.749  56.105  1
589658  90.356  -54.766  56.088  1
589659  90.379  -54.781  56.072  1
589660  90.402  -54.794  56.058  1
589661  90.425  -54.809  56.045  1
589662  90.448  -54.823  56.033  1
589663  90.471  -54.837  56.021  1
589664  90.496  -54.851  56.009  1
589665  90.522  -54.865  55.991  1
589666  90.547  -54.878  55.969  1
589667  90.573  -54.892  55.942  1
589668  90.599  -54.906  55.914  1
589669  90.624  -54.919  55.893  1
589670  90.650  -54.933  55.876  1
589671  90.674  -54.948  55.864  1
589672  90.692  -54.966  55.855  1
589673  90.710  -54.984  55.849  1
589674  90.733  -55.001  55.846  1
589675  90.769  -55.016  55.845  1
589676  90.806  -55.032  55.844  1
589677  90.843  -55.047  55.844  1
589678  90.880  -55.062  55.845  1
589679  90.917  -55.078  55.846  1
589680  90.953  -55.093  55.846  1
589681  90.990  -55.108  55.845  1
589682  91.027  -55.123  55.840  1
589683  91.064  -55.138  55.833  1
589684  91.101  -55.154  55.828  1
589685  91.138  -55.169  55.825  1
589686  91.174  -55.185  55.824  1
589687  91.211  -55.200  55.818  1
589688  91.248  -55.215  55.802  1
589689  91.285  -55.231  55.778  1
589690  91.321  -55.246  55.752  1
589691  91.358  -55.261  55.733  1
589692  91.395  -55.276  55.717  1
589693  91.431  -55.292  55.701  1
589694  91.467  -55.304  55.675  1
589695  91.503  -55.314  55.648  1
589696  91.538  -55.326  55.629  1
589697  91.574  -55.336  55.616  1
589698  91.609  -55.347  55.608  1
589699  91.645  -55.358  55.596  1
589700  91.680  -55.369  55.567  1
589701  91.716  -55.379  55.529  1
589702  91.751  -55.390  55.490  1
589703  91.787  -55.401  55.459  1
589704  91.822  -55.412  55.431  1
589705  91.857  -55.423  55.406  1
589706  91.893  -55.433  55.382  1
589707  91.928  -55.444  55.360  1
589708  91.964  -55.455  55.341  1
589709  91.999  -55.466  55.325  1
589710  92.035  -55.477  55.314  1
589711  92.070  -55.490  55.305  1
589712  92.103  -55.507  55.300  1
589713  92.137  -55.524  55.302  1
589714  92.172  -55.540  55.309  1
589715  92.207  -55.557  55.322  1
589716  92.241  -55.574  55.331  1
589717  92.276  -55.590  55.336  1
589718  92.311  -55.607  55.336  1
589719  92.346  -55.624  55.331  1
589720  92.379  -55.641  55.320  1
589721  92.411  -55.661  55.304  1
589722  92.442  -55.680  55.279  1
589723  92.473  -55.699  55.253  1
589724  92.504  -55.719  55.231  1
589725  92.536  -55.738  55.216  1
589726  92.572  -55.758  55.210  1
589727  92.607  -55.777  55.207  1
589728  92.643  -55.796  55.208  1
589729  92.678  -55.815  55.211  1
589730  92.714  -55.835  55.207  1
589731  92.750  -55.854  55.198  1
589732  92.786  -55.874  55.187  1
589733  92.821  -55.893  55.180  1
589734  92.857  -55.912  55.182  1
589735  92.893  -55.931  55.191  1
589736  92.928  -55.951  55.205  1
589737  92.959  -55.969  55.220  1
589738  92.990  -55.987  55.234  1
589739  93.020  -56.006  55.249  1
589740  93.056  -56.027  55.260  1
589741  93.093  -56.036  55.266  1
589742  93.127  -56.038  55.271  1
589743  93.161  -56.041  55.279  1
589744  93.196  -56.044  55.290  1
589745  93.230  -56.047  55.304  1
589746  93.264  -56.049  55.313  1
589747  93.298  -56.051  55.318  1
589748  93.333  -56.054  55.318  1
589749  93.367  -56.056  55.313  1
589750  93.401  -56.059  55.303  1
589751  93.435  -56.062  55.285  1
589752  93.470  -56.065  55.261  1
589753  93.502  -56.076  55.236  1
589754  93.534  -56.098  55.212  1
589755  93.564  -56.121  55.193  1
589756  93.595  -56.143  55.177  1
589757  93.626  -56.165  55.159  1
589758  93.657  -56.188  55.143  1
589759  93.689  -56.208  55.125  1
589760  93.721  -56.225  55.105  1
589761  93.753  -56.242  55.084  1
589762  93.785  -56.259  55.061  1
589763  93.817  -56.276  55.040  1
589764  93.849  -56.293  55.017  1
589765  93.881  -56.310  54.995  1
589766  93.912  -56.326  54.972  1
589767  93.942  -56.342  54.948  1
589768  93.973  -56.357  54.924  1
589769  94.003  -56.373  54.894  1
589770  94.033  -56.389  54.861  1
589771  94.063  -56.404  54.824  1
589772  94.094  -56.420  54.785  1
589773  94.124  -56.436  54.744  1
589774  94.154  -56.451  54.700  1
589775  94.184  -56.467  54.653  1
589776  94.215  -56.483  54.604  1
589777  94.245  -56.498  54.552  1
589778  94.275  -56.514  54.500  1
589779  94.304  -56.526  54.447  1
589780  94.332  -56.535  54.394  1
589781  94.360  -56.544  54.338  1
589782  94.389  -56.553  54.287  1
589783  94.417  -56.562  54.240  1
589784  94.445  -56.571  54.195  1
589785  94.473  -56.580  54.150  1
589786  94.503  -56.589  54.106  1
589787  94.539  -56.599  54.058  1
589788  94.574  -56.608  54.012  1
589789  94.610  -56.618  53.966  1
589790  94.646  -56.627  53.919  1
589791  94.682  -56.637  53.873  1
589792  94.717  -56.646  53.828  1
589793  94.753  -56.656  53.785  1
589794  94.786  -56.668  53.747  1
589795  94.816  -56.683  53.713  1
589796  94.845  -56.697  53.679  1
589797  94.875  -56.712  53.643  1
589798  94.903  -56.726  53.608  1
589799  94.931  -56.739  53.569  1
589800  94.960  -56.752  53.524  1
589801  94.988  -56.765  53.473  1
589802  95.016  -56.777  53.416  1
589803  95.044  -56.790  53.356  1
589804  95.073  -56.802  53.301  1
589805  95.102  -56.813  53.251  1
589806  95.130  -56.824  53.208  1
589807  95.159  -56.836  53.168  1
589808  95.188  -56.846  53.130  1
589809  95.222  -56.858  53.093  1
589810  95.272  -56.860  53.057  1
589811  95.322  -56.857  53.021  1
589812  95.358  -56.862  52.984  1
589813  95.385  -56.871  52.944  1
589814  95.413  -56.881  52.904  1
589815  95.440  -56.890  52.867  1
589816  95.467  -56.899  52.834  1
589817  95.499  -56.909  52.804  1
589818  95.538  -56.917  52.775  1
589819  95.577  -56.925  52.746  1
589820  95.616  -56.934  52.719  1
589821  95.655  -56.943  52.692  1
589822  95.693  -56.951  52.664  1
589823  95.732  -56.959  52.637  1
589824  95.771  -56.968  52.607  1
589825  95.807  -56.975  52.574  1
589826  95.844  -56.982  52.536  1
589827  95.873  -56.989  52.493  1
589828  95.895  -56.996  52.449  1
589829  95.916  -57.003  52.411  1
589830  95.938  -57.009  52.375  1
589831  95.960  -57.015  52.339  1
589832  95.981  -57.022  52.301  1
589833  96.003  -57.029  52.263  1
589834  96.024  -57.036  52.226  1
589835  96.046  -57.043  52.196  1
589836  96.067  -57.050  52.168  1
589837  96.090  -57.059  52.142  1
589838  96.113  -57.069  52.118  1
589839  96.136  -57.079  52.094  1
589840  96.160  -57.089  52.067  1
589841  96.183  -57.099  52.046  1
589842  96.206  -57.109  52.024  1
589843  96.230  -57.118  52.005  1
589844  96.258  -57.123  51.986  1
589845  96.286  -57.127  51.967  1
589846  96.313  -57.130  51.945  1
589847  96.341  -57.134  51.930  1
589848  96.369  -57.138  51.917  1
589849  96.397  -57.141  51.904  1
589850  96.425  -57.144  51.888  1
589851  96.454  -57.147  51.869  1
589852  96.482  -57.150  51.847  1
589853  96.511  -57.153  51.823  1
589854  96.540  -57.156  51.799  1
589855  96.569  -57.159  51.776  1
589856  96.597  -57.160  51.750  1
589857  96.629  -57.166  51.721  1
589858  96.661  -57.174  51.688  1
589859  96.694  -57.180  51.659  1
589860  96.726  -57.187  51.633  1
589861  96.758  -57.194  51.612  1
589862  96.791  -57.200  51.595  1
589863  96.823  -57.206  51.579  1
589864  96.856  -57.213  51.562  1
589865  96.888  -57.219  51.548  1
589866  96.920  -57.226  51.535  1
589867  96.953  -57.233  51.523  1
589868  96.985  -57.239  51.511  1
589869  97.017  -57.230  51.501  1
589870  97.050  -57.222  51.495  1
589871  97.082  -57.213  51.493  1
589872  97.115  -57.203  51.485  1
589873  97.147  -57.194  51.473  1
589874  97.180  -57.186  51.461  1
589875  97.213  -57.177  51.453  1
589876  97.247  -57.171  51.449  1
589877  97.284  -57.169  51.446  1
589878  97.321  -57.167  51.442  1
589879  97.358  -57.165  51.438  1
589880  97.393  -57.163  51.429  1
589881  97.421  -57.159  51.417  1
589882  97.448  -57.156  51.400  1
589883  97.475  -57.153  51.378  1
589884  97.502  -57.150  51.354  1
589885  97.533  -57.156  51.329  1
589886  97.567  -57.167  51.302  1
589887  97.597  -57.175  51.274  1
589888  97.628  -57.182  51.244  1
589889  97.658  -57.189  51.210  1
589890  97.689  -57.197  51.175  1
589891  97.719  -57.203  51.140  1
589892  97.750  -57.211  51.104  1
589893  97.781  -57.219  51.067  1
589894  97.811  -57.225  51.030  1
589895  97.842  -57.233  50.996  1
589896  97.875  -57.247  50.963  1
589897  97.908  -57.262  50.931  1
589898  97.942  -57.271  50.900  1
589899  97.976  -57.279  50.871  1
589900  98.010  -57.288  50.845  1
589901  98.045  -57.291  50.816  1
589902  98.081  -57.294  50.791  1
589903  98.116  -57.296  50.766  1
589904  98.152  -57.297  50.741  1
589905  98.187  -57.300  50.716  1
589906  98.222  -57.302  50.690  1
589907  98.258  -57.304  50.661  1
589908  98.293  -57.308  50.631  1
589909  98.329  -57.312  50.599  1
589910  98.365  -57.316  50.568  1
589911  98.401  -57.320  50.535  1
589912  98.436  -57.325  50.504  1
589913  98.472  -57.329  50.473  1
589914  98.508  -57.333  50.442  1
589915  98.544  -57.337  50.412  1
589916  98.580  -57.341  50.381  1
589917  98.625  -57.344  50.351  1
589918  98.663  -57.342  50.322  1
589919  98.693  -57.336  50.295  1
589920  98.728  -57.336  50.272  1
589921  98.766  -57.339  50.249  1
589922  98.804  -57.342  50.226  1
589923  98.842  -57.346  50.201  1
589924  98.880  -57.351  50.176  1
589925  98.918  -57.354  50.149  1
589926  98.945  -57.359  50.123  1
589927  98.952  -57.363  50.098  1
589928  98.961  -57.368  50.074  1
589929  98.989  -57.376  50.050  1
589930  99.015  -57.383  50.023  1
589931  99.042  -57.395  49.996  1
589932  99.069  -57.408  49.965  1
589933  99.096  -57.421  49.931  1
589934  99.123  -57.433  49.895  1
589935  99.149  -57.446  49.859  1
589936  99.170  -57.456  49.821  1
589937  99.184  -57.463  49.785  1
589938  99.197  -57.470  49.748  1
589939  99.215  -57.476  49.710  1
589940  99.245  -57.480  49.673  1
589941  99.276  -57.485  49.634  1
589942  99.307  -57.489  49.594  1
589943  99.338  -57.494  49.556  1
589944  99.368  -57.499  49.519  1
589945  99.399  -57.504  49.483  1
589946  99.428  -57.509  49.447  1
589947  99.457  -57.515  49.410  1
589948  99.485  -57.520  49.373  1
589949  99.513  -57.526  49.337  1
589950  99.540  -57.532  49.301  1
589951  99.568  -57.537  49.264  1
589952  99.595  -57.542  49.228  1
589953  99.623  -57.548  49.192  1
589954  99.652  -57.560  49.155  1
589955  99.681  -57.577  49.120  1
589956  99.710  -57.595  49.087  1
589957  99.738  -57.611  49.057  1
589958  99.767  -57.629  49.029  1
589959  99.795  -57.646  49.001  1
589960  99.824  -57.663  48.976  1
589961  99.853  -57.680  48.954  1
589962  99.881  -57.698  48.933  1
589963  99.910  -57.714  48.913  1
589964  99.939  -57.732  48.893  1
589965  99.968  -57.749  48.874  1
590308  88.465  -53.783  57.535  4
590309  88.500  -53.798  57.537  4
590310  88.536  -53.813  57.538  4
590311  88.571  -53.828  57.539  4
590312  88.607  -53.844  57.539  4
590313  88.642  -53.860  57.538  4
590314  88.678  -53.875  57.536  4
590315  88.715  -53.894  57.535  4
590316  88.754  -53.914  57.532  4
590317  88.791  -53.933  57.528  4
590318  88.830  -53.953  57.524  4
590319  88.868  -53.972  57.518  4
590320  88.906  -53.991  57.510  4
590321  88.957  -54.011  57.502  4
590322  88.999  -54.033  57.492  4
590323  89.034  -54.057  57.481  4
590324  89.083  -54.064  57.468  4
590325  89.141  -54.061  57.450  4
590326  89.173  -54.083  57.431  4
590327  89.205  -54.106  57.409  4
590328  89.238  -54.129  57.383  4
590329  89.270  -54.151  57.355  4
590330  89.302  -54.173  57.323  4
590331  89.334  -54.196  57.286  4
590332  89.367  -54.219  57.246  4
590333  89.399  -54.241  57.203  4
590334  89.431  -54.264  57.159  4
590335  89.467  -54.283  57.115  4
590336  89.506  -54.299  57.070  4
590337  89.543  -54.316  57.023  4
590338  89.582  -54.333  56.976  4
590339  89.620  -54.350  56.930  4
590347  89.924  -54.484  56.433  1
590348  89.963  -54.501  56.397  1
590349  90.001  -54.518  56.361  1
590350  90.039  -54.535  56.327  1
590351  90.077  -54.553  56.295  1
590352  90.116  -54.576  56.264  1
590353  90.155  -54.599  56.235  1
590354  90.193  -54.623  56.209  1
590355  90.232  -54.646  56.183  1
590356  90.270  -54.670  56.158  1
590357  90.309  -54.693  56.136  1
590358  90.347  -54.717  56.116  1
590359  90.374  -54.733  56.102  1
590360  90.398  -54.747  56.088  1
590361  90.421  -54.762  56.075  1
590362  90.444  -54.775  56.064  1
590363  90.467  -54.790  56.051  1
590364  90.493  -54.803  56.038  1
590365  90.518  -54.817  56.023  1
590366  90.544  -54.831  56.002  1
590367  90.570  -54.844  55.976  1
590368  90.595  -54.858  55.948  1
590369  90.621  -54.872  55.920  1
590370  90.642  -54.888  55.899  1
590371  90.660  -54.906  55.881  1
590372  90.678  -54.924  55.868  1
590373  90.696  -54.941  55.859  1
590374  90.715  -54.960  55.852  1
590375  90.741  -54.976  55.848  1
590376  90.778  -54.991  55.846  1
590377  90.815  -55.007  55.844  1
590378  90.852  -55.022  55.844  1
590379  90.888  -55.038  55.845  1
590380  90.925  -55.053  55.843  1
590381  90.962  -55.068  55.839  1
590382  90.999  -55.083  55.834  1
590383  91.036  -55.098  55.827  1
590384  91.073  -55.114  55.819  1
590385  91.109  -55.129  55.812  1
590386  91.146  -55.144  55.809  1
590387  91.183  -55.160  55.808  1
590388  91.220  -55.175  55.799  1
590389  91.256  -55.191  55.782  1
590390  91.293  -55.206  55.757  1
590391  91.330  -55.221  55.730  1
590392  91.367  -55.236  55.710  1
590393  91.404  -55.251  55.696  1
590394  91.447  -55.260  55.681  1
590395  91.480  -55.264  55.656  1
590396  91.515  -55.275  55.631  1
590397  91.551  -55.286  55.613  1
590398  91.586  -55.297  55.601  1
590399  91.622  -55.307  55.594  1
590400  91.657  -55.318  55.581  1
590401  91.693  -55.329  55.553  1
590402  91.728  -55.340  55.515  1
590403  91.764  -55.351  55.477  1
590404  91.799  -55.361  55.447  1
590405  91.835  -55.373  55.420  1
590406  91.870  -55.383  55.396  1
590407  91.906  -55.394  55.374  1
590408  91.941  -55.405  55.353  1
590409  91.977  -55.416  55.336  1
590410  92.012  -55.426  55.321  1
590411  92.047  -55.439  55.311  1
590412  92.081  -55.456  55.304  1
590413  92.115  -55.473  55.302  1
590414  92.148  -55.489  55.306  1
590415  92.182  -55.506  55.316  1
590416  92.217  -55.524  55.332  1
590417  92.252  -55.540  55.341  1
590418  92.287  -55.557  55.349  1
590419  92.321  -55.574  55.353  1
590420  92.356  -55.590  55.352  1
590421  92.396  -55.605  55.345  1
590422  92.431  -55.623  55.332  1
590423  92.462  -55.643  55.310  1
590424  92.493  -55.662  55.282  1
590425  92.524  -55.681  55.259  1
590426  92.559  -55.701  55.242  1
590427  92.595  -55.720  55.233  1
590428  92.630  -55.740  55.234  1
590429  92.666  -55.759  55.237  1
590430  92.702  -55.778  55.235  1
590431  92.737  -55.797  55.230  1
590432  92.773  -55.817  55.220  1
590433  92.809  -55.836  55.206  1
590434  92.843  -55.855  55.195  1
590435  92.873  -55.873  55.191  1
590436  92.904  -55.891  55.192  1
590437  92.934  -55.909  55.201  1
590438  92.964  -55.928  55.215  1
590439  92.994  -55.946  55.229  1
590440  93.029  -55.966  55.245  1
590441  93.066  -55.987  55.259  1
590442  93.103  -56.006  55.268  1
590443  93.139  -56.005  55.275  1
590444  93.173  -56.008  55.281  1
590445  93.207  -56.010  55.290  1
590446  93.241  -56.013  55.303  1
590447  93.276  -56.016  55.313  1
590448  93.310  -56.019  55.319  1
590449  93.344  -56.021  55.318  1
590450  93.379  -56.024  55.312  1
590451  93.413  -56.026  55.299  1
590452  93.447  -56.028  55.282  1
590453  93.482  -56.031  55.260  1
590454  93.514  -56.043  55.238  1
590455  93.545  -56.065  55.218  1
590456  93.576  -56.088  55.200  1
590457  93.607  -56.110  55.184  1
590458  93.638  -56.132  55.163  1
590459  93.670  -56.154  55.142  1
590460  93.700  -56.176  55.121  1
590461  93.731  -56.198  55.104  1
590462  93.763  -56.219  55.088  1
590463  93.795  -56.235  55.073  1
590464  93.827  -56.252  55.056  1
590465  93.859  -56.269  55.037  1
590466  93.890  -56.285  55.016  1
590467  93.920  -56.301  54.994  1
590468  93.950  -56.317  54.971  1
590469  93.980  -56.332  54.947  1
590470  94.011  -56.348  54.917  1
590471  94.041  -56.364  54.885  1
590472  94.071  -56.379  54.849  1
590473  94.102  -56.395  54.810  1
590474  94.132  -56.411  54.768  1
590475  94.162  -56.426  54.724  1
590476  94.192  -56.442  54.675  1
590477  94.222  -56.458  54.625  1
590478  94.253  -56.473  54.573  1
590479  94.283  -56.489  54.519  1
590480  94.312  -56.500  54.464  1
590481  94.340  -56.509  54.407  1
590482  94.368  -56.518  54.349  1
590483  94.396  -56.527  54.296  1
590484  94.424  -56.536  54.246  1
590485  94.453  -56.545  54.199  1
590486  94.480  -56.553  54.154  1
590487  94.508  -56.561  54.108  1
590488  94.544  -56.571  54.057  1
590489  94.579  -56.582  54.005  1
590490  94.615  -56.592  53.955  1
590491  94.650  -56.602  53.905  1
590492  94.686  -56.611  53.857  1
590493  94.722  -56.620  53.810  1
590494  94.758  -56.630  53.766  1
590495  94.793  -56.640  53.727  1
590496  94.827  -56.652  53.692  1
590497  94.856  -56.666  53.658  1
590498  94.885  -56.680  53.622  1
590499  94.913  -56.693  53.588  1
590500  94.941  -56.705  53.552  1
590501  94.970  -56.717  53.509  1
590502  94.998  -56.727  53.460  1
590503  95.027  -56.739  53.406  1
590504  95.056  -56.750  53.348  1
590505  95.085  -56.762  53.286  1
590506  95.113  -56.772  53.230  1
590507  95.142  -56.783  53.181  1
590508  95.171  -56.795  53.137  1
590509  95.199  -56.806  53.096  1
590510  95.236  -56.817  53.059  1
590511  95.284  -56.825  53.024  1
590512  95.335  -56.822  52.988  1
590513  95.367  -56.830  52.951  1
590514  95.394  -56.839  52.912  1
590515  95.421  -56.849  52.873  1
590516  95.449  -56.858  52.835  1
590517  95.476  -56.868  52.802  1
590518  95.503  -56.877  52.772  1
590519  95.542  -56.886  52.743  1
590520  95.581  -56.894  52.714  1
590521  95.619  -56.903  52.686  1
590522  95.659  -56.911  52.658  1
590523  95.697  -56.919  52.629  1
590524  95.736  -56.928  52.601  1
590525  95.774  -56.936  52.571  1
590526  95.810  -56.943  52.537  1
590527  95.847  -56.950  52.500  1
590528  95.877  -56.957  52.459  1
590529  95.898  -56.963  52.417  1
590530  95.920  -56.970  52.379  1
590531  95.942  -56.977  52.344  1
590532  95.963  -56.984  52.308  1
590533  95.985  -56.990  52.271  1
590534  96.007  -56.997  52.232  1
590535  96.028  -57.004  52.193  1
590536  96.049  -57.011  52.160  1
590537  96.072  -57.019  52.131  1
590538  96.095  -57.029  52.105  1
590539  96.118  -57.040  52.080  1
590540  96.141  -57.050  52.056  1
590541  96.164  -57.059  52.031  1
590542  96.187  -57.069  52.011  1
590543  96.210  -57.079  51.993  1
590544  96.233  -57.089  51.975  1
590545  96.261  -57.093  51.955  1
590546  96.289  -57.097  51.933  1
590547  96.317  -57.100  51.913  1
590548  96.344  -57.103  51.898  1
590549  96.373  -57.107  51.886  1
590550  96.400  -57.111  51.874  1
590551  96.429  -57.114  51.861  1
590552  96.457  -57.118  51.844  1
590553  96.485  -57.120  51.823  1
590554  96.514  -57.123  51.800  1
590555  96.542  -57.123  51.778  1
590556  96.571  -57.124  51.755  1
590557  96.599  -57.125  51.728  1
590558  96.627  -57.125  51.697  1
590559  96.661  -57.135  51.663  1
590560  96.694  -57.144  51.631  1
590561  96.727  -57.153  51.603  1
590562  96.760  -57.163  51.579  1
590563  96.793  -57.170  51.559  1
590564  96.825  -57.176  51.542  1
590565  96.857  -57.183  51.522  1
590566  96.889  -57.190  51.504  1
590567  96.922  -57.196  51.491  1
590568  96.954  -57.203  51.478  1
590569  96.986  -57.210  51.466  1
590570  97.019  -57.202  51.457  1
590571  97.051  -57.193  51.452  1
590572  97.084  -57.184  51.449  1
590573  97.116  -57.175  51.442  1
590574  97.149  -57.166  51.430  1
590575  97.181  -57.157  51.419  1
590576  97.214  -57.149  51.411  1
590577  97.246  -57.140  51.409  1
590578  97.279  -57.131  51.405  1
590579  97.316  -57.128  51.400  1
590580  97.353  -57.126  51.394  1
590581  97.390  -57.124  51.384  1
590582  97.423  -57.122  51.370  1
590583  97.450  -57.119  51.353  1
590584  97.478  -57.115  51.332  1
590585  97.505  -57.112  51.310  1
590586  97.536  -57.116  51.286  1
590587  97.569  -57.128  51.260  1
590588  97.599  -57.135  51.232  1
590589  97.630  -57.142  51.202  1
590590  97.660  -57.150  51.170  1
590591  97.690  -57.157  51.137  1
590592  97.721  -57.164  51.103  1
590593  97.752  -57.172  51.069  1
590594  97.782  -57.178  51.035  1
590595  97.814  -57.190  51.002  1
590596  97.848  -57.204  50.969  1
590597  97.881  -57.219  50.938  1
590598  97.915  -57.231  50.907  1
590599  97.949  -57.239  50.877  1
590600  97.983  -57.247  50.847  1
590601  98.017  -57.257  50.821  1
590602  98.051  -57.265  50.793  1
590603  98.086  -57.267  50.769  1
590604  98.122  -57.269  50.745  1
590605  98.157  -57.272  50.720  1
590606  98.193  -57.274  50.695  1
590607  98.228  -57.276  50.671  1
590608  98.264  -57.278  50.645  1
590609  98.299  -57.280  50.616  1
590610  98.334  -57.282  50.586  1
590611  98.369  -57.285  50.555  1
590612  98.405  -57.287  50.524  1
590613  98.440  -57.290  50.492  1
590614  98.476  -57.294  50.461  1
590615  98.512  -57.298  50.429  1
590616  98.548  -57.302  50.399  1
590617  98.583  -57.307  50.369  1
590618  98.620  -57.310  50.339  1
590619  98.663  -57.313  50.312  1
590620  98.694  -57.307  50.287  1
590621  98.731  -57.309  50.263  1
590622  98.769  -57.313  50.241  1
590623  98.807  -57.316  50.219  1
590624  98.845  -57.321  50.194  1
590625  98.883  -57.325  50.169  1
590626  98.921  -57.329  50.143  1
590627  98.955  -57.333  50.118  1
590628  98.963  -57.338  50.093  1
590629  98.971  -57.342  50.070  1
590630  98.979  -57.347  50.047  1
590631  99.006  -57.357  50.020  1
590632  99.033  -57.370  49.992  1
590633  99.060  -57.383  49.960  1
590634  99.086  -57.395  49.925  1
590635  99.113  -57.408  49.889  1
590636  99.140  -57.420  49.854  1
590637  99.166  -57.432  49.817  1
590638  99.179  -57.439  49.780  1
590639  99.192  -57.446  49.742  1
590640  99.216  -57.451  49.704  1
590641  99.246  -57.456  49.666  1
590642  99.277  -57.461  49.626  1
590643  99.308  -57.466  49.586  1
590644  99.339  -57.470  49.547  1
590645  99.369  -57.475  49.510  1
590646  99.400  -57.479  49.475  1
590647  99.430  -57.485  49.441  1
590648  99.461  -57.489  49.406  1
590649  99.489  -57.495  49.370  1
590650  99.516  -57.501  49.335  1
590651  99.544  -57.508  49.300  1
590652  99.572  -57.514  49.264  1
590653  99.600  -57.520  49.228  1
590654  99.627  -57.526  49.192  1
590655  99.655  -57.539  49.154  1
590656  99.683  -57.557  49.119  1
590657  99.710  -57.575  49.085  1
590658  99.738  -57.592  49.055  1
590659  99.766  -57.611  49.025  1
590660  99.794  -57.629  48.997  1
590661  99.822  -57.646  48.972  1
590662  99.849  -57.664  48.949  1
590663  99.877  -57.682  48.927  1
590664  99.905  -57.700  48.907  1
590665  99.932  -57.718  48.887  1
590666  99.961  -57.736  48.868  1
591009  88.490  -53.748  57.529  4
591010  88.525  -53.763  57.531  4
591011  88.560  -53.778  57.531  4
591012  88.596  -53.794  57.532  4
591013  88.631  -53.809  57.532  4
591014  88.667  -53.825  57.530  4
591015  88.705  -53.844  57.529  4
591016  88.743  -53.864  57.527  4
591017  88.781  -53.883  57.524  4
591018  88.819  -53.903  57.520  4
591019  88.857  -53.922  57.516  4
591020  88.895  -53.941  57.509  4
591021  88.934  -53.960  57.501  4
591022  88.985  -53.980  57.493  4
591023  89.030  -54.002  57.483  4
591024  89.065  -54.026  57.471  4
591025  89.117  -54.030  57.458  4
591026  89.176  -54.025  57.441  4
591027  89.221  -54.035  57.421  4
591028  89.253  -54.057  57.400  4
591029  89.285  -54.079  57.376  4
591030  89.318  -54.102  57.349  4
591031  89.350  -54.125  57.319  4
591032  89.383  -54.147  57.283  4
591033  89.415  -54.170  57.244  4
591034  89.447  -54.192  57.202  4
591035  89.479  -54.214  57.160  4
591036  89.512  -54.237  57.116  4
591037  89.544  -54.260  57.071  4
591038  89.577  -54.283  57.025  4
591039  89.609  -54.305  56.978  4
591040  89.641  -54.327  56.932  4
591048  89.947  -54.461  56.437  1
591049  89.985  -54.478  56.401  1
591050  90.023  -54.495  56.366  1
591051  90.061  -54.511  56.332  1
591052  90.099  -54.528  56.300  1
591053  90.138  -54.545  56.270  1
591054  90.176  -54.568  56.242  1
591055  90.215  -54.591  56.216  1
591056  90.253  -54.615  56.190  1
591057  90.292  -54.638  56.166  1
591058  90.330  -54.662  56.144  1
591059  90.369  -54.685  56.127  1
591060  90.393  -54.699  56.114  1
591061  90.416  -54.714  56.102  1
591062  90.440  -54.728  56.090  1
591063  90.463  -54.742  56.079  1
591064  90.488  -54.756  56.067  1
591065  90.514  -54.770  56.053  1
591066  90.540  -54.784  56.034  1
591067  90.566  -54.797  56.010  1
591068  90.591  -54.811  55.982  1
591069  90.610  -54.828  55.953  1
591070  90.628  -54.846  55.925  1
591071  90.647  -54.864  55.904  1
591072  90.665  -54.881  55.887  1
591073  90.683  -54.900  55.873  1
591074  90.701  -54.917  55.863  1
591075  90.719  -54.935  55.856  1
591076  90.750  -54.951  55.851  1
591077  90.787  -54.966  55.848  1
591078  90.823  -54.981  55.844  1
591079  90.861  -54.997  55.841  1
591080  90.897  -55.013  55.839  1
591081  90.934  -55.028  55.837  1
591082  90.971  -55.043  55.831  1
591083  91.008  -55.058  55.823  1
591084  91.044  -55.074  55.814  1
591085  91.081  -55.089  55.804  1
591086  91.118  -55.104  55.796  1
591087  91.155  -55.119  55.792  1
591088  91.191  -55.135  55.788  1
591089  91.228  -55.151  55.778  1
591090  91.265  -55.166  55.761  1
591091  91.302  -55.181  55.737  1
591092  91.339  -55.195  55.710  1
591093  91.376  -55.208  55.689  1
591094  91.413  -55.222  55.675  1
591095  91.464  -55.228  55.659  1
591096  91.498  -55.232  55.636  1
591097  91.528  -55.235  55.614  1
591098  91.564  -55.247  55.597  1
591099  91.599  -55.257  55.588  1
591100  91.635  -55.268  55.582  1
591101  91.670  -55.279  55.568  1
591102  91.705  -55.290  55.540  1
591103  91.741  -55.301  55.502  1
591104  91.776  -55.311  55.465  1
591105  91.812  -55.322  55.438  1
591106  91.847  -55.333  55.413  1
591107  91.883  -55.344  55.390  1
591108  91.918  -55.354  55.369  1
591109  91.954  -55.365  55.349  1
591110  91.989  -55.376  55.332  1
591111  92.024  -55.389  55.319  1
591112  92.058  -55.405  55.310  1
591113  92.092  -55.422  55.304  1
591114  92.125  -55.439  55.305  1
591115  92.159  -55.456  55.311  1
591116  92.194  -55.473  55.324  1
591117  92.228  -55.489  55.340  1
591118  92.263  -55.506  55.349  1
591119  92.298  -55.523  55.359  1
591120  92.333  -55.539  55.366  1
591121  92.370  -55.555  55.369  1
591122  92.411  -55.571  55.365  1
591123  92.451  -55.586  55.354  1
591124  92.482  -55.605  55.335  1
591125  92.513  -55.624  55.311  1
591126  92.547  -55.644  55.287  1
591127  92.582  -55.663  55.268  1
591128  92.618  -55.683  55.253  1
591129  92.653  -55.702  55.253  1
591130  92.689  -55.721  55.258  1
591131  92.725  -55.740  55.259  1
591132  92.757  -55.759  55.256  1
591133  92.787  -55.777  55.250  1
591134  92.817  -55.795  55.237  1
591135  92.848  -55.813  55.223  1
591136  92.878  -55.831  55.207  1
591137  92.908  -55.850  55.200  1
591138  92.938  -55.868  55.203  1
591139  92.969  -55.886  55.212  1
591140  93.002  -55.906  55.227  1
591141  93.040  -55.927  55.240  1
591142  93.076  -55.949  55.254  1
591143  93.114  -55.970  55.267  1
591144  93.150  -55.975  55.277  1
591145  93.185  -55.975  55.284  1
591146  93.219  -55.978  55.291  1
591147  93.254  -55.980  55.301  1
591148  93.288  -55.983  55.312  1
591149  93.322  -55.985  55.317  1
591150  93.356  -55.987  55.316  1
591151  93.391  -55.991  55.310  1
591152  93.425  -55.993  55.298  1
591153  93.459  -55.996  55.284  1
591154  93.493  -55.998  55.266  1
591155  93.526  -56.009  55.248  1
591156  93.557  -56.031  55.230  1
591157  93.588  -56.054  55.214  1
591158  93.619  -56.076  55.197  1
591159  93.650  -56.098  55.175  1
591160  93.681  -56.121  55.153  1
591161  93.712  -56.143  55.133  1
591162  93.743  -56.165  55.117  1
591163  93.774  -56.188  55.104  1
591164  93.805  -56.210  55.091  1
591165  93.837  -56.229  55.072  1
591166  93.867  -56.245  55.055  1
591167  93.898  -56.260  55.035  1
591168  93.928  -56.276  55.013  1
591169  93.958  -56.292  54.990  1
591170  93.988  -56.307  54.964  1
591171  94.018  -56.323  54.938  1
591172  94.049  -56.339  54.904  1
591173  94.079  -56.355  54.868  1
591174  94.110  -56.370  54.831  1
591175  94.140  -56.386  54.791  1
591176  94.170  -56.402  54.749  1
591177  94.200  -56.418  54.698  1
591178  94.230  -56.433  54.649  1
591179  94.261  -56.449  54.598  1
591180  94.291  -56.465  54.543  1
591181  94.319  -56.474  54.487  1
591182  94.347  -56.483  54.428  1
591183  94.376  -56.491  54.368  1
591184  94.403  -56.498  54.312  1
591185  94.431  -56.507  54.258  1
591186  94.459  -56.514  54.208  1
591187  94.486  -56.522  54.161  1
591188  94.514  -56.530  54.113  1
591189  94.550  -56.540  54.059  1
591190  94.585  -56.550  54.003  1
591191  94.621  -56.561  53.949  1
591192  94.657  -56.570  53.897  1
591193  94.692  -56.581  53.847  1
591194  94.728  -56.591  53.796  1
591195  94.763  -56.602  53.750  1
591196  94.799  -56.612  53.709  1
591197  94.834  -56.622  53.672  1
591198  94.867  -56.628  53.635  1
591199  94.895  -56.642  53.599  1
591200  94.924  -56.653  53.563  1
591201  94.953  -56.664  53.527  1
591202  94.981  -56.676  53.487  1
591203  95.010  -56.687  53.441  1
591204  95.039  -56.698  53.390  1
591205  95.067  -56.709  53.335  1
591206  95.096  -56.721  53.277  1
591207  95.125  -56.732  53.216  1
591208  95.154  -56.743  53.161  1
591209  95.182  -56.754  53.112  1
591210  95.211  -56.765  53.067  1
591211  95.251  -56.777  53.025  1
591212  95.298  -56.787  52.989  1
591213  95.348  -56.788  52.953  1
591214  95.376  -56.797  52.917  1
591215  95.403  -56.807  52.879  1
591216  95.430  -56.816  52.841  1
591217  95.458  -56.826  52.801  1
591218  95.485  -56.835  52.765  1
591219  95.513  -56.845  52.736  1
591220  95.546  -56.854  52.707  1
591221  95.585  -56.862  52.678  1
591222  95.623  -56.871  52.648  1
591223  95.662  -56.879  52.620  1
591224  95.701  -56.887  52.590  1
591225  95.740  -56.896  52.561  1
591226  95.777  -56.903  52.530  1
591227  95.814  -56.911  52.497  1
591228  95.850  -56.918  52.461  1
591229  95.880  -56.924  52.423  1
591230  95.902  -56.931  52.383  1
591231  95.923  -56.938  52.347  1
591232  95.945  -56.945  52.311  1
591233  95.967  -56.952  52.276  1
591234  95.988  -56.959  52.239  1
591235  96.010  -56.965  52.199  1
591236  96.032  -56.972  52.159  1
591237  96.053  -56.980  52.125  1
591238  96.077  -56.990  52.095  1
591239  96.100  -57.000  52.068  1
591240  96.123  -57.010  52.043  1
591241  96.146  -57.020  52.019  1
591242  96.169  -57.030  51.996  1
591243  96.192  -57.040  51.976  1
591244  96.213  -57.049  51.960  1
591245  96.236  -57.058  51.941  1
591246  96.264  -57.063  51.921  1
591247  96.292  -57.067  51.900  1
591248  96.320  -57.070  51.880  1
591249  96.347  -57.074  51.866  1
591250  96.376  -57.078  51.855  1
591251  96.403  -57.081  51.844  1
591252  96.432  -57.084  51.831  1
591253  96.459  -57.087  51.816  1
591254  96.488  -57.087  51.795  1
591255  96.516  -57.087  51.774  1
591256  96.544  -57.088  51.751  1
591257  96.573  -57.089  51.725  1
591258  96.601  -57.090  51.697  1
591259  96.629  -57.091  51.667  1
591260  96.660  -57.094  51.634  1
591261  96.693  -57.103  51.604  1
591262  96.726  -57.113  51.577  1
591263  96.759  -57.122  51.553  1
591264  96.792  -57.131  51.530  1
591265  96.825  -57.141  51.510  1
591266  96.858  -57.150  51.490  1
591267  96.891  -57.160  51.472  1
591268  96.924  -57.166  51.454  1
591269  96.956  -57.172  51.438  1
591270  96.989  -57.179  51.425  1
591271  97.021  -57.173  51.415  1
591272  97.053  -57.164  51.410  1
591273  97.086  -57.156  51.405  1
591274  97.118  -57.147  51.398  1
591275  97.151  -57.138  51.388  1
591276  97.183  -57.129  51.377  1
591277  97.216  -57.120  51.371  1
591278  97.248  -57.111  51.370  1
591279  97.281  -57.103  51.364  1
591280  97.313  -57.094  51.358  1
591281  97.348  -57.088  51.350  1
591282  97.385  -57.086  51.339  1
591283  97.422  -57.084  51.324  1
591284  97.453  -57.081  51.305  1
591285  97.480  -57.078  51.286  1
591286  97.508  -57.075  51.266  1
591287  97.538  -57.078  51.244  1
591288  97.570  -57.088  51.219  1
591289  97.601  -57.095  51.192  1
591290  97.632  -57.103  51.163  1
591291  97.662  -57.110  51.132  1
591292  97.692  -57.117  51.100  1
591293  97.723  -57.125  51.067  1
591294  97.754  -57.133  51.036  1
591295  97.787  -57.147  51.006  1
591296  97.821  -57.162  50.975  1
591297  97.854  -57.176  50.943  1
591298  97.887  -57.191  50.912  1
591299  97.922  -57.199  50.883  1
591300  97.956  -57.207  50.854  1
591301  97.990  -57.216  50.824  1
591302  98.024  -57.225  50.798  1
591303  98.058  -57.233  50.771  1
591304  98.092  -57.241  50.747  1
591305  98.127  -57.243  50.724  1
591306  98.163  -57.245  50.699  1
591307  98.198  -57.247  50.674  1
591308  98.233  -57.250  50.652  1
591309  98.269  -57.252  50.628  1
591310  98.304  -57.254  50.600  1
591311  98.340  -57.257  50.571  1
591312  98.375  -57.258  50.541  1
591313  98.411  -57.260  50.511  1
591314  98.446  -57.263  50.480  1
591315  98.481  -57.265  50.448  1
591316  98.517  -57.267  50.415  1
591317  98.552  -57.269  50.385  1
591318  98.587  -57.272  50.355  1
591319  98.623  -57.275  50.327  1
591320  98.659  -57.280  50.302  1
591321  98.696  -57.279  50.278  1
591322  98.734  -57.283  50.254  1
591323  98.772  -57.287  50.232  1
591324  98.810  -57.291  50.210  1
591325  98.848  -57.295  50.187  1
591326  98.886  -57.299  50.162  1
591327  98.924  -57.304  50.136  1
591328  98.962  -57.307  50.111  1
591329  98.973  -57.312  50.087  1
591330  98.981  -57.316  50.064  1
591331  98.992  -57.322  50.040  1
591332  99.008  -57.334  50.014  1
591333  99.024  -57.345  49.985  1
591334  99.050  -57.357  49.952  1
591335  99.077  -57.370  49.918  1
591336  99.104  -57.382  49.882  1
591337  99.131  -57.395  49.847  1
591338  99.157  -57.408  49.811  1
591339  99.174  -57.416  49.773  1
591340  99.188  -57.423  49.735  1
591341  99.217  -57.428  49.696  1
591342  99.248  -57.432  49.656  1
591343  99.278  -57.437  49.616  1
591344  99.309  -57.442  49.576  1
591345  99.340  -57.447  49.538  1
591346  99.370  -57.451  49.501  1
591347  99.403  -57.454  49.466  1
591348  99.436  -57.457  49.433  1
591349  99.469  -57.460  49.400  1
591350  99.494  -57.472  49.365  1
591351  99.521  -57.481  49.330  1
591352  99.549  -57.487  49.297  1
591353  99.576  -57.493  49.262  1
591354  99.604  -57.499  49.226  1
591355  99.632  -57.505  49.189  1
591356  99.659  -57.517  49.152  1
591357  99.687  -57.534  49.116  1
591358  99.715  -57.552  49.082  1
591359  99.743  -57.570  49.051  1
591360  99.771  -57.588  49.021  1
591361  99.798  -57.606  48.992  1
591362  99.826  -57.623  48.966  1
591363  99.854  -57.642  48.943  1
591364  99.882  -57.659  48.921  1
591365  99.910  -57.677  48.900  1
591366  99.937  -57.695  48.880  1
591367  99.965  -57.713  48.861  1
591710  88.515  -53.712  57.523  4
591711  88.550  -53.728  57.524  4
591712  88.585  -53.744  57.525  4
591713  88.620  -53.759  57.525  4
591714  88.657  -53.775  57.524  4
591715  88.695  -53.794  57.523  4
591716  88.733  -53.814  57.521  4
591717  88.771  -53.833  57.518  4
591718  88.809  -53.853  57.515  4
591719  88.847  -53.872  57.511  4
591720  88.885  -53.891  57.507  4
591721  88.923  -53.910  57.501  4
591722  88.963  -53.930  57.492  4
591723  89.014  -53.950  57.484  4
591724  89.061  -53.971  57.473  4
591725  89.096  -53.994  57.461  4
591726  89.150  -53.996  57.448  4
591727  89.209  -53.991  57.431  4
591728  89.248  -54.005  57.413  4
591729  89.283  -54.024  57.393  4
591730  89.320  -54.044  57.369  4
591731  89.355  -54.063  57.344  4
591732  89.392  -54.082  57.314  4
591733  89.427  -54.101  57.280  4
591734  89.463  -54.121  57.242  4
591735  89.495  -54.143  57.202  4
591736  89.528  -54.166  57.160  4
591737  89.560  -54.189  57.116  4
591738  89.592  -54.211  57.071  4
591739  89.624  -54.233  57.026  4
591740  89.657  -54.256  56.980  4
591741  89.689  -54.278  56.934  4
591742  89.722  -54.301  56.889  4
591748  89.931  -54.421  56.478  1
591749  89.968  -54.438  56.441  1
591750  90.007  -54.455  56.405  1
591751  90.045  -54.471  56.371  1
591752  90.083  -54.488  56.336  1
591753  90.121  -54.505  56.304  1
591754  90.159  -54.522  56.275  1
591755  90.197  -54.539  56.248  1
591756  90.236  -54.559  56.222  1
591757  90.274  -54.583  56.198  1
591758  90.313  -54.606  56.174  1
591759  90.352  -54.630  56.153  1
591760  90.389  -54.652  56.137  1
591761  90.412  -54.667  56.125  1
591762  90.436  -54.681  56.114  1
591763  90.459  -54.695  56.103  1
591764  90.484  -54.709  56.091  1
591765  90.510  -54.722  56.076  1
591766  90.536  -54.736  56.059  1
591767  90.559  -54.751  56.038  1
591768  90.578  -54.768  56.013  1
591769  90.596  -54.786  55.984  1
591770  90.614  -54.804  55.956  1
591771  90.633  -54.822  55.929  1
591772  90.651  -54.840  55.908  1
591773  90.669  -54.857  55.891  1
591774  90.687  -54.875  55.878  1
591775  90.706  -54.893  55.868  1
591776  90.724  -54.911  55.860  1
591777  90.759  -54.926  55.854  1
591778  90.796  -54.941  55.850  1
591779  90.832  -54.957  55.844  1
591780  90.869  -54.972  55.838  1
591781  90.906  -54.988  55.834  1
591782  90.943  -55.003  55.830  1
591783  90.979  -55.018  55.823  1
591784  91.016  -55.034  55.813  1
591785  91.053  -55.049  55.802  1
591786  91.090  -55.064  55.790  1
591787  91.127  -55.079  55.779  1
591788  91.163  -55.094  55.773  1
591789  91.200  -55.110  55.765  1
591790  91.237  -55.126  55.753  1
591791  91.274  -55.139  55.736  1
591792  91.311  -55.153  55.714  1
591793  91.348  -55.166  55.691  1
591794  91.385  -55.180  55.672  1
591795  91.428  -55.191  55.656  1
591796  91.481  -55.195  55.637  1
591797  91.515  -55.199  55.617  1
591798  91.545  -55.203  55.597  1
591799  91.576  -55.207  55.582  1
591800  91.611  -55.218  55.574  1
591801  91.647  -55.229  55.570  1
591802  91.682  -55.239  55.556  1
591803  91.718  -55.251  55.527  1
591804  91.753  -55.261  55.490  1
591805  91.789  -55.272  55.455  1
591806  91.824  -55.282  55.430  1
591807  91.860  -55.294  55.407  1
591808  91.895  -55.304  55.385  1
591809  91.931  -55.315  55.364  1
591810  91.966  -55.326  55.346  1
591811  92.001  -55.338  55.330  1
591812  92.035  -55.355  55.319  1
591813  92.069  -55.372  55.310  1
591814  92.102  -55.389  55.306  1
591815  92.136  -55.405  55.306  1
591816  92.170  -55.422  55.313  1
591817  92.205  -55.439  55.327  1
591818  92.239  -55.455  55.343  1
591819  92.274  -55.472  55.355  1
591820  92.309  -55.489  55.365  1
591821  92.345  -55.505  55.374  1
591822  92.385  -55.520  55.380  1
591823  92.425  -55.536  55.380  1
591824  92.466  -55.551  55.370  1
591825  92.503  -55.568  55.353  1
591826  92.534  -55.587  55.337  1
591827  92.570  -55.606  55.317  1
591828  92.605  -55.626  55.293  1
591829  92.641  -55.645  55.271  1
591830  92.671  -55.663  55.268  1
591831  92.701  -55.681  55.274  1
591832  92.731  -55.699  55.279  1
591833  92.762  -55.718  55.279  1
591834  92.792  -55.735  55.276  1
591835  92.822  -55.753  55.266  1
591836  92.852  -55.771  55.250  1
591837  92.882  -55.790  55.231  1
591838  92.913  -55.808  55.218  1
591839  92.943  -55.826  55.213  1
591840  92.975  -55.845  55.216  1
591841  93.012  -55.866  55.227  1
591842  93.050  -55.888  55.241  1
591843  93.086  -55.909  55.255  1
591844  93.124  -55.931  55.269  1
591845  93.160  -55.946  55.280  1
591846  93.196  -55.944  55.288  1
591847  93.231  -55.944  55.295  1
591848  93.266  -55.947  55.302  1
591849  93.300  -55.950  55.312  1
591850  93.334  -55.952  55.317  1
591851  93.368  -55.955  55.317  1
591852  93.403  -55.957  55.315  1
591853  93.437  -55.960  55.307  1
591854  93.471  -55.962  55.296  1
591855  93.505  -55.965  55.281  1
591856  93.538  -55.976  55.267  1
591857  93.569  -55.998  55.251  1
591858  93.600  -56.021  55.233  1
591859  93.631  -56.043  55.216  1
591860  93.662  -56.065  55.193  1
591861  93.693  -56.087  55.170  1
591862  93.724  -56.110  55.151  1
591863  93.755  -56.132  55.134  1
591864  93.786  -56.154  55.119  1
591865  93.817  -56.176  55.105  1
591866  93.840  -56.204  55.085  1
591867  93.868  -56.216  55.066  1
591868  93.899  -56.232  55.046  1
591869  93.929  -56.248  55.024  1
591870  93.960  -56.264  54.999  1
591871  93.990  -56.280  54.975  1
591872  94.020  -56.295  54.944  1
591873  94.051  -56.311  54.912  1
591874  94.081  -56.327  54.876  1
591875  94.112  -56.343  54.839  1
591876  94.142  -56.359  54.800  1
591877  94.173  -56.375  54.759  1
591878  94.203  -56.391  54.711  1
591879  94.234  -56.406  54.663  1
591880  94.264  -56.422  54.614  1
591881  94.295  -56.436  54.561  1
591882  94.326  -56.445  54.507  1
591883  94.353  -56.452  54.451  1
591884  94.381  -56.460  54.389  1
591885  94.409  -56.467  54.329  1
591886  94.436  -56.475  54.272  1
591887  94.464  -56.483  54.218  1
591888  94.492  -56.490  54.167  1
591889  94.521  -56.498  54.117  1
591890  94.557  -56.508  54.062  1
591891  94.592  -56.519  54.005  1
591892  94.627  -56.529  53.948  1
591893  94.663  -56.539  53.893  1
591894  94.698  -56.550  53.841  1
591895  94.734  -56.560  53.787  1
591896  94.769  -56.570  53.737  1
591897  94.805  -56.580  53.693  1
591898  94.844  -56.574  53.652  1
591899  94.883  -56.570  53.613  1
591900  94.911  -56.583  53.575  1
591901  94.939  -56.596  53.537  1
591902  94.967  -56.609  53.500  1
591903  94.996  -56.623  53.461  1
591904  95.024  -56.636  53.417  1
591905  95.052  -56.649  53.369  1
591906  95.080  -56.662  53.317  1
591907  95.109  -56.675  53.262  1
591908  95.137  -56.688  53.202  1
591909  95.166  -56.702  53.143  1
591910  95.194  -56.713  53.090  1
591911  95.223  -56.724  53.042  1
591912  95.265  -56.736  52.997  1
591913  95.312  -56.747  52.958  1
591914  95.357  -56.755  52.920  1
591915  95.385  -56.765  52.883  1
591916  95.412  -56.774  52.846  1
591917  95.439  -56.784  52.808  1
591918  95.467  -56.793  52.769  1
591919  95.494  -56.803  52.732  1
591920  95.522  -56.812  52.698  1
591921  95.549  -56.822  52.667  1
591922  95.588  -56.830  52.638  1
591923  95.627  -56.839  52.608  1
591924  95.666  -56.847  52.578  1
591925  95.704  -56.855  52.547  1
591926  95.743  -56.865  52.516  1
591927  95.780  -56.871  52.486  1
591928  95.817  -56.879  52.453  1
591929  95.853  -56.886  52.419  1
591930  95.884  -56.893  52.385  1
591931  95.905  -56.899  52.349  1
591932  95.927  -56.906  52.312  1
591933  95.949  -56.913  52.276  1
591934  95.970  -56.920  52.239  1
591935  95.992  -56.927  52.202  1
591936  96.014  -56.934  52.164  1
591937  96.035  -56.940  52.124  1
591938  96.058  -56.950  52.089  1
591939  96.082  -56.960  52.059  1
591940  96.104  -56.971  52.032  1
591941  96.127  -56.981  52.007  1
591942  96.151  -56.990  51.984  1
591943  96.174  -57.000  51.960  1
591944  96.192  -57.009  51.941  1
591945  96.212  -57.016  51.924  1
591946  96.238  -57.027  51.905  1
591947  96.266  -57.034  51.886  1
591948  96.295  -57.037  51.865  1
591949  96.322  -57.040  51.846  1
591950  96.350  -57.044  51.834  1
591951  96.378  -57.047  51.823  1
591952  96.406  -57.051  51.812  1
591953  96.434  -57.054  51.799  1
591954  96.462  -57.056  51.784  1
591955  96.490  -57.055  51.764  1
591956  96.518  -57.053  51.744  1
591957  96.546  -57.053  51.720  1
591958  96.575  -57.054  51.694  1
591959  96.603  -57.055  51.666  1
591960  96.631  -57.056  51.636  1
591961  96.660  -57.056  51.605  1
591962  96.691  -57.062  51.578  1
591963  96.725  -57.072  51.552  1
591964  96.758  -57.081  51.528  1
591965  96.791  -57.091  51.505  1
591966  96.824  -57.100  51.484  1
591967  96.857  -57.109  51.463  1
591968  96.890  -57.119  51.443  1
591969  96.923  -57.128  51.424  1
591970  96.956  -57.138  51.406  1
591971  96.990  -57.147  51.390  1
591972  97.022  -57.144  51.376  1
591973  97.055  -57.136  51.366  1
591974  97.087  -57.127  51.361  1
591975  97.120  -57.118  51.353  1
591976  97.152  -57.109  51.345  1
591977  97.185  -57.100  51.338  1
591978  97.217  -57.091  51.333  1
591979  97.250  -57.083  51.332  1
591980  97.282  -57.074  51.325  1
591981  97.315  -57.065  51.315  1
591982  97.347  -57.056  51.304  1
591983  97.380  -57.047  51.291  1
591984  97.417  -57.045  51.276  1
591985  97.454  -57.043  51.259  1
591986  97.484  -57.040  51.240  1
591987  97.511  -57.037  51.220  1
591988  97.540  -57.039  51.199  1
591989  97.572  -57.049  51.176  1
591990  97.602  -57.056  51.151  1
591991  97.633  -57.063  51.123  1
591992  97.664  -57.070  51.093  1
591993  97.694  -57.078  51.063  1
591994  97.727  -57.090  51.033  1
591995  97.760  -57.105  51.005  1
591996  97.794  -57.119  50.977  1
591997  97.827  -57.134  50.948  1
591998  97.861  -57.148  50.917  1
591999  97.894  -57.159  50.887  1
592000  97.928  -57.167  50.858  1
592001  97.962  -57.176  50.831  1
592002  97.997  -57.185  50.803  1
592003  98.030  -57.193  50.776  1
592004  98.065  -57.201  50.750  1
592005  98.098  -57.210  50.725  1
592006  98.133  -57.216  50.702  1
592007  98.168  -57.219  50.678  1
592008  98.204  -57.221  50.654  1
592009  98.239  -57.223  50.632  1
592010  98.275  -57.225  50.609  1
592011  98.310  -57.228  50.582  1
592012  98.345  -57.230  50.553  1
592013  98.380  -57.232  50.525  1
592014  98.416  -57.235  50.496  1
592015  98.451  -57.237  50.466  1
592016  98.487  -57.239  50.433  1
592017  98.522  -57.241  50.400  1
592018  98.558  -57.243  50.369  1
592019  98.593  -57.245  50.340  1
592020  98.628  -57.247  50.313  1
592021  98.664  -57.250  50.291  1
592022  98.700  -57.256  50.266  1
592023  98.737  -57.257  50.243  1
592024  98.775  -57.261  50.222  1
592025  98.813  -57.266  50.200  1
592026  98.851  -57.269  50.177  1
592027  98.889  -57.274  50.152  1
592028  98.927  -57.278  50.127  1
592029  98.966  -57.282  50.101  1
592030  98.984  -57.286  50.077  1
592031  98.992  -57.291  50.054  1
592032  99.006  -57.301  50.030  1
592033  99.023  -57.312  50.005  1
592034  99.039  -57.323  49.976  1
592035  99.056  -57.335  49.943  1
592036  99.072  -57.345  49.909  1
592037  99.094  -57.357  49.874  1
592038  99.121  -57.370  49.839  1
592039  99.148  -57.382  49.802  1
592040  99.169  -57.393  49.764  1
592041  99.188  -57.399  49.725  1
592042  99.218  -57.404  49.685  1
592043  99.249  -57.408  49.645  1
592044  99.279  -57.413  49.605  1
592045  99.311  -57.416  49.565  1
592046  99.345  -57.420  49.527  1
592047  99.378  -57.423  49.490  1
592048  99.411  -57.426  49.456  1
592049  99.444  -57.428  49.424  1
592050  99.476  -57.432  49.391  1
592051  99.503  -57.439  49.357  1
592052  99.528  -57.453  49.324  1
592053  99.554  -57.466  49.291  1
592054  99.581  -57.472  49.256  1
592055  99.609  -57.478  49.220  1
592056  99.637  -57.484  49.184  1
592057  99.664  -57.494  49.146  1
592058  99.692  -57.511  49.111  1
592059  99.720  -57.529  49.077  1
592060  99.748  -57.548  49.045  1
592061  99.775  -57.565  49.015  1
592062  99.803  -57.583  48.986  1
592063  99.831  -57.601  48.959  1
592064  99.859  -57.619  48.935  1
592065  99.887  -57.636  48.913  1
592066  99.914  -57.655  48.892  1
592067  99.942  -57.673  48.871  1
592068  99.970  -57.690  48.851  1
592069  99.998  -57.708  48.831  1
592411  88.539  -53.678  57.516  4
592412  88.574  -53.693  57.517  4
592413  88.610  -53.709  57.518  4
592414  88.646  -53.725  57.518  4
592415  88.684  -53.744  57.517  4
592416  88.722  -53.764  57.515  4
592417  88.760  -53.783  57.513  4
592418  88.798  -53.803  57.511  4
592419  88.836  -53.822  57.508  4
592420  88.875  -53.841  57.503  4
592421  88.912  -53.860  57.499  4
592422  88.951  -53.880  57.492  4
592423  88.991  -53.899  57.484  4
592424  89.042  -53.919  57.474  4
592425  89.093  -53.939  57.464  4
592426  89.127  -53.963  57.452  4
592427  89.184  -53.962  57.438  4
592428  89.236  -53.963  57.422  4
592429  89.265  -53.984  57.405  4
592430  89.302  -54.003  57.385  4
592431  89.337  -54.022  57.362  4
592432  89.374  -54.041  57.338  4
592433  89.409  -54.060  57.310  4
592434  89.446  -54.079  57.277  4
592435  89.481  -54.098  57.240  4
592436  89.518  -54.118  57.201  4
592437  89.553  -54.137  57.159  4
592438  89.590  -54.156  57.115  4
592439  89.625  -54.175  57.071  4
592440  89.662  -54.195  57.027  4
592441  89.697  -54.214  56.981  4
592442  89.734  -54.232  56.934  4
592443  89.769  -54.252  56.890  4
592449  89.963  -54.387  56.481  1
592450  89.995  -54.409  56.444  1
592451  90.029  -54.431  56.409  1
592452  90.067  -54.448  56.375  1
592453  90.105  -54.464  56.341  1
592454  90.143  -54.482  56.310  1
592455  90.181  -54.499  56.281  1
592456  90.219  -54.515  56.253  1
592457  90.257  -54.532  56.228  1
592458  90.296  -54.551  56.204  1
592459  90.334  -54.574  56.181  1
592460  90.373  -54.598  56.160  1
592461  90.408  -54.619  56.145  1
592462  90.432  -54.634  56.135  1
592463  90.455  -54.647  56.126  1
592464  90.480  -54.661  56.114  1
592465  90.506  -54.674  56.099  1
592466  90.528  -54.691  56.081  1
592467  90.546  -54.709  56.062  1
592468  90.565  -54.726  56.039  1
592469  90.583  -54.744  56.013  1
592470  90.601  -54.762  55.984  1
592471  90.619  -54.780  55.957  1
592472  90.637  -54.797  55.932  1
592473  90.656  -54.815  55.912  1
592474  90.674  -54.833  55.896  1
592475  90.692  -54.851  55.883  1
592476  90.710  -54.869  55.872  1
592477  90.731  -54.886  55.865  1
592478  90.767  -54.901  55.859  1
592479  90.804  -54.917  55.853  1
592480  90.841  -54.932  55.846  1
592481  90.878  -54.947  55.838  1
592482  90.915  -54.963  55.831  1
592483  90.951  -54.978  55.822  1
592484  90.988  -54.994  55.814  1
592485  91.025  -55.009  55.803  1
592486  91.062  -55.024  55.789  1
592487  91.098  -55.039  55.775  1
592488  91.135  -55.054  55.762  1
592489  91.172  -55.070  55.752  1
592490  91.209  -55.084  55.742  1
592491  91.246  -55.097  55.729  1
592492  91.283  -55.111  55.713  1
592493  91.320  -55.125  55.694  1
592494  91.357  -55.138  55.676  1
592495  91.394  -55.152  55.661  1
592496  91.445  -55.158  55.646  1
592497  91.498  -55.163  55.625  1
592498  91.533  -55.167  55.604  1
592499  91.563  -55.170  55.585  1
592500  91.593  -55.174  55.569  1
592501  91.624  -55.179  55.560  1
592502  91.660  -55.189  55.555  1
592503  91.695  -55.200  55.540  1
592504  91.731  -55.211  55.513  1
592505  91.766  -55.222  55.478  1
592506  91.802  -55.232  55.447  1
592507  91.837  -55.243  55.424  1
592508  91.873  -55.254  55.401  1
592509  91.908  -55.265  55.380  1
592510  91.944  -55.276  55.361  1
592511  91.979  -55.288  55.343  1
592512  92.012  -55.304  55.328  1
592513  92.046  -55.321  55.319  1
592514  92.080  -55.338  55.312  1
592515  92.113  -55.354  55.309  1
592516  92.147  -55.371  55.309  1
592517  92.181  -55.388  55.315  1
592518  92.215  -55.405  55.328  1
592519  92.250  -55.421  55.343  1
592520  92.285  -55.439  55.356  1
592521  92.319  -55.455  55.369  1
592522  92.359  -55.470  55.379  1
592523  92.400  -55.486  55.387  1
592524  92.440  -55.501  55.390  1
592525  92.481  -55.516  55.386  1
592526  92.521  -55.531  55.373  1
592527  92.555  -55.549  55.358  1
592528  92.585  -55.567  55.337  1
592529  92.615  -55.585  55.310  1
592530  92.645  -55.603  55.285  1
592531  92.675  -55.621  55.277  1
592532  92.706  -55.640  55.282  1
592533  92.736  -55.658  55.290  1
592534  92.766  -55.675  55.295  1
592535  92.796  -55.693  55.295  1
592536  92.827  -55.712  55.290  1
592537  92.857  -55.730  55.275  1
592538  92.887  -55.748  55.259  1
592539  92.917  -55.766  55.243  1
592540  92.948  -55.784  55.231  1
592541  92.985  -55.806  55.225  1
592542  93.022  -55.828  55.229  1
592543  93.060  -55.849  55.241  1
592544  93.096  -55.871  55.255  1
592545  93.134  -55.892  55.269  1
592546  93.171  -55.914  55.281  1
592547  93.207  -55.914  55.290  1
592548  93.243  -55.912  55.298  1
592549  93.277  -55.914  55.304  1
592550  93.311  -55.916  55.312  1
592551  93.346  -55.919  55.317  1
592552  93.380  -55.922  55.318  1
592553  93.414  -55.924  55.319  1
592554  93.448  -55.927  55.314  1
592555  93.483  -55.929  55.304  1
592556  93.517  -55.932  55.293  1
592557  93.550  -55.943  55.281  1
592558  93.581  -55.965  55.267  1
592559  93.612  -55.987  55.250  1
592560  93.643  -56.009  55.234  1
592561  93.674  -56.031  55.212  1
592562  93.705  -56.053  55.190  1
592563  93.736  -56.076  55.169  1
592564  93.767  -56.098  55.150  1
592565  93.798  -56.120  55.132  1
592566  93.823  -56.147  55.114  1
592567  93.843  -56.176  55.093  1
592568  93.869  -56.193  55.072  1
592569  93.898  -56.205  55.050  1
592570  93.928  -56.219  55.027  1
592571  93.958  -56.235  55.001  1
592572  93.989  -56.250  54.978  1
592573  94.019  -56.266  54.943  1
592574  94.050  -56.282  54.910  1
592575  94.080  -56.298  54.876  1
592576  94.111  -56.313  54.839  1
592577  94.141  -56.329  54.801  1
592578  94.172  -56.345  54.762  1
592579  94.202  -56.360  54.715  1
592580  94.232  -56.376  54.669  1
592581  94.263  -56.392  54.622  1
592582  94.296  -56.404  54.572  1
592583  94.330  -56.413  54.520  1
592584  94.359  -56.420  54.466  1
592585  94.387  -56.428  54.406  1
592586  94.414  -56.436  54.345  1
592587  94.442  -56.443  54.286  1
592588  94.470  -56.451  54.230  1
592589  94.497  -56.458  54.176  1
592590  94.528  -56.467  54.122  1
592591  94.563  -56.477  54.065  1
592592  94.599  -56.488  54.007  1
592593  94.634  -56.498  53.948  1
592594  94.670  -56.508  53.891  1
592595  94.705  -56.518  53.837  1
592596  94.740  -56.529  53.782  1
592597  94.776  -56.538  53.729  1
592598  94.816  -56.531  53.681  1
592599  94.855  -56.524  53.636  1
592600  94.894  -56.518  53.594  1
592601  94.926  -56.524  53.552  1
592602  94.955  -56.538  53.512  1
592603  94.983  -56.551  53.472  1
592604  95.011  -56.564  53.432  1
592605  95.040  -56.577  53.390  1
592606  95.068  -56.590  53.344  1
592607  95.096  -56.604  53.295  1
592608  95.124  -56.617  53.243  1
592609  95.153  -56.630  53.187  1
592610  95.181  -56.644  53.127  1
592611  95.207  -56.670  53.070  1
592612  95.232  -56.695  53.019  1
592613  95.268  -56.709  52.972  1
592614  95.315  -56.721  52.929  1
592615  95.362  -56.732  52.889  1
592616  95.393  -56.733  52.851  1
592617  95.421  -56.743  52.813  1
592618  95.448  -56.752  52.776  1
592619  95.475  -56.762  52.738  1
592620  95.503  -56.771  52.701  1
592621  95.530  -56.780  52.663  1
592622  95.558  -56.790  52.629  1
592623  95.592  -56.799  52.597  1
592624  95.630  -56.807  52.567  1
592625  95.669  -56.816  52.537  1
592626  95.708  -56.824  52.504  1
592627  95.747  -56.833  52.473  1
592628  95.783  -56.840  52.442  1
592629  95.820  -56.847  52.411  1
592630  95.856  -56.854  52.379  1
592631  95.887  -56.861  52.345  1
592632  95.909  -56.868  52.310  1
592633  95.931  -56.874  52.275  1
592634  95.952  -56.881  52.238  1
592635  95.974  -56.888  52.200  1
592636  95.995  -56.895  52.163  1
592637  96.017  -56.902  52.125  1
592638  96.040  -56.911  52.088  1
592639  96.063  -56.921  52.055  1
592640  96.086  -56.931  52.023  1
592641  96.109  -56.941  51.995  1
592642  96.132  -56.951  51.970  1
592643  96.154  -56.960  51.947  1
592644  96.173  -56.968  51.923  1
592645  96.191  -56.976  51.904  1
592646  96.213  -56.984  51.886  1
592647  96.241  -56.997  51.869  1
592648  96.269  -57.004  51.850  1
592649  96.297  -57.008  51.831  1
592650  96.325  -57.011  51.812  1
592651  96.353  -57.015  51.799  1
592652  96.381  -57.018  51.788  1
592653  96.409  -57.022  51.777  1
592654  96.437  -57.024  51.765  1
592655  96.464  -57.025  51.750  1
592656  96.493  -57.024  51.729  1
592657  96.521  -57.022  51.709  1
592658  96.549  -57.022  51.686  1
592659  96.577  -57.020  51.661  1
592660  96.605  -57.020  51.635  1
592661  96.633  -57.020  51.606  1
592662  96.662  -57.021  51.577  1
592663  96.690  -57.022  51.552  1
592664  96.724  -57.031  51.528  1
592665  96.756  -57.040  51.505  1
592666  96.790  -57.050  51.483  1
592667  96.823  -57.059  51.460  1
592668  96.856  -57.069  51.437  1
592669  96.889  -57.078  51.417  1
592670  96.922  -57.087  51.398  1
592671  96.954  -57.102  51.378  1
592672  96.985  -57.115  51.358  1
592673  97.021  -57.113  51.340  1
592674  97.054  -57.104  51.325  1
592675  97.087  -57.097  51.318  1
592676  97.120  -57.088  51.311  1
592677  97.154  -57.080  51.304  1
592678  97.186  -57.072  51.300  1
592679  97.219  -57.063  51.298  1
592680  97.251  -57.054  51.296  1
592681  97.284  -57.045  51.287  1
592682  97.316  -57.037  51.275  1
592683  97.349  -57.028  51.261  1
592684  97.381  -57.018  51.246  1
592685  97.414  -57.010  51.231  1
592686  97.449  -57.005  51.214  1
592687  97.486  -57.003  51.196  1
592688  97.514  -57.000  51.175  1
592689  97.542  -57.000  51.155  1
592690  97.574  -57.009  51.133  1
592691  97.604  -57.016  51.109  1
592692  97.635  -57.023  51.082  1
592693  97.666  -57.033  51.054  1
592694  97.700  -57.047  51.026  1
592695  97.733  -57.062  50.998  1
592696  97.767  -57.077  50.972  1
592697  97.800  -57.091  50.946  1
592698  97.833  -57.106  50.919  1
592699  97.867  -57.119  50.889  1
592700  97.901  -57.127  50.861  1
592701  97.935  -57.136  50.835  1
592702  97.969  -57.144  50.810  1
592703  98.003  -57.153  50.785  1
592704  98.037  -57.161  50.759  1
592705  98.071  -57.169  50.731  1
592706  98.105  -57.178  50.704  1
592707  98.139  -57.187  50.679  1
592708  98.174  -57.193  50.656  1
592709  98.209  -57.195  50.633  1
592710  98.244  -57.197  50.611  1
592711  98.280  -57.199  50.588  1
592712  98.315  -57.201  50.562  1
592713  98.351  -57.203  50.535  1
592714  98.386  -57.206  50.508  1
592715  98.422  -57.208  50.480  1
592716  98.457  -57.210  50.450  1
592717  98.492  -57.213  50.417  1
592718  98.528  -57.215  50.385  1
592719  98.563  -57.217  50.355  1
592720  98.598  -57.219  50.325  1
592721  98.634  -57.221  50.299  1
592722  98.668  -57.222  50.276  1
592723  98.705  -57.235  50.252  1
592724  98.743  -57.241  50.230  1
592725  98.780  -57.241  50.210  1
592726  98.817  -57.242  50.188  1
592727  98.855  -57.244  50.166  1
592728  98.892  -57.248  50.141  1
592729  98.931  -57.252  50.115  1
592730  98.969  -57.257  50.090  1
592731  98.994  -57.260  50.066  1
592732  99.005  -57.267  50.043  1
592733  99.021  -57.279  50.019  1
592734  99.038  -57.290  49.993  1
592735  99.054  -57.301  49.964  1
592736  99.070  -57.312  49.932  1
592737  99.087  -57.323  49.899  1
592738  99.103  -57.335  49.864  1
592739  99.120  -57.346  49.829  1
592740  99.138  -57.357  49.792  1
592741  99.165  -57.369  49.755  1
592742  99.189  -57.376  49.715  1
592743  99.220  -57.379  49.675  1
592744  99.253  -57.382  49.635  1
592745  99.286  -57.385  49.594  1
592746  99.319  -57.388  49.555  1
592747  99.352  -57.391  49.518  1
592748  99.385  -57.394  49.482  1
592749  99.418  -57.397  49.448  1
592750  99.451  -57.400  49.416  1
592751  99.484  -57.403  49.383  1
592752  99.511  -57.410  49.351  1
592753  99.537  -57.420  49.318  1
592754  99.562  -57.435  49.285  1
592755  99.586  -57.450  49.250  1
592756  99.614  -57.457  49.214  1
592757  99.641  -57.463  49.178  1
592758  99.669  -57.473  49.141  1
592759  99.697  -57.489  49.105  1
592760  99.725  -57.507  49.071  1
592761  99.753  -57.525  49.039  1
592762  99.780  -57.542  49.008  1
592763  99.808  -57.561  48.979  1
592764  99.836  -57.578  48.951  1
592765  99.863  -57.596  48.927  1
592766  99.892  -57.614  48.904  1
592767  99.919  -57.632  48.882  1
592768  99.947  -57.650  48.862  1
592769  99.975  -57.667  48.841  1
592770  100.002  -57.686  48.821  1
593112  88.564  -53.643  57.509  4
593113  88.599  -53.658  57.510  4
593114  88.636  -53.675  57.511  4
593115  88.674  -53.694  57.510  4
593116  88.712  -53.714  57.510  4
593117  88.750  -53.733  57.508  4
593118  88.788  -53.753  57.506  4
593119  88.826  -53.772  57.503  4
593120  88.864  -53.791  57.499  4
593121  88.902  -53.810  57.495  4
593122  88.940  -53.830  57.490  4
593123  88.978  -53.849  57.483  4
593124  89.020  -53.869  57.475  4
593125  89.071  -53.888  57.465  4
593126  89.122  -53.909  57.454  4
593127  89.159  -53.932  57.443  4
593128  89.217  -53.928  57.430  4
593129  89.254  -53.941  57.414  4
593130  89.283  -53.962  57.396  4
593131  89.319  -53.981  57.377  4
593132  89.355  -54.001  57.355  4
593133  89.391  -54.019  57.332  4
593134  89.427  -54.038  57.305  4
593135  89.463  -54.058  57.274  4
593136  89.499  -54.077  57.237  4
593137  89.535  -54.096  57.199  4
593138  89.571  -54.115  57.158  4
593139  89.607  -54.135  57.115  4
593140  89.644  -54.154  57.071  4
593141  89.679  -54.173  57.027  4
593142  89.716  -54.192  56.981  4
593143  89.751  -54.211  56.935  4
593144  89.788  -54.230  56.891  4
593145  89.823  -54.249  56.849  4
593151  90.039  -54.364  56.446  1
593152  90.075  -54.383  56.412  1
593153  90.108  -54.405  56.378  1
593154  90.141  -54.428  56.345  1
593155  90.173  -54.451  56.314  1
593156  90.205  -54.473  56.285  1
593157  90.241  -54.492  56.258  1
593158  90.279  -54.508  56.232  1
593159  90.317  -54.526  56.209  1
593160  90.356  -54.543  56.186  1
593161  90.394  -54.566  56.167  1
593162  90.427  -54.586  56.153  1
593163  90.451  -54.600  56.143  1
593164  90.477  -54.614  56.131  1
593165  90.496  -54.631  56.118  1
593166  90.514  -54.649  56.100  1
593167  90.532  -54.666  56.081  1
593168  90.550  -54.684  56.059  1
593169  90.569  -54.702  56.035  1
593170  90.587  -54.720  56.009  1
593171  90.605  -54.737  55.981  1
593172  90.623  -54.756  55.955  1
593173  90.642  -54.773  55.933  1
593174  90.660  -54.791  55.915  1
593175  90.678  -54.809  55.900  1
593176  90.696  -54.827  55.887  1
593177  90.715  -54.844  55.877  1
593178  90.739  -54.861  55.869  1
593179  90.776  -54.877  55.863  1
593180  90.813  -54.892  55.857  1
593181  90.850  -54.907  55.848  1
593182  90.886  -54.922  55.838  1
593183  90.923  -54.938  55.828  1
593184  90.960  -54.953  55.817  1
593185  90.997  -54.969  55.804  1
593186  91.033  -54.984  55.790  1
593187  91.070  -54.999  55.776  1
593188  91.107  -55.014  55.760  1
593189  91.144  -55.028  55.744  1
593190  91.181  -55.042  55.732  1
593191  91.218  -55.056  55.720  1
593192  91.255  -55.069  55.707  1
593193  91.292  -55.083  55.693  1
593194  91.329  -55.097  55.678  1
593195  91.366  -55.110  55.664  1
593196  91.409  -55.121  55.654  1
593197  91.462  -55.126  55.641  1
593198  91.515  -55.131  55.618  1
593199  91.551  -55.135  55.594  1
593200  91.581  -55.138  55.573  1
593201  91.611  -55.141  55.556  1
593202  91.641  -55.145  55.546  1
593203  91.672  -55.150  55.538  1
593204  91.708  -55.160  55.523  1
593205  91.743  -55.172  55.499  1
593206  91.779  -55.182  55.469  1
593207  91.814  -55.193  55.440  1
593208  91.850  -55.204  55.418  1
593209  91.885  -55.215  55.397  1
593210  91.921  -55.226  55.377  1
593211  91.956  -55.237  55.359  1
593212  91.990  -55.254  55.342  1
593213  92.023  -55.270  55.327  1
593214  92.057  -55.287  55.319  1
593215  92.091  -55.304  55.315  1
593216  92.125  -55.320  55.315  1
593217  92.158  -55.337  55.316  1
593218  92.192  -55.354  55.318  1
593219  92.226  -55.371  55.326  1
593220  92.261  -55.388  55.341  1
593221  92.296  -55.405  55.356  1
593222  92.334  -55.420  55.370  1
593223  92.374  -55.436  55.383  1
593224  92.415  -55.451  55.393  1
593225  92.455  -55.466  55.397  1
593226  92.492  -55.480  55.397  1
593227  92.526  -55.492  55.388  1
593228  92.559  -55.507  55.373  1
593229  92.589  -55.525  55.352  1
593230  92.620  -55.543  55.325  1
593231  92.650  -55.561  55.300  1
593232  92.680  -55.580  55.288  1
593233  92.710  -55.598  55.286  1
593234  92.740  -55.615  55.290  1
593235  92.771  -55.633  55.297  1
593236  92.801  -55.652  55.302  1
593237  92.831  -55.670  55.301  1
593238  92.861  -55.688  55.294  1
593239  92.892  -55.706  55.285  1
593240  92.922  -55.724  55.272  1
593241  92.958  -55.745  55.259  1
593242  92.995  -55.767  55.246  1
593243  93.032  -55.788  55.242  1
593244  93.069  -55.810  55.243  1
593245  93.107  -55.831  55.253  1
593246  93.144  -55.853  55.267  1
593247  93.181  -55.875  55.280  1
593248  93.218  -55.884  55.290  1
593249  93.254  -55.883  55.298  1
593250  93.289  -55.881  55.305  1
593251  93.324  -55.883  55.310  1
593252  93.358  -55.886  55.314  1
593253  93.392  -55.888  55.316  1
593254  93.426  -55.891  55.318  1
593255  93.461  -55.893  55.314  1
593256  93.495  -55.897  55.306  1
593257  93.529  -55.899  55.298  1
593258  93.562  -55.909  55.289  1
593259  93.593  -55.931  55.276  1
593260  93.624  -55.953  55.260  1
593261  93.655  -55.976  55.244  1
593262  93.686  -55.998  55.223  1
593263  93.717  -56.020  55.201  1
593264  93.748  -56.043  55.180  1
593265  93.779  -56.065  55.159  1
593266  93.805  -56.090  55.138  1
593267  93.826  -56.119  55.115  1
593268  93.845  -56.149  55.091  1
593269  93.869  -56.170  55.066  1
593270  93.899  -56.182  55.042  1
593271  93.928  -56.193  55.017  1
593272  93.957  -56.204  54.989  1
593273  93.987  -56.220  54.961  1
593274  94.018  -56.236  54.930  1
593275  94.048  -56.252  54.897  1
593276  94.079  -56.268  54.863  1
593277  94.109  -56.284  54.828  1
593278  94.140  -56.300  54.792  1
593279  94.170  -56.316  54.755  1
593280  94.201  -56.331  54.711  1
593281  94.231  -56.347  54.667  1
593282  94.262  -56.361  54.623  1
593283  94.296  -56.370  54.576  1
593284  94.331  -56.379  54.526  1
593285  94.364  -56.389  54.474  1
593286  94.392  -56.396  54.416  1
593287  94.420  -56.404  54.356  1
593288  94.448  -56.412  54.297  1
593289  94.475  -56.420  54.241  1
593290  94.503  -56.427  54.185  1
593291  94.534  -56.436  54.128  1
593292  94.569  -56.446  54.070  1
593293  94.605  -56.456  54.012  1
593294  94.640  -56.467  53.954  1
593295  94.676  -56.476  53.896  1
593296  94.711  -56.487  53.840  1
593297  94.747  -56.495  53.783  1
593298  94.787  -56.488  53.726  1
593299  94.826  -56.481  53.673  1
593300  94.865  -56.475  53.625  1
593301  94.905  -56.468  53.581  1
593302  94.942  -56.466  53.536  1
593303  94.970  -56.479  53.494  1
593304  94.998  -56.492  53.451  1
593305  95.027  -56.505  53.408  1
593306  95.055  -56.519  53.365  1
593307  95.084  -56.532  53.318  1
593308  95.112  -56.546  53.269  1
593309  95.137  -56.572  53.218  1
593310  95.164  -56.599  53.166  1
593311  95.190  -56.624  53.110  1
593312  95.216  -56.651  53.053  1
593313  95.237  -56.669  52.999  1
593314  95.275  -56.684  52.950  1
593315  95.315  -56.699  52.905  1
593316  95.362  -56.711  52.860  1
593317  95.405  -56.718  52.820  1
593318  95.430  -56.714  52.781  1
593319  95.457  -56.720  52.744  1
593320  95.484  -56.729  52.709  1
593321  95.512  -56.739  52.671  1
593322  95.539  -56.749  52.633  1
593323  95.566  -56.758  52.594  1
593324  95.595  -56.767  52.558  1
593325  95.634  -56.776  52.526  1
593326  95.673  -56.784  52.496  1
593327  95.711  -56.793  52.462  1
593328  95.750  -56.801  52.431  1
593329  95.787  -56.808  52.400  1
593330  95.823  -56.815  52.369  1
593331  95.860  -56.822  52.338  1
593332  95.891  -56.829  52.304  1
593333  95.913  -56.836  52.269  1
593334  95.934  -56.843  52.235  1
593335  95.956  -56.849  52.198  1
593336  95.977  -56.856  52.160  1
593337  95.999  -56.863  52.123  1
593338  96.022  -56.871  52.086  1
593339  96.045  -56.881  52.051  1
593340  96.067  -56.891  52.019  1
593341  96.091  -56.901  51.988  1
593342  96.114  -56.912  51.959  1
593343  96.133  -56.920  51.932  1
593344  96.153  -56.928  51.910  1
593345  96.171  -56.936  51.887  1
593346  96.190  -56.943  51.868  1
593347  96.215  -56.954  51.849  1
593348  96.243  -56.965  51.831  1
593349  96.272  -56.975  51.813  1
593350  96.300  -56.978  51.794  1
593351  96.328  -56.981  51.776  1
593352  96.356  -56.985  51.764  1
593353  96.384  -56.988  51.752  1
593354  96.411  -56.990  51.742  1
593355  96.439  -56.993  51.729  1
593356  96.466  -56.994  51.713  1
593357  96.495  -56.993  51.692  1
593358  96.523  -56.991  51.672  1
593359  96.551  -56.990  51.650  1
593360  96.579  -56.989  51.627  1
593361  96.607  -56.987  51.602  1
593362  96.636  -56.987  51.576  1
593363  96.664  -56.986  51.548  1
593364  96.692  -56.987  51.525  1
593365  96.722  -56.990  51.504  1
593366  96.755  -57.000  51.484  1
593367  96.789  -57.009  51.461  1
593368  96.821  -57.018  51.437  1
593369  96.855  -57.028  51.414  1
593370  96.886  -57.043  51.393  1
593371  96.918  -57.057  51.372  1
593372  96.950  -57.071  51.351  1
593373  96.980  -57.079  51.329  1
593374  97.020  -57.080  51.309  1
593375  97.053  -57.072  51.292  1
593376  97.086  -57.064  51.280  1
593377  97.119  -57.056  51.273  1
593378  97.152  -57.048  51.268  1
593379  97.185  -57.040  51.265  1
593380  97.218  -57.032  51.265  1
593381  97.251  -57.024  51.262  1
593382  97.285  -57.015  51.252  1
593383  97.318  -57.008  51.239  1
593384  97.351  -56.999  51.224  1
593385  97.383  -56.990  51.207  1
593386  97.416  -56.981  51.188  1
593387  97.448  -56.972  51.171  1
593388  97.480  -56.964  51.153  1
593389  97.516  -56.962  51.132  1
593390  97.544  -56.961  51.112  1
593391  97.576  -56.969  51.091  1
593392  97.606  -56.976  51.066  1
593393  97.639  -56.990  51.041  1
593394  97.673  -57.005  51.016  1
593395  97.706  -57.019  50.990  1
593396  97.739  -57.034  50.963  1
593397  97.773  -57.048  50.937  1
593398  97.806  -57.063  50.913  1
593399  97.840  -57.078  50.888  1
593400  97.874  -57.087  50.861  1
593401  97.908  -57.096  50.837  1
593402  97.942  -57.104  50.813  1
593403  97.976  -57.113  50.790  1
593404  98.010  -57.121  50.768  1
593405  98.044  -57.129  50.743  1
593406  98.078  -57.138  50.713  1
593407  98.112  -57.147  50.684  1
593408  98.146  -57.155  50.658  1
593409  98.180  -57.163  50.634  1
593410  98.215  -57.169  50.612  1
593411  98.250  -57.171  50.590  1
593412  98.286  -57.173  50.567  1
593413  98.321  -57.175  50.541  1
593414  98.356  -57.178  50.515  1
593415  98.392  -57.179  50.490  1
593416  98.427  -57.181  50.463  1
593417  98.462  -57.184  50.433  1
593418  98.498  -57.186  50.401  1
593419  98.533  -57.188  50.370  1
593420  98.569  -57.191  50.340  1
593421  98.604  -57.193  50.311  1
593422  98.639  -57.195  50.283  1
593423  98.671  -57.194  50.260  1
593424  98.708  -57.206  50.238  1
593425  98.750  -57.225  50.217  1
593426  98.787  -57.226  50.196  1
593427  98.823  -57.227  50.176  1
593428  98.861  -57.228  50.154  1
593429  98.898  -57.228  50.129  1
593430  98.935  -57.229  50.103  1
593431  98.972  -57.231  50.079  1
593432  99.004  -57.235  50.055  1
593433  99.020  -57.245  50.031  1
593434  99.036  -57.257  50.007  1
593435  99.053  -57.268  49.982  1
593436  99.069  -57.279  49.952  1
593437  99.085  -57.290  49.921  1
593438  99.101  -57.301  49.888  1
593439  99.118  -57.312  49.854  1
593440  99.134  -57.322  49.818  1
593441  99.150  -57.333  49.781  1
593442  99.166  -57.344  49.744  1
593443  99.194  -57.348  49.704  1
593444  99.227  -57.351  49.664  1
593445  99.261  -57.354  49.624  1
593446  99.293  -57.357  49.584  1
593447  99.327  -57.360  49.545  1
593448  99.360  -57.362  49.510  1
593449  99.393  -57.365  49.475  1
593450  99.426  -57.368  49.441  1
593451  99.459  -57.371  49.408  1
593452  99.492  -57.374  49.376  1
593453  99.518  -57.382  49.344  1
593454  99.546  -57.389  49.311  1
593455  99.571  -57.401  49.278  1
593456  99.595  -57.416  49.244  1
593457  99.620  -57.431  49.208  1
593458  99.646  -57.442  49.172  1
593459  99.674  -57.451  49.135  1
593460  99.702  -57.466  49.098  1
593461  99.729  -57.484  49.065  1
593462  99.757  -57.502  49.032  1
593463  99.785  -57.520  49.002  1
593464  99.813  -57.538  48.972  1
593465  99.841  -57.555  48.944  1
593466  99.868  -57.573  48.919  1
593467  99.896  -57.591  48.895  1
593468  99.924  -57.609  48.873  1
593469  99.951  -57.627  48.852  1
593470  99.979  -57.645  48.831  1
593471  100.007  -57.663  48.811  1
593813  88.589  -53.608  57.504  4
593814  88.625  -53.625  57.504  4
593815  88.663  -53.644  57.503  4
593816  88.701  -53.664  57.503  4
593817  88.739  -53.683  57.502  4
593818  88.777  -53.703  57.501  4
593819  88.815  -53.722  57.498  4
593820  88.853  -53.741  57.495  4
593821  88.892  -53.760  57.491  4
593822  88.929  -53.780  57.487  4
593823  88.968  -53.799  57.482  4
593824  89.005  -53.819  57.475  4
593825  89.049  -53.838  57.466  4
593826  89.100  -53.858  57.456  4
593827  89.151  -53.878  57.446  4
593828  89.191  -53.899  57.434  4
593829  89.247  -53.897  57.421  4
593830  89.271  -53.919  57.406  4
593831  89.301  -53.941  57.388  4
593832  89.337  -53.960  57.370  4
593833  89.373  -53.979  57.348  4
593834  89.409  -53.998  57.325  4
593835  89.445  -54.017  57.300  4
593836  89.481  -54.036  57.271  4
593837  89.517  -54.055  57.235  4
593838  89.553  -54.075  57.196  4
593839  89.589  -54.094  57.156  4
593840  89.625  -54.113  57.114  4
593841  89.661  -54.132  57.071  4
593842  89.697  -54.151  57.027  4
593843  89.733  -54.170  56.980  4
593844  89.769  -54.189  56.935  4
593845  89.805  -54.209  56.892  4
593846  89.841  -54.228  56.849  4
593852  90.057  -54.343  56.449  1
593853  90.093  -54.362  56.414  1
593854  90.129  -54.381  56.381  1
593855  90.165  -54.400  56.348  1
593856  90.201  -54.420  56.316  1
593857  90.237  -54.439  56.288  1
593858  90.273  -54.458  56.261  1
593859  90.309  -54.477  56.236  1
593860  90.345  -54.496  56.213  1
593861  90.381  -54.515  56.191  1
593862  90.415  -54.536  56.173  1
593863  90.446  -54.553  56.160  1
593864  90.464  -54.571  56.147  1
593865  90.482  -54.589  56.134  1
593866  90.501  -54.607  56.118  1
593867  90.519  -54.624  56.097  1
593868  90.537  -54.642  56.076  1
593869  90.555  -54.660  56.053  1
593870  90.574  -54.678  56.027  1
593871  90.592  -54.696  56.001  1
593872  90.610  -54.713  55.976  1
593873  90.628  -54.731  55.952  1
593874  90.647  -54.749  55.934  1
593875  90.665  -54.767  55.918  1
593876  90.683  -54.784  55.904  1
593877  90.701  -54.802  55.892  1
593878  90.719  -54.820  55.881  1
593879  90.748  -54.837  55.872  1
593880  90.785  -54.852  55.865  1
593881  90.821  -54.867  55.859  1
593882  90.858  -54.882  55.849  1
593883  90.895  -54.897  55.836  1
593884  90.932  -54.913  55.823  1
593885  90.968  -54.928  55.810  1
593886  91.005  -54.944  55.793  1
593887  91.042  -54.959  55.777  1
593888  91.079  -54.973  55.761  1
593889  91.116  -54.987  55.745  1
593890  91.153  -55.000  55.728  1
593891  91.190  -55.014  55.715  1
593892  91.227  -55.028  55.705  1
593893  91.264  -55.041  55.695  1
593894  91.301  -55.055  55.686  1
593895  91.338  -55.069  55.675  1
593896  91.375  -55.082  55.663  1
593897  91.426  -55.088  55.651  1
593898  91.479  -55.093  55.637  1
593899  91.532  -55.098  55.614  1
593900  91.569  -55.102  55.587  1
593901  91.599  -55.106  55.563  1
593902  91.629  -55.109  55.544  1
593903  91.659  -55.113  55.531  1
593904  91.689  -55.116  55.520  1
593905  91.721  -55.121  55.506  1
593906  91.756  -55.132  55.486  1
593907  91.792  -55.143  55.461  1
593908  91.827  -55.154  55.435  1
593909  91.863  -55.164  55.414  1
593910  91.898  -55.176  55.394  1
593911  91.933  -55.186  55.375  1
593912  91.967  -55.203  55.358  1
593913  92.001  -55.220  55.341  1
593914  92.034  -55.236  55.328  1
593915  92.068  -55.253  55.323  1
593916  92.102  -55.270  55.322  1
593917  92.136  -55.287  55.326  1
593918  92.169  -55.304  55.334  1
593919  92.203  -55.320  55.338  1
593920  92.237  -55.337  55.337  1
593921  92.272  -55.354  55.346  1
593922  92.308  -55.370  55.359  1
593923  92.348  -55.386  55.373  1
593924  92.389  -55.401  55.386  1
593925  92.426  -55.414  55.395  1
593926  92.460  -55.427  55.400  1
593927  92.494  -55.441  55.401  1
593928  92.528  -55.454  55.396  1
593929  92.563  -55.467  55.382  1
593930  92.594  -55.483  55.361  1
593931  92.624  -55.502  55.337  1
593932  92.654  -55.520  55.315  1
593933  92.685  -55.538  55.299  1
593934  92.715  -55.556  55.291  1
593935  92.745  -55.574  55.292  1
593936  92.775  -55.592  55.299  1
593937  92.805  -55.610  55.307  1
593938  92.836  -55.628  55.313  1
593939  92.866  -55.646  55.313  1
593940  92.896  -55.665  55.308  1
593941  92.931  -55.685  55.298  1
593942  92.968  -55.706  55.285  1
593943  93.005  -55.727  55.271  1
593944  93.043  -55.749  55.266  1
593945  93.079  -55.771  55.263  1
593946  93.117  -55.793  55.263  1
593947  93.154  -55.814  55.266  1
593948  93.191  -55.836  55.272  1
593949  93.228  -55.856  55.279  1
593950  93.264  -55.853  55.286  1
593951  93.300  -55.851  55.290  1
593952  93.335  -55.850  55.298  1
593953  93.369  -55.853  55.303  1
593954  93.404  -55.856  55.304  1
593955  93.438  -55.858  55.307  1
593956  93.473  -55.860  55.303  1
593957  93.507  -55.863  55.299  1
593958  93.541  -55.865  55.295  1
593959  93.574  -55.876  55.288  1
593960  93.605  -55.898  55.278  1
593961  93.636  -55.920  55.264  1
593962  93.667  -55.943  55.248  1
593963  93.698  -55.965  55.227  1
593964  93.729  -55.987  55.205  1
593965  93.760  -56.009  55.184  1
593966  93.788  -56.033  55.162  1
593967  93.808  -56.063  55.140  1
593968  93.828  -56.092  55.115  1
593969  93.848  -56.122  55.087  1
593970  93.870  -56.147  55.059  1
593971  93.900  -56.158  55.031  1
593972  93.928  -56.169  55.003  1
593973  93.958  -56.181  54.974  1
593974  93.987  -56.193  54.944  1
593975  94.016  -56.207  54.910  1
593976  94.047  -56.222  54.877  1
593977  94.077  -56.238  54.843  1
593978  94.108  -56.254  54.808  1
593979  94.138  -56.270  54.773  1
593980  94.169  -56.285  54.737  1
593981  94.199  -56.301  54.696  1
593982  94.230  -56.317  54.653  1
593983  94.263  -56.329  54.610  1
593984  94.297  -56.338  54.566  1
593985  94.331  -56.347  54.519  1
593986  94.365  -56.356  54.469  1
593987  94.398  -56.365  54.414  1
593988  94.425  -56.373  54.358  1
593989  94.453  -56.380  54.302  1
593990  94.481  -56.388  54.247  1
593991  94.508  -56.395  54.192  1
593992  94.540  -56.404  54.136  1
593993  94.575  -56.414  54.078  1
593994  94.611  -56.425  54.020  1
593995  94.646  -56.435  53.963  1
593996  94.682  -56.445  53.906  1
593997  94.718  -56.451  53.846  1
593998  94.758  -56.445  53.788  1
593999  94.797  -56.439  53.726  1
594000  94.837  -56.432  53.669  1
594001  94.876  -56.425  53.617  1
594002  94.915  -56.419  53.570  1
594003  94.955  -56.412  53.524  1
594004  94.986  -56.420  53.480  1
594005  95.014  -56.434  53.434  1
594006  95.042  -56.448  53.390  1
594007  95.068  -56.474  53.345  1
594008  95.094  -56.501  53.298  1
594009  95.120  -56.526  53.249  1
594010  95.146  -56.553  53.199  1
594011  95.172  -56.580  53.147  1
594012  95.198  -56.605  53.093  1
594013  95.224  -56.631  53.037  1
594014  95.241  -56.643  52.983  1
594015  95.281  -56.658  52.932  1
594016  95.322  -56.674  52.884  1
594017  95.362  -56.689  52.838  1
594018  95.409  -56.700  52.795  1
594019  95.442  -56.702  52.754  1
594020  95.467  -56.697  52.715  1
594021  95.493  -56.697  52.678  1
594022  95.521  -56.707  52.640  1
594023  95.548  -56.716  52.602  1
594024  95.576  -56.726  52.565  1
594025  95.603  -56.735  52.527  1
594026  95.638  -56.744  52.490  1
594027  95.677  -56.752  52.455  1
594028  95.715  -56.761  52.422  1
594029  95.753  -56.768  52.391  1
594030  95.790  -56.776  52.359  1
594031  95.826  -56.783  52.327  1
594032  95.863  -56.790  52.296  1
594033  95.895  -56.797  52.261  1
594034  95.916  -56.804  52.227  1
594035  95.938  -56.811  52.192  1
594036  95.960  -56.818  52.156  1
594037  95.981  -56.824  52.120  1
594038  96.003  -56.832  52.084  1
594039  96.026  -56.842  52.047  1
594040  96.049  -56.852  52.011  1
594041  96.073  -56.862  51.981  1
594042  96.095  -56.871  51.953  1
594043  96.114  -56.880  51.923  1
594044  96.132  -56.887  51.895  1
594045  96.151  -56.896  51.872  1
594046  96.170  -56.903  51.851  1
594047  96.189  -56.912  51.832  1
594048  96.218  -56.923  51.813  1
594049  96.246  -56.934  51.794  1
594050  96.274  -56.945  51.775  1
594051  96.303  -56.949  51.757  1
594052  96.330  -56.952  51.740  1
594053  96.359  -56.956  51.727  1
594054  96.386  -56.958  51.716  1
594055  96.414  -56.960  51.705  1
594056  96.441  -56.962  51.691  1
594057  96.469  -56.963  51.675  1
594058  96.497  -56.962  51.654  1
594059  96.525  -56.961  51.634  1
594060  96.553  -56.959  51.612  1
594061  96.582  -56.958  51.590  1
594062  96.610  -56.956  51.567  1
594063  96.638  -56.956  51.544  1
594064  96.666  -56.954  51.520  1
594065  96.694  -56.953  51.499  1
594066  96.723  -56.953  51.481  1
594067  96.754  -56.959  51.460  1
594068  96.787  -56.969  51.438  1
594069  96.819  -56.984  51.412  1
594070  96.851  -56.997  51.390  1
594071  96.883  -57.012  51.369  1
594072  96.914  -57.026  51.347  1
594073  96.946  -57.040  51.324  1
594074  96.978  -57.044  51.301  1
594075  97.018  -57.045  51.279  1
594076  97.051  -57.040  51.259  1
594077  97.084  -57.032  51.247  1
594078  97.117  -57.024  51.242  1
594079  97.151  -57.016  51.238  1
594080  97.184  -57.008  51.232  1
594081  97.217  -57.000  51.227  1
594082  97.250  -56.992  51.223  1
594083  97.283  -56.984  51.215  1
594084  97.316  -56.975  51.203  1
594085  97.350  -56.968  51.187  1
594086  97.382  -56.959  51.169  1
594087  97.416  -56.951  51.150  1
594088  97.449  -56.943  51.130  1
594089  97.482  -56.935  51.111  1
594090  97.515  -56.926  51.092  1
594091  97.547  -56.922  51.073  1
594092  97.579  -56.933  51.053  1
594093  97.612  -56.947  51.030  1
594094  97.646  -56.962  51.007  1
594095  97.679  -56.977  50.982  1
594096  97.713  -56.991  50.957  1
594097  97.746  -57.006  50.930  1
594098  97.779  -57.020  50.905  1
594099  97.813  -57.035  50.881  1
594100  97.847  -57.047  50.858  1
594101  97.880  -57.056  50.833  1
594102  97.915  -57.064  50.811  1
594103  97.948  -57.072  50.791  1
594104  97.983  -57.081  50.769  1
594105  98.017  -57.089  50.748  1
594106  98.051  -57.097  50.721  1
594107  98.085  -57.106  50.695  1
594108  98.119  -57.115  50.666  1
594109  98.153  -57.123  50.639  1
594110  98.187  -57.131  50.614  1
594111  98.221  -57.140  50.592  1
594112  98.255  -57.144  50.570  1
594113  98.291  -57.147  50.546  1
594114  98.326  -57.149  50.520  1
594115  98.362  -57.151  50.495  1
594116  98.397  -57.153  50.471  1
594117  98.433  -57.156  50.445  1
594118  98.468  -57.158  50.416  1
594119  98.503  -57.160  50.386  1
594120  98.539  -57.162  50.355  1
594121  98.574  -57.164  50.325  1
594122  98.609  -57.166  50.296  1
594123  98.645  -57.169  50.268  1
594124  98.673  -57.164  50.244  1
594125  98.710  -57.177  50.223  1
594126  98.756  -57.207  50.203  1
594127  98.793  -57.210  50.183  1
594128  98.830  -57.212  50.162  1
594129  98.867  -57.213  50.140  1
594130  98.904  -57.213  50.117  1
594131  98.941  -57.214  50.091  1
594132  98.977  -57.213  50.066  1
594133  99.014  -57.209  50.042  1
594134  99.033  -57.219  50.019  1
594135  99.050  -57.229  49.995  1
594136  99.066  -57.240  49.971  1
594137  99.082  -57.250  49.940  1
594138  99.098  -57.261  49.910  1
594139  99.115  -57.272  49.877  1
594140  99.131  -57.282  49.843  1
594141  99.147  -57.293  49.807  1
594142  99.163  -57.304  49.770  1
594143  99.183  -57.313  49.732  1
594144  99.210  -57.317  49.693  1
594145  99.238  -57.321  49.653  1
594146  99.268  -57.325  49.613  1
594147  99.301  -57.328  49.575  1
594148  99.334  -57.331  49.537  1
594149  99.367  -57.333  49.502  1
594150  99.401  -57.336  49.467  1
594151  99.433  -57.339  49.434  1
594152  99.467  -57.342  49.401  1
594153  99.499  -57.345  49.369  1
594154  99.526  -57.353  49.336  1
594155  99.553  -57.360  49.304  1
594156  99.580  -57.368  49.271  1
594157  99.605  -57.383  49.237  1
594158  99.629  -57.398  49.202  1
594159  99.653  -57.411  49.165  1
594160  99.686  -57.424  49.129  1
594161  99.711  -57.442  49.093  1
594162  99.737  -57.460  49.059  1
594163  99.763  -57.478  49.026  1
594164  99.789  -57.496  48.995  1
594165  99.817  -57.514  48.964  1
594166  99.844  -57.532  48.937  1
594167  99.872  -57.549  48.910  1
594168  99.900  -57.567  48.886  1
594169  99.928  -57.586  48.864  1
594170  99.956  -57.603  48.842  1
594171  99.983  -57.621  48.820  1
594172  100.011  -57.639  48.800  1
594514  88.615  -53.575  57.497  4
594515  88.653  -53.595  57.497  4
594516  88.691  -53.614  57.496  4
594517  88.729  -53.633  57.496  4
594518  88.767  -53.653  57.495  4
594519  88.805  -53.672  57.493  4
594520  88.843  -53.691  57.491  4
594521  88.881  -53.710  57.487  4
594522  88.919  -53.730  57.483  4
594523  88.957  -53.749  57.478  4
594524  88.995  -53.769  57.473  4
594525  89.033  -53.787  57.466  4
594526  89.077  -53.807  57.457  4
594527  89.128  -53.827  57.447  4
594528  89.179  -53.847  57.437  4
594529  89.225  -53.866  57.425  4
594530  89.265  -53.875  57.411  4
594531  89.289  -53.898  57.398  4
594532  89.319  -53.919  57.380  4
594533  89.355  -53.938  57.362  4
594534  89.391  -53.957  57.341  4
594535  89.427  -53.976  57.318  4
594536  89.463  -53.995  57.294  4
594537  89.499  -54.015  57.265  4
594538  89.535  -54.034  57.231  4
594539  89.571  -54.053  57.192  4
594540  89.607  -54.073  57.153  4
594541  89.643  -54.091  57.111  4
594542  89.679  -54.110  57.069  4
594543  89.715  -54.129  57.025  4
594544  89.751  -54.149  56.979  4
594545  89.787  -54.168  56.934  4
594546  89.823  -54.187  56.891  4
594547  89.859  -54.206  56.849  4
594553  90.075  -54.321  56.451  1
594554  90.111  -54.340  56.416  1
594555  90.147  -54.360  56.384  1
594556  90.183  -54.379  56.350  1
594557  90.219  -54.398  56.319  1
594558  90.255  -54.417  56.290  1
594559  90.291  -54.436  56.263  1
594560  90.325  -54.454  56.239  1
594561  90.360  -54.471  56.217  1
594562  90.394  -54.489  56.197  1
594563  90.430  -54.506  56.179  1
594564  90.452  -54.524  56.164  1
594565  90.469  -54.544  56.149  1
594566  90.487  -54.565  56.133  1
594567  90.505  -54.582  56.115  1
594568  90.523  -54.600  56.092  1
594569  90.541  -54.618  56.070  1
594570  90.559  -54.636  56.045  1
594571  90.578  -54.653  56.019  1
594572  90.596  -54.671  55.994  1
594573  90.614  -54.689  55.972  1
594574  90.633  -54.707  55.951  1
594575  90.651  -54.724  55.935  1
594576  90.669  -54.742  55.921  1
594577  90.687  -54.760  55.908  1
594578  90.706  -54.778  55.896  1
594579  90.724  -54.796  55.884  1
594580  90.756  -54.812  55.873  1
594581  90.793  -54.827  55.864  1
594582  90.830  -54.842  55.856  1
594583  90.867  -54.857  55.845  1
594584  90.903  -54.873  55.830  1
594585  90.940  -54.888  55.815  1
594586  90.977  -54.903  55.800  1
594587  91.014  -54.918  55.782  1
594588  91.051  -54.931  55.764  1
594589  91.088  -54.945  55.746  1
594590  91.125  -54.959  55.729  1
594591  91.162  -54.972  55.714  1
594592  91.199  -54.986  55.701  1
594593  91.236  -55.000  55.693  1
594594  91.273  -55.013  55.688  1
594595  91.310  -55.027  55.682  1
594596  91.347  -55.041  55.675  1
594597  91.389  -55.051  55.663  1
594598  91.443  -55.056  55.649  1
594599  91.496  -55.061  55.632  1
594600  91.549  -55.066  55.609  1
594601  91.586  -55.069  55.581  1
594602  91.616  -55.073  55.554  1
594603  91.647  -55.076  55.534  1
594604  91.677  -55.080  55.519  1
594605  91.707  -55.084  55.506  1
594606  91.737  -55.087  55.492  1
594607  91.769  -55.093  55.476  1
594608  91.804  -55.104  55.455  1
594609  91.840  -55.114  55.434  1
594610  91.875  -55.125  55.412  1
594611  91.911  -55.136  55.392  1
594612  91.944  -55.152  55.374  1
594613  91.978  -55.169  55.357  1
594614  92.012  -55.186  55.342  1
594615  92.046  -55.203  55.330  1
594616  92.079  -55.220  55.327  1
594617  92.113  -55.236  55.329  1
594618  92.147  -55.253  55.338  1
594619  92.180  -55.270  55.350  1
594620  92.214  -55.286  55.357  1
594621  92.248  -55.303  55.355  1
594622  92.283  -55.320  55.358  1
594623  92.322  -55.335  55.365  1
594624  92.360  -55.349  55.376  1
594625  92.394  -55.362  55.386  1
594626  92.428  -55.376  55.393  1
594627  92.462  -55.389  55.399  1
594628  92.497  -55.401  55.400  1
594629  92.530  -55.415  55.394  1
594630  92.565  -55.428  55.381  1
594631  92.598  -55.442  55.364  1
594632  92.629  -55.460  55.347  1
594633  92.659  -55.478  55.328  1
594634  92.689  -55.496  55.310  1
594635  92.719  -55.514  55.300  1
594636  92.749  -55.532  55.299  1
594637  92.780  -55.550  55.306  1
594638  92.810  -55.568  55.314  1
594639  92.840  -55.586  55.325  1
594640  92.870  -55.605  55.331  1
594641  92.904  -55.624  55.329  1
594642  92.941  -55.646  55.321  1
594643  92.978  -55.667  55.310  1
594644  93.015  -55.689  55.297  1
594645  93.053  -55.710  55.292  1
594646  93.089  -55.732  55.288  1
594647  93.127  -55.753  55.280  1
594648  93.164  -55.775  55.272  1
594649  93.201  -55.796  55.268  1
594650  93.238  -55.818  55.268  1
594651  93.275  -55.824  55.271  1
594652  93.310  -55.821  55.274  1
594653  93.346  -55.820  55.280  1
594654  93.381  -55.819  55.286  1
594655  93.416  -55.822  55.289  1
594656  93.450  -55.824  55.292  1
594657  93.484  -55.828  55.294  1
594658  93.518  -55.830  55.291  1
594659  93.553  -55.833  55.286  1
594660  93.586  -55.843  55.278  1
594661  93.617  -55.865  55.268  1
594662  93.648  -55.887  55.258  1
594663  93.679  -55.909  55.243  1
594664  93.710  -55.931  55.222  1
594665  93.741  -55.953  55.198  1
594666  93.771  -55.976  55.177  1
594667  93.791  -56.006  55.159  1
594668  93.811  -56.035  55.137  1
594669  93.831  -56.065  55.112  1
594670  93.851  -56.094  55.082  1
594671  93.871  -56.123  55.051  1
594672  93.900  -56.135  55.019  1
594673  93.929  -56.146  54.988  1
594674  93.958  -56.157  54.958  1
594675  93.987  -56.169  54.928  1
594676  94.016  -56.181  54.892  1
594677  94.046  -56.193  54.857  1
594678  94.076  -56.209  54.824  1
594679  94.107  -56.225  54.790  1
594680  94.137  -56.241  54.755  1
594681  94.168  -56.256  54.720  1
594682  94.198  -56.272  54.679  1
594683  94.229  -56.287  54.637  1
594684  94.263  -56.296  54.595  1
594685  94.297  -56.305  54.552  1
594686  94.331  -56.314  54.507  1
594687  94.365  -56.323  54.458  1
594688  94.400  -56.332  54.405  1
594689  94.431  -56.341  54.351  1
594690  94.459  -56.348  54.297  1
594691  94.486  -56.356  54.244  1
594692  94.514  -56.364  54.191  1
594693  94.546  -56.373  54.136  1
594694  94.582  -56.383  54.081  1
594695  94.617  -56.394  54.025  1
594696  94.653  -56.404  53.968  1
594697  94.690  -56.408  53.911  1
594698  94.729  -56.401  53.852  1
594699  94.768  -56.395  53.792  1
594700  94.808  -56.389  53.730  1
594701  94.847  -56.382  53.669  1
594702  94.887  -56.376  53.613  1
594703  94.926  -56.369  53.561  1
594704  94.965  -56.363  53.514  1
594705  94.999  -56.376  53.468  1
594706  95.025  -56.403  53.422  1
594707  95.051  -56.429  53.377  1
594708  95.077  -56.455  53.330  1
594709  95.103  -56.482  53.283  1
594710  95.129  -56.508  53.234  1
594711  95.155  -56.534  53.183  1
594712  95.181  -56.561  53.131  1
594713  95.207  -56.586  53.078  1
594714  95.229  -56.605  53.024  1
594715  95.248  -56.618  52.971  1
594716  95.288  -56.633  52.918  1
594717  95.329  -56.648  52.867  1
594718  95.369  -56.663  52.819  1
594719  95.409  -56.678  52.773  1
594720  95.454  -56.689  52.729  1
594721  95.479  -56.684  52.688  1
594722  95.505  -56.680  52.648  1
594723  95.530  -56.675  52.610  1
594724  95.557  -56.684  52.572  1
594725  95.584  -56.693  52.535  1
594726  95.612  -56.703  52.497  1
594727  95.641  -56.712  52.458  1
594728  95.680  -56.721  52.420  1
594729  95.719  -56.729  52.385  1
594730  95.756  -56.736  52.352  1
594731  95.793  -56.744  52.320  1
594732  95.829  -56.751  52.287  1
594733  95.866  -56.758  52.254  1
594734  95.898  -56.765  52.219  1
594735  95.920  -56.772  52.184  1
594736  95.942  -56.779  52.150  1
594737  95.963  -56.786  52.114  1
594738  95.985  -56.793  52.078  1
594739  96.008  -56.802  52.043  1
594740  96.031  -56.812  52.008  1
594741  96.054  -56.822  51.974  1
594742  96.075  -56.831  51.945  1
594743  96.094  -56.839  51.916  1
594744  96.112  -56.847  51.887  1
594745  96.131  -56.855  51.860  1
594746  96.150  -56.863  51.834  1
594747  96.169  -56.871  51.813  1
594748  96.192  -56.881  51.795  1
594749  96.220  -56.892  51.776  1
594750  96.249  -56.903  51.756  1
594751  96.277  -56.915  51.737  1
594752  96.305  -56.918  51.722  1
594753  96.333  -56.922  51.706  1
594754  96.361  -56.925  51.692  1
594755  96.388  -56.927  51.678  1
594756  96.416  -56.929  51.665  1
594757  96.444  -56.931  51.651  1
594758  96.471  -56.932  51.636  1
594759  96.500  -56.931  51.615  1
594760  96.528  -56.930  51.594  1
594761  96.556  -56.928  51.572  1
594762  96.584  -56.927  51.551  1
594763  96.612  -56.926  51.530  1
594764  96.641  -56.924  51.510  1
594765  96.669  -56.923  51.490  1
594766  96.697  -56.921  51.474  1
594767  96.724  -56.921  51.456  1
594768  96.751  -56.924  51.435  1
594769  96.783  -56.938  51.412  1
594770  96.815  -56.953  51.387  1
594771  96.847  -56.967  51.363  1
594772  96.879  -56.981  51.342  1
594773  96.910  -56.995  51.319  1
594774  96.942  -57.009  51.295  1
594775  96.976  -57.009  51.272  1
594776  97.016  -57.010  51.247  1
594777  97.050  -57.008  51.225  1
594778  97.083  -57.000  51.215  1
594779  97.116  -56.992  51.212  1
594780  97.149  -56.984  51.207  1
594781  97.182  -56.975  51.198  1
594782  97.216  -56.968  51.189  1
594783  97.248  -56.959  51.182  1
594784  97.282  -56.951  51.175  1
594785  97.315  -56.943  51.163  1
594786  97.348  -56.935  51.147  1
594787  97.381  -56.927  51.129  1
594788  97.414  -56.919  51.109  1
594789  97.447  -56.911  51.088  1
594790  97.480  -56.903  51.069  1
594791  97.514  -56.895  51.051  1
594792  97.549  -56.893  51.033  1
594793  97.585  -56.905  51.013  1
594794  97.618  -56.919  50.992  1
594795  97.652  -56.934  50.973  1
594796  97.685  -56.949  50.950  1
594797  97.719  -56.963  50.924  1
594798  97.752  -56.978  50.899  1
594799  97.786  -56.992  50.873  1
594800  97.819  -57.007  50.850  1
594801  97.853  -57.015  50.828  1
594802  97.887  -57.024  50.805  1
594803  97.921  -57.032  50.785  1
594804  97.955  -57.040  50.766  1
594805  97.989  -57.049  50.746  1
594806  98.023  -57.057  50.724  1
594807  98.057  -57.066  50.699  1
594808  98.091  -57.075  50.674  1
594809  98.126  -57.083  50.647  1
594810  98.159  -57.091  50.620  1
594811  98.194  -57.100  50.594  1
594812  98.227  -57.108  50.572  1
594813  98.262  -57.117  50.549  1
594814  98.297  -57.120  50.525  1
594815  98.332  -57.122  50.499  1
594816  98.367  -57.125  50.474  1
594817  98.403  -57.127  50.450  1
594818  98.438  -57.129  50.424  1
594819  98.474  -57.131  50.397  1
594820  98.509  -57.134  50.367  1
594821  98.545  -57.136  50.338  1
594822  98.580  -57.138  50.308  1
594823  98.615  -57.141  50.279  1
594824  98.647  -57.139  50.252  1
594825  98.676  -57.134  50.227  1
594826  98.713  -57.147  50.207  1
594827  98.758  -57.178  50.187  1
594828  98.799  -57.195  50.166  1
594829  98.837  -57.196  50.146  1
594830  98.873  -57.197  50.125  1
594831  98.909  -57.194  50.102  1
594832  98.944  -57.190  50.077  1
594833  98.978  -57.185  50.053  1
594834  99.017  -57.184  50.030  1
594835  99.047  -57.189  50.007  1
594836  99.063  -57.200  49.983  1
594837  99.079  -57.211  49.957  1
594838  99.095  -57.222  49.927  1
594839  99.112  -57.232  49.896  1
594840  99.128  -57.243  49.864  1
594841  99.144  -57.254  49.829  1
594842  99.160  -57.264  49.794  1
594843  99.177  -57.275  49.758  1
594844  99.199  -57.282  49.719  1
594845  99.227  -57.286  49.680  1
594846  99.255  -57.290  49.642  1
594847  99.282  -57.294  49.604  1
594848  99.310  -57.299  49.567  1
594849  99.342  -57.302  49.531  1
594850  99.375  -57.305  49.495  1
594851  99.408  -57.307  49.461  1
594852  99.441  -57.310  49.428  1
594853  99.474  -57.313  49.395  1
594854  99.507  -57.316  49.363  1
594855  99.534  -57.324  49.331  1
594856  99.561  -57.332  49.299  1
594857  99.588  -57.338  49.265  1
594858  99.614  -57.350  49.231  1
594859  99.638  -57.364  49.195  1
594860  99.660  -57.373  49.159  1
594861  99.697  -57.401  49.122  1
594862  99.722  -57.418  49.087  1
594863  99.748  -57.436  49.052  1
594864  99.773  -57.454  49.020  1
594865  99.799  -57.472  48.988  1
594866  99.825  -57.490  48.957  1
594867  99.850  -57.507  48.928  1
594868  99.876  -57.526  48.903  1
594869  99.904  -57.543  48.878  1
594870  99.931  -57.561  48.855  1
594871  99.959  -57.579  48.832  1
594872  99.987  -57.597  48.811  1
594873  100.015  -57.615  48.789  1
595216  88.680  -53.564  57.491  4
595217  88.718  -53.584  57.490  4
595218  88.756  -53.603  57.489  4
595219  88.794  -53.621  57.487  4
595220  88.832  -53.641  57.485  4
595221  88.871  -53.660  57.482  4
595222  88.909  -53.680  57.478  4
595223  88.947  -53.699  57.474  4
595224  88.985  -53.719  57.469  4
595225  89.023  -53.737  57.463  4
595226  89.061  -53.757  57.456  4
595227  89.106  -53.777  57.448  4
595228  89.157  -53.797  57.438  4
595229  89.208  -53.816  57.427  4
595230  89.258  -53.831  57.415  4
595231  89.282  -53.853  57.403  4
595232  89.307  -53.876  57.390  4
595233  89.337  -53.897  57.373  4
595234  89.373  -53.916  57.355  4
595235  89.409  -53.935  57.333  4
595236  89.445  -53.955  57.310  4
595237  89.481  -53.974  57.287  4
595238  89.517  -53.993  57.259  4
595239  89.553  -54.013  57.226  4
595240  89.589  -54.032  57.189  4
595241  89.625  -54.051  57.150  4
595242  89.661  -54.070  57.110  4
595243  89.697  -54.089  57.068  4
595244  89.733  -54.108  57.025  4
595245  89.769  -54.127  56.980  4
595246  89.805  -54.146  56.935  4
595247  89.841  -54.166  56.892  4
595248  89.877  -54.185  56.849  4
595249  89.913  -54.204  56.808  4
595254  90.093  -54.300  56.453  1
595255  90.129  -54.319  56.418  1
595256  90.163  -54.336  56.386  1
595257  90.197  -54.354  56.352  1
595258  90.232  -54.371  56.321  1
595259  90.266  -54.389  56.292  1
595260  90.300  -54.407  56.265  1
595261  90.335  -54.424  56.241  1
595262  90.369  -54.442  56.218  1
595263  90.403  -54.459  56.199  1
595264  90.443  -54.473  56.181  1
595265  90.460  -54.493  56.163  1
595266  90.477  -54.513  56.146  1
595267  90.495  -54.533  56.127  1
595268  90.512  -54.553  56.108  1
595269  90.529  -54.574  56.087  1
595270  90.546  -54.593  56.064  1
595271  90.565  -54.612  56.038  1
595272  90.583  -54.629  56.011  1
595273  90.601  -54.647  55.988  1
595274  90.619  -54.665  55.968  1
595275  90.637  -54.682  55.951  1
595276  90.656  -54.700  55.937  1
595277  90.674  -54.718  55.925  1
595278  90.692  -54.736  55.912  1
595279  90.710  -54.753  55.900  1
595280  90.728  -54.772  55.887  1
595281  90.765  -54.787  55.873  1
595282  90.802  -54.802  55.860  1
595283  90.838  -54.817  55.848  1
595284  90.875  -54.833  55.835  1
595285  90.912  -54.848  55.819  1
595286  90.949  -54.862  55.803  1
595287  90.986  -54.876  55.788  1
595288  91.023  -54.890  55.770  1
595289  91.060  -54.903  55.751  1
595290  91.097  -54.917  55.733  1
595291  91.134  -54.931  55.715  1
595292  91.171  -54.944  55.701  1
595293  91.208  -54.957  55.692  1
595294  91.245  -54.971  55.688  1
595295  91.282  -54.985  55.685  1
595296  91.319  -54.998  55.682  1
595297  91.356  -55.012  55.678  1
595298  91.406  -55.019  55.665  1
595299  91.460  -55.023  55.647  1
595300  91.513  -55.028  55.628  1
595301  91.567  -55.033  55.604  1
595302  91.604  -55.037  55.576  1
595303  91.634  -55.041  55.546  1
595304  91.664  -55.044  55.525  1
595305  91.695  -55.047  55.508  1
595306  91.725  -55.051  55.494  1
595307  91.755  -55.054  55.480  1
595308  91.785  -55.058  55.465  1
595309  91.817  -55.064  55.448  1
595310  91.852  -55.075  55.432  1
595311  91.888  -55.085  55.410  1
595312  91.922  -55.102  55.390  1
595313  91.955  -55.119  55.372  1
595314  91.989  -55.135  55.356  1
595315  92.023  -55.152  55.343  1
595316  92.057  -55.169  55.332  1
595317  92.090  -55.185  55.330  1
595318  92.124  -55.202  55.335  1
595319  92.158  -55.219  55.347  1
595320  92.192  -55.235  55.363  1
595321  92.225  -55.253  55.374  1
595322  92.259  -55.270  55.377  1
595323  92.294  -55.284  55.375  1
595324  92.328  -55.298  55.375  1
595325  92.362  -55.311  55.379  1
595326  92.397  -55.323  55.385  1
595327  92.431  -55.336  55.391  1
595328  92.465  -55.350  55.396  1
595329  92.499  -55.363  55.396  1
595330  92.533  -55.376  55.389  1
595331  92.567  -55.389  55.377  1
595332  92.601  -55.402  55.363  1
595333  92.633  -55.418  55.350  1
595334  92.663  -55.436  55.333  1
595335  92.694  -55.454  55.319  1
595336  92.724  -55.472  55.312  1
595337  92.754  -55.490  55.314  1
595338  92.784  -55.508  55.322  1
595339  92.814  -55.527  55.329  1
595340  92.845  -55.545  55.338  1
595341  92.876  -55.564  55.344  1
595342  92.914  -55.585  55.345  1
595343  92.951  -55.607  55.341  1
595344  92.988  -55.628  55.333  1
595345  93.025  -55.649  55.321  1
595346  93.063  -55.671  55.318  1
595347  93.099  -55.693  55.315  1
595348  93.137  -55.715  55.305  1
595349  93.174  -55.736  55.288  1
595350  93.211  -55.758  55.268  1
595351  93.249  -55.779  55.259  1
595352  93.285  -55.795  55.258  1
595353  93.321  -55.793  55.258  1
595354  93.357  -55.790  55.262  1
595355  93.393  -55.788  55.268  1
595356  93.428  -55.789  55.272  1
595357  93.462  -55.792  55.277  1
595358  93.496  -55.794  55.284  1
595359  93.531  -55.796  55.284  1
595360  93.565  -55.799  55.280  1
595361  93.598  -55.809  55.272  1
595362  93.629  -55.831  55.262  1
595363  93.660  -55.853  55.252  1
595364  93.691  -55.876  55.235  1
595365  93.722  -55.898  55.212  1
595366  93.753  -55.920  55.188  1
595367  93.774  -55.949  55.165  1
595368  93.794  -55.978  55.144  1
595369  93.814  -56.007  55.125  1
595370  93.834  -56.037  55.103  1
595371  93.854  -56.066  55.076  1
595372  93.874  -56.096  55.045  1
595373  93.901  -56.111  55.012  1
595374  93.930  -56.122  54.979  1
595375  93.959  -56.135  54.947  1
595376  93.988  -56.146  54.916  1
595377  94.017  -56.157  54.882  1
595378  94.046  -56.169  54.847  1
595379  94.075  -56.180  54.812  1
595380  94.105  -56.195  54.776  1
595381  94.136  -56.210  54.741  1
595382  94.166  -56.226  54.705  1
595383  94.197  -56.242  54.663  1
595384  94.229  -56.254  54.622  1
595385  94.264  -56.263  54.580  1
595386  94.297  -56.273  54.537  1
595387  94.332  -56.282  54.492  1
595388  94.366  -56.291  54.445  1
595389  94.400  -56.300  54.393  1
595390  94.434  -56.309  54.340  1
595391  94.464  -56.317  54.289  1
595392  94.492  -56.325  54.237  1
595393  94.520  -56.332  54.186  1
595394  94.553  -56.342  54.134  1
595395  94.588  -56.352  54.080  1
595396  94.624  -56.362  54.024  1
595397  94.661  -56.365  53.968  1
595398  94.700  -56.359  53.910  1
595399  94.740  -56.352  53.851  1
595400  94.779  -56.345  53.790  1
595401  94.819  -56.339  53.727  1
595402  94.858  -56.332  53.666  1
595403  94.893  -56.338  53.609  1
595404  94.927  -56.345  53.557  1
595405  94.961  -56.353  53.509  1
595406  95.006  -56.358  53.463  1
595407  95.034  -56.384  53.417  1
595408  95.060  -56.410  53.370  1
595409  95.086  -56.436  53.324  1
595410  95.112  -56.463  53.278  1
595411  95.138  -56.489  53.229  1
595412  95.164  -56.515  53.178  1
595413  95.190  -56.541  53.125  1
595414  95.215  -56.567  53.072  1
595415  95.233  -56.580  53.019  1
595416  95.255  -56.592  52.966  1
595417  95.296  -56.608  52.909  1
595418  95.336  -56.623  52.856  1
595419  95.376  -56.637  52.805  1
595420  95.416  -56.652  52.756  1
595421  95.457  -56.668  52.709  1
595422  95.491  -56.672  52.664  1
595423  95.516  -56.668  52.621  1
595424  95.541  -56.663  52.581  1
595425  95.567  -56.658  52.543  1
595426  95.593  -56.661  52.505  1
595427  95.620  -56.671  52.467  1
595428  95.648  -56.680  52.429  1
595429  95.684  -56.689  52.389  1
595430  95.723  -56.697  52.351  1
595431  95.760  -56.705  52.316  1
595432  95.796  -56.712  52.282  1
595433  95.832  -56.719  52.248  1
595434  95.869  -56.726  52.213  1
595435  95.902  -56.733  52.178  1
595436  95.923  -56.740  52.142  1
595437  95.945  -56.746  52.109  1
595438  95.967  -56.753  52.075  1
595439  95.989  -56.763  52.040  1
595440  96.013  -56.773  52.005  1
595441  96.036  -56.783  51.970  1
595442  96.054  -56.791  51.937  1
595443  96.074  -56.799  51.908  1
595444  96.092  -56.807  51.880  1
595445  96.111  -56.815  51.854  1
595446  96.130  -56.823  51.828  1
595447  96.149  -56.830  51.803  1
595448  96.168  -56.839  51.778  1
595449  96.194  -56.849  51.757  1
595450  96.223  -56.861  51.738  1
595451  96.251  -56.873  51.718  1
595452  96.280  -56.884  51.700  1
595453  96.308  -56.889  51.685  1
595454  96.336  -56.892  51.669  1
595455  96.363  -56.894  51.655  1
595456  96.391  -56.896  51.642  1
595457  96.418  -56.898  51.628  1
595458  96.446  -56.899  51.611  1
595459  96.474  -56.901  51.593  1
595460  96.502  -56.900  51.573  1
595461  96.530  -56.899  51.551  1
595462  96.558  -56.897  51.530  1
595463  96.587  -56.896  51.510  1
595464  96.613  -56.896  51.489  1
595465  96.641  -56.895  51.471  1
595466  96.667  -56.894  51.453  1
595467  96.694  -56.893  51.438  1
595468  96.721  -56.893  51.421  1
595469  96.748  -56.893  51.402  1
595470  96.780  -56.907  51.380  1
595471  96.811  -56.921  51.355  1
595472  96.843  -56.936  51.330  1
595473  96.875  -56.950  51.308  1
595474  96.907  -56.964  51.284  1
595475  96.936  -56.975  51.260  1
595476  96.974  -56.973  51.236  1
595477  97.015  -56.975  51.211  1
595478  97.048  -56.975  51.190  1
595479  97.082  -56.968  51.182  1
595480  97.114  -56.959  51.180  1
595481  97.148  -56.952  51.176  1
595482  97.181  -56.943  51.165  1
595483  97.214  -56.935  51.151  1
595484  97.247  -56.928  51.139  1
595485  97.280  -56.919  51.131  1
595486  97.313  -56.911  51.118  1
595487  97.347  -56.903  51.102  1
595488  97.380  -56.895  51.085  1
595489  97.413  -56.887  51.066  1
595490  97.446  -56.879  51.043  1
595491  97.479  -56.871  51.026  1
595492  97.512  -56.862  51.009  1
595493  97.552  -56.868  50.990  1
595494  97.591  -56.877  50.971  1
595495  97.625  -56.891  50.953  1
595496  97.658  -56.906  50.936  1
595497  97.692  -56.921  50.917  1
595498  97.725  -56.935  50.892  1
595499  97.758  -56.950  50.867  1
595500  97.792  -56.964  50.842  1
595501  97.826  -56.975  50.820  1
595502  97.860  -56.984  50.799  1
595503  97.894  -56.992  50.779  1
595504  97.928  -57.000  50.759  1
595505  97.962  -57.009  50.740  1
595506  97.996  -57.018  50.722  1
595507  98.030  -57.026  50.701  1
595508  98.064  -57.034  50.678  1
595509  98.098  -57.043  50.653  1
595510  98.132  -57.051  50.627  1
595511  98.166  -57.059  50.600  1
595512  98.200  -57.068  50.576  1
595513  98.234  -57.077  50.553  1
595514  98.268  -57.085  50.529  1
595515  98.302  -57.094  50.505  1
595516  98.338  -57.097  50.480  1
595517  98.373  -57.099  50.454  1
595518  98.409  -57.100  50.429  1
595519  98.444  -57.103  50.402  1
595520  98.479  -57.105  50.377  1
595521  98.514  -57.107  50.348  1
595522  98.550  -57.109  50.320  1
595523  98.585  -57.112  50.291  1
595524  98.621  -57.114  50.262  1
595525  98.650  -57.110  50.235  1
595526  98.678  -57.106  50.211  1
595527  98.715  -57.119  50.190  1
595528  98.761  -57.149  50.169  1
595529  98.806  -57.180  50.149  1
595530  98.841  -57.177  50.129  1
595531  98.876  -57.172  50.108  1
595532  98.910  -57.168  50.086  1
595533  98.945  -57.163  50.062  1
595534  98.980  -57.159  50.039  1
595535  99.021  -57.158  50.016  1
595536  99.060  -57.160  49.993  1
595537  99.076  -57.171  49.968  1
595538  99.092  -57.181  49.941  1
595539  99.109  -57.192  49.912  1
595540  99.125  -57.203  49.880  1
595541  99.141  -57.213  49.848  1
595542  99.157  -57.224  49.815  1
595543  99.173  -57.235  49.779  1
595544  99.190  -57.246  49.744  1
595545  99.216  -57.250  49.706  1
595546  99.244  -57.255  49.668  1
595547  99.272  -57.259  49.631  1
595548  99.299  -57.263  49.594  1
595549  99.327  -57.267  49.558  1
595550  99.355  -57.272  49.523  1
595551  99.382  -57.276  49.488  1
595552  99.416  -57.279  49.454  1
595553  99.448  -57.282  49.422  1
595554  99.482  -57.285  49.389  1
595555  99.514  -57.288  49.357  1
595556  99.542  -57.295  49.325  1
595557  99.569  -57.303  49.292  1
595558  99.595  -57.310  49.258  1
595559  99.623  -57.317  49.224  1
595560  99.647  -57.332  49.188  1
595561  99.682  -57.359  49.152  1
595562  99.708  -57.376  49.115  1
595563  99.733  -57.395  49.080  1
595564  99.759  -57.412  49.045  1
595565  99.784  -57.430  49.013  1
595566  99.810  -57.448  48.981  1
595567  99.835  -57.466  48.950  1
595568  99.861  -57.484  48.920  1
595569  99.887  -57.501  48.894  1
595570  99.912  -57.520  48.869  1
595571  99.937  -57.537  48.845  1
595572  99.963  -57.555  48.822  1
595573  99.991  -57.573  48.800  1
595574  100.018  -57.591  48.779  1
595917  88.708  -53.534  57.484  4
595918  88.746  -53.552  57.483  4
595919  88.784  -53.572  57.482  4
595920  88.822  -53.591  57.479  4
595921  88.860  -53.610  57.477  4
595922  88.898  -53.630  57.473  4
595923  88.936  -53.649  57.470  4
595924  88.974  -53.668  57.465  4
595925  89.012  -53.687  57.460  4
595926  89.050  -53.707  57.454  4
595927  89.088  -53.726  57.448  4
595928  89.134  -53.746  57.439  4
595929  89.185  -53.766  57.429  4
595930  89.237  -53.786  57.418  4
595931  89.276  -53.809  57.406  4
595932  89.300  -53.832  57.394  4
595933  89.324  -53.855  57.381  4
595934  89.354  -53.875  57.363  4
595935  89.391  -53.895  57.345  4
595936  89.426  -53.914  57.325  4
595937  89.463  -53.933  57.303  4
595938  89.498  -53.953  57.279  4
595939  89.535  -53.972  57.254  4
595940  89.570  -53.991  57.221  4
595941  89.607  -54.010  57.185  4
595942  89.642  -54.029  57.148  4
595943  89.679  -54.048  57.108  4
595944  89.715  -54.067  57.067  4
595945  89.751  -54.086  57.025  4
595946  89.787  -54.106  56.980  4
595947  89.823  -54.125  56.936  4
595948  89.859  -54.144  56.892  4
595949  89.895  -54.164  56.850  4
595950  89.931  -54.182  56.809  4
595955  90.104  -54.271  56.455  1
595956  90.138  -54.289  56.420  1
595957  90.172  -54.307  56.386  1
595958  90.206  -54.324  56.354  1
595959  90.241  -54.342  56.322  1
595960  90.275  -54.359  56.293  1
595961  90.310  -54.377  56.266  1
595962  90.344  -54.394  56.241  1
595963  90.378  -54.412  56.219  1
595964  90.416  -54.427  56.199  1
595965  90.450  -54.441  56.180  1
595966  90.468  -54.461  56.160  1
595967  90.485  -54.481  56.141  1
595968  90.502  -54.502  56.122  1
595969  90.519  -54.521  56.103  1
595970  90.536  -54.542  56.081  1
595971  90.554  -54.562  56.057  1
595972  90.571  -54.582  56.030  1
595973  90.588  -54.602  56.005  1
595974  90.605  -54.622  55.984  1
595975  90.623  -54.640  55.965  1
595976  90.642  -54.658  55.952  1
595977  90.660  -54.676  55.940  1
595978  90.678  -54.693  55.928  1
595979  90.696  -54.712  55.915  1
595980  90.715  -54.729  55.903  1
595981  90.737  -54.746  55.887  1
595982  90.773  -54.762  55.870  1
595983  90.810  -54.777  55.854  1
595984  90.848  -54.793  55.838  1
595985  90.884  -54.807  55.822  1
595986  90.921  -54.821  55.806  1
595987  90.958  -54.834  55.790  1
595988  90.995  -54.847  55.775  1
595989  91.032  -54.861  55.756  1
595990  91.069  -54.875  55.737  1
595991  91.106  -54.888  55.720  1
595992  91.143  -54.902  55.704  1
595993  91.180  -54.916  55.692  1
595994  91.217  -54.929  55.685  1
595995  91.254  -54.943  55.684  1
595996  91.291  -54.956  55.685  1
595997  91.328  -54.970  55.683  1
595998  91.370  -54.981  55.679  1
595999  91.424  -54.986  55.666  1
596000  91.477  -54.991  55.645  1
596001  91.530  -54.996  55.623  1
596002  91.584  -55.000  55.599  1
596003  91.622  -55.005  55.570  1
596004  91.652  -55.008  55.539  1
596005  91.682  -55.012  55.516  1
596006  91.712  -55.015  55.499  1
596007  91.742  -55.019  55.484  1
596008  91.773  -55.022  55.469  1
596009  91.803  -55.025  55.455  1
596010  91.833  -55.029  55.441  1
596011  91.865  -55.035  55.428  1
596012  91.899  -55.051  55.408  1
596013  91.933  -55.068  55.388  1
596014  91.966  -55.085  55.370  1
596015  92.000  -55.102  55.355  1
596016  92.034  -55.119  55.343  1
596017  92.068  -55.137  55.333  1
596018  92.102  -55.155  55.331  1
596019  92.136  -55.173  55.337  1
596020  92.170  -55.190  55.351  1
596021  92.204  -55.207  55.368  1
596022  92.237  -55.225  55.382  1
596023  92.272  -55.242  55.387  1
596024  92.307  -55.248  55.388  1
596025  92.333  -55.259  55.386  1
596026  92.365  -55.272  55.384  1
596027  92.399  -55.285  55.385  1
596028  92.433  -55.298  55.392  1
596029  92.467  -55.311  55.392  1
596030  92.501  -55.324  55.389  1
596031  92.535  -55.337  55.381  1
596032  92.569  -55.350  55.370  1
596033  92.603  -55.364  55.359  1
596034  92.638  -55.376  55.349  1
596035  92.668  -55.394  55.335  1
596036  92.698  -55.412  55.328  1
596037  92.728  -55.430  55.324  1
596038  92.759  -55.448  55.328  1
596039  92.789  -55.467  55.340  1
596040  92.819  -55.485  55.346  1
596041  92.849  -55.503  55.352  1
596042  92.886  -55.524  55.357  1
596043  92.924  -55.546  55.359  1
596044  92.961  -55.568  55.357  1
596045  92.998  -55.589  55.351  1
596046  93.036  -55.611  55.343  1
596047  93.073  -55.632  55.341  1
596048  93.110  -55.654  55.337  1
596049  93.147  -55.675  55.325  1
596050  93.184  -55.697  55.308  1
596051  93.221  -55.718  55.291  1
596052  93.259  -55.740  55.277  1
596053  93.296  -55.762  55.268  1
596054  93.332  -55.763  55.260  1
596055  93.368  -55.761  55.254  1
596056  93.404  -55.759  55.253  1
596057  93.439  -55.757  55.256  1
596058  93.474  -55.759  55.264  1
596059  93.508  -55.761  55.273  1
596060  93.542  -55.764  55.277  1
596061  93.577  -55.766  55.275  1
596062  93.610  -55.776  55.269  1
596063  93.641  -55.798  55.260  1
596064  93.672  -55.820  55.245  1
596065  93.703  -55.843  55.226  1
596066  93.734  -55.865  55.203  1
596067  93.757  -55.892  55.178  1
596068  93.777  -55.922  55.153  1
596069  93.797  -55.950  55.129  1
596070  93.817  -55.980  55.109  1
596071  93.837  -56.009  55.089  1
596072  93.857  -56.039  55.064  1
596073  93.876  -56.069  55.034  1
596074  93.902  -56.088  55.002  1
596075  93.931  -56.100  54.967  1
596076  93.960  -56.111  54.933  1
596077  93.989  -56.122  54.901  1
596078  94.018  -56.134  54.869  1
596079  94.047  -56.145  54.837  1
596080  94.076  -56.157  54.804  1
596081  94.105  -56.169  54.771  1
596082  94.134  -56.181  54.739  1
596083  94.165  -56.197  54.704  1
596084  94.196  -56.212  54.662  1
596085  94.230  -56.221  54.618  1
596086  94.264  -56.230  54.574  1
596087  94.298  -56.239  54.527  1
596088  94.332  -56.248  54.479  1
596089  94.366  -56.257  54.433  1
596090  94.400  -56.266  54.383  1
596091  94.434  -56.276  54.330  1
596092  94.469  -56.285  54.279  1
596093  94.497  -56.293  54.230  1
596094  94.525  -56.301  54.180  1
596095  94.559  -56.310  54.128  1
596096  94.595  -56.320  54.074  1
596097  94.632  -56.322  54.019  1
596098  94.672  -56.316  53.962  1
596099  94.711  -56.309  53.904  1
596100  94.750  -56.302  53.845  1
596101  94.786  -56.305  53.784  1
596102  94.821  -56.313  53.722  1
596103  94.855  -56.320  53.662  1
596104  94.889  -56.328  53.606  1
596105  94.923  -56.335  53.555  1
596106  94.960  -56.342  53.507  1
596107  95.007  -56.348  53.461  1
596108  95.042  -56.364  53.415  1
596109  95.068  -56.391  53.368  1
596110  95.095  -56.417  53.322  1
596111  95.120  -56.443  53.276  1
596112  95.146  -56.470  53.227  1
596113  95.173  -56.496  53.175  1
596114  95.199  -56.522  53.123  1
596115  95.220  -56.541  53.070  1
596116  95.238  -56.554  53.017  1
596117  95.262  -56.567  52.963  1
596118  95.302  -56.582  52.905  1
596119  95.343  -56.597  52.848  1
596120  95.383  -56.612  52.794  1
596121  95.423  -56.627  52.743  1
596122  95.464  -56.642  52.693  1
596123  95.500  -56.652  52.646  1
596124  95.527  -56.652  52.600  1
596125  95.553  -56.650  52.557  1
596126  95.579  -56.646  52.517  1
596127  95.604  -56.641  52.477  1
596128  95.629  -56.639  52.438  1
596129  95.657  -56.648  52.400  1
596130  95.687  -56.658  52.360  1
596131  95.726  -56.666  52.320  1
596132  95.763  -56.673  52.282  1
596133  95.799  -56.680  52.246  1
596134  95.836  -56.687  52.210  1
596135  95.872  -56.694  52.174  1
596136  95.905  -56.701  52.138  1
596137  95.927  -56.708  52.103  1
596138  95.949  -56.714  52.071  1
596139  95.971  -56.724  52.038  1
596140  95.994  -56.733  52.004  1
596141  96.016  -56.743  51.970  1
596142  96.035  -56.751  51.933  1
596143  96.053  -56.758  51.900  1
596144  96.073  -56.767  51.871  1
596145  96.091  -56.774  51.845  1
596146  96.110  -56.783  51.822  1
596147  96.129  -56.790  51.798  1
596148  96.148  -56.799  51.774  1
596149  96.169  -56.807  51.744  1
596150  96.197  -56.818  51.720  1
596151  96.226  -56.830  51.699  1
596152  96.254  -56.842  51.680  1
596153  96.283  -56.853  51.663  1
596154  96.311  -56.859  51.646  1
596155  96.338  -56.862  51.629  1
596156  96.366  -56.863  51.617  1
596157  96.393  -56.865  51.604  1
596158  96.421  -56.867  51.590  1
596159  96.449  -56.868  51.572  1
596160  96.476  -56.871  51.553  1
596161  96.504  -56.869  51.532  1
596162  96.530  -56.869  51.510  1
596163  96.557  -56.868  51.489  1
596164  96.584  -56.868  51.469  1
596165  96.611  -56.867  51.450  1
596166  96.638  -56.867  51.432  1
596167  96.664  -56.866  51.416  1
596168  96.691  -56.865  51.402  1
596169  96.718  -56.865  51.385  1
596170  96.745  -56.865  51.366  1
596171  96.776  -56.877  51.345  1
596172  96.807  -56.890  51.322  1
596173  96.839  -56.905  51.299  1
596174  96.871  -56.919  51.277  1
596175  96.903  -56.934  51.253  1
596176  96.929  -56.937  51.228  1
596177  96.972  -56.938  51.202  1
596178  97.013  -56.940  51.176  1
596179  97.047  -56.940  51.153  1
596180  97.080  -56.936  51.142  1
596181  97.113  -56.928  51.137  1
596182  97.146  -56.919  51.132  1
596183  97.179  -56.912  51.123  1
596184  97.213  -56.903  51.108  1
596185  97.246  -56.895  51.094  1
596186  97.279  -56.887  51.083  1
596187  97.312  -56.879  51.069  1
596188  97.345  -56.871  51.054  1
596189  97.378  -56.863  51.038  1
596190  97.412  -56.855  51.019  1
596191  97.444  -56.846  51.000  1
596192  97.477  -56.838  50.983  1
596193  97.514  -56.837  50.965  1
596194  97.555  -56.843  50.947  1
596195  97.596  -56.850  50.929  1
596196  97.631  -56.863  50.913  1
596197  97.665  -56.877  50.897  1
596198  97.698  -56.893  50.880  1
596199  97.731  -56.907  50.858  1
596200  97.765  -56.921  50.835  1
596201  97.798  -56.935  50.813  1
596202  97.832  -56.943  50.791  1
596203  97.867  -56.952  50.774  1
596204  97.900  -56.960  50.756  1
596205  97.935  -56.968  50.737  1
596206  97.968  -56.978  50.719  1
596207  98.003  -56.986  50.702  1
596208  98.037  -56.994  50.685  1
596209  98.071  -57.003  50.660  1
596210  98.105  -57.011  50.632  1
596211  98.139  -57.019  50.606  1
596212  98.173  -57.028  50.582  1
596213  98.207  -57.037  50.559  1
596214  98.241  -57.045  50.536  1
596215  98.275  -57.053  50.515  1
596216  98.309  -57.062  50.490  1
596217  98.343  -57.070  50.463  1
596218  98.378  -57.072  50.436  1
596219  98.414  -57.075  50.409  1
596220  98.449  -57.077  50.381  1
596221  98.485  -57.079  50.355  1
596222  98.520  -57.081  50.327  1
596223  98.556  -57.083  50.299  1
596224  98.591  -57.085  50.271  1
596225  98.624  -57.085  50.244  1
596226  98.652  -57.081  50.219  1
596227  98.681  -57.076  50.195  1
596228  98.718  -57.089  50.171  1
596229  98.763  -57.120  50.149  1
596230  98.806  -57.146  50.129  1
596231  98.843  -57.150  50.109  1
596232  98.877  -57.146  50.089  1
596233  98.912  -57.141  50.069  1
596234  98.946  -57.137  50.045  1
596235  98.981  -57.132  50.022  1
596236  99.024  -57.132  49.999  1
596237  99.069  -57.133  49.976  1
596238  99.089  -57.142  49.951  1
596239  99.106  -57.153  49.923  1
596240  99.122  -57.163  49.895  1
596241  99.138  -57.174  49.863  1
596242  99.154  -57.185  49.832  1
596243  99.170  -57.195  49.799  1
596244  99.187  -57.206  49.764  1
596245  99.205  -57.215  49.729  1
596246  99.233  -57.219  49.694  1
596247  99.261  -57.223  49.657  1
596248  99.288  -57.228  49.621  1
596249  99.316  -57.232  49.586  1
596250  99.344  -57.236  49.549  1
596251  99.371  -57.241  49.515  1
596252  99.399  -57.245  49.481  1
596253  99.427  -57.249  49.449  1
596254  99.456  -57.253  49.416  1
596255  99.489  -57.256  49.383  1
596256  99.522  -57.259  49.351  1
596257  99.549  -57.266  49.319  1
596258  99.576  -57.274  49.284  1
596259  99.603  -57.281  49.250  1
596260  99.630  -57.288  49.216  1
596261  99.657  -57.310  49.180  1
596262  99.693  -57.335  49.143  1
596263  99.718  -57.353  49.107  1
596264  99.744  -57.370  49.072  1
596265  99.770  -57.388  49.038  1
596266  99.795  -57.406  49.005  1
596267  99.821  -57.424  48.973  1
596268  99.846  -57.442  48.941  1
596269  99.872  -57.460  48.911  1
596270  99.898  -57.478  48.885  1
596271  99.923  -57.495  48.858  1
596272  99.948  -57.514  48.834  1
596273  99.974  -57.531  48.811  1
596274  100.000  -57.549  48.789  1
596615  88.621  -53.445  57.479  4
596616  88.660  -53.464  57.478  4
596617  88.697  -53.483  57.478  4
596618  88.736  -53.502  57.477  4
596619  88.773  -53.522  57.476  4
596620  88.812  -53.541  57.474  4
596621  88.849  -53.561  57.472  4
596622  88.888  -53.580  57.469  4
596623  88.925  -53.599  57.465  4
596624  88.964  -53.618  57.461  4
596625  89.002  -53.637  57.457  4
596626  89.040  -53.657  57.451  4
596627  89.078  -53.676  57.445  4
596628  89.116  -53.696  57.440  4
596629  89.163  -53.715  57.430  4
596630  89.214  -53.735  57.420  4
596631  89.259  -53.757  57.409  4
596632  89.290  -53.784  57.398  4
596633  89.318  -53.810  57.385  4
596634  89.342  -53.833  57.373  4
596635  89.373  -53.854  57.354  4
596636  89.408  -53.873  57.336  4
596637  89.444  -53.893  57.317  4
596638  89.480  -53.912  57.295  4
596639  89.516  -53.931  57.272  4
596640  89.552  -53.950  57.247  4
596641  89.588  -53.969  57.216  4
596642  89.624  -53.988  57.182  4
596643  89.660  -54.007  57.145  4
596644  89.696  -54.026  57.107  4
596645  89.732  -54.046  57.066  4
596646  89.768  -54.065  57.025  4
596647  89.804  -54.084  56.980  4
596648  89.838  -54.101  56.937  4
596649  89.873  -54.119  56.893  4
596650  89.907  -54.136  56.851  4
596651  89.941  -54.154  56.810  4
596656  90.113  -54.242  56.457  1
596657  90.148  -54.259  56.422  1
596658  90.182  -54.276  56.388  1
596659  90.216  -54.295  56.355  1
596660  90.250  -54.312  56.323  1
596661  90.285  -54.330  56.293  1
596662  90.319  -54.347  56.266  1
596663  90.354  -54.364  56.240  1
596664  90.389  -54.381  56.219  1
596665  90.432  -54.392  56.197  1
596666  90.458  -54.410  56.176  1
596667  90.475  -54.430  56.155  1
596668  90.493  -54.450  56.136  1
596669  90.510  -54.470  56.117  1
596670  90.527  -54.490  56.098  1
596671  90.544  -54.511  56.075  1
596672  90.561  -54.530  56.049  1
596673  90.579  -54.551  56.023  1
596674  90.596  -54.571  55.999  1
596675  90.613  -54.591  55.979  1
596676  90.630  -54.612  55.965  1
596677  90.648  -54.631  55.953  1
596678  90.665  -54.652  55.941  1
596679  90.683  -54.669  55.929  1
596680  90.701  -54.687  55.915  1
596681  90.719  -54.705  55.902  1
596682  90.746  -54.721  55.884  1
596683  90.783  -54.737  55.864  1
596684  90.819  -54.751  55.844  1
596685  90.856  -54.765  55.825  1
596686  90.893  -54.778  55.807  1
596687  90.930  -54.792  55.792  1
596688  90.967  -54.806  55.776  1
596689  91.004  -54.819  55.761  1
596690  91.041  -54.833  55.742  1
596691  91.078  -54.847  55.723  1
596692  91.115  -54.860  55.706  1
596693  91.152  -54.874  55.693  1
596694  91.189  -54.887  55.683  1
596695  91.226  -54.901  55.680  1
596696  91.263  -54.915  55.680  1
596697  91.300  -54.928  55.682  1
596698  91.337  -54.942  55.681  1
596699  91.387  -54.949  55.677  1
596700  91.441  -54.953  55.664  1
596701  91.494  -54.959  55.643  1
596702  91.547  -54.963  55.618  1
596703  91.601  -54.968  55.591  1
596704  91.640  -54.972  55.562  1
596705  91.670  -54.975  55.532  1
596706  91.700  -54.979  55.508  1
596707  91.730  -54.983  55.490  1
596708  91.760  -54.986  55.475  1
596709  91.790  -54.990  55.461  1
596710  91.820  -54.993  55.448  1
596711  91.851  -54.997  55.435  1
596712  91.879  -55.004  55.422  1
596713  91.911  -55.024  55.405  1
596714  91.945  -55.041  55.386  1
596715  91.979  -55.059  55.368  1
596716  92.013  -55.076  55.353  1
596717  92.047  -55.094  55.341  1
596718  92.081  -55.112  55.333  1
596719  92.115  -55.129  55.331  1
596720  92.148  -55.147  55.337  1
596721  92.182  -55.164  55.351  1
596722  92.216  -55.182  55.368  1
596723  92.250  -55.199  55.384  1
596724  92.285  -55.213  55.391  1
596725  92.324  -55.216  55.394  1
596726  92.353  -55.225  55.392  1
596727  92.379  -55.236  55.388  1
596728  92.406  -55.247  55.386  1
596729  92.435  -55.259  55.388  1
596730  92.470  -55.272  55.384  1
596731  92.503  -55.285  55.379  1
596732  92.537  -55.298  55.371  1
596733  92.572  -55.311  55.363  1
596734  92.606  -55.324  55.353  1
596735  92.640  -55.338  55.344  1
596736  92.673  -55.352  55.339  1
596737  92.703  -55.370  55.336  1
596738  92.733  -55.389  55.334  1
596739  92.763  -55.407  55.338  1
596740  92.793  -55.425  55.356  1
596741  92.824  -55.443  55.365  1
596742  92.859  -55.464  55.369  1
596743  92.897  -55.486  55.371  1
596744  92.934  -55.507  55.371  1
596745  92.971  -55.529  55.370  1
596746  93.008  -55.550  55.366  1
596747  93.046  -55.571  55.363  1
596748  93.083  -55.593  55.361  1
596749  93.120  -55.614  55.356  1
596750  93.157  -55.636  55.343  1
596751  93.194  -55.658  55.325  1
596752  93.231  -55.680  55.308  1
596753  93.269  -55.701  55.292  1
596754  93.306  -55.723  55.279  1
596755  93.343  -55.734  55.269  1
596756  93.378  -55.732  55.262  1
596757  93.414  -55.730  55.256  1
596758  93.450  -55.727  55.252  1
596759  93.486  -55.725  55.254  1
596760  93.520  -55.728  55.260  1
596761  93.554  -55.730  55.264  1
596762  93.588  -55.733  55.264  1
596763  93.622  -55.743  55.259  1
596764  93.653  -55.765  55.251  1
596765  93.684  -55.787  55.238  1
596766  93.715  -55.809  55.220  1
596767  93.740  -55.835  55.198  1
596768  93.760  -55.864  55.173  1
596769  93.780  -55.893  55.146  1
596770  93.800  -55.923  55.119  1
596771  93.820  -55.953  55.091  1
596772  93.840  -55.982  55.070  1
596773  93.859  -56.012  55.047  1
596774  93.880  -56.041  55.019  1
596775  93.902  -56.064  54.988  1
596776  93.931  -56.076  54.954  1
596777  93.961  -56.088  54.918  1
596778  93.989  -56.099  54.886  1
596779  94.018  -56.110  54.855  1
596780  94.048  -56.122  54.825  1
596781  94.077  -56.134  54.796  1
596782  94.106  -56.145  54.766  1
596783  94.135  -56.157  54.735  1
596784  94.164  -56.168  54.701  1
596785  94.196  -56.179  54.661  1
596786  94.230  -56.188  54.617  1
596787  94.264  -56.197  54.571  1
596788  94.298  -56.207  54.523  1
596789  94.333  -56.216  54.475  1
596790  94.367  -56.225  54.428  1
596791  94.401  -56.234  54.377  1
596792  94.435  -56.243  54.325  1
596793  94.469  -56.252  54.273  1
596794  94.503  -56.261  54.222  1
596795  94.531  -56.269  54.172  1
596796  94.565  -56.279  54.120  1
596797  94.603  -56.279  54.065  1
596798  94.642  -56.273  54.008  1
596799  94.680  -56.273  53.949  1
596800  94.714  -56.280  53.889  1
596801  94.748  -56.288  53.830  1
596802  94.782  -56.295  53.772  1
596803  94.817  -56.303  53.714  1
596804  94.851  -56.310  53.658  1
596805  94.885  -56.318  53.605  1
596806  94.919  -56.326  53.555  1
596807  94.960  -56.332  53.509  1
596808  95.007  -56.337  53.464  1
596809  95.051  -56.345  53.418  1
596810  95.077  -56.372  53.370  1
596811  95.103  -56.398  53.323  1
596812  95.129  -56.424  53.277  1
596813  95.156  -56.451  53.228  1
596814  95.181  -56.477  53.174  1
596815  95.207  -56.502  53.121  1
596816  95.225  -56.515  53.069  1
596817  95.242  -56.528  53.015  1
596818  95.269  -56.542  52.961  1
596819  95.309  -56.557  52.903  1
596820  95.349  -56.572  52.844  1
596821  95.390  -56.586  52.787  1
596822  95.430  -56.602  52.733  1
596823  95.469  -56.614  52.681  1
596824  95.507  -56.623  52.631  1
596825  95.534  -56.624  52.583  1
596826  95.561  -56.624  52.538  1
596827  95.588  -56.625  52.495  1
596828  95.615  -56.625  52.453  1
596829  95.641  -56.624  52.412  1
596830  95.666  -56.620  52.373  1
596831  95.693  -56.625  52.333  1
596832  95.730  -56.634  52.292  1
596833  95.766  -56.641  52.253  1
596834  95.803  -56.648  52.215  1
596835  95.839  -56.655  52.176  1
596836  95.875  -56.662  52.138  1
596837  95.909  -56.669  52.101  1
596838  95.931  -56.676  52.065  1
596839  95.953  -56.684  52.033  1
596840  95.976  -56.694  52.001  1
596841  95.995  -56.702  51.969  1
596842  96.015  -56.710  51.936  1
596843  96.033  -56.718  51.900  1
596844  96.052  -56.726  51.866  1
596845  96.071  -56.734  51.836  1
596846  96.090  -56.743  51.812  1
596847  96.109  -56.750  51.790  1
596848  96.128  -56.758  51.765  1
596849  96.147  -56.766  51.740  1
596850  96.171  -56.777  51.711  1
596851  96.200  -56.788  51.685  1
596852  96.228  -56.799  51.661  1
596853  96.256  -56.811  51.640  1
596854  96.287  -56.822  51.623  1
596855  96.312  -56.830  51.606  1
596856  96.340  -56.832  51.589  1
596857  96.368  -56.834  51.575  1
596858  96.395  -56.837  51.563  1
596859  96.422  -56.839  51.550  1
596860  96.450  -56.840  51.535  1
596861  96.475  -56.840  51.517  1
596862  96.501  -56.841  51.492  1
596863  96.527  -56.841  51.470  1
596864  96.554  -56.840  51.448  1
596865  96.581  -56.840  51.428  1
596866  96.608  -56.839  51.412  1
596867  96.635  -56.839  51.394  1
596868  96.661  -56.838  51.378  1
596869  96.688  -56.837  51.364  1
596870  96.715  -56.837  51.348  1
596871  96.742  -56.837  51.328  1
596872  96.772  -56.846  51.307  1
596873  96.804  -56.860  51.288  1
596874  96.835  -56.874  51.267  1
596875  96.867  -56.888  51.246  1
596876  96.899  -56.903  51.223  1
596877  96.921  -56.901  51.197  1
596878  96.970  -56.903  51.168  1
596879  97.012  -56.904  51.141  1
596880  97.045  -56.905  51.118  1
596881  97.079  -56.903  51.102  1
596882  97.112  -56.895  51.092  1
596883  97.145  -56.887  51.085  1
596884  97.178  -56.879  51.076  1
596885  97.211  -56.871  51.063  1
596886  97.244  -56.863  51.048  1
596887  97.278  -56.855  51.035  1
596888  97.310  -56.846  51.023  1
596889  97.344  -56.839  51.009  1
596890  97.377  -56.830  50.995  1
596891  97.410  -56.822  50.977  1
596892  97.443  -56.815  50.959  1
596893  97.476  -56.806  50.942  1
596894  97.517  -56.812  50.924  1
596895  97.558  -56.819  50.906  1
596896  97.599  -56.826  50.889  1
596897  97.638  -56.835  50.872  1
596898  97.671  -56.849  50.856  1
596899  97.705  -56.864  50.839  1
596900  97.738  -56.879  50.820  1
596901  97.771  -56.893  50.800  1
596902  97.805  -56.903  50.781  1
596903  97.839  -56.912  50.762  1
596904  97.873  -56.920  50.747  1
596905  97.908  -56.928  50.730  1
596906  97.941  -56.937  50.714  1
596907  97.975  -56.946  50.698  1
596908  98.009  -56.954  50.682  1
596909  98.043  -56.962  50.667  1
596910  98.078  -56.971  50.643  1
596911  98.111  -56.979  50.614  1
596912  98.146  -56.988  50.588  1
596913  98.179  -56.997  50.564  1
596914  98.214  -57.005  50.542  1
596915  98.247  -57.013  50.521  1
596916  98.282  -57.022  50.500  1
596917  98.316  -57.030  50.475  1
596918  98.350  -57.038  50.448  1
596919  98.384  -57.046  50.420  1
596920  98.420  -57.048  50.392  1
596921  98.455  -57.050  50.364  1
596922  98.490  -57.053  50.336  1
596923  98.525  -57.055  50.307  1
596924  98.561  -57.057  50.280  1
596925  98.596  -57.059  50.253  1
596926  98.626  -57.056  50.227  1
596927  98.655  -57.051  50.203  1
596928  98.684  -57.047  50.178  1
596929  98.720  -57.060  50.154  1
596930  98.765  -57.090  50.131  1
596931  98.805  -57.111  50.109  1
596932  98.844  -57.124  50.088  1
596933  98.878  -57.119  50.068  1
596934  98.913  -57.115  50.047  1
596935  98.947  -57.110  50.026  1
596936  98.984  -57.106  50.003  1
596937  99.028  -57.106  49.980  1
596938  99.072  -57.107  49.957  1
596939  99.102  -57.113  49.931  1
596940  99.119  -57.123  49.902  1
596941  99.135  -57.134  49.874  1
596942  99.151  -57.144  49.844  1
596943  99.167  -57.156  49.813  1
596944  99.183  -57.166  49.781  1
596945  99.200  -57.177  49.747  1
596946  99.222  -57.184  49.713  1
596947  99.250  -57.188  49.680  1
596948  99.277  -57.192  49.645  1
596949  99.305  -57.197  49.609  1
596950  99.333  -57.201  49.574  1
596951  99.360  -57.205  49.539  1
596952  99.388  -57.210  49.504  1
596953  99.416  -57.213  49.471  1
596954  99.443  -57.218  49.439  1
596955  99.471  -57.222  49.407  1
596956  99.499  -57.226  49.375  1
596957  99.529  -57.230  49.344  1
596958  99.557  -57.238  49.311  1
596959  99.592  -57.256  49.276  1
596960  99.628  -57.273  49.241  1
596961  99.648  -57.267  49.206  1
596962  99.679  -57.293  49.170  1
596963  99.704  -57.311  49.134  1
596964  99.729  -57.329  49.097  1
596965  99.755  -57.347  49.062  1
596966  99.781  -57.364  49.027  1
596967  99.806  -57.382  48.994  1
596968  99.832  -57.401  48.962  1
596969  99.857  -57.418  48.931  1
596970  99.883  -57.436  48.901  1
596971  99.908  -57.454  48.874  1
596972  99.934  -57.472  48.848  1
596973  99.960  -57.489  48.823  1
596974  99.985  -57.507  48.799  1
596975  100.010  -57.525  48.776  1
597313  88.535  -53.356  57.474  4
597314  88.573  -53.375  57.474  4
597315  88.611  -53.395  57.474  4
597316  88.649  -53.414  57.473  4
597317  88.687  -53.433  57.472  4
597318  88.725  -53.452  57.472  4
597319  88.763  -53.472  57.470  4
597320  88.801  -53.491  57.468  4
597321  88.839  -53.511  57.467  4
597322  88.877  -53.530  57.464  4
597323  88.915  -53.549  57.461  4
597324  88.953  -53.568  57.457  4
597325  88.991  -53.587  57.452  4
597326  89.029  -53.607  57.448  4
597327  89.067  -53.626  57.442  4
597328  89.105  -53.646  57.436  4
597329  89.143  -53.665  57.430  4
597330  89.192  -53.684  57.421  4
597331  89.242  -53.705  57.411  4
597332  89.272  -53.732  57.401  4
597333  89.303  -53.760  57.390  4
597334  89.333  -53.787  57.377  4
597335  89.359  -53.812  57.363  4
597336  89.390  -53.833  57.347  4
597337  89.426  -53.852  57.329  4
597338  89.462  -53.871  57.309  4
597339  89.498  -53.890  57.288  4
597340  89.534  -53.910  57.266  4
597341  89.570  -53.928  57.241  4
597342  89.606  -53.947  57.212  4
597343  89.641  -53.966  57.179  4
597344  89.676  -53.984  57.144  4
597345  89.710  -54.001  57.106  4
597346  89.745  -54.019  57.066  4
597347  89.779  -54.036  57.025  4
597348  89.813  -54.054  56.981  4
597349  89.847  -54.072  56.937  4
597350  89.882  -54.089  56.894  4
597351  89.916  -54.107  56.852  4
597352  89.951  -54.124  56.811  4
597353  89.985  -54.142  56.773  4
597357  90.122  -54.212  56.458  1
597358  90.157  -54.229  56.423  1
597359  90.191  -54.247  56.390  1
597360  90.225  -54.264  56.356  1
597361  90.260  -54.282  56.324  1
597362  90.294  -54.300  56.293  1
597363  90.328  -54.317  56.265  1
597364  90.363  -54.335  56.239  1
597365  90.404  -54.347  56.216  1
597366  90.447  -54.358  56.193  1
597367  90.466  -54.378  56.171  1
597368  90.483  -54.399  56.151  1
597369  90.500  -54.418  56.133  1
597370  90.517  -54.439  56.116  1
597371  90.535  -54.458  56.095  1
597372  90.552  -54.479  56.070  1
597373  90.569  -54.499  56.043  1
597374  90.586  -54.519  56.017  1
597375  90.603  -54.540  55.995  1
597376  90.620  -54.559  55.976  1
597377  90.638  -54.580  55.965  1
597378  90.655  -54.600  55.954  1
597379  90.672  -54.620  55.941  1
597380  90.689  -54.640  55.928  1
597381  90.707  -54.660  55.913  1
597382  90.724  -54.681  55.899  1
597383  90.754  -54.696  55.880  1
597384  90.791  -54.709  55.858  1
597385  90.828  -54.723  55.835  1
597386  90.865  -54.737  55.813  1
597387  90.902  -54.750  55.793  1
597388  90.939  -54.764  55.777  1
597389  90.976  -54.778  55.762  1
597390  91.013  -54.791  55.746  1
597391  91.050  -54.805  55.729  1
597392  91.087  -54.818  55.710  1
597393  91.124  -54.832  55.694  1
597394  91.161  -54.846  55.682  1
597395  91.198  -54.859  55.677  1
597396  91.235  -54.873  55.674  1
597397  91.272  -54.887  55.674  1
597398  91.309  -54.900  55.675  1
597399  91.351  -54.911  55.675  1
597400  91.404  -54.916  55.672  1
597401  91.458  -54.921  55.660  1
597402  91.511  -54.926  55.640  1
597403  91.565  -54.931  55.615  1
597404  91.618  -54.936  55.585  1
597405  91.658  -54.940  55.554  1
597406  91.687  -54.944  55.525  1
597407  91.718  -54.947  55.501  1
597408  91.748  -54.950  55.483  1
597409  91.778  -54.953  55.467  1
597410  91.808  -54.957  55.453  1
597411  91.838  -54.960  55.439  1
597412  91.868  -54.966  55.427  1
597413  91.895  -54.977  55.414  1
597414  91.926  -54.994  55.398  1
597415  91.958  -55.014  55.381  1
597416  91.992  -55.033  55.365  1
597417  92.025  -55.050  55.351  1
597418  92.059  -55.069  55.339  1
597419  92.093  -55.086  55.331  1
597420  92.127  -55.104  55.329  1
597421  92.161  -55.121  55.335  1
597422  92.195  -55.138  55.347  1
597423  92.229  -55.156  55.363  1
597424  92.263  -55.173  55.380  1
597425  92.299  -55.182  55.390  1
597426  92.338  -55.185  55.394  1
597427  92.372  -55.191  55.392  1
597428  92.399  -55.202  55.388  1
597429  92.426  -55.213  55.385  1
597430  92.452  -55.224  55.381  1
597431  92.479  -55.235  55.374  1
597432  92.506  -55.246  55.367  1
597433  92.540  -55.259  55.360  1
597434  92.574  -55.273  55.353  1
597435  92.608  -55.285  55.345  1
597436  92.642  -55.298  55.343  1
597437  92.676  -55.312  55.343  1
597438  92.708  -55.329  55.340  1
597439  92.738  -55.347  55.341  1
597440  92.768  -55.365  55.350  1
597441  92.798  -55.383  55.366  1
597442  92.832  -55.403  55.374  1
597443  92.869  -55.425  55.377  1
597444  92.907  -55.446  55.378  1
597445  92.944  -55.468  55.379  1
597446  92.981  -55.489  55.379  1
597447  93.018  -55.511  55.378  1
597448  93.056  -55.533  55.380  1
597449  93.093  -55.554  55.378  1
597450  93.130  -55.576  55.371  1
597451  93.167  -55.597  55.357  1
597452  93.204  -55.619  55.339  1
597453  93.241  -55.640  55.319  1
597454  93.279  -55.662  55.303  1
597455  93.316  -55.683  55.290  1
597456  93.353  -55.705  55.281  1
597457  93.389  -55.702  55.274  1
597458  93.425  -55.700  55.265  1
597459  93.461  -55.698  55.255  1
597460  93.496  -55.696  55.249  1
597461  93.532  -55.695  55.249  1
597462  93.566  -55.697  55.249  1
597463  93.601  -55.700  55.249  1
597464  93.634  -55.709  55.245  1
597465  93.664  -55.731  55.236  1
597466  93.696  -55.753  55.222  1
597467  93.723  -55.778  55.206  1
597468  93.743  -55.807  55.185  1
597469  93.763  -55.837  55.160  1
597470  93.783  -55.866  55.133  1
597471  93.802  -55.896  55.104  1
597472  93.823  -55.925  55.076  1
597473  93.842  -55.955  55.051  1
597474  93.862  -55.984  55.025  1
597475  93.882  -56.013  54.997  1
597476  93.903  -56.041  54.967  1
597477  93.932  -56.053  54.937  1
597478  93.961  -56.064  54.906  1
597479  93.990  -56.075  54.876  1
597480  94.019  -56.087  54.844  1
597481  94.048  -56.099  54.814  1
597482  94.077  -56.110  54.786  1
597483  94.107  -56.122  54.758  1
597484  94.135  -56.133  54.730  1
597485  94.165  -56.144  54.698  1
597486  94.198  -56.152  54.659  1
597487  94.232  -56.160  54.616  1
597488  94.266  -56.169  54.571  1
597489  94.299  -56.177  54.523  1
597490  94.334  -56.185  54.475  1
597491  94.367  -56.194  54.426  1
597492  94.402  -56.202  54.373  1
597493  94.435  -56.211  54.320  1
597494  94.470  -56.219  54.269  1
597495  94.503  -56.229  54.217  1
597496  94.537  -56.238  54.165  1
597497  94.573  -56.240  54.112  1
597498  94.607  -56.248  54.055  1
597499  94.641  -56.255  53.996  1
597500  94.676  -56.262  53.936  1
597501  94.710  -56.269  53.876  1
597502  94.744  -56.277  53.819  1
597503  94.778  -56.285  53.764  1
597504  94.813  -56.292  53.708  1
597505  94.847  -56.300  53.654  1
597506  94.881  -56.307  53.604  1
597507  94.915  -56.315  53.558  1
597508  94.961  -56.321  53.514  1
597509  95.008  -56.326  53.470  1
597510  95.055  -56.331  53.424  1
597511  95.086  -56.353  53.376  1
597512  95.112  -56.379  53.328  1
597513  95.138  -56.405  53.279  1
597514  95.164  -56.432  53.227  1
597515  95.190  -56.458  53.173  1
597516  95.211  -56.477  53.119  1
597517  95.229  -56.489  53.065  1
597518  95.247  -56.502  53.013  1
597519  95.276  -56.517  52.959  1
597520  95.316  -56.531  52.902  1
597521  95.356  -56.546  52.843  1
597522  95.397  -56.561  52.784  1
597523  95.437  -56.575  52.727  1
597524  95.474  -56.584  52.672  1
597525  95.512  -56.593  52.620  1
597526  95.541  -56.595  52.569  1
597527  95.568  -56.596  52.522  1
597528  95.595  -56.597  52.477  1
597529  95.621  -56.598  52.432  1
597530  95.649  -56.598  52.388  1
597531  95.675  -56.599  52.346  1
597532  95.702  -56.599  52.307  1
597533  95.733  -56.602  52.265  1
597534  95.769  -56.609  52.227  1
597535  95.806  -56.616  52.187  1
597536  95.842  -56.623  52.146  1
597537  95.879  -56.630  52.106  1
597538  95.913  -56.637  52.067  1
597539  95.935  -56.644  52.030  1
597540  95.957  -56.654  51.997  1
597541  95.976  -56.662  51.965  1
597542  95.994  -56.670  51.934  1
597543  96.013  -56.678  51.902  1
597544  96.032  -56.686  51.866  1
597545  96.051  -56.694  51.832  1
597546  96.070  -56.702  51.803  1
597547  96.089  -56.710  51.778  1
597548  96.108  -56.718  51.755  1
597549  96.126  -56.726  51.731  1
597550  96.146  -56.734  51.704  1
597551  96.174  -56.746  51.675  1
597552  96.202  -56.757  51.648  1
597553  96.231  -56.768  51.624  1
597554  96.265  -56.779  51.602  1
597555  96.296  -56.790  51.584  1
597556  96.314  -56.802  51.565  1
597557  96.341  -56.805  51.547  1
597558  96.369  -56.807  51.534  1
597559  96.396  -56.809  51.521  1
597560  96.424  -56.811  51.507  1
597561  96.452  -56.813  51.489  1
597562  96.475  -56.809  51.470  1
597563  96.498  -56.812  51.446  1
597564  96.525  -56.812  51.426  1
597565  96.551  -56.812  51.406  1
597566  96.578  -56.812  51.389  1
597567  96.605  -56.811  51.373  1
597568  96.631  -56.810  51.357  1
597569  96.659  -56.810  51.341  1
597570  96.685  -56.809  51.325  1
597571  96.712  -56.809  51.307  1
597572  96.739  -56.808  51.288  1
597573  96.768  -56.815  51.269  1
597574  96.800  -56.829  51.251  1
597575  96.831  -56.843  51.230  1
597576  96.864  -56.857  51.209  1
597577  96.894  -56.870  51.186  1
597578  96.916  -56.865  51.161  1
597579  96.968  -56.868  51.133  1
597580  97.010  -56.869  51.107  1
597581  97.043  -56.869  51.087  1
597582  97.077  -56.870  51.068  1
597583  97.110  -56.863  51.049  1
597584  97.144  -56.855  51.034  1
597585  97.176  -56.847  51.023  1
597586  97.210  -56.839  51.013  1
597587  97.243  -56.830  51.001  1
597588  97.276  -56.823  50.988  1
597589  97.309  -56.815  50.978  1
597590  97.342  -56.806  50.968  1
597591  97.375  -56.799  50.956  1
597592  97.408  -56.790  50.940  1
597593  97.442  -56.782  50.921  1
597594  97.478  -56.781  50.903  1
597595  97.519  -56.788  50.885  1
597596  97.561  -56.795  50.868  1
597597  97.601  -56.802  50.850  1
597598  97.642  -56.809  50.831  1
597599  97.677  -56.821  50.815  1
597600  97.711  -56.836  50.798  1
597601  97.744  -56.851  50.781  1
597602  97.778  -56.863  50.764  1
597603  97.812  -56.871  50.749  1
597604  97.846  -56.880  50.735  1
597605  97.880  -56.888  50.720  1
597606  97.914  -56.897  50.705  1
597607  97.948  -56.906  50.691  1
597608  97.982  -56.914  50.677  1
597609  98.016  -56.922  50.662  1
597610  98.050  -56.931  50.648  1
597611  98.084  -56.939  50.625  1
597612  98.118  -56.948  50.597  1
597613  98.152  -56.956  50.571  1
597614  98.186  -56.965  50.548  1
597615  98.220  -56.973  50.526  1
597616  98.254  -56.981  50.506  1
597617  98.288  -56.990  50.485  1
597618  98.322  -56.998  50.461  1
597619  98.357  -57.007  50.433  1
597620  98.390  -57.015  50.404  1
597621  98.425  -57.022  50.376  1
597622  98.460  -57.024  50.346  1
597623  98.496  -57.026  50.316  1
597624  98.531  -57.028  50.288  1
597625  98.567  -57.031  50.262  1
597626  98.600  -57.031  50.236  1
597627  98.629  -57.027  50.211  1
597628  98.657  -57.022  50.186  1
597629  98.686  -57.017  50.160  1
597630  98.723  -57.031  50.137  1
597631  98.765  -57.055  50.112  1
597632  98.805  -57.075  50.089  1
597633  98.845  -57.096  50.068  1
597634  98.880  -57.092  50.046  1
597635  98.914  -57.087  50.025  1
597636  98.949  -57.083  50.005  1
597637  98.988  -57.081  49.983  1
597638  99.032  -57.081  49.960  1
597639  99.076  -57.081  49.936  1
597640  99.115  -57.084  49.909  1
597641  99.132  -57.094  49.881  1
597642  99.148  -57.105  49.853  1
597643  99.164  -57.116  49.824  1
597644  99.180  -57.126  49.793  1
597645  99.197  -57.137  49.761  1
597646  99.213  -57.147  49.729  1
597647  99.239  -57.153  49.697  1
597648  99.267  -57.157  49.665  1
597649  99.294  -57.161  49.631  1
597650  99.322  -57.166  49.596  1
597651  99.350  -57.169  49.562  1
597652  99.377  -57.174  49.527  1
597653  99.405  -57.178  49.494  1
597654  99.433  -57.182  49.461  1
597655  99.461  -57.187  49.430  1
597656  99.488  -57.191  49.399  1
597657  99.516  -57.195  49.367  1
597658  99.544  -57.206  49.335  1
597659  99.588  -57.237  49.301  1
597660  99.627  -57.260  49.267  1
597661  99.662  -57.278  49.231  1
597662  99.655  -57.247  49.195  1
597663  99.689  -57.269  49.159  1
597664  99.715  -57.287  49.123  1
597665  99.740  -57.305  49.086  1
597666  99.766  -57.322  49.051  1
597667  99.791  -57.341  49.017  1
597668  99.817  -57.358  48.983  1
597669  99.843  -57.376  48.952  1
597670  99.868  -57.395  48.921  1
597671  99.894  -57.412  48.890  1
597672  99.919  -57.430  48.863  1
597673  99.945  -57.448  48.837  1
597674  99.971  -57.466  48.812  1
597675  99.996  -57.483  48.787  1
597676  100.021  -57.501  48.764  1
598011  88.454  -53.275  57.467  4
598012  88.489  -53.290  57.467  4
598013  88.524  -53.306  57.468  4
598014  88.562  -53.325  57.469  4
598015  88.601  -53.345  57.469  4
598016  88.638  -53.364  57.469  4
598017  88.677  -53.383  57.468  4
598018  88.714  -53.402  57.467  4
598019  88.753  -53.422  57.466  4
598020  88.790  -53.441  57.464  4
598021  88.829  -53.461  57.462  4
598022  88.867  -53.480  57.459  4
598023  88.905  -53.499  57.456  4
598024  88.943  -53.518  57.452  4
598025  88.981  -53.537  57.448  4
598026  89.019  -53.557  57.444  4
598027  89.057  -53.576  57.439  4
598028  89.095  -53.596  57.433  4
598029  89.133  -53.615  57.427  4
598030  89.171  -53.634  57.419  4
598031  89.221  -53.654  57.411  4
598032  89.254  -53.680  57.402  4
598033  89.285  -53.708  57.392  4
598034  89.316  -53.735  57.381  4
598035  89.346  -53.762  57.368  4
598036  89.377  -53.790  57.355  4
598037  89.408  -53.811  57.339  4
598038  89.444  -53.830  57.320  4
598039  89.479  -53.849  57.301  4
598040  89.514  -53.866  57.281  4
598041  89.548  -53.884  57.259  4
598042  89.582  -53.901  57.236  4
598043  89.617  -53.919  57.208  4
598044  89.651  -53.936  57.176  4
598045  89.685  -53.954  57.142  4
598046  89.720  -53.972  57.105  4
598047  89.754  -53.989  57.066  4
598048  89.788  -54.007  57.026  4
598049  89.823  -54.024  56.983  4
598050  89.857  -54.041  56.938  4
598051  89.891  -54.059  56.894  4
598052  89.925  -54.077  56.852  4
598053  89.960  -54.095  56.812  4
598054  89.994  -54.112  56.773  4
598058  90.131  -54.182  56.458  1
598059  90.166  -54.200  56.423  1
598060  90.200  -54.217  56.390  1
598061  90.235  -54.235  56.356  1
598062  90.269  -54.252  56.323  1
598063  90.303  -54.270  56.293  1
598064  90.337  -54.287  56.264  1
598065  90.376  -54.302  56.236  1
598066  90.419  -54.313  56.213  1
598067  90.456  -54.327  56.189  1
598068  90.473  -54.347  56.166  1
598069  90.490  -54.367  56.147  1
598070  90.508  -54.387  56.131  1
598071  90.525  -54.407  56.112  1
598072  90.542  -54.427  56.089  1
598073  90.559  -54.448  56.063  1
598074  90.577  -54.467  56.035  1
598075  90.594  -54.488  56.010  1
598076  90.611  -54.508  55.989  1
598077  90.628  -54.528  55.973  1
598078  90.646  -54.549  55.963  1
598079  90.663  -54.568  55.952  1
598080  90.680  -54.589  55.939  1
598081  90.697  -54.609  55.924  1
598082  90.714  -54.629  55.910  1
598083  90.738  -54.644  55.894  1
598084  90.767  -54.665  55.876  1
598085  90.800  -54.681  55.852  1
598086  90.837  -54.695  55.826  1
598087  90.874  -54.709  55.801  1
598088  90.911  -54.722  55.779  1
598089  90.948  -54.736  55.763  1
598090  90.986  -54.750  55.748  1
598091  91.022  -54.763  55.732  1
598092  91.059  -54.777  55.715  1
598093  91.096  -54.790  55.698  1
598094  91.133  -54.804  55.684  1
598095  91.170  -54.818  55.675  1
598096  91.207  -54.831  55.673  1
598097  91.244  -54.845  55.674  1
598098  91.281  -54.859  55.674  1
598099  91.318  -54.872  55.674  1
598100  91.368  -54.879  55.674  1
598101  91.422  -54.884  55.670  1
598102  91.475  -54.888  55.658  1
598103  91.528  -54.894  55.641  1
598104  91.582  -54.898  55.615  1
598105  91.635  -54.903  55.583  1
598106  91.675  -54.907  55.548  1
598107  91.706  -54.911  55.519  1
598108  91.735  -54.914  55.495  1
598109  91.766  -54.918  55.476  1
598110  91.796  -54.921  55.460  1
598111  91.826  -54.925  55.446  1
598112  91.856  -54.928  55.431  1
598113  91.884  -54.938  55.419  1
598114  91.911  -54.950  55.405  1
598115  91.940  -54.963  55.391  1
598116  91.972  -54.984  55.377  1
598117  92.005  -55.004  55.362  1
598118  92.038  -55.025  55.349  1
598119  92.072  -55.043  55.337  1
598120  92.105  -55.060  55.329  1
598121  92.140  -55.078  55.326  1
598122  92.173  -55.095  55.330  1
598123  92.207  -55.113  55.340  1
598124  92.241  -55.130  55.356  1
598125  92.275  -55.148  55.372  1
598126  92.313  -55.151  55.381  1
598127  92.352  -55.155  55.386  1
598128  92.391  -55.158  55.385  1
598129  92.419  -55.168  55.381  1
598130  92.445  -55.179  55.378  1
598131  92.472  -55.190  55.372  1
598132  92.498  -55.201  55.362  1
598133  92.525  -55.212  55.354  1
598134  92.552  -55.223  55.346  1
598135  92.578  -55.234  55.340  1
598136  92.611  -55.247  55.335  1
598137  92.645  -55.260  55.342  1
598138  92.678  -55.273  55.343  1
598139  92.712  -55.287  55.341  1
598140  92.742  -55.305  55.345  1
598141  92.773  -55.323  55.357  1
598142  92.805  -55.342  55.369  1
598143  92.842  -55.364  55.376  1
598144  92.879  -55.386  55.379  1
598145  92.917  -55.408  55.381  1
598146  92.954  -55.429  55.381  1
598147  92.991  -55.451  55.382  1
598148  93.028  -55.472  55.383  1
598149  93.066  -55.493  55.387  1
598150  93.103  -55.515  55.385  1
598151  93.140  -55.536  55.378  1
598152  93.177  -55.558  55.366  1
598153  93.214  -55.580  55.347  1
598154  93.252  -55.602  55.325  1
598155  93.289  -55.623  55.305  1
598156  93.326  -55.645  55.292  1
598157  93.363  -55.666  55.286  1
598158  93.400  -55.674  55.283  1
598159  93.435  -55.671  55.276  1
598160  93.471  -55.669  55.265  1
598161  93.507  -55.667  55.253  1
598162  93.543  -55.665  55.241  1
598163  93.578  -55.665  55.233  1
598164  93.612  -55.667  55.229  1
598165  93.645  -55.675  55.226  1
598166  93.677  -55.698  55.215  1
598167  93.706  -55.721  55.201  1
598168  93.726  -55.750  55.187  1
598169  93.746  -55.780  55.167  1
598170  93.766  -55.809  55.144  1
598171  93.785  -55.839  55.118  1
598172  93.805  -55.868  55.091  1
598173  93.825  -55.898  55.066  1
598174  93.845  -55.927  55.040  1
598175  93.865  -55.956  55.015  1
598176  93.885  -55.986  54.988  1
598177  93.905  -56.016  54.961  1
598178  93.933  -56.029  54.934  1
598179  93.962  -56.041  54.904  1
598180  93.991  -56.052  54.874  1
598181  94.020  -56.064  54.839  1
598182  94.049  -56.075  54.803  1
598183  94.078  -56.087  54.773  1
598184  94.107  -56.098  54.744  1
598185  94.136  -56.110  54.716  1
598186  94.168  -56.119  54.685  1
598187  94.200  -56.125  54.648  1
598188  94.234  -56.134  54.607  1
598189  94.268  -56.142  54.564  1
598190  94.301  -56.150  54.518  1
598191  94.336  -56.159  54.472  1
598192  94.369  -56.168  54.423  1
598193  94.403  -56.176  54.370  1
598194  94.437  -56.185  54.317  1
598195  94.471  -56.193  54.265  1
598196  94.505  -56.201  54.214  1
598197  94.543  -56.210  54.160  1
598198  94.579  -56.219  54.103  1
598199  94.613  -56.226  54.044  1
598200  94.647  -56.235  53.983  1
598201  94.681  -56.242  53.924  1
598202  94.715  -56.250  53.865  1
598203  94.749  -56.258  53.811  1
598204  94.783  -56.266  53.758  1
598205  94.817  -56.273  53.704  1
598206  94.851  -56.281  53.653  1
598207  94.885  -56.289  53.605  1
598208  94.919  -56.295  53.560  1
598209  94.961  -56.310  53.518  1
598210  95.008  -56.315  53.475  1
598211  95.056  -56.320  53.430  1
598212  95.095  -56.334  53.383  1
598213  95.121  -56.360  53.333  1
598214  95.147  -56.386  53.283  1
598215  95.173  -56.413  53.230  1
598216  95.198  -56.439  53.176  1
598217  95.216  -56.451  53.120  1
598218  95.234  -56.464  53.064  1
598219  95.251  -56.476  53.009  1
598220  95.282  -56.491  52.954  1
598221  95.323  -56.506  52.898  1
598222  95.364  -56.521  52.840  1
598223  95.404  -56.536  52.782  1
598224  95.442  -56.545  52.725  1
598225  95.479  -56.555  52.668  1
598226  95.517  -56.564  52.614  1
598227  95.548  -56.568  52.561  1
598228  95.575  -56.568  52.511  1
598229  95.602  -56.569  52.463  1
598230  95.628  -56.570  52.416  1
598231  95.656  -56.570  52.370  1
598232  95.682  -56.570  52.326  1
598233  95.709  -56.571  52.283  1
598234  95.742  -56.575  52.242  1
598235  95.776  -56.581  52.202  1
598236  95.811  -56.586  52.161  1
598237  95.846  -56.592  52.120  1
598238  95.882  -56.599  52.078  1
598239  95.916  -56.605  52.037  1
598240  95.937  -56.614  51.998  1
598241  95.956  -56.621  51.962  1
598242  95.974  -56.630  51.929  1
598243  95.993  -56.638  51.898  1
598244  96.012  -56.646  51.866  1
598245  96.031  -56.654  51.831  1
598246  96.050  -56.661  51.800  1
598247  96.068  -56.670  51.771  1
598248  96.088  -56.677  51.744  1
598249  96.106  -56.686  51.718  1
598250  96.125  -56.693  51.694  1
598251  96.148  -56.703  51.666  1
598252  96.176  -56.714  51.638  1
598253  96.209  -56.725  51.611  1
598254  96.244  -56.736  51.586  1
598255  96.278  -56.746  51.563  1
598256  96.300  -56.760  51.543  1
598257  96.315  -56.775  51.523  1
598258  96.343  -56.777  51.505  1
598259  96.370  -56.780  51.491  1
598260  96.398  -56.782  51.478  1
598261  96.426  -56.783  51.462  1
598262  96.451  -56.783  51.444  1
598263  96.474  -56.777  51.425  1
598264  96.498  -56.780  51.403  1
598265  96.520  -56.787  51.384  1
598266  96.548  -56.785  51.366  1
598267  96.575  -56.783  51.349  1
598268  96.602  -56.783  51.332  1
598269  96.629  -56.782  51.315  1
598270  96.656  -56.782  51.298  1
598271  96.682  -56.781  51.281  1
598272  96.709  -56.780  51.264  1
598273  96.736  -56.780  51.245  1
598274  96.764  -56.783  51.227  1
598275  96.796  -56.798  51.209  1
598276  96.828  -56.812  51.188  1
598277  96.860  -56.827  51.167  1
598278  96.887  -56.834  51.147  1
598279  96.914  -56.829  51.123  1
598280  96.966  -56.832  51.096  1
598281  97.009  -56.834  51.074  1
598282  97.042  -56.834  51.054  1
598283  97.076  -56.834  51.034  1
598284  97.109  -56.831  51.013  1
598285  97.142  -56.823  50.994  1
598286  97.175  -56.815  50.977  1
598287  97.208  -56.807  50.969  1
598288  97.241  -56.799  50.958  1
598289  97.275  -56.790  50.948  1
598290  97.308  -56.783  50.938  1
598291  97.341  -56.774  50.929  1
598292  97.374  -56.766  50.918  1
598293  97.407  -56.758  50.902  1
598294  97.440  -56.750  50.884  1
598295  97.481  -56.757  50.868  1
598296  97.522  -56.764  50.852  1
598297  97.563  -56.771  50.834  1
598298  97.604  -56.777  50.815  1
598299  97.645  -56.784  50.797  1
598300  97.684  -56.793  50.781  1
598301  97.717  -56.808  50.764  1
598302  97.750  -56.823  50.749  1
598303  97.785  -56.831  50.734  1
598304  97.818  -56.840  50.721  1
598305  97.853  -56.848  50.709  1
598306  97.887  -56.857  50.695  1
598307  97.921  -56.865  50.681  1
598308  97.955  -56.874  50.668  1
598309  97.989  -56.882  50.655  1
598310  98.023  -56.890  50.642  1
598311  98.057  -56.899  50.629  1
598312  98.091  -56.908  50.607  1
598313  98.125  -56.916  50.581  1
598314  98.159  -56.924  50.555  1
598315  98.193  -56.933  50.532  1
598316  98.227  -56.941  50.510  1
598317  98.261  -56.950  50.489  1
598318  98.295  -56.958  50.469  1
598319  98.329  -56.967  50.445  1
598320  98.363  -56.975  50.417  1
598321  98.397  -56.984  50.388  1
598322  98.431  -56.992  50.359  1
598323  98.466  -56.998  50.328  1
598324  98.501  -57.000  50.296  1
598325  98.536  -57.002  50.269  1
598326  98.572  -57.004  50.244  1
598327  98.603  -57.002  50.218  1
598328  98.631  -56.997  50.192  1
598329  98.660  -56.993  50.168  1
598330  98.688  -56.988  50.144  1
598331  98.724  -56.999  50.119  1
598332  98.764  -57.019  50.094  1
598333  98.804  -57.040  50.071  1
598334  98.844  -57.061  50.048  1
598335  98.881  -57.065  50.024  1
598336  98.916  -57.061  50.004  1
598337  98.950  -57.056  49.985  1
598338  98.991  -57.056  49.964  1
598339  99.035  -57.056  49.940  1
598340  99.080  -57.056  49.914  1
598341  99.124  -57.056  49.887  1
598342  99.145  -57.065  49.859  1
598343  99.161  -57.076  49.831  1
598344  99.177  -57.087  49.803  1
598345  99.193  -57.097  49.773  1
598346  99.210  -57.108  49.741  1
598347  99.228  -57.117  49.709  1
598348  99.256  -57.122  49.678  1
598349  99.283  -57.125  49.647  1
598350  99.311  -57.130  49.615  1
598351  99.339  -57.134  49.581  1
598352  99.366  -57.138  49.548  1
598353  99.394  -57.143  49.516  1
598354  99.422  -57.147  49.484  1
598355  99.449  -57.151  49.451  1
598356  99.477  -57.156  49.421  1
598357  99.503  -57.161  49.390  1
598358  99.528  -57.167  49.358  1
598359  99.560  -57.183  49.326  1
598360  99.605  -57.213  49.291  1
598361  99.648  -57.244  49.257  1
598362  99.645  -57.203  49.221  1
598363  99.675  -57.228  49.185  1
598364  99.700  -57.245  49.148  1
598365  99.726  -57.263  49.111  1
598366  99.752  -57.281  49.075  1
598367  99.777  -57.299  49.041  1
598368  99.802  -57.316  49.006  1
598369  99.828  -57.335  48.973  1
598370  99.854  -57.352  48.941  1
598371  99.879  -57.370  48.910  1
598372  99.905  -57.388  48.879  1
598373  99.930  -57.406  48.851  1
598374  99.956  -57.424  48.825  1
598375  99.981  -57.442  48.800  1
598376  100.007  -57.460  48.776  1
598377  100.033  -57.477  48.752  1
598709  88.372  -53.194  57.461  4
598710  88.407  -53.210  57.462  4
598711  88.443  -53.225  57.462  4
598712  88.478  -53.240  57.463  4
598713  88.514  -53.256  57.464  4
598714  88.552  -53.276  57.464  4
598715  88.590  -53.295  57.465  4
598716  88.628  -53.314  57.465  4
598717  88.666  -53.333  57.464  4
598718  88.704  -53.352  57.463  4
598719  88.742  -53.372  57.462  4
598720  88.780  -53.391  57.460  4
598721  88.818  -53.411  57.458  4
598722  88.856  -53.430  57.455  4
598723  88.894  -53.449  57.452  4
598724  88.932  -53.468  57.448  4
598725  88.970  -53.488  57.444  4
598726  89.009  -53.507  57.440  4
598727  89.046  -53.526  57.435  4
598728  89.085  -53.546  57.429  4
598729  89.122  -53.565  57.423  4
598730  89.161  -53.584  57.417  4
598731  89.198  -53.603  57.410  4
598732  89.237  -53.628  57.402  4
598733  89.267  -53.655  57.393  4
598734  89.298  -53.683  57.382  4
598735  89.328  -53.711  57.372  4
598736  89.358  -53.739  57.359  4
598737  89.388  -53.767  57.346  4
598738  89.420  -53.784  57.330  4
598739  89.454  -53.801  57.312  4
598740  89.488  -53.819  57.293  4
598741  89.523  -53.837  57.274  4
598742  89.557  -53.854  57.253  4
598743  89.592  -53.872  57.230  4
598744  89.626  -53.889  57.204  4
598745  89.660  -53.907  57.174  4
598746  89.694  -53.924  57.140  4
598747  89.729  -53.941  57.104  4
598748  89.763  -53.960  57.066  4
598749  89.798  -53.977  57.027  4
598750  89.832  -53.994  56.984  4
598751  89.866  -54.012  56.940  4
598752  89.900  -54.029  56.896  4
598753  89.935  -54.047  56.853  4
598754  89.969  -54.064  56.814  4
598755  90.004  -54.082  56.774  4
598760  90.175  -54.170  56.423  1
598761  90.210  -54.187  56.389  1
598762  90.244  -54.205  56.355  1
598763  90.278  -54.223  56.321  1
598764  90.313  -54.240  56.290  1
598765  90.348  -54.257  56.261  1
598766  90.391  -54.268  56.234  1
598767  90.435  -54.279  56.208  1
598768  90.464  -54.295  56.184  1
598769  90.481  -54.315  56.161  1
598770  90.498  -54.336  56.142  1
598771  90.516  -54.355  56.129  1
598772  90.533  -54.376  56.108  1
598773  90.550  -54.395  56.082  1
598774  90.567  -54.416  56.054  1
598775  90.584  -54.436  56.028  1
598776  90.601  -54.456  56.003  1
598777  90.619  -54.477  55.983  1
598778  90.636  -54.496  55.969  1
598779  90.653  -54.517  55.959  1
598780  90.670  -54.537  55.947  1
598781  90.687  -54.557  55.931  1
598782  90.705  -54.577  55.916  1
598783  90.727  -54.593  55.904  1
598784  90.757  -54.608  55.888  1
598785  90.787  -54.628  55.868  1
598786  90.815  -54.648  55.843  1
598787  90.847  -54.667  55.816  1
598788  90.883  -54.681  55.789  1
598789  90.921  -54.694  55.767  1
598790  90.957  -54.708  55.749  1
598791  90.994  -54.721  55.733  1
598792  91.031  -54.735  55.717  1
598793  91.068  -54.749  55.701  1
598794  91.105  -54.762  55.686  1
598795  91.142  -54.776  55.675  1
598796  91.179  -54.790  55.670  1
598797  91.216  -54.803  55.671  1
598798  91.253  -54.817  55.673  1
598799  91.290  -54.830  55.675  1
598800  91.331  -54.841  55.674  1
598801  91.385  -54.847  55.674  1
598802  91.439  -54.851  55.669  1
598803  91.492  -54.856  55.659  1
598804  91.545  -54.861  55.641  1
598805  91.599  -54.866  55.616  1
598806  91.652  -54.871  55.583  1
598807  91.693  -54.875  55.546  1
598808  91.723  -54.878  55.514  1
598809  91.753  -54.882  55.489  1
598810  91.784  -54.885  55.470  1
598811  91.813  -54.889  55.454  1
598812  91.844  -54.892  55.439  1
598813  91.872  -54.900  55.425  1
598814  91.899  -54.911  55.411  1
598815  91.927  -54.922  55.397  1
598816  91.954  -54.933  55.384  1
598817  91.987  -54.953  55.372  1
598818  92.019  -54.974  55.359  1
598819  92.052  -54.994  55.346  1
598820  92.085  -55.015  55.335  1
598821  92.118  -55.035  55.327  1
598822  92.152  -55.052  55.323  1
598823  92.186  -55.069  55.325  1
598824  92.220  -55.087  55.332  1
598825  92.253  -55.105  55.347  1
598826  92.289  -55.118  55.362  1
598827  92.328  -55.121  55.370  1
598828  92.366  -55.125  55.373  1
598829  92.405  -55.128  55.373  1
598830  92.438  -55.135  55.369  1
598831  92.465  -55.145  55.365  1
598832  92.492  -55.157  55.358  1
598833  92.518  -55.167  55.348  1
598834  92.545  -55.178  55.340  1
598835  92.571  -55.189  55.333  1
598836  92.597  -55.200  55.328  1
598837  92.624  -55.211  55.329  1
598838  92.651  -55.222  55.335  1
598839  92.681  -55.234  55.335  1
598840  92.715  -55.247  55.336  1
598841  92.747  -55.263  55.344  1
598842  92.778  -55.282  55.357  1
598843  92.815  -55.304  55.365  1
598844  92.852  -55.325  55.371  1
598845  92.889  -55.347  55.376  1
598846  92.927  -55.368  55.378  1
598847  92.964  -55.390  55.379  1
598848  93.001  -55.411  55.382  1
598849  93.039  -55.433  55.385  1
598850  93.076  -55.455  55.387  1
598851  93.113  -55.476  55.387  1
598852  93.150  -55.498  55.382  1
598853  93.187  -55.519  55.370  1
598854  93.224  -55.541  55.353  1
598855  93.262  -55.562  55.330  1
598856  93.299  -55.584  55.307  1
598857  93.336  -55.605  55.291  1
598858  93.373  -55.627  55.285  1
598859  93.410  -55.644  55.284  1
598860  93.446  -55.642  55.279  1
598861  93.482  -55.640  55.269  1
598862  93.517  -55.637  55.255  1
598863  93.554  -55.635  55.242  1
598864  93.589  -55.633  55.230  1
598865  93.624  -55.633  55.219  1
598866  93.657  -55.642  55.205  1
598867  93.689  -55.665  55.191  1
598868  93.709  -55.693  55.177  1
598869  93.728  -55.723  55.163  1
598870  93.749  -55.752  55.146  1
598871  93.768  -55.782  55.124  1
598872  93.788  -55.812  55.103  1
598873  93.808  -55.841  55.084  1
598874  93.828  -55.870  55.061  1
598875  93.848  -55.900  55.039  1
598876  93.868  -55.929  55.015  1
598877  93.888  -55.959  54.989  1
598878  93.908  -55.988  54.963  1
598879  93.933  -56.006  54.936  1
598880  93.963  -56.017  54.907  1
598881  93.992  -56.028  54.876  1
598882  94.021  -56.041  54.838  1
598883  94.050  -56.052  54.797  1
598884  94.079  -56.063  54.761  1
598885  94.108  -56.075  54.728  1
598886  94.137  -56.086  54.697  1
598887  94.170  -56.093  54.665  1
598888  94.202  -56.100  54.629  1
598889  94.236  -56.107  54.590  1
598890  94.270  -56.116  54.549  1
598891  94.303  -56.124  54.506  1
598892  94.337  -56.133  54.461  1
598893  94.371  -56.141  54.413  1
598894  94.405  -56.150  54.361  1
598895  94.439  -56.158  54.306  1
598896  94.473  -56.166  54.253  1
598897  94.507  -56.175  54.201  1
598898  94.549  -56.185  54.148  1
598899  94.589  -56.194  54.091  1
598900  94.623  -56.202  54.032  1
598901  94.657  -56.210  53.973  1
598902  94.691  -56.217  53.916  1
598903  94.725  -56.226  53.861  1
598904  94.759  -56.233  53.808  1
598905  94.793  -56.241  53.757  1
598906  94.827  -56.249  53.706  1
598907  94.861  -56.257  53.655  1
598908  94.895  -56.264  53.608  1
598909  94.929  -56.269  53.562  1
598910  94.967  -56.288  53.521  1
598911  95.009  -56.304  53.479  1
598912  95.056  -56.309  53.435  1
598913  95.103  -56.315  53.389  1
598914  95.129  -56.341  53.340  1
598915  95.156  -56.367  53.290  1
598916  95.182  -56.394  53.236  1
598917  95.203  -56.413  53.181  1
598918  95.220  -56.426  53.124  1
598919  95.238  -56.439  53.067  1
598920  95.256  -56.451  53.009  1
598921  95.289  -56.466  52.952  1
598922  95.330  -56.480  52.896  1
598923  95.370  -56.495  52.839  1
598924  95.409  -56.507  52.782  1
598925  95.447  -56.516  52.724  1
598926  95.484  -56.525  52.666  1
598927  95.522  -56.534  52.610  1
598928  95.555  -56.540  52.555  1
598929  95.582  -56.540  52.502  1
598930  95.609  -56.541  52.451  1
598931  95.635  -56.542  52.402  1
598932  95.662  -56.542  52.354  1
598933  95.689  -56.542  52.308  1
598934  95.716  -56.543  52.263  1
598935  95.751  -56.549  52.219  1
598936  95.786  -56.555  52.178  1
598937  95.821  -56.560  52.137  1
598938  95.855  -56.566  52.095  1
598939  95.890  -56.571  52.052  1
598940  95.919  -56.580  52.010  1
598941  95.945  -56.583  51.970  1
598942  95.964  -56.590  51.933  1
598943  95.981  -56.598  51.898  1
598944  95.998  -56.605  51.864  1
598945  96.015  -56.614  51.831  1
598946  96.032  -56.621  51.797  1
598947  96.049  -56.630  51.764  1
598948  96.067  -56.637  51.736  1
598949  96.087  -56.646  51.710  1
598950  96.105  -56.653  51.683  1
598951  96.124  -56.661  51.654  1
598952  96.153  -56.672  51.626  1
598953  96.187  -56.683  51.597  1
598954  96.222  -56.693  51.572  1
598955  96.256  -56.704  51.546  1
598956  96.289  -56.715  51.522  1
598957  96.304  -56.730  51.502  1
598958  96.319  -56.746  51.480  1
598959  96.344  -56.750  51.461  1
598960  96.372  -56.752  51.447  1
598961  96.399  -56.755  51.432  1
598962  96.427  -56.756  51.415  1
598963  96.450  -56.752  51.398  1
598964  96.474  -56.747  51.381  1
598965  96.497  -56.747  51.364  1
598966  96.520  -56.754  51.345  1
598967  96.542  -56.760  51.326  1
598968  96.571  -56.757  51.309  1
598969  96.599  -56.755  51.291  1
598970  96.626  -56.754  51.271  1
598971  96.653  -56.753  51.251  1
598972  96.679  -56.753  51.235  1
598973  96.707  -56.752  51.217  1
598974  96.733  -56.752  51.199  1
598975  96.760  -56.753  51.180  1
598976  96.792  -56.767  51.162  1
598977  96.824  -56.781  51.142  1
598978  96.856  -56.796  51.123  1
598979  96.880  -56.796  51.104  1
598980  96.912  -56.794  51.082  1
598981  96.963  -56.797  51.059  1
598982  97.007  -56.799  51.039  1
598983  97.040  -56.799  51.018  1
598984  97.074  -56.799  50.997  1
598985  97.107  -56.799  50.975  1
598986  97.141  -56.790  50.953  1
598987  97.174  -56.783  50.933  1
598988  97.207  -56.774  50.924  1
598989  97.240  -56.766  50.916  1
598990  97.273  -56.758  50.908  1
598991  97.306  -56.750  50.899  1
598992  97.339  -56.742  50.890  1
598993  97.372  -56.734  50.879  1
598994  97.405  -56.726  50.864  1
598995  97.443  -56.726  50.849  1
598996  97.484  -56.733  50.834  1
598997  97.525  -56.740  50.819  1
598998  97.566  -56.746  50.802  1
598999  97.607  -56.753  50.784  1
599000  97.648  -56.760  50.766  1
599001  97.689  -56.767  50.749  1
599002  97.724  -56.780  50.733  1
599003  97.757  -56.791  50.718  1
599004  97.791  -56.799  50.705  1
599005  97.825  -56.808  50.693  1
599006  97.859  -56.817  50.683  1
599007  97.893  -56.825  50.672  1
599008  97.928  -56.834  50.659  1
599009  97.961  -56.842  50.647  1
599010  97.996  -56.850  50.634  1
599011  98.029  -56.859  50.621  1
599012  98.064  -56.868  50.608  1
599013  98.098  -56.876  50.589  1
599014  98.132  -56.884  50.563  1
599015  98.166  -56.893  50.538  1
599016  98.200  -56.901  50.515  1
599017  98.234  -56.909  50.494  1
599018  98.268  -56.918  50.474  1
599019  98.302  -56.927  50.453  1
599020  98.336  -56.935  50.426  1
599021  98.370  -56.943  50.399  1
599022  98.404  -56.952  50.369  1
599023  98.438  -56.960  50.339  1
599024  98.472  -56.968  50.307  1
599025  98.507  -56.974  50.276  1
599026  98.543  -56.976  50.249  1
599027  98.577  -56.977  50.223  1
599028  98.605  -56.972  50.197  1
599029  98.634  -56.968  50.172  1
599030  98.662  -56.963  50.147  1
599031  98.693  -56.965  50.124  1
599032  98.725  -56.967  50.098  1
599033  98.764  -56.984  50.074  1
599034  98.803  -57.005  50.050  1
599035  98.844  -57.025  50.026  1
599036  98.882  -57.039  50.003  1
599037  98.917  -57.034  49.981  1
599038  98.951  -57.030  49.960  1
599039  98.995  -57.030  49.939  1
599040  99.039  -57.030  49.916  1
599041  99.083  -57.031  49.890  1
599042  99.127  -57.031  49.864  1
599043  99.158  -57.036  49.837  1
599044  99.174  -57.047  49.809  1
599045  99.190  -57.057  49.780  1
599046  99.207  -57.068  49.750  1
599047  99.223  -57.078  49.719  1
599048  99.245  -57.086  49.688  1
599049  99.273  -57.091  49.658  1
599050  99.300  -57.094  49.628  1
599051  99.328  -57.099  49.596  1
599052  99.356  -57.103  49.564  1
599053  99.383  -57.107  49.533  1
599054  99.411  -57.112  49.502  1
599055  99.439  -57.116  49.472  1
599056  99.467  -57.120  49.440  1
599057  99.491  -57.126  49.410  1
599058  99.516  -57.133  49.379  1
599059  99.541  -57.139  49.346  1
599060  99.576  -57.160  49.313  1
599061  99.621  -57.191  49.279  1
599062  99.665  -57.222  49.244  1
599063  99.657  -57.185  49.208  1
599064  99.686  -57.203  49.172  1
599065  99.711  -57.222  49.136  1
599066  99.737  -57.239  49.099  1
599067  99.762  -57.257  49.063  1
599068  99.788  -57.275  49.029  1
599069  99.814  -57.293  48.996  1
599070  99.839  -57.310  48.963  1
599071  99.864  -57.329  48.931  1
599072  99.890  -57.347  48.900  1
599073  99.916  -57.364  48.869  1
599074  99.941  -57.382  48.841  1
599075  99.967  -57.400  48.814  1
599076  99.992  -57.418  48.789  1
599077  100.018  -57.435  48.765  1
599409  88.361  -53.144  57.456  4
599410  88.397  -53.159  57.457  4
599411  88.432  -53.175  57.458  4
599412  88.468  -53.190  57.458  4
599413  88.503  -53.206  57.459  4
599414  88.541  -53.226  57.459  4
599415  88.579  -53.245  57.460  4
599416  88.618  -53.264  57.460  4
599417  88.656  -53.283  57.460  4
599418  88.694  -53.302  57.459  4
599419  88.732  -53.322  57.458  4
599420  88.770  -53.341  57.456  4
599421  88.808  -53.361  57.454  4
599422  88.846  -53.380  57.452  4
599423  88.884  -53.399  57.448  4
599424  88.922  -53.418  57.445  4
599425  88.960  -53.438  57.441  4
599426  88.998  -53.457  57.437  4
599427  89.036  -53.477  57.432  4
599428  89.074  -53.496  57.426  4
599429  89.112  -53.515  57.420  4
599430  89.150  -53.534  57.414  4
599431  89.188  -53.553  57.408  4
599432  89.221  -53.577  57.400  4
599433  89.248  -53.606  57.392  4
599434  89.278  -53.634  57.383  4
599435  89.308  -53.662  57.372  4
599436  89.338  -53.690  57.361  4
599437  89.368  -53.719  57.349  4
599438  89.398  -53.747  57.336  4
599439  89.435  -53.758  57.321  4
599440  89.464  -53.772  57.304  4
599441  89.498  -53.789  57.285  4
599442  89.532  -53.806  57.267  4
599443  89.566  -53.824  57.247  4
599444  89.601  -53.842  57.225  4
599445  89.635  -53.860  57.200  4
599446  89.670  -53.877  57.171  4
599447  89.704  -53.894  57.138  4
599448  89.738  -53.912  57.103  4
599449  89.772  -53.929  57.065  4
599450  89.807  -53.947  57.026  4
599451  89.841  -53.965  56.984  4
599452  89.876  -53.982  56.941  4
599453  89.910  -54.000  56.897  4
599454  89.944  -54.017  56.855  4
599455  89.978  -54.035  56.814  4
599456  90.013  -54.052  56.774  4
599457  90.047  -54.070  56.735  4
599461  90.184  -54.140  56.424  1
599462  90.219  -54.157  56.389  1
599463  90.253  -54.175  56.354  1
599464  90.288  -54.192  56.320  1
599465  90.322  -54.211  56.288  1
599466  90.364  -54.223  56.258  1
599467  90.407  -54.234  56.230  1
599468  90.450  -54.245  56.204  1
599469  90.471  -54.264  56.179  1
599470  90.488  -54.284  56.156  1
599471  90.506  -54.304  56.135  1
599472  90.523  -54.324  56.119  1
599473  90.540  -54.344  56.098  1
599474  90.557  -54.364  56.073  1
599475  90.575  -54.385  56.046  1
599476  90.592  -54.405  56.020  1
599477  90.609  -54.425  55.996  1
599478  90.626  -54.445  55.976  1
599479  90.644  -54.465  55.962  1
599480  90.661  -54.486  55.951  1
599481  90.678  -54.505  55.938  1
599482  90.695  -54.526  55.922  1
599483  90.714  -54.544  55.907  1
599484  90.748  -54.551  55.896  1
599485  90.777  -54.571  55.879  1
599486  90.806  -54.592  55.858  1
599487  90.834  -54.612  55.833  1
599488  90.864  -54.632  55.805  1
599489  90.892  -54.652  55.777  1
599490  90.929  -54.666  55.755  1
599491  90.966  -54.680  55.736  1
599492  91.003  -54.693  55.719  1
599493  91.040  -54.706  55.704  1
599494  91.077  -54.720  55.690  1
599495  91.114  -54.734  55.677  1
599496  91.151  -54.747  55.670  1
599497  91.188  -54.761  55.668  1
599498  91.225  -54.775  55.669  1
599499  91.262  -54.788  55.672  1
599500  91.299  -54.802  55.675  1
599501  91.349  -54.809  55.675  1
599502  91.402  -54.814  55.675  1
599503  91.456  -54.818  55.670  1
599504  91.509  -54.824  55.659  1
599505  91.563  -54.828  55.641  1
599506  91.616  -54.834  55.615  1
599507  91.669  -54.838  55.582  1
599508  91.711  -54.843  55.543  1
599509  91.741  -54.846  55.509  1
599510  91.771  -54.850  55.483  1
599511  91.801  -54.853  55.463  1
599512  91.831  -54.856  55.447  1
599513  91.861  -54.861  55.433  1
599514  91.888  -54.872  55.419  1
599515  91.916  -54.884  55.405  1
599516  91.943  -54.894  55.392  1
599517  91.970  -54.906  55.380  1
599518  92.001  -54.923  55.369  1
599519  92.033  -54.944  55.356  1
599520  92.067  -54.964  55.343  1
599521  92.099  -54.985  55.333  1
599522  92.132  -55.005  55.324  1
599523  92.165  -55.025  55.319  1
599524  92.199  -55.044  55.319  1
599525  92.232  -55.062  55.324  1
599526  92.266  -55.079  55.338  1
599527  92.303  -55.088  55.351  1
599528  92.342  -55.091  55.357  1
599529  92.380  -55.094  55.358  1
599530  92.419  -55.097  55.358  1
599531  92.458  -55.101  55.356  1
599532  92.485  -55.111  55.350  1
599533  92.511  -55.123  55.344  1
599534  92.537  -55.133  55.336  1
599535  92.564  -55.144  55.328  1
599536  92.591  -55.155  55.323  1
599537  92.617  -55.166  55.321  1
599538  92.644  -55.177  55.324  1
599539  92.670  -55.188  55.328  1
599540  92.697  -55.199  55.329  1
599541  92.723  -55.210  55.332  1
599542  92.752  -55.222  55.340  1
599543  92.788  -55.243  55.349  1
599544  92.825  -55.264  55.356  1
599545  92.862  -55.286  55.361  1
599546  92.900  -55.307  55.366  1
599547  92.937  -55.329  55.371  1
599548  92.974  -55.351  55.376  1
599549  93.011  -55.373  55.381  1
599550  93.049  -55.394  55.380  1
599551  93.086  -55.415  55.380  1
599552  93.123  -55.437  55.383  1
599553  93.160  -55.458  55.381  1
599554  93.197  -55.480  55.370  1
599555  93.234  -55.502  55.354  1
599556  93.272  -55.524  55.333  1
599557  93.309  -55.545  55.308  1
599558  93.346  -55.567  55.291  1
599559  93.383  -55.588  55.284  1
599560  93.421  -55.609  55.283  1
599561  93.457  -55.613  55.279  1
599562  93.492  -55.611  55.269  1
599563  93.529  -55.608  55.256  1
599564  93.564  -55.606  55.244  1
599565  93.600  -55.604  55.231  1
599566  93.636  -55.602  55.215  1
599567  93.670  -55.608  55.196  1
599568  93.692  -55.636  55.179  1
599569  93.711  -55.666  55.161  1
599570  93.731  -55.696  55.146  1
599571  93.751  -55.725  55.130  1
599572  93.771  -55.755  55.112  1
599573  93.791  -55.784  55.094  1
599574  93.811  -55.813  55.078  1
599575  93.831  -55.843  55.057  1
599576  93.851  -55.872  55.037  1
599577  93.870  -55.902  55.014  1
599578  93.891  -55.931  54.987  1
599579  93.910  -55.961  54.961  1
599580  93.934  -55.982  54.935  1
599581  93.964  -55.994  54.908  1
599582  93.992  -56.006  54.879  1
599583  94.022  -56.017  54.843  1
599584  94.051  -56.028  54.800  1
599585  94.079  -56.040  54.754  1
599586  94.109  -56.051  54.711  1
599587  94.140  -56.060  54.676  1
599588  94.173  -56.067  54.641  1
599589  94.205  -56.074  54.605  1
599590  94.238  -56.081  54.568  1
599591  94.271  -56.090  54.529  1
599592  94.306  -56.098  54.489  1
599593  94.339  -56.107  54.446  1
599594  94.373  -56.115  54.399  1
599595  94.407  -56.123  54.347  1
599596  94.441  -56.132  54.292  1
599597  94.475  -56.140  54.237  1
599598  94.509  -56.149  54.186  1
599599  94.556  -56.160  54.135  1
599600  94.599  -56.169  54.081  1
599601  94.633  -56.177  54.024  1
599602  94.667  -56.185  53.967  1
599603  94.701  -56.193  53.913  1
599604  94.735  -56.201  53.863  1
599605  94.769  -56.208  53.813  1
599606  94.803  -56.216  53.764  1
599607  94.837  -56.224  53.714  1
599608  94.871  -56.232  53.664  1
599609  94.905  -56.238  53.614  1
599610  94.939  -56.241  53.565  1
599611  94.976  -56.259  53.522  1
599612  95.015  -56.282  53.481  1
599613  95.057  -56.298  53.437  1
599614  95.105  -56.303  53.392  1
599615  95.138  -56.322  53.345  1
599616  95.164  -56.348  53.297  1
599617  95.190  -56.374  53.243  1
599618  95.207  -56.387  53.188  1
599619  95.225  -56.400  53.132  1
599620  95.243  -56.413  53.074  1
599621  95.260  -56.426  53.015  1
599622  95.297  -56.440  52.957  1
599623  95.337  -56.455  52.901  1
599624  95.376  -56.468  52.844  1
599625  95.414  -56.477  52.785  1
599626  95.451  -56.486  52.725  1
599627  95.489  -56.495  52.665  1
599628  95.526  -56.505  52.609  1
599629  95.562  -56.512  52.551  1
599630  95.589  -56.512  52.496  1
599631  95.616  -56.513  52.442  1
599632  95.642  -56.514  52.389  1
599633  95.669  -56.514  52.340  1
599634  95.696  -56.514  52.291  1
599635  95.727  -56.517  52.244  1
599636  95.761  -56.523  52.199  1
599637  95.796  -56.528  52.156  1
599638  95.831  -56.534  52.114  1
599639  95.865  -56.539  52.071  1
599640  95.896  -56.550  52.028  1
599641  95.922  -56.561  51.985  1
599642  95.947  -56.564  51.943  1
599643  95.972  -56.567  51.905  1
599644  95.997  -56.570  51.868  1
599645  96.020  -56.574  51.832  1
599646  96.037  -56.583  51.797  1
599647  96.053  -56.590  51.763  1
599648  96.071  -56.599  51.731  1
599649  96.088  -56.606  51.702  1
599650  96.104  -56.614  51.674  1
599651  96.121  -56.622  51.646  1
599652  96.138  -56.630  51.617  1
599653  96.166  -56.639  51.589  1
599654  96.200  -56.650  51.559  1
599655  96.235  -56.661  51.532  1
599656  96.269  -56.671  51.507  1
599657  96.293  -56.685  51.483  1
599658  96.308  -56.700  51.460  1
599659  96.323  -56.715  51.439  1
599660  96.345  -56.723  51.419  1
599661  96.373  -56.725  51.403  1
599662  96.401  -56.727  51.388  1
599663  96.426  -56.726  51.371  1
599664  96.450  -56.721  51.354  1
599665  96.473  -56.716  51.336  1
599666  96.497  -56.714  51.319  1
599667  96.519  -56.721  51.304  1
599668  96.542  -56.727  51.290  1
599669  96.565  -56.734  51.275  1
599670  96.594  -56.730  51.256  1
599671  96.623  -56.726  51.234  1
599672  96.650  -56.725  51.210  1
599673  96.677  -56.725  51.187  1
599674  96.703  -56.724  51.167  1
599675  96.730  -56.724  51.147  1
599676  96.757  -56.723  51.128  1
599677  96.789  -56.736  51.110  1
599678  96.820  -56.750  51.091  1
599679  96.852  -56.765  51.074  1
599680  96.872  -56.760  51.055  1
599681  96.910  -56.758  51.037  1
599682  96.961  -56.762  51.021  1
599683  97.006  -56.764  51.000  1
599684  97.039  -56.764  50.978  1
599685  97.073  -56.765  50.955  1
599686  97.106  -56.765  50.931  1
599687  97.139  -56.758  50.908  1
599688  97.172  -56.750  50.888  1
599689  97.206  -56.743  50.879  1
599690  97.238  -56.734  50.874  1
599691  97.272  -56.726  50.868  1
599692  97.305  -56.718  50.861  1
599693  97.338  -56.710  50.852  1
599694  97.371  -56.702  50.840  1
599695  97.404  -56.695  50.828  1
599696  97.445  -56.702  50.816  1
599697  97.487  -56.708  50.802  1
599698  97.527  -56.715  50.788  1
599699  97.569  -56.722  50.772  1
599700  97.609  -56.729  50.755  1
599701  97.650  -56.736  50.736  1
599702  97.691  -56.743  50.719  1
599703  97.730  -56.751  50.704  1
599704  97.764  -56.759  50.689  1
599705  97.798  -56.768  50.676  1
599706  97.832  -56.777  50.665  1
599707  97.866  -56.785  50.656  1
599708  97.900  -56.793  50.648  1
599709  97.934  -56.802  50.637  1
599710  97.968  -56.810  50.625  1
599711  98.002  -56.818  50.612  1
599712  98.036  -56.827  50.599  1
599713  98.070  -56.836  50.585  1
599714  98.104  -56.844  50.568  1
599715  98.138  -56.852  50.544  1
599716  98.172  -56.861  50.520  1
599717  98.207  -56.869  50.497  1
599718  98.240  -56.878  50.477  1
599719  98.275  -56.887  50.457  1
599720  98.308  -56.895  50.435  1
599721  98.343  -56.903  50.407  1
599722  98.377  -56.912  50.379  1
599723  98.411  -56.920  50.349  1
599724  98.445  -56.928  50.317  1
599725  98.479  -56.937  50.285  1
599726  98.513  -56.946  50.255  1
599727  98.548  -56.950  50.228  1
599728  98.579  -56.948  50.201  1
599729  98.608  -56.943  50.175  1
599730  98.640  -56.946  50.149  1
599731  98.671  -56.949  50.124  1
599732  98.703  -56.951  50.101  1
599733  98.735  -56.953  50.076  1
599734  98.767  -56.956  50.051  1
599735  98.803  -56.969  50.027  1
599736  98.843  -56.990  50.004  1
599737  98.883  -57.010  49.981  1
599738  98.918  -57.008  49.958  1
599739  98.954  -57.004  49.935  1
599740  98.999  -57.004  49.914  1
599741  99.043  -57.005  49.891  1
599742  99.087  -57.005  49.866  1
599743  99.131  -57.005  49.840  1
599744  99.171  -57.007  49.813  1
599745  99.187  -57.018  49.784  1
599746  99.203  -57.028  49.755  1
599747  99.220  -57.039  49.725  1
599748  99.236  -57.050  49.695  1
599749  99.262  -57.055  49.666  1
599750  99.289  -57.059  49.636  1
599751  99.317  -57.063  49.608  1
599752  99.345  -57.068  49.579  1
599753  99.372  -57.072  49.549  1
599754  99.400  -57.076  49.519  1
599755  99.428  -57.081  49.489  1
599756  99.454  -57.086  49.459  1
599757  99.479  -57.092  49.428  1
599758  99.504  -57.098  49.397  1
599759  99.528  -57.105  49.366  1
599760  99.553  -57.111  49.333  1
599761  99.593  -57.136  49.300  1
599762  99.637  -57.167  49.265  1
599763  99.643  -57.140  49.230  1
599764  99.671  -57.162  49.195  1
599765  99.697  -57.180  49.159  1
599766  99.722  -57.197  49.123  1
599767  99.748  -57.216  49.087  1
599768  99.773  -57.233  49.051  1
599769  99.799  -57.251  49.017  1
599770  99.825  -57.269  48.985  1
599771  99.850  -57.287  48.952  1
599772  99.875  -57.304  48.920  1
599773  99.901  -57.322  48.889  1
599774  99.927  -57.341  48.859  1
599775  99.952  -57.358  48.831  1
599776  99.978  -57.376  48.804  1
599777  100.003  -57.394  48.779  1
599778  100.028  -57.412  48.755  1
600109  88.351  -53.094  57.452  4
600110  88.386  -53.109  57.452  4
600111  88.421  -53.124  57.452  4
600112  88.457  -53.139  57.454  4
600113  88.493  -53.156  57.455  4
600114  88.531  -53.176  57.455  4
600115  88.569  -53.195  57.455  4
600116  88.607  -53.214  57.455  4
600117  88.645  -53.233  57.456  4
600118  88.683  -53.252  57.455  4
600119  88.721  -53.272  57.454  4
600120  88.759  -53.291  57.453  4
600121  88.797  -53.311  57.451  4
600122  88.835  -53.330  57.448  4
600123  88.874  -53.349  57.445  4
600124  88.911  -53.368  57.442  4
600125  88.950  -53.388  57.438  4
600126  88.987  -53.407  57.434  4
600127  89.026  -53.427  57.430  4
600128  89.063  -53.446  57.424  4
600129  89.102  -53.465  57.417  4
600130  89.139  -53.484  57.411  4
600131  89.174  -53.506  57.405  4
600132  89.205  -53.529  57.398  4
600133  89.236  -53.553  57.390  4
600134  89.258  -53.586  57.381  4
600135  89.288  -53.615  57.372  4
600136  89.318  -53.643  57.361  4
600137  89.348  -53.671  57.350  4
600138  89.378  -53.699  57.338  4
600139  89.408  -53.728  57.325  4
600140  89.451  -53.733  57.310  4
600141  89.477  -53.744  57.294  4
600142  89.507  -53.759  57.277  4
600143  89.541  -53.777  57.260  4
600144  89.576  -53.794  57.240  4
600145  89.610  -53.812  57.221  4
600146  89.645  -53.829  57.197  4
600147  89.679  -53.847  57.168  4
600148  89.713  -53.865  57.136  4
600149  89.747  -53.882  57.101  4
600150  89.782  -53.900  57.065  4
600151  89.816  -53.917  57.026  4
600152  89.850  -53.935  56.984  4
600153  89.885  -53.952  56.942  4
600154  89.919  -53.969  56.899  4
600155  89.954  -53.988  56.856  4
600156  89.988  -54.005  56.815  4
600157  90.022  -54.022  56.775  4
600158  90.056  -54.040  56.735  4
600163  90.228  -54.128  56.389  1
600164  90.262  -54.145  56.354  1
600165  90.297  -54.163  56.319  1
600166  90.335  -54.177  56.287  1
600167  90.379  -54.189  56.255  1
600168  90.422  -54.200  56.227  1
600169  90.462  -54.212  56.200  1
600170  90.479  -54.232  56.175  1
600171  90.497  -54.252  56.150  1
600172  90.514  -54.273  56.128  1
600173  90.531  -54.292  56.109  1
600174  90.548  -54.313  56.088  1
600175  90.565  -54.333  56.064  1
600176  90.582  -54.353  56.037  1
600177  90.600  -54.373  56.011  1
600178  90.617  -54.393  55.989  1
600179  90.634  -54.414  55.969  1
600180  90.651  -54.433  55.953  1
600181  90.668  -54.454  55.940  1
600182  90.685  -54.474  55.925  1
600183  90.703  -54.494  55.910  1
600184  90.737  -54.497  55.897  1
600185  90.767  -54.515  55.885  1
600186  90.796  -54.535  55.868  1
600187  90.825  -54.555  55.846  1
600188  90.854  -54.575  55.820  1
600189  90.883  -54.596  55.794  1
600190  90.912  -54.615  55.766  1
600191  90.941  -54.636  55.742  1
600192  90.975  -54.651  55.723  1
600193  91.012  -54.665  55.706  1
600194  91.049  -54.678  55.692  1
600195  91.086  -54.692  55.680  1
600196  91.123  -54.706  55.670  1
600197  91.160  -54.719  55.666  1
600198  91.198  -54.733  55.666  1
600199  91.234  -54.746  55.669  1
600200  91.272  -54.760  55.673  1
600201  91.312  -54.772  55.676  1
600202  91.366  -54.777  55.676  1
600203  91.419  -54.781  55.674  1
600204  91.473  -54.786  55.667  1
600205  91.526  -54.791  55.653  1
600206  91.580  -54.796  55.634  1
600207  91.633  -54.801  55.607  1
600208  91.686  -54.806  55.574  1
600209  91.729  -54.810  55.536  1
600210  91.759  -54.813  55.504  1
600211  91.789  -54.817  55.477  1
600212  91.819  -54.820  55.457  1
600213  91.849  -54.824  55.441  1
600214  91.877  -54.834  55.426  1
600215  91.904  -54.845  55.412  1
600216  91.931  -54.856  55.400  1
600217  91.959  -54.867  55.387  1
600218  91.986  -54.878  55.376  1
600219  92.015  -54.893  55.366  1
600220  92.048  -54.913  55.353  1
600221  92.081  -54.934  55.341  1
600222  92.113  -54.954  55.330  1
600223  92.146  -54.975  55.321  1
600224  92.179  -54.995  55.315  1
600225  92.212  -55.016  55.313  1
600226  92.245  -55.036  55.316  1
600227  92.279  -55.054  55.327  1
600228  92.317  -55.057  55.336  1
600229  92.356  -55.060  55.340  1
600230  92.394  -55.063  55.341  1
600231  92.433  -55.067  55.342  1
600232  92.472  -55.070  55.341  1
600233  92.504  -55.078  55.336  1
600234  92.531  -55.088  55.332  1
600235  92.557  -55.100  55.325  1
600236  92.584  -55.110  55.318  1
600237  92.611  -55.121  55.315  1
600238  92.637  -55.132  55.317  1
600239  92.663  -55.143  55.321  1
600240  92.690  -55.154  55.324  1
600241  92.717  -55.165  55.328  1
600242  92.743  -55.176  55.334  1
600243  92.769  -55.194  55.342  1
600244  92.802  -55.212  55.350  1
600245  92.837  -55.230  55.357  1
600246  92.873  -55.248  55.365  1
600247  92.910  -55.269  55.375  1
600248  92.947  -55.290  55.383  1
600249  92.984  -55.312  55.389  1
600250  93.021  -55.333  55.392  1
600251  93.059  -55.354  55.387  1
600252  93.096  -55.376  55.382  1
600253  93.133  -55.398  55.382  1
600254  93.170  -55.420  55.379  1
600255  93.207  -55.441  55.369  1
600256  93.245  -55.463  55.351  1
600257  93.282  -55.484  55.328  1
600258  93.319  -55.506  55.307  1
600259  93.356  -55.527  55.292  1
600260  93.394  -55.549  55.284  1
600261  93.431  -55.571  55.280  1
600262  93.468  -55.583  55.275  1
600263  93.503  -55.581  55.267  1
600264  93.539  -55.579  55.256  1
600265  93.575  -55.577  55.246  1
600266  93.611  -55.574  55.233  1
600267  93.646  -55.572  55.217  1
600268  93.674  -55.583  55.197  1
600269  93.695  -55.609  55.174  1
600270  93.714  -55.639  55.154  1
600271  93.734  -55.668  55.136  1
600272  93.754  -55.698  55.120  1
600273  93.774  -55.727  55.102  1
600274  93.794  -55.756  55.086  1
600275  93.814  -55.786  55.070  1
600276  93.834  -55.815  55.050  1
600277  93.854  -55.845  55.030  1
600278  93.873  -55.875  55.007  1
600279  93.894  -55.903  54.982  1
600280  93.913  -55.933  54.958  1
600281  93.935  -55.959  54.933  1
600282  93.964  -55.970  54.908  1
600283  93.993  -55.982  54.878  1
600284  94.022  -55.994  54.841  1
600285  94.051  -56.005  54.797  1
600286  94.080  -56.016  54.750  1
600287  94.110  -56.028  54.703  1
600288  94.142  -56.034  54.666  1
600289  94.175  -56.041  54.631  1
600290  94.207  -56.048  54.594  1
600291  94.240  -56.055  54.554  1
600292  94.273  -56.063  54.511  1
600293  94.308  -56.072  54.469  1
600294  94.341  -56.080  54.426  1
600295  94.375  -56.088  54.380  1
600296  94.409  -56.097  54.329  1
600297  94.443  -56.106  54.274  1
600298  94.477  -56.114  54.221  1
600299  94.512  -56.122  54.170  1
600300  94.563  -56.134  54.120  1
600301  94.609  -56.145  54.072  1
600302  94.643  -56.153  54.019  1
600303  94.677  -56.160  53.965  1
600304  94.711  -56.168  53.915  1
600305  94.745  -56.176  53.869  1
600306  94.779  -56.184  53.823  1
600307  94.813  -56.191  53.776  1
600308  94.847  -56.199  53.726  1
600309  94.881  -56.207  53.674  1
600310  94.915  -56.212  53.622  1
600311  94.949  -56.215  53.570  1
600312  94.985  -56.230  53.525  1
600313  95.024  -56.254  53.482  1
600314  95.062  -56.277  53.439  1
600315  95.105  -56.292  53.394  1
600316  95.147  -56.303  53.348  1
600317  95.173  -56.329  53.302  1
600318  95.195  -56.348  53.250  1
600319  95.212  -56.361  53.196  1
600320  95.230  -56.374  53.140  1
600321  95.247  -56.387  53.082  1
600322  95.265  -56.400  53.022  1
600323  95.303  -56.414  52.963  1
600324  95.343  -56.429  52.905  1
600325  95.381  -56.439  52.848  1
600326  95.418  -56.448  52.790  1
600327  95.456  -56.457  52.731  1
600328  95.494  -56.466  52.672  1
600329  95.531  -56.475  52.611  1
600330  95.569  -56.484  52.551  1
600331  95.596  -56.484  52.492  1
600332  95.622  -56.485  52.436  1
600333  95.650  -56.486  52.381  1
600334  95.676  -56.486  52.328  1
600335  95.703  -56.486  52.278  1
600336  95.736  -56.491  52.229  1
600337  95.771  -56.496  52.181  1
600338  95.806  -56.502  52.136  1
600339  95.840  -56.508  52.093  1
600340  95.873  -56.516  52.048  1
600341  95.899  -56.533  52.005  1
600342  95.924  -56.541  51.961  1
600343  95.950  -56.544  51.917  1
600344  95.975  -56.547  51.877  1
600345  96.000  -56.550  51.839  1
600346  96.025  -56.553  51.801  1
600347  96.050  -56.556  51.765  1
600348  96.075  -56.559  51.731  1
600349  96.092  -56.567  51.698  1
600350  96.109  -56.575  51.667  1
600351  96.126  -56.583  51.638  1
600352  96.143  -56.591  51.610  1
600353  96.160  -56.599  51.582  1
600354  96.179  -56.607  51.552  1
600355  96.214  -56.617  51.522  1
600356  96.248  -56.628  51.494  1
600357  96.281  -56.639  51.468  1
600358  96.297  -56.655  51.444  1
600359  96.312  -56.670  51.420  1
600360  96.327  -56.685  51.398  1
600361  96.347  -56.696  51.377  1
600362  96.375  -56.698  51.361  1
600363  96.402  -56.699  51.346  1
600364  96.426  -56.695  51.330  1
600365  96.449  -56.690  51.315  1
600366  96.472  -56.685  51.299  1
600367  96.496  -56.682  51.281  1
600368  96.519  -56.689  51.265  1
600369  96.541  -56.695  51.249  1
600370  96.564  -56.702  51.232  1
600371  96.587  -56.708  51.212  1
600372  96.617  -56.702  51.190  1
600373  96.647  -56.697  51.165  1
600374  96.674  -56.696  51.142  1
600375  96.700  -56.696  51.120  1
600376  96.727  -56.696  51.098  1
600377  96.754  -56.695  51.076  1
600378  96.785  -56.705  51.057  1
600379  96.816  -56.720  51.037  1
600380  96.846  -56.730  51.021  1
600381  96.865  -56.723  51.005  1
600382  96.908  -56.724  50.989  1
600383  96.959  -56.727  50.974  1
600384  97.004  -56.728  50.952  1
600385  97.037  -56.729  50.930  1
600386  97.071  -56.729  50.907  1
600387  97.104  -56.730  50.883  1
600388  97.138  -56.727  50.861  1
600389  97.171  -56.718  50.842  1
600390  97.204  -56.710  50.832  1
600391  97.237  -56.702  50.828  1
600392  97.270  -56.694  50.823  1
600393  97.303  -56.686  50.818  1
600394  97.336  -56.677  50.811  1
600395  97.370  -56.670  50.802  1
600396  97.407  -56.670  50.793  1
600397  97.448  -56.677  50.782  1
600398  97.489  -56.684  50.771  1
600399  97.530  -56.691  50.758  1
600400  97.571  -56.698  50.742  1
600401  97.612  -56.705  50.724  1
600402  97.653  -56.711  50.707  1
600403  97.692  -56.716  50.691  1
600404  97.726  -56.717  50.676  1
600405  97.762  -56.724  50.662  1
600406  97.798  -56.730  50.649  1
600407  97.832  -56.739  50.638  1
600408  97.867  -56.747  50.629  1
600409  97.901  -56.756  50.622  1
600410  97.935  -56.765  50.615  1
600411  97.969  -56.774  50.604  1
600412  98.004  -56.782  50.589  1
600413  98.038  -56.791  50.574  1
600414  98.072  -56.799  50.559  1
600415  98.107  -56.809  50.544  1
600416  98.141  -56.817  50.522  1
600417  98.175  -56.826  50.500  1
600418  98.210  -56.834  50.479  1
600419  98.244  -56.843  50.458  1
600420  98.278  -56.852  50.438  1
600421  98.312  -56.860  50.415  1
600422  98.347  -56.869  50.387  1
600423  98.381  -56.877  50.358  1
600424  98.415  -56.887  50.327  1
600425  98.449  -56.895  50.294  1
600426  98.484  -56.904  50.260  1
600427  98.518  -56.912  50.232  1
600428  98.553  -56.921  50.205  1
600429  98.586  -56.928  50.178  1
600430  98.618  -56.930  50.151  1
600431  98.649  -56.933  50.124  1
600432  98.681  -56.935  50.098  1
600433  98.713  -56.938  50.075  1
600434  98.744  -56.940  50.050  1
600435  98.776  -56.943  50.025  1
600436  98.808  -56.946  50.002  1
600437  98.843  -56.955  49.980  1
600438  98.882  -56.975  49.957  1
600439  98.919  -56.981  49.933  1
600440  98.958  -56.978  49.911  1
600441  99.002  -56.978  49.889  1
600442  99.046  -56.979  49.866  1
600443  99.090  -56.979  49.841  1
600444  99.135  -56.980  49.814  1
600445  99.179  -56.980  49.787  1
600446  99.200  -56.988  49.758  1
600447  99.217  -56.999  49.729  1
600448  99.233  -57.010  49.700  1
600449  99.251  -57.019  49.671  1
600450  99.279  -57.024  49.642  1
600451  99.306  -57.028  49.614  1
600452  99.334  -57.032  49.589  1
600453  99.362  -57.037  49.563  1
600454  99.390  -57.040  49.535  1
600455  99.417  -57.045  49.506  1
600456  99.442  -57.051  49.476  1
600457  99.467  -57.057  49.444  1
600458  99.492  -57.064  49.414  1
600459  99.516  -57.070  49.382  1
600460  99.541  -57.077  49.350  1
600461  99.566  -57.083  49.318  1
600462  99.609  -57.113  49.285  1
600463  99.653  -57.144  49.250  1
600464  99.656  -57.120  49.215  1
600465  99.682  -57.138  49.180  1
600466  99.707  -57.156  49.145  1
600467  99.733  -57.174  49.110  1
600468  99.759  -57.191  49.074  1
600469  99.784  -57.210  49.039  1
600470  99.809  -57.227  49.006  1
600471  99.835  -57.245  48.973  1
600472  99.861  -57.263  48.941  1
600473  99.887  -57.281  48.910  1
600474  99.912  -57.298  48.879  1
600475  99.937  -57.316  48.849  1
600476  99.963  -57.335  48.821  1
600477  99.989  -57.352  48.794  1
600478  100.014  -57.370  48.769  1
600479  100.040  -57.388  48.745  1
600809  88.340  -53.043  57.447  4
600810  88.376  -53.059  57.447  4
600811  88.411  -53.074  57.447  4
600812  88.446  -53.089  57.448  4
600813  88.482  -53.106  57.449  4
600814  88.521  -53.126  57.450  4
600815  88.558  -53.145  57.451  4
600816  88.597  -53.164  57.450  4
600817  88.635  -53.183  57.451  4
600818  88.673  -53.203  57.451  4
600819  88.711  -53.222  57.450  4
600820  88.749  -53.241  57.448  4
600821  88.787  -53.261  57.447  4
600822  88.825  -53.280  57.444  4
600823  88.863  -53.299  57.442  4
600824  88.901  -53.318  57.439  4
600825  88.939  -53.338  57.435  4
600826  88.977  -53.357  57.430  4
600827  89.015  -53.377  57.426  4
600828  89.053  -53.396  57.421  4
600829  89.091  -53.415  57.415  4
600830  89.129  -53.434  57.408  4
600831  89.158  -53.460  57.402  4
600832  89.190  -53.483  57.395  4
600833  89.222  -53.505  57.387  4
600834  89.251  -53.531  57.379  4
600835  89.273  -53.563  57.370  4
600836  89.298  -53.594  57.360  4
600837  89.328  -53.623  57.350  4
600838  89.358  -53.651  57.339  4
600839  89.388  -53.679  57.327  4
600840  89.418  -53.707  57.314  4
600841  89.468  -53.707  57.301  4
600842  89.493  -53.719  57.285  4
600843  89.519  -53.731  57.269  4
600844  89.551  -53.747  57.253  4
600845  89.585  -53.765  57.234  4
600846  89.619  -53.782  57.214  4
600847  89.654  -53.800  57.192  4
600848  89.688  -53.817  57.166  4
600849  89.723  -53.834  57.134  4
600850  89.757  -53.852  57.101  4
600851  89.791  -53.870  57.064  4
600852  89.825  -53.888  57.026  4
600853  89.860  -53.905  56.986  4
600854  89.894  -53.922  56.943  4
600855  89.929  -53.940  56.901  4
600856  89.963  -53.957  56.858  4
600857  89.997  -53.975  56.816  4
600858  90.031  -53.993  56.776  4
600859  90.066  -54.010  56.736  4
600860  90.100  -54.028  56.697  4
600864  90.237  -54.098  56.390  1
600865  90.272  -54.116  56.354  1
600866  90.308  -54.132  56.319  1
600867  90.351  -54.143  56.286  1
600868  90.394  -54.154  56.254  1
600869  90.437  -54.166  56.225  1
600870  90.469  -54.180  56.197  1
600871  90.487  -54.201  56.170  1
600872  90.504  -54.221  56.144  1
600873  90.521  -54.241  56.121  1
600874  90.538  -54.261  56.100  1
600875  90.555  -54.281  56.078  1
600876  90.573  -54.301  56.054  1
600877  90.590  -54.322  56.028  1
600878  90.607  -54.342  56.004  1
600879  90.624  -54.362  55.982  1
600880  90.642  -54.382  55.962  1
600881  90.659  -54.402  55.945  1
600882  90.676  -54.423  55.930  1
600883  90.693  -54.442  55.915  1
600884  90.725  -54.449  55.900  1
600885  90.757  -54.458  55.888  1
600886  90.787  -54.478  55.874  1
600887  90.815  -54.499  55.856  1
600888  90.845  -54.518  55.831  1
600889  90.873  -54.539  55.804  1
600890  90.902  -54.558  55.778  1
600891  90.931  -54.579  55.752  1
600892  90.960  -54.599  55.729  1
600893  90.989  -54.619  55.711  1
600894  91.021  -54.637  55.695  1
600895  91.059  -54.650  55.682  1
600896  91.095  -54.664  55.672  1
600897  91.133  -54.678  55.665  1
600898  91.169  -54.691  55.663  1
600899  91.207  -54.705  55.664  1
600900  91.243  -54.718  55.668  1
600901  91.280  -54.732  55.671  1
600902  91.329  -54.739  55.673  1
600903  91.383  -54.744  55.672  1
600904  91.436  -54.749  55.669  1
600905  91.490  -54.754  55.660  1
600906  91.543  -54.759  55.643  1
600907  91.597  -54.763  55.621  1
600908  91.650  -54.768  55.594  1
600909  91.704  -54.773  55.561  1
600910  91.746  -54.778  55.527  1
600911  91.777  -54.781  55.496  1
600912  91.807  -54.784  55.470  1
600913  91.837  -54.788  55.450  1
600914  91.866  -54.795  55.434  1
600915  91.893  -54.806  55.419  1
600916  91.920  -54.817  55.406  1
600917  91.947  -54.828  55.394  1
600918  91.975  -54.840  55.382  1
600919  92.002  -54.850  55.372  1
600920  92.029  -54.862  55.363  1
600921  92.062  -54.883  55.351  1
600922  92.095  -54.903  55.339  1
600923  92.128  -54.924  55.328  1
600924  92.160  -54.944  55.318  1
600925  92.193  -54.965  55.311  1
600926  92.227  -54.985  55.308  1
600927  92.261  -55.004  55.309  1
600928  92.295  -55.022  55.316  1
600929  92.331  -55.027  55.322  1
600930  92.370  -55.030  55.325  1
600931  92.409  -55.033  55.327  1
600932  92.447  -55.037  55.328  1
600933  92.486  -55.040  55.326  1
600934  92.524  -55.044  55.323  1
600935  92.551  -55.054  55.321  1
600936  92.577  -55.066  55.318  1
600937  92.603  -55.076  55.317  1
600938  92.630  -55.088  55.319  1
600939  92.656  -55.098  55.324  1
600940  92.683  -55.110  55.329  1
600941  92.710  -55.120  55.334  1
600942  92.736  -55.132  55.340  1
600943  92.762  -55.150  55.347  1
600944  92.788  -55.167  55.355  1
600945  92.817  -55.185  55.364  1
600946  92.853  -55.204  55.373  1
600947  92.889  -55.222  55.385  1
600948  92.924  -55.239  55.400  1
600949  92.960  -55.257  55.411  1
600950  92.995  -55.276  55.416  1
600951  93.031  -55.295  55.413  1
600952  93.069  -55.316  55.405  1
600953  93.106  -55.337  55.393  1
600954  93.143  -55.359  55.386  1
600955  93.180  -55.380  55.379  1
600956  93.217  -55.402  55.366  1
600957  93.255  -55.423  55.348  1
600958  93.292  -55.445  55.327  1
600959  93.329  -55.467  55.310  1
600960  93.366  -55.489  55.300  1
600961  93.404  -55.510  55.292  1
600962  93.441  -55.531  55.285  1
600963  93.478  -55.553  55.276  1
600964  93.514  -55.552  55.266  1
600965  93.550  -55.550  55.254  1
600966  93.585  -55.548  55.242  1
600967  93.621  -55.546  55.229  1
600968  93.652  -55.551  55.215  1
600969  93.674  -55.571  55.198  1
600970  93.695  -55.592  55.179  1
600971  93.717  -55.613  55.159  1
600972  93.737  -55.640  55.139  1
600973  93.757  -55.670  55.117  1
600974  93.777  -55.699  55.095  1
600975  93.797  -55.729  55.076  1
600976  93.817  -55.759  55.059  1
600977  93.837  -55.788  55.039  1
600978  93.856  -55.818  55.020  1
600979  93.876  -55.846  54.998  1
600980  93.896  -55.876  54.974  1
600981  93.916  -55.906  54.953  1
600982  93.936  -55.935  54.929  1
600983  93.965  -55.947  54.903  1
600984  93.994  -55.959  54.873  1
600985  94.023  -55.970  54.835  1
600986  94.052  -55.981  54.790  1
600987  94.081  -55.993  54.744  1
600988  94.113  -56.002  54.697  1
600989  94.145  -56.009  54.660  1
600990  94.178  -56.016  54.627  1
600991  94.210  -56.022  54.590  1
600992  94.242  -56.029  54.549  1
600993  94.275  -56.037  54.505  1
600994  94.309  -56.045  54.461  1
600995  94.343  -56.053  54.416  1
600996  94.377  -56.063  54.369  1
600997  94.411  -56.071  54.318  1
600998  94.445  -56.079  54.267  1
600999  94.479  -56.088  54.219  1
601000  94.519  -56.097  54.170  1
601001  94.569  -56.109  54.121  1
601002  94.619  -56.120  54.074  1
601003  94.653  -56.128  54.025  1
601004  94.687  -56.136  53.975  1
601005  94.721  -56.144  53.928  1
601006  94.755  -56.151  53.882  1
601007  94.789  -56.159  53.837  1
601008  94.823  -56.167  53.790  1
601009  94.857  -56.175  53.739  1
601010  94.891  -56.182  53.686  1
601011  94.925  -56.185  53.633  1
601012  94.959  -56.188  53.579  1
601013  94.995  -56.201  53.529  1
601014  95.033  -56.225  53.484  1
601015  95.072  -56.248  53.440  1
601016  95.110  -56.272  53.395  1
601017  95.153  -56.286  53.350  1
601018  95.182  -56.310  53.305  1
601019  95.199  -56.323  53.256  1
601020  95.216  -56.335  53.204  1
601021  95.234  -56.348  53.148  1
601022  95.252  -56.361  53.089  1
601023  95.270  -56.374  53.030  1
601024  95.310  -56.389  52.970  1
601025  95.348  -56.400  52.910  1
601026  95.386  -56.409  52.852  1
601027  95.423  -56.418  52.794  1
601028  95.461  -56.427  52.737  1
601029  95.498  -56.436  52.679  1
601030  95.536  -56.445  52.616  1
601031  95.573  -56.454  52.553  1
601032  95.603  -56.457  52.491  1
601033  95.629  -56.457  52.431  1
601034  95.657  -56.458  52.374  1
601035  95.683  -56.458  52.319  1
601036  95.711  -56.459  52.267  1
601037  95.746  -56.464  52.215  1
601038  95.780  -56.470  52.165  1
601039  95.815  -56.476  52.117  1
601040  95.849  -56.482  52.072  1
601041  95.876  -56.499  52.027  1
601042  95.902  -56.517  51.981  1
601043  95.927  -56.520  51.937  1
601044  95.952  -56.523  51.893  1
601045  95.977  -56.527  51.851  1
601046  96.003  -56.530  51.811  1
601047  96.027  -56.533  51.773  1
601048  96.052  -56.536  51.737  1
601049  96.078  -56.539  51.701  1
601050  96.103  -56.542  51.667  1
601051  96.128  -56.545  51.635  1
601052  96.148  -56.552  51.605  1
601053  96.164  -56.560  51.576  1
601054  96.181  -56.567  51.546  1
601055  96.198  -56.576  51.515  1
601056  96.227  -56.586  51.486  1
601057  96.261  -56.596  51.457  1
601058  96.285  -56.609  51.431  1
601059  96.301  -56.624  51.406  1
601060  96.316  -56.639  51.384  1
601061  96.332  -56.655  51.360  1
601062  96.348  -56.668  51.338  1
601063  96.376  -56.671  51.321  1
601064  96.401  -56.668  51.306  1
601065  96.425  -56.664  51.292  1
601066  96.448  -56.659  51.281  1
601067  96.472  -56.655  51.268  1
601068  96.496  -56.650  51.249  1
601069  96.518  -56.656  51.226  1
601070  96.541  -56.662  51.204  1
601071  96.564  -56.669  51.183  1
601072  96.586  -56.675  51.164  1
601073  96.609  -56.682  51.142  1
601074  96.640  -56.675  51.118  1
601075  96.671  -56.668  51.096  1
601076  96.697  -56.668  51.074  1
601077  96.725  -56.668  51.050  1
601078  96.751  -56.667  51.025  1
601079  96.781  -56.674  51.004  1
601080  96.813  -56.689  50.984  1
601081  96.838  -56.693  50.967  1
601082  96.858  -56.686  50.952  1
601083  96.906  -56.688  50.938  1
601084  96.957  -56.691  50.923  1
601085  97.002  -56.693  50.902  1
601086  97.036  -56.693  50.879  1
601087  97.069  -56.694  50.857  1
601088  97.103  -56.694  50.835  1
601089  97.136  -56.694  50.815  1
601090  97.169  -56.686  50.796  1
601091  97.203  -56.678  50.784  1
601092  97.236  -56.670  50.780  1
601093  97.268  -56.661  50.777  1
601094  97.302  -56.654  50.773  1
601095  97.335  -56.646  50.768  1
601096  97.369  -56.639  50.762  1
601097  97.410  -56.646  50.755  1
601098  97.451  -56.652  50.745  1
601099  97.492  -56.659  50.737  1
601100  97.533  -56.666  50.725  1
601101  97.574  -56.673  50.710  1
601102  97.615  -56.680  50.693  1
601103  97.651  -56.683  50.677  1
601104  97.685  -56.683  50.662  1
601105  97.720  -56.683  50.648  1
601106  97.756  -56.689  50.634  1
601107  97.792  -56.696  50.622  1
601108  97.828  -56.702  50.612  1
601109  97.864  -56.708  50.603  1
601110  97.899  -56.716  50.594  1
601111  97.933  -56.725  50.586  1
601112  97.967  -56.733  50.575  1
601113  98.002  -56.743  50.560  1
601114  98.036  -56.751  50.545  1
601115  98.070  -56.760  50.529  1
601116  98.104  -56.768  50.515  1
601117  98.139  -56.777  50.496  1
601118  98.173  -56.786  50.475  1
601119  98.208  -56.794  50.455  1
601120  98.242  -56.803  50.434  1
601121  98.276  -56.812  50.414  1
601122  98.310  -56.821  50.390  1
601123  98.345  -56.829  50.363  1
601124  98.379  -56.838  50.333  1
601125  98.413  -56.846  50.301  1
601126  98.447  -56.855  50.268  1
601127  98.482  -56.864  50.235  1
601128  98.516  -56.873  50.207  1
601129  98.550  -56.881  50.179  1
601130  98.584  -56.889  50.151  1
601131  98.618  -56.896  50.124  1
601132  98.652  -56.904  50.098  1
601133  98.686  -56.912  50.072  1
601134  98.720  -56.920  50.048  1
601135  98.754  -56.928  50.024  1
601136  98.786  -56.930  49.999  1
601137  98.817  -56.932  49.976  1
601138  98.849  -56.935  49.955  1
601139  98.882  -56.940  49.932  1
601140  98.921  -56.954  49.909  1
601141  98.961  -56.953  49.884  1
601142  99.006  -56.953  49.861  1
601143  99.050  -56.953  49.836  1
601144  99.094  -56.953  49.811  1
601145  99.138  -56.954  49.785  1
601146  99.182  -56.954  49.758  1
601147  99.213  -56.959  49.729  1
601148  99.230  -56.970  49.700  1
601149  99.246  -56.981  49.673  1
601150  99.268  -56.988  49.646  1
601151  99.295  -56.993  49.618  1
601152  99.323  -56.997  49.592  1
601153  99.351  -57.001  49.568  1
601154  99.378  -57.006  49.545  1
601155  99.405  -57.010  49.519  1
601156  99.430  -57.017  49.490  1
601157  99.454  -57.023  49.460  1
601158  99.479  -57.029  49.427  1
601159  99.504  -57.036  49.395  1
601160  99.529  -57.042  49.364  1
601161  99.554  -57.049  49.332  1
601162  99.581  -57.059  49.300  1
601163  99.625  -57.090  49.267  1
601164  99.640  -57.075  49.232  1
601165  99.667  -57.096  49.199  1
601166  99.693  -57.114  49.164  1
601167  99.718  -57.131  49.129  1
601168  99.744  -57.150  49.095  1
601169  99.770  -57.168  49.059  1
601170  99.795  -57.185  49.025  1
601171  99.821  -57.203  48.993  1
601172  99.846  -57.221  48.960  1
601173  99.872  -57.239  48.929  1
601174  99.897  -57.257  48.898  1
601175  99.923  -57.275  48.868  1
601176  99.948  -57.293  48.838  1
601177  99.974  -57.310  48.810  1
601178  99.999  -57.329  48.783  1
601179  100.025  -57.346  48.758  1
601180  100.051  -57.364  48.734  1
601510  88.364  -53.008  57.443  4
601511  88.400  -53.023  57.443  4
601512  88.435  -53.039  57.443  4
601513  88.472  -53.056  57.444  4
601514  88.510  -53.076  57.445  4
601515  88.548  -53.095  57.446  4
601516  88.586  -53.114  57.446  4
601517  88.624  -53.133  57.446  4
601518  88.662  -53.153  57.446  4
601519  88.700  -53.172  57.446  4
601520  88.738  -53.192  57.444  4
601521  88.776  -53.211  57.444  4
601522  88.814  -53.230  57.441  4
601523  88.852  -53.249  57.438  4
601524  88.890  -53.268  57.435  4
601525  88.928  -53.288  57.432  4
601526  88.967  -53.307  57.428  4
601527  89.004  -53.327  57.423  4
601528  89.043  -53.346  57.418  4
601529  89.081  -53.365  57.413  4
601530  89.111  -53.390  57.406  4
601531  89.142  -53.413  57.399  4
601532  89.174  -53.436  57.392  4
601533  89.206  -53.458  57.385  4
601534  89.238  -53.481  57.377  4
601535  89.266  -53.508  57.369  4
601536  89.288  -53.540  57.359  4
601537  89.311  -53.572  57.349  4
601538  89.338  -53.603  57.339  4
601539  89.368  -53.631  57.329  4
601540  89.398  -53.659  57.317  4
601541  89.428  -53.686  57.304  4
601542  89.481  -53.684  57.291  4
601543  89.509  -53.693  57.277  4
601544  89.535  -53.706  57.262  4
601545  89.560  -53.717  57.246  4
601546  89.595  -53.734  57.228  4
601547  89.629  -53.753  57.209  4
601548  89.663  -53.770  57.189  4
601549  89.697  -53.787  57.166  4
601550  89.732  -53.805  57.134  4
601551  89.766  -53.822  57.100  4
601552  89.801  -53.840  57.064  4
601553  89.835  -53.857  57.027  4
601554  89.869  -53.875  56.988  4
601555  89.903  -53.893  56.945  4
601556  89.938  -53.910  56.902  4
601557  89.972  -53.928  56.859  4
601558  90.007  -53.945  56.818  4
601559  90.041  -53.963  56.778  4
601560  90.075  -53.980  56.738  4
601561  90.109  -53.998  56.699  4
601566  90.281  -54.085  56.355  1
601567  90.323  -54.098  56.319  1
601568  90.366  -54.109  56.285  1
601569  90.409  -54.120  56.254  1
601570  90.453  -54.132  56.223  1
601571  90.477  -54.149  56.195  1
601572  90.495  -54.170  56.167  1
601573  90.512  -54.189  56.140  1
601574  90.529  -54.210  56.114  1
601575  90.546  -54.229  56.090  1
601576  90.563  -54.250  56.067  1
601577  90.581  -54.270  56.044  1
601578  90.598  -54.290  56.021  1
601579  90.615  -54.311  55.996  1
601580  90.632  -54.330  55.976  1
601581  90.649  -54.351  55.956  1
601582  90.666  -54.370  55.938  1
601583  90.684  -54.391  55.921  1
601584  90.712  -54.400  55.906  1
601585  90.748  -54.402  55.893  1
601586  90.777  -54.421  55.879  1
601587  90.806  -54.442  55.862  1
601588  90.835  -54.461  55.842  1
601589  90.864  -54.482  55.816  1
601590  90.893  -54.502  55.788  1
601591  90.922  -54.522  55.762  1
601592  90.950  -54.543  55.738  1
601593  90.979  -54.562  55.717  1
601594  91.008  -54.583  55.700  1
601595  91.037  -54.603  55.685  1
601596  91.068  -54.622  55.672  1
601597  91.104  -54.636  55.664  1
601598  91.142  -54.649  55.659  1
601599  91.178  -54.663  55.658  1
601600  91.215  -54.677  55.660  1
601601  91.252  -54.690  55.662  1
601602  91.293  -54.702  55.664  1
601603  91.347  -54.706  55.666  1
601604  91.400  -54.712  55.664  1
601605  91.453  -54.716  55.661  1
601606  91.507  -54.721  55.650  1
601607  91.561  -54.726  55.631  1
601608  91.614  -54.731  55.606  1
601609  91.667  -54.736  55.578  1
601610  91.721  -54.740  55.548  1
601611  91.764  -54.745  55.517  1
601612  91.794  -54.749  55.487  1
601613  91.824  -54.752  55.462  1
601614  91.854  -54.756  55.442  1
601615  91.881  -54.768  55.427  1
601616  91.909  -54.779  55.413  1
601617  91.936  -54.790  55.400  1
601618  91.963  -54.801  55.388  1
601619  91.991  -54.812  55.377  1
601620  92.018  -54.823  55.368  1
601621  92.048  -54.834  55.360  1
601622  92.081  -54.849  55.350  1
601623  92.115  -54.869  55.337  1
601624  92.149  -54.888  55.326  1
601625  92.183  -54.908  55.316  1
601626  92.217  -54.928  55.308  1
601627  92.251  -54.947  55.304  1
601628  92.286  -54.966  55.303  1
601629  92.319  -54.986  55.306  1
601630  92.351  -54.994  55.309  1
601631  92.384  -55.000  55.312  1
601632  92.423  -55.003  55.314  1
601633  92.461  -55.006  55.315  1
601634  92.500  -55.010  55.314  1
601635  92.539  -55.013  55.313  1
601636  92.570  -55.021  55.313  1
601637  92.596  -55.032  55.315  1
601638  92.623  -55.042  55.320  1
601639  92.650  -55.054  55.328  1
601640  92.676  -55.064  55.340  1
601641  92.703  -55.075  55.349  1
601642  92.729  -55.087  55.357  1
601643  92.755  -55.105  55.367  1
601644  92.781  -55.123  55.379  1
601645  92.807  -55.141  55.390  1
601646  92.834  -55.160  55.399  1
601647  92.869  -55.177  55.415  1
601648  92.905  -55.195  55.432  1
601649  92.940  -55.213  55.447  1
601650  92.976  -55.231  55.458  1
601651  93.011  -55.249  55.460  1
601652  93.047  -55.267  55.454  1
601653  93.082  -55.285  55.439  1
601654  93.118  -55.303  55.419  1
601655  93.154  -55.321  55.399  1
601656  93.190  -55.342  55.381  1
601657  93.227  -55.363  55.363  1
601658  93.265  -55.385  55.345  1
601659  93.302  -55.406  55.328  1
601660  93.339  -55.428  55.317  1
601661  93.376  -55.449  55.309  1
601662  93.414  -55.471  55.301  1
601663  93.451  -55.492  55.292  1
601664  93.488  -55.514  55.280  1
601665  93.524  -55.523  55.268  1
601666  93.560  -55.520  55.254  1
601667  93.596  -55.518  55.240  1
601668  93.630  -55.518  55.227  1
601669  93.652  -55.539  55.213  1
601670  93.674  -55.560  55.197  1
601671  93.695  -55.580  55.180  1
601672  93.717  -55.601  55.162  1
601673  93.739  -55.621  55.142  1
601674  93.760  -55.643  55.119  1
601675  93.780  -55.672  55.095  1
601676  93.799  -55.702  55.072  1
601677  93.820  -55.731  55.050  1
601678  93.839  -55.760  55.028  1
601679  93.859  -55.790  55.007  1
601680  93.879  -55.819  54.985  1
601681  93.899  -55.849  54.961  1
601682  93.919  -55.878  54.938  1
601683  93.939  -55.908  54.915  1
601684  93.966  -55.924  54.888  1
601685  93.995  -55.935  54.857  1
601686  94.024  -55.947  54.820  1
601687  94.053  -55.958  54.777  1
601688  94.082  -55.969  54.735  1
601689  94.115  -55.976  54.694  1
601690  94.147  -55.983  54.659  1
601691  94.180  -55.990  54.627  1
601692  94.212  -55.997  54.591  1
601693  94.245  -56.003  54.549  1
601694  94.277  -56.010  54.504  1
601695  94.311  -56.019  54.459  1
601696  94.345  -56.028  54.412  1
601697  94.379  -56.036  54.363  1
601698  94.413  -56.044  54.313  1
601699  94.447  -56.053  54.266  1
601700  94.481  -56.061  54.222  1
601701  94.526  -56.072  54.175  1
601702  94.576  -56.083  54.128  1
601703  94.626  -56.095  54.083  1
601704  94.663  -56.103  54.037  1
601705  94.697  -56.111  53.991  1
601706  94.731  -56.119  53.946  1
601707  94.765  -56.127  53.898  1
601708  94.799  -56.135  53.852  1
601709  94.833  -56.142  53.804  1
601710  94.867  -56.150  53.754  1
601711  94.901  -56.154  53.701  1
601712  94.934  -56.158  53.647  1
601713  94.969  -56.161  53.592  1
601714  95.004  -56.172  53.538  1
601715  95.043  -56.196  53.489  1
601716  95.081  -56.219  53.442  1
601717  95.120  -56.243  53.395  1
601718  95.158  -56.266  53.351  1
601719  95.186  -56.285  53.305  1
601720  95.204  -56.298  53.257  1
601721  95.221  -56.310  53.207  1
601722  95.239  -56.323  53.154  1
601723  95.256  -56.335  53.097  1
601724  95.277  -56.349  53.038  1
601725  95.316  -56.361  52.977  1
601726  95.353  -56.370  52.917  1
601727  95.391  -56.379  52.858  1
601728  95.428  -56.389  52.800  1
601729  95.466  -56.398  52.743  1
601730  95.503  -56.407  52.686  1
601731  95.541  -56.416  52.625  1
601732  95.579  -56.425  52.558  1
601733  95.610  -56.429  52.493  1
601734  95.636  -56.429  52.429  1
601735  95.663  -56.429  52.369  1
601736  95.690  -56.430  52.312  1
601737  95.721  -56.432  52.257  1
601738  95.755  -56.439  52.203  1
601739  95.790  -56.444  52.150  1
601740  95.825  -56.449  52.101  1
601741  95.852  -56.465  52.053  1
601742  95.878  -56.483  52.007  1
601743  95.904  -56.498  51.960  1
601744  95.930  -56.501  51.914  1
601745  95.955  -56.504  51.869  1
601746  95.979  -56.507  51.827  1
601747  96.005  -56.510  51.786  1
601748  96.030  -56.513  51.747  1
601749  96.055  -56.517  51.710  1
601750  96.080  -56.520  51.672  1
601751  96.105  -56.523  51.638  1
601752  96.130  -56.526  51.605  1
601753  96.156  -56.529  51.574  1
601754  96.181  -56.532  51.544  1
601755  96.203  -56.537  51.513  1
601756  96.220  -56.545  51.482  1
601757  96.239  -56.553  51.451  1
601758  96.273  -56.564  51.423  1
601759  96.289  -56.579  51.397  1
601760  96.305  -56.594  51.373  1
601761  96.320  -56.609  51.350  1
601762  96.336  -56.624  51.325  1
601763  96.351  -56.639  51.303  1
601764  96.377  -56.642  51.284  1
601765  96.401  -56.638  51.269  1
601766  96.424  -56.633  51.256  1
601767  96.448  -56.628  51.245  1
601768  96.471  -56.624  51.231  1
601769  96.495  -56.619  51.211  1
601770  96.518  -56.624  51.191  1
601771  96.540  -56.630  51.170  1
601772  96.563  -56.636  51.147  1
601773  96.586  -56.642  51.119  1
601774  96.608  -56.649  51.093  1
601775  96.631  -56.655  51.069  1
601776  96.663  -56.648  51.046  1
601777  96.695  -56.639  51.023  1
601778  96.722  -56.639  50.999  1
601779  96.748  -56.639  50.975  1
601780  96.777  -56.643  50.953  1
601781  96.809  -56.658  50.932  1
601782  96.831  -56.656  50.915  1
601783  96.853  -56.650  50.899  1
601784  96.904  -56.653  50.883  1
601785  96.955  -56.656  50.867  1
601786  97.001  -56.658  50.849  1
601787  97.034  -56.658  50.828  1
601788  97.068  -56.658  50.807  1
601789  97.101  -56.659  50.787  1
601790  97.135  -56.659  50.769  1
601791  97.168  -56.654  50.751  1
601792  97.201  -56.646  50.737  1
601793  97.234  -56.638  50.731  1
601794  97.267  -56.630  50.729  1
601795  97.300  -56.621  50.726  1
601796  97.333  -56.614  50.724  1
601797  97.372  -56.614  50.722  1
601798  97.413  -56.621  50.715  1
601799  97.453  -56.628  50.707  1
601800  97.495  -56.635  50.700  1
601801  97.535  -56.642  50.690  1
601802  97.576  -56.649  50.677  1
601803  97.611  -56.649  50.662  1
601804  97.645  -56.649  50.647  1
601805  97.679  -56.650  50.632  1
601806  97.714  -56.650  50.619  1
601807  97.749  -56.656  50.606  1
601808  97.786  -56.662  50.594  1
601809  97.822  -56.668  50.585  1
601810  97.858  -56.674  50.577  1
601811  97.894  -56.680  50.566  1
601812  97.930  -56.686  50.556  1
601813  97.965  -56.693  50.543  1
601814  98.000  -56.702  50.529  1
601815  98.034  -56.711  50.514  1
601816  98.068  -56.720  50.498  1
601817  98.102  -56.728  50.484  1
601818  98.137  -56.737  50.466  1
601819  98.171  -56.746  50.447  1
601820  98.206  -56.755  50.428  1
601821  98.240  -56.763  50.407  1
601822  98.274  -56.772  50.388  1
601823  98.308  -56.780  50.363  1
601824  98.343  -56.790  50.335  1
601825  98.377  -56.798  50.305  1
601826  98.411  -56.806  50.274  1
601827  98.445  -56.815  50.241  1
601828  98.480  -56.824  50.208  1
601829  98.514  -56.833  50.180  1
601830  98.548  -56.840  50.152  1
601831  98.582  -56.849  50.124  1
601832  98.616  -56.856  50.098  1
601833  98.650  -56.864  50.071  1
601834  98.684  -56.871  50.045  1
601835  98.718  -56.880  50.020  1
601836  98.752  -56.887  49.995  1
601837  98.786  -56.895  49.971  1
601838  98.820  -56.903  49.948  1
601839  98.854  -56.911  49.927  1
601840  98.888  -56.918  49.906  1
601841  98.922  -56.926  49.882  1
601842  98.966  -56.928  49.858  1
601843  99.009  -56.928  49.833  1
601844  99.054  -56.928  49.807  1
601845  99.097  -56.928  49.781  1
601846  99.142  -56.928  49.755  1
601847  99.186  -56.929  49.727  1
601848  99.227  -56.931  49.699  1
601849  99.243  -56.941  49.671  1
601850  99.259  -56.952  49.645  1
601851  99.284  -56.957  49.619  1
601852  99.312  -56.962  49.593  1
601853  99.340  -56.965  49.567  1
601854  99.367  -56.970  49.544  1
601855  99.393  -56.976  49.522  1
601856  99.418  -56.982  49.498  1
601857  99.442  -56.989  49.470  1
601858  99.467  -56.995  49.440  1
601859  99.492  -57.001  49.407  1
601860  99.516  -57.008  49.375  1
601861  99.541  -57.014  49.344  1
601862  99.566  -57.020  49.312  1
601863  99.597  -57.035  49.280  1
601864  99.642  -57.066  49.247  1
601865  99.653  -57.054  49.213  1
601866  99.678  -57.072  49.181  1
601867  99.704  -57.090  49.147  1
601868  99.729  -57.108  49.113  1
601869  99.755  -57.126  49.079  1
601870  99.780  -57.144  49.044  1
601871  99.806  -57.162  49.010  1
601872  99.832  -57.179  48.979  1
601873  99.857  -57.197  48.947  1
601874  99.883  -57.215  48.916  1
601875  99.908  -57.233  48.885  1
601876  99.934  -57.250  48.855  1
601877  99.960  -57.269  48.827  1
601878  99.985  -57.287  48.799  1
601879  100.010  -57.304  48.772  1
601880  100.036  -57.322  48.747  1
602210  88.354  -52.958  57.438  4
602211  88.389  -52.973  57.438  4
602212  88.425  -52.988  57.438  4
602213  88.462  -53.006  57.438  4
602214  88.499  -53.026  57.439  4
602215  88.538  -53.045  57.440  4
602216  88.575  -53.064  57.441  4
602217  88.614  -53.083  57.441  4
602218  88.651  -53.103  57.441  4
602219  88.690  -53.122  57.441  4
602220  88.728  -53.142  57.440  4
602221  88.766  -53.161  57.439  4
602222  88.804  -53.180  57.438  4
602223  88.842  -53.199  57.436  4
602224  88.880  -53.218  57.432  4
602225  88.918  -53.238  57.428  4
602226  88.956  -53.257  57.424  4
602227  88.994  -53.277  57.420  4
602228  89.032  -53.295  57.415  4
602229  89.070  -53.315  57.410  4
602230  89.095  -53.344  57.404  4
602231  89.127  -53.367  57.398  4
602232  89.159  -53.389  57.391  4
602233  89.190  -53.412  57.383  4
602234  89.222  -53.435  57.375  4
602235  89.254  -53.458  57.367  4
602236  89.281  -53.485  57.359  4
602237  89.304  -53.518  57.349  4
602238  89.326  -53.549  57.339  4
602239  89.349  -53.582  57.329  4
602240  89.378  -53.611  57.318  4
602241  89.408  -53.639  57.307  4
602242  89.441  -53.663  57.295  4
602243  89.493  -53.660  57.283  4
602244  89.526  -53.668  57.269  4
602245  89.551  -53.680  57.254  4
602246  89.577  -53.692  57.239  4
602247  89.604  -53.705  57.222  4
602248  89.638  -53.722  57.206  4
602249  89.672  -53.740  57.188  4
602250  89.707  -53.757  57.167  4
602251  89.741  -53.775  57.134  4
602252  89.775  -53.793  57.100  4
602253  89.810  -53.810  57.064  4
602254  89.844  -53.828  57.028  4
602255  89.878  -53.845  56.989  4
602256  89.913  -53.863  56.946  4
602257  89.947  -53.880  56.904  4
602258  89.981  -53.898  56.862  4
602259  90.016  -53.916  56.821  4
602260  90.050  -53.933  56.781  4
602261  90.085  -53.950  56.741  4
602262  90.119  -53.968  56.700  4
602267  90.295  -54.053  56.356  1
602268  90.338  -54.063  56.320  1
602269  90.382  -54.075  56.285  1
602270  90.425  -54.086  56.253  1
602271  90.468  -54.098  56.222  1
602272  90.485  -54.117  56.193  1
602273  90.502  -54.138  56.164  1
602274  90.519  -54.158  56.136  1
602275  90.536  -54.178  56.109  1
602276  90.553  -54.198  56.083  1
602277  90.571  -54.218  56.060  1
602278  90.588  -54.239  56.037  1
602279  90.605  -54.259  56.014  1
602280  90.622  -54.279  55.991  1
602281  90.640  -54.299  55.969  1
602282  90.657  -54.319  55.950  1
602283  90.674  -54.339  55.933  1
602284  90.699  -54.352  55.916  1
602285  90.735  -54.353  55.902  1
602286  90.767  -54.364  55.886  1
602287  90.796  -54.385  55.869  1
602288  90.825  -54.405  55.849  1
602289  90.854  -54.425  55.825  1
602290  90.883  -54.446  55.799  1
602291  90.912  -54.465  55.772  1
602292  90.941  -54.486  55.747  1
602293  90.970  -54.506  55.725  1
602294  90.999  -54.526  55.707  1
602295  91.028  -54.546  55.690  1
602296  91.057  -54.566  55.676  1
602297  91.086  -54.587  55.665  1
602298  91.114  -54.607  55.657  1
602299  91.151  -54.621  55.655  1
602300  91.187  -54.635  55.656  1
602301  91.224  -54.649  55.657  1
602302  91.261  -54.662  55.658  1
602303  91.310  -54.669  55.658  1
602304  91.364  -54.674  55.659  1
602305  91.417  -54.679  55.659  1
602306  91.470  -54.684  55.653  1
602307  91.524  -54.689  55.639  1
602308  91.578  -54.693  55.617  1
602309  91.631  -54.699  55.590  1
602310  91.684  -54.703  55.564  1
602311  91.738  -54.709  55.536  1
602312  91.782  -54.712  55.506  1
602313  91.812  -54.716  55.478  1
602314  91.842  -54.720  55.454  1
602315  91.870  -54.729  55.435  1
602316  91.897  -54.740  55.419  1
602317  91.925  -54.751  55.406  1
602318  91.952  -54.762  55.395  1
602319  91.979  -54.774  55.383  1
602320  92.009  -54.784  55.372  1
602321  92.041  -54.795  55.363  1
602322  92.074  -54.806  55.356  1
602323  92.106  -54.816  55.346  1
602324  92.139  -54.831  55.335  1
602325  92.173  -54.850  55.323  1
602326  92.208  -54.870  55.313  1
602327  92.241  -54.890  55.305  1
602328  92.276  -54.909  55.300  1
602329  92.310  -54.929  55.298  1
602330  92.344  -54.949  55.299  1
602331  92.376  -54.960  55.301  1
602332  92.408  -54.966  55.303  1
602333  92.439  -54.972  55.305  1
602334  92.476  -54.975  55.307  1
602335  92.514  -54.979  55.307  1
602336  92.553  -54.982  55.307  1
602337  92.590  -54.987  55.311  1
602338  92.616  -54.997  55.316  1
602339  92.643  -55.009  55.326  1
602340  92.669  -55.019  55.343  1
602341  92.696  -55.031  55.361  1
602342  92.722  -55.042  55.375  1
602343  92.748  -55.060  55.387  1
602344  92.774  -55.079  55.402  1
602345  92.800  -55.097  55.419  1
602346  92.826  -55.115  55.434  1
602347  92.852  -55.133  55.442  1
602348  92.885  -55.151  55.457  1
602349  92.920  -55.169  55.473  1
602350  92.956  -55.187  55.487  1
602351  92.992  -55.205  55.494  1
602352  93.027  -55.223  55.493  1
602353  93.063  -55.241  55.486  1
602354  93.098  -55.259  55.471  1
602355  93.134  -55.277  55.453  1
602356  93.169  -55.295  55.432  1
602357  93.205  -55.313  55.411  1
602358  93.240  -55.331  55.389  1
602359  93.276  -55.348  55.364  1
602360  93.312  -55.367  55.341  1
602361  93.349  -55.389  55.323  1
602362  93.387  -55.411  55.311  1
602363  93.424  -55.432  55.305  1
602364  93.461  -55.453  55.298  1
602365  93.498  -55.475  55.288  1
602366  93.535  -55.494  55.274  1
602367  93.571  -55.492  55.258  1
602368  93.607  -55.489  55.243  1
602369  93.630  -55.507  55.228  1
602370  93.652  -55.527  55.213  1
602371  93.674  -55.548  55.198  1
602372  93.695  -55.568  55.183  1
602373  93.716  -55.589  55.168  1
602374  93.738  -55.609  55.150  1
602375  93.760  -55.630  55.129  1
602376  93.781  -55.650  55.102  1
602377  93.802  -55.674  55.075  1
602378  93.822  -55.703  55.048  1
602379  93.842  -55.733  55.023  1
602380  93.862  -55.762  54.999  1
602381  93.882  -55.792  54.974  1
602382  93.902  -55.821  54.948  1
602383  93.922  -55.851  54.922  1
602384  93.941  -55.880  54.896  1
602385  93.966  -55.900  54.866  1
602386  93.995  -55.912  54.835  1
602387  94.025  -55.923  54.801  1
602388  94.054  -55.934  54.762  1
602389  94.085  -55.943  54.722  1
602390  94.117  -55.950  54.685  1
602391  94.150  -55.957  54.651  1
602392  94.182  -55.964  54.618  1
602393  94.215  -55.971  54.582  1
602394  94.247  -55.978  54.543  1
602395  94.280  -55.984  54.500  1
602396  94.313  -55.993  54.457  1
602397  94.347  -56.001  54.411  1
602398  94.381  -56.009  54.363  1
602399  94.415  -56.018  54.316  1
602400  94.449  -56.026  54.272  1
602401  94.483  -56.034  54.229  1
602402  94.532  -56.047  54.183  1
602403  94.583  -56.058  54.140  1
602404  94.633  -56.069  54.098  1
602405  94.673  -56.078  54.055  1
602406  94.707  -56.086  54.011  1
602407  94.741  -56.094  53.966  1
602408  94.775  -56.102  53.916  1
602409  94.809  -56.110  53.868  1
602410  94.843  -56.118  53.820  1
602411  94.877  -56.125  53.769  1
602412  94.911  -56.128  53.716  1
602413  94.945  -56.131  53.662  1
602414  94.978  -56.135  53.605  1
602415  95.014  -56.143  53.550  1
602416  95.052  -56.166  53.498  1
602417  95.091  -56.190  53.447  1
602418  95.129  -56.213  53.398  1
602419  95.168  -56.237  53.352  1
602420  95.188  -56.248  53.305  1
602421  95.206  -56.263  53.258  1
602422  95.225  -56.278  53.209  1
602423  95.243  -56.294  53.157  1
602424  95.261  -56.309  53.102  1
602425  95.283  -56.323  53.045  1
602426  95.321  -56.332  52.984  1
602427  95.358  -56.341  52.924  1
602428  95.396  -56.349  52.864  1
602429  95.433  -56.358  52.805  1
602430  95.471  -56.367  52.746  1
602431  95.509  -56.376  52.688  1
602432  95.546  -56.385  52.627  1
602433  95.584  -56.395  52.564  1
602434  95.616  -56.401  52.497  1
602435  95.643  -56.401  52.431  1
602436  95.670  -56.401  52.370  1
602437  95.697  -56.402  52.309  1
602438  95.730  -56.407  52.250  1
602439  95.765  -56.412  52.195  1
602440  95.800  -56.417  52.140  1
602441  95.829  -56.431  52.088  1
602442  95.855  -56.448  52.038  1
602443  95.881  -56.466  51.989  1
602444  95.906  -56.478  51.942  1
602445  95.932  -56.481  51.894  1
602446  95.957  -56.484  51.848  1
602447  95.982  -56.487  51.804  1
602448  96.007  -56.490  51.763  1
602449  96.032  -56.493  51.722  1
602450  96.057  -56.496  51.683  1
602451  96.083  -56.499  51.645  1
602452  96.108  -56.503  51.609  1
602453  96.133  -56.506  51.576  1
602454  96.158  -56.509  51.544  1
602455  96.183  -56.512  51.513  1
602456  96.208  -56.515  51.482  1
602457  96.233  -56.518  51.451  1
602458  96.258  -56.521  51.420  1
602459  96.278  -56.533  51.391  1
602460  96.293  -56.548  51.366  1
602461  96.309  -56.564  51.341  1
602462  96.324  -56.579  51.316  1
602463  96.340  -56.594  51.292  1
602464  96.356  -56.609  51.269  1
602465  96.377  -56.611  51.250  1
602466  96.400  -56.607  51.234  1
602467  96.424  -56.602  51.219  1
602468  96.447  -56.598  51.205  1
602469  96.470  -56.592  51.190  1
602470  96.494  -56.588  51.170  1
602471  96.517  -56.591  51.151  1
602472  96.540  -56.597  51.132  1
602473  96.562  -56.604  51.108  1
602474  96.585  -56.610  51.081  1
602475  96.608  -56.617  51.054  1
602476  96.630  -56.623  51.026  1
602477  96.653  -56.630  51.001  1
602478  96.686  -56.620  50.976  1
602479  96.719  -56.611  50.951  1
602480  96.745  -56.611  50.928  1
602481  96.773  -56.613  50.906  1
602482  96.804  -56.626  50.883  1
602483  96.823  -56.619  50.864  1
602484  96.851  -56.614  50.847  1
602485  96.902  -56.617  50.831  1
602486  96.953  -56.620  50.814  1
602487  96.999  -56.623  50.798  1
602488  97.033  -56.623  50.778  1
602489  97.066  -56.624  50.759  1
602490  97.100  -56.624  50.741  1
602491  97.133  -56.624  50.723  1
602492  97.166  -56.622  50.707  1
602493  97.199  -56.614  50.692  1
602494  97.233  -56.605  50.684  1
602495  97.266  -56.598  50.679  1
602496  97.299  -56.589  50.678  1
602497  97.333  -56.583  50.676  1
602498  97.374  -56.590  50.673  1
602499  97.415  -56.597  50.667  1
602500  97.456  -56.604  50.662  1
602501  97.497  -56.611  50.658  1
602502  97.536  -56.615  50.651  1
602503  97.570  -56.616  50.641  1
602504  97.604  -56.616  50.629  1
602505  97.639  -56.617  50.616  1
602506  97.673  -56.617  50.602  1
602507  97.708  -56.617  50.589  1
602508  97.743  -56.622  50.576  1
602509  97.779  -56.628  50.563  1
602510  97.815  -56.634  50.552  1
602511  97.852  -56.640  50.546  1
602512  97.887  -56.646  50.537  1
602513  97.924  -56.653  50.525  1
602514  97.960  -56.659  50.511  1
602515  97.996  -56.665  50.497  1
602516  98.032  -56.671  50.482  1
602517  98.066  -56.680  50.467  1
602518  98.100  -56.689  50.451  1
602519  98.135  -56.697  50.434  1
602520  98.169  -56.706  50.416  1
602521  98.203  -56.714  50.398  1
602522  98.237  -56.724  50.378  1
602523  98.272  -56.732  50.357  1
602524  98.306  -56.740  50.332  1
602525  98.341  -56.749  50.305  1
602526  98.375  -56.758  50.276  1
602527  98.409  -56.767  50.245  1
602528  98.443  -56.775  50.212  1
602529  98.478  -56.784  50.179  1
602530  98.512  -56.793  50.152  1
602531  98.546  -56.800  50.124  1
602532  98.580  -56.808  50.097  1
602533  98.614  -56.816  50.071  1
602534  98.648  -56.824  50.044  1
602535  98.682  -56.831  50.018  1
602536  98.716  -56.839  49.991  1
602537  98.750  -56.847  49.965  1
602538  98.784  -56.855  49.941  1
602539  98.818  -56.862  49.919  1
602540  98.854  -56.870  49.898  1
602541  98.895  -56.877  49.877  1
602542  98.934  -56.884  49.855  1
602543  98.975  -56.892  49.831  1
602544  99.014  -56.899  49.805  1
602545  99.057  -56.903  49.777  1
602546  99.101  -56.903  49.751  1
602547  99.145  -56.903  49.724  1
602548  99.190  -56.903  49.696  1
602549  99.233  -56.903  49.669  1
602550  99.256  -56.912  49.642  1
602551  99.274  -56.921  49.617  1
602552  99.301  -56.926  49.592  1
602553  99.329  -56.931  49.567  1
602554  99.356  -56.935  49.542  1
602555  99.380  -56.941  49.519  1
602556  99.405  -56.948  49.496  1
602557  99.430  -56.954  49.472  1
602558  99.455  -56.960  49.445  1
602559  99.480  -56.967  49.417  1
602560  99.504  -56.973  49.385  1
602561  99.529  -56.980  49.354  1
602562  99.554  -56.986  49.323  1
602563  99.578  -56.992  49.291  1
602564  99.614  -57.012  49.258  1
602565  99.637  -57.012  49.226  1
602566  99.663  -57.031  49.193  1
602567  99.689  -57.048  49.161  1
602568  99.715  -57.066  49.129  1
602569  99.740  -57.084  49.096  1
602570  99.766  -57.102  49.062  1
602571  99.791  -57.120  49.029  1
602572  99.817  -57.138  48.995  1
602573  99.843  -57.156  48.964  1
602574  99.868  -57.173  48.933  1
602575  99.894  -57.191  48.901  1
602576  99.919  -57.209  48.871  1
602577  99.945  -57.227  48.842  1
602578  99.970  -57.244  48.814  1
602579  99.996  -57.263  48.788  1
602580  100.021  -57.281  48.762  1
602581  100.047  -57.298  48.737  1
602911  88.379  -52.923  57.433  4
602912  88.414  -52.938  57.433  4
602913  88.451  -52.956  57.433  4
602914  88.489  -52.976  57.433  4
602915  88.527  -52.995  57.435  4
602916  88.565  -53.014  57.435  4
602917  88.603  -53.033  57.436  4
602918  88.641  -53.053  57.436  4
602919  88.679  -53.072  57.436  4
602920  88.717  -53.092  57.436  4
602921  88.755  -53.111  57.435  4
602922  88.793  -53.130  57.434  4
602923  88.831  -53.149  57.432  4
602924  88.870  -53.168  57.430  4
602925  88.907  -53.188  57.426  4
602926  88.946  -53.207  57.422  4
602927  88.984  -53.227  57.418  4
602928  89.022  -53.245  57.413  4
602929  89.048  -53.274  57.407  4
602930  89.080  -53.297  57.402  4
602931  89.112  -53.320  57.397  4
602932  89.143  -53.342  57.390  4
602933  89.175  -53.365  57.383  4
602934  89.206  -53.388  57.375  4
602935  89.238  -53.411  57.366  4
602936  89.270  -53.433  57.357  4
602937  89.296  -53.462  57.349  4
602938  89.319  -53.494  57.340  4
602939  89.341  -53.527  57.330  4
602940  89.364  -53.559  57.320  4
602941  89.388  -53.591  57.309  4
602942  89.417  -53.619  57.299  4
602943  89.453  -53.640  57.288  4
602944  89.506  -53.637  57.276  4
602945  89.542  -53.643  57.263  4
602946  89.567  -53.655  57.248  4
602947  89.593  -53.667  57.233  4
602948  89.618  -53.678  57.218  4
602949  89.648  -53.693  57.202  4
602950  89.682  -53.710  57.184  4
602951  89.716  -53.728  57.164  4
602952  89.750  -53.745  57.133  4
602953  89.785  -53.762  57.100  4
602954  89.819  -53.781  57.065  4
602955  89.853  -53.798  57.029  4
602956  89.888  -53.816  56.990  4
602957  89.922  -53.833  56.948  4
602958  89.956  -53.850  56.906  4
602959  89.990  -53.868  56.864  4
602960  90.025  -53.885  56.823  4
602961  90.059  -53.903  56.783  4
602962  90.094  -53.921  56.744  4
602963  90.128  -53.938  56.703  4
602964  90.162  -53.956  56.665  4
602969  90.354  -54.029  56.322  1
602970  90.397  -54.041  56.286  1
602971  90.440  -54.052  56.253  1
602972  90.475  -54.066  56.221  1
602973  90.493  -54.086  56.192  1
602974  90.510  -54.107  56.163  1
602975  90.527  -54.126  56.133  1
602976  90.544  -54.147  56.105  1
602977  90.561  -54.167  56.079  1
602978  90.579  -54.187  56.054  1
602979  90.596  -54.207  56.031  1
602980  90.613  -54.227  56.008  1
602981  90.630  -54.248  55.985  1
602982  90.647  -54.267  55.964  1
602983  90.665  -54.288  55.945  1
602984  90.687  -54.303  55.928  1
602985  90.723  -54.305  55.913  1
602986  90.757  -54.308  55.898  1
602987  90.787  -54.328  55.880  1
602988  90.815  -54.348  55.857  1
602989  90.845  -54.368  55.833  1
602990  90.873  -54.389  55.808  1
602991  90.902  -54.409  55.783  1
602992  90.931  -54.429  55.758  1
602993  90.960  -54.449  55.735  1
602994  90.989  -54.469  55.714  1
602995  91.018  -54.489  55.696  1
602996  91.047  -54.510  55.681  1
602997  91.076  -54.530  55.668  1
602998  91.105  -54.550  55.658  1
602999  91.134  -54.570  55.652  1
603000  91.163  -54.590  55.652  1
603001  91.196  -54.606  55.654  1
603002  91.233  -54.620  55.655  1
603003  91.274  -54.632  55.655  1
603004  91.327  -54.637  55.654  1
603005  91.381  -54.642  55.654  1
603006  91.434  -54.646  55.653  1
603007  91.488  -54.652  55.643  1
603008  91.541  -54.656  55.625  1
603009  91.594  -54.661  55.601  1
603010  91.648  -54.666  55.574  1
603011  91.702  -54.671  55.550  1
603012  91.755  -54.676  55.523  1
603013  91.800  -54.681  55.495  1
603014  91.830  -54.684  55.469  1
603015  91.859  -54.690  55.446  1
603016  91.886  -54.702  55.427  1
603017  91.913  -54.713  55.412  1
603018  91.941  -54.724  55.400  1
603019  91.971  -54.734  55.389  1
603020  92.003  -54.745  55.378  1
603021  92.035  -54.756  55.367  1
603022  92.068  -54.766  55.358  1
603023  92.100  -54.777  55.352  1
603024  92.132  -54.787  55.342  1
603025  92.164  -54.798  55.331  1
603026  92.198  -54.812  55.321  1
603027  92.232  -54.832  55.310  1
603028  92.266  -54.852  55.302  1
603029  92.300  -54.872  55.296  1
603030  92.334  -54.891  55.294  1
603031  92.368  -54.911  55.293  1
603032  92.401  -54.925  55.294  1
603033  92.433  -54.931  55.296  1
603034  92.464  -54.937  55.298  1
603035  92.496  -54.943  55.300  1
603036  92.528  -54.949  55.303  1
603037  92.567  -54.952  55.307  1
603038  92.605  -54.955  55.314  1
603039  92.636  -54.964  55.324  1
603040  92.662  -54.975  55.338  1
603041  92.689  -54.985  55.359  1
603042  92.715  -54.998  55.381  1
603043  92.741  -55.016  55.403  1
603044  92.767  -55.034  55.423  1
603045  92.793  -55.052  55.445  1
603046  92.819  -55.070  55.467  1
603047  92.845  -55.088  55.485  1
603048  92.871  -55.107  55.492  1
603049  92.901  -55.125  55.498  1
603050  92.936  -55.143  55.509  1
603051  92.972  -55.160  55.520  1
603052  93.007  -55.179  55.524  1
603053  93.043  -55.197  55.520  1
603054  93.079  -55.214  55.513  1
603055  93.114  -55.232  55.501  1
603056  93.150  -55.251  55.484  1
603057  93.185  -55.269  55.464  1
603058  93.221  -55.286  55.441  1
603059  93.257  -55.304  55.416  1
603060  93.292  -55.323  55.387  1
603061  93.328  -55.340  55.359  1
603062  93.363  -55.358  55.334  1
603063  93.399  -55.376  55.316  1
603064  93.434  -55.394  55.307  1
603065  93.471  -55.414  55.301  1
603066  93.508  -55.436  55.292  1
603067  93.545  -55.458  55.281  1
603068  93.581  -55.462  55.271  1
603069  93.609  -55.474  55.259  1
603070  93.630  -55.495  55.246  1
603071  93.651  -55.515  55.231  1
603072  93.673  -55.536  55.216  1
603073  93.695  -55.556  55.200  1
603074  93.716  -55.577  55.187  1
603075  93.738  -55.597  55.172  1
603076  93.760  -55.618  55.151  1
603077  93.781  -55.639  55.121  1
603078  93.803  -55.659  55.089  1
603079  93.825  -55.680  55.056  1
603080  93.845  -55.705  55.024  1
603081  93.865  -55.735  54.994  1
603082  93.885  -55.765  54.966  1
603083  93.905  -55.794  54.936  1
603084  93.924  -55.823  54.906  1
603085  93.944  -55.853  54.877  1
603086  93.967  -55.877  54.846  1
603087  93.996  -55.888  54.815  1
603088  94.025  -55.900  54.782  1
603089  94.055  -55.910  54.746  1
603090  94.087  -55.917  54.709  1
603091  94.120  -55.925  54.675  1
603092  94.152  -55.931  54.641  1
603093  94.185  -55.938  54.608  1
603094  94.217  -55.945  54.574  1
603095  94.250  -55.952  54.537  1
603096  94.282  -55.959  54.497  1
603097  94.315  -55.966  54.456  1
603098  94.349  -55.975  54.410  1
603099  94.383  -55.983  54.363  1
603100  94.417  -55.991  54.318  1
603101  94.451  -56.000  54.277  1
603102  94.489  -56.009  54.234  1
603103  94.539  -56.021  54.194  1
603104  94.590  -56.032  54.154  1
603105  94.640  -56.044  54.115  1
603106  94.683  -56.054  54.076  1
603107  94.717  -56.062  54.035  1
603108  94.751  -56.069  53.990  1
603109  94.785  -56.077  53.939  1
603110  94.819  -56.085  53.888  1
603111  94.853  -56.093  53.837  1
603112  94.887  -56.097  53.785  1
603113  94.920  -56.101  53.730  1
603114  94.955  -56.104  53.676  1
603115  94.988  -56.107  53.619  1
603116  95.023  -56.114  53.563  1
603117  95.061  -56.138  53.509  1
603118  95.100  -56.161  53.456  1
603119  95.138  -56.185  53.404  1
603120  95.171  -56.204  53.354  1
603121  95.189  -56.213  53.306  1
603122  95.208  -56.224  53.258  1
603123  95.226  -56.239  53.209  1
603124  95.244  -56.255  53.159  1
603125  95.262  -56.270  53.106  1
603126  95.293  -56.285  53.050  1
603127  95.326  -56.301  52.990  1
603128  95.363  -56.310  52.929  1
603129  95.401  -56.320  52.869  1
603130  95.438  -56.329  52.809  1
603131  95.476  -56.338  52.750  1
603132  95.513  -56.347  52.691  1
603133  95.551  -56.356  52.631  1
603134  95.588  -56.365  52.570  1
603135  95.623  -56.373  52.504  1
603136  95.651  -56.373  52.437  1
603137  95.677  -56.373  52.372  1
603138  95.705  -56.375  52.310  1
603139  95.740  -56.380  52.249  1
603140  95.774  -56.385  52.191  1
603141  95.806  -56.397  52.134  1
603142  95.831  -56.414  52.080  1
603143  95.858  -56.432  52.029  1
603144  95.884  -56.450  51.977  1
603145  95.909  -56.458  51.927  1
603146  95.934  -56.461  51.879  1
603147  95.959  -56.464  51.831  1
603148  95.984  -56.467  51.785  1
603149  96.010  -56.470  51.742  1
603150  96.035  -56.473  51.701  1
603151  96.060  -56.476  51.660  1
603152  96.085  -56.479  51.621  1
603153  96.110  -56.483  51.584  1
603154  96.135  -56.486  51.550  1
603155  96.161  -56.489  51.516  1
603156  96.185  -56.492  51.484  1
603157  96.210  -56.495  51.453  1
603158  96.236  -56.498  51.422  1
603159  96.267  -56.500  51.392  1
603160  96.287  -56.501  51.364  1
603161  96.302  -56.503  51.337  1
603162  96.318  -56.511  51.311  1
603163  96.333  -56.526  51.285  1
603164  96.349  -56.541  51.260  1
603165  96.365  -56.555  51.237  1
603166  96.380  -56.570  51.218  1
603167  96.399  -56.576  51.200  1
603168  96.423  -56.571  51.183  1
603169  96.446  -56.567  51.164  1
603170  96.470  -56.562  51.147  1
603171  96.493  -56.558  51.127  1
603172  96.517  -56.558  51.108  1
603173  96.539  -56.564  51.089  1
603174  96.562  -56.571  51.066  1
603175  96.585  -56.577  51.043  1
603176  96.607  -56.584  51.017  1
603177  96.630  -56.590  50.987  1
603178  96.653  -56.597  50.957  1
603179  96.675  -56.603  50.931  1
603180  96.709  -56.592  50.906  1
603181  96.743  -56.583  50.883  1
603182  96.769  -56.582  50.860  1
603183  96.797  -56.589  50.836  1
603184  96.816  -56.582  50.816  1
603185  96.849  -56.580  50.798  1
603186  96.900  -56.583  50.780  1
603187  96.951  -56.585  50.764  1
603188  96.998  -56.587  50.748  1
603189  97.031  -56.588  50.729  1
603190  97.065  -56.588  50.712  1
603191  97.098  -56.589  50.695  1
603192  97.132  -56.589  50.678  1
603193  97.165  -56.589  50.663  1
603194  97.198  -56.581  50.648  1
603195  97.231  -56.573  50.639  1
603196  97.264  -56.565  50.632  1
603197  97.298  -56.557  50.629  1
603198  97.336  -56.559  50.627  1
603199  97.377  -56.566  50.623  1
603200  97.418  -56.573  50.618  1
603201  97.459  -56.580  50.614  1
603202  97.495  -56.582  50.612  1
603203  97.530  -56.583  50.607  1
603204  97.564  -56.583  50.599  1
603205  97.598  -56.583  50.589  1
603206  97.633  -56.583  50.579  1
603207  97.667  -56.584  50.567  1
603208  97.702  -56.584  50.554  1
603209  97.737  -56.589  50.541  1
603210  97.773  -56.595  50.527  1
603211  97.809  -56.601  50.515  1
603212  97.845  -56.607  50.508  1
603213  97.881  -56.613  50.501  1
603214  97.917  -56.619  50.490  1
603215  97.953  -56.625  50.477  1
603216  97.989  -56.631  50.463  1
603217  98.025  -56.637  50.448  1
603218  98.062  -56.643  50.433  1
603219  98.097  -56.650  50.418  1
603220  98.133  -56.657  50.400  1
603221  98.167  -56.666  50.383  1
603222  98.201  -56.674  50.364  1
603223  98.235  -56.683  50.344  1
603224  98.270  -56.692  50.323  1
603225  98.304  -56.701  50.300  1
603226  98.339  -56.709  50.273  1
603227  98.373  -56.718  50.244  1
603228  98.407  -56.727  50.214  1
603229  98.441  -56.736  50.183  1
603230  98.476  -56.744  50.150  1
603231  98.510  -56.752  50.122  1
603232  98.544  -56.760  50.095  1
603233  98.578  -56.768  50.069  1
603234  98.612  -56.775  50.042  1
603235  98.646  -56.783  50.015  1
603236  98.679  -56.791  49.989  1
603237  98.714  -56.799  49.962  1
603238  98.747  -56.807  49.936  1
603239  98.787  -56.814  49.912  1
603240  98.827  -56.821  49.889  1
603241  98.867  -56.828  49.868  1
603242  98.907  -56.836  49.847  1
603243  98.947  -56.843  49.826  1
603244  98.987  -56.850  49.801  1
603245  99.027  -56.858  49.775  1
603246  99.067  -56.865  49.749  1
603247  99.108  -56.872  49.722  1
603248  99.149  -56.877  49.695  1
603249  99.193  -56.877  49.668  1
603250  99.237  -56.878  49.641  1
603251  99.269  -56.883  49.614  1
603252  99.290  -56.890  49.589  1
603253  99.318  -56.895  49.565  1
603254  99.344  -56.900  49.541  1
603255  99.368  -56.907  49.515  1
603256  99.393  -56.913  49.492  1
603257  99.418  -56.920  49.468  1
603258  99.442  -56.926  49.443  1
603259  99.467  -56.932  49.417  1
603260  99.492  -56.939  49.390  1
603261  99.517  -56.945  49.361  1
603262  99.542  -56.952  49.332  1
603263  99.566  -56.958  49.302  1
603264  99.591  -56.964  49.270  1
603265  99.630  -56.989  49.239  1
603266  99.649  -56.989  49.207  1
603267  99.675  -57.006  49.174  1
603268  99.700  -57.025  49.143  1
603269  99.726  -57.042  49.110  1
603270  99.751  -57.060  49.078  1
603271  99.777  -57.078  49.046  1
603272  99.802  -57.096  49.013  1
603273  99.828  -57.114  48.980  1
603274  99.853  -57.131  48.949  1
603275  99.879  -57.150  48.918  1
603276  99.905  -57.167  48.888  1
603277  99.930  -57.185  48.858  1
603278  99.956  -57.203  48.830  1
603279  99.981  -57.221  48.803  1
603280  100.007  -57.239  48.777  1
603281  100.033  -57.257  48.751  1
603612  88.403  -52.888  57.428  4
603613  88.440  -52.907  57.428  4
603614  88.479  -52.926  57.428  4
603615  88.517  -52.944  57.428  4
603616  88.555  -52.964  57.430  4
603617  88.593  -52.983  57.430  4
603618  88.631  -53.003  57.431  4
603619  88.669  -53.022  57.431  4
603620  88.707  -53.042  57.430  4
603621  88.745  -53.060  57.430  4
603622  88.783  -53.080  57.430  4
603623  88.821  -53.099  57.429  4
603624  88.859  -53.119  57.426  4
603625  88.897  -53.138  57.423  4
603626  88.935  -53.157  57.419  4
603627  88.973  -53.176  57.415  4
603628  89.011  -53.195  57.411  4
603629  89.033  -53.228  57.405  4
603630  89.064  -53.251  57.400  4
603631  89.096  -53.273  57.394  4
603632  89.128  -53.296  57.388  4
603633  89.159  -53.319  57.381  4
603634  89.191  -53.342  57.374  4
603635  89.223  -53.364  57.366  4
603636  89.254  -53.386  57.358  4
603637  89.286  -53.409  57.349  4
603638  89.311  -53.439  57.340  4
603639  89.334  -53.471  57.332  4
603640  89.356  -53.504  57.322  4
603641  89.379  -53.537  57.312  4
603642  89.402  -53.568  57.301  4
603643  89.427  -53.599  57.291  4
603644  89.466  -53.616  57.281  4
603645  89.518  -53.614  57.271  4
603646  89.558  -53.618  57.257  4
603647  89.584  -53.630  57.242  4
603648  89.609  -53.641  57.228  4
603649  89.634  -53.653  57.213  4
603650  89.660  -53.665  57.197  4
603651  89.691  -53.681  57.179  4
603652  89.725  -53.698  57.159  4
603653  89.760  -53.715  57.130  4
603654  89.794  -53.733  57.099  4
603655  89.828  -53.750  57.065  4
603656  89.863  -53.768  57.029  4
603657  89.897  -53.786  56.992  4
603658  89.932  -53.803  56.950  4
603659  89.966  -53.821  56.909  4
603660  90.000  -53.838  56.867  4
603661  90.034  -53.856  56.826  4
603662  90.069  -53.873  56.786  4
603663  90.103  -53.891  56.747  4
603664  90.138  -53.909  56.706  4
603665  90.172  -53.926  56.668  4
603671  90.412  -54.007  56.287  1
603672  90.455  -54.018  56.254  1
603673  90.483  -54.035  56.221  1
603674  90.500  -54.054  56.191  1
603675  90.517  -54.075  56.161  1
603676  90.534  -54.095  56.131  1
603677  90.552  -54.115  56.102  1
603678  90.569  -54.135  56.075  1
603679  90.586  -54.155  56.050  1
603680  90.603  -54.176  56.026  1
603681  90.620  -54.196  56.003  1
603682  90.638  -54.216  55.980  1
603683  90.655  -54.236  55.960  1
603684  90.674  -54.254  55.940  1
603685  90.710  -54.256  55.925  1
603686  90.746  -54.258  55.911  1
603687  90.777  -54.271  55.894  1
603688  90.806  -54.292  55.873  1
603689  90.835  -54.312  55.846  1
603690  90.864  -54.332  55.820  1
603691  90.893  -54.352  55.794  1
603692  90.922  -54.372  55.769  1
603693  90.951  -54.392  55.746  1
603694  90.979  -54.413  55.724  1
603695  91.009  -54.433  55.705  1
603696  91.037  -54.453  55.688  1
603697  91.066  -54.473  55.673  1
603698  91.095  -54.493  55.661  1
603699  91.124  -54.513  55.652  1
603700  91.153  -54.533  55.647  1
603701  91.182  -54.554  55.649  1
603702  91.211  -54.574  55.652  1
603703  91.242  -54.592  55.655  1
603704  91.291  -54.599  55.656  1
603705  91.345  -54.604  55.655  1
603706  91.398  -54.609  55.653  1
603707  91.451  -54.614  55.648  1
603708  91.505  -54.619  55.633  1
603709  91.558  -54.624  55.612  1
603710  91.611  -54.629  55.585  1
603711  91.665  -54.634  55.558  1
603712  91.719  -54.638  55.536  1
603713  91.772  -54.643  55.511  1
603714  91.817  -54.648  55.485  1
603715  91.847  -54.652  55.460  1
603716  91.875  -54.663  55.439  1
603717  91.902  -54.674  55.420  1
603718  91.932  -54.685  55.406  1
603719  91.964  -54.696  55.394  1
603720  91.997  -54.706  55.383  1
603721  92.029  -54.717  55.373  1
603722  92.062  -54.728  55.362  1
603723  92.094  -54.738  55.353  1
603724  92.126  -54.749  55.346  1
603725  92.158  -54.759  55.337  1
603726  92.191  -54.769  55.327  1
603727  92.223  -54.780  55.317  1
603728  92.256  -54.795  55.308  1
603729  92.290  -54.815  55.299  1
603730  92.324  -54.834  55.294  1
603731  92.358  -54.853  55.290  1
603732  92.392  -54.873  55.289  1
603733  92.426  -54.891  55.290  1
603734  92.457  -54.897  55.291  1
603735  92.489  -54.903  55.292  1
603736  92.520  -54.909  55.296  1
603737  92.552  -54.915  55.302  1
603738  92.584  -54.920  55.309  1
603739  92.620  -54.925  55.321  1
603740  92.655  -54.930  55.336  1
603741  92.682  -54.941  55.354  1
603742  92.708  -54.953  55.378  1
603743  92.734  -54.972  55.403  1
603744  92.760  -54.990  55.430  1
603745  92.786  -55.008  55.455  1
603746  92.812  -55.026  55.480  1
603747  92.838  -55.044  55.504  1
603748  92.864  -55.062  55.521  1
603749  92.890  -55.080  55.530  1
603750  92.917  -55.098  55.536  1
603751  92.952  -55.116  55.543  1
603752  92.988  -55.135  55.548  1
603753  93.023  -55.152  55.547  1
603754  93.059  -55.170  55.540  1
603755  93.094  -55.188  55.534  1
603756  93.130  -55.206  55.523  1
603757  93.165  -55.224  55.508  1
603758  93.201  -55.242  55.491  1
603759  93.237  -55.260  55.470  1
603760  93.272  -55.278  55.444  1
603761  93.308  -55.296  55.414  1
603762  93.344  -55.314  55.381  1
603763  93.379  -55.332  55.348  1
603764  93.415  -55.350  55.323  1
603765  93.450  -55.368  55.308  1
603766  93.486  -55.386  55.303  1
603767  93.521  -55.404  55.295  1
603768  93.557  -55.422  55.289  1
603769  93.587  -55.442  55.283  1
603770  93.608  -55.462  55.274  1
603771  93.630  -55.483  55.262  1
603772  93.651  -55.503  55.247  1
603773  93.673  -55.524  55.232  1
603774  93.695  -55.545  55.218  1
603775  93.716  -55.565  55.207  1
603776  93.738  -55.586  55.194  1
603777  93.760  -55.606  55.174  1
603778  93.781  -55.627  55.146  1
603779  93.802  -55.647  55.113  1
603780  93.824  -55.668  55.078  1
603781  93.846  -55.688  55.042  1
603782  93.867  -55.709  55.006  1
603783  93.888  -55.737  54.970  1
603784  93.907  -55.766  54.933  1
603785  93.927  -55.796  54.899  1
603786  93.947  -55.825  54.867  1
603787  93.968  -55.853  54.834  1
603788  93.997  -55.865  54.801  1
603789  94.026  -55.877  54.766  1
603790  94.057  -55.884  54.729  1
603791  94.090  -55.891  54.695  1
603792  94.122  -55.899  54.662  1
603793  94.155  -55.906  54.630  1
603794  94.187  -55.912  54.598  1
603795  94.220  -55.919  54.566  1
603796  94.252  -55.926  54.531  1
603797  94.285  -55.933  54.493  1
603798  94.317  -55.940  54.452  1
603799  94.351  -55.948  54.407  1
603800  94.385  -55.957  54.363  1
603801  94.419  -55.965  54.321  1
603802  94.453  -55.974  54.282  1
603803  94.495  -55.984  54.244  1
603804  94.546  -55.995  54.211  1
603805  94.596  -56.007  54.176  1
603806  94.646  -56.019  54.141  1
603807  94.693  -56.029  54.104  1
603808  94.727  -56.037  54.062  1
603809  94.761  -56.045  54.019  1
603810  94.795  -56.053  53.970  1
603811  94.829  -56.060  53.920  1
603812  94.863  -56.067  53.869  1
603813  94.897  -56.071  53.816  1
603814  94.930  -56.074  53.761  1
603815  94.964  -56.077  53.704  1
603816  94.998  -56.081  53.649  1
603817  95.032  -56.085  53.592  1
603818  95.070  -56.109  53.533  1
603819  95.109  -56.132  53.473  1
603820  95.147  -56.156  53.415  1
603821  95.172  -56.169  53.359  1
603822  95.191  -56.179  53.309  1
603823  95.209  -56.188  53.259  1
603824  95.228  -56.201  53.209  1
603825  95.246  -56.216  53.158  1
603826  95.270  -56.232  53.105  1
603827  95.304  -56.247  53.051  1
603828  95.337  -56.262  52.993  1
603829  95.371  -56.277  52.933  1
603830  95.405  -56.290  52.873  1
603831  95.443  -56.299  52.814  1
603832  95.480  -56.308  52.754  1
603833  95.518  -56.317  52.696  1
603834  95.556  -56.326  52.636  1
603835  95.593  -56.335  52.576  1
603836  95.630  -56.345  52.512  1
603837  95.657  -56.345  52.444  1
603838  95.684  -56.345  52.377  1
603839  95.715  -56.348  52.312  1
603840  95.750  -56.354  52.249  1
603841  95.782  -56.363  52.188  1
603842  95.808  -56.380  52.130  1
603843  95.834  -56.398  52.074  1
603844  95.860  -56.415  52.020  1
603845  95.886  -56.433  51.967  1
603846  95.911  -56.438  51.914  1
603847  95.937  -56.441  51.865  1
603848  95.962  -56.445  51.815  1
603849  95.987  -56.448  51.768  1
603850  96.012  -56.451  51.724  1
603851  96.037  -56.454  51.681  1
603852  96.062  -56.457  51.639  1
603853  96.088  -56.460  51.599  1
603854  96.112  -56.463  51.561  1
603855  96.137  -56.466  51.525  1
603856  96.163  -56.469  51.491  1
603857  96.188  -56.472  51.458  1
603858  96.218  -56.474  51.426  1
603859  96.250  -56.476  51.395  1
603860  96.282  -56.479  51.364  1
603861  96.297  -56.479  51.336  1
603862  96.313  -56.481  51.309  1
603863  96.328  -56.482  51.283  1
603864  96.343  -56.483  51.256  1
603865  96.359  -56.484  51.231  1
603866  96.375  -56.498  51.206  1
603867  96.390  -56.514  51.185  1
603868  96.406  -56.528  51.165  1
603869  96.422  -56.541  51.145  1
603870  96.446  -56.536  51.125  1
603871  96.469  -56.531  51.106  1
603872  96.493  -56.526  51.086  1
603873  96.516  -56.526  51.066  1
603874  96.539  -56.532  51.045  1
603875  96.561  -56.539  51.022  1
603876  96.584  -56.545  50.996  1
603877  96.607  -56.552  50.970  1
603878  96.629  -56.558  50.942  1
603879  96.652  -56.564  50.915  1
603880  96.675  -56.570  50.889  1
603881  96.697  -56.577  50.864  1
603882  96.732  -56.565  50.840  1
603883  96.766  -56.554  50.816  1
603884  96.790  -56.552  50.792  1
603885  96.809  -56.545  50.770  1
603886  96.847  -56.544  50.751  1
603887  96.897  -56.547  50.732  1
603888  96.949  -56.550  50.715  1
603889  96.996  -56.552  50.699  1
603890  97.029  -56.552  50.680  1
603891  97.063  -56.553  50.665  1
603892  97.096  -56.553  50.650  1
603893  97.130  -56.554  50.634  1
603894  97.163  -56.554  50.619  1
603895  97.196  -56.549  50.605  1
603896  97.230  -56.541  50.595  1
603897  97.263  -56.533  50.586  1
603898  97.298  -56.528  50.580  1
603899  97.338  -56.535  50.576  1
603900  97.380  -56.542  50.572  1
603901  97.421  -56.548  50.568  1
603902  97.455  -56.548  50.564  1
603903  97.489  -56.549  50.562  1
603904  97.523  -56.549  50.559  1
603905  97.558  -56.550  50.553  1
603906  97.592  -56.550  50.545  1
603907  97.627  -56.551  50.538  1
603908  97.661  -56.551  50.528  1
603909  97.695  -56.552  50.517  1
603910  97.730  -56.555  50.503  1
603911  97.767  -56.561  50.489  1
603912  97.802  -56.567  50.476  1
603913  97.839  -56.573  50.468  1
603914  97.875  -56.579  50.462  1
603915  97.911  -56.586  50.453  1
603916  97.947  -56.592  50.442  1
603917  97.983  -56.598  50.428  1
603918  98.019  -56.604  50.414  1
603919  98.055  -56.610  50.399  1
603920  98.091  -56.616  50.384  1
603921  98.127  -56.622  50.367  1
603922  98.163  -56.628  50.349  1
603923  98.199  -56.635  50.330  1
603924  98.233  -56.643  50.309  1
603925  98.268  -56.652  50.288  1
603926  98.302  -56.661  50.266  1
603927  98.336  -56.670  50.239  1
603928  98.371  -56.678  50.210  1
603929  98.405  -56.686  50.180  1
603930  98.439  -56.696  50.150  1
603931  98.474  -56.704  50.119  1
603932  98.507  -56.712  50.091  1
603933  98.541  -56.720  50.064  1
603934  98.575  -56.727  50.039  1
603935  98.609  -56.735  50.012  1
603936  98.643  -56.743  49.985  1
603937  98.679  -56.751  49.959  1
603938  98.720  -56.758  49.932  1
603939  98.760  -56.765  49.906  1
603940  98.800  -56.772  49.882  1
603941  98.840  -56.780  49.859  1
603942  98.880  -56.787  49.837  1
603943  98.920  -56.794  49.816  1
603944  98.960  -56.802  49.794  1
603945  99.000  -56.809  49.769  1
603946  99.040  -56.816  49.744  1
603947  99.080  -56.824  49.719  1
603948  99.120  -56.830  49.693  1
603949  99.160  -56.838  49.666  1
603950  99.200  -56.846  49.639  1
603951  99.240  -56.852  49.612  1
603952  99.282  -56.853  49.586  1
603953  99.306  -56.860  49.561  1
603954  99.332  -56.866  49.537  1
603955  99.356  -56.872  49.513  1
603956  99.381  -56.879  49.488  1
603957  99.406  -56.885  49.465  1
603958  99.430  -56.892  49.440  1
603959  99.455  -56.898  49.415  1
603960  99.480  -56.904  49.389  1
603961  99.504  -56.911  49.363  1
603962  99.529  -56.917  49.336  1
603963  99.554  -56.923  49.309  1
603964  99.579  -56.930  49.280  1
603965  99.604  -56.936  49.250  1
603966  99.635  -56.948  49.219  1
603967  99.660  -56.965  49.188  1
603968  99.686  -56.983  49.156  1
603969  99.711  -57.000  49.125  1
603970  99.736  -57.018  49.093  1
603971  99.762  -57.036  49.061  1
603972  99.788  -57.054  49.029  1
603973  99.814  -57.072  48.997  1
603974  99.839  -57.090  48.965  1
603975  99.864  -57.108  48.935  1
603976  99.890  -57.125  48.905  1
603977  99.916  -57.144  48.876  1
603978  99.941  -57.161  48.847  1
603979  99.967  -57.179  48.819  1
603980  99.992  -57.197  48.793  1
603981  100.018  -57.215  48.767  1
603982  100.043  -57.233  48.741  1
604313  88.430  -52.857  57.423  4
604314  88.468  -52.876  57.422  4
604315  88.506  -52.895  57.422  4
604316  88.544  -52.914  57.423  4
604317  88.582  -52.933  57.425  4
604318  88.620  -52.953  57.425  4
604319  88.659  -52.972  57.426  4
604320  88.696  -52.991  57.425  4
604321  88.735  -53.010  57.425  4
604322  88.772  -53.030  57.424  4
604323  88.811  -53.049  57.424  4
604324  88.848  -53.069  57.422  4
604325  88.887  -53.088  57.419  4
604326  88.924  -53.107  57.416  4
604327  88.963  -53.126  57.412  4
604328  88.986  -53.158  57.407  4
604329  89.017  -53.181  57.402  4
604330  89.049  -53.204  57.398  4
604331  89.081  -53.227  57.392  4
604332  89.112  -53.249  57.386  4
604333  89.144  -53.272  57.379  4
604334  89.175  -53.295  57.372  4
604335  89.207  -53.317  57.364  4
604336  89.239  -53.340  57.357  4
604337  89.270  -53.363  57.349  4
604338  89.302  -53.386  57.340  4
604339  89.326  -53.416  57.332  4
604340  89.349  -53.449  57.324  4
604341  89.372  -53.481  57.315  4
604342  89.394  -53.514  57.304  4
604343  89.417  -53.546  57.294  4
604344  89.440  -53.578  57.284  4
604345  89.478  -53.593  57.274  4
604346  89.530  -53.590  57.264  4
604347  89.574  -53.593  57.250  4
604348  89.600  -53.604  57.235  4
604349  89.625  -53.616  57.221  4
604350  89.651  -53.628  57.207  4
604351  89.676  -53.640  57.190  4
604352  89.702  -53.652  57.173  4
604353  89.735  -53.668  57.152  4
604354  89.769  -53.686  57.126  4
604355  89.803  -53.703  57.097  4
604356  89.837  -53.721  57.065  4
604357  89.872  -53.738  57.030  4
604358  89.906  -53.756  56.993  4
604359  89.941  -53.773  56.953  4
604360  89.975  -53.791  56.911  4
604361  90.009  -53.809  56.870  4
604362  90.044  -53.826  56.829  4
604363  90.078  -53.844  56.789  4
604364  90.112  -53.861  56.750  4
604365  90.147  -53.878  56.709  4
604366  90.181  -53.896  56.671  4
604367  90.215  -53.914  56.634  4
604373  90.470  -53.984  56.255  1
604374  90.490  -54.003  56.222  1
604375  90.508  -54.023  56.190  1
604376  90.525  -54.044  56.160  1
604377  90.542  -54.063  56.129  1
604378  90.559  -54.084  56.101  1
604379  90.577  -54.104  56.073  1
604380  90.594  -54.124  56.047  1
604381  90.611  -54.145  56.023  1
604382  90.628  -54.164  56.000  1
604383  90.646  -54.185  55.977  1
604384  90.663  -54.204  55.956  1
604385  90.697  -54.207  55.938  1
604386  90.733  -54.209  55.923  1
604387  90.767  -54.215  55.909  1
604388  90.796  -54.235  55.892  1
604389  90.825  -54.255  55.868  1
604390  90.854  -54.275  55.838  1
604391  90.883  -54.295  55.809  1
604392  90.912  -54.316  55.782  1
604393  90.941  -54.336  55.758  1
604394  90.970  -54.356  55.735  1
604395  90.999  -54.376  55.715  1
604396  91.028  -54.396  55.697  1
604397  91.057  -54.417  55.680  1
604398  91.086  -54.436  55.666  1
604399  91.114  -54.457  55.654  1
604400  91.144  -54.477  55.645  1
604401  91.172  -54.497  55.642  1
604402  91.202  -54.517  55.643  1
604403  91.230  -54.537  55.647  1
604404  91.262  -54.557  55.650  1
604405  91.311  -54.566  55.650  1
604406  91.364  -54.571  55.648  1
604407  91.416  -54.576  55.646  1
604408  91.469  -54.581  55.637  1
604409  91.522  -54.587  55.621  1
604410  91.575  -54.591  55.598  1
604411  91.629  -54.596  55.572  1
604412  91.682  -54.601  55.546  1
604413  91.736  -54.606  55.523  1
604414  91.789  -54.611  55.500  1
604415  91.836  -54.615  55.476  1
604416  91.863  -54.624  55.452  1
604417  91.894  -54.635  55.432  1
604418  91.926  -54.646  55.414  1
604419  91.958  -54.656  55.400  1
604420  91.991  -54.667  55.388  1
604421  92.023  -54.678  55.377  1
604422  92.055  -54.688  55.367  1
604423  92.088  -54.699  55.357  1
604424  92.120  -54.709  55.348  1
604425  92.152  -54.720  55.340  1
604426  92.184  -54.731  55.332  1
604427  92.217  -54.741  55.323  1
604428  92.249  -54.752  55.313  1
604429  92.281  -54.762  55.304  1
604430  92.314  -54.777  55.296  1
604431  92.349  -54.797  55.291  1
604432  92.382  -54.816  55.288  1
604433  92.417  -54.836  55.287  1
604434  92.451  -54.856  55.286  1
604435  92.483  -54.862  55.287  1
604436  92.514  -54.868  55.289  1
604437  92.546  -54.874  55.295  1
604438  92.577  -54.880  55.304  1
604439  92.609  -54.886  55.314  1
604440  92.640  -54.892  55.331  1
604441  92.672  -54.897  55.352  1
604442  92.702  -54.909  55.374  1
604443  92.727  -54.927  55.399  1
604444  92.754  -54.945  55.426  1
604445  92.779  -54.963  55.455  1
604446  92.805  -54.981  55.482  1
604447  92.831  -55.000  55.509  1
604448  92.857  -55.018  55.532  1
604449  92.883  -55.036  55.548  1
604450  92.909  -55.054  55.557  1
604451  92.935  -55.072  55.563  1
604452  92.968  -55.090  55.567  1
604453  93.004  -55.108  55.568  1
604454  93.039  -55.126  55.563  1
604455  93.075  -55.144  55.553  1
604456  93.111  -55.162  55.545  1
604457  93.146  -55.180  55.533  1
604458  93.182  -55.198  55.518  1
604459  93.217  -55.216  55.500  1
604460  93.253  -55.234  55.481  1
604461  93.288  -55.252  55.457  1
604462  93.324  -55.270  55.427  1
604463  93.359  -55.288  55.393  1
604464  93.395  -55.306  55.359  1
604465  93.430  -55.323  55.329  1
604466  93.466  -55.342  55.310  1
604467  93.502  -55.360  55.303  1
604468  93.537  -55.377  55.297  1
604469  93.570  -55.395  55.296  1
604470  93.594  -55.408  55.294  1
604471  93.615  -55.433  55.287  1
604472  93.635  -55.457  55.275  1
604473  93.655  -55.480  55.260  1
604474  93.676  -55.505  55.246  1
604475  93.696  -55.529  55.234  1
604476  93.716  -55.553  55.224  1
604477  93.737  -55.574  55.212  1
604478  93.759  -55.594  55.194  1
604479  93.781  -55.614  55.168  1
604480  93.802  -55.635  55.135  1
604481  93.824  -55.655  55.098  1
604482  93.846  -55.676  55.059  1
604483  93.867  -55.696  55.021  1
604484  93.889  -55.718  54.982  1
604485  93.910  -55.739  54.943  1
604486  93.930  -55.768  54.907  1
604487  93.950  -55.798  54.872  1
604488  93.970  -55.828  54.838  1
604489  93.997  -55.841  54.803  1
604490  94.028  -55.852  54.767  1
604491  94.060  -55.859  54.728  1
604492  94.092  -55.865  54.692  1
604493  94.125  -55.873  54.657  1
604494  94.157  -55.880  54.622  1
604495  94.190  -55.887  54.587  1
604496  94.222  -55.893  54.553  1
604497  94.255  -55.900  54.517  1
604498  94.287  -55.907  54.480  1
604499  94.320  -55.915  54.440  1
604500  94.353  -55.922  54.400  1
604501  94.387  -55.931  54.362  1
604502  94.421  -55.939  54.327  1
604503  94.455  -55.947  54.287  1
604504  94.502  -55.959  54.260  1
604505  94.552  -55.970  54.234  1
604506  94.603  -55.981  54.206  1
604507  94.653  -55.994  54.174  1
604508  94.703  -56.005  54.137  1
604509  94.737  -56.013  54.094  1
604510  94.771  -56.020  54.051  1
604511  94.805  -56.028  54.005  1
604512  94.839  -56.036  53.957  1
604513  94.873  -56.041  53.906  1
604514  94.906  -56.044  53.852  1
604515  94.941  -56.047  53.795  1
604516  94.974  -56.050  53.736  1
604517  95.008  -56.053  53.680  1
604518  95.042  -56.056  53.621  1
604519  95.080  -56.079  53.559  1
604520  95.118  -56.103  53.494  1
604521  95.154  -56.125  53.430  1
604522  95.173  -56.134  53.369  1
604523  95.192  -56.144  53.314  1
604524  95.211  -56.154  53.261  1
604525  95.230  -56.163  53.210  1
604526  95.248  -56.178  53.157  1
604527  95.281  -56.193  53.102  1
604528  95.315  -56.208  53.048  1
604529  95.348  -56.223  52.990  1
604530  95.382  -56.238  52.930  1
604531  95.415  -56.254  52.870  1
604532  95.449  -56.268  52.811  1
604533  95.485  -56.279  52.752  1
604534  95.523  -56.288  52.695  1
604535  95.560  -56.297  52.637  1
604536  95.598  -56.306  52.577  1
604537  95.635  -56.315  52.516  1
604538  95.664  -56.317  52.452  1
604539  95.691  -56.317  52.386  1
604540  95.725  -56.322  52.315  1
604541  95.759  -56.329  52.250  1
604542  95.784  -56.346  52.188  1
604543  95.811  -56.364  52.127  1
604544  95.837  -56.381  52.068  1
604545  95.863  -56.399  52.013  1
604546  95.889  -56.415  51.958  1
604547  95.914  -56.418  51.904  1
604548  95.939  -56.421  51.852  1
604549  95.964  -56.424  51.801  1
604550  95.989  -56.427  51.752  1
604551  96.015  -56.430  51.706  1
604552  96.040  -56.434  51.662  1
604553  96.064  -56.437  51.619  1
604554  96.090  -56.440  51.578  1
604555  96.115  -56.443  51.538  1
604556  96.140  -56.446  51.501  1
604557  96.168  -56.448  51.466  1
604558  96.200  -56.451  51.433  1
604559  96.232  -56.453  51.401  1
604560  96.264  -56.454  51.368  1
604561  96.292  -56.457  51.337  1
604562  96.308  -56.458  51.308  1
604563  96.323  -56.459  51.282  1
604564  96.338  -56.460  51.255  1
604565  96.354  -56.461  51.228  1
604566  96.369  -56.462  51.202  1
604567  96.385  -56.463  51.176  1
604568  96.400  -56.464  51.152  1
604569  96.415  -56.471  51.131  1
604570  96.431  -56.486  51.110  1
604571  96.447  -56.501  51.089  1
604572  96.469  -56.501  51.067  1
604573  96.492  -56.495  51.046  1
604574  96.516  -56.493  51.024  1
604575  96.538  -56.500  51.003  1
604576  96.561  -56.506  50.981  1
604577  96.584  -56.512  50.955  1
604578  96.606  -56.519  50.929  1
604579  96.629  -56.525  50.901  1
604580  96.652  -56.532  50.875  1
604581  96.674  -56.538  50.850  1
604582  96.697  -56.545  50.824  1
604583  96.720  -56.551  50.800  1
604584  96.754  -56.534  50.775  1
604585  96.782  -56.517  50.751  1
604586  96.801  -56.508  50.728  1
604587  96.844  -56.509  50.707  1
604588  96.895  -56.512  50.688  1
604589  96.947  -56.514  50.670  1
604590  96.995  -56.517  50.653  1
604591  97.028  -56.517  50.636  1
604592  97.062  -56.517  50.621  1
604593  97.095  -56.518  50.607  1
604594  97.129  -56.518  50.592  1
604595  97.162  -56.519  50.578  1
604596  97.195  -56.517  50.564  1
604597  97.228  -56.509  50.552  1
604598  97.261  -56.501  50.542  1
604599  97.300  -56.504  50.535  1
604600  97.342  -56.511  50.529  1
604601  97.380  -56.515  50.524  1
604602  97.414  -56.515  50.519  1
604603  97.449  -56.516  50.515  1
604604  97.483  -56.516  50.512  1
604605  97.517  -56.517  50.508  1
604606  97.551  -56.517  50.504  1
604607  97.586  -56.517  50.497  1
604608  97.620  -56.517  50.491  1
604609  97.655  -56.518  50.483  1
604610  97.689  -56.519  50.473  1
604611  97.724  -56.521  50.461  1
604612  97.760  -56.527  50.448  1
604613  97.796  -56.533  50.436  1
604614  97.832  -56.539  50.426  1
604615  97.868  -56.545  50.420  1
604616  97.904  -56.552  50.414  1
604617  97.940  -56.558  50.404  1
604618  97.977  -56.564  50.392  1
604619  98.012  -56.570  50.378  1
604620  98.049  -56.576  50.365  1
604621  98.085  -56.583  50.349  1
604622  98.121  -56.589  50.332  1
604623  98.157  -56.595  50.314  1
604624  98.193  -56.601  50.294  1
604625  98.229  -56.607  50.274  1
604626  98.265  -56.613  50.252  1
604627  98.300  -56.620  50.228  1
604628  98.334  -56.630  50.202  1
604629  98.368  -56.638  50.173  1
604630  98.403  -56.647  50.142  1
604631  98.437  -56.655  50.113  1
604632  98.471  -56.664  50.085  1
604633  98.505  -56.671  50.059  1
604634  98.539  -56.680  50.033  1
604635  98.573  -56.687  50.007  1
604636  98.613  -56.695  49.980  1
604637  98.652  -56.702  49.953  1
604638  98.693  -56.709  49.927  1
604639  98.732  -56.716  49.902  1
604640  98.773  -56.724  49.875  1
604641  98.812  -56.731  49.850  1
604642  98.853  -56.738  49.828  1
604643  98.893  -56.746  49.806  1
604644  98.933  -56.753  49.784  1
604645  98.973  -56.760  49.761  1
604646  99.013  -56.768  49.735  1
604647  99.053  -56.774  49.711  1
604648  99.093  -56.782  49.688  1
604649  99.130  -56.790  49.663  1
604650  99.166  -56.798  49.637  1
604651  99.203  -56.805  49.610  1
604652  99.239  -56.814  49.584  1
604653  99.275  -56.821  49.558  1
604654  99.311  -56.830  49.532  1
604655  99.342  -56.837  49.508  1
604656  99.369  -56.844  49.485  1
604657  99.394  -56.851  49.461  1
604658  99.418  -56.857  49.437  1
604659  99.443  -56.863  49.412  1
604660  99.468  -56.870  49.388  1
604661  99.492  -56.876  49.363  1
604662  99.517  -56.883  49.337  1
604663  99.542  -56.889  49.311  1
604664  99.567  -56.895  49.286  1
604665  99.591  -56.902  49.258  1
604666  99.619  -56.911  49.230  1
604667  99.645  -56.923  49.200  1
604668  99.671  -56.941  49.169  1
604669  99.697  -56.959  49.139  1
604670  99.722  -56.977  49.107  1
604671  99.748  -56.994  49.075  1
604672  99.773  -57.012  49.044  1
604673  99.799  -57.030  49.013  1
604674  99.824  -57.048  48.982  1
604675  99.850  -57.066  48.951  1
604676  99.875  -57.084  48.922  1
604677  99.901  -57.102  48.893  1
604678  99.926  -57.119  48.864  1
604679  99.952  -57.138  48.836  1
604680  99.978  -57.155  48.809  1
604681  100.003  -57.173  48.783  1
604682  100.028  -57.191  48.757  1
605015  88.496  -52.845  57.417  4
605016  88.534  -52.864  57.417  4
605017  88.572  -52.883  57.417  4
605018  88.610  -52.903  57.419  4
605019  88.648  -52.922  57.420  4
605020  88.686  -52.941  57.420  4
605021  88.724  -52.960  57.420  4
605022  88.762  -52.980  57.419  4
605023  88.800  -52.999  57.418  4
605024  88.838  -53.019  57.418  4
605025  88.876  -53.038  57.415  4
605026  88.914  -53.057  57.412  4
605027  88.952  -53.076  57.408  4
605028  88.970  -53.112  57.404  4
605029  89.001  -53.135  57.399  4
605030  89.033  -53.158  57.393  4
605031  89.065  -53.180  57.388  4
605032  89.097  -53.203  57.383  4
605033  89.128  -53.226  57.376  4
605034  89.160  -53.248  57.370  4
605035  89.192  -53.270  57.363  4
605036  89.223  -53.293  57.355  4
605037  89.255  -53.316  57.347  4
605038  89.286  -53.339  57.339  4
605039  89.318  -53.361  57.331  4
605040  89.341  -53.393  57.323  4
605041  89.364  -53.426  57.317  4
605042  89.387  -53.458  57.307  4
605043  89.409  -53.490  57.296  4
605044  89.432  -53.523  57.286  4
605045  89.455  -53.556  57.277  4
605046  89.491  -53.569  57.267  4
605047  89.542  -53.568  57.257  4
605048  89.590  -53.567  57.244  4
605049  89.616  -53.579  57.229  4
605050  89.641  -53.591  57.215  4
605051  89.667  -53.603  57.200  4
605052  89.692  -53.615  57.183  4
605053  89.718  -53.626  57.166  4
605054  89.744  -53.638  57.145  4
605055  89.778  -53.656  57.123  4
605056  89.813  -53.673  57.095  4
605057  89.847  -53.691  57.064  4
605058  89.881  -53.709  57.031  4
605059  89.915  -53.726  56.995  4
605060  89.950  -53.744  56.955  4
605061  89.984  -53.761  56.914  4
605062  90.019  -53.778  56.873  4
605063  90.053  -53.796  56.832  4
605064  90.087  -53.814  56.793  4
605065  90.121  -53.831  56.754  4
605066  90.156  -53.849  56.713  4
605067  90.190  -53.866  56.675  4
605068  90.227  -53.882  56.638  4
605075  90.498  -53.972  56.224  1
605076  90.515  -53.992  56.192  1
605077  90.533  -54.012  56.162  1
605078  90.550  -54.032  56.129  1
605079  90.567  -54.052  56.100  1
605080  90.584  -54.073  56.072  1
605081  90.601  -54.092  56.045  1
605082  90.618  -54.113  56.021  1
605083  90.636  -54.133  55.998  1
605084  90.653  -54.153  55.974  1
605085  90.685  -54.159  55.953  1
605086  90.721  -54.160  55.935  1
605087  90.756  -54.162  55.920  1
605088  90.787  -54.178  55.906  1
605089  90.815  -54.198  55.888  1
605090  90.845  -54.219  55.861  1
605091  90.873  -54.239  55.830  1
605092  90.902  -54.259  55.801  1
605093  90.931  -54.279  55.774  1
605094  90.960  -54.299  55.750  1
605095  90.989  -54.320  55.728  1
605096  91.018  -54.339  55.708  1
605097  91.047  -54.360  55.691  1
605098  91.076  -54.380  55.674  1
605099  91.105  -54.400  55.660  1
605100  91.134  -54.420  55.648  1
605101  91.163  -54.440  55.639  1
605102  91.192  -54.461  55.635  1
605103  91.221  -54.480  55.636  1
605104  91.254  -54.500  55.640  1
605105  91.287  -54.521  55.642  1
605106  91.332  -54.531  55.642  1
605107  91.385  -54.536  55.640  1
605108  91.438  -54.542  55.637  1
605109  91.491  -54.546  55.627  1
605110  91.543  -54.552  55.610  1
605111  91.596  -54.557  55.586  1
605112  91.649  -54.562  55.560  1
605113  91.702  -54.568  55.535  1
605114  91.754  -54.573  55.514  1
605115  91.807  -54.577  55.492  1
605116  91.854  -54.585  55.468  1
605117  91.887  -54.596  55.445  1
605118  91.920  -54.607  55.425  1
605119  91.952  -54.618  55.407  1
605120  91.985  -54.628  55.395  1
605121  92.017  -54.638  55.383  1
605122  92.049  -54.649  55.373  1
605123  92.081  -54.659  55.362  1
605124  92.113  -54.670  55.352  1
605125  92.146  -54.681  55.343  1
605126  92.178  -54.691  55.335  1
605127  92.211  -54.702  55.327  1
605128  92.243  -54.712  55.319  1
605129  92.275  -54.723  55.310  1
605130  92.307  -54.734  55.301  1
605131  92.340  -54.744  55.294  1
605132  92.373  -54.759  55.289  1
605133  92.407  -54.778  55.287  1
605134  92.441  -54.798  55.285  1
605135  92.475  -54.818  55.285  1
605136  92.507  -54.828  55.286  1
605137  92.539  -54.834  55.289  1
605138  92.570  -54.840  55.297  1
605139  92.602  -54.846  55.308  1
605140  92.634  -54.851  55.322  1
605141  92.665  -54.857  55.341  1
605142  92.695  -54.868  55.366  1
605143  92.720  -54.883  55.390  1
605144  92.746  -54.900  55.417  1
605145  92.772  -54.919  55.446  1
605146  92.798  -54.937  55.474  1
605147  92.824  -54.955  55.502  1
605148  92.850  -54.973  55.529  1
605149  92.876  -54.991  55.550  1
605150  92.902  -55.010  55.564  1
605151  92.928  -55.028  55.573  1
605152  92.954  -55.046  55.580  1
605153  92.984  -55.063  55.583  1
605154  93.019  -55.082  55.582  1
605155  93.055  -55.100  55.574  1
605156  93.090  -55.118  55.561  1
605157  93.126  -55.135  55.552  1
605158  93.162  -55.154  55.538  1
605159  93.197  -55.172  55.520  1
605160  93.233  -55.189  55.503  1
605161  93.269  -55.207  55.487  1
605162  93.304  -55.226  55.465  1
605163  93.340  -55.244  55.435  1
605164  93.375  -55.261  55.401  1
605165  93.411  -55.279  55.366  1
605166  93.446  -55.298  55.336  1
605167  93.482  -55.315  55.319  1
605168  93.517  -55.333  55.312  1
605169  93.551  -55.351  55.305  1
605170  93.576  -55.364  55.300  1
605171  93.601  -55.378  55.296  1
605172  93.623  -55.399  55.289  1
605173  93.643  -55.423  55.278  1
605174  93.663  -55.448  55.263  1
605175  93.684  -55.472  55.251  1
605176  93.704  -55.496  55.241  1
605177  93.724  -55.520  55.232  1
605178  93.744  -55.544  55.222  1
605179  93.764  -55.568  55.207  1
605180  93.784  -55.593  55.182  1
605181  93.805  -55.617  55.150  1
605182  93.825  -55.641  55.113  1
605183  93.845  -55.665  55.074  1
605184  93.867  -55.685  55.037  1
605185  93.889  -55.705  55.000  1
605186  93.910  -55.726  54.960  1
605187  93.932  -55.746  54.923  1
605188  93.953  -55.771  54.886  1
605189  93.973  -55.799  54.849  1
605190  93.998  -55.818  54.814  1
605191  94.030  -55.826  54.778  1
605192  94.062  -55.833  54.737  1
605193  94.095  -55.840  54.698  1
605194  94.127  -55.847  54.659  1
605195  94.160  -55.854  54.622  1
605196  94.192  -55.861  54.586  1
605197  94.225  -55.868  54.550  1
605198  94.257  -55.875  54.511  1
605199  94.290  -55.881  54.474  1
605200  94.322  -55.889  54.436  1
605201  94.355  -55.896  54.400  1
605202  94.389  -55.904  54.365  1
605203  94.423  -55.912  54.332  1
605204  94.459  -55.922  54.298  1
605205  94.509  -55.933  54.278  1
605206  94.559  -55.944  54.258  1
605207  94.610  -55.956  54.235  1
605208  94.660  -55.968  54.208  1
605209  94.710  -55.979  54.174  1
605210  94.747  -55.987  54.133  1
605211  94.781  -55.996  54.089  1
605212  94.815  -56.003  54.043  1
605213  94.849  -56.010  53.994  1
605214  94.883  -56.014  53.943  1
605215  94.916  -56.017  53.888  1
605216  94.950  -56.020  53.829  1
605217  94.984  -56.023  53.769  1
605218  95.018  -56.027  53.711  1
605219  95.052  -56.030  53.651  1
605220  95.090  -56.050  53.586  1
605221  95.128  -56.074  53.518  1
605222  95.155  -56.090  53.449  1
605223  95.174  -56.099  53.381  1
605224  95.193  -56.109  53.321  1
605225  95.212  -56.119  53.264  1
605226  95.231  -56.128  53.210  1
605227  95.258  -56.142  53.155  1
605228  95.293  -56.154  53.098  1
605229  95.326  -56.169  53.042  1
605230  95.359  -56.184  52.984  1
605231  95.393  -56.199  52.924  1
605232  95.426  -56.214  52.864  1
605233  95.460  -56.229  52.805  1
605234  95.493  -56.244  52.747  1
605235  95.528  -56.258  52.689  1
605236  95.565  -56.267  52.633  1
605237  95.603  -56.276  52.575  1
605238  95.640  -56.285  52.515  1
605239  95.671  -56.289  52.455  1
605240  95.699  -56.290  52.391  1
605241  95.734  -56.296  52.321  1
605242  95.761  -56.312  52.253  1
605243  95.788  -56.329  52.189  1
605244  95.813  -56.347  52.126  1
605245  95.839  -56.365  52.065  1
605246  95.866  -56.382  52.007  1
605247  95.891  -56.395  51.950  1
605248  95.916  -56.398  51.895  1
605249  95.942  -56.401  51.841  1
605250  95.967  -56.404  51.788  1
605251  95.992  -56.407  51.738  1
605252  96.017  -56.410  51.691  1
605253  96.042  -56.414  51.645  1
605254  96.067  -56.417  51.601  1
605255  96.092  -56.420  51.557  1
605256  96.118  -56.423  51.516  1
605257  96.150  -56.425  51.478  1
605258  96.182  -56.427  51.442  1
605259  96.214  -56.429  51.408  1
605260  96.246  -56.431  51.374  1
605261  96.277  -56.433  51.342  1
605262  96.303  -56.435  51.311  1
605263  96.318  -56.436  51.282  1
605264  96.333  -56.437  51.255  1
605265  96.349  -56.438  51.229  1
605266  96.364  -56.439  51.202  1
605267  96.380  -56.440  51.174  1
605268  96.395  -56.441  51.146  1
605269  96.410  -56.442  51.121  1
605270  96.426  -56.443  51.099  1
605271  96.442  -56.445  51.076  1
605272  96.457  -56.445  51.054  1
605273  96.472  -56.459  51.031  1
605274  96.491  -56.465  51.007  1
605275  96.515  -56.461  50.985  1
605276  96.538  -56.467  50.964  1
605277  96.560  -56.473  50.942  1
605278  96.583  -56.479  50.917  1
605279  96.606  -56.486  50.890  1
605280  96.628  -56.492  50.862  1
605281  96.651  -56.498  50.836  1
605282  96.673  -56.504  50.812  1
605283  96.694  -56.508  50.787  1
605284  96.716  -56.514  50.761  1
605285  96.743  -56.507  50.735  1
605286  96.774  -56.489  50.710  1
605287  96.799  -56.478  50.687  1
605288  96.843  -56.474  50.666  1
605289  96.893  -56.476  50.646  1
605290  96.945  -56.479  50.626  1
605291  96.993  -56.482  50.609  1
605292  97.026  -56.483  50.592  1
605293  97.060  -56.483  50.578  1
605294  97.093  -56.483  50.564  1
605295  97.127  -56.483  50.550  1
605296  97.160  -56.484  50.536  1
605297  97.194  -56.484  50.522  1
605298  97.227  -56.476  50.509  1
605299  97.262  -56.473  50.499  1
605300  97.303  -56.479  50.490  1
605301  97.339  -56.482  50.483  1
605302  97.374  -56.482  50.477  1
605303  97.408  -56.483  50.471  1
605304  97.442  -56.483  50.466  1
605305  97.476  -56.483  50.461  1
605306  97.511  -56.483  50.457  1
605307  97.545  -56.484  50.453  1
605308  97.580  -56.484  50.448  1
605309  97.614  -56.485  50.444  1
605310  97.648  -56.485  50.438  1
605311  97.683  -56.486  50.430  1
605312  97.717  -56.487  50.418  1
605313  97.753  -56.493  50.405  1
605314  97.790  -56.499  50.393  1
605315  97.825  -56.505  50.382  1
605316  97.862  -56.511  50.376  1
605317  97.898  -56.518  50.370  1
605318  97.934  -56.524  50.361  1
605319  97.970  -56.530  50.351  1
605320  98.006  -56.536  50.341  1
605321  98.042  -56.542  50.327  1
605322  98.078  -56.548  50.312  1
605323  98.114  -56.555  50.296  1
605324  98.150  -56.561  50.277  1
605325  98.186  -56.567  50.258  1
605326  98.223  -56.573  50.237  1
605327  98.258  -56.580  50.214  1
605328  98.295  -56.586  50.189  1
605329  98.331  -56.592  50.162  1
605330  98.366  -56.599  50.134  1
605331  98.401  -56.607  50.105  1
605332  98.435  -56.616  50.077  1
605333  98.469  -56.624  50.049  1
605334  98.505  -56.631  50.022  1
605335  98.545  -56.639  49.996  1
605336  98.585  -56.646  49.969  1
605337  98.625  -56.653  49.943  1
605338  98.665  -56.660  49.918  1
605339  98.705  -56.668  49.892  1
605340  98.743  -56.675  49.866  1
605341  98.780  -56.683  49.840  1
605342  98.816  -56.691  49.816  1
605343  98.852  -56.699  49.792  1
605344  98.888  -56.707  49.770  1
605345  98.925  -56.714  49.749  1
605346  98.961  -56.723  49.725  1
605347  98.997  -56.730  49.700  1
605348  99.033  -56.739  49.676  1
605349  99.070  -56.746  49.653  1
605350  99.106  -56.755  49.629  1
605351  99.142  -56.762  49.603  1
605352  99.179  -56.771  49.575  1
605353  99.215  -56.778  49.550  1
605354  99.251  -56.787  49.526  1
605355  99.287  -56.794  49.501  1
605356  99.324  -56.802  49.477  1
605357  99.360  -56.810  49.454  1
605358  99.395  -56.818  49.431  1
605359  99.423  -56.826  49.408  1
605360  99.451  -56.834  49.384  1
605361  99.480  -56.842  49.361  1
605362  99.505  -56.848  49.338  1
605363  99.529  -56.855  49.313  1
605364  99.554  -56.861  49.288  1
605365  99.579  -56.867  49.263  1
605366  99.604  -56.874  49.236  1
605367  99.632  -56.884  49.209  1
605368  99.656  -56.899  49.181  1
605369  99.682  -56.917  49.151  1
605370  99.707  -56.935  49.120  1
605371  99.733  -56.953  49.089  1
605372  99.759  -56.971  49.058  1
605373  99.784  -56.988  49.028  1
605374  99.809  -57.006  48.998  1
605375  99.835  -57.024  48.968  1
605376  99.861  -57.042  48.937  1
605377  99.887  -57.060  48.908  1
605378  99.912  -57.078  48.880  1
605379  99.937  -57.096  48.852  1
605380  99.963  -57.113  48.825  1
605381  99.989  -57.131  48.799  1
605382  100.014  -57.149  48.773  1
605716  88.523  -52.814  57.412  4
605717  88.561  -52.834  57.412  4
605718  88.600  -52.853  57.411  4
605719  88.637  -52.872  57.413  4
605720  88.676  -52.891  57.414  4
605721  88.713  -52.910  57.414  4
605722  88.752  -52.930  57.414  4
605723  88.789  -52.949  57.413  4
605724  88.828  -52.969  57.411  4
605725  88.865  -52.988  57.410  4
605726  88.904  -53.007  57.408  4
605727  88.926  -53.039  57.405  4
605728  88.955  -53.065  57.401  4
605729  88.986  -53.088  57.396  4
605730  89.018  -53.111  57.391  4
605731  89.049  -53.133  57.385  4
605732  89.081  -53.156  57.379  4
605733  89.113  -53.179  57.373  4
605734  89.144  -53.201  57.367  4
605735  89.176  -53.224  57.361  4
605736  89.208  -53.247  57.355  4
605737  89.239  -53.270  57.347  4
605738  89.271  -53.292  57.339  4
605739  89.303  -53.315  57.331  4
605740  89.334  -53.338  57.324  4
605741  89.356  -53.371  57.316  4
605742  89.379  -53.403  57.308  4
605743  89.402  -53.435  57.299  4
605744  89.424  -53.468  57.290  4
605745  89.447  -53.500  57.280  4
605746  89.477  -53.523  57.270  4
605747  89.516  -53.534  57.259  4
605748  89.555  -53.544  57.250  4
605749  89.607  -53.542  57.237  4
605750  89.632  -53.554  57.223  4
605751  89.658  -53.565  57.209  4
605752  89.683  -53.577  57.194  4
605753  89.708  -53.589  57.177  4
605754  89.734  -53.601  57.161  4
605755  89.760  -53.612  57.141  4
605756  89.788  -53.626  57.121  4
605757  89.822  -53.643  57.097  4
605758  89.856  -53.661  57.067  4
605759  89.891  -53.678  57.034  4
605760  89.925  -53.697  56.998  4
605761  89.959  -53.714  56.958  4
605762  89.993  -53.731  56.918  4
605763  90.028  -53.749  56.877  4
605764  90.062  -53.766  56.837  4
605765  90.097  -53.784  56.798  4
605766  90.131  -53.801  56.759  4
605767  90.165  -53.819  56.718  4
605768  90.199  -53.837  56.680  4
605769  90.242  -53.848  56.644  4
605770  90.285  -53.860  56.608  4
605777  90.523  -53.960  56.195  1
605778  90.540  -53.981  56.164  1
605779  90.557  -54.001  56.132  1
605780  90.575  -54.021  56.101  1
605781  90.592  -54.041  56.073  1
605782  90.609  -54.061  56.046  1
605783  90.626  -54.082  56.020  1
605784  90.644  -54.101  55.997  1
605785  90.672  -54.110  55.973  1
605786  90.708  -54.112  55.951  1
605787  90.743  -54.113  55.932  1
605788  90.777  -54.122  55.917  1
605789  90.806  -54.142  55.901  1
605790  90.835  -54.162  55.882  1
605791  90.864  -54.182  55.854  1
605792  90.893  -54.202  55.823  1
605793  90.922  -54.223  55.793  1
605794  90.951  -54.242  55.767  1
605795  90.979  -54.263  55.744  1
605796  91.009  -54.283  55.723  1
605797  91.037  -54.303  55.703  1
605798  91.067  -54.323  55.685  1
605799  91.095  -54.343  55.669  1
605800  91.124  -54.364  55.655  1
605801  91.153  -54.383  55.644  1
605802  91.182  -54.404  55.635  1
605803  91.212  -54.424  55.632  1
605804  91.245  -54.444  55.631  1
605805  91.279  -54.464  55.633  1
605806  91.312  -54.483  55.634  1
605807  91.354  -54.496  55.632  1
605808  91.406  -54.502  55.631  1
605809  91.459  -54.507  55.626  1
605810  91.512  -54.512  55.616  1
605811  91.565  -54.518  55.598  1
605812  91.618  -54.522  55.575  1
605813  91.671  -54.527  55.549  1
605814  91.723  -54.533  55.525  1
605815  91.776  -54.538  55.505  1
605816  91.828  -54.543  55.483  1
605817  91.865  -54.555  55.459  1
605818  91.900  -54.565  55.438  1
605819  91.936  -54.577  55.419  1
605820  91.972  -54.588  55.402  1
605821  92.008  -54.599  55.390  1
605822  92.043  -54.610  55.378  1
605823  92.075  -54.621  55.368  1
605824  92.107  -54.631  55.357  1
605825  92.140  -54.642  55.347  1
605826  92.172  -54.652  55.337  1
605827  92.204  -54.663  55.330  1
605828  92.237  -54.673  55.323  1
605829  92.269  -54.684  55.315  1
605830  92.301  -54.694  55.307  1
605831  92.334  -54.705  55.298  1
605832  92.366  -54.715  55.291  1
605833  92.398  -54.726  55.288  1
605834  92.431  -54.740  55.286  1
605835  92.465  -54.760  55.284  1
605836  92.499  -54.780  55.285  1
605837  92.532  -54.793  55.287  1
605838  92.564  -54.799  55.291  1
605839  92.595  -54.805  55.301  1
605840  92.627  -54.811  55.313  1
605841  92.658  -54.817  55.329  1
605842  92.688  -54.828  55.352  1
605843  92.715  -54.846  55.379  1
605844  92.741  -54.861  55.403  1
605845  92.766  -54.875  55.432  1
605846  92.791  -54.893  55.462  1
605847  92.817  -54.911  55.490  1
605848  92.843  -54.928  55.517  1
605849  92.869  -54.947  55.540  1
605850  92.895  -54.965  55.557  1
605851  92.921  -54.983  55.571  1
605852  92.947  -55.001  55.582  1
605853  92.973  -55.019  55.588  1
605854  93.000  -55.038  55.590  1
605855  93.036  -55.055  55.588  1
605856  93.071  -55.073  55.578  1
605857  93.107  -55.091  55.564  1
605858  93.142  -55.110  55.553  1
605859  93.178  -55.127  55.537  1
605860  93.213  -55.145  55.516  1
605861  93.249  -55.163  55.498  1
605862  93.284  -55.181  55.485  1
605863  93.320  -55.199  55.467  1
605864  93.355  -55.217  55.439  1
605865  93.391  -55.235  55.405  1
605866  93.427  -55.253  55.371  1
605867  93.462  -55.271  55.345  1
605868  93.498  -55.289  55.335  1
605869  93.533  -55.307  55.329  1
605870  93.557  -55.320  55.319  1
605871  93.582  -55.334  55.310  1
605872  93.608  -55.348  55.300  1
605873  93.631  -55.367  55.290  1
605874  93.651  -55.390  55.279  1
605875  93.671  -55.414  55.266  1
605876  93.691  -55.439  55.253  1
605877  93.711  -55.463  55.243  1
605878  93.732  -55.487  55.234  1
605879  93.752  -55.511  55.224  1
605880  93.772  -55.536  55.209  1
605881  93.792  -55.559  55.184  1
605882  93.813  -55.583  55.153  1
605883  93.833  -55.608  55.117  1
605884  93.853  -55.632  55.082  1
605885  93.873  -55.656  55.048  1
605886  93.894  -55.680  55.015  1
605887  93.914  -55.704  54.978  1
605888  93.934  -55.728  54.942  1
605889  93.954  -55.752  54.906  1
605890  93.975  -55.775  54.871  1
605891  94.000  -55.793  54.836  1
605892  94.033  -55.800  54.799  1
605893  94.065  -55.807  54.757  1
605894  94.098  -55.815  54.712  1
605895  94.130  -55.821  54.670  1
605896  94.163  -55.828  54.630  1
605897  94.195  -55.835  54.592  1
605898  94.227  -55.842  54.555  1
605899  94.260  -55.849  54.513  1
605900  94.292  -55.856  54.475  1
605901  94.325  -55.863  54.440  1
605902  94.357  -55.870  54.407  1
605903  94.391  -55.878  54.374  1
605904  94.424  -55.886  54.342  1
605905  94.465  -55.896  54.312  1
605906  94.516  -55.908  54.295  1
605907  94.566  -55.919  54.280  1
605908  94.616  -55.931  54.262  1
605909  94.667  -55.942  54.239  1
605910  94.717  -55.954  54.209  1
605911  94.757  -55.963  54.171  1
605912  94.790  -55.971  54.128  1
605913  94.825  -55.978  54.081  1
605914  94.858  -55.984  54.031  1
605915  94.892  -55.987  53.979  1
605916  94.926  -55.990  53.922  1
605917  94.960  -55.994  53.860  1
605918  94.994  -55.997  53.797  1
605919  95.028  -56.000  53.735  1
605920  95.061  -56.003  53.672  1
605921  95.099  -56.022  53.608  1
605922  95.137  -56.045  53.539  1
605923  95.157  -56.055  53.468  1
605924  95.175  -56.064  53.397  1
605925  95.194  -56.074  53.330  1
605926  95.213  -56.088  53.268  1
605927  95.233  -56.106  53.210  1
605928  95.265  -56.118  53.153  1
605929  95.300  -56.129  53.094  1
605930  95.334  -56.141  53.036  1
605931  95.369  -56.152  52.976  1
605932  95.403  -56.164  52.916  1
605933  95.438  -56.175  52.855  1
605934  95.471  -56.191  52.794  1
605935  95.505  -56.206  52.737  1
605936  95.538  -56.221  52.681  1
605937  95.571  -56.236  52.626  1
605938  95.608  -56.247  52.568  1
605939  95.645  -56.256  52.511  1
605940  95.678  -56.261  52.452  1
605941  95.709  -56.264  52.391  1
605942  95.738  -56.278  52.326  1
605943  95.764  -56.295  52.256  1
605944  95.790  -56.313  52.190  1
605945  95.816  -56.331  52.126  1
605946  95.842  -56.348  52.063  1
605947  95.868  -56.366  52.003  1
605948  95.894  -56.376  51.945  1
605949  95.919  -56.379  51.888  1
605950  95.944  -56.382  51.832  1
605951  95.969  -56.385  51.777  1
605952  95.994  -56.388  51.725  1
605953  96.019  -56.391  51.676  1
605954  96.044  -56.394  51.629  1
605955  96.070  -56.397  51.584  1
605956  96.101  -56.399  51.539  1
605957  96.132  -56.401  51.496  1
605958  96.164  -56.403  51.456  1
605959  96.196  -56.405  51.420  1
605960  96.228  -56.407  51.385  1
605961  96.260  -56.409  51.350  1
605962  96.292  -56.411  51.317  1
605963  96.313  -56.413  51.286  1
605964  96.328  -56.414  51.256  1
605965  96.344  -56.415  51.229  1
605966  96.359  -56.416  51.202  1
605967  96.375  -56.417  51.175  1
605968  96.390  -56.418  51.147  1
605969  96.405  -56.419  51.119  1
605970  96.421  -56.420  51.093  1
605971  96.437  -56.421  51.069  1
605972  96.452  -56.423  51.045  1
605973  96.467  -56.423  51.022  1
605974  96.482  -56.425  50.998  1
605975  96.498  -56.426  50.973  1
605976  96.514  -56.429  50.949  1
605977  96.537  -56.435  50.927  1
605978  96.559  -56.439  50.904  1
605979  96.581  -56.445  50.878  1
605980  96.602  -56.449  50.853  1
605981  96.624  -56.455  50.826  1
605982  96.646  -56.461  50.801  1
605983  96.668  -56.467  50.778  1
605984  96.690  -56.472  50.753  1
605985  96.712  -56.477  50.726  1
605986  96.740  -56.470  50.698  1
605987  96.770  -56.458  50.672  1
605988  96.814  -56.454  50.648  1
605989  96.859  -56.452  50.627  1
605990  96.902  -56.450  50.605  1
605991  96.947  -56.448  50.585  1
605992  96.991  -56.447  50.568  1
605993  97.025  -56.447  50.550  1
605994  97.058  -56.448  50.535  1
605995  97.092  -56.448  50.522  1
605996  97.125  -56.448  50.508  1
605997  97.159  -56.448  50.495  1
605998  97.192  -56.449  50.482  1
605999  97.226  -56.445  50.468  1
606000  97.264  -56.448  50.457  1
606001  97.299  -56.448  50.447  1
606002  97.333  -56.448  50.439  1
606003  97.367  -56.449  50.431  1
606004  97.402  -56.449  50.424  1
606005  97.436  -56.450  50.418  1
606006  97.470  -56.450  50.412  1
606007  97.505  -56.451  50.407  1
606008  97.539  -56.451  50.402  1
606009  97.574  -56.451  50.398  1
606010  97.608  -56.451  50.396  1
606011  97.642  -56.452  50.392  1
606012  97.676  -56.453  50.385  1
606013  97.711  -56.454  50.374  1
606014  97.747  -56.460  50.362  1
606015  97.783  -56.466  50.349  1
606016  97.819  -56.472  50.338  1
606017  97.855  -56.478  50.331  1
606018  97.891  -56.484  50.325  1
606019  97.927  -56.490  50.317  1
606020  97.963  -56.496  50.309  1
606021  98.000  -56.502  50.300  1
606022  98.035  -56.508  50.288  1
606023  98.072  -56.515  50.273  1
606024  98.108  -56.521  50.257  1
606025  98.144  -56.527  50.239  1
606026  98.180  -56.533  50.220  1
606027  98.216  -56.539  50.199  1
606028  98.252  -56.545  50.176  1
606029  98.288  -56.552  50.150  1
606030  98.324  -56.558  50.123  1
606031  98.360  -56.564  50.095  1
606032  98.397  -56.570  50.067  1
606033  98.436  -56.579  50.039  1
606034  98.470  -56.586  50.010  1
606035  98.505  -56.593  49.983  1
606036  98.539  -56.601  49.957  1
606037  98.574  -56.608  49.929  1
606038  98.610  -56.616  49.903  1
606039  98.647  -56.624  49.877  1
606040  98.683  -56.632  49.852  1
606041  98.719  -56.640  49.825  1
606042  98.756  -56.648  49.801  1
606043  98.792  -56.656  49.776  1
606044  98.828  -56.664  49.753  1
606045  98.864  -56.672  49.731  1
606046  98.901  -56.680  49.710  1
606047  98.937  -56.687  49.686  1
606048  98.973  -56.696  49.661  1
606049  99.009  -56.703  49.637  1
606050  99.046  -56.711  49.614  1
606051  99.082  -56.719  49.591  1
606052  99.118  -56.727  49.565  1
606053  99.154  -56.735  49.537  1
606054  99.191  -56.743  49.514  1
606055  99.227  -56.751  49.491  1
606056  99.263  -56.759  49.468  1
606057  99.299  -56.767  49.445  1
606058  99.336  -56.775  49.423  1
606059  99.372  -56.783  49.402  1
606060  99.408  -56.791  49.380  1
606061  99.444  -56.799  49.357  1
606062  99.475  -56.806  49.335  1
606063  99.503  -56.815  49.312  1
606064  99.532  -56.822  49.288  1
606065  99.560  -56.830  49.264  1
606066  99.589  -56.838  49.239  1
606067  99.616  -56.846  49.214  1
606068  99.642  -56.857  49.188  1
606069  99.667  -56.875  49.161  1
606070  99.693  -56.893  49.132  1
606071  99.718  -56.911  49.101  1
606072  99.744  -56.929  49.071  1
606073  99.770  -56.946  49.041  1
606074  99.795  -56.965  49.011  1
606075  99.821  -56.982  48.982  1
606076  99.846  -57.000  48.953  1
606077  99.871  -57.018  48.923  1
606078  99.897  -57.036  48.894  1
606079  99.923  -57.054  48.867  1
606080  99.948  -57.072  48.841  1
606081  99.974  -57.090  48.814  1
606082  99.999  -57.107  48.788  1
606083  100.025  -57.125  48.763  1
606417  88.551  -52.784  57.407  4
606418  88.589  -52.803  57.407  4
606419  88.627  -52.822  57.405  4
606420  88.665  -52.841  57.407  4
606421  88.703  -52.860  57.408  4
606422  88.741  -52.880  57.408  4
606423  88.779  -52.899  57.407  4
606424  88.817  -52.919  57.406  4
606425  88.855  -52.938  57.404  4
606426  88.893  -52.957  57.402  4
606427  88.907  -52.996  57.400  4
606428  88.939  -53.019  57.396  4
606429  88.971  -53.042  57.392  4
606430  89.002  -53.064  57.387  4
606431  89.034  -53.087  57.381  4
606432  89.065  -53.110  57.375  4
606433  89.097  -53.132  57.370  4
606434  89.129  -53.154  57.364  4
606435  89.161  -53.177  57.358  4
606436  89.192  -53.200  57.352  4
606437  89.224  -53.223  57.346  4
606438  89.255  -53.245  57.339  4
606439  89.287  -53.268  57.331  4
606440  89.319  -53.291  57.324  4
606441  89.349  -53.315  57.316  4
606442  89.372  -53.348  57.308  4
606443  89.394  -53.380  57.301  4
606444  89.417  -53.412  57.293  4
606445  89.440  -53.445  57.284  4
606446  89.463  -53.477  57.275  4
606447  89.501  -53.488  57.265  4
606448  89.540  -53.499  57.255  4
606449  89.578  -53.510  57.244  4
606450  89.619  -53.518  57.232  4
606451  89.649  -53.528  57.218  4
606452  89.674  -53.540  57.203  4
606453  89.699  -53.552  57.188  4
606454  89.725  -53.564  57.173  4
606455  89.750  -53.575  57.157  4
606456  89.776  -53.587  57.139  4
606457  89.802  -53.599  57.120  4
606458  89.831  -53.614  57.098  4
606459  89.866  -53.631  57.071  4
606460  89.900  -53.649  57.038  4
606461  89.934  -53.666  57.001  4
606462  89.968  -53.684  56.963  4
606463  90.003  -53.702  56.923  4
606464  90.037  -53.719  56.883  4
606465  90.072  -53.737  56.843  4
606466  90.106  -53.754  56.804  4
606467  90.140  -53.772  56.766  4
606468  90.174  -53.789  56.726  4
606469  90.214  -53.803  56.688  4
606470  90.257  -53.814  56.650  4
606471  90.300  -53.825  56.615  4
606479  90.548  -53.949  56.168  1
606480  90.565  -53.969  56.136  1
606481  90.582  -53.989  56.104  1
606482  90.599  -54.010  56.075  1
606483  90.617  -54.029  56.047  1
606484  90.634  -54.050  56.021  1
606485  90.660  -54.062  55.997  1
606486  90.695  -54.063  55.972  1
606487  90.731  -54.065  55.949  1
606488  90.766  -54.066  55.929  1
606489  90.796  -54.085  55.911  1
606490  90.825  -54.105  55.894  1
606491  90.854  -54.126  55.873  1
606492  90.883  -54.145  55.845  1
606493  90.912  -54.166  55.815  1
606494  90.941  -54.185  55.786  1
606495  90.970  -54.206  55.761  1
606496  90.999  -54.226  55.739  1
606497  91.028  -54.246  55.718  1
606498  91.057  -54.267  55.698  1
606499  91.086  -54.286  55.681  1
606500  91.114  -54.307  55.665  1
606501  91.144  -54.327  55.651  1
606502  91.172  -54.347  55.641  1
606503  91.203  -54.367  55.632  1
606504  91.236  -54.387  55.629  1
606505  91.270  -54.407  55.630  1
606506  91.303  -54.427  55.632  1
606507  91.336  -54.446  55.632  1
606508  91.375  -54.462  55.632  1
606509  91.428  -54.467  55.627  1
606510  91.481  -54.472  55.618  1
606511  91.534  -54.477  55.604  1
606512  91.587  -54.483  55.585  1
606513  91.640  -54.488  55.562  1
606514  91.693  -54.493  55.538  1
606515  91.745  -54.498  55.515  1
606516  91.798  -54.503  55.495  1
606517  91.840  -54.512  55.473  1
606518  91.876  -54.524  55.451  1
606519  91.912  -54.535  55.430  1
606520  91.947  -54.546  55.412  1
606521  91.984  -54.557  55.397  1
606522  92.019  -54.568  55.384  1
606523  92.056  -54.579  55.373  1
606524  92.091  -54.590  55.363  1
606525  92.127  -54.602  55.353  1
606526  92.163  -54.612  55.342  1
606527  92.198  -54.624  55.332  1
606528  92.230  -54.634  55.325  1
606529  92.263  -54.645  55.318  1
606530  92.295  -54.656  55.311  1
606531  92.328  -54.666  55.303  1
606532  92.360  -54.677  55.295  1
606533  92.392  -54.687  55.288  1
606534  92.424  -54.697  55.286  1
606535  92.456  -54.708  55.284  1
606536  92.490  -54.723  55.284  1
606537  92.523  -54.743  55.285  1
606538  92.557  -54.759  55.289  1
606539  92.588  -54.765  55.294  1
606540  92.620  -54.771  55.305  1
606541  92.652  -54.777  55.318  1
606542  92.681  -54.789  55.338  1
606543  92.708  -54.806  55.362  1
606544  92.735  -54.824  55.390  1
606545  92.761  -54.840  55.415  1
606546  92.786  -54.853  55.444  1
606547  92.810  -54.867  55.474  1
606548  92.836  -54.884  55.502  1
606549  92.862  -54.903  55.526  1
606550  92.888  -54.921  55.546  1
606551  92.914  -54.938  55.561  1
606552  92.940  -54.956  55.577  1
606553  92.966  -54.975  55.589  1
606554  92.992  -54.993  55.594  1
606555  93.018  -55.011  55.594  1
606556  93.051  -55.029  55.590  1
606557  93.087  -55.047  55.577  1
606558  93.122  -55.065  55.563  1
606559  93.158  -55.083  55.551  1
606560  93.194  -55.101  55.534  1
606561  93.229  -55.119  55.512  1
606562  93.265  -55.137  55.491  1
606563  93.300  -55.155  55.481  1
606564  93.336  -55.173  55.462  1
606565  93.371  -55.191  55.435  1
606566  93.407  -55.209  55.404  1
606567  93.442  -55.227  55.377  1
606568  93.478  -55.245  55.363  1
606569  93.513  -55.263  55.364  1
606570  93.539  -55.276  55.356  1
606571  93.564  -55.290  55.342  1
606572  93.589  -55.304  55.326  1
606573  93.614  -55.318  55.308  1
606574  93.638  -55.333  55.292  1
606575  93.659  -55.358  55.282  1
606576  93.679  -55.382  55.270  1
606577  93.699  -55.406  55.257  1
606578  93.719  -55.430  55.247  1
606579  93.740  -55.454  55.237  1
606580  93.760  -55.478  55.227  1
606581  93.780  -55.502  55.213  1
606582  93.800  -55.527  55.188  1
606583  93.821  -55.551  55.157  1
606584  93.841  -55.574  55.124  1
606585  93.861  -55.599  55.091  1
606586  93.881  -55.623  55.059  1
606587  93.902  -55.647  55.028  1
606588  93.922  -55.671  54.993  1
606589  93.942  -55.696  54.957  1
606590  93.962  -55.720  54.923  1
606591  93.982  -55.743  54.888  1
606592  94.008  -55.761  54.853  1
606593  94.039  -55.771  54.817  1
606594  94.069  -55.780  54.774  1
606595  94.100  -55.789  54.729  1
606596  94.132  -55.796  54.689  1
606597  94.165  -55.803  54.651  1
606598  94.197  -55.809  54.613  1
606599  94.230  -55.816  54.575  1
606600  94.262  -55.823  54.534  1
606601  94.294  -55.830  54.493  1
606602  94.327  -55.837  54.457  1
606603  94.359  -55.844  54.423  1
606604  94.393  -55.851  54.391  1
606605  94.426  -55.860  54.360  1
606606  94.472  -55.871  54.329  1
606607  94.522  -55.882  54.312  1
606608  94.572  -55.893  54.299  1
606609  94.623  -55.906  54.285  1
606610  94.674  -55.917  54.266  1
606611  94.724  -55.928  54.240  1
606612  94.766  -55.938  54.206  1
606613  94.801  -55.946  54.165  1
606614  94.834  -55.953  54.118  1
606615  94.868  -55.956  54.067  1
606616  94.902  -55.960  54.013  1
606617  94.936  -55.963  53.954  1
606618  94.970  -55.966  53.889  1
606619  95.003  -55.969  53.823  1
606620  95.037  -55.973  53.757  1
606621  95.071  -55.976  53.692  1
606622  95.108  -55.992  53.626  1
606623  95.139  -56.010  53.558  1
606624  95.158  -56.020  53.485  1
606625  95.177  -56.030  53.411  1
606626  95.195  -56.047  53.342  1
606627  95.214  -56.066  53.276  1
606628  95.240  -56.081  53.212  1
606629  95.273  -56.094  53.152  1
606630  95.306  -56.105  53.090  1
606631  95.340  -56.116  53.030  1
606632  95.375  -56.128  52.969  1
606633  95.410  -56.140  52.908  1
606634  95.444  -56.151  52.846  1
606635  95.479  -56.163  52.784  1
606636  95.514  -56.174  52.724  1
606637  95.548  -56.185  52.666  1
606638  95.583  -56.197  52.611  1
606639  95.616  -56.213  52.555  1
606640  95.650  -56.226  52.499  1
606641  95.685  -56.233  52.443  1
606642  95.714  -56.244  52.386  1
606643  95.741  -56.261  52.323  1
606644  95.766  -56.279  52.258  1
606645  95.793  -56.297  52.190  1
606646  95.819  -56.314  52.125  1
606647  95.844  -56.332  52.061  1
606648  95.871  -56.349  52.000  1
606649  95.896  -56.355  51.942  1
606650  95.921  -56.358  51.882  1
606651  95.946  -56.361  51.824  1
606652  95.971  -56.365  51.767  1
606653  95.996  -56.368  51.713  1
606654  96.022  -56.371  51.662  1
606655  96.051  -56.373  51.614  1
606656  96.083  -56.376  51.567  1
606657  96.115  -56.377  51.521  1
606658  96.147  -56.379  51.477  1
606659  96.178  -56.381  51.436  1
606660  96.210  -56.383  51.399  1
606661  96.242  -56.385  51.363  1
606662  96.274  -56.387  51.327  1
606663  96.306  -56.389  51.294  1
606664  96.323  -56.391  51.261  1
606665  96.339  -56.392  51.231  1
606666  96.354  -56.393  51.204  1
606667  96.370  -56.394  51.177  1
606668  96.385  -56.395  51.149  1
606669  96.400  -56.396  51.121  1
606670  96.416  -56.397  51.092  1
606671  96.432  -56.398  51.066  1
606672  96.447  -56.399  51.041  1
606673  96.462  -56.401  51.016  1
606674  96.477  -56.401  50.992  1
606675  96.493  -56.403  50.967  1
606676  96.509  -56.404  50.940  1
606677  96.522  -56.405  50.916  1
606678  96.535  -56.407  50.893  1
606679  96.557  -56.412  50.868  1
606680  96.579  -56.417  50.842  1
606681  96.601  -56.423  50.816  1
606682  96.622  -56.429  50.789  1
606683  96.645  -56.435  50.764  1
606684  96.666  -56.440  50.741  1
606685  96.688  -56.445  50.717  1
606686  96.712  -56.447  50.690  1
606687  96.742  -56.434  50.663  1
606688  96.784  -56.429  50.637  1
606689  96.828  -56.427  50.613  1
606690  96.872  -56.425  50.591  1
606691  96.916  -56.423  50.570  1
606692  96.954  -56.421  50.550  1
606693  96.988  -56.420  50.530  1
606694  97.022  -56.420  50.512  1
606695  97.055  -56.419  50.497  1
606696  97.089  -56.418  50.483  1
606697  97.123  -56.417  50.470  1
606698  97.157  -56.417  50.457  1
606699  97.190  -56.416  50.442  1
606700  97.224  -56.415  50.429  1
606701  97.258  -56.415  50.417  1
606702  97.293  -56.415  50.406  1
606703  97.327  -56.416  50.396  1
606704  97.361  -56.416  50.387  1
606705  97.395  -56.417  50.379  1
606706  97.430  -56.417  50.371  1
606707  97.464  -56.417  50.365  1
606708  97.499  -56.417  50.359  1
606709  97.533  -56.418  50.353  1
606710  97.567  -56.418  50.349  1
606711  97.601  -56.419  50.345  1
606712  97.636  -56.420  50.339  1
606713  97.670  -56.420  50.335  1
606714  97.705  -56.420  50.328  1
606715  97.740  -56.426  50.317  1
606716  97.777  -56.432  50.304  1
606717  97.813  -56.438  50.294  1
606718  97.849  -56.444  50.285  1
606719  97.885  -56.451  50.279  1
606720  97.921  -56.457  50.272  1
606721  97.957  -56.463  50.264  1
606722  97.993  -56.469  50.255  1
606723  98.029  -56.475  50.246  1
606724  98.065  -56.481  50.232  1
606725  98.101  -56.487  50.216  1
606726  98.138  -56.493  50.200  1
606727  98.173  -56.499  50.181  1
606728  98.210  -56.506  50.161  1
606729  98.249  -56.514  50.138  1
606730  98.290  -56.522  50.111  1
606731  98.330  -56.531  50.084  1
606732  98.370  -56.539  50.056  1
606733  98.411  -56.548  50.028  1
606734  98.446  -56.555  49.999  1
606735  98.480  -56.563  49.970  1
606736  98.515  -56.570  49.942  1
606737  98.549  -56.577  49.914  1
606738  98.584  -56.585  49.887  1
606739  98.618  -56.592  49.859  1
606740  98.653  -56.599  49.832  1
606741  98.687  -56.607  49.806  1
606742  98.722  -56.614  49.780  1
606743  98.756  -56.621  49.756  1
606744  98.791  -56.629  49.733  1
606745  98.825  -56.636  49.710  1
606746  98.860  -56.643  49.687  1
606747  98.894  -56.651  49.667  1
606748  98.929  -56.658  49.645  1
606749  98.963  -56.665  49.620  1
606750  98.998  -56.673  49.596  1
606751  99.032  -56.680  49.572  1
606752  99.067  -56.687  49.548  1
606753  99.101  -56.695  49.523  1
606754  99.136  -56.702  49.497  1
606755  99.170  -56.709  49.475  1
606756  99.205  -56.717  49.453  1
606757  99.239  -56.724  49.433  1
606758  99.275  -56.732  49.413  1
606759  99.311  -56.740  49.392  1
606760  99.348  -56.748  49.372  1
606761  99.384  -56.755  49.351  1
606762  99.421  -56.763  49.329  1
606763  99.457  -56.771  49.307  1
606764  99.493  -56.779  49.285  1
606765  99.527  -56.787  49.263  1
606766  99.556  -56.795  49.239  1
606767  99.585  -56.805  49.215  1
606768  99.618  -56.821  49.191  1
606769  99.646  -56.836  49.166  1
606770  99.674  -56.852  49.140  1
606771  99.702  -56.870  49.111  1
606772  99.729  -56.887  49.082  1
606773  99.755  -56.905  49.053  1
606774  99.780  -56.923  49.024  1
606775  99.806  -56.940  48.995  1
606776  99.832  -56.959  48.966  1
606777  99.857  -56.976  48.938  1
606778  99.883  -56.994  48.909  1
606779  99.908  -57.012  48.881  1
606780  99.934  -57.030  48.855  1
606781  99.959  -57.048  48.829  1
606782  99.985  -57.065  48.804  1
606783  100.010  -57.084  48.778  1
607118  88.578  -52.753  57.401  4
607119  88.616  -52.772  57.401  4
607120  88.654  -52.791  57.399  4
607121  88.693  -52.811  57.400  4
607122  88.731  -52.830  57.401  4
607123  88.769  -52.849  57.400  4
607124  88.807  -52.869  57.399  4
607125  88.845  -52.888  57.398  4
607126  88.866  -52.921  57.396  4
607127  88.892  -52.949  57.394  4
607128  88.923  -52.972  57.391  4
607129  88.955  -52.995  57.387  4
607130  88.987  -53.017  57.383  4
607131  89.018  -53.040  57.377  4
607132  89.050  -53.063  57.372  4
607133  89.082  -53.086  57.366  4
607134  89.113  -53.108  57.361  4
607135  89.145  -53.131  57.355  4
607136  89.177  -53.154  57.349  4
607137  89.208  -53.176  57.342  4
607138  89.240  -53.199  57.337  4
607139  89.272  -53.222  57.331  4
607140  89.303  -53.245  57.324  4
607141  89.335  -53.267  57.317  4
607142  89.365  -53.292  57.310  4
607143  89.387  -53.325  57.302  4
607144  89.409  -53.357  57.295  4
607145  89.432  -53.389  57.287  4
607146  89.455  -53.422  57.279  4
607147  89.487  -53.442  57.270  4
607148  89.525  -53.452  57.261  4
607149  89.564  -53.464  57.250  4
607150  89.602  -53.475  57.240  4
607151  89.635  -53.488  57.227  4
607152  89.666  -53.505  57.213  4
607153  89.690  -53.515  57.198  4
607154  89.716  -53.527  57.183  4
607155  89.741  -53.538  57.169  4
607156  89.766  -53.550  57.154  4
607157  89.792  -53.562  57.136  4
607158  89.818  -53.574  57.117  4
607159  89.843  -53.586  57.097  4
607160  89.875  -53.602  57.074  4
607161  89.909  -53.619  57.043  4
607162  89.944  -53.637  57.006  4
607163  89.978  -53.654  56.968  4
607164  90.012  -53.672  56.928  4
607165  90.046  -53.689  56.889  4
607166  90.081  -53.706  56.850  4
607167  90.115  -53.725  56.811  4
607168  90.150  -53.742  56.773  4
607169  90.186  -53.758  56.735  4
607170  90.229  -53.769  56.696  4
607171  90.272  -53.780  56.659  4
607172  90.316  -53.791  56.623  4
607173  90.359  -53.803  56.590  4
607181  90.573  -53.938  56.140  1
607182  90.590  -53.958  56.108  1
607183  90.607  -53.978  56.078  1
607184  90.624  -53.998  56.049  1
607185  90.647  -54.013  56.023  1
607186  90.683  -54.015  55.998  1
607187  90.718  -54.016  55.973  1
607188  90.754  -54.018  55.949  1
607189  90.787  -54.029  55.927  1
607190  90.815  -54.048  55.906  1
607191  90.845  -54.069  55.887  1
607192  90.873  -54.088  55.864  1
607193  90.902  -54.109  55.836  1
607194  90.931  -54.129  55.808  1
607195  90.960  -54.149  55.781  1
607196  90.989  -54.170  55.756  1
607197  91.018  -54.189  55.734  1
607198  91.047  -54.210  55.714  1
607199  91.076  -54.229  55.695  1
607200  91.105  -54.250  55.677  1
607201  91.134  -54.270  55.661  1
607202  91.163  -54.290  55.647  1
607203  91.194  -54.311  55.637  1
607204  91.228  -54.330  55.629  1
607205  91.261  -54.350  55.628  1
607206  91.294  -54.370  55.630  1
607207  91.328  -54.389  55.632  1
607208  91.361  -54.410  55.633  1
607209  91.397  -54.427  55.632  1
607210  91.450  -54.433  55.625  1
607211  91.503  -54.438  55.612  1
607212  91.556  -54.443  55.595  1
607213  91.608  -54.448  55.574  1
607214  91.661  -54.453  55.551  1
607215  91.714  -54.458  55.528  1
607216  91.767  -54.464  55.507  1
607217  91.815  -54.471  55.486  1
607218  91.851  -54.481  55.465  1
607219  91.887  -54.493  55.444  1
607220  91.923  -54.504  55.424  1
607221  91.959  -54.515  55.408  1
607222  91.995  -54.526  55.392  1
607223  92.030  -54.537  55.380  1
607224  92.067  -54.549  55.368  1
607225  92.102  -54.559  55.358  1
607226  92.138  -54.571  55.348  1
607227  92.174  -54.582  55.337  1
607228  92.210  -54.593  55.326  1
607229  92.246  -54.604  55.320  1
607230  92.282  -54.615  55.313  1
607231  92.318  -54.626  55.306  1
607232  92.353  -54.637  55.299  1
607233  92.385  -54.648  55.293  1
607234  92.418  -54.659  55.286  1
607235  92.450  -54.669  55.284  1
607236  92.483  -54.680  55.284  1
607237  92.515  -54.690  55.284  1
607238  92.548  -54.705  55.286  1
607239  92.582  -54.724  55.291  1
607240  92.614  -54.730  55.297  1
607241  92.645  -54.736  55.310  1
607242  92.674  -54.749  55.326  1
607243  92.701  -54.767  55.348  1
607244  92.728  -54.784  55.373  1
607245  92.755  -54.802  55.400  1
607246  92.781  -54.818  55.425  1
607247  92.806  -54.831  55.451  1
607248  92.831  -54.845  55.478  1
607249  92.856  -54.859  55.503  1
607250  92.881  -54.876  55.525  1
607251  92.907  -54.894  55.543  1
607252  92.933  -54.913  55.562  1
607253  92.959  -54.931  55.583  1
607254  92.985  -54.948  55.593  1
607255  93.011  -54.966  55.596  1
607256  93.037  -54.985  55.595  1
607257  93.067  -55.003  55.589  1
607258  93.102  -55.021  55.574  1
607259  93.138  -55.038  55.558  1
607260  93.174  -55.057  55.545  1
607261  93.209  -55.075  55.528  1
607262  93.245  -55.093  55.506  1
607263  93.280  -55.110  55.483  1
607264  93.316  -55.129  55.472  1
607265  93.352  -55.147  55.454  1
607266  93.387  -55.164  55.430  1
607267  93.423  -55.182  55.408  1
607268  93.459  -55.201  55.394  1
607269  93.494  -55.219  55.389  1
607270  93.520  -55.232  55.389  1
607271  93.545  -55.247  55.380  1
607272  93.570  -55.260  55.364  1
607273  93.595  -55.274  55.345  1
607274  93.621  -55.288  55.326  1
607275  93.646  -55.302  55.308  1
607276  93.666  -55.324  55.296  1
607277  93.687  -55.348  55.284  1
607278  93.707  -55.373  55.272  1
607279  93.727  -55.397  55.261  1
607280  93.748  -55.421  55.251  1
607281  93.768  -55.445  55.239  1
607282  93.788  -55.469  55.222  1
607283  93.808  -55.493  55.194  1
607284  93.828  -55.517  55.164  1
607285  93.849  -55.542  55.133  1
607286  93.869  -55.566  55.103  1
607287  93.889  -55.590  55.072  1
607288  93.909  -55.614  55.041  1
607289  93.929  -55.638  55.008  1
607290  93.949  -55.662  54.974  1
607291  93.970  -55.687  54.941  1
607292  93.991  -55.709  54.907  1
607293  94.016  -55.725  54.871  1
607294  94.049  -55.737  54.834  1
607295  94.080  -55.746  54.791  1
607296  94.110  -55.755  54.748  1
607297  94.141  -55.764  54.710  1
607298  94.171  -55.773  54.673  1
607299  94.202  -55.781  54.635  1
607300  94.232  -55.790  54.597  1
607301  94.265  -55.797  54.555  1
607302  94.297  -55.804  54.515  1
607303  94.330  -55.812  54.477  1
607304  94.362  -55.818  54.442  1
607305  94.395  -55.825  54.409  1
607306  94.428  -55.834  54.377  1
607307  94.479  -55.845  54.346  1
607308  94.529  -55.856  54.328  1
607309  94.579  -55.868  54.314  1
607310  94.630  -55.880  54.301  1
607311  94.680  -55.891  54.286  1
607312  94.731  -55.903  54.267  1
607313  94.776  -55.914  54.237  1
607314  94.811  -55.922  54.199  1
607315  94.844  -55.926  54.152  1
607316  94.878  -55.930  54.100  1
607317  94.912  -55.933  54.044  1
607318  94.946  -55.936  53.984  1
607319  94.980  -55.940  53.917  1
607320  95.014  -55.943  53.850  1
607321  95.047  -55.946  53.779  1
607322  95.081  -55.950  53.710  1
607323  95.117  -55.963  53.642  1
607324  95.140  -55.975  53.574  1
607325  95.159  -55.988  53.501  1
607326  95.178  -56.007  53.427  1
607327  95.197  -56.026  53.356  1
607328  95.216  -56.045  53.286  1
607329  95.248  -56.057  53.218  1
607330  95.280  -56.069  53.153  1
607331  95.313  -56.081  53.089  1
607332  95.347  -56.093  53.026  1
607333  95.382  -56.104  52.964  1
607334  95.416  -56.116  52.901  1
607335  95.451  -56.127  52.839  1
607336  95.485  -56.138  52.777  1
607337  95.520  -56.150  52.715  1
607338  95.554  -56.161  52.655  1
607339  95.589  -56.172  52.598  1
607340  95.624  -56.184  52.542  1
607341  95.658  -56.195  52.486  1
607342  95.691  -56.209  52.430  1
607343  95.717  -56.227  52.376  1
607344  95.743  -56.244  52.318  1
607345  95.769  -56.262  52.256  1
607346  95.795  -56.280  52.193  1
607347  95.821  -56.298  52.128  1
607348  95.847  -56.315  52.063  1
607349  95.873  -56.332  52.001  1
607350  95.898  -56.335  51.940  1
607351  95.923  -56.338  51.879  1
607352  95.949  -56.342  51.819  1
607353  95.974  -56.345  51.761  1
607354  96.002  -56.348  51.705  1
607355  96.033  -56.350  51.652  1
607356  96.065  -56.351  51.602  1
607357  96.097  -56.354  51.554  1
607358  96.129  -56.355  51.506  1
607359  96.161  -56.357  51.461  1
607360  96.192  -56.360  51.419  1
607361  96.224  -56.361  51.380  1
607362  96.256  -56.364  51.343  1
607363  96.288  -56.366  51.306  1
607364  96.318  -56.367  51.272  1
607365  96.334  -56.369  51.238  1
607366  96.349  -56.370  51.207  1
607367  96.365  -56.371  51.180  1
607368  96.380  -56.372  51.153  1
607369  96.395  -56.373  51.125  1
607370  96.411  -56.374  51.097  1
607371  96.427  -56.375  51.068  1
607372  96.442  -56.376  51.040  1
607373  96.457  -56.377  51.015  1
607374  96.473  -56.379  50.989  1
607375  96.488  -56.379  50.963  1
607376  96.504  -56.381  50.937  1
607377  96.518  -56.382  50.910  1
607378  96.530  -56.383  50.884  1
607379  96.542  -56.384  50.860  1
607380  96.555  -56.385  50.834  1
607381  96.577  -56.392  50.807  1
607382  96.599  -56.397  50.780  1
607383  96.621  -56.402  50.753  1
607384  96.643  -56.408  50.728  1
607385  96.665  -56.414  50.704  1
607386  96.686  -56.420  50.681  1
607387  96.715  -56.410  50.655  1
607388  96.753  -56.404  50.629  1
607389  96.798  -56.402  50.604  1
607390  96.842  -56.400  50.580  1
607391  96.884  -56.398  50.557  1
607392  96.918  -56.397  50.536  1
607393  96.951  -56.396  50.515  1
607394  96.985  -56.395  50.495  1
607395  97.018  -56.395  50.476  1
607396  97.052  -56.394  50.461  1
607397  97.086  -56.393  50.446  1
607398  97.119  -56.392  50.433  1
607399  97.153  -56.391  50.419  1
607400  97.187  -56.390  50.404  1
607401  97.221  -56.389  50.391  1
607402  97.254  -56.388  50.378  1
607403  97.288  -56.386  50.367  1
607404  97.322  -56.385  50.356  1
607405  97.356  -56.385  50.345  1
607406  97.389  -56.383  50.336  1
607407  97.424  -56.384  50.327  1
607408  97.458  -56.384  50.319  1
607409  97.493  -56.385  50.312  1
607410  97.527  -56.385  50.306  1
607411  97.561  -56.385  50.301  1
607412  97.595  -56.385  50.296  1
607413  97.630  -56.386  50.289  1
607414  97.664  -56.387  50.283  1
607415  97.699  -56.387  50.276  1
607416  97.734  -56.392  50.267  1
607417  97.770  -56.398  50.255  1
607418  97.806  -56.404  50.247  1
607419  97.843  -56.410  50.240  1
607420  97.878  -56.417  50.233  1
607421  97.915  -56.423  50.226  1
607422  97.951  -56.429  50.218  1
607423  97.987  -56.435  50.208  1
607424  98.023  -56.441  50.200  1
607425  98.060  -56.448  50.188  1
607426  98.101  -56.457  50.173  1
607427  98.141  -56.465  50.156  1
607428  98.181  -56.473  50.138  1
607429  98.222  -56.483  50.117  1
607430  98.263  -56.491  50.094  1
607431  98.303  -56.499  50.067  1
607432  98.343  -56.508  50.040  1
607433  98.383  -56.517  50.012  1
607434  98.421  -56.524  49.983  1
607435  98.456  -56.532  49.954  1
607436  98.490  -56.539  49.925  1
607437  98.525  -56.546  49.897  1
607438  98.559  -56.554  49.868  1
607439  98.594  -56.561  49.840  1
607440  98.628  -56.568  49.812  1
607441  98.663  -56.576  49.784  1
607442  98.698  -56.583  49.757  1
607443  98.732  -56.590  49.730  1
607444  98.767  -56.598  49.705  1
607445  98.801  -56.605  49.682  1
607446  98.836  -56.612  49.659  1
607447  98.870  -56.620  49.637  1
607448  98.905  -56.627  49.619  1
607449  98.939  -56.634  49.598  1
607450  98.974  -56.642  49.573  1
607451  99.008  -56.649  49.548  1
607452  99.043  -56.656  49.525  1
607453  99.077  -56.664  49.502  1
607454  99.112  -56.671  49.477  1
607455  99.146  -56.678  49.453  1
607456  99.181  -56.686  49.431  1
607457  99.215  -56.693  49.412  1
607458  99.250  -56.700  49.395  1
607459  99.284  -56.708  49.377  1
607460  99.319  -56.715  49.357  1
607461  99.353  -56.722  49.339  1
607462  99.387  -56.730  49.319  1
607463  99.422  -56.737  49.299  1
607464  99.456  -56.744  49.278  1
607465  99.491  -56.752  49.258  1
607466  99.525  -56.759  49.237  1
607467  99.556  -56.771  49.213  1
607468  99.589  -56.787  49.190  1
607469  99.621  -56.802  49.167  1
607470  99.648  -56.815  49.143  1
607471  99.676  -56.831  49.117  1
607472  99.703  -56.849  49.090  1
607473  99.731  -56.866  49.062  1
607474  99.759  -56.883  49.034  1
607475  99.787  -56.900  49.006  1
607476  99.815  -56.918  48.978  1
607477  99.842  -56.934  48.951  1
607478  99.868  -56.953  48.923  1
607479  99.894  -56.970  48.895  1
607480  99.919  -56.988  48.869  1
607481  99.944  -57.006  48.843  1
607482  99.970  -57.024  48.818  1
607483  99.996  -57.042  48.793  1
607819  88.606  -52.722  57.396  4
607820  88.644  -52.741  57.395  4
607821  88.682  -52.761  57.394  4
607822  88.720  -52.780  57.393  4
607823  88.758  -52.799  57.393  4
607824  88.796  -52.819  57.393  4
607825  88.834  -52.838  57.392  4
607826  88.844  -52.880  57.390  4
607827  88.876  -52.903  57.387  4
607828  88.908  -52.926  57.385  4
607829  88.940  -52.948  57.382  4
607830  88.971  -52.971  57.378  4
607831  89.003  -52.994  57.373  4
607832  89.035  -53.016  57.368  4
607833  89.066  -53.038  57.363  4
607834  89.098  -53.061  57.357  4
607835  89.129  -53.084  57.352  4
607836  89.161  -53.107  57.347  4
607837  89.193  -53.129  57.341  4
607838  89.225  -53.152  57.334  4
607839  89.256  -53.175  57.329  4
607840  89.288  -53.198  57.323  4
607841  89.319  -53.220  57.317  4
607842  89.351  -53.243  57.310  4
607843  89.380  -53.270  57.303  4
607844  89.402  -53.302  57.295  4
607845  89.424  -53.334  57.289  4
607846  89.447  -53.367  57.282  4
607847  89.473  -53.396  57.274  4
607848  89.511  -53.406  57.266  4
607849  89.550  -53.418  57.256  4
607850  89.588  -53.429  57.246  4
607851  89.621  -53.442  57.236  4
607852  89.645  -53.459  57.223  4
607853  89.685  -53.486  57.209  4
607854  89.713  -53.499  57.194  4
607855  89.733  -53.502  57.179  4
607856  89.757  -53.513  57.165  4
607857  89.783  -53.525  57.150  4
607858  89.808  -53.537  57.133  4
607859  89.834  -53.549  57.113  4
607860  89.860  -53.560  57.093  4
607861  89.885  -53.572  57.071  4
607862  89.918  -53.589  57.042  4
607863  89.953  -53.607  57.009  4
607864  89.987  -53.625  56.972  4
607865  90.022  -53.642  56.934  4
607866  90.056  -53.659  56.896  4
607867  90.090  -53.677  56.858  4
607868  90.124  -53.694  56.819  4
607869  90.159  -53.712  56.782  4
607870  90.201  -53.724  56.743  4
607871  90.245  -53.735  56.705  4
607872  90.288  -53.746  56.669  4
607873  90.331  -53.757  56.633  4
607874  90.374  -53.769  56.599  4
607882  90.581  -53.907  56.145  1
607883  90.598  -53.926  56.113  1
607884  90.615  -53.947  56.083  1
607885  90.635  -53.964  56.053  1
607886  90.670  -53.966  56.026  1
607887  90.706  -53.968  56.000  1
607888  90.741  -53.969  55.974  1
607889  90.777  -53.972  55.948  1
607890  90.806  -53.991  55.925  1
607891  90.835  -54.012  55.902  1
607892  90.864  -54.032  55.880  1
607893  90.893  -54.052  55.855  1
607894  90.922  -54.073  55.828  1
607895  90.951  -54.092  55.801  1
607896  90.979  -54.113  55.776  1
607897  91.009  -54.132  55.752  1
607898  91.037  -54.153  55.730  1
607899  91.067  -54.173  55.710  1
607900  91.095  -54.193  55.691  1
607901  91.124  -54.214  55.673  1
607902  91.153  -54.233  55.657  1
607903  91.186  -54.254  55.644  1
607904  91.219  -54.273  55.634  1
607905  91.252  -54.293  55.626  1
607906  91.286  -54.313  55.625  1
607907  91.319  -54.333  55.627  1
607908  91.353  -54.353  55.630  1
607909  91.386  -54.373  55.631  1
607910  91.419  -54.392  55.630  1
607911  91.471  -54.398  55.623  1
607912  91.524  -54.403  55.608  1
607913  91.577  -54.408  55.587  1
607914  91.630  -54.414  55.564  1
607915  91.683  -54.419  55.542  1
607916  91.735  -54.424  55.519  1
607917  91.788  -54.429  55.499  1
607918  91.826  -54.439  55.478  1
607919  91.862  -54.451  55.457  1
607920  91.898  -54.461  55.437  1
607921  91.934  -54.473  55.419  1
607922  91.970  -54.484  55.403  1
607923  92.006  -54.495  55.388  1
607924  92.041  -54.506  55.375  1
607925  92.078  -54.518  55.364  1
607926  92.113  -54.529  55.354  1
607927  92.149  -54.540  55.343  1
607928  92.186  -54.551  55.333  1
607929  92.221  -54.562  55.323  1
607930  92.258  -54.573  55.316  1
607931  92.293  -54.584  55.309  1
607932  92.329  -54.596  55.302  1
607933  92.365  -54.606  55.296  1
607934  92.401  -54.618  55.290  1
607935  92.437  -54.629  55.285  1
607936  92.473  -54.640  55.284  1
607937  92.509  -54.651  55.284  1
607938  92.541  -54.662  55.285  1
607939  92.573  -54.672  55.288  1
607940  92.606  -54.687  55.293  1
607941  92.638  -54.696  55.301  1
607942  92.667  -54.709  55.314  1
607943  92.694  -54.727  55.334  1
607944  92.721  -54.745  55.357  1
607945  92.748  -54.762  55.382  1
607946  92.775  -54.780  55.406  1
607947  92.801  -54.797  55.428  1
607948  92.827  -54.810  55.452  1
607949  92.851  -54.824  55.475  1
607950  92.876  -54.837  55.498  1
607951  92.901  -54.851  55.519  1
607952  92.926  -54.868  55.538  1
607953  92.952  -54.886  55.558  1
607954  92.978  -54.904  55.577  1
607955  93.004  -54.922  55.587  1
607956  93.030  -54.941  55.589  1
607957  93.056  -54.958  55.585  1
607958  93.083  -54.976  55.577  1
607959  93.119  -54.994  55.563  1
607960  93.154  -55.013  55.548  1
607961  93.190  -55.030  55.536  1
607962  93.225  -55.048  55.520  1
607963  93.261  -55.066  55.498  1
607964  93.296  -55.085  55.473  1
607965  93.332  -55.102  55.459  1
607966  93.367  -55.120  55.443  1
607967  93.403  -55.138  55.428  1
607968  93.438  -55.156  55.419  1
607969  93.474  -55.174  55.417  1
607970  93.501  -55.189  55.417  1
607971  93.526  -55.203  55.413  1
607972  93.552  -55.217  55.402  1
607973  93.577  -55.230  55.383  1
607974  93.602  -55.244  55.363  1
607975  93.627  -55.258  55.343  1
607976  93.652  -55.272  55.325  1
607977  93.675  -55.292  55.312  1
607978  93.695  -55.316  55.300  1
607979  93.715  -55.339  55.288  1
607980  93.735  -55.364  55.277  1
607981  93.755  -55.388  55.265  1
607982  93.776  -55.412  55.252  1
607983  93.796  -55.436  55.234  1
607984  93.816  -55.461  55.205  1
607985  93.836  -55.485  55.178  1
607986  93.856  -55.508  55.151  1
607987  93.876  -55.533  55.123  1
607988  93.897  -55.557  55.093  1
607989  93.917  -55.581  55.065  1
607990  93.937  -55.605  55.032  1
607991  93.958  -55.630  55.001  1
607992  93.978  -55.653  54.968  1
607993  94.000  -55.673  54.931  1
607994  94.026  -55.690  54.891  1
607995  94.058  -55.701  54.852  1
607996  94.090  -55.712  54.809  1
607997  94.121  -55.721  54.770  1
607998  94.151  -55.730  54.733  1
607999  94.182  -55.739  54.696  1
608000  94.212  -55.748  54.658  1
608001  94.243  -55.757  54.619  1
608002  94.273  -55.765  54.576  1
608003  94.303  -55.774  54.536  1
608004  94.334  -55.784  54.497  1
608005  94.364  -55.793  54.461  1
608006  94.397  -55.799  54.426  1
608007  94.435  -55.808  54.395  1
608008  94.485  -55.820  54.363  1
608009  94.536  -55.831  54.341  1
608010  94.586  -55.843  54.325  1
608011  94.636  -55.855  54.314  1
608012  94.687  -55.866  54.302  1
608013  94.737  -55.878  54.287  1
608014  94.786  -55.889  54.260  1
608015  94.820  -55.897  54.225  1
608016  94.854  -55.900  54.180  1
608017  94.888  -55.903  54.128  1
608018  94.922  -55.906  54.071  1
608019  94.956  -55.909  54.009  1
608020  94.989  -55.912  53.941  1
608021  95.023  -55.916  53.871  1
608022  95.057  -55.919  53.800  1
608023  95.091  -55.922  53.730  1
608024  95.122  -55.931  53.660  1
608025  95.141  -55.948  53.592  1
608026  95.160  -55.967  53.520  1
608027  95.179  -55.986  53.446  1
608028  95.198  -56.005  53.372  1
608029  95.223  -56.021  53.299  1
608030  95.256  -56.033  53.228  1
608031  95.288  -56.044  53.160  1
608032  95.320  -56.056  53.091  1
608033  95.354  -56.069  53.027  1
608034  95.388  -56.080  52.961  1
608035  95.423  -56.091  52.897  1
608036  95.457  -56.103  52.835  1
608037  95.492  -56.114  52.772  1
608038  95.527  -56.125  52.710  1
608039  95.561  -56.137  52.648  1
608040  95.596  -56.148  52.588  1
608041  95.630  -56.160  52.530  1
608042  95.665  -56.172  52.474  1
608043  95.692  -56.190  52.418  1
608044  95.719  -56.209  52.364  1
608045  95.746  -56.228  52.310  1
608046  95.772  -56.246  52.253  1
608047  95.798  -56.263  52.194  1
608048  95.824  -56.281  52.130  1
608049  95.850  -56.298  52.065  1
608050  95.876  -56.313  52.002  1
608051  95.901  -56.316  51.940  1
608052  95.926  -56.319  51.878  1
608053  95.952  -56.322  51.817  1
608054  95.983  -56.324  51.757  1
608055  96.016  -56.326  51.699  1
608056  96.047  -56.328  51.645  1
608057  96.079  -56.329  51.593  1
608058  96.111  -56.332  51.543  1
608059  96.143  -56.334  51.494  1
608060  96.175  -56.335  51.448  1
608061  96.206  -56.338  51.404  1
608062  96.238  -56.340  51.364  1
608063  96.270  -56.342  51.326  1
608064  96.302  -56.344  51.289  1
608065  96.329  -56.345  51.253  1
608066  96.344  -56.347  51.219  1
608067  96.360  -56.348  51.187  1
608068  96.375  -56.348  51.158  1
608069  96.390  -56.350  51.130  1
608070  96.406  -56.351  51.101  1
608071  96.421  -56.352  51.073  1
608072  96.437  -56.353  51.044  1
608073  96.452  -56.354  51.015  1
608074  96.468  -56.355  50.989  1
608075  96.483  -56.357  50.964  1
608076  96.499  -56.357  50.937  1
608077  96.513  -56.359  50.909  1
608078  96.525  -56.360  50.882  1
608079  96.538  -56.361  50.855  1
608080  96.550  -56.363  50.830  1
608081  96.562  -56.364  50.803  1
608082  96.575  -56.365  50.776  1
608083  96.597  -56.370  50.748  1
608084  96.619  -56.376  50.720  1
608085  96.641  -56.382  50.694  1
608086  96.663  -56.388  50.670  1
608087  96.687  -56.388  50.646  1
608088  96.723  -56.379  50.621  1
608089  96.767  -56.377  50.596  1
608090  96.811  -56.374  50.571  1
608091  96.847  -56.373  50.547  1
608092  96.880  -56.373  50.525  1
608093  96.914  -56.372  50.504  1
608094  96.948  -56.371  50.482  1
608095  96.981  -56.370  50.462  1
608096  97.015  -56.370  50.443  1
608097  97.049  -56.368  50.426  1
608098  97.083  -56.367  50.411  1
608099  97.116  -56.366  50.396  1
608100  97.150  -56.365  50.382  1
608101  97.184  -56.364  50.367  1
608102  97.218  -56.363  50.354  1
608103  97.251  -56.362  50.341  1
608104  97.285  -56.360  50.328  1
608105  97.318  -56.360  50.317  1
608106  97.352  -56.358  50.306  1
608107  97.386  -56.357  50.295  1
608108  97.420  -56.357  50.285  1
608109  97.453  -56.355  50.276  1
608110  97.487  -56.354  50.268  1
608111  97.521  -56.353  50.261  1
608112  97.555  -56.352  50.254  1
608113  97.589  -56.353  50.248  1
608114  97.624  -56.354  50.241  1
608115  97.658  -56.354  50.233  1
608116  97.692  -56.354  50.226  1
608117  97.728  -56.358  50.217  1
608118  97.764  -56.364  50.207  1
608119  97.800  -56.370  50.199  1
608120  97.836  -56.376  50.194  1
608121  97.872  -56.383  50.187  1
608122  97.912  -56.391  50.180  1
608123  97.952  -56.400  50.171  1
608124  97.993  -56.408  50.162  1
608125  98.033  -56.417  50.154  1
608126  98.074  -56.425  50.142  1
608127  98.114  -56.434  50.128  1
608128  98.154  -56.442  50.112  1
608129  98.195  -56.451  50.093  1
608130  98.235  -56.460  50.072  1
608131  98.276  -56.468  50.048  1
608132  98.316  -56.476  50.023  1
608133  98.357  -56.485  49.996  1
608134  98.397  -56.494  49.968  1
608135  98.432  -56.501  49.939  1
608136  98.466  -56.508  49.910  1
608137  98.501  -56.516  49.881  1
608138  98.535  -56.523  49.852  1
608139  98.570  -56.530  49.823  1
608140  98.604  -56.538  49.794  1
608141  98.639  -56.545  49.765  1
608142  98.673  -56.552  49.737  1
608143  98.708  -56.560  49.710  1
608144  98.742  -56.567  49.682  1
608145  98.777  -56.574  49.657  1
608146  98.811  -56.582  49.634  1
608147  98.846  -56.589  49.611  1
608148  98.880  -56.596  49.588  1
608149  98.915  -56.604  49.570  1
608150  98.949  -56.611  49.549  1
608151  98.984  -56.618  49.525  1
608152  99.018  -56.626  49.500  1
608153  99.053  -56.633  49.477  1
608154  99.087  -56.640  49.454  1
608155  99.122  -56.648  49.431  1
608156  99.156  -56.655  49.409  1
608157  99.191  -56.662  49.388  1
608158  99.225  -56.670  49.371  1
608159  99.260  -56.677  49.355  1
608160  99.294  -56.684  49.339  1
608161  99.329  -56.692  49.321  1
608162  99.363  -56.699  49.303  1
608163  99.398  -56.706  49.286  1
608164  99.432  -56.714  49.267  1
608165  99.467  -56.721  49.247  1
608166  99.501  -56.728  49.228  1
608167  99.530  -56.736  49.208  1
608168  99.560  -56.752  49.186  1
608169  99.593  -56.768  49.165  1
608170  99.623  -56.781  49.143  1
608171  99.649  -56.793  49.119  1
608172  99.678  -56.810  49.095  1
608173  99.705  -56.827  49.069  1
608174  99.733  -56.845  49.043  1
608175  99.761  -56.862  49.016  1
608176  99.789  -56.879  48.989  1
608177  99.817  -56.896  48.962  1
608178  99.844  -56.913  48.935  1
608179  99.872  -56.931  48.909  1
608180  99.900  -56.948  48.882  1
608181  99.928  -56.965  48.858  1
608182  99.956  -56.982  48.832  1
608183  99.981  -57.000  48.807  1
608184  100.007  -57.018  48.783  1
608521  88.672  -52.711  57.389  4
608522  88.710  -52.730  57.388  4
608523  88.748  -52.750  57.387  4
608524  88.786  -52.769  57.386  4
608525  88.806  -52.803  57.385  4
608526  88.829  -52.833  57.385  4
608527  88.860  -52.856  57.382  4
608528  88.892  -52.879  57.378  4
608529  88.924  -52.901  57.376  4
608530  88.956  -52.924  57.373  4
608531  88.987  -52.947  57.369  4
608532  89.019  -52.970  57.364  4
608533  89.051  -52.992  57.359  4
608534  89.082  -53.015  57.353  4
608535  89.114  -53.038  57.348  4
608536  89.145  -53.060  57.343  4
608537  89.177  -53.083  57.338  4
608538  89.209  -53.106  57.332  4
608539  89.241  -53.129  57.326  4
608540  89.272  -53.151  57.320  4
608541  89.304  -53.173  57.315  4
608542  89.336  -53.196  57.310  4
608543  89.367  -53.219  57.304  4
608544  89.395  -53.246  57.297  4
608545  89.417  -53.279  57.290  4
608546  89.440  -53.311  57.285  4
608547  89.462  -53.344  57.278  4
608548  89.497  -53.360  57.271  4
608549  89.535  -53.371  57.263  4
608550  89.574  -53.383  57.254  4
608551  89.607  -53.396  57.243  4
608552  89.630  -53.413  57.232  4
608553  89.654  -53.430  57.218  4
608554  89.695  -53.458  57.204  4
608555  89.737  -53.484  57.191  4
608556  89.761  -53.494  57.176  4
608557  89.780  -53.496  57.163  4
608558  89.799  -53.499  57.147  4
608559  89.825  -53.512  57.129  4
608560  89.850  -53.523  57.110  4
608561  89.876  -53.535  57.089  4
608562  89.901  -53.547  57.068  4
608563  89.928  -53.559  57.041  4
608564  89.962  -53.577  57.012  4
608565  89.996  -53.594  56.977  4
608566  90.031  -53.612  56.941  4
608567  90.065  -53.630  56.904  4
608568  90.099  -53.647  56.866  4
608569  90.134  -53.665  56.829  4
608570  90.173  -53.678  56.792  4
608571  90.217  -53.690  56.754  4
608572  90.260  -53.701  56.716  4
608573  90.303  -53.712  56.679  4
608574  90.346  -53.723  56.643  4
608575  90.389  -53.734  56.609  4
608583  90.588  -53.875  56.152  1
608584  90.605  -53.895  56.119  1
608585  90.622  -53.915  56.088  1
608586  90.658  -53.917  56.057  1
608587  90.693  -53.919  56.029  1
608588  90.729  -53.921  56.002  1
608589  90.764  -53.922  55.975  1
608590  90.796  -53.935  55.949  1
608591  90.825  -53.955  55.923  1
608592  90.854  -53.976  55.899  1
608593  90.883  -53.995  55.875  1
608594  90.912  -54.016  55.849  1
608595  90.941  -54.035  55.823  1
608596  90.970  -54.056  55.797  1
608597  90.999  -54.076  55.772  1
608598  91.028  -54.096  55.749  1
608599  91.057  -54.117  55.727  1
608600  91.086  -54.136  55.707  1
608601  91.114  -54.157  55.688  1
608602  91.144  -54.177  55.670  1
608603  91.177  -54.197  55.655  1
608604  91.211  -54.217  55.642  1
608605  91.244  -54.236  55.632  1
608606  91.277  -54.256  55.624  1
608607  91.310  -54.276  55.622  1
608608  91.344  -54.296  55.624  1
608609  91.377  -54.316  55.627  1
608610  91.411  -54.336  55.628  1
608611  91.444  -54.355  55.626  1
608612  91.493  -54.364  55.619  1
608613  91.546  -54.368  55.604  1
608614  91.599  -54.373  55.584  1
608615  91.652  -54.379  55.559  1
608616  91.704  -54.384  55.534  1
608617  91.757  -54.389  55.511  1
608618  91.801  -54.398  55.490  1
608619  91.837  -54.408  55.471  1
608620  91.873  -54.420  55.451  1
608621  91.909  -54.431  55.432  1
608622  91.945  -54.442  55.415  1
608623  91.981  -54.453  55.400  1
608624  92.017  -54.464  55.385  1
608625  92.053  -54.475  55.372  1
608626  92.089  -54.486  55.361  1
608627  92.125  -54.498  55.351  1
608628  92.161  -54.508  55.340  1
608629  92.197  -54.520  55.330  1
608630  92.232  -54.531  55.320  1
608631  92.269  -54.543  55.313  1
608632  92.304  -54.553  55.306  1
608633  92.340  -54.565  55.300  1
608634  92.376  -54.576  55.294  1
608635  92.412  -54.587  55.288  1
608636  92.448  -54.598  55.283  1
608637  92.484  -54.609  55.283  1
608638  92.520  -54.620  55.284  1
608639  92.556  -54.631  55.285  1
608640  92.592  -54.643  55.289  1
608641  92.628  -54.654  55.296  1
608642  92.660  -54.670  55.304  1
608643  92.687  -54.687  55.320  1
608644  92.714  -54.705  55.342  1
608645  92.741  -54.723  55.365  1
608646  92.768  -54.740  55.387  1
608647  92.795  -54.758  55.409  1
608648  92.822  -54.775  55.427  1
608649  92.847  -54.788  55.447  1
608650  92.871  -54.802  55.468  1
608651  92.896  -54.815  55.489  1
608652  92.921  -54.829  55.509  1
608653  92.945  -54.843  55.528  1
608654  92.971  -54.859  55.548  1
608655  92.997  -54.878  55.564  1
608656  93.023  -54.896  55.574  1
608657  93.049  -54.914  55.575  1
608658  93.075  -54.932  55.569  1
608659  93.101  -54.950  55.560  1
608660  93.134  -54.968  55.545  1
608661  93.170  -54.986  55.531  1
608662  93.205  -55.004  55.519  1
608663  93.241  -55.022  55.504  1
608664  93.277  -55.040  55.486  1
608665  93.312  -55.058  55.464  1
608666  93.348  -55.076  55.451  1
608667  93.383  -55.094  55.444  1
608668  93.419  -55.112  55.444  1
608669  93.454  -55.130  55.449  1
608670  93.483  -55.145  55.453  1
608671  93.508  -55.159  55.446  1
608672  93.533  -55.173  55.434  1
608673  93.558  -55.186  55.418  1
608674  93.583  -55.201  55.398  1
608675  93.609  -55.214  55.378  1
608676  93.633  -55.228  55.359  1
608677  93.658  -55.242  55.343  1
608678  93.682  -55.258  55.329  1
608679  93.703  -55.282  55.316  1
608680  93.723  -55.307  55.305  1
608681  93.743  -55.331  55.292  1
608682  93.763  -55.355  55.279  1
608683  93.783  -55.379  55.265  1
608684  93.803  -55.403  55.247  1
608685  93.824  -55.427  55.220  1
608686  93.844  -55.452  55.196  1
608687  93.864  -55.476  55.173  1
608688  93.885  -55.500  55.148  1
608689  93.905  -55.524  55.120  1
608690  93.925  -55.548  55.093  1
608691  93.945  -55.572  55.062  1
608692  93.966  -55.596  55.031  1
608693  93.986  -55.620  54.997  1
608694  94.010  -55.636  54.958  1
608695  94.035  -55.653  54.918  1
608696  94.067  -55.665  54.877  1
608697  94.100  -55.677  54.834  1
608698  94.131  -55.687  54.795  1
608699  94.162  -55.696  54.757  1
608700  94.192  -55.705  54.719  1
608701  94.223  -55.714  54.679  1
608702  94.253  -55.723  54.640  1
608703  94.284  -55.732  54.595  1
608704  94.314  -55.741  54.554  1
608705  94.345  -55.749  54.514  1
608706  94.375  -55.759  54.477  1
608707  94.406  -55.768  54.443  1
608708  94.445  -55.778  54.412  1
608709  94.495  -55.791  54.378  1
608710  94.544  -55.804  54.351  1
608711  94.594  -55.816  54.333  1
608712  94.643  -55.829  54.323  1
608713  94.694  -55.840  54.315  1
608714  94.744  -55.853  54.302  1
608715  94.794  -55.864  54.278  1
608716  94.830  -55.869  54.247  1
608717  94.864  -55.873  54.204  1
608718  94.898  -55.876  54.152  1
608719  94.931  -55.879  54.095  1
608720  94.963  -55.884  54.032  1
608721  94.995  -55.890  53.961  1
608722  95.026  -55.895  53.890  1
608723  95.058  -55.900  53.818  1
608724  95.089  -55.906  53.748  1
608725  95.121  -55.912  53.679  1
608726  95.142  -55.928  53.612  1
608727  95.162  -55.946  53.543  1
608728  95.180  -55.965  53.470  1
608729  95.199  -55.984  53.394  1
608730  95.231  -55.997  53.318  1
608731  95.263  -56.008  53.244  1
608732  95.296  -56.020  53.171  1
608733  95.328  -56.032  53.100  1
608734  95.360  -56.044  53.032  1
608735  95.395  -56.056  52.964  1
608736  95.429  -56.067  52.898  1
608737  95.464  -56.078  52.833  1
608738  95.498  -56.090  52.769  1
608739  95.533  -56.101  52.706  1
608740  95.568  -56.113  52.645  1
608741  95.602  -56.125  52.585  1
608742  95.637  -56.136  52.526  1
608743  95.667  -56.151  52.469  1
608744  95.694  -56.170  52.412  1
608745  95.721  -56.189  52.356  1
608746  95.747  -56.208  52.302  1
608747  95.774  -56.228  52.246  1
608748  95.801  -56.247  52.189  1
608749  95.826  -56.264  52.129  1
608750  95.852  -56.282  52.066  1
608751  95.878  -56.292  52.002  1
608752  95.903  -56.296  51.942  1
608753  95.934  -56.298  51.878  1
608754  95.966  -56.300  51.816  1
608755  95.997  -56.302  51.755  1
608756  96.030  -56.304  51.695  1
608757  96.061  -56.306  51.639  1
608758  96.093  -56.308  51.586  1
608759  96.125  -56.310  51.534  1
608760  96.157  -56.312  51.484  1
608761  96.189  -56.314  51.436  1
608762  96.221  -56.316  51.391  1
608763  96.252  -56.318  51.350  1
608764  96.284  -56.320  51.310  1
608765  96.316  -56.322  51.273  1
608766  96.339  -56.323  51.236  1
608767  96.355  -56.325  51.200  1
608768  96.370  -56.326  51.167  1
608769  96.385  -56.326  51.137  1
608770  96.401  -56.328  51.108  1
608771  96.416  -56.329  51.078  1
608772  96.432  -56.330  51.049  1
608773  96.447  -56.331  51.020  1
608774  96.463  -56.332  50.990  1
608775  96.478  -56.333  50.964  1
608776  96.493  -56.335  50.938  1
608777  96.509  -56.335  50.910  1
608778  96.521  -56.337  50.881  1
608779  96.533  -56.338  50.853  1
608780  96.545  -56.339  50.826  1
608781  96.558  -56.341  50.801  1
608782  96.571  -56.342  50.774  1
608783  96.583  -56.343  50.748  1
608784  96.595  -56.345  50.719  1
608785  96.617  -56.350  50.690  1
608786  96.639  -56.355  50.663  1
608787  96.661  -56.361  50.638  1
608788  96.693  -56.354  50.613  1
608789  96.737  -56.351  50.590  1
608790  96.776  -56.350  50.565  1
608791  96.810  -56.349  50.539  1
608792  96.843  -56.348  50.516  1
608793  96.877  -56.348  50.494  1
608794  96.910  -56.347  50.472  1
608795  96.944  -56.345  50.450  1
608796  96.978  -56.345  50.430  1
608797  97.012  -56.344  50.410  1
608798  97.045  -56.342  50.392  1
608799  97.079  -56.342  50.376  1
608800  97.113  -56.340  50.361  1
608801  97.147  -56.339  50.346  1
608802  97.180  -56.338  50.331  1
608803  97.214  -56.337  50.318  1
608804  97.248  -56.335  50.305  1
608805  97.282  -56.335  50.292  1
608806  97.315  -56.334  50.279  1
608807  97.349  -56.332  50.268  1
608808  97.383  -56.332  50.256  1
608809  97.417  -56.330  50.245  1
608810  97.450  -56.329  50.235  1
608811  97.484  -56.328  50.226  1
608812  97.518  -56.327  50.216  1
608813  97.551  -56.326  50.208  1
608814  97.585  -56.325  50.201  1
608815  97.619  -56.324  50.195  1
608816  97.652  -56.323  50.188  1
608817  97.686  -56.322  50.181  1
608818  97.723  -56.326  50.172  1
608819  97.764  -56.334  50.160  1
608820  97.804  -56.342  50.153  1
608821  97.844  -56.351  50.148  1
608822  97.885  -56.360  50.141  1
608823  97.925  -56.368  50.134  1
608824  97.965  -56.377  50.125  1
608825  98.006  -56.385  50.115  1
608826  98.046  -56.394  50.107  1
608827  98.087  -56.402  50.095  1
608828  98.127  -56.411  50.081  1
608829  98.167  -56.420  50.065  1
608830  98.208  -56.428  50.047  1
608831  98.248  -56.436  50.026  1
608832  98.289  -56.445  50.002  1
608833  98.329  -56.454  49.978  1
608834  98.370  -56.462  49.952  1
608835  98.407  -56.470  49.924  1
608836  98.442  -56.477  49.896  1
608837  98.476  -56.485  49.867  1
608838  98.511  -56.492  49.838  1
608839  98.545  -56.499  49.808  1
608840  98.580  -56.507  49.779  1
608841  98.614  -56.514  49.749  1
608842  98.649  -56.521  49.719  1
608843  98.683  -56.529  49.692  1
608844  98.718  -56.536  49.664  1
608845  98.752  -56.543  49.637  1
608846  98.787  -56.551  49.612  1
608847  98.821  -56.558  49.587  1
608848  98.856  -56.565  49.564  1
608849  98.890  -56.573  49.541  1
608850  98.925  -56.580  49.521  1
608851  98.959  -56.587  49.500  1
608852  98.994  -56.595  49.476  1
608853  99.028  -56.602  49.452  1
608854  99.063  -56.609  49.428  1
608855  99.097  -56.617  49.406  1
608856  99.132  -56.624  49.385  1
608857  99.166  -56.631  49.365  1
608858  99.201  -56.639  49.346  1
608859  99.235  -56.646  49.329  1
608860  99.270  -56.653  49.314  1
608861  99.304  -56.661  49.299  1
608862  99.339  -56.668  49.282  1
608863  99.373  -56.675  49.267  1
608864  99.408  -56.683  49.251  1
608865  99.442  -56.690  49.233  1
608866  99.477  -56.697  49.215  1
608867  99.506  -56.700  49.198  1
608868  99.532  -56.718  49.179  1
608869  99.564  -56.734  49.159  1
608870  99.596  -56.750  49.140  1
608871  99.625  -56.761  49.118  1
608872  99.651  -56.772  49.096  1
608873  99.679  -56.789  49.073  1
608874  99.707  -56.806  49.048  1
608875  99.735  -56.824  49.024  1
608876  99.763  -56.840  48.998  1
608877  99.790  -56.858  48.972  1
608878  99.818  -56.875  48.946  1
608879  99.846  -56.892  48.920  1
608880  99.874  -56.909  48.895  1
608881  99.902  -56.927  48.868  1
608882  99.929  -56.943  48.846  1
608883  99.958  -56.961  48.822  1
608884  99.985  -56.978  48.797  1
609224  88.775  -52.719  57.380  4
609225  88.782  -52.764  57.379  4
609226  88.814  -52.787  57.378  4
609227  88.845  -52.810  57.376  4
609228  88.877  -52.832  57.374  4
609229  88.908  -52.855  57.369  4
609230  88.940  -52.878  57.366  4
609231  88.972  -52.900  57.363  4
609232  89.003  -52.923  57.359  4
609233  89.035  -52.945  57.354  4
609234  89.067  -52.968  57.349  4
609235  89.098  -52.991  57.344  4
609236  89.130  -53.013  57.339  4
609237  89.162  -53.036  57.334  4
609238  89.193  -53.059  57.329  4
609239  89.225  -53.082  57.323  4
609240  89.257  -53.104  57.318  4
609241  89.288  -53.127  57.313  4
609242  89.320  -53.150  57.309  4
609243  89.352  -53.173  57.304  4
609244  89.383  -53.195  57.298  4
609245  89.410  -53.223  57.292  4
609246  89.433  -53.256  57.286  4
609247  89.455  -53.289  57.281  4
609248  89.483  -53.314  57.274  4
609249  89.521  -53.325  57.268  4
609250  89.559  -53.336  57.262  4
609251  89.593  -53.349  57.252  4
609252  89.616  -53.367  57.241  4
609253  89.639  -53.384  57.228  4
609254  89.665  -53.402  57.215  4
609255  89.706  -53.430  57.201  4
609256  89.747  -53.456  57.188  4
609257  89.789  -53.483  57.174  4
609258  89.809  -53.488  57.161  4
609259  89.828  -53.491  57.145  4
609260  89.846  -53.494  57.127  4
609261  89.866  -53.498  57.107  4
609262  89.892  -53.510  57.087  4
609263  89.917  -53.521  57.066  4
609264  89.943  -53.534  57.041  4
609265  89.971  -53.547  57.014  4
609266  90.006  -53.565  56.983  4
609267  90.040  -53.582  56.948  4
609268  90.075  -53.599  56.912  4
609269  90.109  -53.617  56.875  4
609270  90.146  -53.633  56.839  4
609271  90.189  -53.644  56.803  4
609272  90.232  -53.656  56.765  4
609273  90.275  -53.667  56.727  4
609274  90.318  -53.678  56.690  4
609275  90.362  -53.689  56.655  4
609276  90.405  -53.700  56.620  4
609277  90.448  -53.712  56.587  4
609284  90.596  -53.844  56.160  1
609285  90.613  -53.863  56.126  1
609286  90.645  -53.869  56.093  1
609287  90.680  -53.871  56.062  1
609288  90.716  -53.872  56.033  1
609289  90.752  -53.874  56.006  1
609290  90.787  -53.878  55.978  1
609291  90.816  -53.898  55.950  1
609292  90.845  -53.919  55.924  1
609293  90.874  -53.939  55.898  1
609294  90.902  -53.959  55.873  1
609295  90.931  -53.979  55.847  1
609296  90.960  -53.999  55.821  1
609297  90.989  -54.019  55.795  1
609298  91.018  -54.039  55.771  1
609299  91.047  -54.060  55.747  1
609300  91.076  -54.080  55.725  1
609301  91.105  -54.100  55.705  1
609302  91.135  -54.120  55.686  1
609303  91.169  -54.140  55.668  1
609304  91.202  -54.160  55.654  1
609305  91.235  -54.179  55.641  1
609306  91.269  -54.200  55.630  1
609307  91.302  -54.220  55.622  1
609308  91.335  -54.239  55.620  1
609309  91.368  -54.259  55.621  1
609310  91.402  -54.279  55.624  1
609311  91.435  -54.299  55.624  1
609312  91.468  -54.319  55.621  1
609313  91.515  -54.329  55.615  1
609314  91.568  -54.334  55.602  1
609315  91.621  -54.339  55.582  1
609316  91.673  -54.344  55.557  1
609317  91.726  -54.349  55.530  1
609318  91.777  -54.355  55.505  1
609319  91.812  -54.367  55.483  1
609320  91.848  -54.377  55.464  1
609321  91.884  -54.389  55.446  1
609322  91.920  -54.400  55.429  1
609323  91.956  -54.411  55.413  1
609324  91.992  -54.422  55.397  1
609325  92.028  -54.433  55.382  1
609326  92.064  -54.445  55.370  1
609327  92.100  -54.455  55.359  1
609328  92.136  -54.467  55.349  1
609329  92.172  -54.478  55.338  1
609330  92.208  -54.489  55.327  1
609331  92.243  -54.500  55.317  1
609332  92.280  -54.511  55.310  1
609333  92.315  -54.522  55.304  1
609334  92.351  -54.533  55.298  1
609335  92.387  -54.545  55.292  1
609336  92.423  -54.556  55.286  1
609337  92.459  -54.567  55.282  1
609338  92.495  -54.578  55.282  1
609339  92.532  -54.590  55.284  1
609340  92.571  -54.602  55.286  1
609341  92.609  -54.615  55.291  1
609342  92.648  -54.627  55.298  1
609343  92.681  -54.646  55.308  1
609344  92.707  -54.665  55.325  1
609345  92.734  -54.684  55.345  1
609346  92.761  -54.701  55.366  1
609347  92.788  -54.718  55.385  1
609348  92.815  -54.736  55.403  1
609349  92.842  -54.753  55.419  1
609350  92.867  -54.767  55.439  1
609351  92.892  -54.781  55.460  1
609352  92.916  -54.794  55.478  1
609353  92.941  -54.808  55.496  1
609354  92.966  -54.822  55.513  1
609355  92.991  -54.834  55.531  1
609356  93.016  -54.851  55.545  1
609357  93.042  -54.869  55.554  1
609358  93.068  -54.887  55.555  1
609359  93.094  -54.906  55.550  1
609360  93.120  -54.924  55.539  1
609361  93.150  -54.942  55.524  1
609362  93.186  -54.960  55.511  1
609363  93.221  -54.978  55.500  1
609364  93.257  -54.996  55.487  1
609365  93.292  -55.013  55.473  1
609366  93.328  -55.032  55.459  1
609367  93.363  -55.050  55.453  1
609368  93.399  -55.068  55.456  1
609369  93.435  -55.085  55.465  1
609370  93.464  -55.101  55.474  1
609371  93.489  -55.115  55.476  1
609372  93.514  -55.129  55.468  1
609373  93.540  -55.143  55.452  1
609374  93.565  -55.157  55.432  1
609375  93.589  -55.170  55.412  1
609376  93.615  -55.184  55.392  1
609377  93.640  -55.198  55.372  1
609378  93.665  -55.212  55.355  1
609379  93.690  -55.226  55.344  1
609380  93.710  -55.249  55.331  1
609381  93.730  -55.273  55.319  1
609382  93.751  -55.298  55.307  1
609383  93.771  -55.322  55.294  1
609384  93.791  -55.346  55.278  1
609385  93.812  -55.370  55.260  1
609386  93.832  -55.395  55.238  1
609387  93.852  -55.418  55.219  1
609388  93.872  -55.442  55.199  1
609389  93.893  -55.467  55.177  1
609390  93.913  -55.491  55.151  1
609391  93.933  -55.515  55.123  1
609392  93.953  -55.539  55.093  1
609393  93.973  -55.563  55.060  1
609394  93.995  -55.583  55.023  1
609395  94.020  -55.600  54.983  1
609396  94.044  -55.617  54.942  1
609397  94.076  -55.630  54.901  1
609398  94.109  -55.642  54.859  1
609399  94.142  -55.653  54.819  1
609400  94.173  -55.662  54.779  1
609401  94.203  -55.671  54.738  1
609402  94.234  -55.680  54.697  1
609403  94.264  -55.690  54.656  1
609404  94.294  -55.698  54.610  1
609405  94.325  -55.707  54.566  1
609406  94.355  -55.716  54.525  1
609407  94.386  -55.725  54.487  1
609408  94.416  -55.734  54.453  1
609409  94.458  -55.745  54.423  1
609410  94.508  -55.758  54.389  1
609411  94.557  -55.771  54.362  1
609412  94.607  -55.783  54.344  1
609413  94.657  -55.796  54.332  1
609414  94.706  -55.809  54.323  1
609415  94.755  -55.821  54.313  1
609416  94.803  -55.834  54.289  1
609417  94.834  -55.844  54.259  1
609418  94.862  -55.854  54.220  1
609419  94.891  -55.864  54.171  1
609420  94.921  -55.871  54.114  1
609421  94.953  -55.876  54.052  1
609422  94.984  -55.882  53.978  1
609423  95.016  -55.887  53.906  1
609424  95.047  -55.893  53.834  1
609425  95.078  -55.898  53.764  1
609426  95.110  -55.903  53.697  1
609427  95.141  -55.909  53.632  1
609428  95.163  -55.925  53.566  1
609429  95.182  -55.944  53.495  1
609430  95.206  -55.960  53.418  1
609431  95.238  -55.972  53.340  1
609432  95.271  -55.984  53.263  1
609433  95.303  -55.996  53.186  1
609434  95.336  -56.008  53.112  1
609435  95.368  -56.020  53.040  1
609436  95.401  -56.031  52.970  1
609437  95.436  -56.043  52.902  1
609438  95.471  -56.054  52.835  1
609439  95.505  -56.066  52.770  1
609440  95.540  -56.078  52.707  1
609441  95.574  -56.089  52.645  1
609442  95.609  -56.100  52.584  1
609443  95.642  -56.113  52.525  1
609444  95.669  -56.132  52.467  1
609445  95.695  -56.151  52.409  1
609446  95.722  -56.170  52.353  1
609447  95.749  -56.189  52.297  1
609448  95.775  -56.208  52.241  1
609449  95.802  -56.227  52.185  1
609450  95.828  -56.246  52.127  1
609451  95.855  -56.265  52.068  1
609452  95.884  -56.272  52.007  1
609453  95.916  -56.274  51.943  1
609454  95.948  -56.276  51.881  1
609455  95.980  -56.278  51.817  1
609456  96.012  -56.280  51.753  1
609457  96.043  -56.282  51.692  1
609458  96.076  -56.284  51.635  1
609459  96.107  -56.286  51.580  1
609460  96.139  -56.288  51.527  1
609461  96.171  -56.290  51.475  1
609462  96.202  -56.292  51.425  1
609463  96.235  -56.294  51.378  1
609464  96.266  -56.296  51.336  1
609465  96.298  -56.298  51.296  1
609466  96.330  -56.300  51.257  1
609467  96.349  -56.301  51.219  1
609468  96.365  -56.303  51.182  1
609469  96.380  -56.304  51.148  1
609470  96.396  -56.304  51.118  1
609471  96.411  -56.306  51.087  1
609472  96.427  -56.307  51.057  1
609473  96.442  -56.308  51.026  1
609474  96.458  -56.309  50.995  1
609475  96.473  -56.310  50.965  1
609476  96.488  -56.311  50.938  1
609477  96.504  -56.313  50.910  1
609478  96.516  -56.313  50.882  1
609479  96.529  -56.315  50.853  1
609480  96.541  -56.317  50.823  1
609481  96.553  -56.317  50.796  1
609482  96.566  -56.319  50.771  1
609483  96.578  -56.320  50.746  1
609484  96.591  -56.321  50.719  1
609485  96.603  -56.323  50.690  1
609486  96.615  -56.323  50.661  1
609487  96.637  -56.329  50.633  1
609488  96.663  -56.329  50.607  1
609489  96.705  -56.327  50.582  1
609490  96.739  -56.326  50.558  1
609491  96.772  -56.325  50.534  1
609492  96.806  -56.324  50.508  1
609493  96.840  -56.323  50.484  1
609494  96.874  -56.322  50.462  1
609495  96.907  -56.321  50.440  1
609496  96.941  -56.320  50.419  1
609497  96.975  -56.319  50.398  1
609498  97.009  -56.317  50.377  1
609499  97.042  -56.317  50.358  1
609500  97.076  -56.315  50.341  1
609501  97.110  -56.314  50.326  1
609502  97.144  -56.313  50.311  1
609503  97.177  -56.312  50.295  1
609504  97.212  -56.311  50.281  1
609505  97.246  -56.310  50.268  1
609506  97.282  -56.309  50.255  1
609507  97.316  -56.308  50.242  1
609508  97.351  -56.307  50.230  1
609509  97.386  -56.306  50.217  1
609510  97.421  -56.305  50.205  1
609511  97.456  -56.304  50.195  1
609512  97.491  -56.303  50.185  1
609513  97.526  -56.301  50.174  1
609514  97.561  -56.301  50.165  1
609515  97.596  -56.300  50.157  1
609516  97.631  -56.298  50.149  1
609517  97.666  -56.298  50.141  1
609518  97.700  -56.297  50.134  1
609519  97.736  -56.303  50.125  1
609520  97.777  -56.311  50.114  1
609521  97.817  -56.320  50.106  1
609522  97.858  -56.329  50.100  1
609523  97.898  -56.337  50.094  1
609524  97.938  -56.345  50.087  1
609525  97.979  -56.354  50.078  1
609526  98.019  -56.363  50.070  1
609527  98.060  -56.371  50.061  1
609528  98.100  -56.379  50.049  1
609529  98.141  -56.389  50.035  1
609530  98.181  -56.397  50.019  1
609531  98.221  -56.405  50.001  1
609532  98.262  -56.414  49.980  1
609533  98.302  -56.423  49.957  1
609534  98.343  -56.431  49.933  1
609535  98.383  -56.439  49.907  1
609536  98.417  -56.447  49.880  1
609537  98.452  -56.454  49.852  1
609538  98.486  -56.461  49.823  1
609539  98.521  -56.469  49.794  1
609540  98.556  -56.476  49.764  1
609541  98.590  -56.483  49.735  1
609542  98.625  -56.491  49.705  1
609543  98.659  -56.498  49.675  1
609544  98.694  -56.505  49.647  1
609545  98.728  -56.513  49.619  1
609546  98.763  -56.520  49.592  1
609547  98.797  -56.527  49.567  1
609548  98.832  -56.535  49.543  1
609549  98.866  -56.542  49.519  1
609550  98.901  -56.549  49.496  1
609551  98.935  -56.557  49.474  1
609552  98.970  -56.564  49.452  1
609553  99.004  -56.571  49.429  1
609554  99.039  -56.579  49.406  1
609555  99.073  -56.586  49.384  1
609556  99.108  -56.593  49.362  1
609557  99.142  -56.601  49.341  1
609558  99.177  -56.608  49.321  1
609559  99.211  -56.615  49.304  1
609560  99.245  -56.623  49.289  1
609561  99.280  -56.630  49.274  1
609562  99.314  -56.637  49.258  1
609563  99.349  -56.645  49.244  1
609564  99.383  -56.652  49.229  1
609565  99.418  -56.659  49.213  1
609566  99.452  -56.667  49.199  1
609567  99.482  -56.669  49.183  1
609568  99.508  -56.682  49.166  1
609569  99.535  -56.700  49.149  1
609570  99.568  -56.716  49.131  1
609571  99.600  -56.731  49.113  1
609572  99.626  -56.740  49.093  1
609573  99.653  -56.751  49.072  1
609574  99.681  -56.768  49.050  1
609575  99.709  -56.785  49.027  1
609576  99.736  -56.802  49.003  1
609577  99.764  -56.820  48.979  1
609578  99.792  -56.837  48.955  1
609579  99.820  -56.854  48.930  1
609580  99.848  -56.871  48.905  1
609581  99.875  -56.888  48.881  1
609582  99.904  -56.906  48.855  1
609583  99.931  -56.923  48.833  1
609584  99.959  -56.940  48.810  1
609926  88.798  -52.740  57.372  4
609927  88.830  -52.763  57.370  4
609928  88.861  -52.785  57.368  4
609929  88.893  -52.808  57.365  4
609930  88.924  -52.831  57.361  4
609931  88.956  -52.854  57.358  4
609932  88.988  -52.876  57.353  4
609933  89.020  -52.899  57.349  4
609934  89.051  -52.922  57.344  4
609935  89.083  -52.944  57.339  4
609936  89.115  -52.967  57.334  4
609937  89.146  -52.990  57.329  4
609938  89.178  -53.013  57.324  4
609939  89.209  -53.035  57.319  4
609940  89.241  -53.057  57.315  4
609941  89.273  -53.080  57.311  4
609942  89.305  -53.103  57.306  4
609943  89.336  -53.126  57.302  4
609944  89.368  -53.148  57.297  4
609945  89.399  -53.171  57.292  4
609946  89.425  -53.201  57.287  4
609947  89.448  -53.233  57.282  4
609948  89.470  -53.266  57.277  4
609949  89.507  -53.279  57.271  4
609950  89.545  -53.290  57.265  4
609951  89.579  -53.303  57.260  4
609952  89.602  -53.321  57.250  4
609953  89.625  -53.338  57.238  4
609954  89.649  -53.355  57.225  4
609955  89.676  -53.374  57.212  4
609956  89.717  -53.402  57.198  4
609957  89.758  -53.429  57.185  4
609958  89.799  -53.455  57.172  4
609959  89.837  -53.480  57.158  4
609960  89.857  -53.483  57.143  4
609961  89.875  -53.485  57.126  4
609962  89.894  -53.488  57.106  4
609963  89.913  -53.491  57.086  4
609964  89.934  -53.496  57.065  4
609965  89.959  -53.508  57.043  4
609966  89.984  -53.520  57.019  4
609967  90.015  -53.535  56.990  4
609968  90.049  -53.552  56.957  4
609969  90.084  -53.570  56.922  4
609970  90.118  -53.587  56.885  4
609971  90.161  -53.599  56.849  4
609972  90.204  -53.610  56.814  4
609973  90.247  -53.621  56.778  4
609974  90.291  -53.633  56.739  4
609975  90.333  -53.644  56.702  4
609976  90.377  -53.655  56.666  4
609977  90.420  -53.666  56.632  4
609978  90.463  -53.678  56.600  4
609985  90.603  -53.812  56.169  1
609986  90.633  -53.820  56.134  1
609987  90.668  -53.822  56.101  1
609988  90.704  -53.824  56.070  1
609989  90.739  -53.825  56.040  1
609990  90.775  -53.828  56.011  1
609991  90.806  -53.842  55.982  1
609992  90.835  -53.862  55.954  1
609993  90.864  -53.882  55.926  1
609994  90.893  -53.902  55.899  1
609995  90.922  -53.922  55.872  1
609996  90.951  -53.942  55.846  1
609997  90.979  -53.963  55.821  1
609998  91.009  -53.983  55.795  1
609999  91.037  -54.003  55.771  1
610000  91.067  -54.023  55.747  1
610001  91.095  -54.043  55.726  1
610002  91.127  -54.063  55.705  1
610003  91.160  -54.083  55.686  1
610004  91.193  -54.103  55.669  1
610005  91.227  -54.123  55.654  1
610006  91.260  -54.143  55.640  1
610007  91.293  -54.163  55.630  1
610008  91.326  -54.182  55.622  1
610009  91.360  -54.202  55.617  1
610010  91.393  -54.222  55.616  1
610011  91.427  -54.242  55.618  1
610012  91.460  -54.262  55.617  1
610013  91.493  -54.282  55.616  1
610014  91.536  -54.294  55.611  1
610015  91.589  -54.299  55.600  1
610016  91.642  -54.305  55.582  1
610017  91.695  -54.310  55.557  1
610018  91.747  -54.315  55.527  1
610019  91.788  -54.324  55.500  1
610020  91.823  -54.336  55.478  1
610021  91.860  -54.347  55.459  1
610022  91.895  -54.358  55.442  1
610023  91.931  -54.369  55.426  1
610024  91.967  -54.380  55.411  1
610025  92.003  -54.391  55.396  1
610026  92.039  -54.402  55.381  1
610027  92.075  -54.414  55.369  1
610028  92.111  -54.425  55.358  1
610029  92.147  -54.436  55.347  1
610030  92.183  -54.447  55.336  1
610031  92.219  -54.458  55.325  1
610032  92.254  -54.469  55.315  1
610033  92.291  -54.480  55.308  1
610034  92.326  -54.492  55.302  1
610035  92.363  -54.502  55.296  1
610036  92.399  -54.514  55.291  1
610037  92.437  -54.527  55.286  1
610038  92.476  -54.539  55.282  1
610039  92.514  -54.552  55.282  1
610040  92.553  -54.564  55.284  1
610041  92.591  -54.576  55.287  1
610042  92.630  -54.589  55.292  1
610043  92.668  -54.601  55.299  1
610044  92.704  -54.617  55.311  1
610045  92.727  -54.643  55.328  1
610046  92.754  -54.662  55.346  1
610047  92.781  -54.679  55.364  1
610048  92.808  -54.696  55.380  1
610049  92.835  -54.714  55.396  1
610050  92.862  -54.732  55.412  1
610051  92.887  -54.745  55.430  1
610052  92.912  -54.759  55.449  1
610053  92.937  -54.772  55.467  1
610054  92.961  -54.786  55.483  1
610055  92.986  -54.800  55.497  1
610056  93.011  -54.813  55.509  1
610057  93.036  -54.827  55.521  1
610058  93.061  -54.843  55.529  1
610059  93.087  -54.861  55.531  1
610060  93.113  -54.879  55.525  1
610061  93.139  -54.897  55.514  1
610062  93.166  -54.916  55.499  1
610063  93.202  -54.934  55.486  1
610064  93.237  -54.951  55.477  1
610065  93.273  -54.969  55.469  1
610066  93.308  -54.988  55.459  1
610067  93.344  -55.005  55.455  1
610068  93.379  -55.023  55.463  1
610069  93.415  -55.041  55.478  1
610070  93.445  -55.057  55.490  1
610071  93.471  -55.071  55.495  1
610072  93.496  -55.085  55.492  1
610073  93.521  -55.099  55.484  1
610074  93.546  -55.113  55.466  1
610075  93.571  -55.126  55.445  1
610076  93.596  -55.140  55.425  1
610077  93.621  -55.154  55.406  1
610078  93.646  -55.168  55.387  1
610079  93.672  -55.182  55.370  1
610080  93.697  -55.195  55.358  1
610081  93.718  -55.217  55.346  1
610082  93.739  -55.241  55.335  1
610083  93.759  -55.265  55.323  1
610084  93.779  -55.289  55.310  1
610085  93.799  -55.313  55.296  1
610086  93.820  -55.337  55.280  1
610087  93.840  -55.361  55.261  1
610088  93.860  -55.386  55.242  1
610089  93.880  -55.410  55.223  1
610090  93.900  -55.433  55.202  1
610091  93.920  -55.458  55.178  1
610092  93.941  -55.482  55.151  1
610093  93.961  -55.506  55.116  1
610094  93.981  -55.530  55.081  1
610095  94.005  -55.547  55.044  1
610096  94.030  -55.564  55.003  1
610097  94.054  -55.580  54.960  1
610098  94.085  -55.594  54.922  1
610099  94.118  -55.605  54.881  1
610100  94.150  -55.618  54.840  1
610101  94.183  -55.629  54.798  1
610102  94.213  -55.638  54.755  1
610103  94.244  -55.646  54.713  1
610104  94.274  -55.655  54.668  1
610105  94.305  -55.665  54.622  1
610106  94.335  -55.674  54.577  1
610107  94.366  -55.682  54.535  1
610108  94.396  -55.691  54.497  1
610109  94.427  -55.700  54.462  1
610110  94.471  -55.712  54.433  1
610111  94.521  -55.724  54.402  1
610112  94.570  -55.737  54.376  1
610113  94.620  -55.750  54.357  1
610114  94.670  -55.762  54.342  1
610115  94.719  -55.775  54.331  1
610116  94.768  -55.788  54.320  1
610117  94.808  -55.801  54.294  1
610118  94.841  -55.812  54.265  1
610119  94.870  -55.821  54.226  1
610120  94.898  -55.831  54.180  1
610121  94.926  -55.841  54.125  1
610122  94.954  -55.851  54.062  1
610123  94.982  -55.860  53.989  1
610124  95.011  -55.870  53.917  1
610125  95.039  -55.880  53.848  1
610126  95.067  -55.890  53.782  1
610127  95.099  -55.895  53.717  1
610128  95.130  -55.900  53.652  1
610129  95.162  -55.906  53.586  1
610130  95.183  -55.922  53.517  1
610131  95.213  -55.935  53.443  1
610132  95.246  -55.947  53.365  1
610133  95.278  -55.959  53.285  1
610134  95.311  -55.972  53.204  1
610135  95.343  -55.984  53.126  1
610136  95.376  -55.996  53.052  1
610137  95.408  -56.007  52.980  1
610138  95.443  -56.019  52.909  1
610139  95.477  -56.031  52.841  1
610140  95.512  -56.042  52.774  1
610141  95.546  -56.053  52.710  1
610142  95.581  -56.065  52.648  1
610143  95.615  -56.076  52.586  1
610144  95.643  -56.094  52.525  1
610145  95.670  -56.113  52.466  1
610146  95.697  -56.132  52.407  1
610147  95.724  -56.151  52.351  1
610148  95.750  -56.170  52.294  1
610149  95.777  -56.189  52.238  1
610150  95.804  -56.208  52.182  1
610151  95.832  -56.224  52.127  1
610152  95.865  -56.238  52.071  1
610153  95.898  -56.251  52.014  1
610154  95.930  -56.252  51.948  1
610155  95.962  -56.254  51.883  1
610156  95.994  -56.257  51.818  1
610157  96.026  -56.258  51.753  1
610158  96.057  -56.260  51.691  1
610159  96.089  -56.262  51.631  1
610160  96.121  -56.264  51.575  1
610161  96.153  -56.266  51.520  1
610162  96.185  -56.268  51.467  1
610163  96.217  -56.270  51.416  1
610164  96.249  -56.273  51.367  1
610165  96.281  -56.274  51.323  1
610166  96.312  -56.276  51.282  1
610167  96.344  -56.279  51.242  1
610168  96.360  -56.279  51.202  1
610169  96.375  -56.280  51.164  1
610170  96.391  -56.282  51.128  1
610171  96.406  -56.282  51.096  1
610172  96.421  -56.284  51.065  1
610173  96.437  -56.285  51.033  1
610174  96.453  -56.286  51.001  1
610175  96.468  -56.287  50.969  1
610176  96.483  -56.288  50.939  1
610177  96.499  -56.289  50.910  1
610178  96.512  -56.291  50.882  1
610179  96.524  -56.291  50.854  1
610180  96.536  -56.293  50.824  1
610181  96.549  -56.295  50.794  1
610182  96.561  -56.295  50.765  1
610183  96.574  -56.297  50.739  1
610184  96.586  -56.298  50.714  1
610185  96.598  -56.299  50.686  1
610186  96.611  -56.301  50.658  1
610187  96.623  -56.302  50.631  1
610188  96.636  -56.303  50.604  1
610189  96.668  -56.302  50.578  1
610190  96.703  -56.301  50.551  1
610191  96.738  -56.301  50.527  1
610192  96.772  -56.299  50.502  1
610193  96.808  -56.298  50.477  1
610194  96.842  -56.298  50.453  1
610195  96.878  -56.296  50.430  1
610196  96.912  -56.295  50.409  1
610197  96.948  -56.295  50.387  1
610198  96.982  -56.293  50.366  1
610199  97.018  -56.292  50.344  1
610200  97.052  -56.291  50.325  1
610201  97.088  -56.290  50.308  1
610202  97.122  -56.289  50.291  1
610203  97.158  -56.288  50.275  1
610204  97.192  -56.287  50.260  1
610205  97.227  -56.286  50.244  1
610206  97.262  -56.285  50.231  1
610207  97.297  -56.284  50.218  1
610208  97.332  -56.282  50.205  1
610209  97.367  -56.282  50.192  1
610210  97.402  -56.281  50.179  1
610211  97.437  -56.279  50.167  1
610212  97.472  -56.279  50.155  1
610213  97.507  -56.278  50.144  1
610214  97.542  -56.276  50.133  1
610215  97.577  -56.276  50.124  1
610216  97.612  -56.275  50.114  1
610217  97.647  -56.273  50.104  1
610218  97.682  -56.273  50.095  1
610219  97.709  -56.271  50.088  1
610220  97.749  -56.280  50.079  1
610221  97.790  -56.288  50.070  1
610222  97.830  -56.297  50.062  1
610223  97.871  -56.305  50.055  1
610224  97.911  -56.314  50.048  1
610225  97.952  -56.323  50.041  1
610226  97.992  -56.331  50.033  1
610227  98.032  -56.340  50.025  1
610228  98.073  -56.348  50.015  1
610229  98.113  -56.357  50.004  1
610230  98.154  -56.365  49.990  1
610231  98.194  -56.374  49.974  1
610232  98.235  -56.382  49.955  1
610233  98.275  -56.391  49.935  1
610234  98.315  -56.399  49.913  1
610235  98.356  -56.408  49.889  1
610236  98.393  -56.416  49.864  1
610237  98.428  -56.423  49.837  1
610238  98.462  -56.430  49.808  1
610239  98.497  -56.438  49.780  1
610240  98.531  -56.445  49.751  1
610241  98.566  -56.452  49.721  1
610242  98.600  -56.460  49.691  1
610243  98.635  -56.467  49.661  1
610244  98.669  -56.474  49.632  1
610245  98.704  -56.482  49.603  1
610246  98.738  -56.489  49.575  1
610247  98.773  -56.496  49.548  1
610248  98.807  -56.504  49.522  1
610249  98.842  -56.511  49.498  1
610250  98.876  -56.518  49.475  1
610251  98.911  -56.526  49.451  1
610252  98.945  -56.533  49.428  1
610253  98.980  -56.540  49.406  1
610254  99.014  -56.548  49.383  1
610255  99.049  -56.555  49.361  1
610256  99.083  -56.562  49.339  1
610257  99.118  -56.570  49.318  1
610258  99.152  -56.577  49.298  1
610259  99.187  -56.584  49.279  1
610260  99.221  -56.592  49.262  1
610261  99.256  -56.599  49.247  1
610262  99.290  -56.606  49.233  1
610263  99.325  -56.614  49.219  1
610264  99.359  -56.621  49.205  1
610265  99.394  -56.628  49.191  1
610266  99.428  -56.636  49.177  1
610267  99.458  -56.639  49.163  1
610268  99.484  -56.646  49.148  1
610269  99.509  -56.664  49.133  1
610270  99.539  -56.682  49.118  1
610271  99.572  -56.698  49.101  1
610272  99.602  -56.711  49.084  1
610273  99.628  -56.720  49.066  1
610274  99.655  -56.730  49.046  1
610275  99.683  -56.747  49.026  1
610276  99.710  -56.764  49.005  1
610277  99.738  -56.781  48.982  1
610278  99.766  -56.799  48.960  1
610279  99.794  -56.815  48.937  1
610280  99.822  -56.833  48.914  1
610281  99.850  -56.850  48.890  1
610282  99.877  -56.867  48.866  1
610283  99.905  -56.884  48.842  1
610284  99.933  -56.902  48.820  1
610628  88.846  -52.739  57.362  4
610629  88.878  -52.762  57.360  4
610630  88.909  -52.784  57.357  4
610631  88.941  -52.807  57.352  4
610632  88.972  -52.829  57.348  4
610633  89.004  -52.852  57.344  4
610634  89.036  -52.875  57.339  4
610635  89.067  -52.897  57.335  4
610636  89.099  -52.920  57.330  4
610637  89.131  -52.943  57.325  4
610638  89.162  -52.966  57.320  4
610639  89.194  -52.988  57.315  4
610640  89.226  -53.011  57.310  4
610641  89.257  -53.034  57.306  4
610642  89.289  -53.057  57.302  4
610643  89.321  -53.079  57.298  4
610644  89.352  -53.102  57.294  4
610645  89.384  -53.125  57.290  4
610646  89.415  -53.147  57.286  4
610647  89.440  -53.178  57.282  4
610648  89.463  -53.211  57.277  4
610649  89.492  -53.233  57.272  4
610650  89.531  -53.244  57.266  4
610651  89.564  -53.257  57.259  4
610652  89.588  -53.274  57.254  4
610653  89.611  -53.292  57.245  4
610654  89.634  -53.309  57.233  4
610655  89.658  -53.327  57.220  4
610656  89.686  -53.347  57.207  4
610657  89.728  -53.374  57.194  4
610658  89.768  -53.401  57.182  4
610659  89.810  -53.427  57.169  4
610660  89.851  -53.455  57.155  4
610661  89.885  -53.474  57.141  4
610662  89.904  -53.477  57.125  4
610663  89.923  -53.480  57.106  4
610664  89.942  -53.483  57.086  4
610665  89.961  -53.485  57.066  4
610666  89.979  -53.488  57.046  4
610667  90.001  -53.495  57.024  4
610668  90.026  -53.506  56.998  4
610669  90.058  -53.523  56.967  4
610670  90.093  -53.540  56.931  4
610671  90.133  -53.554  56.896  4
610672  90.176  -53.565  56.861  4
610673  90.219  -53.576  56.827  4
610674  90.262  -53.587  56.791  4
610675  90.306  -53.599  56.753  4
610676  90.349  -53.610  56.716  4
610677  90.392  -53.621  56.679  4
610678  90.436  -53.632  56.645  4
610679  90.478  -53.643  56.613  4
610680  90.508  -53.659  56.580  4
610687  90.655  -53.773  56.144  1
610688  90.691  -53.775  56.110  1
610689  90.727  -53.777  56.078  1
610690  90.762  -53.778  56.048  1
610691  90.796  -53.785  56.019  1
610692  90.825  -53.805  55.989  1
610693  90.854  -53.825  55.959  1
610694  90.883  -53.845  55.931  1
610695  90.912  -53.866  55.903  1
610696  90.941  -53.886  55.876  1
610697  90.970  -53.906  55.850  1
610698  90.999  -53.926  55.823  1
610699  91.028  -53.946  55.797  1
610700  91.057  -53.966  55.772  1
610701  91.086  -53.987  55.749  1
610702  91.118  -54.007  55.727  1
610703  91.151  -54.026  55.707  1
610704  91.184  -54.046  55.688  1
610705  91.218  -54.066  55.671  1
610706  91.251  -54.086  55.655  1
610707  91.285  -54.106  55.641  1
610708  91.318  -54.126  55.630  1
610709  91.351  -54.145  55.622  1
610710  91.384  -54.166  55.615  1
610711  91.418  -54.185  55.612  1
610712  91.451  -54.205  55.611  1
610713  91.485  -54.225  55.609  1
610714  91.518  -54.245  55.607  1
610715  91.558  -54.260  55.602  1
610716  91.611  -54.264  55.591  1
610717  91.663  -54.270  55.574  1
610718  91.716  -54.275  55.550  1
610719  91.763  -54.283  55.522  1
610720  91.799  -54.294  55.496  1
610721  91.835  -54.305  55.474  1
610722  91.871  -54.316  55.456  1
610723  91.907  -54.327  55.440  1
610724  91.942  -54.338  55.424  1
610725  91.979  -54.349  55.409  1
610726  92.014  -54.361  55.395  1
610727  92.050  -54.371  55.381  1
610728  92.086  -54.383  55.368  1
610729  92.122  -54.394  55.357  1
610730  92.158  -54.405  55.346  1
610731  92.194  -54.416  55.335  1
610733  92.266  -54.439  55.314  1
610734  92.303  -54.450  55.307  1
610735  92.342  -54.463  55.301  1
610736  92.380  -54.475  55.295  1
610737  92.419  -54.488  55.291  1
610738  92.457  -54.500  55.286  1
610739  92.496  -54.513  55.282  1
610740  92.534  -54.525  55.282  1
610741  92.573  -54.537  55.285  1
610742  92.611  -54.550  55.288  1
610743  92.649  -54.562  55.293  1
610744  92.688  -54.575  55.300  1
610745  92.726  -54.587  55.311  1
610746  92.749  -54.616  55.325  1
610747  92.774  -54.640  55.341  1
610748  92.801  -54.657  55.358  1
610749  92.829  -54.674  55.373  1
610750  92.855  -54.692  55.387  1
610751  92.882  -54.710  55.404  1
610752  92.907  -54.724  55.421  1
610753  92.932  -54.737  55.438  1
610754  92.957  -54.751  55.454  1
610755  92.982  -54.765  55.469  1
610756  93.006  -54.778  55.481  1
610757  93.031  -54.791  55.491  1
610758  93.056  -54.805  55.500  1
610759  93.081  -54.818  55.506  1
610760  93.106  -54.835  55.507  1
610761  93.132  -54.853  55.499  1
610762  93.158  -54.871  55.489  1
610763  93.184  -54.889  55.477  1
610764  93.217  -54.907  55.467  1
610765  93.253  -54.925  55.463  1
610766  93.288  -54.943  55.461  1
610767  93.324  -54.961  55.462  1
610768  93.360  -54.979  55.472  1
610769  93.395  -54.997  55.488  1
610770  93.427  -55.013  55.502  1
610771  93.452  -55.027  55.510  1
610772  93.477  -55.041  55.510  1
610773  93.502  -55.055  55.502  1
610774  93.528  -55.069  55.489  1
610775  93.552  -55.082  55.473  1
610776  93.577  -55.097  55.456  1
610777  93.603  -55.110  55.438  1
610778  93.628  -55.124  55.419  1
610779  93.653  -55.138  55.402  1
610780  93.678  -55.151  55.385  1
610781  93.703  -55.166  55.372  1
610782  93.726  -55.183  55.360  1
610783  93.747  -55.207  55.348  1
610784  93.767  -55.232  55.335  1
610785  93.787  -55.256  55.323  1
610786  93.807  -55.280  55.310  1
610787  93.827  -55.304  55.296  1
610788  93.847  -55.328  55.278  1
610789  93.868  -55.352  55.260  1
610790  93.888  -55.376  55.241  1
610791  93.908  -55.401  55.220  1
610792  93.928  -55.425  55.198  1
610793  93.948  -55.449  55.169  1
610794  93.969  -55.473  55.134  1
610795  93.991  -55.495  55.096  1
610796  94.015  -55.511  55.056  1
610797  94.039  -55.527  55.014  1
610798  94.063  -55.544  54.972  1
610799  94.094  -55.558  54.935  1
610800  94.126  -55.570  54.893  1
610801  94.159  -55.582  54.852  1
610802  94.192  -55.593  54.810  1
610803  94.224  -55.604  54.767  1
610804  94.255  -55.613  54.722  1
610805  94.285  -55.622  54.677  1
610806  94.316  -55.630  54.630  1
610807  94.346  -55.640  54.586  1
610808  94.377  -55.649  54.544  1
610809  94.407  -55.658  54.505  1
610810  94.437  -55.666  54.472  1
610811  94.484  -55.679  54.444  1
610812  94.534  -55.691  54.416  1
610813  94.583  -55.704  54.393  1
610814  94.633  -55.717  54.373  1
610815  94.683  -55.729  54.355  1
610816  94.732  -55.742  54.339  1
610817  94.773  -55.755  54.323  1
610818  94.813  -55.768  54.296  1
610819  94.848  -55.779  54.266  1
610820  94.876  -55.789  54.228  1
610821  94.905  -55.799  54.182  1
610822  94.933  -55.809  54.129  1
610823  94.961  -55.818  54.068  1
610824  94.989  -55.828  53.996  1
610825  95.018  -55.837  53.927  1
610826  95.046  -55.847  53.862  1
610827  95.074  -55.857  53.798  1
610828  95.103  -55.867  53.733  1
610829  95.131  -55.877  53.667  1
610830  95.160  -55.887  53.600  1
610831  95.188  -55.899  53.531  1
610832  95.221  -55.911  53.459  1
610833  95.254  -55.923  53.382  1
610834  95.286  -55.935  53.303  1
610835  95.318  -55.947  53.221  1
610836  95.351  -55.959  53.141  1
610837  95.383  -55.971  53.066  1
610838  95.416  -55.983  52.992  1
610839  95.449  -55.995  52.921  1
610840  95.484  -56.006  52.851  1
610841  95.519  -56.018  52.781  1
610842  95.553  -56.029  52.717  1
610843  95.588  -56.041  52.653  1
610844  95.618  -56.056  52.589  1
610845  95.645  -56.075  52.527  1
610846  95.672  -56.094  52.466  1
610847  95.698  -56.113  52.407  1
610848  95.725  -56.132  52.350  1
610849  95.752  -56.150  52.293  1
610850  95.780  -56.167  52.237  1
610851  95.812  -56.181  52.182  1
610852  95.843  -56.194  52.129  1
610853  95.877  -56.208  52.077  1
610854  95.911  -56.222  52.023  1
610855  95.944  -56.231  51.956  1
610856  95.976  -56.232  51.888  1
610857  96.008  -56.235  51.820  1
610858  96.040  -56.236  51.754  1
610859  96.072  -56.238  51.690  1
610860  96.103  -56.241  51.629  1
610861  96.135  -56.242  51.570  1
610862  96.167  -56.244  51.514  1
610863  96.199  -56.247  51.460  1
610864  96.231  -56.248  51.407  1
610865  96.262  -56.251  51.357  1
610866  96.295  -56.252  51.311  1
610867  96.326  -56.254  51.268  1
610868  96.355  -56.257  51.227  1
610869  96.370  -56.257  51.186  1
610870  96.386  -56.258  51.146  1
610871  96.401  -56.260  51.109  1
610872  96.416  -56.260  51.075  1
610873  96.432  -56.262  51.043  1
610874  96.448  -56.263  51.010  1
610875  96.463  -56.264  50.977  1
610876  96.478  -56.265  50.945  1
610877  96.493  -56.266  50.913  1
610878  96.507  -56.267  50.883  1
610879  96.519  -56.269  50.854  1
610880  96.532  -56.270  50.825  1
610881  96.544  -56.271  50.795  1
610882  96.556  -56.273  50.764  1
610883  96.569  -56.273  50.735  1
610884  96.581  -56.275  50.708  1
610885  96.594  -56.276  50.681  1
610886  96.606  -56.277  50.653  1
610887  96.618  -56.279  50.625  1
610888  96.632  -56.279  50.598  1
610889  96.649  -56.279  50.571  1
610890  96.684  -56.277  50.546  1
610891  96.719  -56.276  50.521  1
610892  96.754  -56.276  50.496  1
610893  96.789  -56.274  50.471  1
610894  96.824  -56.273  50.446  1
610895  96.859  -56.272  50.422  1
610896  96.894  -56.271  50.400  1
610897  96.929  -56.270  50.378  1
610898  96.964  -56.269  50.356  1
610899  96.999  -56.268  50.334  1
610900  97.034  -56.267  50.312  1
610901  97.069  -56.266  50.292  1
610902  97.103  -56.265  50.275  1
610903  97.139  -56.264  50.258  1
610904  97.173  -56.263  50.241  1
610905  97.209  -56.262  50.225  1
610906  97.243  -56.260  50.209  1
610907  97.279  -56.260  50.195  1
610908  97.313  -56.259  50.182  1
610909  97.349  -56.257  50.168  1
610910  97.383  -56.257  50.154  1
610911  97.419  -56.256  50.140  1
610912  97.453  -56.254  50.128  1
610913  97.489  -56.254  50.116  1
610914  97.523  -56.253  50.105  1
610915  97.558  -56.251  50.093  1
610916  97.593  -56.251  50.083  1
610917  97.628  -56.249  50.072  1
610918  97.663  -56.248  50.061  1
610919  97.693  -56.248  50.053  1
610920  97.722  -56.248  50.044  1
610921  97.762  -56.257  50.035  1
610922  97.803  -56.266  50.027  1
610923  97.844  -56.274  50.019  1
610924  97.884  -56.282  50.011  1
610925  97.925  -56.291  50.004  1
610926  97.965  -56.300  49.997  1
610927  98.005  -56.308  49.989  1
610928  98.045  -56.317  49.980  1
610929  98.086  -56.326  49.970  1
610930  98.127  -56.334  49.958  1
610931  98.167  -56.342  49.944  1
610932  98.208  -56.351  49.929  1
610933  98.248  -56.360  49.911  1
610934  98.288  -56.368  49.891  1
610935  98.329  -56.376  49.869  1
610936  98.369  -56.385  49.846  1
610937  98.403  -56.392  49.820  1
610938  98.438  -56.400  49.794  1
610939  98.472  -56.407  49.766  1
610940  98.507  -56.414  49.737  1
610941  98.541  -56.422  49.708  1
610942  98.576  -56.429  49.679  1
610943  98.610  -56.436  49.648  1
610944  98.645  -56.444  49.618  1
610945  98.679  -56.451  49.589  1
610946  98.714  -56.458  49.560  1
610947  98.748  -56.466  49.532  1
610948  98.783  -56.473  49.505  1
610949  98.817  -56.480  49.479  1
610950  98.852  -56.488  49.454  1
610951  98.886  -56.495  49.430  1
610952  98.921  -56.502  49.407  1
610953  98.955  -56.510  49.383  1
610954  98.990  -56.517  49.362  1
610955  99.024  -56.524  49.338  1
610956  99.059  -56.532  49.316  1
610957  99.093  -56.539  49.295  1
610958  99.128  -56.546  49.274  1
610959  99.162  -56.554  49.256  1
610960  99.197  -56.561  49.238  1
610961  99.231  -56.568  49.221  1
610962  99.266  -56.576  49.206  1
610963  99.300  -56.583  49.192  1
610964  99.335  -56.590  49.179  1
610965  99.369  -56.598  49.166  1
610966  99.404  -56.605  49.153  1
610967  99.434  -56.608  49.140  1
610968  99.461  -56.610  49.127  1
610969  99.486  -56.628  49.112  1
610970  99.511  -56.647  49.099  1
610971  99.543  -56.664  49.085  1
610972  99.575  -56.680  49.069  1
610973  99.604  -56.690  49.054  1
610974  99.630  -56.699  49.038  1
610975  99.656  -56.709  49.020  1
610976  99.685  -56.726  49.001  1
610977  99.712  -56.743  48.981  1
610978  99.740  -56.760  48.960  1
610979  99.768  -56.777  48.940  1
610980  99.796  -56.794  48.919  1
610981  99.824  -56.812  48.896  1
610982  99.851  -56.829  48.874  1
610983  99.879  -56.846  48.852  1
610984  99.907  -56.863  48.829  1
611330  88.894  -52.738  57.351  4
611331  88.925  -52.760  57.347  4
611332  88.957  -52.783  57.343  4
611333  88.988  -52.806  57.339  4
611334  89.020  -52.828  57.335  4
611335  89.052  -52.851  57.330  4
611336  89.084  -52.874  57.325  4
611337  89.115  -52.897  57.321  4
611338  89.147  -52.919  57.315  4
611339  89.179  -52.941  57.310  4
611340  89.210  -52.964  57.306  4
611341  89.242  -52.987  57.301  4
611342  89.273  -53.010  57.297  4
611343  89.305  -53.032  57.293  4
611344  89.337  -53.055  57.289  4
611345  89.369  -53.078  57.285  4
611346  89.400  -53.101  57.282  4
611347  89.432  -53.123  57.280  4
611348  89.455  -53.155  57.276  4
611349  89.478  -53.186  57.271  4
611350  89.517  -53.198  57.265  4
611351  89.550  -53.211  57.259  4
611352  89.574  -53.228  57.252  4
611353  89.597  -53.245  57.245  4
611354  89.620  -53.263  57.237  4
611355  89.644  -53.280  57.226  4
611356  89.667  -53.298  57.214  4
611357  89.697  -53.319  57.202  4
611358  89.738  -53.346  57.190  4
611359  89.779  -53.373  57.180  4
611360  89.820  -53.399  57.167  4
611361  89.862  -53.427  57.154  4
611362  89.902  -53.447  57.140  4
611363  89.927  -53.454  57.124  4
611364  89.948  -53.461  57.106  4
611365  89.968  -53.468  57.087  4
611366  89.989  -53.475  57.069  4
611367  90.008  -53.480  57.050  4
611368  90.027  -53.483  57.029  4
611369  90.046  -53.486  57.005  4
611370  90.068  -53.493  56.976  4
611371  90.105  -53.509  56.941  4
611372  90.148  -53.520  56.908  4
611373  90.191  -53.531  56.874  4
611374  90.235  -53.542  56.840  4
611375  90.278  -53.553  56.805  4
611376  90.321  -53.565  56.768  4
611377  90.364  -53.576  56.731  4
611378  90.407  -53.587  56.696  4
611379  90.451  -53.598  56.662  4
611380  90.494  -53.609  56.628  4
611381  90.515  -53.628  56.595  4
611388  90.678  -53.727  56.155  1
611389  90.714  -53.728  56.120  1
611390  90.750  -53.730  56.088  1
611391  90.786  -53.732  56.057  1
611392  90.816  -53.749  56.028  1
611393  90.845  -53.769  55.998  1
611394  90.874  -53.789  55.966  1
611395  90.902  -53.809  55.938  1
611396  90.932  -53.829  55.909  1
611397  90.960  -53.849  55.881  1
611398  90.990  -53.869  55.855  1
611399  91.018  -53.890  55.829  1
611400  91.047  -53.910  55.802  1
611401  91.076  -53.930  55.777  1
611402  91.109  -53.950  55.754  1
611403  91.143  -53.969  55.732  1
611404  91.176  -53.989  55.711  1
611405  91.209  -54.010  55.692  1
611406  91.243  -54.029  55.674  1
611407  91.276  -54.049  55.658  1
611408  91.309  -54.069  55.642  1
611409  91.343  -54.088  55.631  1
611410  91.376  -54.109  55.622  1
611411  91.409  -54.129  55.614  1
611412  91.442  -54.148  55.608  1
611413  91.476  -54.168  55.604  1
611414  91.509  -54.188  55.601  1
611415  91.542  -54.208  55.596  1
611416  91.580  -54.225  55.590  1
611417  91.633  -54.230  55.579  1
611418  91.685  -54.236  55.563  1
611419  91.738  -54.240  55.540  1
611420  91.774  -54.251  55.514  1
611421  91.810  -54.263  55.491  1
611422  91.846  -54.273  55.470  1
611423  91.882  -54.285  55.453  1
611424  91.918  -54.296  55.438  1
611425  91.954  -54.308  55.423  1
611426  91.990  -54.318  55.408  1
611427  92.025  -54.330  55.394  1
611428  92.062  -54.341  55.380  1
611429  92.097  -54.352  55.368  1
611430  92.133  -54.363  55.356  1
611431  92.169  -54.374  55.345  1
611438  92.439  -54.461  55.290  1
611439  92.477  -54.474  55.286  1
611440  92.515  -54.486  55.283  1
611441  92.554  -54.499  55.283  1
611442  92.592  -54.511  55.285  1
611443  92.631  -54.524  55.289  1
611444  92.669  -54.536  55.294  1
611445  92.708  -54.549  55.300  1
611446  92.746  -54.561  55.309  1
611447  92.772  -54.587  55.321  1
611448  92.795  -54.615  55.336  1
611449  92.821  -54.635  55.352  1
611450  92.848  -54.652  55.366  1
611451  92.875  -54.670  55.380  1
611452  92.903  -54.688  55.395  1
611453  92.928  -54.702  55.411  1
611454  92.952  -54.715  55.426  1
611455  92.977  -54.729  55.441  1
611456  93.002  -54.743  55.455  1
611457  93.026  -54.756  55.468  1
611458  93.051  -54.770  55.476  1
611459  93.076  -54.784  55.483  1
611460  93.101  -54.797  55.486  1
611461  93.126  -54.811  55.483  1
611462  93.151  -54.827  55.473  1
611463  93.177  -54.845  55.465  1
611464  93.203  -54.862  55.457  1
611465  93.233  -54.881  55.454  1
611466  93.269  -54.899  55.456  1
611467  93.304  -54.917  55.462  1
611468  93.340  -54.934  55.473  1
611469  93.375  -54.953  55.492  1
611470  93.408  -54.969  55.511  1
611471  93.433  -54.984  55.522  1
611472  93.459  -54.997  55.525  1
611473  93.484  -55.011  55.521  1
611474  93.509  -55.025  55.511  1
611475  93.534  -55.038  55.498  1
611476  93.559  -55.053  55.486  1
611477  93.584  -55.066  55.473  1
611478  93.609  -55.080  55.456  1
611479  93.634  -55.094  55.438  1
611480  93.659  -55.108  55.419  1
611481  93.684  -55.122  55.398  1
611482  93.709  -55.135  55.383  1
611483  93.734  -55.151  55.367  1
611484  93.754  -55.175  55.353  1
611485  93.774  -55.198  55.341  1
611486  93.794  -55.223  55.330  1
611487  93.815  -55.247  55.319  1
611488  93.835  -55.271  55.306  1
611489  93.855  -55.295  55.290  1
611490  93.875  -55.320  55.273  1
611491  93.896  -55.343  55.255  1
611492  93.916  -55.367  55.233  1
611493  93.936  -55.392  55.210  1
611494  93.957  -55.416  55.181  1
611495  93.977  -55.440  55.146  1
611496  94.000  -55.458  55.106  1
611497  94.025  -55.475  55.064  1
611498  94.049  -55.492  55.021  1
611499  94.073  -55.508  54.979  1
611500  94.102  -55.522  54.942  1
611501  94.135  -55.534  54.901  1
611502  94.168  -55.546  54.859  1
611503  94.201  -55.558  54.816  1
611504  94.234  -55.570  54.773  1
611505  94.265  -55.579  54.730  1
611506  94.295  -55.588  54.687  1
611507  94.326  -55.597  54.643  1
611508  94.356  -55.606  54.600  1
611509  94.387  -55.614  54.558  1
611510  94.417  -55.624  54.521  1
611511  94.448  -55.633  54.488  1
611512  94.497  -55.646  54.460  1
611513  94.547  -55.658  54.434  1
611514  94.597  -55.671  54.410  1
611515  94.646  -55.683  54.389  1
611516  94.696  -55.696  54.368  1
611517  94.739  -55.709  54.344  1
611518  94.779  -55.721  54.323  1
611519  94.819  -55.734  54.293  1
611520  94.855  -55.746  54.260  1
611521  94.883  -55.756  54.221  1
611522  94.911  -55.765  54.176  1
611523  94.940  -55.775  54.124  1
611524  94.968  -55.785  54.067  1
611525  94.996  -55.795  53.998  1
611526  95.025  -55.805  53.935  1
611527  95.053  -55.815  53.874  1
611528  95.082  -55.824  53.813  1
611529  95.110  -55.834  53.747  1
611530  95.138  -55.843  53.678  1
611531  95.167  -55.856  53.608  1
611532  95.196  -55.872  53.539  1
611533  95.228  -55.885  53.468  1
611534  95.261  -55.898  53.393  1
611535  95.294  -55.911  53.316  1
611536  95.326  -55.923  53.236  1
611537  95.358  -55.934  53.156  1
611538  95.391  -55.947  53.080  1
611539  95.423  -55.959  53.007  1
611540  95.456  -55.971  52.935  1
611541  95.490  -55.982  52.863  1
611542  95.525  -55.994  52.792  1
611543  95.559  -56.005  52.726  1
611544  95.593  -56.017  52.660  1
611545  95.620  -56.036  52.595  1
611546  95.647  -56.055  52.532  1
611547  95.673  -56.074  52.469  1
611548  95.700  -56.094  52.409  1
611549  95.729  -56.110  52.350  1
611550  95.760  -56.124  52.293  1
611551  95.791  -56.137  52.236  1
611552  95.822  -56.150  52.181  1
611553  95.855  -56.165  52.127  1
611554  95.890  -56.179  52.076  1
611555  95.924  -56.192  52.024  1
611556  95.958  -56.206  51.963  1
611557  95.990  -56.210  51.894  1
611558  96.022  -56.213  51.824  1
611559  96.054  -56.215  51.756  1
611560  96.086  -56.216  51.689  1
611561  96.117  -56.219  51.627  1
611562  96.149  -56.221  51.567  1
611563  96.181  -56.222  51.509  1
611564  96.213  -56.225  51.453  1
611565  96.245  -56.226  51.399  1
611566  96.276  -56.229  51.348  1
611567  96.309  -56.231  51.301  1
611568  96.340  -56.232  51.256  1
611569  96.365  -56.235  51.212  1
611570  96.381  -56.235  51.170  1
611571  96.396  -56.236  51.129  1
611572  96.411  -56.238  51.090  1
611573  96.427  -56.238  51.056  1
611574  96.443  -56.240  51.021  1
611575  96.458  -56.241  50.988  1
611576  96.473  -56.242  50.954  1
611577  96.488  -56.243  50.920  1
611578  96.503  -56.244  50.888  1
611579  96.515  -56.245  50.857  1
611580  96.527  -56.247  50.827  1
611581  96.539  -56.248  50.796  1
611582  96.552  -56.249  50.766  1
611583  96.565  -56.251  50.735  1
611584  96.577  -56.252  50.705  1
611585  96.589  -56.253  50.678  1
611586  96.601  -56.254  50.650  1
611587  96.614  -56.256  50.621  1
611588  96.630  -56.255  50.593  1
611589  96.647  -56.254  50.565  1
611590  96.665  -56.253  50.539  1
611591  96.700  -56.252  50.515  1
611592  96.735  -56.251  50.490  1
611593  96.770  -56.250  50.465  1
611594  96.805  -56.249  50.441  1
611595  96.840  -56.248  50.416  1
611596  96.875  -56.247  50.392  1
611597  96.910  -56.246  50.369  1
611598  96.945  -56.245  50.347  1
611599  96.980  -56.244  50.326  1
611600  97.015  -56.243  50.303  1
611601  97.049  -56.241  50.281  1
611602  97.085  -56.241  50.261  1
611603  97.119  -56.240  50.243  1
611604  97.155  -56.238  50.226  1
611605  97.189  -56.238  50.208  1
611606  97.225  -56.237  50.192  1
611607  97.259  -56.235  50.175  1
611608  97.295  -56.235  50.160  1
611609  97.329  -56.234  50.147  1
611610  97.365  -56.232  50.132  1
611611  97.399  -56.232  50.118  1
611612  97.435  -56.230  50.104  1
611613  97.469  -56.229  50.091  1
611614  97.504  -56.229  50.078  1
611615  97.539  -56.227  50.066  1
611616  97.574  -56.226  50.054  1
611617  97.609  -56.226  50.044  1
611618  97.644  -56.224  50.033  1
611619  97.679  -56.223  50.022  1
611620  97.702  -56.222  50.012  1
611621  97.736  -56.226  50.004  1
611622  97.776  -56.234  49.995  1
611623  97.816  -56.243  49.986  1
611624  97.857  -56.251  49.978  1
611625  97.897  -56.260  49.970  1
611626  97.938  -56.269  49.962  1
611627  97.978  -56.277  49.954  1
611628  98.019  -56.285  49.946  1
611629  98.059  -56.294  49.937  1
611630  98.099  -56.303  49.927  1
611631  98.140  -56.311  49.915  1
611632  98.180  -56.320  49.901  1
611633  98.221  -56.328  49.885  1
611634  98.261  -56.337  49.867  1
611635  98.301  -56.345  49.848  1
611636  98.342  -56.354  49.826  1
611637  98.379  -56.362  49.803  1
611638  98.413  -56.369  49.778  1
611639  98.448  -56.376  49.752  1
611640  98.483  -56.384  49.725  1
611641  98.517  -56.391  49.696  1
611642  98.552  -56.398  49.667  1
611643  98.586  -56.406  49.638  1
611644  98.621  -56.413  49.608  1
611645  98.655  -56.420  49.578  1
611646  98.690  -56.428  49.548  1
611647  98.724  -56.435  49.519  1
611648  98.759  -56.442  49.491  1
611649  98.793  -56.450  49.464  1
611650  98.828  -56.457  49.437  1
611651  98.862  -56.464  49.412  1
611652  98.897  -56.472  49.388  1
611653  98.931  -56.479  49.364  1
611654  98.966  -56.486  49.341  1
611655  99.000  -56.494  49.318  1
611656  99.034  -56.501  49.295  1
611657  99.069  -56.508  49.273  1
611658  99.103  -56.516  49.253  1
611659  99.138  -56.523  49.233  1
611660  99.172  -56.530  49.214  1
611661  99.207  -56.538  49.196  1
611662  99.241  -56.545  49.180  1
611663  99.276  -56.552  49.165  1
611664  99.310  -56.559  49.152  1
611665  99.345  -56.567  49.139  1
611666  99.379  -56.574  49.126  1
611667  99.410  -56.577  49.112  1
611668  99.436  -56.578  49.101  1
611669  99.462  -56.592  49.088  1
611670  99.488  -56.611  49.076  1
611671  99.514  -56.629  49.063  1
611672  99.547  -56.646  49.049  1
611673  99.579  -56.661  49.036  1
611674  99.606  -56.670  49.022  1
611675  99.632  -56.680  49.007  1
611676  99.658  -56.689  48.991  1
611677  99.686  -56.705  48.974  1
611678  99.714  -56.721  48.956  1
611679  99.742  -56.739  48.937  1
611680  99.770  -56.756  48.918  1
611681  99.797  -56.773  48.898  1
611682  99.825  -56.790  48.878  1
611683  99.853  -56.808  48.857  1
611684  99.881  -56.825  48.836  1
612031  88.910  -52.713  57.343  4
612032  88.941  -52.736  57.339  4
612033  88.973  -52.759  57.334  4
612034  89.004  -52.782  57.330  4
612035  89.036  -52.804  57.326  4
612036  89.068  -52.827  57.320  4
612037  89.100  -52.850  57.315  4
612038  89.131  -52.872  57.310  4
612039  89.163  -52.895  57.305  4
612040  89.195  -52.918  57.300  4
612041  89.226  -52.941  57.296  4
612042  89.258  -52.963  57.291  4
612043  89.290  -52.986  57.287  4
612044  89.321  -53.009  57.283  4
612045  89.353  -53.031  57.279  4
612046  89.385  -53.054  57.276  4
612047  89.416  -53.076  57.273  4
612048  89.448  -53.100  57.271  4
612049  89.470  -53.132  57.266  4
612050  89.502  -53.151  57.260  4
612051  89.536  -53.164  57.254  4
612052  89.559  -53.182  57.247  4
612053  89.583  -53.199  57.241  4
612054  89.606  -53.217  57.235  4
612055  89.629  -53.234  57.227  4
612056  89.653  -53.252  57.218  4
612057  89.676  -53.269  57.208  4
612058  89.707  -53.291  57.198  4
612059  89.749  -53.317  57.186  4
612060  89.790  -53.345  57.177  4
612061  89.831  -53.371  57.165  4
612062  89.872  -53.396  57.152  4
612063  89.910  -53.402  57.139  4
612064  89.941  -53.408  57.124  4
612065  89.962  -53.415  57.106  4
612066  89.982  -53.422  57.088  4
612067  90.003  -53.430  57.071  4
612068  90.024  -53.436  57.053  4
612069  90.044  -53.444  57.033  4
612070  90.064  -53.452  57.011  4
612071  90.085  -53.458  56.983  4
612072  90.120  -53.474  56.952  4
612073  90.163  -53.486  56.920  4
612074  90.206  -53.497  56.887  4
612075  90.250  -53.508  56.854  4
612076  90.293  -53.519  56.820  4
612077  90.336  -53.531  56.784  4
612078  90.380  -53.542  56.748  4
612079  90.423  -53.552  56.713  4
612080  90.466  -53.564  56.679  4
612081  90.506  -53.577  56.646  4
612082  90.523  -53.596  56.613  4
612090  90.737  -53.681  56.134  1
612091  90.773  -53.683  56.100  1
612092  90.806  -53.692  56.068  1
612093  90.835  -53.712  56.038  1
612094  90.864  -53.732  56.007  1
612095  90.893  -53.752  55.976  1
612096  90.922  -53.772  55.947  1
612097  90.951  -53.793  55.917  1
612098  90.979  -53.813  55.888  1
612099  91.009  -53.833  55.862  1
612100  91.037  -53.853  55.836  1
612101  91.068  -53.873  55.809  1
612102  91.101  -53.893  55.783  1
612103  91.134  -53.913  55.760  1
612104  91.167  -53.933  55.737  1
612105  91.201  -53.953  55.716  1
612106  91.234  -53.972  55.696  1
612107  91.267  -53.992  55.678  1
612108  91.301  -54.012  55.662  1
612109  91.334  -54.032  55.646  1
612110  91.367  -54.052  55.632  1
612111  91.400  -54.072  55.621  1
612112  91.434  -54.091  55.612  1
612113  91.467  -54.111  55.604  1
612114  91.501  -54.132  55.599  1
612115  91.534  -54.151  55.593  1
612116  91.567  -54.171  55.585  1
612117  91.601  -54.190  55.575  1
612118  91.654  -54.195  55.563  1
612119  91.707  -54.201  55.548  1
612120  91.749  -54.210  55.528  1
612121  91.785  -54.220  55.506  1
612122  91.821  -54.232  55.486  1
612123  91.857  -54.243  55.467  1
612124  91.893  -54.254  55.450  1
612125  91.929  -54.265  55.436  1
612126  91.965  -54.276  55.422  1
612127  92.001  -54.288  55.408  1
612128  92.036  -54.298  55.394  1
612129  92.074  -54.311  55.380  1
612130  92.112  -54.323  55.367  1
612131  92.151  -54.336  55.356  1
612132  92.190  -54.348  55.345  1
612139  92.458  -54.435  55.289  1
612140  92.497  -54.448  55.285  1
612141  92.535  -54.460  55.283  1
612142  92.574  -54.473  55.283  1
612143  92.613  -54.485  55.286  1
612144  92.651  -54.498  55.290  1
612145  92.689  -54.510  55.295  1
612146  92.728  -54.522  55.300  1
612147  92.766  -54.535  55.308  1
612148  92.795  -54.558  55.318  1
612149  92.818  -54.586  55.332  1
612150  92.842  -54.613  55.346  1
612151  92.868  -54.630  55.360  1
612152  92.896  -54.649  55.373  1
612153  92.923  -54.666  55.385  1
612154  92.948  -54.681  55.400  1
612155  92.973  -54.694  55.415  1
612156  92.997  -54.708  55.430  1
612157  93.022  -54.721  55.446  1
612158  93.047  -54.735  55.460  1
612159  93.072  -54.749  55.467  1
612160  93.096  -54.762  55.471  1
612161  93.121  -54.775  55.471  1
612162  93.146  -54.789  55.464  1
612163  93.170  -54.803  55.451  1
612164  93.196  -54.818  55.446  1
612165  93.222  -54.837  55.446  1
612166  93.249  -54.855  55.452  1
612167  93.285  -54.872  55.462  1
612168  93.320  -54.891  55.476  1
612169  93.356  -54.909  55.493  1
612170  93.390  -54.925  55.515  1
612171  93.415  -54.940  55.531  1
612172  93.440  -54.953  55.538  1
612173  93.465  -54.967  55.537  1
612174  93.490  -54.981  55.529  1
612175  93.515  -54.995  55.519  1
612176  93.540  -55.009  55.508  1
612177  93.565  -55.022  55.497  1
612178  93.590  -55.036  55.486  1
612179  93.616  -55.050  55.471  1
612180  93.641  -55.064  55.452  1
612181  93.665  -55.078  55.430  1
612182  93.691  -55.091  55.407  1
612183  93.716  -55.105  55.388  1
612184  93.741  -55.119  55.369  1
612185  93.762  -55.141  55.352  1
612186  93.782  -55.166  55.337  1
612187  93.802  -55.190  55.324  1
612188  93.823  -55.214  55.314  1
612189  93.843  -55.238  55.301  1
612190  93.863  -55.262  55.285  1
612191  93.884  -55.286  55.269  1
612192  93.904  -55.311  55.252  1
612193  93.924  -55.335  55.232  1
612194  93.944  -55.359  55.211  1
612195  93.964  -55.383  55.183  1
612196  93.986  -55.405  55.147  1
612197  94.010  -55.422  55.108  1
612198  94.034  -55.439  55.067  1
612199  94.058  -55.455  55.023  1
612200  94.083  -55.472  54.982  1
612201  94.111  -55.486  54.944  1
612202  94.144  -55.498  54.905  1
612203  94.177  -55.510  54.863  1
612204  94.210  -55.522  54.820  1
612205  94.243  -55.534  54.778  1
612206  94.275  -55.546  54.738  1
612207  94.306  -55.555  54.700  1
612208  94.336  -55.563  54.658  1
612209  94.367  -55.572  54.615  1
612210  94.397  -55.581  54.574  1
612211  94.428  -55.590  54.537  1
612212  94.461  -55.599  54.504  1
612213  94.510  -55.612  54.477  1
612214  94.560  -55.625  54.451  1
612215  94.610  -55.637  54.428  1
612216  94.659  -55.650  54.405  1
612217  94.704  -55.663  54.380  1
612218  94.744  -55.676  54.351  1
612219  94.784  -55.688  54.323  1
612220  94.824  -55.701  54.288  1
612221  94.862  -55.714  54.250  1
612222  94.890  -55.723  54.210  1
612223  94.918  -55.733  54.165  1
612224  94.947  -55.743  54.114  1
612225  94.975  -55.752  54.059  1
612226  95.003  -55.762  53.999  1
612227  95.032  -55.772  53.940  1
612228  95.060  -55.782  53.880  1
612229  95.088  -55.792  53.817  1
612230  95.117  -55.801  53.751  1
612231  95.145  -55.812  53.681  1
612232  95.174  -55.828  53.610  1
612233  95.203  -55.843  53.540  1
612234  95.235  -55.858  53.469  1
612235  95.268  -55.871  53.396  1
612236  95.301  -55.884  53.321  1
612237  95.333  -55.898  53.245  1
612238  95.366  -55.910  53.169  1
612239  95.398  -55.922  53.096  1
612240  95.431  -55.934  53.024  1
612241  95.463  -55.947  52.950  1
612242  95.497  -55.958  52.877  1
612243  95.532  -55.969  52.806  1
612244  95.566  -55.981  52.737  1
612245  95.595  -55.998  52.669  1
612246  95.621  -56.017  52.603  1
612247  95.648  -56.036  52.539  1
612248  95.676  -56.053  52.475  1
612249  95.707  -56.066  52.412  1
612250  95.739  -56.080  52.352  1
612251  95.770  -56.094  52.294  1
612252  95.802  -56.107  52.237  1
612253  95.834  -56.121  52.180  1
612254  95.868  -56.135  52.126  1
612255  95.902  -56.149  52.074  1
612256  95.936  -56.163  52.022  1
612257  95.970  -56.176  51.965  1
612258  96.004  -56.189  51.899  1
612259  96.036  -56.191  51.829  1
612260  96.068  -56.193  51.758  1
612261  96.100  -56.195  51.690  1
612262  96.131  -56.197  51.627  1
612263  96.163  -56.199  51.566  1
612264  96.195  -56.201  51.507  1
612265  96.227  -56.203  51.450  1
612266  96.259  -56.205  51.394  1
612267  96.291  -56.207  51.341  1
612268  96.322  -56.209  51.293  1
612269  96.355  -56.211  51.247  1
612270  96.376  -56.212  51.202  1
612271  96.391  -56.213  51.158  1
612272  96.406  -56.214  51.116  1
612273  96.422  -56.216  51.075  1
612274  96.438  -56.216  51.039  1
612275  96.453  -56.218  51.003  1
612276  96.468  -56.219  50.968  1
612277  96.484  -56.220  50.933  1
612278  96.498  -56.221  50.898  1
612279  96.510  -56.222  50.864  1
612280  96.523  -56.224  50.833  1
612281  96.535  -56.225  50.802  1
612282  96.547  -56.226  50.771  1
612283  96.559  -56.227  50.739  1
612284  96.572  -56.229  50.708  1
612285  96.585  -56.230  50.677  1
612286  96.597  -56.231  50.649  1
612287  96.611  -56.232  50.621  1
612288  96.628  -56.231  50.593  1
612289  96.645  -56.230  50.564  1
612290  96.661  -56.229  50.536  1
612291  96.681  -56.228  50.509  1
612292  96.716  -56.227  50.485  1
612293  96.751  -56.226  50.459  1
612294  96.786  -56.225  50.435  1
612295  96.821  -56.224  50.410  1
612296  96.856  -56.223  50.385  1
612297  96.891  -56.222  50.361  1
612298  96.926  -56.221  50.340  1
612299  96.961  -56.219  50.318  1
612300  96.996  -56.219  50.296  1
612301  97.031  -56.218  50.273  1
612302  97.066  -56.216  50.252  1
612303  97.101  -56.216  50.231  1
612304  97.136  -56.215  50.212  1
612305  97.171  -56.213  50.193  1
612306  97.206  -56.213  50.176  1
612307  97.241  -56.211  50.159  1
612308  97.276  -56.210  50.142  1
612309  97.311  -56.210  50.127  1
612310  97.346  -56.208  50.112  1
612311  97.380  -56.207  50.098  1
612312  97.416  -56.207  50.082  1
612313  97.450  -56.205  50.069  1
612314  97.486  -56.204  50.055  1
612315  97.520  -56.204  50.041  1
612316  97.556  -56.202  50.029  1
612317  97.590  -56.201  50.016  1
612318  97.626  -56.200  50.005  1
612319  97.660  -56.199  49.995  1
612320  97.687  -56.198  49.983  1
612321  97.710  -56.195  49.973  1
612322  97.749  -56.203  49.964  1
612323  97.789  -56.211  49.956  1
612324  97.830  -56.220  49.948  1
612325  97.870  -56.229  49.939  1
612326  97.911  -56.237  49.931  1
612327  97.951  -56.245  49.922  1
612328  97.992  -56.254  49.914  1
612329  98.032  -56.263  49.904  1
612330  98.072  -56.271  49.895  1
612331  98.112  -56.280  49.884  1
612332  98.153  -56.288  49.872  1
612333  98.194  -56.297  49.858  1
612334  98.234  -56.305  49.842  1
612335  98.275  -56.314  49.825  1
612336  98.315  -56.323  49.806  1
612337  98.355  -56.331  49.784  1
612338  98.389  -56.338  49.761  1
612339  98.424  -56.345  49.737  1
612340  98.458  -56.353  49.712  1
612341  98.493  -56.360  49.685  1
612342  98.527  -56.367  49.657  1
612343  98.562  -56.375  49.627  1
612344  98.596  -56.382  49.599  1
612345  98.631  -56.389  49.569  1
612346  98.665  -56.397  49.539  1
612347  98.700  -56.404  49.509  1
612348  98.734  -56.411  49.480  1
612349  98.769  -56.419  49.452  1
612350  98.803  -56.426  49.425  1
612351  98.838  -56.433  49.398  1
612352  98.872  -56.441  49.372  1
612353  98.907  -56.448  49.348  1
612354  98.941  -56.455  49.323  1
612355  98.976  -56.463  49.300  1
612356  99.010  -56.470  49.276  1
612357  99.045  -56.477  49.254  1
612358  99.079  -56.485  49.232  1
612359  99.114  -56.492  49.212  1
612360  99.148  -56.499  49.192  1
612361  99.183  -56.507  49.173  1
612362  99.217  -56.514  49.156  1
612363  99.252  -56.521  49.139  1
612364  99.286  -56.529  49.124  1
612365  99.321  -56.536  49.110  1
612366  99.355  -56.543  49.097  1
612367  99.385  -56.547  49.085  1
612368  99.412  -56.547  49.072  1
612369  99.438  -56.556  49.061  1
612370  99.464  -56.574  49.049  1
612371  99.489  -56.593  49.038  1
612372  99.518  -56.611  49.026  1
612373  99.551  -56.627  49.013  1
612374  99.581  -56.640  49.001  1
612375  99.608  -56.649  48.988  1
612376  99.634  -56.659  48.975  1
612377  99.660  -56.668  48.960  1
612378  99.688  -56.683  48.945  1
612379  99.716  -56.701  48.929  1
612380  99.744  -56.718  48.911  1
612381  99.771  -56.735  48.894  1
612382  99.799  -56.752  48.875  1
612383  99.827  -56.769  48.857  1
612384  99.855  -56.787  48.837  1
612731  88.894  -52.667  57.339  4
612732  88.926  -52.690  57.335  4
612733  88.958  -52.713  57.330  4
612734  88.989  -52.735  57.325  4
612735  89.021  -52.758  57.320  4
612736  89.052  -52.780  57.316  4
612737  89.084  -52.803  57.311  4
612738  89.116  -52.825  57.306  4
612739  89.147  -52.848  57.301  4
612740  89.179  -52.871  57.296  4
612741  89.211  -52.894  57.291  4
612742  89.242  -52.916  57.286  4
612743  89.274  -52.939  57.281  4
612744  89.306  -52.962  57.277  4
612745  89.337  -52.985  57.272  4
612746  89.369  -53.007  57.269  4
612747  89.401  -53.030  57.266  4
612748  89.433  -53.053  57.264  4
612749  89.463  -53.077  57.261  4
612750  89.488  -53.105  57.255  4
612751  89.522  -53.118  57.249  4
612752  89.545  -53.136  57.243  4
612753  89.568  -53.153  57.236  4
612754  89.592  -53.170  57.230  4
612755  89.615  -53.188  57.224  4
612756  89.638  -53.205  57.218  4
612757  89.662  -53.223  57.210  4
612758  89.685  -53.240  57.201  4
612759  89.718  -53.263  57.192  4
612760  89.759  -53.289  57.182  4
612761  89.801  -53.317  57.173  4
612762  89.842  -53.343  57.162  4
612763  89.881  -53.352  57.150  4
612764  89.919  -53.357  57.138  4
612765  89.956  -53.362  57.124  4
612766  89.976  -53.369  57.107  4
612767  89.996  -53.377  57.090  4
612768  90.017  -53.384  57.074  4
612769  90.038  -53.391  57.056  4
612770  90.058  -53.399  57.037  4
612771  90.079  -53.405  57.017  4
612772  90.103  -53.416  56.990  4
612773  90.139  -53.436  56.962  4
612774  90.179  -53.452  56.932  4
612775  90.222  -53.463  56.901  4
612776  90.265  -53.474  56.870  4
612777  90.308  -53.485  56.837  4
612778  90.352  -53.496  56.802  4
612779  90.395  -53.508  56.765  4
612780  90.438  -53.519  56.730  4
612781  90.481  -53.530  56.697  4
612782  90.514  -53.545  56.665  4
612783  90.531  -53.565  56.632  4
612784  90.548  -53.585  56.597  4
612792  90.796  -53.637  56.114  1
612793  90.825  -53.655  56.081  1
612794  90.854  -53.675  56.050  1
612795  90.883  -53.696  56.019  1
612796  90.912  -53.715  55.987  1
612797  90.941  -53.736  55.956  1
612798  90.970  -53.756  55.927  1
612799  90.999  -53.776  55.898  1
612800  91.028  -53.797  55.870  1
612801  91.059  -53.816  55.844  1
612802  91.092  -53.836  55.817  1
612803  91.126  -53.856  55.790  1
612804  91.159  -53.876  55.766  1
612805  91.192  -53.896  55.744  1
612806  91.225  -53.916  55.722  1
612807  91.258  -53.935  55.702  1
612808  91.292  -53.955  55.683  1
612809  91.325  -53.976  55.666  1
612810  91.359  -53.995  55.650  1
612811  91.392  -54.015  55.635  1
612812  91.425  -54.035  55.623  1
612813  91.458  -54.054  55.612  1
612814  91.492  -54.075  55.602  1
612815  91.525  -54.095  55.594  1
612816  91.559  -54.114  55.586  1
612817  91.592  -54.134  55.577  1
612818  91.625  -54.154  55.566  1
612819  91.675  -54.161  55.552  1
612820  91.724  -54.167  55.537  1
612821  91.760  -54.179  55.519  1
612822  91.796  -54.190  55.500  1
612823  91.832  -54.201  55.482  1
612824  91.868  -54.212  55.465  1
612825  91.904  -54.223  55.448  1
612826  91.940  -54.235  55.433  1
612827  91.979  -54.247  55.421  1
612828  92.017  -54.259  55.407  1
612829  92.056  -54.272  55.394  1
612830  92.094  -54.284  55.380  1
612831  92.133  -54.297  55.367  1
612832  92.171  -54.309  55.356  1
612840  92.479  -54.409  55.290  1
612841  92.517  -54.421  55.287  1
612842  92.556  -54.434  55.284  1
612843  92.594  -54.446  55.284  1
612844  92.632  -54.458  55.287  1
612845  92.671  -54.471  55.291  1
612846  92.709  -54.483  55.296  1
612847  92.747  -54.496  55.301  1
612848  92.786  -54.508  55.307  1
612849  92.818  -54.528  55.316  1
612850  92.841  -54.557  55.329  1
612851  92.864  -54.586  55.341  1
612852  92.888  -54.609  55.354  1
612853  92.916  -54.627  55.366  1
612854  92.943  -54.644  55.376  1
612855  92.968  -54.659  55.389  1
612856  92.993  -54.672  55.405  1
612857  93.017  -54.686  55.422  1
612858  93.043  -54.699  55.440  1
612859  93.067  -54.713  55.453  1
612860  93.092  -54.727  55.460  1
612861  93.117  -54.740  55.462  1
612862  93.141  -54.754  55.459  1
612863  93.166  -54.768  55.449  1
612864  93.191  -54.781  55.438  1
612865  93.216  -54.795  55.437  1
612866  93.241  -54.810  55.446  1
612867  93.267  -54.828  55.462  1
612868  93.300  -54.847  55.478  1
612869  93.336  -54.864  55.492  1
612870  93.371  -54.882  55.507  1
612871  93.396  -54.896  55.520  1
612872  93.421  -54.909  55.530  1
612873  93.446  -54.923  55.537  1
612874  93.471  -54.938  55.538  1
612875  93.496  -54.951  55.533  1
612876  93.521  -54.965  55.527  1
612877  93.547  -54.978  55.518  1
612878  93.572  -54.992  55.506  1
612879  93.597  -55.007  55.494  1
612880  93.622  -55.020  55.480  1
612881  93.647  -55.034  55.462  1
612882  93.672  -55.047  55.437  1
612883  93.697  -55.062  55.411  1
612884  93.722  -55.075  55.391  1
612885  93.748  -55.089  55.370  1
612886  93.770  -55.108  55.350  1
612887  93.790  -55.132  55.332  1
612888  93.811  -55.157  55.316  1
612889  93.831  -55.181  55.304  1
612890  93.851  -55.205  55.290  1
612891  93.871  -55.229  55.274  1
612892  93.891  -55.254  55.257  1
612893  93.912  -55.277  55.241  1
612894  93.932  -55.301  55.223  1
612895  93.952  -55.326  55.202  1
612896  93.972  -55.350  55.174  1
612897  93.995  -55.369  55.140  1
612898  94.019  -55.386  55.103  1
612899  94.044  -55.402  55.064  1
612900  94.068  -55.419  55.023  1
612901  94.092  -55.436  54.983  1
612902  94.120  -55.450  54.945  1
612903  94.153  -55.462  54.905  1
612904  94.186  -55.474  54.864  1
612905  94.219  -55.486  54.826  1
612906  94.252  -55.498  54.789  1
612907  94.285  -55.510  54.755  1
612908  94.317  -55.520  54.718  1
612909  94.347  -55.530  54.675  1
612910  94.378  -55.539  54.631  1
612911  94.408  -55.547  54.589  1
612912  94.438  -55.556  54.553  1
612913  94.474  -55.566  54.521  1
612914  94.524  -55.579  54.495  1
612915  94.573  -55.592  54.469  1
612916  94.623  -55.604  54.445  1
612917  94.670  -55.617  54.420  1
612918  94.710  -55.630  54.392  1
612919  94.750  -55.643  54.360  1
612920  94.789  -55.655  54.325  1
612921  94.829  -55.668  54.285  1
612922  94.868  -55.680  54.243  1
612923  94.897  -55.690  54.201  1
612924  94.925  -55.700  54.156  1
612925  94.954  -55.710  54.107  1
612926  94.982  -55.720  54.055  1
612927  95.011  -55.730  54.000  1
612928  95.039  -55.740  53.942  1
612929  95.067  -55.749  53.881  1
612930  95.095  -55.759  53.817  1
612931  95.123  -55.768  53.750  1
612932  95.153  -55.784  53.679  1
612933  95.182  -55.800  53.608  1
612934  95.211  -55.816  53.539  1
612935  95.242  -55.831  53.470  1
612936  95.275  -55.844  53.398  1
612937  95.308  -55.857  53.326  1
612938  95.340  -55.871  53.255  1
612939  95.373  -55.884  53.181  1
612940  95.406  -55.897  53.109  1
612941  95.439  -55.910  53.037  1
612942  95.471  -55.922  52.966  1
612943  95.503  -55.934  52.894  1
612944  95.538  -55.945  52.821  1
612945  95.569  -55.959  52.751  1
612946  95.596  -55.978  52.682  1
612947  95.624  -55.996  52.614  1
612948  95.656  -56.009  52.548  1
612949  95.687  -56.023  52.483  1
612950  95.718  -56.037  52.421  1
612951  95.749  -56.050  52.358  1
612952  95.780  -56.063  52.298  1
612953  95.813  -56.077  52.239  1
612954  95.847  -56.091  52.181  1
612955  95.881  -56.105  52.125  1
612956  95.915  -56.119  52.071  1
612957  95.949  -56.133  52.019  1
612958  95.983  -56.147  51.963  1
612959  96.017  -56.160  51.901  1
612960  96.050  -56.169  51.832  1
612961  96.082  -56.171  51.761  1
612962  96.114  -56.173  51.692  1
612963  96.146  -56.175  51.629  1
612964  96.177  -56.177  51.568  1
612965  96.209  -56.179  51.508  1
612966  96.241  -56.181  51.449  1
612967  96.273  -56.183  51.392  1
612968  96.305  -56.185  51.337  1
612969  96.336  -56.187  51.287  1
612970  96.368  -56.189  51.240  1
612971  96.386  -56.190  51.194  1
612972  96.401  -56.191  51.149  1
612973  96.417  -56.192  51.105  1
612974  96.433  -56.194  51.062  1
612975  96.448  -56.194  51.024  1
612976  96.463  -56.196  50.987  1
612977  96.479  -56.197  50.950  1
612978  96.493  -56.198  50.914  1
612979  96.506  -56.199  50.878  1
612980  96.518  -56.201  50.844  1
612981  96.530  -56.202  50.812  1
612982  96.543  -56.203  50.780  1
612983  96.555  -56.204  50.748  1
612984  96.568  -56.206  50.715  1
612985  96.580  -56.207  50.682  1
612986  96.592  -56.208  50.651  1
612987  96.609  -56.207  50.622  1
612988  96.625  -56.207  50.595  1
612989  96.642  -56.206  50.566  1
612990  96.659  -56.204  50.537  1
612991  96.675  -56.204  50.508  1
612992  96.697  -56.203  50.481  1
612993  96.732  -56.202  50.457  1
612994  96.767  -56.201  50.431  1
612995  96.802  -56.200  50.407  1
612996  96.837  -56.199  50.382  1
612997  96.872  -56.197  50.358  1
612998  96.907  -56.197  50.334  1
612999  96.942  -56.196  50.313  1
613000  96.977  -56.194  50.290  1
613001  97.012  -56.194  50.267  1
613002  97.047  -56.193  50.245  1
613003  97.082  -56.191  50.223  1
613004  97.117  -56.191  50.202  1
613005  97.152  -56.189  50.182  1
613006  97.187  -56.188  50.165  1
613007  97.222  -56.188  50.145  1
613008  97.256  -56.186  50.128  1
613009  97.292  -56.185  50.110  1
613010  97.326  -56.185  50.094  1
613011  97.362  -56.183  50.079  1
613012  97.396  -56.182  50.064  1
613013  97.432  -56.182  50.048  1
613014  97.466  -56.180  50.034  1
613015  97.502  -56.179  50.019  1
613016  97.536  -56.178  50.005  1
613017  97.572  -56.177  49.992  1
613018  97.606  -56.176  49.981  1
613019  97.642  -56.175  49.968  1
613020  97.673  -56.174  49.958  1
613021  97.696  -56.173  49.947  1
613022  97.722  -56.172  49.936  1
613023  97.762  -56.180  49.927  1
613024  97.803  -56.188  49.919  1
613025  97.843  -56.197  49.910  1
613026  97.883  -56.206  49.900  1
613027  97.924  -56.214  49.893  1
613028  97.964  -56.222  49.884  1
613029  98.005  -56.232  49.875  1
613030  98.045  -56.240  49.864  1
613031  98.086  -56.248  49.854  1
613032  98.126  -56.257  49.843  1
613033  98.166  -56.266  49.831  1
613034  98.207  -56.274  49.817  1
613035  98.247  -56.282  49.801  1
613036  98.288  -56.291  49.784  1
613037  98.328  -56.300  49.765  1
613038  98.365  -56.307  49.744  1
613039  98.399  -56.315  49.722  1
613040  98.434  -56.322  49.698  1
613041  98.468  -56.329  49.673  1
613042  98.503  -56.337  49.646  1
613043  98.537  -56.344  49.618  1
613044  98.572  -56.351  49.589  1
613045  98.606  -56.359  49.561  1
613046  98.641  -56.366  49.531  1
613047  98.675  -56.373  49.501  1
613048  98.710  -56.381  49.472  1
613049  98.744  -56.388  49.442  1
613050  98.779  -56.395  49.415  1
613051  98.813  -56.403  49.386  1
613052  98.848  -56.410  49.359  1
613053  98.882  -56.417  49.334  1
613054  98.917  -56.425  49.309  1
613055  98.951  -56.432  49.284  1
613056  98.986  -56.439  49.260  1
613057  99.020  -56.447  49.236  1
613058  99.055  -56.454  49.214  1
613059  99.089  -56.461  49.192  1
613060  99.124  -56.469  49.172  1
613061  99.158  -56.476  49.152  1
613062  99.193  -56.483  49.133  1
613063  99.227  -56.491  49.116  1
613064  99.262  -56.498  49.099  1
613065  99.296  -56.505  49.083  1
613066  99.331  -56.513  49.069  1
613067  99.361  -56.516  49.056  1
613068  99.388  -56.517  49.043  1
613069  99.415  -56.520  49.032  1
613070  99.440  -56.539  49.021  1
613071  99.466  -56.557  49.010  1
613072  99.491  -56.576  48.999  1
613073  99.521  -56.592  48.987  1
613074  99.554  -56.609  48.976  1
613075  99.583  -56.620  48.965  1
613076  99.609  -56.629  48.954  1
613077  99.636  -56.639  48.941  1
613078  99.662  -56.648  48.928  1
613079  99.690  -56.662  48.914  1
613080  99.717  -56.680  48.900  1
613081  99.745  -56.696  48.884  1
613082  99.773  -56.714  48.868  1
613083  99.801  -56.731  48.851  1
613431  88.879  -52.620  57.335  4
613432  88.910  -52.643  57.331  4
613433  88.942  -52.666  57.326  4
613434  88.974  -52.688  57.321  4
613435  89.005  -52.711  57.315  4
613436  89.037  -52.734  57.310  4
613437  89.068  -52.756  57.306  4
613438  89.100  -52.779  57.301  4
613439  89.132  -52.802  57.296  4
613440  89.164  -52.825  57.291  4
613441  89.195  -52.847  57.285  4
613442  89.227  -52.870  57.280  4
613443  89.258  -52.893  57.275  4
613444  89.290  -52.915  57.271  4
613445  89.322  -52.938  57.267  4
613446  89.353  -52.960  57.262  4
613447  89.385  -52.983  57.258  4
613448  89.417  -53.006  57.255  4
613449  89.449  -53.029  57.254  4
613450  89.478  -53.054  57.250  4
613451  89.508  -53.072  57.244  4
613452  89.531  -53.089  57.237  4
613453  89.554  -53.107  57.231  4
613454  89.578  -53.124  57.225  4
613455  89.601  -53.142  57.219  4
613456  89.624  -53.159  57.214  4
613457  89.648  -53.176  57.208  4
613458  89.671  -53.194  57.201  4
613459  89.694  -53.211  57.193  4
613460  89.729  -53.235  57.185  4
613461  89.770  -53.261  57.176  4
613462  89.811  -53.289  57.167  4
613463  89.850  -53.301  57.158  4
613464  89.889  -53.306  57.148  4
613465  89.928  -53.311  57.138  4
613466  89.966  -53.317  57.125  4
613467  89.990  -53.324  57.108  4
613468  90.011  -53.331  57.092  4
613469  90.031  -53.338  57.075  4
613470  90.052  -53.346  57.058  4
613471  90.073  -53.352  57.041  4
613472  90.093  -53.360  57.022  4
613473  90.124  -53.376  56.997  4
613474  90.160  -53.396  56.971  4
613475  90.195  -53.416  56.944  4
613476  90.237  -53.429  56.915  4
613477  90.281  -53.440  56.886  4
613478  90.324  -53.451  56.855  4
613479  90.367  -53.462  56.821  4
613480  90.410  -53.474  56.785  4
613481  90.453  -53.485  56.751  4
613482  90.497  -53.496  56.718  4
613483  90.521  -53.514  56.686  4
613484  90.538  -53.534  56.653  4
613485  90.555  -53.554  56.618  4
613486  90.573  -53.574  56.586  4
613494  90.845  -53.618  56.095  1
613495  90.874  -53.639  56.063  1
613496  90.902  -53.659  56.031  1
613497  90.932  -53.679  55.999  1
613498  90.960  -53.700  55.968  1
613499  90.990  -53.719  55.938  1
613500  91.018  -53.740  55.908  1
613501  91.050  -53.759  55.880  1
613502  91.083  -53.779  55.853  1
613503  91.117  -53.800  55.826  1
613504  91.150  -53.819  55.799  1
613505  91.183  -53.839  55.775  1
613506  91.217  -53.859  55.751  1
613507  91.250  -53.878  55.730  1
613508  91.283  -53.899  55.709  1
613509  91.317  -53.919  55.689  1
613510  91.350  -53.938  55.671  1
613511  91.383  -53.958  55.654  1
613512  91.417  -53.978  55.639  1
613513  91.450  -53.998  55.625  1
613514  91.483  -54.018  55.614  1
613515  91.516  -54.038  55.601  1
613516  91.550  -54.057  55.591  1
613517  91.583  -54.077  55.582  1
613518  91.616  -54.098  55.572  1
613519  91.650  -54.117  55.559  1
613520  91.697  -54.126  55.545  1
613521  91.735  -54.136  55.530  1
613522  91.772  -54.148  55.513  1
613523  91.807  -54.159  55.496  1
613524  91.845  -54.171  55.479  1
613525  91.883  -54.183  55.463  1
613526  91.922  -54.196  55.447  1
613527  91.960  -54.208  55.433  1
613528  91.999  -54.220  55.420  1
613529  92.037  -54.233  55.407  1
613530  92.076  -54.245  55.393  1
613531  92.114  -54.258  55.380  1
613532  92.152  -54.270  55.367  1
613541  92.499  -54.383  55.291  1
613542  92.537  -54.395  55.288  1
613543  92.575  -54.408  55.286  1
613544  92.614  -54.420  55.286  1
613545  92.652  -54.433  55.289  1
613546  92.691  -54.445  55.292  1
613547  92.729  -54.458  55.297  1
613548  92.768  -54.470  55.302  1
613549  92.806  -54.483  55.308  1
613550  92.841  -54.499  55.315  1
613551  92.864  -54.527  55.327  1
613552  92.886  -54.556  55.337  1
613553  92.909  -54.585  55.349  1
613554  92.936  -54.605  55.359  1
613555  92.963  -54.622  55.370  1
613556  92.988  -54.637  55.383  1
613557  93.013  -54.651  55.399  1
613558  93.038  -54.665  55.419  1
613559  93.063  -54.678  55.436  1
613560  93.087  -54.692  55.448  1
613561  93.112  -54.706  55.453  1
613562  93.137  -54.718  55.454  1
613563  93.161  -54.732  55.449  1
613564  93.187  -54.746  55.437  1
613565  93.211  -54.759  55.429  1
613566  93.236  -54.773  55.433  1
613567  93.261  -54.787  55.449  1
613568  93.286  -54.802  55.471  1
613569  93.317  -54.820  55.490  1
613570  93.352  -54.838  55.501  1
613571  93.377  -54.852  55.510  1
613572  93.403  -54.866  55.516  1
613573  93.428  -54.879  55.522  1
613574  93.452  -54.894  55.528  1
613575  93.478  -54.907  55.532  1
613576  93.503  -54.921  55.532  1
613577  93.528  -54.934  55.527  1
613578  93.553  -54.949  55.520  1
613579  93.578  -54.963  55.507  1
613580  93.603  -54.976  55.492  1
613581  93.628  -54.990  55.477  1
613582  93.653  -55.004  55.460  1
613583  93.679  -55.018  55.437  1
613584  93.704  -55.032  55.413  1
613585  93.729  -55.045  55.393  1
613586  93.754  -55.059  55.374  1
613587  93.778  -55.075  55.353  1
613588  93.798  -55.100  55.330  1
613589  93.818  -55.124  55.307  1
613590  93.839  -55.148  55.288  1
613591  93.859  -55.172  55.272  1
613592  93.879  -55.196  55.255  1
613593  93.899  -55.220  55.239  1
613594  93.919  -55.245  55.224  1
613595  93.939  -55.269  55.209  1
613596  93.960  -55.292  55.187  1
613597  93.981  -55.316  55.161  1
613598  94.005  -55.332  55.130  1
613599  94.029  -55.349  55.095  1
613600  94.054  -55.366  55.059  1
613601  94.078  -55.383  55.022  1
613602  94.102  -55.399  54.984  1
613603  94.129  -55.414  54.948  1
613604  94.161  -55.426  54.910  1
613605  94.195  -55.439  54.874  1
613606  94.227  -55.450  54.841  1
613607  94.261  -55.462  54.809  1
613608  94.293  -55.474  54.776  1
613609  94.326  -55.486  54.738  1
613610  94.357  -55.495  54.694  1
613611  94.388  -55.505  54.649  1
613612  94.418  -55.514  54.607  1
613613  94.449  -55.523  54.570  1
613614  94.487  -55.533  54.539  1
613615  94.537  -55.546  54.514  1
613616  94.586  -55.558  54.487  1
613617  94.636  -55.571  54.461  1
613618  94.676  -55.583  54.434  1
613619  94.715  -55.596  54.404  1
613620  94.755  -55.609  54.369  1
613621  94.795  -55.622  54.332  1
613622  94.835  -55.635  54.291  1
613623  94.875  -55.648  54.246  1
613624  94.904  -55.658  54.200  1
613625  94.932  -55.668  54.153  1
613626  94.961  -55.677  54.105  1
613627  94.989  -55.687  54.057  1
613628  95.017  -55.697  54.002  1
613629  95.046  -55.706  53.942  1
613630  95.074  -55.716  53.879  1
613631  95.102  -55.726  53.812  1
613632  95.131  -55.740  53.745  1
613633  95.161  -55.756  53.676  1
613634  95.190  -55.772  53.607  1
613635  95.219  -55.789  53.540  1
613636  95.249  -55.804  53.472  1
613637  95.282  -55.817  53.404  1
613638  95.315  -55.831  53.334  1
613639  95.347  -55.843  53.266  1
613640  95.380  -55.857  53.194  1
613641  95.413  -55.870  53.123  1
613642  95.446  -55.884  53.053  1
613643  95.478  -55.897  52.984  1
613644  95.511  -55.909  52.913  1
613645  95.544  -55.922  52.840  1
613646  95.572  -55.939  52.767  1
613647  95.604  -55.953  52.697  1
613648  95.635  -55.965  52.628  1
613649  95.666  -55.979  52.560  1
613650  95.697  -55.993  52.494  1
613651  95.729  -56.006  52.430  1
613652  95.760  -56.020  52.367  1
613653  95.791  -56.034  52.306  1
613654  95.825  -56.047  52.245  1
613655  95.860  -56.061  52.185  1
613656  95.893  -56.075  52.127  1
613657  95.927  -56.089  52.071  1
613658  95.961  -56.103  52.016  1
613659  95.995  -56.117  51.959  1
613660  96.030  -56.131  51.898  1
613661  96.063  -56.144  51.833  1
613662  96.096  -56.149  51.765  1
613663  96.128  -56.151  51.697  1
613664  96.160  -56.154  51.632  1
613665  96.191  -56.155  51.570  1
613666  96.223  -56.157  51.509  1
613667  96.255  -56.160  51.450  1
613668  96.287  -56.161  51.392  1
613669  96.319  -56.163  51.336  1
613670  96.350  -56.165  51.284  1
613671  96.381  -56.167  51.236  1
613672  96.396  -56.168  51.188  1
613673  96.412  -56.169  51.141  1
613674  96.428  -56.170  51.096  1
613675  96.443  -56.172  51.052  1
613676  96.458  -56.172  51.012  1
613677  96.474  -56.174  50.973  1
613678  96.488  -56.175  50.935  1
613679  96.501  -56.176  50.897  1
613680  96.513  -56.177  50.860  1
613681  96.526  -56.179  50.825  1
613682  96.538  -56.180  50.791  1
613683  96.550  -56.181  50.759  1
613684  96.563  -56.182  50.725  1
613685  96.575  -56.184  50.691  1
613686  96.590  -56.184  50.658  1
613687  96.607  -56.183  50.626  1
613688  96.623  -56.182  50.596  1
613689  96.640  -56.181  50.568  1
613690  96.657  -56.180  50.539  1
613691  96.673  -56.179  50.510  1
613692  96.690  -56.179  50.481  1
613693  96.713  -56.178  50.454  1
613694  96.748  -56.177  50.429  1
613695  96.783  -56.175  50.404  1
613696  96.818  -56.175  50.379  1
613697  96.853  -56.174  50.355  1
613698  96.888  -56.172  50.330  1
613699  96.923  -56.172  50.306  1
613700  96.958  -56.170  50.285  1
613701  96.993  -56.169  50.261  1
613702  97.028  -56.169  50.239  1
613703  97.063  -56.167  50.217  1
613704  97.098  -56.166  50.195  1
613705  97.133  -56.166  50.173  1
613706  97.168  -56.164  50.153  1
613707  97.203  -56.163  50.135  1
613708  97.238  -56.163  50.115  1
613709  97.273  -56.161  50.097  1
613710  97.308  -56.160  50.079  1
613711  97.343  -56.159  50.061  1
613712  97.378  -56.158  50.046  1
613713  97.413  -56.157  50.030  1
613714  97.448  -56.156  50.014  1
613715  97.483  -56.155  49.999  1
613716  97.518  -56.154  49.984  1
613717  97.552  -56.153  49.969  1
613718  97.587  -56.152  49.956  1
613719  97.623  -56.151  49.944  1
613720  97.657  -56.150  49.933  1
613721  97.681  -56.149  49.921  1
613722  97.704  -56.147  49.910  1
613723  97.735  -56.149  49.899  1
613724  97.776  -56.157  49.890  1
613725  97.816  -56.166  49.881  1
613726  97.856  -56.174  49.873  1
613727  97.896  -56.183  49.863  1
613728  97.937  -56.191  49.854  1
613729  97.978  -56.200  49.846  1
613730  98.018  -56.208  49.837  1
613731  98.059  -56.217  49.826  1
613732  98.099  -56.226  49.816  1
613733  98.139  -56.234  49.804  1
613734  98.179  -56.243  49.791  1
613735  98.220  -56.251  49.776  1
613736  98.261  -56.260  49.761  1
613737  98.301  -56.268  49.744  1
613738  98.340  -56.276  49.724  1
613739  98.375  -56.284  49.705  1
613740  98.410  -56.291  49.683  1
613741  98.444  -56.298  49.660  1
613742  98.479  -56.306  49.635  1
613743  98.513  -56.313  49.609  1
613744  98.548  -56.320  49.582  1
613745  98.582  -56.328  49.554  1
613746  98.617  -56.335  49.525  1
613747  98.651  -56.342  49.495  1
613748  98.686  -56.350  49.466  1
613752  98.823  -56.379  49.351  1
613753  98.858  -56.386  49.323  1
613754  98.892  -56.394  49.297  1
613755  98.927  -56.401  49.271  1
613756  98.961  -56.408  49.246  1
613757  98.996  -56.416  49.222  1
613758  99.030  -56.423  49.199  1
613759  99.065  -56.430  49.176  1
613760  99.099  -56.438  49.154  1
613761  99.134  -56.445  49.133  1
613762  99.168  -56.452  49.113  1
613763  99.203  -56.460  49.094  1
613764  99.237  -56.467  49.077  1
613765  99.272  -56.474  49.059  1
613766  99.306  -56.482  49.044  1
613767  99.337  -56.486  49.029  1
613768  99.364  -56.486  49.016  1
613769  99.391  -56.486  49.004  1
613770  99.416  -56.502  48.992  1
613771  99.442  -56.521  48.981  1
613772  99.467  -56.539  48.970  1
613773  99.493  -56.558  48.959  1
613774  99.525  -56.574  48.948  1
613775  99.558  -56.590  48.937  1
613776  99.585  -56.599  48.928  1
613777  99.611  -56.608  48.916  1
613778  99.638  -56.618  48.905  1
613779  99.664  -56.627  48.893  1
613780  99.691  -56.641  48.880  1
613781  99.719  -56.658  48.867  1
613782  99.747  -56.675  48.853  1
613783  99.775  -56.693  48.839  1
614131  88.863  -52.574  57.331  4
614132  88.895  -52.597  57.327  4
614133  88.926  -52.619  57.323  4
614134  88.958  -52.642  57.318  4
614135  88.990  -52.664  57.312  4
614136  89.022  -52.687  57.307  4
614137  89.053  -52.709  57.301  4
614138  89.085  -52.732  57.296  4
614139  89.116  -52.755  57.290  4
614140  89.148  -52.778  57.285  4
614141  89.180  -52.800  57.280  4
614142  89.211  -52.823  57.275  4
614143  89.243  -52.846  57.269  4
614144  89.275  -52.869  57.264  4
614145  89.306  -52.891  57.260  4
614146  89.338  -52.914  57.256  4
614147  89.370  -52.937  57.252  4
614148  89.401  -52.960  57.248  4
614149  89.433  -52.982  57.244  4
614150  89.465  -53.005  57.241  4
614151  89.493  -53.026  57.237  4
614152  89.517  -53.043  57.232  4
614153  89.540  -53.060  57.226  4
614154  89.563  -53.078  57.220  4
614155  89.587  -53.095  57.215  4
614156  89.610  -53.113  57.209  4
614157  89.633  -53.130  57.204  4
614158  89.657  -53.148  57.198  4
614159  89.680  -53.165  57.192  4
614160  89.703  -53.183  57.185  4
614161  89.740  -53.207  57.178  4
614162  89.780  -53.233  57.170  4
614163  89.821  -53.250  57.162  4
614164  89.859  -53.255  57.153  4
614165  89.898  -53.261  57.145  4
614166  89.937  -53.266  57.136  4
614167  89.975  -53.271  57.126  4
614168  90.005  -53.278  57.111  4
614169  90.025  -53.285  57.094  4
614170  90.045  -53.292  57.078  4
614171  90.066  -53.299  57.061  4
614172  90.087  -53.307  57.046  4
614173  90.109  -53.315  57.028  4
614174  90.145  -53.336  57.004  4
614175  90.180  -53.355  56.980  4
614176  90.216  -53.376  56.955  4
614177  90.252  -53.395  56.928  4
614178  90.296  -53.405  56.902  4
614179  90.339  -53.417  56.872  4
614180  90.382  -53.428  56.840  4
614181  90.426  -53.440  56.806  4
614182  90.469  -53.451  56.773  4
614183  90.512  -53.462  56.740  4
614184  90.529  -53.482  56.708  4
614185  90.546  -53.502  56.676  4
614186  90.563  -53.522  56.641  4
614187  90.592  -53.531  56.608  4
614188  90.628  -53.532  56.576  4
614189  90.664  -53.534  56.545  4
614199  90.979  -53.662  55.980  1
614200  91.009  -53.683  55.950  1
614201  91.041  -53.703  55.920  1
614202  91.075  -53.722  55.891  1
614203  91.108  -53.743  55.864  1
614204  91.142  -53.762  55.837  1
614205  91.175  -53.782  55.810  1
614206  91.208  -53.802  55.785  1
614207  91.241  -53.822  55.761  1
614208  91.275  -53.842  55.739  1
614209  91.308  -53.862  55.719  1
614210  91.342  -53.882  55.698  1
614211  91.375  -53.901  55.680  1
614212  91.408  -53.921  55.663  1
614213  91.441  -53.941  55.647  1
614214  91.474  -53.961  55.631  1
614215  91.508  -53.981  55.618  1
614216  91.541  -54.001  55.605  1
614217  91.575  -54.020  55.593  1
614218  91.608  -54.041  55.582  1
614219  91.641  -54.060  55.570  1
614220  91.674  -54.080  55.556  1
614221  91.711  -54.095  55.540  1
614222  91.749  -54.107  55.526  1
614223  91.788  -54.120  55.509  1
614224  91.826  -54.132  55.494  1
614225  91.865  -54.145  55.478  1
614226  91.904  -54.157  55.462  1
614227  91.942  -54.170  55.447  1
614228  91.980  -54.182  55.434  1
614229  92.019  -54.195  55.420  1
614230  92.057  -54.207  55.407  1
614231  92.095  -54.220  55.394  1
614232  92.134  -54.232  55.380  1
614233  92.172  -54.244  55.368  1
614242  92.518  -54.356  55.293  1
614243  92.557  -54.369  55.290  1
614244  92.595  -54.381  55.288  1
614245  92.634  -54.394  55.288  1
614246  92.672  -54.406  55.291  1
614247  92.711  -54.419  55.294  1
614248  92.749  -54.431  55.298  1
614249  92.788  -54.443  55.303  1
614250  92.826  -54.456  55.309  1
614251  92.864  -54.470  55.316  1
614252  92.886  -54.498  55.326  1
614253  92.909  -54.527  55.335  1
614254  92.932  -54.555  55.346  1
614255  92.956  -54.583  55.355  1
614256  92.983  -54.600  55.366  1
614257  93.009  -54.616  55.379  1
614258  93.034  -54.629  55.397  1
614259  93.058  -54.643  55.416  1
614260  93.083  -54.656  55.430  1
614261  93.108  -54.670  55.438  1
614262  93.132  -54.684  55.442  1
614263  93.157  -54.697  55.441  1
614264  93.182  -54.711  55.436  1
614265  93.207  -54.724  55.423  1
614266  93.231  -54.738  55.420  1
614267  93.256  -54.752  55.431  1
614268  93.281  -54.765  55.453  1
614269  93.305  -54.778  55.477  1
614270  93.332  -54.793  55.493  1
614271  93.359  -54.808  55.499  1
614272  93.384  -54.822  55.502  1
614273  93.409  -54.836  55.503  1
614274  93.434  -54.850  55.507  1
614275  93.459  -54.863  55.514  1
614276  93.484  -54.877  55.523  1
614277  93.509  -54.891  55.528  1
614278  93.535  -54.905  55.525  1
614279  93.560  -54.919  55.518  1
614280  93.584  -54.932  55.504  1
614281  93.610  -54.946  55.487  1
614282  93.635  -54.960  55.470  1
614283  93.660  -54.974  55.454  1
614284  93.685  -54.988  55.433  1
614285  93.710  -55.001  55.409  1
614286  93.735  -55.016  55.390  1
614287  93.760  -55.029  55.371  1
614288  93.785  -55.043  55.350  1
614289  93.806  -55.066  55.326  1
614290  93.826  -55.091  55.301  1
614291  93.846  -55.115  55.279  1
614292  93.866  -55.139  55.258  1
614293  93.887  -55.163  55.238  1
614294  93.907  -55.187  55.219  1
614295  93.927  -55.211  55.204  1
614296  93.947  -55.235  55.187  1
614297  93.968  -55.260  55.168  1
614298  93.990  -55.279  55.144  1
614299  94.014  -55.296  55.116  1
614300  94.039  -55.313  55.085  1
614301  94.063  -55.329  55.053  1
614302  94.087  -55.346  55.020  1
614303  94.112  -55.363  54.986  1
614304  94.137  -55.379  54.953  1
614305  94.171  -55.391  54.921  1
614306  94.203  -55.402  54.890  1
614307  94.236  -55.414  54.861  1
614308  94.269  -55.426  54.832  1
614309  94.302  -55.438  54.798  1
614310  94.335  -55.450  54.759  1
614311  94.368  -55.462  54.713  1
614312  94.399  -55.471  54.667  1
614313  94.429  -55.480  54.626  1
614314  94.460  -55.489  54.590  1
614315  94.500  -55.500  54.559  1
614316  94.550  -55.512  54.533  1
614317  94.599  -55.525  54.505  1
614318  94.641  -55.538  54.476  1
614319  94.681  -55.551  54.446  1
614320  94.720  -55.564  54.414  1
614321  94.760  -55.576  54.380  1
614322  94.800  -55.589  54.342  1
614323  94.840  -55.602  54.300  1
614324  94.880  -55.614  54.255  1
614325  94.911  -55.625  54.207  1
614326  94.939  -55.635  54.158  1
614327  94.968  -55.645  54.108  1
614328  94.996  -55.654  54.056  1
614329  95.024  -55.664  53.998  1
614330  95.052  -55.674  53.935  1
614331  95.081  -55.683  53.871  1
614332  95.110  -55.697  53.806  1
614333  95.139  -55.713  53.741  1
614334  95.168  -55.729  53.676  1
614335  95.197  -55.745  53.611  1
614336  95.227  -55.761  53.547  1
614337  95.256  -55.777  53.482  1
614338  95.289  -55.790  53.415  1
614339  95.322  -55.803  53.348  1
614340  95.354  -55.817  53.280  1
614341  95.387  -55.830  53.209  1
614342  95.420  -55.843  53.139  1
614343  95.453  -55.856  53.071  1
614344  95.485  -55.870  53.003  1
614345  95.519  -55.883  52.933  1
614346  95.552  -55.895  52.860  1
614347  95.583  -55.909  52.785  1
614348  95.614  -55.922  52.713  1
614349  95.645  -55.936  52.643  1
614350  95.677  -55.950  52.574  1
614351  95.708  -55.963  52.507  1
614352  95.739  -55.977  52.440  1
614353  95.770  -55.990  52.377  1
614354  95.804  -56.004  52.314  1
614355  95.838  -56.018  52.252  1
614356  95.872  -56.031  52.190  1
614357  95.906  -56.045  52.130  1
614358  95.940  -56.059  52.072  1
614359  95.974  -56.073  52.015  1
614360  96.008  -56.087  51.957  1
614361  96.042  -56.101  51.897  1
614362  96.076  -56.115  51.834  1
614363  96.110  -56.128  51.769  1
614364  96.142  -56.129  51.701  1
614365  96.174  -56.132  51.638  1
614366  96.205  -56.133  51.575  1
614367  96.237  -56.135  51.513  1
614368  96.269  -56.138  51.452  1
614369  96.301  -56.139  51.394  1
614370  96.333  -56.141  51.336  1
614371  96.365  -56.144  51.283  1
614372  96.391  -56.145  51.232  1
614373  96.407  -56.146  51.183  1
614374  96.422  -56.147  51.135  1
614375  96.438  -56.148  51.087  1
614376  96.453  -56.150  51.042  1
614377  96.469  -56.150  51.001  1
614378  96.484  -56.152  50.960  1
614379  96.497  -56.153  50.920  1
614380  96.509  -56.154  50.881  1
614381  96.521  -56.156  50.842  1
614382  96.533  -56.157  50.805  1
614383  96.546  -56.158  50.770  1
614384  96.558  -56.160  50.737  1
614385  96.571  -56.160  50.703  1
614386  96.588  -56.160  50.668  1
614387  96.604  -56.159  50.634  1
614388  96.621  -56.158  50.602  1
614389  96.638  -56.157  50.571  1
614390  96.654  -56.156  50.542  1
614391  96.671  -56.155  50.512  1
614392  96.687  -56.154  50.483  1
614393  96.704  -56.154  50.454  1
614394  96.729  -56.153  50.426  1
614395  96.764  -56.151  50.401  1
614396  96.799  -56.150  50.376  1
614397  96.834  -56.150  50.352  1
614398  96.869  -56.148  50.327  1
614399  96.904  -56.147  50.301  1
614400  96.939  -56.147  50.278  1
614401  96.974  -56.145  50.257  1
614402  97.009  -56.144  50.234  1
614403  97.044  -56.144  50.211  1
614404  97.079  -56.142  50.189  1
614405  97.114  -56.141  50.166  1
614406  97.149  -56.140  50.144  1
614407  97.184  -56.139  50.124  1
614408  97.219  -56.138  50.105  1
614409  97.254  -56.137  50.085  1
614410  97.289  -56.136  50.067  1
614411  97.324  -56.135  50.047  1
614412  97.359  -56.134  50.029  1
614413  97.394  -56.133  50.013  1
614414  97.429  -56.132  49.997  1
614415  97.464  -56.131  49.981  1
614416  97.499  -56.130  49.964  1
614417  97.533  -56.128  49.948  1
614418  97.569  -56.128  49.934  1
614419  97.603  -56.127  49.920  1
614420  97.639  -56.125  49.908  1
614421  97.666  -56.125  49.897  1
614422  97.689  -56.124  49.885  1
614423  97.712  -56.120  49.873  1
614424  97.748  -56.125  49.863  1
614425  97.789  -56.135  49.854  1
614426  97.829  -56.143  49.844  1
614427  97.870  -56.151  49.836  1
614428  97.910  -56.160  49.827  1
614429  97.950  -56.169  49.817  1
614430  97.991  -56.177  49.808  1
614431  98.031  -56.185  49.799  1
614432  98.072  -56.194  49.788  1
614433  98.112  -56.203  49.777  1
614434  98.153  -56.211  49.764  1
614435  98.193  -56.219  49.751  1
614436  98.233  -56.229  49.737  1
614437  98.274  -56.237  49.721  1
614438  98.314  -56.245  49.704  1
614439  98.351  -56.253  49.685  1
614440  98.385  -56.260  49.666  1
614441  98.420  -56.268  49.645  1
614442  98.454  -56.275  49.622  1
614443  98.489  -56.282  49.598  1
614444  98.523  -56.290  49.572  1
614454  98.868  -56.363  49.289  1
614455  98.903  -56.370  49.262  1
614456  98.937  -56.378  49.236  1
614457  98.972  -56.385  49.211  1
614458  99.006  -56.392  49.187  1
614459  99.041  -56.400  49.163  1
614460  99.075  -56.407  49.140  1
614461  99.110  -56.414  49.118  1
614462  99.144  -56.422  49.097  1
614463  99.179  -56.429  49.076  1
614464  99.213  -56.436  49.057  1
614465  99.248  -56.444  49.039  1
614466  99.282  -56.451  49.022  1
614467  99.313  -56.455  49.006  1
614468  99.340  -56.455  48.991  1
614469  99.367  -56.456  48.977  1
614470  99.393  -56.467  48.964  1
614471  99.418  -56.485  48.952  1
614472  99.443  -56.503  48.941  1
614473  99.469  -56.522  48.930  1
614474  99.497  -56.540  48.918  1
614475  99.529  -56.556  48.907  1
614476  99.560  -56.570  48.897  1
614477  99.586  -56.579  48.887  1
614478  99.613  -56.589  48.878  1
614479  99.639  -56.598  48.867  1
614480  99.666  -56.607  48.856  1
614481  99.693  -56.620  48.845  1
614482  99.721  -56.637  48.833  1
614483  99.749  -56.654  48.821  1
614831  88.847  -52.527  57.332  4
614832  88.879  -52.550  57.324  4
614833  88.911  -52.572  57.320  4
614834  88.943  -52.595  57.315  4
614835  88.974  -52.618  57.309  4
614836  89.006  -52.640  57.303  4
614837  89.038  -52.663  57.297  4
614838  89.069  -52.686  57.291  4
614839  89.101  -52.709  57.286  4
614840  89.132  -52.731  57.281  4
614841  89.164  -52.754  57.275  4
614842  89.196  -52.777  57.269  4
614843  89.228  -52.799  57.264  4
614844  89.259  -52.822  57.259  4
614845  89.291  -52.844  57.254  4
614846  89.322  -52.867  57.249  4
614847  89.354  -52.890  57.245  4
614848  89.386  -52.913  57.241  4
614849  89.417  -52.935  57.237  4
614850  89.451  -52.955  57.233  4
614851  89.483  -52.974  57.229  4
614852  89.517  -52.989  57.225  4
614853  89.537  -53.007  57.221  4
614854  89.553  -53.029  57.216  4
614855  89.573  -53.049  57.210  4
614856  89.596  -53.067  57.206  4
614857  89.619  -53.084  57.201  4
614858  89.642  -53.101  57.195  4
614859  89.666  -53.119  57.190  4
614860  89.689  -53.136  57.185  4
614861  89.712  -53.154  57.179  4
614862  89.750  -53.179  57.173  4
614863  89.791  -53.200  57.165  4
614864  89.829  -53.205  57.157  4
614865  89.868  -53.211  57.149  4
614866  89.906  -53.216  57.141  4
614867  89.945  -53.221  57.133  4
614868  89.983  -53.227  57.126  4
614869  90.019  -53.232  57.112  4
614870  90.039  -53.239  57.096  4
614871  90.059  -53.246  57.080  4
614872  90.080  -53.254  57.065  4
614873  90.101  -53.261  57.050  4
614874  90.129  -53.275  57.033  4
614875  90.165  -53.295  57.011  4
614876  90.201  -53.315  56.990  4
614877  90.236  -53.336  56.966  4
614878  90.272  -53.355  56.942  4
614879  90.311  -53.371  56.917  4
614880  90.354  -53.383  56.890  4
614881  90.397  -53.394  56.860  4
614882  90.441  -53.405  56.828  4
614883  90.484  -53.417  56.796  4
614884  90.519  -53.430  56.764  4
614885  90.536  -53.451  56.731  4
614886  90.553  -53.471  56.700  4
614887  90.580  -53.482  56.666  4
614888  90.615  -53.483  56.632  4
614889  90.651  -53.485  56.599  4
614890  90.687  -53.487  56.567  4
614891  90.723  -53.489  56.537  4
614905  91.166  -53.725  55.849  1
614906  91.200  -53.745  55.822  1
614907  91.233  -53.766  55.797  1
614908  91.266  -53.785  55.773  1
614909  91.299  -53.805  55.750  1
614910  91.332  -53.825  55.730  1
614911  91.366  -53.844  55.709  1
614912  91.399  -53.865  55.690  1
614913  91.433  -53.885  55.672  1
614914  91.466  -53.904  55.655  1
614915  91.499  -53.924  55.639  1
614916  91.532  -53.944  55.624  1
614917  91.566  -53.964  55.610  1
614918  91.599  -53.984  55.597  1
614919  91.630  -54.004  55.584  1
614920  91.657  -54.025  55.571  1
614921  91.689  -54.048  55.557  1
614922  91.727  -54.066  55.540  1
614923  91.768  -54.080  55.526  1
614924  91.808  -54.093  55.509  1
614925  91.847  -54.106  55.494  1
614926  91.885  -54.118  55.478  1
614927  91.923  -54.131  55.463  1
614928  91.962  -54.143  55.447  1
614929  92.000  -54.156  55.435  1
614930  92.038  -54.168  55.421  1
614931  92.077  -54.181  55.408  1
614932  92.116  -54.193  55.394  1
614933  92.154  -54.205  55.381  1
614943  92.538  -54.330  55.294  1
614944  92.577  -54.342  55.292  1
614945  92.616  -54.355  55.290  1
614946  92.654  -54.367  55.290  1
614947  92.692  -54.380  55.293  1
614948  92.731  -54.392  55.297  1
614949  92.769  -54.405  55.301  1
614950  92.807  -54.417  55.306  1
614951  92.846  -54.430  55.311  1
614952  92.884  -54.442  55.317  1
614953  92.909  -54.469  55.326  1
614954  92.932  -54.498  55.335  1
614955  92.955  -54.527  55.344  1
614956  92.978  -54.555  55.354  1
614957  93.003  -54.578  55.364  1
614958  93.029  -54.594  55.377  1
614959  93.054  -54.608  55.395  1
614960  93.078  -54.621  55.412  1
614961  93.103  -54.635  55.421  1
614962  93.128  -54.649  55.426  1
614963  93.153  -54.662  55.427  1
614964  93.178  -54.675  55.425  1
614965  93.202  -54.689  55.419  1
614966  93.227  -54.703  55.409  1
614967  93.252  -54.716  55.410  1
614968  93.274  -54.727  55.423  1
614969  93.296  -54.736  55.444  1
614970  93.318  -54.748  55.465  1
614971  93.344  -54.765  55.478  1
614972  93.366  -54.778  55.481  1
614973  93.391  -54.792  55.481  1
614974  93.415  -54.806  55.484  1
614975  93.440  -54.819  55.492  1
614976  93.466  -54.833  55.504  1
614977  93.491  -54.847  55.516  1
614978  93.516  -54.861  55.523  1
614979  93.541  -54.875  55.522  1
614980  93.566  -54.888  55.513  1
614981  93.591  -54.903  55.496  1
614982  93.616  -54.916  55.476  1
614983  93.641  -54.930  55.456  1
614984  93.666  -54.944  55.444  1
614985  93.692  -54.958  55.423  1
614986  93.716  -54.972  55.401  1
614987  93.742  -54.985  55.382  1
614988  93.767  -54.999  55.364  1
614989  93.792  -55.013  55.344  1
614990  93.814  -55.034  55.320  1
614991  93.834  -55.057  55.296  1
614992  93.854  -55.082  55.271  1
614993  93.874  -55.106  55.248  1
614994  93.895  -55.130  55.225  1
614995  93.915  -55.154  55.203  1
614996  93.935  -55.179  55.185  1
614997  93.956  -55.202  55.167  1
614998  93.976  -55.226  55.149  1
614999  94.000  -55.243  55.130  1
615000  94.024  -55.260  55.108  1
615001  94.049  -55.276  55.083  1
615002  94.073  -55.293  55.057  1
615003  94.097  -55.310  55.030  1
615004  94.122  -55.326  55.000  1
615005  94.146  -55.343  54.970  1
615006  94.179  -55.354  54.940  1
615007  94.212  -55.367  54.912  1
615008  94.245  -55.379  54.886  1
615009  94.278  -55.390  54.856  1
615010  94.311  -55.402  54.821  1
615011  94.344  -55.414  54.779  1
615012  94.377  -55.426  54.732  1
615013  94.409  -55.437  54.685  1
615014  94.439  -55.446  54.645  1
615015  94.470  -55.455  54.611  1
615016  94.513  -55.467  54.580  1
615017  94.563  -55.479  54.552  1
615018  94.607  -55.492  54.521  1
615019  94.646  -55.505  54.489  1
615020  94.686  -55.517  54.457  1
615021  94.726  -55.530  54.423  1
615022  94.766  -55.543  54.389  1
615023  94.806  -55.556  54.351  1
615024  94.845  -55.568  54.309  1
615025  94.885  -55.581  54.262  1
615026  94.918  -55.593  54.212  1
615027  94.946  -55.602  54.160  1
615028  94.974  -55.611  54.108  1
615029  95.003  -55.621  54.053  1
615030  95.031  -55.631  53.992  1
615031  95.059  -55.641  53.930  1
615032  95.088  -55.653  53.867  1
615033  95.117  -55.670  53.805  1
615034  95.146  -55.686  53.740  1
615035  95.176  -55.702  53.679  1
615036  95.205  -55.718  53.618  1
615037  95.235  -55.734  53.558  1
615038  95.264  -55.749  53.496  1
615039  95.296  -55.763  53.431  1
615040  95.329  -55.776  53.362  1
615041  95.361  -55.790  53.291  1
615042  95.394  -55.803  53.220  1
615043  95.427  -55.816  53.149  1
615044  95.460  -55.829  53.080  1
615045  95.494  -55.841  53.013  1
615046  95.528  -55.853  52.943  1
615047  95.561  -55.865  52.873  1
615048  95.594  -55.879  52.801  1
615049  95.625  -55.892  52.730  1
615050  95.656  -55.906  52.660  1
615051  95.687  -55.919  52.591  1
615052  95.719  -55.933  52.523  1
615053  95.750  -55.947  52.454  1
615054  95.782  -55.960  52.387  1
615055  95.816  -55.974  52.323  1
615056  95.850  -55.988  52.259  1
615057  95.884  -56.002  52.195  1
615058  95.918  -56.016  52.133  1
615059  95.953  -56.029  52.074  1
615060  95.986  -56.044  52.016  1
615061  96.021  -56.057  51.957  1
615062  96.054  -56.071  51.898  1
615063  96.089  -56.085  51.835  1
615064  96.123  -56.099  51.771  1
615065  96.156  -56.107  51.706  1
615066  96.188  -56.110  51.643  1
615067  96.220  -56.112  51.580  1
615068  96.251  -56.113  51.517  1
615069  96.283  -56.116  51.456  1
615070  96.315  -56.118  51.396  1
615071  96.347  -56.119  51.336  1
615072  96.379  -56.122  51.282  1
615073  96.402  -56.123  51.230  1
615074  96.417  -56.124  51.179  1
615075  96.433  -56.125  51.129  1
615076  96.448  -56.126  51.080  1
615077  96.464  -56.128  51.032  1
615078  96.479  -56.128  50.990  1
615079  96.492  -56.130  50.948  1
615080  96.504  -56.131  50.906  1
615081  96.517  -56.132  50.865  1
615082  96.529  -56.134  50.825  1
615083  96.541  -56.135  50.786  1
615084  96.554  -56.136  50.750  1
615085  96.569  -56.136  50.716  1
615086  96.586  -56.135  50.681  1
615087  96.602  -56.135  50.646  1
615088  96.619  -56.134  50.611  1
615089  96.636  -56.132  50.578  1
615090  96.652  -56.132  50.547  1
615091  96.669  -56.131  50.517  1
615092  96.685  -56.130  50.487  1
615093  96.702  -56.129  50.457  1
615094  96.719  -56.128  50.428  1
615095  96.745  -56.128  50.399  1
615096  96.780  -56.126  50.374  1
615097  96.815  -56.125  50.350  1
615098  96.850  -56.125  50.325  1
615099  96.885  -56.123  50.299  1
615100  96.920  -56.122  50.274  1
615101  96.955  -56.122  50.250  1
615102  96.990  -56.120  50.228  1
615103  97.025  -56.119  50.206  1
615104  97.060  -56.118  50.183  1
615105  97.095  -56.117  50.160  1
615106  97.130  -56.116  50.137  1
615107  97.165  -56.115  50.115  1
615108  97.200  -56.114  50.095  1
615109  97.235  -56.113  50.074  1
615110  97.270  -56.112  50.055  1
615111  97.305  -56.111  50.035  1
615120  97.619  -56.102  49.885  1
615121  97.652  -56.100  49.872  1
615122  97.675  -56.100  49.860  1
615123  97.698  -56.099  49.848  1
615124  97.721  -56.094  49.837  1
615125  97.761  -56.103  49.826  1
615126  97.802  -56.112  49.817  1
615127  97.843  -56.120  49.808  1
615128  97.883  -56.128  49.799  1
615129  97.923  -56.137  49.790  1
615130  97.964  -56.146  49.781  1
615131  98.004  -56.154  49.772  1
615132  98.044  -56.163  49.761  1
615133  98.085  -56.171  49.749  1
615134  98.126  -56.180  49.738  1
615135  98.166  -56.188  49.725  1
615136  98.206  -56.197  49.712  1
615137  98.246  -56.206  49.698  1
615138  98.287  -56.214  49.683  1
615139  98.326  -56.222  49.666  1
615140  98.361  -56.229  49.648  1
615157  98.947  -56.354  49.203  1
615158  98.982  -56.361  49.177  1
615159  99.016  -56.369  49.152  1
615160  99.051  -56.376  49.129  1
615161  99.085  -56.383  49.105  1
615162  99.120  -56.391  49.083  1
615163  99.154  -56.398  49.062  1
615164  99.189  -56.405  49.041  1
615165  99.223  -56.413  49.021  1
615166  99.258  -56.420  49.002  1
615167  99.289  -56.424  48.985  1
615168  99.315  -56.425  48.969  1
615169  99.343  -56.425  48.954  1
615170  99.369  -56.430  48.939  1
615171  99.395  -56.448  48.926  1
615172  99.420  -56.467  48.913  1
615173  99.445  -56.486  48.902  1
615174  99.471  -56.505  48.890  1
615175  99.500  -56.522  48.878  1
615176  99.533  -56.538  48.867  1
615177  99.562  -56.549  48.856  1
615178  99.588  -56.558  48.846  1
615179  99.615  -56.568  48.838  1
615180  99.641  -56.577  48.828  1
615181  99.668  -56.586  48.818  1
615182  99.695  -56.599  48.809  1
615531  88.832  -52.481  57.331  4
615532  88.863  -52.503  57.324  4
615533  88.895  -52.526  57.316  4
615534  88.927  -52.548  57.311  4
615535  88.959  -52.571  57.306  4
615536  88.990  -52.593  57.300  4
615537  89.022  -52.616  57.294  4
615538  89.054  -52.639  57.287  4
615539  89.085  -52.662  57.281  4
615540  89.117  -52.684  57.276  4
615541  89.148  -52.707  57.271  4
615542  89.180  -52.730  57.265  4
615543  89.212  -52.753  57.260  4
615544  89.244  -52.775  57.254  4
615545  89.275  -52.798  57.248  4
615546  89.307  -52.821  57.244  4
615547  89.339  -52.844  57.239  4
615548  89.371  -52.863  57.234  4
615549  89.404  -52.883  57.230  4
615550  89.438  -52.902  57.226  4
615551  89.470  -52.922  57.222  4
615552  89.504  -52.941  57.218  4
615553  89.536  -52.956  57.214  4
615554  89.568  -52.964  57.210  4
615555  89.585  -52.986  57.206  4
615556  89.601  -53.008  57.201  4
615557  89.617  -53.030  57.197  4
615558  89.632  -53.053  57.192  4
615559  89.652  -53.073  57.187  4
615560  89.675  -53.090  57.182  4
615561  89.698  -53.107  57.178  4
615562  89.722  -53.125  57.173  4
615563  89.761  -53.149  57.167  4
615564  89.799  -53.154  57.160  4
615565  89.838  -53.160  57.152  4
615566  89.877  -53.165  57.145  4
615567  89.915  -53.170  57.137  4
615568  89.954  -53.176  57.131  4
615569  89.992  -53.181  57.123  4
615570  90.031  -53.186  57.110  4
615571  90.053  -53.193  57.095  4
615572  90.074  -53.201  57.081  4
615573  90.094  -53.208  57.068  4
615574  90.115  -53.215  57.054  4
615575  90.150  -53.235  57.037  4
615576  90.186  -53.255  57.019  4
615577  90.221  -53.275  56.999  4
615578  90.257  -53.295  56.978  4
615579  90.293  -53.315  56.956  4
615580  90.328  -53.336  56.933  4
615581  90.370  -53.349  56.909  4
615582  90.413  -53.360  56.881  4
615583  90.456  -53.371  56.851  4
615584  90.499  -53.383  56.821  4
615585  90.527  -53.399  56.790  4
615586  90.544  -53.419  56.758  4
615587  90.567  -53.433  56.727  4
615588  90.603  -53.435  56.693  4
615589  90.639  -53.437  56.658  4
615590  90.674  -53.439  56.624  4
615591  90.710  -53.440  56.592  4
615592  90.745  -53.442  56.560  4
615593  90.781  -53.444  56.531  4
615606  91.191  -53.688  55.865  1
615607  91.224  -53.709  55.837  1
615608  91.257  -53.728  55.811  1
615609  91.291  -53.748  55.787  1
615610  91.324  -53.768  55.764  1
615611  91.357  -53.787  55.743  1
615612  91.391  -53.808  55.721  1
615613  91.424  -53.828  55.701  1
615614  91.457  -53.847  55.682  1
615615  91.491  -53.867  55.664  1
615616  91.524  -53.887  55.647  1
615617  91.554  -53.907  55.631  1
615618  91.581  -53.928  55.617  1
615619  91.607  -53.949  55.602  1
615620  91.637  -53.971  55.588  1
615621  91.670  -53.996  55.574  1
615622  91.704  -54.020  55.559  1
615623  91.741  -54.038  55.543  1
615624  91.782  -54.051  55.527  1
615625  91.823  -54.065  55.511  1
615626  91.864  -54.079  55.495  1
615627  91.905  -54.091  55.480  1
615628  91.943  -54.104  55.464  1
615629  91.982  -54.117  55.449  1
615630  92.020  -54.129  55.435  1
615631  92.059  -54.142  55.423  1
615632  92.097  -54.154  55.409  1
615633  92.136  -54.167  55.396  1
615634  92.174  -54.179  55.382  1
615644  92.558  -54.304  55.296  1
615645  92.597  -54.317  55.293  1
615646  92.635  -54.329  55.292  1
615647  92.674  -54.341  55.292  1
615648  92.712  -54.354  55.295  1
615649  92.751  -54.366  55.299  1
615650  92.789  -54.379  55.304  1
615651  92.828  -54.391  55.309  1
615652  92.866  -54.404  55.314  1
615653  92.905  -54.416  55.321  1
615654  92.932  -54.439  55.329  1
615655  92.955  -54.468  55.338  1
615656  92.978  -54.497  55.348  1
615657  93.001  -54.526  55.357  1
615658  93.023  -54.555  55.366  1
615659  93.049  -54.573  55.376  1
615660  93.074  -54.586  55.390  1
615661  93.098  -54.599  55.402  1
615662  93.124  -54.613  55.409  1
615663  93.148  -54.627  55.410  1
615664  93.170  -54.637  55.409  1
615665  93.192  -54.646  55.405  1
615666  93.214  -54.656  55.400  1
615667  93.236  -54.666  55.395  1
615668  93.258  -54.676  55.399  1
615669  93.280  -54.686  55.413  1
615670  93.301  -54.703  55.431  1
615671  93.322  -54.727  55.447  1
615672  93.355  -54.736  55.458  1
615673  93.377  -54.749  55.461  1
615674  93.400  -54.762  55.463  1
615675  93.422  -54.775  55.471  1
615676  93.447  -54.790  55.486  1
615677  93.472  -54.803  55.502  1
615678  93.497  -54.817  55.515  1
615679  93.522  -54.831  55.519  1
615680  93.547  -54.845  55.515  1
615681  93.572  -54.859  55.503  1
615682  93.597  -54.872  55.486  1
615683  93.623  -54.886  55.464  1
615684  93.648  -54.900  55.440  1
615685  93.673  -54.914  55.427  1
615686  93.698  -54.928  55.408  1
615687  93.723  -54.941  55.385  1
615688  93.748  -54.955  55.367  1
615689  93.773  -54.969  55.351  1
615690  93.798  -54.983  55.334  1
615691  93.822  -55.000  55.312  1
615692  93.842  -55.025  55.288  1
615693  93.862  -55.049  55.263  1
615694  93.883  -55.073  55.239  1
615695  93.903  -55.097  55.215  1
615696  93.923  -55.121  55.191  1
615697  93.943  -55.145  55.168  1
615698  93.963  -55.169  55.149  1
615699  93.985  -55.190  55.133  1
615700  94.009  -55.207  55.119  1
615701  94.034  -55.223  55.104  1
615702  94.058  -55.240  55.086  1
615703  94.082  -55.257  55.066  1
615704  94.107  -55.273  55.043  1
615705  94.131  -55.290  55.017  1
615706  94.155  -55.307  54.989  1
615707  94.188  -55.319  54.961  1
615708  94.221  -55.331  54.934  1
615709  94.254  -55.342  54.909  1
615710  94.287  -55.354  54.877  1
615711  94.320  -55.367  54.841  1
615712  94.353  -55.379  54.797  1
615713  94.386  -55.390  54.749  1
615714  94.419  -55.402  54.703  1
615715  94.450  -55.412  54.665  1
615716  94.481  -55.421  54.632  1
615717  94.527  -55.433  54.600  1
615718  94.572  -55.446  54.569  1
615719  94.612  -55.458  54.535  1
615720  94.652  -55.471  54.500  1
615721  94.692  -55.484  54.465  1
615722  94.732  -55.497  54.429  1
615723  94.771  -55.510  54.393  1
615724  94.811  -55.523  54.356  1
615725  94.851  -55.536  54.312  1
615726  94.891  -55.549  54.264  1
615727  94.925  -55.559  54.212  1
615728  94.953  -55.569  54.158  1
615729  94.981  -55.579  54.104  1
615730  95.010  -55.589  54.047  1
615731  95.038  -55.599  53.986  1
615732  95.066  -55.610  53.927  1
615733  95.096  -55.626  53.868  1
615734  95.125  -55.642  53.806  1
615735  95.155  -55.658  53.742  1
615736  95.184  -55.674  53.682  1
615737  95.213  -55.690  53.625  1
615738  95.242  -55.705  53.569  1
615739  95.271  -55.722  53.510  1
615740  95.303  -55.736  53.445  1
615741  95.336  -55.749  53.374  1
615742  95.369  -55.762  53.302  1
615743  95.402  -55.775  53.229  1
615744  95.436  -55.787  53.157  1
615745  95.469  -55.799  53.087  1
615746  95.503  -55.812  53.019  1
615747  95.537  -55.824  52.951  1
615748  95.570  -55.837  52.884  1
615749  95.604  -55.849  52.815  1
615750  95.635  -55.862  52.745  1
615751  95.667  -55.876  52.674  1
615752  95.698  -55.890  52.605  1
615753  95.729  -55.903  52.536  1
615754  95.761  -55.917  52.466  1
615755  95.795  -55.931  52.398  1
615756  95.829  -55.944  52.331  1
615757  95.863  -55.958  52.266  1
615758  95.897  -55.972  52.202  1
615759  95.931  -55.986  52.139  1
615760  95.965  -56.000  52.078  1
615761  95.999  -56.014  52.019  1
615762  96.033  -56.028  51.961  1
615763  96.067  -56.041  51.901  1
615764  96.101  -56.055  51.839  1
615765  96.135  -56.069  51.775  1
615766  96.169  -56.083  51.711  1
615767  96.201  -56.088  51.649  1
615768  96.234  -56.090  51.585  1
615769  96.265  -56.092  51.522  1
615770  96.297  -56.094  51.461  1
615771  96.329  -56.096  51.399  1
615772  96.361  -56.097  51.338  1
615773  96.393  -56.100  51.283  1
615774  96.412  -56.101  51.230  1
615775  96.428  -56.102  51.177  1
615776  96.443  -56.103  51.125  1
615777  96.459  -56.104  51.074  1
615778  96.474  -56.106  51.024  1
615779  96.487  -56.107  50.980  1
615780  96.500  -56.108  50.937  1
615781  96.512  -56.110  50.893  1
615782  96.524  -56.110  50.850  1
615783  96.537  -56.112  50.808  1
615784  96.550  -56.113  50.767  1
615785  96.567  -56.112  50.730  1
615786  96.583  -56.111  50.694  1
615787  96.600  -56.110  50.659  1
615788  96.616  -56.109  50.623  1
615789  96.633  -56.108  50.589  1
615790  96.650  -56.107  50.554  1
615791  96.666  -56.107  50.523  1
615792  96.683  -56.106  50.492  1
615793  96.699  -56.105  50.462  1
615794  96.716  -56.104  50.432  1
615795  96.733  -56.103  50.402  1
615796  96.761  -56.103  50.373  1
615797  96.796  -56.101  50.348  1
615798  96.831  -56.100  50.323  1
615799  96.866  -56.099  50.298  1
615800  96.901  -56.098  50.272  1
615801  96.936  -56.097  50.247  1
615802  96.971  -56.096  50.223  1
615803  97.006  -56.095  50.200  1
615804  97.041  -56.094  50.177  1
615805  97.076  -56.093  50.155  1
615806  97.111  -56.092  50.132  1
615807  97.146  -56.091  50.109  1
615808  97.181  -56.090  50.086  1
615809  97.216  -56.089  50.066  1
615810  97.251  -56.088  50.045  1
615811  97.286  -56.087  50.025  1
615824  97.706  -56.073  49.812  1
615825  97.734  -56.072  49.801  1
615826  97.775  -56.080  49.790  1
615827  97.815  -56.088  49.780  1
615828  97.856  -56.097  49.772  1
615829  97.896  -56.106  49.763  1
615830  97.937  -56.114  49.754  1
615831  97.977  -56.123  49.744  1
615832  98.017  -56.132  49.734  1
615833  98.058  -56.140  49.724  1
616231  88.817  -52.434  57.330  4
616232  88.848  -52.456  57.323  4
616233  88.880  -52.479  57.316  4
616234  88.911  -52.502  57.308  4
616235  88.943  -52.525  57.303  4
616236  88.975  -52.547  57.297  4
616237  89.006  -52.570  57.291  4
616238  89.038  -52.593  57.285  4
616239  89.070  -52.615  57.279  4
616240  89.102  -52.638  57.272  4
616241  89.133  -52.660  57.266  4
616242  89.165  -52.683  57.261  4
616243  89.196  -52.706  57.255  4
616244  89.228  -52.728  57.250  4
616245  89.260  -52.751  57.245  4
616246  89.292  -52.772  57.238  4
616247  89.325  -52.792  57.233  4
616248  89.358  -52.811  57.229  4
616249  89.391  -52.831  57.224  4
616250  89.424  -52.850  57.219  4
616251  89.458  -52.869  57.215  4
616252  89.490  -52.888  57.211  4
616253  89.524  -52.908  57.208  4
616254  89.556  -52.923  57.204  4
616255  89.589  -52.930  57.200  4
616256  89.616  -52.943  57.196  4
616257  89.632  -52.965  57.192  4
616258  89.648  -52.987  57.188  4
616259  89.664  -53.010  57.184  4
616260  89.680  -53.032  57.179  4
616261  89.696  -53.054  57.175  4
616262  89.712  -53.076  57.170  4
616263  89.731  -53.096  57.166  4
616264  89.769  -53.104  57.161  4
616265  89.808  -53.109  57.155  4
616266  89.846  -53.114  57.148  4
616267  89.885  -53.120  57.141  4
616268  89.923  -53.125  57.133  4
616269  89.962  -53.130  57.127  4
616270  90.001  -53.136  57.120  4
616271  90.039  -53.141  57.109  4
616272  90.067  -53.148  57.096  4
616273  90.088  -53.154  57.084  4
616274  90.109  -53.162  57.071  4
616275  90.135  -53.174  57.058  4
616276  90.171  -53.195  57.043  4
616277  90.206  -53.214  57.027  4
616278  90.242  -53.235  57.009  4
616279  90.277  -53.255  56.990  4
616280  90.313  -53.275  56.970  4
616281  90.349  -53.295  56.950  4
616282  90.385  -53.314  56.929  4
616283  90.428  -53.326  56.903  4
616284  90.471  -53.337  56.876  4
616285  90.515  -53.349  56.847  4
616286  90.534  -53.368  56.818  4
616287  90.554  -53.385  56.787  4
616288  90.590  -53.386  56.756  4
616289  90.626  -53.388  56.722  4
616290  90.662  -53.390  56.687  4
616291  90.697  -53.392  56.652  4
616292  90.733  -53.393  56.619  4
616293  90.768  -53.395  56.586  4
616294  90.804  -53.397  56.557  4
616295  90.835  -53.412  56.524  4
616307  91.216  -53.652  55.881  1
616308  91.249  -53.672  55.854  1
616309  91.282  -53.691  55.828  1
616310  91.315  -53.711  55.803  1
616311  91.349  -53.731  55.779  1
616312  91.382  -53.751  55.758  1
616313  91.416  -53.771  55.736  1
616314  91.449  -53.791  55.714  1
616315  91.477  -53.811  55.694  1
616316  91.504  -53.832  55.676  1
616317  91.531  -53.853  55.659  1
616318  91.558  -53.873  55.642  1
616319  91.585  -53.894  55.624  1
616320  91.617  -53.918  55.610  1
616321  91.651  -53.943  55.595  1
616322  91.684  -53.967  55.578  1
616323  91.717  -53.991  55.562  1
616324  91.755  -54.009  55.546  1
616325  91.796  -54.022  55.530  1
616326  91.837  -54.036  55.514  1
616327  91.878  -54.050  55.498  1
616328  91.919  -54.063  55.482  1
616329  91.959  -54.076  55.466  1
616330  92.000  -54.090  55.451  1
616331  92.040  -54.103  55.437  1
616332  92.079  -54.116  55.424  1
616333  92.117  -54.128  55.410  1
616334  92.155  -54.141  55.396  1
616345  92.578  -54.277  55.297  1
616346  92.617  -54.290  55.295  1
616347  92.655  -54.302  55.294  1
616348  92.694  -54.315  55.294  1
616349  92.732  -54.327  55.298  1
616350  92.771  -54.340  55.302  1
616351  92.809  -54.352  55.307  1
616352  92.848  -54.364  55.312  1
616353  92.886  -54.377  55.318  1
616354  92.924  -54.389  55.326  1
616355  92.955  -54.410  55.334  1
616356  92.978  -54.439  55.344  1
616357  93.001  -54.467  55.353  1
616358  93.023  -54.496  55.361  1
616359  93.047  -54.525  55.369  1
616360  93.067  -54.548  55.375  1
616361  93.089  -54.557  55.384  1
616362  93.111  -54.567  55.391  1
616363  93.133  -54.577  55.393  1
616364  93.155  -54.587  55.390  1
616365  93.177  -54.596  55.386  1
616366  93.199  -54.605  55.381  1
616367  93.220  -54.615  55.376  1
616368  93.242  -54.625  55.375  1
616369  93.264  -54.635  55.384  1
616370  93.285  -54.658  55.397  1
616371  93.306  -54.681  55.412  1
616372  93.335  -54.697  55.425  1
616373  93.367  -54.706  55.434  1
616374  93.389  -54.720  55.440  1
616375  93.411  -54.733  55.448  1
616376  93.433  -54.746  55.464  1
616377  93.455  -54.759  55.485  1
616378  93.479  -54.773  55.504  1
616379  93.503  -54.787  55.513  1
616380  93.529  -54.801  55.514  1
616381  93.554  -54.815  55.505  1
616382  93.579  -54.828  55.492  1
616383  93.604  -54.842  55.475  1
616384  93.629  -54.856  55.451  1
616385  93.654  -54.870  55.424  1
616386  93.679  -54.884  55.408  1
616387  93.704  -54.897  55.391  1
616388  93.729  -54.912  55.370  1
616389  93.755  -54.925  55.352  1
616390  93.780  -54.939  55.339  1
616391  93.804  -54.953  55.323  1
616392  93.830  -54.967  55.302  1
616393  93.850  -54.991  55.279  1
616394  93.870  -55.016  55.256  1
616395  93.890  -55.040  55.233  1
616396  93.910  -55.064  55.210  1
616397  93.930  -55.088  55.185  1
616398  93.951  -55.112  55.160  1
616399  93.971  -55.136  55.138  1
616400  93.995  -55.154  55.124  1
616401  94.019  -55.170  55.117  1
616402  94.044  -55.187  55.110  1
616403  94.068  -55.204  55.097  1
616404  94.092  -55.220  55.080  1
616405  94.117  -55.237  55.059  1
616406  94.141  -55.254  55.035  1
616407  94.165  -55.270  55.010  1
616408  94.197  -55.283  54.984  1
616409  94.229  -55.295  54.956  1
616410  94.263  -55.307  54.928  1
616411  94.295  -55.319  54.896  1
616412  94.329  -55.331  54.858  1
616413  94.361  -55.342  54.813  1
616414  94.395  -55.354  54.765  1
616415  94.427  -55.367  54.720  1
616416  94.461  -55.378  54.683  1
616417  94.491  -55.388  54.650  1
616418  94.538  -55.400  54.617  1
616419  94.577  -55.413  54.584  1
616420  94.617  -55.426  54.547  1
616421  94.657  -55.439  54.509  1
616422  94.697  -55.451  54.472  1
616423  94.737  -55.464  54.434  1
616424  94.776  -55.477  54.396  1
616425  94.816  -55.489  54.357  1
616426  94.856  -55.502  54.311  1
616427  94.896  -55.515  54.260  1
616428  94.932  -55.527  54.208  1
616429  94.960  -55.536  54.152  1
616430  94.988  -55.546  54.098  1
616431  95.017  -55.556  54.043  1
616432  95.045  -55.567  53.986  1
616433  95.074  -55.583  53.927  1
616434  95.104  -55.599  53.868  1
616435  95.133  -55.614  53.806  1
616436  95.162  -55.630  53.743  1
616437  95.191  -55.646  53.686  1
616438  95.220  -55.662  53.632  1
616439  95.250  -55.678  53.578  1
616440  95.279  -55.694  53.520  1
616441  95.310  -55.709  53.456  1
616442  95.343  -55.721  53.385  1
616443  95.377  -55.734  53.311  1
616444  95.411  -55.746  53.237  1
616445  95.445  -55.758  53.163  1
616446  95.478  -55.771  53.091  1
616447  95.512  -55.783  53.024  1
616448  95.546  -55.795  52.957  1
616449  95.580  -55.807  52.893  1
616450  95.613  -55.819  52.827  1
616451  95.646  -55.832  52.756  1
616452  95.677  -55.846  52.685  1
616453  95.708  -55.859  52.616  1
616454  95.740  -55.873  52.547  1
616455  95.773  -55.887  52.477  1
616456  95.807  -55.901  52.407  1
616457  95.841  -55.915  52.339  1
616458  95.876  -55.928  52.273  1
616459  95.909  -55.942  52.207  1
616460  95.944  -55.956  52.144  1
616461  95.977  -55.970  52.081  1
616462  96.012  -55.984  52.022  1
616463  96.046  -55.998  51.963  1
616464  96.080  -56.012  51.903  1
616465  96.114  -56.025  51.841  1
616466  96.148  -56.039  51.779  1
616467  96.182  -56.053  51.716  1
616468  96.216  -56.066  51.655  1
616469  96.248  -56.068  51.592  1
616470  96.279  -56.070  51.529  1
616471  96.311  -56.072  51.466  1
616472  96.343  -56.074  51.403  1
616473  96.375  -56.076  51.343  1
616474  96.407  -56.078  51.286  1
616475  96.422  -56.079  51.231  1
616476  96.438  -56.080  51.176  1
616477  96.454  -56.081  51.122  1
616478  96.469  -56.082  51.069  1
616479  96.482  -56.084  51.017  1
616480  96.495  -56.085  50.971  1
616481  96.507  -56.086  50.926  1
616482  96.520  -56.088  50.881  1
616483  96.532  -56.088  50.836  1
616484  96.548  -56.088  50.793  1
616485  96.565  -56.088  50.750  1
616486  96.581  -56.087  50.713  1
616487  96.598  -56.086  50.675  1
616488  96.614  -56.085  50.638  1
616489  96.631  -56.084  50.602  1
616490  96.648  -56.083  50.566  1
616491  96.664  -56.082  50.531  1
616492  96.681  -56.081  50.500  1
616493  96.697  -56.081  50.468  1
616494  96.714  -56.080  50.437  1
616495  96.731  -56.079  50.407  1
616496  96.747  -56.078  50.377  1
616497  96.777  -56.077  50.348  1
616498  96.812  -56.076  50.322  1
616499  96.847  -56.075  50.297  1
616500  96.882  -56.074  50.271  1
616501  96.917  -56.073  50.246  1
616502  96.952  -56.072  50.222  1
616503  96.987  -56.071  50.196  1
616504  97.022  -56.070  50.172  1
616505  97.057  -56.069  50.149  1
616506  97.092  -56.068  50.128  1
616507  97.127  -56.067  50.104  1
616508  97.162  -56.066  50.080  1
616509  97.197  -56.065  50.057  1
616510  97.232  -56.064  50.037  1
616932  88.833  -52.410  57.324  4
616933  88.864  -52.432  57.316  4
616934  88.896  -52.455  57.308  4
616935  88.927  -52.477  57.301  4
616936  88.959  -52.500  57.294  4
616937  88.991  -52.523  57.288  4
616938  89.023  -52.546  57.282  4
616939  89.054  -52.568  57.275  4
616940  89.086  -52.591  57.269  4
616941  89.118  -52.614  57.262  4
616942  89.149  -52.637  57.256  4
616943  89.181  -52.659  57.251  4
616944  89.213  -52.681  57.245  4
616945  89.246  -52.700  57.239  4
616946  89.279  -52.720  57.234  4
616947  89.312  -52.739  57.228  4
616948  89.345  -52.759  57.222  4
616949  89.378  -52.778  57.218  4
616950  89.411  -52.797  57.213  4
616951  89.445  -52.816  57.208  4
616952  89.477  -52.836  57.205  4
616953  89.511  -52.855  57.200  4
616954  89.544  -52.875  57.197  4
616955  89.577  -52.889  57.194  4
616956  89.609  -52.897  57.190  4
616957  89.641  -52.905  57.187  4
616958  89.663  -52.922  57.183  4
616959  89.679  -52.944  57.180  4
616960  89.695  -52.966  57.176  4
616961  89.711  -52.988  57.172  4
616962  89.727  -53.010  57.167  4
616963  89.743  -53.032  57.164  4
616964  89.759  -53.054  57.160  4
616965  89.785  -53.064  57.156  4
616966  89.817  -53.064  57.151  4
616967  89.855  -53.070  57.143  4
616968  89.894  -53.075  57.136  4
616969  89.932  -53.080  57.130  4
616970  89.971  -53.086  57.123  4
616971  90.010  -53.091  57.118  4
616972  90.048  -53.096  57.108  4
616973  90.082  -53.102  57.097  4
616974  90.102  -53.109  57.086  4
616975  90.123  -53.117  57.074  4
616976  90.156  -53.134  57.063  4
616977  90.191  -53.154  57.050  4
616978  90.227  -53.174  57.035  4
616979  90.262  -53.195  57.019  4
616980  90.298  -53.214  57.002  4
616981  90.334  -53.235  56.985  4
616982  90.369  -53.255  56.969  4
616983  90.405  -53.275  56.950  4
616984  90.443  -53.292  56.928  4
616985  90.486  -53.303  56.902  4
616986  90.525  -53.316  56.875  4
616987  90.542  -53.336  56.848  4
616988  90.578  -53.338  56.817  4
616989  90.613  -53.339  56.787  4
616990  90.649  -53.341  56.752  4
616991  90.685  -53.343  56.717  4
616992  90.720  -53.345  56.681  4
616993  90.756  -53.346  56.647  4
616994  90.792  -53.349  56.614  4
616995  90.825  -53.355  56.583  4
616996  90.855  -53.375  56.551  4
616997  90.883  -53.396  56.519  4
616998  90.912  -53.416  56.488  4
617008  91.240  -53.615  55.900  1
617009  91.274  -53.634  55.872  1
617010  91.307  -53.654  55.845  1
617011  91.340  -53.675  55.820  1
617012  91.373  -53.694  55.795  1
617013  91.401  -53.715  55.773  1
617014  91.428  -53.735  55.751  1
617015  91.455  -53.756  55.729  1
617016  91.482  -53.777  55.708  1
617017  91.509  -53.798  55.689  1
617018  91.535  -53.819  55.671  1
617019  91.565  -53.841  55.652  1
617020  91.598  -53.865  55.634  1
617021  91.631  -53.890  55.618  1
617022  91.664  -53.914  55.601  1
617023  91.698  -53.938  55.585  1
617024  91.731  -53.963  55.568  1
617025  91.770  -53.980  55.551  1
617026  91.810  -53.994  55.534  1
617027  91.851  -54.007  55.518  1
617028  91.892  -54.020  55.502  1
617029  91.933  -54.034  55.486  1
617030  91.974  -54.048  55.469  1
617031  92.014  -54.061  55.453  1
617032  92.055  -54.075  55.439  1
617033  92.095  -54.088  55.426  1
617034  92.136  -54.101  55.411  1
617035  92.175  -54.114  55.397  1
617046  92.598  -54.251  55.298  1
617047  92.637  -54.264  55.296  1
617048  92.675  -54.276  55.295  1
617049  92.714  -54.289  55.295  1
617050  92.752  -54.301  55.300  1
617051  92.790  -54.314  55.304  1
617052  92.829  -54.326  55.309  1
617053  92.867  -54.339  55.315  1
617054  92.906  -54.351  55.322  1
617055  92.944  -54.364  55.330  1
617056  92.978  -54.381  55.341  1
617057  93.001  -54.410  55.351  1
617058  93.023  -54.439  55.359  1
617059  93.047  -54.467  55.366  1
617060  93.069  -54.496  55.372  1
617061  93.078  -54.508  55.375  1
617062  93.095  -54.517  55.378  1
617063  93.117  -54.526  55.379  1
617064  93.139  -54.536  55.377  1
617065  93.161  -54.546  55.371  1
617066  93.183  -54.555  55.365  1
617067  93.205  -54.565  55.360  1
617068  93.227  -54.574  55.356  1
617069  93.248  -54.589  55.359  1
617070  93.269  -54.613  55.369  1
617071  93.290  -54.637  55.382  1
617072  93.310  -54.660  55.396  1
617073  93.350  -54.667  55.408  1
617074  93.378  -54.678  55.417  1
617075  93.401  -54.690  55.425  1
617076  93.423  -54.704  55.438  1
617077  93.445  -54.717  55.458  1
617078  93.467  -54.731  55.480  1
617079  93.489  -54.744  55.498  1
617080  93.511  -54.757  55.505  1
617081  93.535  -54.771  55.501  1
617082  93.560  -54.784  55.492  1
617083  93.585  -54.799  55.480  1
617084  93.611  -54.812  55.463  1
617085  93.635  -54.826  55.438  1
617086  93.660  -54.840  55.407  1
617087  93.686  -54.853  55.390  1
617088  93.711  -54.868  55.374  1
617089  93.736  -54.881  55.356  1
617090  93.761  -54.895  55.341  1
617091  93.786  -54.909  55.328  1
617092  93.811  -54.923  55.312  1
617093  93.836  -54.937  55.292  1
617094  93.857  -54.959  55.270  1
617095  93.878  -54.983  55.248  1
617096  93.898  -55.007  55.228  1
617097  93.918  -55.031  55.205  1
617098  93.938  -55.055  55.180  1
617099  93.959  -55.079  55.153  1
617100  93.980  -55.101  55.130  1
617101  94.004  -55.117  55.121  1
617102  94.029  -55.134  55.119  1
617103  94.053  -55.151  55.117  1
617104  94.077  -55.167  55.108  1
617105  94.102  -55.184  55.095  1
617106  94.126  -55.201  55.077  1
617107  94.150  -55.217  55.053  1
617108  94.175  -55.234  55.029  1
617109  94.205  -55.247  55.003  1
617110  94.239  -55.259  54.974  1
617111  94.271  -55.271  54.943  1
617112  94.305  -55.283  54.912  1
617113  94.337  -55.295  54.872  1
617114  94.370  -55.307  54.827  1
617115  94.403  -55.319  54.779  1
617116  94.436  -55.330  54.734  1
617117  94.469  -55.342  54.697  1
617118  94.503  -55.354  54.664  1
617119  94.543  -55.367  54.631  1
617120  94.583  -55.379  54.596  1
617121  94.623  -55.392  54.557  1
617122  94.663  -55.405  54.517  1
617123  94.702  -55.418  54.478  1
617124  94.742  -55.431  54.438  1
617125  94.782  -55.443  54.398  1
617126  94.822  -55.456  54.357  1
617127  94.861  -55.469  54.309  1
617128  94.901  -55.482  54.257  1
617129  94.938  -55.494  54.204  1
617130  94.967  -55.504  54.148  1
617131  94.995  -55.514  54.095  1
617132  95.024  -55.524  54.043  1
617133  95.053  -55.539  53.987  1
617134  95.082  -55.555  53.929  1
617135  95.111  -55.571  53.868  1
617136  95.140  -55.586  53.805  1
617137  95.170  -55.602  53.743  1
617138  95.199  -55.619  53.687  1
617139  95.229  -55.635  53.633  1
617140  95.258  -55.650  53.579  1
617141  95.289  -55.665  53.522  1
617142  95.321  -55.678  53.458  1
617143  95.354  -55.691  53.388  1
617144  95.387  -55.704  53.314  1
617145  95.420  -55.717  53.240  1
617146  95.454  -55.729  53.166  1
617147  95.487  -55.741  53.094  1
617148  95.521  -55.753  53.024  1
617149  95.555  -55.765  52.957  1
617150  95.589  -55.778  52.895  1
617151  95.622  -55.790  52.829  1
617152  95.656  -55.803  52.760  1
617153  95.688  -55.816  52.691  1
617154  95.719  -55.830  52.623  1
617155  95.752  -55.843  52.553  1
617156  95.786  -55.857  52.484  1
617157  95.820  -55.871  52.414  1
617158  95.854  -55.885  52.345  1
617159  95.888  -55.899  52.278  1
617160  95.922  -55.912  52.212  1
617161  95.956  -55.926  52.147  1
617162  95.990  -55.940  52.085  1
617163  96.024  -55.954  52.024  1
617164  96.058  -55.968  51.964  1
617165  96.092  -55.982  51.904  1
617166  96.126  -55.996  51.844  1
617167  96.160  -56.009  51.782  1
617168  96.194  -56.023  51.721  1
617169  96.229  -56.038  51.661  1
617170  96.261  -56.046  51.599  1
617171  96.294  -56.048  51.536  1
617172  96.325  -56.050  51.472  1
617173  96.357  -56.052  51.409  1
617174  96.389  -56.054  51.348  1
617175  96.417  -56.056  51.290  1
617176  96.433  -56.057  51.233  1
617177  96.449  -56.058  51.177  1
617178  96.464  -56.059  51.121  1
617179  96.478  -56.060  51.066  1
617180  96.490  -56.062  51.013  1
617181  96.503  -56.063  50.964  1
617182  96.515  -56.064  50.917  1
617183  96.529  -56.065  50.870  1
617184  96.546  -56.064  50.824  1
617185  96.562  -56.063  50.779  1
617186  96.579  -56.063  50.736  1
617187  96.595  -56.061  50.697  1
617188  96.612  -56.060  50.658  1
617189  96.628  -56.059  50.621  1
617193  96.695  -56.056  50.479  1
617194  96.712  -56.056  50.448  1
617195  96.728  -56.055  50.417  1
617196  96.745  -56.054  50.386  1
617197  96.761  -56.053  50.355  1
617198  96.793  -56.052  50.326  1
617199  96.828  -56.051  50.300  1
617200  96.863  -56.050  50.274  1
617201  96.898  -56.049  50.248  1
617202  96.933  -56.048  50.222  1
617203  96.968  -56.047  50.196  1
617204  97.003  -56.046  50.171  1
617205  97.038  -56.045  50.149  1
617206  97.073  -56.044  50.126  1
617207  97.108  -56.043  50.103  1
617208  97.143  -56.042  50.079  1
617209  97.178  -56.041  50.055  1
617210  97.213  -56.040  50.033  1
617633  88.849  -52.386  57.317  4
617634  88.881  -52.409  57.308  4
617635  88.912  -52.431  57.300  4
617636  88.944  -52.454  57.292  4
617637  88.975  -52.477  57.285  4
617638  89.007  -52.499  57.279  4
617639  89.039  -52.522  57.273  4
617640  89.070  -52.544  57.266  4
617641  89.102  -52.567  57.259  4
617642  89.134  -52.590  57.252  4
617643  89.167  -52.609  57.246  4
617644  89.200  -52.629  57.241  4
617645  89.233  -52.648  57.235  4
617646  89.266  -52.668  57.229  4
617647  89.299  -52.687  57.223  4
617648  89.332  -52.706  57.217  4
617649  89.365  -52.725  57.212  4
617650  89.398  -52.744  57.207  4
617651  89.431  -52.764  57.202  4
617652  89.464  -52.783  57.199  4
617653  89.497  -52.803  57.195  4
617654  89.531  -52.822  57.190  4
617655  89.563  -52.841  57.187  4
617656  89.596  -52.856  57.183  4
617657  89.628  -52.863  57.180  4
617658  89.661  -52.872  57.178  4
617659  89.693  -52.879  57.175  4
617660  89.710  -52.901  57.172  4
617661  89.726  -52.923  57.168  4
617662  89.742  -52.945  57.164  4
617663  89.758  -52.967  57.161  4
617664  89.774  -52.989  57.157  4
617665  89.791  -53.011  57.154  4
617666  89.808  -53.032  57.151  4
617667  89.840  -53.032  57.146  4
617668  89.873  -53.032  57.139  4
617669  89.904  -53.032  57.133  4
617670  89.941  -53.035  57.127  4
617671  89.979  -53.040  57.121  4
617672  90.018  -53.045  57.116  4
617673  90.056  -53.051  57.108  4
617674  90.095  -53.056  57.098  4
617675  90.116  -53.064  57.088  4
617676  90.141  -53.073  57.078  4
617677  90.176  -53.094  57.068  4
617678  90.212  -53.114  57.057  4
617679  90.247  -53.134  57.044  4
617680  90.283  -53.154  57.030  4
617681  90.319  -53.174  57.015  4
617682  90.355  -53.195  57.001  4
617683  90.390  -53.214  56.987  4
617684  90.426  -53.235  56.972  4
617685  90.461  -53.255  56.952  4
617686  90.502  -53.269  56.930  4
617687  90.532  -53.285  56.905  4
617688  90.565  -53.289  56.878  4
617689  90.601  -53.291  56.849  4
617690  90.637  -53.292  56.819  4
617691  90.672  -53.295  56.785  4
617692  90.708  -53.296  56.748  4
617693  90.743  -53.298  56.712  4
617694  90.779  -53.300  56.677  4
617695  90.815  -53.302  56.643  4
617696  90.845  -53.319  56.612  4
617697  90.874  -53.339  56.579  4
617698  90.902  -53.359  56.547  4
617699  90.932  -53.379  56.516  4
617700  90.965  -53.399  56.486  4
617709  91.265  -53.577  55.920  1
617710  91.298  -53.598  55.891  1
617711  91.325  -53.618  55.864  1
617712  91.352  -53.639  55.837  1
617713  91.378  -53.660  55.813  1
617714  91.405  -53.681  55.790  1
617715  91.432  -53.701  55.766  1
617716  91.459  -53.722  55.744  1
617717  91.486  -53.743  55.723  1
617718  91.513  -53.764  55.702  1
617719  91.545  -53.787  55.683  1
617720  91.578  -53.812  55.663  1
617721  91.612  -53.837  55.645  1
617722  91.645  -53.861  55.627  1
617723  91.678  -53.885  55.610  1
617724  91.712  -53.910  55.592  1
617725  91.745  -53.935  55.574  1
617726  91.784  -53.951  55.557  1
617727  91.824  -53.965  55.540  1
617728  91.865  -53.979  55.524  1
617729  91.906  -53.991  55.507  1
617730  91.947  -54.005  55.490  1
617731  91.988  -54.019  55.473  1
617732  92.028  -54.032  55.456  1
617733  92.069  -54.046  55.442  1
617734  92.110  -54.059  55.428  1
617735  92.150  -54.073  55.413  1
617747  92.618  -54.225  55.298  1
617748  92.657  -54.238  55.297  1
617749  92.695  -54.250  55.297  1
617750  92.733  -54.262  55.296  1
617751  92.772  -54.275  55.301  1
617752  92.810  -54.287  55.305  1
617753  92.849  -54.300  55.311  1
617754  92.887  -54.312  55.318  1
617755  92.926  -54.325  55.325  1
617756  92.964  -54.337  55.335  1
617757  93.001  -54.352  55.348  1
617758  93.023  -54.380  55.359  1
617759  93.047  -54.409  55.366  1
617760  93.069  -54.438  55.371  1
617761  93.092  -54.467  55.375  1
617762  93.093  -54.471  55.375  1
617763  93.101  -54.476  55.373  1
617764  93.123  -54.485  55.368  1
617765  93.145  -54.495  55.362  1
617766  93.167  -54.505  55.354  1
617767  93.189  -54.515  55.346  1
617768  93.211  -54.524  55.340  1
617769  93.232  -54.544  55.340  1
617770  93.253  -54.568  55.345  1
617771  93.273  -54.591  55.355  1
617772  93.294  -54.615  55.369  1
617773  93.323  -54.631  55.383  1
617774  93.364  -54.637  55.393  1
617775  93.390  -54.648  55.403  1
617776  93.412  -54.662  55.413  1
617777  93.434  -54.674  55.429  1
617778  93.457  -54.688  55.451  1
617779  93.479  -54.702  55.472  1
617780  93.501  -54.715  55.486  1
617781  93.523  -54.728  55.491  1
617782  93.545  -54.741  55.484  1
617783  93.567  -54.755  55.474  1
617784  93.592  -54.768  55.461  1
617785  93.617  -54.782  55.443  1
617786  93.642  -54.796  55.420  1
617787  93.667  -54.810  55.392  1
617788  93.692  -54.824  55.375  1
617789  93.717  -54.837  55.364  1
617790  93.743  -54.851  55.350  1
617791  93.767  -54.866  55.335  1
617792  93.792  -54.879  55.321  1
617793  93.818  -54.893  55.302  1
617794  93.843  -54.906  55.282  1
617795  93.865  -54.925  55.262  1
617796  93.886  -54.950  55.242  1
617797  93.906  -54.974  55.223  1
617798  93.926  -54.998  55.201  1
617799  93.946  -55.022  55.176  1
617800  93.967  -55.046  55.147  1
617801  93.990  -55.064  55.125  1
617802  94.014  -55.081  55.118  1
617803  94.039  -55.097  55.121  1
617804  94.063  -55.114  55.122  1
617805  94.087  -55.131  55.117  1
617806  94.112  -55.148  55.107  1
617807  94.136  -55.164  55.090  1
617808  94.160  -55.181  55.069  1
617809  94.185  -55.198  55.046  1
617810  94.214  -55.211  55.019  1
617811  94.247  -55.223  54.989  1
617812  94.280  -55.235  54.955  1
617813  94.313  -55.247  54.922  1
617814  94.346  -55.259  54.881  1
617815  94.379  -55.271  54.836  1
617816  94.412  -55.282  54.788  1
617817  94.445  -55.295  54.741  1
617818  94.478  -55.307  54.704  1
617819  94.516  -55.318  54.669  1
617820  94.553  -55.332  54.637  1
617821  94.591  -55.345  54.602  1
617822  94.628  -55.359  54.563  1
617823  94.668  -55.372  54.522  1
617824  94.708  -55.385  54.483  1
617825  94.748  -55.398  54.441  1
617826  94.787  -55.411  54.399  1
617827  94.827  -55.423  54.357  1
617828  94.867  -55.436  54.309  1
617829  94.907  -55.448  54.255  1
617830  94.946  -55.461  54.202  1
617831  94.974  -55.471  54.149  1
617832  95.002  -55.481  54.096  1
617833  95.031  -55.495  54.045  1
617834  95.060  -55.511  53.990  1
617835  95.090  -55.527  53.930  1
617836  95.119  -55.543  53.868  1
617837  95.148  -55.559  53.805  1
617838  95.178  -55.575  53.742  1
617839  95.208  -55.589  53.686  1
617840  95.239  -55.605  53.631  1
617841  95.270  -55.620  53.576  1
617842  95.302  -55.633  53.518  1
617843  95.333  -55.646  53.455  1
617844  95.366  -55.660  53.386  1
617845  95.399  -55.672  53.314  1
617846  95.432  -55.685  53.241  1
617847  95.465  -55.698  53.167  1
617848  95.498  -55.711  53.094  1
617849  95.531  -55.724  53.023  1
617850  95.564  -55.737  52.956  1
617851  95.598  -55.749  52.891  1
617852  95.631  -55.761  52.826  1
617853  95.665  -55.773  52.760  1
617854  95.698  -55.786  52.695  1
617855  95.730  -55.799  52.629  1
617856  95.764  -55.813  52.561  1
617857  95.799  -55.828  52.490  1
617858  95.832  -55.841  52.420  1
617859  95.867  -55.855  52.350  1
617860  95.901  -55.869  52.282  1
617861  95.935  -55.883  52.215  1
617862  95.969  -55.897  52.150  1
617863  96.003  -55.910  52.088  1
617864  96.037  -55.925  52.027  1
617865  96.071  -55.938  51.967  1
617866  96.105  -55.952  51.907  1
617867  96.139  -55.966  51.846  1
617868  96.173  -55.980  51.785  1
617869  96.207  -55.994  51.725  1
617870  96.241  -56.007  51.665  1
617871  96.275  -56.022  51.604  1
617872  96.307  -56.026  51.542  1
617873  96.339  -56.028  51.479  1
617874  96.371  -56.031  51.416  1
617875  96.403  -56.032  51.354  1
617876  96.428  -56.034  51.295  1
617877  96.444  -56.035  51.237  1
617878  96.459  -56.036  51.179  1
617879  96.473  -56.038  51.121  1
617880  96.486  -56.038  51.065  1
617881  96.498  -56.040  51.010  1
617882  96.511  -56.041  50.958  1
617883  96.527  -56.041  50.910  1
617884  96.543  -56.040  50.861  1
617885  96.560  -56.039  50.813  1
617886  96.577  -56.038  50.768  1
617899  96.809  -56.027  50.305  1
617900  96.844  -56.026  50.279  1
617901  96.879  -56.025  50.252  1
617902  96.914  -56.024  50.227  1
617903  96.949  -56.023  50.200  1
617904  96.984  -56.022  50.174  1
617905  97.019  -56.021  50.149  1
617906  97.054  -56.020  50.127  1
617907  97.089  -56.019  50.104  1
617908  97.124  -56.018  50.081  1
617909  97.159  -56.016  50.057  1
618334  88.865  -52.362  57.310  4
618335  88.897  -52.384  57.300  4
618336  88.928  -52.407  57.292  4
618337  88.960  -52.430  57.284  4
618338  88.991  -52.452  57.277  4
618339  89.023  -52.475  57.270  4
618340  89.055  -52.498  57.264  4
618341  89.088  -52.518  57.256  4
618342  89.120  -52.537  57.249  4
618343  89.154  -52.557  57.242  4
618344  89.187  -52.576  57.236  4
618345  89.220  -52.596  57.231  4
618346  89.253  -52.615  57.225  4
618347  89.286  -52.634  57.219  4
618348  89.319  -52.653  57.213  4
618349  89.352  -52.673  57.207  4
618350  89.385  -52.692  57.201  4
618351  89.418  -52.712  57.197  4
618352  89.451  -52.731  57.192  4
618353  89.484  -52.750  57.189  4
618354  89.518  -52.769  57.185  4
618355  89.550  -52.789  57.181  4
618356  89.584  -52.808  57.177  4
618357  89.616  -52.822  57.174  4
618358  89.649  -52.830  57.172  4
618359  89.681  -52.838  57.169  4
618360  89.713  -52.846  57.167  4
618361  89.742  -52.858  57.164  4
618362  89.757  -52.880  57.160  4
618363  89.773  -52.902  57.157  4
618364  89.790  -52.924  57.155  4
618365  89.806  -52.946  57.151  4
618366  89.822  -52.969  57.149  4
618367  89.838  -52.991  57.146  4
618368  89.864  -52.999  57.142  4
618369  89.896  -52.998  57.136  4
618370  89.928  -52.998  57.131  4
618371  89.960  -52.998  57.126  4
618372  89.992  -52.998  57.121  4
618373  90.027  -53.001  57.116  4
618374  90.065  -53.006  57.109  4
618375  90.104  -53.011  57.101  4
618376  90.130  -53.017  57.092  4
618377  90.161  -53.033  57.083  4
618378  90.197  -53.054  57.073  4
618379  90.233  -53.073  57.063  4
618380  90.268  -53.094  57.052  4
618381  90.304  -53.114  57.041  4
618382  90.339  -53.134  57.029  4
618383  90.375  -53.154  57.017  4
618384  90.410  -53.174  57.006  4
618385  90.446  -53.195  56.993  4
618386  90.482  -53.214  56.977  4
618387  90.517  -53.235  56.958  4
618388  90.552  -53.241  56.935  4
618389  90.588  -53.242  56.909  4
618390  90.624  -53.244  56.881  4
618391  90.660  -53.246  56.850  4
618392  90.695  -53.248  56.816  4
618393  90.731  -53.249  56.780  4
618394  90.766  -53.251  56.743  4
618395  90.802  -53.253  56.707  4
618396  90.835  -53.262  56.675  4
618397  90.864  -53.282  56.642  4
618398  90.893  -53.302  56.609  4
618399  90.923  -53.323  56.577  4
618400  90.956  -53.342  56.545  4
618401  90.990  -53.362  56.515  4
618402  91.023  -53.382  56.486  4
618410  91.275  -53.543  55.941  1
618411  91.302  -53.564  55.912  1
618412  91.329  -53.584  55.884  1
618413  91.356  -53.605  55.857  1
618414  91.383  -53.626  55.831  1
618415  91.410  -53.646  55.807  1
618416  91.436  -53.667  55.784  1
618417  91.463  -53.688  55.760  1
618418  91.493  -53.710  55.738  1
618419  91.526  -53.734  55.717  1
618420  91.559  -53.759  55.696  1
618421  91.592  -53.784  55.676  1
618422  91.626  -53.808  55.657  1
618423  91.659  -53.833  55.639  1
618424  91.693  -53.857  55.621  1
618425  91.726  -53.882  55.602  1
618426  91.759  -53.907  55.582  1
618427  91.798  -53.922  55.564  1
618428  91.839  -53.936  55.548  1
618429  91.879  -53.949  55.530  1
618430  91.920  -53.963  55.513  1
618431  91.961  -53.976  55.495  1
618432  92.002  -53.990  55.477  1
618433  92.042  -54.004  55.460  1
618434  92.083  -54.016  55.445  1
618435  92.124  -54.030  55.430  1
618436  92.165  -54.044  55.415  1
618448  92.638  -54.198  55.299  1
618449  92.676  -54.211  55.298  1
618450  92.715  -54.223  55.298  1
618451  92.754  -54.236  55.298  1
618452  92.792  -54.248  55.301  1
618453  92.831  -54.261  55.307  1
618454  92.869  -54.273  55.313  1
618455  92.907  -54.286  55.320  1
618456  92.946  -54.298  55.328  1
618457  92.984  -54.311  55.340  1
618458  93.022  -54.323  55.355  1
618459  93.047  -54.351  55.366  1
618460  93.069  -54.380  55.373  1
618461  93.092  -54.408  55.376  1
618462  93.109  -54.430  55.377  1
618463  93.109  -54.433  55.373  1
618464  93.110  -54.435  55.366  1
618465  93.129  -54.444  55.356  1
618466  93.151  -54.454  55.346  1
618467  93.173  -54.464  55.336  1
618468  93.195  -54.475  55.327  1
618469  93.216  -54.499  55.323  1
618470  93.236  -54.523  55.326  1
618471  93.257  -54.546  55.333  1
618472  93.278  -54.570  55.343  1
618473  93.298  -54.593  55.357  1
618474  93.337  -54.601  55.372  1
618475  93.378  -54.606  55.382  1
618476  93.402  -54.619  55.391  1
618477  93.424  -54.632  55.403  1
618478  93.446  -54.646  55.421  1
618479  93.468  -54.659  55.443  1
618480  93.490  -54.672  55.461  1
618481  93.512  -54.686  55.469  1
618482  93.535  -54.699  55.473  1
618483  93.557  -54.712  55.463  1
618484  93.579  -54.725  55.452  1
618485  93.601  -54.739  55.439  1
618486  93.623  -54.753  55.422  1
618487  93.648  -54.766  55.404  1
618488  93.674  -54.780  55.385  1
618489  93.699  -54.793  55.375  1
618490  93.724  -54.807  55.365  1
618491  93.749  -54.822  55.351  1
618492  93.774  -54.835  55.334  1
618493  93.799  -54.849  55.315  1
618494  93.824  -54.862  55.293  1
618495  93.849  -54.877  55.272  1
618496  93.873  -54.893  55.253  1
618497  93.894  -54.916  55.234  1
618498  93.914  -54.941  55.216  1
618499  93.934  -54.965  55.195  1
618500  93.954  -54.989  55.169  1
618501  93.975  -55.011  55.139  1
618502  94.000  -55.028  55.119  1
618503  94.024  -55.044  55.116  1
618504  94.048  -55.061  55.120  1
618505  94.072  -55.078  55.124  1
618506  94.097  -55.094  55.122  1
618507  94.121  -55.111  55.114  1
618508  94.145  -55.128  55.098  1
618509  94.170  -55.144  55.081  1
618510  94.194  -55.161  55.059  1
618511  94.223  -55.176  55.032  1
618512  94.256  -55.187  55.001  1
618513  94.289  -55.199  54.965  1
618514  94.322  -55.211  54.928  1
618515  94.355  -55.223  54.886  1
618516  94.388  -55.235  54.842  1
618517  94.421  -55.247  54.794  1
618518  94.455  -55.259  54.746  1
618519  94.492  -55.270  54.708  1
618520  94.530  -55.282  54.673  1
618521  94.567  -55.295  54.639  1
618522  94.604  -55.309  54.605  1
618523  94.642  -55.323  54.566  1
618524  94.679  -55.336  54.524  1
618525  94.716  -55.350  54.483  1
618526  94.754  -55.364  54.441  1
618527  94.792  -55.377  54.397  1
618528  94.832  -55.390  54.354  1
618529  94.872  -55.403  54.306  1
618530  94.912  -55.416  54.254  1
618531  94.952  -55.428  54.203  1
618532  94.981  -55.439  54.150  1
618533  95.010  -55.452  54.096  1
618534  95.039  -55.467  54.043  1
618535  95.068  -55.483  53.986  1
618536  95.098  -55.499  53.925  1
618537  95.128  -55.514  53.862  1
618538  95.159  -55.530  53.798  1
618539  95.189  -55.545  53.737  1
618540  95.219  -55.559  53.680  1
618541  95.251  -55.574  53.624  1
618542  95.282  -55.588  53.567  1
618543  95.314  -55.601  53.509  1
618544  95.346  -55.614  53.447  1
618545  95.379  -55.628  53.381  1
618546  95.411  -55.641  53.311  1
618547  95.445  -55.654  53.239  1
618548  95.478  -55.666  53.165  1
618549  95.511  -55.679  53.092  1
618550  95.544  -55.692  53.020  1
618551  95.577  -55.705  52.953  1
618552  95.610  -55.718  52.886  1
618553  95.643  -55.730  52.820  1
618554  95.676  -55.743  52.757  1
618555  95.708  -55.756  52.696  1
618556  95.743  -55.770  52.633  1
618557  95.777  -55.784  52.566  1
618558  95.811  -55.797  52.494  1
618559  95.845  -55.812  52.423  1
618560  95.879  -55.825  52.353  1
618561  95.913  -55.839  52.284  1
618562  95.947  -55.853  52.218  1
618563  95.981  -55.867  52.153  1
618564  96.015  -55.881  52.091  1
618565  96.049  -55.894  52.031  1
618566  96.083  -55.909  51.971  1
618567  96.117  -55.922  51.910  1
618568  96.152  -55.936  51.850  1
618569  96.185  -55.950  51.790  1
618570  96.220  -55.964  51.729  1
618571  96.253  -55.978  51.670  1
618572  96.288  -55.991  51.610  1
618573  96.321  -56.005  51.549  1
618574  96.354  -56.006  51.487  1
618575  96.385  -56.009  51.424  1
618576  96.417  -56.010  51.361  1
618577  96.439  -56.012  51.301  1
618578  96.454  -56.013  51.242  1
618579  96.469  -56.014  51.182  1
618580  96.481  -56.016  51.124  1
618581  96.493  -56.017  51.066  1
618582  96.508  -56.017  51.009  1
618583  96.525  -56.016  50.956  1
618584  96.541  -56.016  50.906  1
618585  96.558  -56.015  50.855  1
618586  96.575  -56.013  50.806  1
618587  96.591  -56.013  50.759  1
619035  88.881  -52.338  57.302  4
619036  88.913  -52.361  57.292  4
619037  88.945  -52.384  57.284  4
619038  88.976  -52.406  57.275  4
619039  89.008  -52.427  57.268  4
619040  89.041  -52.446  57.261  4
619041  89.074  -52.466  57.254  4
619042  89.107  -52.485  57.246  4
619043  89.140  -52.505  57.239  4
619044  89.174  -52.524  57.232  4
619045  89.207  -52.543  57.226  4
619046  89.240  -52.562  57.220  4
619047  89.273  -52.581  57.214  4
619048  89.306  -52.601  57.209  4
619049  89.339  -52.620  57.203  4
619050  89.372  -52.640  57.196  4
619051  89.405  -52.659  57.191  4
619052  89.438  -52.678  57.187  4
619053  89.471  -52.697  57.183  4
619054  89.505  -52.717  57.179  4
619055  89.538  -52.736  57.176  4
619056  89.570  -52.756  57.171  4
619057  89.604  -52.775  57.168  4
619058  89.636  -52.789  57.165  4
619059  89.669  -52.797  57.163  4
619060  89.701  -52.805  57.161  4
619061  89.733  -52.813  57.158  4
619062  89.765  -52.821  57.156  4
619063  89.789  -52.837  57.153  4
619064  89.805  -52.859  57.151  4
619065  89.821  -52.881  57.149  4
619066  89.837  -52.903  57.146  4
619067  89.853  -52.926  57.143  4
619068  89.869  -52.948  57.141  4
619069  89.888  -52.966  57.138  4
619070  89.920  -52.966  57.134  4
619071  89.952  -52.966  57.129  4
619072  89.984  -52.966  57.125  4
619073  90.016  -52.966  57.120  4
619074  90.048  -52.966  57.116  4
619075  90.080  -52.966  57.111  4
619076  90.112  -52.966  57.104  4
619077  90.146  -52.973  57.097  4
619078  90.182  -52.993  57.088  4
619079  90.218  -53.013  57.080  4
619080  90.253  -53.033  57.072  4
619081  90.289  -53.054  57.063  4
619082  90.323  -53.074  57.053  4
619083  90.359  -53.095  57.043  4
619084  90.394  -53.116  57.033  4
619085  90.429  -53.136  57.024  4
619086  90.464  -53.157  57.014  4
619087  90.499  -53.177  57.002  4
619088  90.534  -53.198  56.986  4
619089  90.575  -53.195  56.965  4
619090  90.611  -53.195  56.939  4
619091  90.647  -53.197  56.912  4
619092  90.682  -53.199  56.882  4
619093  90.718  -53.201  56.848  4
619094  90.754  -53.202  56.811  4
619095  90.790  -53.205  56.774  4
619096  90.825  -53.206  56.738  4
619097  90.855  -53.226  56.706  4
619098  90.883  -53.245  56.673  4
619099  90.915  -53.266  56.639  4
619100  90.948  -53.286  56.607  4
619101  90.981  -53.305  56.576  4
619102  91.014  -53.325  56.545  4
619103  91.047  -53.345  56.516  4
619104  91.081  -53.365  56.488  4
619105  91.114  -53.385  56.458  4
619111  91.280  -53.509  55.963  1
619112  91.306  -53.530  55.933  1
619113  91.333  -53.550  55.905  1
619114  91.360  -53.571  55.879  1
619115  91.387  -53.592  55.851  1
619116  91.414  -53.612  55.826  1
619117  91.441  -53.633  55.802  1
619118  91.473  -53.657  55.778  1
619119  91.506  -53.681  55.755  1
619120  91.539  -53.706  55.733  1
619121  91.573  -53.731  55.712  1
619122  91.606  -53.755  55.691  1
619123  91.640  -53.780  55.670  1
619124  91.673  -53.804  55.651  1
619125  91.706  -53.828  55.632  1
619126  91.739  -53.853  55.612  1
619127  91.773  -53.878  55.592  1
619128  91.812  -53.894  55.573  1
619129  91.853  -53.907  55.555  1
619130  91.893  -53.920  55.537  1
619131  91.934  -53.934  55.519  1
619132  91.975  -53.947  55.500  1
619133  92.016  -53.961  55.482  1
619134  92.057  -53.975  55.465  1
619135  92.097  -53.988  55.448  1
619136  92.138  -54.001  55.433  1
619149  92.658  -54.173  55.299  1
619150  92.697  -54.185  55.298  1
619151  92.735  -54.198  55.298  1
619152  92.774  -54.210  55.298  1
619153  92.812  -54.223  55.302  1
619154  92.850  -54.235  55.307  1
619155  92.889  -54.247  55.314  1
619156  92.927  -54.260  55.321  1
619157  92.966  -54.272  55.329  1
619158  93.004  -54.285  55.344  1
619159  93.043  -54.297  55.360  1
619160  93.069  -54.322  55.372  1
619161  93.092  -54.351  55.379  1
619162  93.115  -54.380  55.380  1
619163  93.124  -54.392  55.378  1
619164  93.125  -54.395  55.369  1
619165  93.125  -54.398  55.356  1
619166  93.136  -54.404  55.342  1
619167  93.157  -54.413  55.329  1
619168  93.179  -54.430  55.317  1
619169  93.200  -54.454  55.310  1
619170  93.220  -54.477  55.308  1
619171  93.241  -54.502  55.313  1
619172  93.262  -54.525  55.321  1
619173  93.282  -54.549  55.332  1
619174  93.310  -54.565  55.346  1
619175  93.352  -54.571  55.360  1
619176  93.391  -54.577  55.371  1
619177  93.413  -54.590  55.380  1
619178  93.435  -54.603  55.391  1
619179  93.458  -54.616  55.410  1
619180  93.480  -54.630  55.430  1
619181  93.502  -54.643  55.444  1
619182  93.524  -54.656  55.449  1
619183  93.546  -54.670  55.447  1
619184  93.568  -54.683  55.437  1
619185  93.590  -54.696  55.426  1
619186  93.613  -54.709  55.413  1
619187  93.635  -54.723  55.399  1
619188  93.657  -54.737  55.387  1
619189  93.680  -54.750  55.384  1
619190  93.705  -54.764  55.383  1
619191  93.730  -54.778  55.373  1
619192  93.755  -54.791  55.355  1
619193  93.780  -54.805  55.333  1
619194  93.805  -54.819  55.307  1
619195  93.831  -54.833  55.283  1
619196  93.856  -54.847  55.260  1
619197  93.880  -54.860  55.242  1
619198  93.901  -54.884  55.225  1
619199  93.922  -54.908  55.207  1
619200  93.942  -54.932  55.186  1
619201  93.962  -54.956  55.158  1
619202  93.985  -54.975  55.128  1
619203  94.009  -54.991  55.113  1
619204  94.034  -55.008  55.111  1
619205  94.058  -55.025  55.115  1
619206  94.082  -55.041  55.118  1
619207  94.107  -55.058  55.117  1
619208  94.131  -55.075  55.112  1
619209  94.155  -55.091  55.101  1
619210  94.180  -55.108  55.084  1
619211  94.204  -55.125  55.064  1
619212  94.231  -55.139  55.038  1
619213  94.265  -55.151  55.004  1
619214  94.297  -55.163  54.968  1
619215  94.331  -55.176  54.930  1
619216  94.363  -55.187  54.888  1
619217  94.397  -55.199  54.844  1
619218  94.431  -55.211  54.798  1
619219  94.469  -55.223  54.750  1
619220  94.506  -55.234  54.711  1
619221  94.544  -55.246  54.674  1
619222  94.581  -55.258  54.639  1
619223  94.618  -55.273  54.604  1
619224  94.655  -55.286  54.565  1
619225  94.693  -55.300  54.523  1
619226  94.731  -55.314  54.480  1
619227  94.768  -55.327  54.437  1
619228  94.805  -55.341  54.392  1
619229  94.842  -55.355  54.346  1
619230  94.880  -55.369  54.299  1
619231  94.917  -55.383  54.249  1
619232  94.957  -55.395  54.198  1
619233  94.988  -55.408  54.147  1
619234  95.018  -55.423  54.092  1
619235  95.048  -55.439  54.036  1
619236  95.079  -55.454  53.977  1
619237  95.109  -55.469  53.915  1
619238  95.140  -55.484  53.852  1
619239  95.170  -55.499  53.788  1
619240  95.200  -55.514  53.726  1
619241  95.232  -55.529  53.666  1
619242  95.263  -55.542  53.608  1
619243  95.295  -55.555  53.551  1
619244  95.327  -55.569  53.492  1
619245  95.359  -55.583  53.431  1
619246  95.391  -55.596  53.366  1
619247  95.424  -55.609  53.300  1
619248  95.457  -55.622  53.231  1
619249  95.490  -55.635  53.159  1
619250  95.523  -55.648  53.086  1
619251  95.556  -55.660  53.015  1
619252  95.589  -55.673  52.946  1
619253  95.622  -55.686  52.879  1
619254  95.655  -55.699  52.814  1
619255  95.688  -55.712  52.753  1
619256  95.720  -55.723  52.693  1
619257  95.753  -55.736  52.631  1
619258  95.788  -55.751  52.565  1
619259  95.822  -55.765  52.494  1
619260  95.856  -55.780  52.423  1
619261  95.891  -55.795  52.353  1
619262  95.925  -55.809  52.285  1
619263  95.960  -55.823  52.220  1
619264  95.994  -55.837  52.156  1
619265  96.028  -55.851  52.094  1
619266  96.062  -55.865  52.034  1
619267  96.096  -55.878  51.974  1
619268  96.130  -55.893  51.913  1
619269  96.164  -55.906  51.854  1
619270  96.198  -55.920  51.795  1
619271  96.232  -55.934  51.733  1
619272  96.266  -55.948  51.674  1
619273  96.300  -55.962  51.615  1
619274  96.334  -55.975  51.556  1
619275  96.367  -55.984  51.495  1
619276  96.399  -55.987  51.432  1
619277  96.431  -55.989  51.368  1
619278  96.449  -55.990  51.308  1
619279  96.464  -55.991  51.247  1
619280  96.476  -55.992  51.187  1
619281  96.489  -55.994  51.127  1
619282  96.506  -55.993  51.068  1
619283  96.522  -55.992  51.008  1
619284  96.539  -55.991  50.954  1
619285  96.555  -55.991  50.901  1
619286  96.572  -55.989  50.850  1
619287  96.589  -55.988  50.800  1
619288  96.605  -55.987  50.751  1
619736  88.897  -52.314  57.294  4
619737  88.929  -52.336  57.284  4
619738  88.962  -52.355  57.275  4
619739  88.995  -52.374  57.266  4
619740  89.028  -52.394  57.258  4
619741  89.061  -52.413  57.251  4
619742  89.095  -52.433  57.245  4
619743  89.127  -52.452  57.237  4
619744  89.161  -52.471  57.230  4
619745  89.194  -52.490  57.222  4
619746  89.227  -52.510  57.215  4
619747  89.260  -52.529  57.210  4
619748  89.293  -52.549  57.204  4
619749  89.326  -52.568  57.198  4
619750  89.359  -52.587  57.192  4
619751  89.392  -52.606  57.186  4
619752  89.425  -52.626  57.181  4
619753  89.458  -52.645  57.177  4
619754  89.491  -52.665  57.173  4
619755  89.525  -52.684  57.168  4
619756  89.557  -52.703  57.166  4
619757  89.591  -52.722  57.163  4
619758  89.624  -52.741  57.159  4
619759  89.657  -52.756  57.157  4
619760  89.689  -52.763  57.155  4
619761  89.721  -52.772  57.153  4
619762  89.753  -52.779  57.150  4
619763  89.786  -52.788  57.148  4
619764  89.818  -52.795  57.146  4
619765  89.836  -52.816  57.144  4
619766  89.852  -52.838  57.143  4
619767  89.868  -52.860  57.140  4
619768  89.884  -52.882  57.138  4
619769  89.900  -52.904  57.137  4
619770  89.916  -52.926  57.135  4
619771  89.944  -52.933  57.130  4
619772  89.976  -52.933  57.127  4
619773  90.008  -52.933  57.124  4
619774  90.040  -52.933  57.120  4
619775  90.072  -52.933  57.117  4
619776  90.104  -52.933  57.113  4
619777  90.136  -52.933  57.106  4
619778  90.167  -52.935  57.101  4
619779  90.199  -52.957  57.094  4
619780  90.234  -52.977  57.087  4
619781  90.269  -52.998  57.081  4
619782  90.304  -53.019  57.074  4
619783  90.339  -53.039  57.065  4
619784  90.375  -53.060  57.057  4
619785  90.410  -53.080  57.049  4
619786  90.445  -53.101  57.042  4
619787  90.480  -53.122  57.036  4
619788  90.515  -53.142  57.029  4
619789  90.550  -53.163  57.018  4
619790  90.591  -53.161  57.000  4
619791  90.632  -53.153  56.969  4
619792  90.670  -53.151  56.941  4
619793  90.706  -53.152  56.911  4
619794  90.741  -53.154  56.878  4
619795  90.777  -53.156  56.842  4
619796  90.813  -53.158  56.805  4
619797  90.845  -53.169  56.770  4
619798  90.874  -53.189  56.736  4
619799  90.906  -53.209  56.704  4
619800  90.939  -53.229  56.671  4
619801  90.972  -53.248  56.637  4
619802  91.006  -53.268  56.607  4
619803  91.039  -53.289  56.576  4
619804  91.069  -53.308  56.548  4
619805  91.096  -53.330  56.519  4
619806  91.122  -53.350  56.489  4
619807  91.150  -53.371  56.459  4
619812  91.284  -53.474  55.989  1
619813  91.310  -53.496  55.958  1
619814  91.338  -53.516  55.929  1
619815  91.364  -53.537  55.901  1
619816  91.391  -53.558  55.873  1
619817  91.420  -53.580  55.848  1
619818  91.453  -53.604  55.823  1
619819  91.487  -53.628  55.797  1
619820  91.520  -53.653  55.773  1
619821  91.554  -53.678  55.750  1
619822  91.587  -53.702  55.728  1
619823  91.620  -53.727  55.707  1
619824  91.653  -53.751  55.685  1
619825  91.687  -53.775  55.665  1
619826  91.720  -53.800  55.645  1
619827  91.753  -53.825  55.624  1
619828  91.787  -53.849  55.604  1
619829  91.826  -53.865  55.583  1
619830  91.867  -53.878  55.565  1
619831  91.908  -53.891  55.546  1
619832  91.948  -53.905  55.526  1
619833  91.989  -53.919  55.507  1
619834  92.030  -53.932  55.489  1
619835  92.071  -53.945  55.470  1
619836  92.111  -53.959  55.453  1
619837  92.152  -53.972  55.437  1
619850  92.678  -54.146  55.299  1
619851  92.716  -54.159  55.297  1
619852  92.755  -54.171  55.297  1
619853  92.793  -54.183  55.298  1
619854  92.832  -54.196  55.301  1
619855  92.870  -54.208  55.307  1
619856  92.909  -54.221  55.313  1
619857  92.947  -54.233  55.320  1
619858  92.986  -54.246  55.327  1
619859  93.024  -54.258  55.341  1
619860  93.063  -54.270  55.358  1
619861  93.092  -54.292  55.370  1
619862  93.115  -54.321  55.376  1
619863  93.138  -54.350  55.377  1
619864  93.140  -54.355  55.372  1
619865  93.140  -54.357  55.359  1
619866  93.140  -54.360  55.343  1
619867  93.142  -54.363  55.326  1
619868  93.162  -54.386  55.310  1
619869  93.183  -54.409  55.298  1
619870  93.204  -54.433  55.293  1
619871  93.225  -54.456  55.293  1
619872  93.246  -54.480  55.298  1
619873  93.266  -54.504  55.308  1
619874  93.287  -54.527  55.321  1
619875  93.325  -54.535  55.335  1
619876  93.366  -54.540  55.348  1
619877  93.403  -54.547  55.359  1
619878  93.425  -54.561  55.367  1
619879  93.447  -54.574  55.378  1
619880  93.469  -54.587  55.395  1
619881  93.491  -54.601  55.411  1
619882  93.513  -54.614  55.422  1
619883  93.536  -54.627  55.426  1
619884  93.558  -54.640  55.420  1
619885  93.580  -54.654  55.411  1
619886  93.602  -54.667  55.401  1
619887  93.624  -54.681  55.392  1
619888  93.646  -54.694  55.387  1
619889  93.669  -54.707  55.390  1
619890  93.691  -54.721  55.391  1
619891  93.713  -54.734  55.388  1
619892  93.736  -54.747  55.377  1
619893  93.762  -54.761  55.356  1
619894  93.787  -54.775  55.328  1
619895  93.812  -54.789  55.297  1
619896  93.837  -54.803  55.268  1
619897  93.862  -54.816  55.247  1
619898  93.887  -54.831  55.229  1
619899  93.909  -54.850  55.213  1
619900  93.929  -54.875  55.196  1
619901  93.949  -54.899  55.174  1
619902  93.970  -54.922  55.145  1
619903  93.995  -54.939  55.115  1
619904  94.019  -54.956  55.105  1
619905  94.043  -54.972  55.104  1
619906  94.068  -54.988  55.107  1
619907  94.092  -55.005  55.110  1
619908  94.116  -55.022  55.109  1
619909  94.140  -55.038  55.106  1
619910  94.165  -55.055  55.098  1
619911  94.189  -55.072  55.083  1
619912  94.213  -55.088  55.064  1
619913  94.241  -55.104  55.039  1
619914  94.273  -55.116  55.005  1
619915  94.307  -55.128  54.969  1
619916  94.339  -55.139  54.930  1
619917  94.372  -55.151  54.889  1
619918  94.407  -55.163  54.847  1
619919  94.445  -55.175  54.802  1
619920  94.482  -55.186  54.754  1
619921  94.520  -55.198  54.711  1
619922  94.557  -55.210  54.671  1
619923  94.595  -55.222  54.634  1
619924  94.632  -55.235  54.597  1
619925  94.670  -55.249  54.558  1
619926  94.707  -55.263  54.514  1
619927  94.744  -55.277  54.471  1
619928  94.782  -55.291  54.425  1
619929  94.819  -55.304  54.378  1
619930  94.856  -55.318  54.332  1
619931  94.894  -55.332  54.286  1
619932  94.931  -55.346  54.238  1
619933  94.967  -55.361  54.187  1
619934  94.999  -55.378  54.138  1
619935  95.029  -55.393  54.082  1
619936  95.060  -55.408  54.025  1
619937  95.090  -55.423  53.964  1
619938  95.120  -55.439  53.901  1
619939  95.151  -55.454  53.839  1
619940  95.181  -55.469  53.776  1
619941  95.212  -55.483  53.712  1
619942  95.244  -55.497  53.649  1
619943  95.276  -55.510  53.589  1
619944  95.308  -55.524  53.531  1
619945  95.340  -55.537  53.471  1
619946  95.372  -55.551  53.409  1
619947  95.404  -55.564  53.346  1
619948  95.436  -55.577  53.284  1
619949  95.469  -55.590  53.219  1
619950  95.502  -55.603  53.150  1
619951  95.535  -55.616  53.077  1
619952  95.568  -55.629  53.007  1
619953  95.601  -55.642  52.937  1
619954  95.634  -55.654  52.870  1
619955  95.668  -55.667  52.804  1
619956  95.700  -55.679  52.741  1
619957  95.730  -55.690  52.680  1
619958  95.763  -55.702  52.618  1
619959  95.798  -55.717  52.552  1
619960  95.832  -55.732  52.484  1
619961  95.867  -55.746  52.417  1
619962  95.901  -55.761  52.350  1
619963  95.936  -55.775  52.285  1
619964  95.970  -55.790  52.222  1
619965  96.005  -55.805  52.160  1
619966  96.039  -55.819  52.098  1
619967  96.074  -55.834  52.038  1
619968  96.108  -55.849  51.978  1
619969  96.143  -55.862  51.918  1
619970  96.177  -55.877  51.858  1
619971  96.210  -55.890  51.798  1
619972  96.245  -55.904  51.736  1
619973  96.278  -55.919  51.677  1
619974  96.313  -55.932  51.619  1
619975  96.347  -55.946  51.560  1
619976  96.381  -55.959  51.501  1
619977  96.413  -55.965  51.440  1
619978  96.444  -55.967  51.376  1
619979  96.459  -55.968  51.315  1
619980  96.472  -55.969  51.253  1
619981  96.487  -55.969  51.192  1
619982  96.504  -55.969  51.130  1
619983  96.520  -55.968  51.069  1
619984  96.537  -55.967  51.008  1
619985  96.553  -55.966  50.951  1
619986  96.570  -55.965  50.897  1
619987  96.587  -55.964  50.845  1
619988  96.603  -55.963  50.793  1
619989  96.620  -55.962  50.744  1
620437  88.916  -52.283  57.285  4
620438  88.949  -52.303  57.275  4
620439  88.982  -52.322  57.266  4
620440  89.015  -52.342  57.257  4
620441  89.048  -52.361  57.249  4
620442  89.082  -52.380  57.242  4
620443  89.114  -52.399  57.235  4
620444  89.147  -52.418  57.227  4
620445  89.181  -52.438  57.219  4
620446  89.213  -52.457  57.212  4
620447  89.247  -52.477  57.205  4
620448  89.280  -52.496  57.199  4
620449  89.313  -52.515  57.193  4
620450  89.346  -52.534  57.188  4
620451  89.379  -52.554  57.182  4
620452  89.412  -52.573  57.176  4
620453  89.445  -52.593  57.171  4
620454  89.478  -52.612  57.167  4
620455  89.512  -52.631  57.163  4
620456  89.544  -52.650  57.159  4
620457  89.578  -52.670  57.157  4
620458  89.611  -52.689  57.154  4
620459  89.644  -52.709  57.151  4
620460  89.676  -52.722  57.149  4
620461  89.708  -52.730  57.147  4
620462  89.741  -52.738  57.144  4
620463  89.773  -52.746  57.143  4
620464  89.806  -52.754  57.141  4
620465  89.838  -52.762  57.139  4
620466  89.867  -52.772  57.137  4
620467  89.883  -52.794  57.137  4
620468  89.899  -52.817  57.135  4
620469  89.915  -52.839  57.134  4
620470  89.932  -52.861  57.133  4
620471  89.948  -52.883  57.131  4
620472  89.967  -52.901  57.128  4
620473  90.000  -52.901  57.126  4
620474  90.031  -52.901  57.124  4
620475  90.063  -52.901  57.121  4
620476  90.096  -52.900  57.118  4
620477  90.127  -52.900  57.115  4
620478  90.160  -52.900  57.111  4
620479  90.192  -52.900  57.105  4
620480  90.218  -52.921  57.100  4
620481  90.250  -52.941  57.095  4
620482  90.286  -52.963  57.090  4
620483  90.320  -52.983  57.084  4
620484  90.356  -53.004  57.077  4
620485  90.391  -53.024  57.071  4
620486  90.426  -53.045  57.065  4
620487  90.461  -53.066  57.060  4
620488  90.497  -53.086  57.057  4
620489  90.531  -53.107  57.055  4
620490  90.567  -53.127  57.048  4
620491  90.607  -53.125  57.030  4
620492  90.648  -53.117  56.998  4
620493  90.689  -53.111  56.968  4
620494  90.729  -53.105  56.938  4
620495  90.764  -53.107  56.906  4
620496  90.800  -53.109  56.872  4
620497  90.835  -53.112  56.837  4
620498  90.864  -53.132  56.802  4
620499  90.897  -53.152  56.769  4
620500  90.931  -53.172  56.737  4
620501  90.964  -53.192  56.704  4
620502  90.993  -53.212  56.671  4
620503  91.019  -53.233  56.640  4
620504  91.046  -53.254  56.610  4
620505  91.073  -53.274  56.580  4
620506  91.100  -53.295  56.551  4
620507  91.127  -53.316  56.521  4
620508  91.154  -53.336  56.490  4
620509  91.180  -53.358  56.460  4
620513  91.288  -53.440  56.015  1
620514  91.315  -53.462  55.984  1
620515  91.342  -53.482  55.954  1
620516  91.368  -53.502  55.925  1
620517  91.401  -53.527  55.897  1
620518  91.434  -53.551  55.871  1
620519  91.467  -53.576  55.845  1
620520  91.501  -53.600  55.819  1
620521  91.534  -53.625  55.794  1
620522  91.567  -53.650  55.769  1
620523  91.601  -53.674  55.747  1
620524  91.634  -53.698  55.724  1
620525  91.667  -53.723  55.702  1
620526  91.701  -53.747  55.680  1
620527  91.734  -53.772  55.658  1
620528  91.768  -53.797  55.637  1
620529  91.801  -53.821  55.616  1
620530  91.841  -53.836  55.595  1
620531  91.881  -53.849  55.575  1
620532  91.922  -53.863  55.555  1
620533  91.962  -53.876  55.535  1
620534  92.003  -53.890  55.515  1
620535  92.044  -53.903  55.497  1
620536  92.085  -53.916  55.477  1
620537  92.126  -53.930  55.459  1
620551  92.696  -54.119  55.298  1
620552  92.736  -54.132  55.297  1
620553  92.775  -54.145  55.296  1
620554  92.813  -54.157  55.297  1
620555  92.852  -54.170  55.300  1
620556  92.890  -54.182  55.305  1
620557  92.929  -54.195  55.311  1
620558  92.967  -54.207  55.317  1
620559  93.006  -54.220  55.324  1
620560  93.044  -54.232  55.336  1
620561  93.082  -54.245  55.353  1
620562  93.115  -54.263  55.364  1
620563  93.138  -54.292  55.369  1
620564  93.155  -54.314  55.367  1
620565  93.155  -54.317  55.359  1
620566  93.156  -54.320  55.342  1
620567  93.156  -54.323  55.325  1
620568  93.167  -54.345  55.306  1
620569  93.177  -54.366  55.291  1
620570  93.188  -54.388  55.281  1
620571  93.208  -54.411  55.276  1
620572  93.229  -54.435  55.277  1
620573  93.250  -54.458  55.284  1
620574  93.271  -54.482  55.296  1
620575  93.298  -54.499  55.310  1
620576  93.339  -54.505  55.323  1
620577  93.380  -54.510  55.335  1
620578  93.414  -54.518  55.346  1
620579  93.436  -54.531  55.353  1
620580  93.459  -54.545  55.363  1
620581  93.481  -54.558  55.377  1
620582  93.503  -54.571  55.390  1
620583  93.525  -54.585  55.397  1
620584  93.547  -54.598  55.400  1
620585  93.569  -54.612  55.392  1
620586  93.591  -54.624  55.385  1
620587  93.614  -54.638  55.379  1
620588  93.636  -54.651  55.376  1
620589  93.658  -54.665  55.378  1
620590  93.680  -54.678  55.388  1
620591  93.702  -54.691  55.391  1
620592  93.724  -54.705  55.386  1
620593  93.747  -54.718  55.372  1
620594  93.769  -54.731  55.348  1
620595  93.793  -54.745  55.317  1
620596  93.818  -54.759  55.281  1
620597  93.843  -54.773  55.248  1
620598  93.868  -54.787  55.228  1
620599  93.894  -54.800  55.212  1
620600  93.917  -54.818  55.198  1
620601  93.937  -54.842  55.181  1
620602  93.958  -54.866  55.160  1
620603  93.980  -54.886  55.130  1
620604  94.004  -54.903  55.102  1
620605  94.029  -54.919  55.094  1
620606  94.053  -54.936  55.094  1
620607  94.077  -54.953  55.095  1
620608  94.102  -54.969  55.098  1
620609  94.126  -54.985  55.098  1
620610  94.150  -55.002  55.096  1
620611  94.175  -55.019  55.089  1
620612  94.199  -55.035  55.077  1
620613  94.223  -55.052  55.059  1
620614  94.249  -55.068  55.035  1
620615  94.282  -55.080  55.003  1
620616  94.315  -55.091  54.968  1
620617  94.348  -55.104  54.929  1
620618  94.384  -55.116  54.890  1
620619  94.421  -55.127  54.850  1
620620  94.459  -55.138  54.807  1
620621  94.496  -55.151  54.759  1
620622  94.534  -55.162  54.713  1
620623  94.571  -55.173  54.669  1
620624  94.609  -55.185  54.628  1
620625  94.646  -55.199  54.588  1
620626  94.684  -55.213  54.546  1
620627  94.721  -55.226  54.501  1
620628  94.758  -55.240  54.454  1
620629  94.795  -55.254  54.406  1
620630  94.833  -55.268  54.358  1
620631  94.871  -55.282  54.310  1
620632  94.908  -55.295  54.262  1
620633  94.944  -55.311  54.213  1
620634  94.976  -55.328  54.165  1
620635  95.008  -55.346  54.115  1
620636  95.041  -55.363  54.062  1
620637  95.071  -55.378  54.006  1
620638  95.101  -55.393  53.947  1
620639  95.132  -55.408  53.885  1
620640  95.162  -55.423  53.822  1
620641  95.193  -55.438  53.758  1
620642  95.225  -55.452  53.693  1
620643  95.257  -55.464  53.628  1
620644  95.289  -55.478  53.566  1
620645  95.321  -55.492  53.506  1
620646  95.353  -55.505  53.445  1
620647  95.385  -55.519  53.383  1
620648  95.416  -55.533  53.322  1
620649  95.449  -55.546  53.263  1
620650  95.481  -55.559  53.202  1
620651  95.515  -55.571  53.136  1
620652  95.548  -55.584  53.067  1
620653  95.581  -55.597  52.997  1
620654  95.614  -55.610  52.927  1
620655  95.647  -55.623  52.860  1
620656  95.680  -55.636  52.793  1
620657  95.710  -55.646  52.729  1
620658  95.741  -55.657  52.666  1
620659  95.773  -55.669  52.604  1
620660  95.808  -55.683  52.540  1
620661  95.842  -55.698  52.476  1
620662  95.877  -55.712  52.412  1
620663  95.911  -55.727  52.349  1
620664  95.946  -55.742  52.285  1
620665  95.980  -55.756  52.224  1
620666  96.015  -55.771  52.163  1
620667  96.049  -55.786  52.102  1
620668  96.084  -55.800  52.042  1
620669  96.118  -55.815  51.982  1
620670  96.153  -55.830  51.922  1
620671  96.187  -55.844  51.863  1
620672  96.222  -55.859  51.802  1
620673  96.256  -55.874  51.739  1
620674  96.291  -55.888  51.681  1
620675  96.325  -55.903  51.622  1
620676  96.359  -55.916  51.563  1
620677  96.393  -55.930  51.504  1
620678  96.427  -55.943  51.444  1
620679  96.454  -55.945  51.380  1
620680  96.468  -55.946  51.318  1
620681  96.484  -55.945  51.256  1
620682  96.501  -55.944  51.194  1
620683  96.518  -55.944  51.131  1
620684  96.534  -55.943  51.069  1
620685  96.551  -55.941  51.008  1
620686  96.568  -55.940  50.950  1
620687  96.584  -55.940  50.895  1
620688  96.601  -55.939  50.840  1
620689  96.617  -55.938  50.787  1
620690  96.634  -55.937  50.736  1
621138  88.936  -52.250  57.277  4
621139  88.969  -52.270  57.267  4
621140  89.002  -52.289  57.258  4
621141  89.035  -52.308  57.249  4
621142  89.068  -52.327  57.240  4
621143  89.101  -52.347  57.232  4
621144  89.134  -52.366  57.225  4
621145  89.168  -52.386  57.217  4
621146  89.200  -52.405  57.209  4
621147  89.234  -52.424  57.201  4
621148  89.267  -52.443  57.194  4
621149  89.300  -52.463  57.188  4
621150  89.333  -52.482  57.183  4
621151  89.366  -52.501  57.178  4
621152  89.399  -52.521  57.173  4
621153  89.432  -52.540  57.167  4
621154  89.465  -52.559  57.161  4
621155  89.498  -52.578  57.158  4
621156  89.531  -52.598  57.154  4
621157  89.564  -52.617  57.151  4
621158  89.598  -52.637  57.148  4
621159  89.630  -52.656  57.145  4
621160  89.664  -52.675  57.142  4
621162  89.729  -52.697  57.139  4
621163  89.761  -52.705  57.137  4
621164  89.793  -52.713  57.136  4
621165  89.825  -52.721  57.135  4
621166  89.858  -52.728  57.133  4
621167  89.890  -52.737  57.132  4
621168  89.914  -52.751  57.132  4
621169  89.931  -52.774  57.131  4
621170  89.947  -52.796  57.130  4
621171  89.963  -52.818  57.129  4
621172  89.979  -52.840  57.128  4
621173  89.995  -52.862  57.126  4
621174  90.023  -52.868  57.125  4
621175  90.055  -52.867  57.124  4
621176  90.087  -52.867  57.123  4
621177  90.119  -52.867  57.121  4
621178  90.152  -52.867  57.119  4
621179  90.183  -52.867  57.116  4
621180  90.216  -52.867  57.111  4
621181  90.243  -52.884  57.107  4
621182  90.268  -52.906  57.103  4
621183  90.302  -52.927  57.100  4
621184  90.336  -52.948  57.097  4
621185  90.372  -52.968  57.091  4
621186  90.407  -52.988  57.085  4
621187  90.442  -53.010  57.082  4
621188  90.477  -53.030  57.078  4
621189  90.513  -53.051  57.077  4
621190  90.547  -53.071  57.078  4
621191  90.583  -53.092  57.075  4
621192  90.623  -53.089  57.053  4
621193  90.664  -53.082  57.024  4
621194  90.705  -53.075  56.994  4
621195  90.746  -53.068  56.964  4
621196  90.787  -53.061  56.933  4
621197  90.823  -53.062  56.900  4
621198  90.855  -53.076  56.867  4
621199  90.888  -53.095  56.834  4
621200  90.916  -53.116  56.801  4
621201  90.943  -53.137  56.770  4
621202  90.970  -53.158  56.739  4
621203  90.997  -53.178  56.706  4
621204  91.024  -53.199  56.675  4
621205  91.050  -53.220  56.645  4
621206  91.077  -53.240  56.614  4
621207  91.104  -53.261  56.585  4
621208  91.131  -53.282  56.556  4
621209  91.158  -53.302  56.525  4
621210  91.185  -53.324  56.494  4
621211  91.212  -53.344  56.465  4
621212  91.238  -53.365  56.436  4
621214  91.292  -53.406  56.043  1
621215  91.319  -53.427  56.011  1
621216  91.348  -53.449  55.980  1
621217  91.381  -53.474  55.950  1
621218  91.415  -53.498  55.922  1
621219  91.448  -53.523  55.895  1
621220  91.482  -53.547  55.868  1
621221  91.515  -53.571  55.841  1
621222  91.548  -53.596  55.816  1
621223  91.581  -53.621  55.790  1
621224  91.614  -53.645  55.767  1
621225  91.648  -53.670  55.743  1
621226  91.681  -53.694  55.720  1
621227  91.715  -53.719  55.697  1
621228  91.748  -53.744  55.674  1
621229  91.781  -53.768  55.652  1
621230  91.814  -53.792  55.630  1
621231  91.855  -53.807  55.608  1
621232  91.895  -53.820  55.587  1
621233  91.936  -53.834  55.566  1
621234  91.977  -53.847  55.545  1
621235  92.017  -53.861  55.525  1
621236  92.058  -53.874  55.504  1
621237  92.099  -53.888  55.484  1
621238  92.140  -53.901  55.464  1
621252  92.710  -54.090  55.296  1
621253  92.751  -54.104  55.294  1
621254  92.792  -54.117  55.294  1
621255  92.833  -54.131  55.294  1
621256  92.872  -54.144  55.297  1
621257  92.910  -54.156  55.301  1
621258  92.948  -54.168  55.307  1
621259  92.987  -54.181  55.312  1
621260  93.025  -54.193  55.318  1
621261  93.064  -54.206  55.329  1
621262  93.102  -54.218  55.345  1
621263  93.138  -54.234  55.355  1
621264  93.161  -54.263  55.358  1
621265  93.171  -54.276  55.354  1
621266  93.171  -54.279  55.342  1
621267  93.172  -54.284  55.323  1
621268  93.183  -54.306  55.304  1
621269  93.193  -54.327  55.286  1
621270  93.204  -54.349  55.272  1
621271  93.214  -54.370  55.263  1
621272  93.224  -54.392  55.260  1
621273  93.234  -54.414  55.262  1
621274  93.254  -54.437  55.270  1
621275  93.275  -54.461  55.283  1
621276  93.312  -54.469  55.296  1
621277  93.354  -54.474  55.308  1
621278  93.395  -54.480  55.320  1
621279  93.426  -54.489  55.329  1
621280  93.448  -54.502  55.336  1
621281  93.470  -54.515  55.344  1
621282  93.492  -54.529  55.355  1
621283  93.514  -54.543  55.365  1
621284  93.537  -54.555  55.371  1
621285  93.559  -54.569  55.371  1
621286  93.581  -54.582  55.364  1
621287  93.603  -54.596  55.361  1
621288  93.625  -54.609  55.362  1
621289  93.647  -54.622  55.365  1
621290  93.670  -54.636  55.373  1
621291  93.692  -54.649  55.380  1
621292  93.714  -54.662  55.384  1
621293  93.736  -54.675  55.378  1
621294  93.758  -54.689  55.361  1
621295  93.780  -54.702  55.334  1
621296  93.802  -54.715  55.300  1
621297  93.825  -54.729  55.261  1
621298  93.850  -54.743  55.228  1
621299  93.875  -54.756  55.210  1
621300  93.900  -54.770  55.197  1
621301  93.925  -54.784  55.183  1
621302  93.945  -54.809  55.166  1
621303  93.966  -54.833  55.144  1
621304  93.990  -54.850  55.112  1
621305  94.014  -54.866  55.090  1
621306  94.038  -54.883  55.084  1
621307  94.063  -54.900  55.084  1
621308  94.087  -54.916  55.085  1
621309  94.111  -54.933  55.088  1
621310  94.135  -54.950  55.087  1
621311  94.160  -54.966  55.084  1
621312  94.184  -54.982  55.076  1
621313  94.208  -54.999  55.064  1
621314  94.232  -55.016  55.047  1
621315  94.258  -55.032  55.026  1
621316  94.291  -55.044  54.998  1
621317  94.324  -55.056  54.963  1
621318  94.360  -55.067  54.927  1
621319  94.398  -55.079  54.890  1
621320  94.435  -55.091  54.852  1
621321  94.473  -55.103  54.812  1
621322  94.510  -55.114  54.767  1
621323  94.548  -55.126  54.718  1
621324  94.585  -55.138  54.669  1
621325  94.623  -55.149  54.622  1
621326  94.660  -55.163  54.577  1
621327  94.698  -55.176  54.532  1
621328  94.735  -55.190  54.484  1
621329  94.772  -55.204  54.434  1
621330  94.810  -55.217  54.385  1
621331  94.847  -55.231  54.335  1
621332  94.884  -55.245  54.285  1
621333  94.920  -55.260  54.235  1
621334  94.953  -55.278  54.184  1
621335  94.985  -55.295  54.137  1
621336  95.018  -55.314  54.088  1
621337  95.051  -55.332  54.037  1
621338  95.082  -55.348  53.983  1
621339  95.113  -55.363  53.925  1
621340  95.143  -55.378  53.864  1
621341  95.174  -55.392  53.801  1
621342  95.206  -55.406  53.736  1
621343  95.238  -55.419  53.670  1
621344  95.270  -55.433  53.605  1
621345  95.302  -55.446  53.540  1
621346  95.334  -55.460  53.477  1
621347  95.366  -55.474  53.415  1
621348  95.397  -55.487  53.353  1
621349  95.429  -55.501  53.293  1
621350  95.461  -55.514  53.236  1
621351  95.494  -55.527  53.176  1
621352  95.527  -55.540  53.115  1
621353  95.560  -55.553  53.052  1
621354  95.593  -55.565  52.987  1
621355  95.626  -55.578  52.918  1
621356  95.659  -55.591  52.851  1
621357  95.691  -55.603  52.784  1
621358  95.722  -55.614  52.719  1
621359  95.752  -55.624  52.656  1
621360  95.783  -55.635  52.594  1
621361  95.818  -55.650  52.533  1
621362  95.852  -55.665  52.470  1
621363  95.887  -55.679  52.409  1
621364  95.921  -55.693  52.349  1
621365  95.956  -55.709  52.287  1
621366  95.990  -55.723  52.227  1
621367  96.025  -55.737  52.166  1
621368  96.059  -55.752  52.107  1
621369  96.094  -55.767  52.047  1
621370  96.128  -55.781  51.986  1
621371  96.163  -55.796  51.926  1
621372  96.197  -55.811  51.866  1
621373  96.232  -55.825  51.806  1
621374  96.266  -55.840  51.744  1
621375  96.301  -55.855  51.685  1
621376  96.336  -55.869  51.626  1
621377  96.370  -55.884  51.566  1
621378  96.405  -55.899  51.507  1
621379  96.439  -55.913  51.448  1
621380  96.466  -55.922  51.384  1
621381  96.482  -55.921  51.322  1
621382  96.499  -55.920  51.259  1
621383  96.516  -55.919  51.195  1
621384  96.532  -55.919  51.132  1
621385  96.549  -55.917  51.069  1
621386  96.566  -55.916  51.007  1
621387  96.582  -55.915  50.948  1
621388  96.599  -55.915  50.891  1
621389  96.615  -55.914  50.836  1
621390  96.632  -55.913  50.782  1
621391  96.649  -55.912  50.729  1
621839  88.956  -52.217  57.269  4
621840  88.989  -52.236  57.259  4
621841  89.022  -52.255  57.249  4
621842  89.055  -52.275  57.240  4
621843  89.088  -52.294  57.230  4
621844  89.121  -52.314  57.223  4
621845  89.155  -52.333  57.215  4
621846  89.187  -52.352  57.207  4
621847  89.221  -52.371  57.199  4
621848  89.254  -52.391  57.191  4
621849  89.287  -52.410  57.183  4
621850  89.320  -52.430  57.178  4
621851  89.353  -52.449  57.173  4
621852  89.386  -52.468  57.168  4
621853  89.419  -52.487  57.163  4
621854  89.452  -52.507  57.157  4
621855  89.485  -52.526  57.153  4
621856  89.518  -52.546  57.148  4
621857  89.551  -52.565  57.145  4
621858  89.585  -52.584  57.142  4
621859  89.617  -52.603  57.139  4
621860  89.651  -52.622  57.137  4
621864  89.781  -52.672  57.129  4
621865  89.813  -52.679  57.129  4
621866  89.845  -52.687  57.129  4
621867  89.878  -52.695  57.128  4
621868  89.910  -52.703  57.127  4
621869  89.942  -52.712  57.127  4
621870  89.962  -52.731  57.127  4
621871  89.978  -52.753  57.127  4
621872  89.994  -52.775  57.127  4
621873  90.010  -52.797  57.127  4
621874  90.026  -52.819  57.126  4
621875  90.047  -52.835  57.126  4
621876  90.079  -52.835  57.127  4
621877  90.111  -52.835  57.128  4
621878  90.143  -52.835  57.127  4
621879  90.175  -52.835  57.125  4
621880  90.207  -52.835  57.122  4
621881  90.239  -52.835  57.119  4
621882  90.267  -52.847  57.116  4
621883  90.293  -52.869  57.113  4
621884  90.318  -52.891  57.111  4
621885  90.353  -52.912  57.110  4
621886  90.388  -52.933  57.104  4
621887  90.423  -52.954  57.101  4
621888  90.458  -52.974  57.099  4
621889  90.494  -52.995  57.096  4
621890  90.529  -53.015  57.095  4
621891  90.564  -53.036  57.095  4
621892  90.599  -53.057  57.090  4
621893  90.639  -53.054  57.069  4
621894  90.680  -53.047  57.042  4
621895  90.721  -53.040  57.014  4
621896  90.762  -53.032  56.986  4
621897  90.803  -53.026  56.958  4
621898  90.844  -53.022  56.927  4
621899  90.867  -53.040  56.895  4
621900  90.893  -53.061  56.865  4
621901  90.921  -53.082  56.834  4
621902  90.947  -53.103  56.804  4
621903  90.974  -53.123  56.774  4
621904  91.001  -53.144  56.742  4
621905  91.028  -53.165  56.711  4
621906  91.054  -53.186  56.681  4
621907  91.082  -53.206  56.651  4
621908  91.108  -53.227  56.621  4
621909  91.135  -53.248  56.592  4
621910  91.162  -53.268  56.561  4
621911  91.189  -53.289  56.530  4
621912  91.216  -53.310  56.499  4
621913  91.243  -53.331  56.470  4
621914  91.270  -53.352  56.441  4
621953  92.724  -54.061  55.294  1
621954  92.765  -54.075  55.292  1
621955  92.806  -54.088  55.291  1
621956  92.847  -54.102  55.290  1
621957  92.887  -54.115  55.292  1
621958  92.928  -54.129  55.296  1
621959  92.969  -54.142  55.300  1
621960  93.007  -54.154  55.304  1
621961  93.046  -54.167  55.311  1
621962  93.084  -54.179  55.322  1
621963  93.123  -54.192  55.336  1
621964  93.161  -54.204  55.344  1
621965  93.184  -54.233  55.344  1
621966  93.187  -54.239  55.338  1
621967  93.189  -54.245  55.322  1
621968  93.199  -54.267  55.300  1
621969  93.209  -54.289  55.280  1
621970  93.220  -54.311  55.264  1
621971  93.230  -54.332  55.253  1
621972  93.240  -54.354  55.246  1
621973  93.251  -54.375  55.243  1
621974  93.261  -54.397  55.246  1
621975  93.271  -54.418  55.255  1
621976  93.287  -54.434  55.268  1
621977  93.327  -54.439  55.280  1
621978  93.368  -54.444  55.291  1
621979  93.409  -54.449  55.303  1
621980  93.437  -54.460  55.310  1
621981  93.460  -54.473  55.317  1
621982  93.482  -54.486  55.324  1
621983  93.504  -54.500  55.332  1
621984  93.526  -54.513  55.340  1
621985  93.548  -54.527  55.345  1
621986  93.570  -54.540  55.344  1
621987  93.592  -54.553  55.340  1
621988  93.615  -54.566  55.342  1
621989  93.637  -54.580  55.346  1
621990  93.659  -54.593  55.352  1
621991  93.681  -54.606  55.360  1
621992  93.703  -54.620  55.365  1
621993  93.725  -54.633  55.363  1
621994  93.748  -54.646  55.354  1
621995  93.770  -54.659  55.335  1
621996  93.792  -54.673  55.308  1
621997  93.814  -54.687  55.275  1
621998  93.836  -54.699  55.238  1
621999  93.858  -54.713  55.207  1
622000  93.882  -54.727  55.194  1
622001  93.907  -54.740  55.184  1
622002  93.931  -54.754  55.170  1
622003  93.953  -54.775  55.151  1
622004  93.975  -54.797  55.125  1
622005  93.999  -54.813  55.095  1
622006  94.024  -54.830  55.079  1
622007  94.048  -54.847  55.075  1
622008  94.072  -54.863  55.077  1
622009  94.097  -54.880  55.078  1
622010  94.121  -54.897  55.080  1
622011  94.145  -54.913  55.077  1
622012  94.170  -54.930  55.070  1
622013  94.194  -54.947  55.060  1
622014  94.218  -54.963  55.047  1
622015  94.243  -54.979  55.031  1
622016  94.267  -54.996  55.012  1
622017  94.300  -55.008  54.983  1
622018  94.337  -55.019  54.950  1
622019  94.374  -55.032  54.917  1
622020  94.412  -55.043  54.884  1
622021  94.449  -55.055  54.849  1
622022  94.487  -55.066  54.809  1
622023  94.524  -55.078  54.765  1
622024  94.562  -55.090  54.717  1
622025  94.599  -55.101  54.667  1
622026  94.637  -55.113  54.616  1
622027  94.674  -55.126  54.566  1
622028  94.711  -55.139  54.516  1
622029  94.749  -55.154  54.462  1
622030  94.786  -55.167  54.411  1
622031  94.824  -55.181  54.360  1
622032  94.861  -55.195  54.309  1
622033  94.897  -55.209  54.258  1
622034  94.930  -55.227  54.205  1
622035  94.963  -55.245  54.151  1
622036  94.995  -55.263  54.105  1
622037  95.028  -55.281  54.056  1
622038  95.060  -55.298  54.007  1
622039  95.093  -55.317  53.956  1
622040  95.124  -55.332  53.900  1
622041  95.155  -55.347  53.840  1
622042  95.187  -55.361  53.777  1
622043  95.219  -55.373  53.712  1
622044  95.251  -55.387  53.645  1
622045  95.282  -55.401  53.579  1
622046  95.315  -55.414  53.513  1
622047  95.346  -55.428  53.448  1
622048  95.378  -55.442  53.386  1
622049  95.410  -55.455  53.325  1
622050  95.442  -55.469  53.265  1
622051  95.474  -55.483  53.207  1
622052  95.506  -55.495  53.149  1
622053  95.539  -55.508  53.089  1
622054  95.572  -55.521  53.031  1
622055  95.605  -55.534  52.972  1
622056  95.638  -55.547  52.907  1
622057  95.671  -55.559  52.842  1
622058  95.702  -55.570  52.777  1
622059  95.732  -55.580  52.714  1
622060  95.763  -55.591  52.652  1
622061  95.793  -55.602  52.592  1
622062  95.828  -55.616  52.532  1
622063  95.862  -55.630  52.471  1
622064  95.897  -55.646  52.411  1
622065  95.931  -55.660  52.351  1
622066  95.966  -55.674  52.291  1
622067  96.001  -55.690  52.232  1
622068  96.035  -55.704  52.172  1
622069  96.070  -55.718  52.112  1
622070  96.104  -55.734  52.052  1
622071  96.138  -55.748  51.991  1
622072  96.173  -55.762  51.930  1
622073  96.207  -55.777  51.870  1
622074  96.242  -55.792  51.809  1
622075  96.276  -55.806  51.749  1
622076  96.311  -55.821  51.690  1
622077  96.346  -55.836  51.630  1
622078  96.380  -55.850  51.570  1
622079  96.413  -55.862  51.511  1
622080  96.444  -55.873  51.449  1
622081  96.479  -55.894  51.388  1
622082  96.497  -55.896  51.325  1
622083  96.513  -55.895  51.261  1
622084  96.530  -55.893  51.197  1
622085  96.546  -55.893  51.132  1
622086  96.563  -55.892  51.068  1
622087  96.580  -55.891  51.005  1
622088  96.596  -55.890  50.946  1
622089  96.613  -55.890  50.888  1
622090  96.629  -55.889  50.832  1
622091  96.646  -55.888  50.777  1
622092  96.663  -55.887  50.723  1
622541  89.009  -52.203  57.251  4
622542  89.042  -52.223  57.241  4
622543  89.075  -52.242  57.231  4
622544  89.108  -52.261  57.220  4
622545  89.141  -52.280  57.213  4
622546  89.175  -52.300  57.204  4
622547  89.207  -52.319  57.197  4
622548  89.241  -52.338  57.190  4
622549  89.274  -52.358  57.181  4
622550  89.307  -52.377  57.173  4
622551  89.340  -52.396  57.169  4
622552  89.373  -52.415  57.164  4
622553  89.406  -52.435  57.158  4
622554  89.439  -52.454  57.153  4
622555  89.472  -52.474  57.148  4
622556  89.505  -52.493  57.143  4
622557  89.538  -52.512  57.139  4
622558  89.571  -52.531  57.136  4
622559  89.605  -52.551  57.134  4
622565  89.801  -52.638  57.124  4
622566  89.833  -52.646  57.123  4
622567  89.866  -52.654  57.122  4
622568  89.898  -52.662  57.122  4
622569  89.930  -52.670  57.122  4
622570  89.962  -52.678  57.122  4
622571  89.993  -52.687  57.123  4
622572  90.009  -52.709  57.124  4
622573  90.025  -52.731  57.125  4
622574  90.041  -52.753  57.126  4
622575  90.057  -52.775  57.126  4
622576  90.074  -52.798  57.128  4
622577  90.103  -52.802  57.131  4
622578  90.134  -52.802  57.134  4
622579  90.167  -52.802  57.134  4
622580  90.199  -52.802  57.133  4
622581  90.231  -52.802  57.131  4
622582  90.263  -52.802  57.129  4
622583  90.293  -52.810  57.127  4
622584  90.318  -52.832  57.126  4
622585  90.343  -52.854  57.124  4
622586  90.369  -52.877  57.123  4
622587  90.404  -52.897  57.118  4
622588  90.439  -52.918  57.117  4
622589  90.474  -52.938  57.116  4
622590  90.510  -52.959  57.114  4
622591  90.544  -52.980  57.112  4
622592  90.580  -53.001  57.110  4
622593  90.615  -53.021  57.101  4
622594  90.655  -53.019  57.082  4
622595  90.696  -53.011  57.058  4
622596  90.737  -53.004  57.032  4
622597  90.778  -52.998  57.007  4
622598  90.819  -52.990  56.982  4
622599  90.860  -52.995  56.953  4
622600  90.888  -53.007  56.924  4
622601  90.898  -53.027  56.894  4
622602  90.925  -53.048  56.866  4
622603  90.951  -53.069  56.839  4
622604  90.978  -53.089  56.810  4
622605  91.005  -53.110  56.779  4
622606  91.032  -53.131  56.748  4
622607  91.059  -53.151  56.719  4
622608  91.086  -53.172  56.689  4
622609  91.112  -53.193  56.659  4
622610  91.140  -53.214  56.629  4
622611  91.166  -53.234  56.597  4
622612  91.193  -53.255  56.566  4
622613  91.220  -53.276  56.534  4
622614  91.247  -53.297  56.504  4
622615  91.276  -53.319  56.475  4
622616  91.309  -53.343  56.445  4
622617  91.343  -53.368  56.413  4
622618  91.376  -53.392  56.383  4
622619  91.409  -53.417  56.355  4
622620  91.442  -53.441  56.326  4
622621  91.476  -53.466  56.298  4
622622  91.509  -53.490  56.270  4
622623  91.542  -53.515  56.242  4
622624  91.576  -53.540  56.215  4
622625  91.609  -53.564  56.189  4
622626  91.642  -53.588  56.163  4
622627  91.676  -53.613  56.137  4
622628  91.709  -53.637  56.111  4
622629  91.742  -53.662  56.086  4
622630  91.776  -53.687  56.060  4
622631  91.809  -53.711  56.033  4
622632  91.843  -53.735  56.007  4
622633  91.883  -53.749  55.981  4
622634  91.924  -53.762  55.955  4
622635  91.964  -53.776  55.929  4
622636  92.005  -53.790  55.902  4
622637  92.046  -53.803  55.876  4
622638  92.087  -53.816  55.850  4
622654  92.738  -54.032  55.292  1
622655  92.779  -54.046  55.289  1
622656  92.820  -54.060  55.286  1
622657  92.861  -54.073  55.285  1
622658  92.902  -54.086  55.286  1
622659  92.942  -54.100  55.288  1
622660  92.983  -54.113  55.291  1
622661  93.024  -54.127  55.295  1
622662  93.064  -54.140  55.301  1
622663  93.104  -54.153  55.313  1
622664  93.142  -54.166  55.324  1
622665  93.181  -54.178  55.329  1
622666  93.202  -54.198  55.327  1
622667  93.205  -54.207  55.316  1
622668  93.215  -54.229  55.298  1
622669  93.226  -54.250  55.276  1
622670  93.236  -54.272  55.258  1
622671  93.247  -54.293  55.244  1
622672  93.256  -54.314  55.235  1
622673  93.265  -54.333  55.229  1
622674  93.274  -54.353  55.227  1
622675  93.283  -54.373  55.230  1
622676  93.292  -54.393  55.237  1
622677  93.312  -54.407  55.248  1
622678  93.350  -54.411  55.261  1
622679  93.389  -54.415  55.272  1
622680  93.427  -54.420  55.284  1
622681  93.452  -54.431  55.291  1
622682  93.474  -54.444  55.296  1
622683  93.495  -54.458  55.302  1
622684  93.517  -54.471  55.308  1
622685  93.538  -54.484  55.315  1
622686  93.560  -54.497  55.319  1
622687  93.582  -54.511  55.318  1
622688  93.604  -54.524  55.318  1
622689  93.626  -54.537  55.322  1
622690  93.648  -54.551  55.329  1
622691  93.671  -54.564  55.336  1
622692  93.693  -54.577  55.342  1
622693  93.715  -54.590  55.341  1
622694  93.737  -54.604  55.334  1
622695  93.759  -54.617  55.320  1
622696  93.781  -54.630  55.300  1
622697  93.803  -54.644  55.273  1
622698  93.826  -54.657  55.242  1
622699  93.848  -54.671  55.212  1
622700  93.870  -54.684  55.191  1
622701  93.892  -54.697  55.180  1
622702  93.914  -54.710  55.169  1
622703  93.938  -54.724  55.153  1
622704  93.961  -54.743  55.132  1
622705  93.985  -54.760  55.105  1
622706  94.009  -54.777  55.079  1
622707  94.033  -54.793  55.072  1
622708  94.058  -54.810  55.073  1
622709  94.082  -54.827  55.075  1
622710  94.106  -54.844  55.076  1
622711  94.131  -54.860  55.076  1
622712  94.155  -54.877  55.067  1
622713  94.179  -54.894  55.054  1
622714  94.203  -54.910  55.041  1
622715  94.228  -54.927  55.027  1
622716  94.252  -54.943  55.013  1
622717  94.277  -54.960  54.994  1
622718  94.313  -54.972  54.963  1
622719  94.351  -54.984  54.933  1
622720  94.388  -54.995  54.902  1
622721  94.426  -55.007  54.871  1
622722  94.463  -55.019  54.838  1
622723  94.501  -55.030  54.800  1
622724  94.538  -55.042  54.758  1
622725  94.576  -55.054  54.711  1
622726  94.613  -55.065  54.660  1
622727  94.651  -55.077  54.607  1
622728  94.688  -55.089  54.554  1
622729  94.725  -55.103  54.501  1
622730  94.763  -55.116  54.444  1
622731  94.800  -55.130  54.389  1
622732  94.837  -55.144  54.334  1
622733  94.874  -55.159  54.281  1
622734  94.907  -55.176  54.227  1
622735  94.939  -55.195  54.173  1
622736  94.972  -55.212  54.119  1
622737  95.004  -55.230  54.072  1
622738  95.037  -55.248  54.023  1
622739  95.069  -55.266  53.975  1
622740  95.103  -55.284  53.926  1
622741  95.136  -55.300  53.873  1
622742  95.168  -55.314  53.814  1
622743  95.200  -55.328  53.751  1
622744  95.232  -55.342  53.684  1
622745  95.264  -55.355  53.617  1
622746  95.296  -55.369  53.551  1
622747  95.327  -55.383  53.487  1
622748  95.359  -55.396  53.422  1
622749  95.391  -55.410  53.360  1
622750  95.423  -55.423  53.299  1
622751  95.455  -55.437  53.237  1
622752  95.487  -55.451  53.178  1
622753  95.519  -55.464  53.120  1
622754  95.551  -55.477  53.063  1
622755  95.585  -55.489  53.008  1
622756  95.618  -55.502  52.954  1
622757  95.651  -55.515  52.897  1
622758  95.682  -55.527  52.835  1
622759  95.712  -55.537  52.773  1
622760  95.743  -55.548  52.713  1
622761  95.773  -55.558  52.653  1
622762  95.804  -55.569  52.594  1
622763  95.838  -55.583  52.535  1
622764  95.872  -55.597  52.475  1
622765  95.907  -55.611  52.416  1
622766  95.941  -55.627  52.357  1
622767  95.976  -55.641  52.298  1
622768  96.011  -55.655  52.239  1
622769  96.045  -55.671  52.179  1
622770  96.080  -55.685  52.119  1
622771  96.114  -55.699  52.059  1
622772  96.149  -55.714  51.999  1
622773  96.183  -55.729  51.938  1
622774  96.218  -55.743  51.877  1
622775  96.252  -55.758  51.815  1
622776  96.287  -55.773  51.755  1
622777  96.321  -55.787  51.695  1
622778  96.355  -55.801  51.634  1
622779  96.386  -55.811  51.574  1
622780  96.417  -55.821  51.514  1
622781  96.449  -55.833  51.452  1
622782  96.484  -55.857  51.389  1
622783  96.511  -55.871  51.327  1
622784  96.528  -55.869  51.263  1
622785  96.544  -55.868  51.199  1
622786  96.561  -55.868  51.135  1
622787  96.578  -55.867  51.070  1
622788  96.594  -55.866  51.006  1
622789  96.611  -55.865  50.946  1
622790  96.627  -55.865  50.887  1
622791  96.644  -55.864  50.830  1
622792  96.661  -55.863  50.774  1
622793  96.677  -55.862  50.720  1
623194  87.519  -51.108  56.283  5
623195  87.550  -51.131  56.295  5
623196  87.581  -51.155  56.306  5
623197  87.612  -51.178  56.317  5
623198  87.643  -51.202  56.322  5
623199  87.674  -51.224  56.326  5
623200  87.705  -51.248  56.328  5
623201  87.736  -51.271  56.328  5
623202  87.767  -51.295  56.327  5
623203  87.798  -51.318  56.325  5
623204  87.829  -51.342  56.319  5
623243  89.062  -52.189  57.232  4
623244  89.095  -52.208  57.222  4
623245  89.128  -52.228  57.211  4
623246  89.162  -52.247  57.203  4
623247  89.194  -52.267  57.195  4
623248  89.228  -52.286  57.186  4
623249  89.261  -52.305  57.179  4
623250  89.294  -52.324  57.171  4
623251  89.327  -52.344  57.163  4
623252  89.360  -52.363  57.158  4
623253  89.393  -52.383  57.154  4
623254  89.426  -52.402  57.148  4
623255  89.459  -52.421  57.143  4
623256  89.492  -52.440  57.139  4
623257  89.525  -52.459  57.133  4
623258  89.558  -52.479  57.131  4
623267  89.853  -52.612  57.118  4
623268  89.886  -52.621  57.117  4
623269  89.918  -52.628  57.118  4
623270  89.950  -52.637  57.118  4
623271  89.982  -52.644  57.119  4
623272  90.015  -52.653  57.120  4
623273  90.040  -52.666  57.122  4
623274  90.056  -52.688  57.123  4
623275  90.073  -52.710  57.126  4
623276  90.089  -52.733  57.127  4
623277  90.105  -52.755  57.131  4
623278  90.126  -52.769  57.135  4
623279  90.159  -52.769  57.138  4
623280  90.190  -52.769  57.140  4
623281  90.223  -52.769  57.141  4
623282  90.255  -52.769  57.140  4
623283  90.287  -52.769  57.140  4
623284  90.318  -52.772  57.139  4
623285  90.343  -52.794  57.139  4
623286  90.368  -52.817  57.138  4
623287  90.393  -52.840  57.137  4
623288  90.420  -52.862  57.134  4
623289  90.455  -52.882  57.134  4
623290  90.490  -52.904  57.134  4
623291  90.526  -52.924  57.133  4
623292  90.561  -52.944  57.130  4
623293  90.596  -52.965  57.126  4
623294  90.631  -52.985  57.111  4
623295  90.671  -52.983  57.092  4
623296  90.712  -52.976  57.072  4
623297  90.753  -52.969  57.049  4
623298  90.794  -52.962  57.027  4
623299  90.835  -52.962  57.005  4
623300  90.875  -52.970  56.978  4
623301  90.916  -52.977  56.951  4
623302  90.927  -52.994  56.924  4
623303  90.932  -53.013  56.898  4
623304  90.956  -53.035  56.872  4
623305  90.982  -53.055  56.846  4
623306  91.009  -53.076  56.816  4
623307  91.036  -53.097  56.786  4
623308  91.063  -53.117  56.757  4
623309  91.090  -53.138  56.727  4
623310  91.117  -53.159  56.698  4
623311  91.144  -53.180  56.667  4
623312  91.170  -53.200  56.635  4
623313  91.198  -53.221  56.604  4
623314  91.224  -53.242  56.572  4
623315  91.256  -53.266  56.541  4
623316  91.290  -53.290  56.510  4
623317  91.323  -53.314  56.479  4
623318  91.356  -53.339  56.446  4
623319  91.390  -53.364  56.416  4
623320  91.423  -53.388  56.385  4
623321  91.456  -53.413  56.355  4
623322  91.490  -53.437  56.326  4
623323  91.523  -53.462  56.297  4
623324  91.556  -53.487  56.268  4
623325  91.590  -53.511  56.240  4
623326  91.623  -53.535  56.212  4
623327  91.656  -53.560  56.185  4
623328  91.689  -53.584  56.159  4
623329  91.723  -53.609  56.131  4
623330  91.756  -53.634  56.104  4
623331  91.790  -53.658  56.077  4
623332  91.823  -53.682  56.050  4
623333  91.856  -53.706  56.022  4
623334  91.897  -53.720  55.994  4
623335  91.938  -53.734  55.967  4
623336  91.979  -53.747  55.939  4
623337  92.019  -53.761  55.911  4
623338  92.060  -53.774  55.883  4
623339  92.101  -53.787  55.856  4
623340  92.142  -53.801  55.829  4
623355  92.753  -54.004  55.287  1
623356  92.793  -54.017  55.283  1
623357  92.834  -54.031  55.280  1
623358  92.875  -54.044  55.278  1
623359  92.916  -54.057  55.278  1
623360  92.956  -54.071  55.279  1
623361  92.997  -54.085  55.281  1
623362  93.038  -54.098  55.284  1
623363  93.079  -54.111  55.289  1
623364  93.119  -54.125  55.299  1
623365  93.160  -54.138  55.308  1
623366  93.201  -54.152  55.312  1
623367  93.221  -54.168  55.307  1
623368  93.231  -54.189  55.292  1
623369  93.240  -54.208  55.273  1
623370  93.249  -54.229  55.253  1
623371  93.258  -54.248  55.237  1
623372  93.267  -54.268  55.224  1
623373  93.276  -54.289  55.216  1
623374  93.285  -54.308  55.212  1
623375  93.295  -54.328  55.211  1
623376  93.304  -54.348  55.212  1
623377  93.313  -54.368  55.219  1
623378  93.337  -54.380  55.229  1
623379  93.375  -54.384  55.240  1
623380  93.413  -54.389  55.252  1
623381  93.448  -54.395  55.262  1
623382  93.479  -54.402  55.268  1
623383  93.501  -54.415  55.273  1
623384  93.522  -54.429  55.278  1
623385  93.544  -54.442  55.283  1
623386  93.565  -54.455  55.289  1
623387  93.587  -54.468  55.293  1
623388  93.609  -54.482  55.295  1
623389  93.630  -54.496  55.298  1
623390  93.651  -54.508  55.303  1
623391  93.673  -54.522  55.309  1
623392  93.694  -54.535  55.316  1
623393  93.716  -54.549  55.318  1
623394  93.737  -54.562  55.311  1
623395  93.759  -54.575  55.298  1
623396  93.780  -54.588  55.280  1
623397  93.801  -54.602  55.259  1
623398  93.823  -54.615  55.235  1
623399  93.844  -54.628  55.209  1
623400  93.866  -54.641  55.189  1
623401  93.888  -54.655  55.177  1
623402  93.909  -54.668  55.167  1
623403  93.930  -54.681  55.155  1
623404  93.952  -54.695  55.136  1
623405  93.972  -54.707  55.113  1
623406  93.996  -54.723  55.086  1
623407  94.021  -54.740  55.067  1
623408  94.046  -54.756  55.064  1
623409  94.070  -54.773  55.067  1
623410  94.095  -54.790  55.070  1
623411  94.120  -54.806  55.069  1
623412  94.145  -54.822  55.066  1
623413  94.170  -54.839  55.052  1
623414  94.194  -54.856  55.036  1
623415  94.219  -54.872  55.019  1
623416  94.244  -54.889  55.003  1
623417  94.268  -54.906  54.988  1
623418  94.293  -54.922  54.968  1
623419  94.328  -54.935  54.939  1
623420  94.365  -54.947  54.909  1
623421  94.402  -54.959  54.879  1
623422  94.439  -54.971  54.850  1
623423  94.477  -54.982  54.819  1
623424  94.514  -54.994  54.786  1
623425  94.552  -55.006  54.746  1
623426  94.590  -55.017  54.698  1
623427  94.627  -55.029  54.648  1
623428  94.665  -55.041  54.595  1
623429  94.702  -55.053  54.540  1
623430  94.740  -55.066  54.485  1
623431  94.777  -55.080  54.427  1
623432  94.814  -55.094  54.368  1
623433  94.851  -55.108  54.309  1
623434  94.884  -55.126  54.252  1
623435  94.916  -55.144  54.197  1
623436  94.949  -55.162  54.142  1
623437  94.981  -55.179  54.087  1
623438  95.014  -55.198  54.038  1
623439  95.048  -55.215  53.990  1
623440  95.083  -55.233  53.941  1
623441  95.117  -55.251  53.892  1
623442  95.149  -55.266  53.840  1
623443  95.181  -55.280  53.782  1
623444  95.213  -55.295  53.718  1
623445  95.245  -55.309  53.653  1
623446  95.276  -55.323  53.587  1
623447  95.308  -55.337  53.522  1
623448  95.340  -55.351  53.459  1
623449  95.372  -55.364  53.396  1
623450  95.404  -55.378  53.335  1
623451  95.436  -55.392  53.275  1
623452  95.468  -55.405  53.216  1
623453  95.499  -55.418  53.159  1
623454  95.531  -55.432  53.104  1
623455  95.564  -55.445  53.050  1
623456  95.597  -55.458  52.997  1
623457  95.630  -55.470  52.944  1
623458  95.662  -55.483  52.888  1
623459  95.693  -55.493  52.832  1
623460  95.724  -55.504  52.774  1
623461  95.754  -55.514  52.716  1
623462  95.784  -55.525  52.659  1
623463  95.815  -55.536  52.601  1
623464  95.848  -55.549  52.542  1
623465  95.882  -55.564  52.484  1
623466  95.917  -55.578  52.426  1
623467  95.951  -55.593  52.367  1
623468  95.986  -55.608  52.307  1
623469  96.021  -55.622  52.248  1
623470  96.055  -55.636  52.188  1
623471  96.090  -55.652  52.128  1
623472  96.124  -55.666  52.067  1
623473  96.159  -55.680  52.007  1
623474  96.193  -55.695  51.946  1
623475  96.228  -55.710  51.885  1
623476  96.262  -55.724  51.824  1
623477  96.297  -55.739  51.762  1
623478  96.328  -55.749  51.701  1
623479  96.359  -55.759  51.640  1
623480  96.390  -55.769  51.580  1
623481  96.421  -55.779  51.518  1
623482  96.454  -55.795  51.456  1
623483  96.489  -55.819  51.392  1
623484  96.524  -55.843  51.330  1
623485  96.542  -55.844  51.266  1
623486  96.558  -55.843  51.202  1
623487  96.575  -55.843  51.138  1
623488  96.592  -55.842  51.073  1
623489  96.608  -55.841  51.009  1
623490  96.625  -55.840  50.948  1
623491  96.642  -55.840  50.889  1
623492  96.658  -55.839  50.831  1
623493  96.675  -55.838  50.775  1
623494  96.691  -55.837  50.721  1
623893  87.479  -51.032  56.282  5
623894  87.510  -51.055  56.295  5
623895  87.541  -51.078  56.307  5
623896  87.572  -51.102  56.320  5
623897  87.603  -51.125  56.331  5
623898  87.634  -51.149  56.342  5
623899  87.665  -51.172  56.348  5
623900  87.696  -51.195  56.351  5
623901  87.727  -51.218  56.353  5
623902  87.758  -51.242  56.353  5
623903  87.789  -51.265  56.351  5
623904  87.820  -51.289  56.347  5
623905  87.851  -51.312  56.340  5
623906  87.882  -51.335  56.331  5
623907  87.916  -51.352  56.321  5
623945  89.115  -52.175  57.213  4
623946  89.148  -52.195  57.202  4
623947  89.181  -52.214  57.193  4
623948  89.214  -52.233  57.185  4
623949  89.248  -52.252  57.176  4
623950  89.280  -52.272  57.168  4
623951  89.314  -52.291  57.161  4
623952  89.347  -52.311  57.153  4
623953  89.380  -52.330  57.148  4
623954  89.413  -52.349  57.143  4
623955  89.446  -52.368  57.138  4
623956  89.479  -52.388  57.133  4
623957  89.512  -52.407  57.129  4
623958  89.545  -52.427  57.124  4
623968  89.873  -52.579  57.113  4
623969  89.905  -52.587  57.113  4
623970  89.938  -52.595  57.114  4
623971  89.970  -52.603  57.115  4
623972  90.003  -52.611  57.116  4
623973  90.035  -52.619  57.119  4
623974  90.067  -52.628  57.122  4
623975  90.088  -52.645  57.124  4
623976  90.104  -52.667  57.128  4
623977  90.120  -52.690  57.130  4
623978  90.136  -52.712  57.134  4
623979  90.152  -52.734  57.139  4
623980  90.182  -52.737  57.143  4
623981  90.214  -52.736  57.146  4
623982  90.246  -52.736  57.151  4
623983  90.279  -52.736  57.150  4
623984  90.310  -52.736  57.150  4
623985  90.342  -52.736  57.151  4
623986  90.368  -52.757  57.151  4
623987  90.393  -52.780  57.152  4
623988  90.418  -52.803  57.153  4
623989  90.444  -52.825  57.150  4
623990  90.471  -52.847  57.150  4
623991  90.507  -52.868  57.151  4
623992  90.542  -52.888  57.151  4
623993  90.577  -52.909  57.149  4
623994  90.612  -52.929  57.145  4
623995  90.647  -52.951  57.125  4
623996  90.687  -52.948  57.108  4
623997  90.728  -52.941  57.089  4
623998  90.769  -52.934  57.069  4
623999  90.810  -52.928  57.049  4
624000  90.851  -52.935  57.028  4
624001  90.891  -52.943  57.004  4
624002  90.931  -52.951  56.978  4
624003  90.962  -52.961  56.953  4
624004  90.966  -52.981  56.929  4
624005  90.970  -53.001  56.906  4
624006  90.987  -53.021  56.882  4
624007  91.014  -53.042  56.852  4
624008  91.040  -53.063  56.823  4
624009  91.067  -53.083  56.795  4
624010  91.094  -53.104  56.765  4
624011  91.121  -53.125  56.736  4
624012  91.148  -53.145  56.706  4
624013  91.175  -53.166  56.674  4
624014  91.204  -53.188  56.641  4
624015  91.237  -53.213  56.610  4
624016  91.270  -53.237  56.577  4
624017  91.304  -53.261  56.545  4
624018  91.337  -53.286  56.514  4
624019  91.370  -53.311  56.480  4
624020  91.403  -53.335  56.448  4
624021  91.437  -53.360  56.417  4
624022  91.470  -53.384  56.385  4
624023  91.504  -53.408  56.354  4
624024  91.537  -53.433  56.325  4
624025  91.570  -53.458  56.295  4
624026  91.603  -53.482  56.265  4
624027  91.637  -53.507  56.236  4
624028  91.670  -53.531  56.208  4
624029  91.704  -53.556  56.181  4
624030  91.737  -53.581  56.153  4
624031  91.770  -53.605  56.124  4
624032  91.803  -53.629  56.096  4
624033  91.837  -53.654  56.068  4
624034  91.870  -53.678  56.038  4
624035  91.911  -53.691  56.009  4
624036  91.952  -53.705  55.980  4
624037  91.993  -53.719  55.950  4
624038  92.033  -53.732  55.922  4
624039  92.074  -53.745  55.892  4
624040  92.115  -53.759  55.864  4
624041  92.156  -53.772  55.835  4
624056  92.767  -53.975  55.283  1
624057  92.807  -53.988  55.278  1
624058  92.848  -54.001  55.274  1
624059  92.889  -54.015  55.271  1
624060  92.930  -54.029  55.269  1
624061  92.971  -54.042  55.269  1
624062  93.011  -54.056  55.270  1
624063  93.052  -54.069  55.271  1
624064  93.093  -54.082  55.273  1
624065  93.134  -54.096  55.280  1
624066  93.174  -54.110  55.287  1
624067  93.216  -54.120  55.289  1
624068  93.236  -54.142  55.281  1
624069  93.252  -54.164  55.263  1
624070  93.261  -54.183  55.247  1
624071  93.270  -54.204  55.231  1
624072  93.279  -54.223  55.216  1
624073  93.288  -54.243  55.205  1
624074  93.297  -54.264  55.198  1
624075  93.306  -54.283  55.195  1
624076  93.315  -54.303  55.194  1
624077  93.325  -54.323  55.194  1
624078  93.334  -54.343  55.201  1
624079  93.361  -54.353  55.210  1
624080  93.400  -54.358  55.219  1
624081  93.437  -54.362  55.229  1
624082  93.468  -54.370  55.238  1
624083  93.499  -54.377  55.243  1
624084  93.529  -54.387  55.248  1
624085  93.550  -54.400  55.252  1
624086  93.571  -54.414  55.256  1
624087  93.592  -54.427  55.263  1
624088  93.614  -54.440  55.268  1
624089  93.636  -54.453  55.273  1
624090  93.657  -54.467  55.278  1
624091  93.679  -54.480  55.283  1
624092  93.700  -54.493  55.287  1
624093  93.721  -54.506  55.287  1
624094  93.743  -54.520  55.283  1
624095  93.764  -54.533  55.271  1
624096  93.786  -54.546  55.253  1
624097  93.807  -54.560  55.233  1
624098  93.829  -54.573  55.214  1
624099  93.850  -54.587  55.198  1
624100  93.871  -54.599  55.184  1
624101  93.893  -54.613  55.175  1
624102  93.915  -54.626  55.168  1
624103  93.936  -54.640  55.157  1
624104  93.958  -54.652  55.140  1
624105  93.979  -54.666  55.119  1
624106  93.995  -54.674  55.094  1
624107  94.012  -54.686  55.069  1
624108  94.037  -54.702  55.058  1
624109  94.062  -54.718  55.057  1
624110  94.086  -54.735  55.061  1
624111  94.112  -54.752  55.062  1
624112  94.136  -54.768  55.059  1
624113  94.161  -54.784  55.053  1
624114  94.186  -54.801  55.035  1
624115  94.210  -54.818  55.015  1
624116  94.235  -54.834  54.995  1
624117  94.260  -54.851  54.978  1
624118  94.284  -54.868  54.962  1
624119  94.309  -54.884  54.941  1
624120  94.342  -54.897  54.912  1
624121  94.380  -54.909  54.881  1
624122  94.417  -54.922  54.852  1
624123  94.454  -54.934  54.824  1
624124  94.491  -54.946  54.795  1
624125  94.529  -54.958  54.764  1
624126  94.566  -54.969  54.724  1
624127  94.604  -54.981  54.677  1
624128  94.641  -54.993  54.630  1
624129  94.679  -55.004  54.579  1
624130  94.716  -55.016  54.525  1
624131  94.754  -55.029  54.471  1
624132  94.791  -55.044  54.410  1
624133  94.828  -55.057  54.348  1
624134  94.860  -55.075  54.287  1
624135  94.893  -55.093  54.227  1
624136  94.925  -55.111  54.170  1
624137  94.959  -55.129  54.113  1
624138  94.993  -55.147  54.056  1
624139  95.028  -55.164  54.005  1
624140  95.062  -55.182  53.958  1
624141  95.096  -55.200  53.908  1
624142  95.130  -55.217  53.858  1
624143  95.163  -55.232  53.804  1
624144  95.194  -55.246  53.745  1
624145  95.226  -55.260  53.683  1
624146  95.258  -55.275  53.620  1
624147  95.289  -55.289  53.556  1
624148  95.321  -55.304  53.494  1
624149  95.353  -55.318  53.433  1
624150  95.385  -55.332  53.372  1
624151  95.417  -55.346  53.312  1
624152  95.449  -55.359  53.255  1
624153  95.480  -55.373  53.200  1
624154  95.513  -55.386  53.147  1
624155  95.544  -55.400  53.097  1
624156  95.576  -55.414  53.046  1
624157  95.609  -55.426  52.995  1
624158  95.642  -55.439  52.944  1
624159  95.673  -55.450  52.892  1
624160  95.703  -55.461  52.839  1
624161  95.734  -55.471  52.784  1
624162  95.765  -55.482  52.729  1
624163  95.795  -55.492  52.673  1
624164  95.826  -55.503  52.616  1
624165  95.858  -55.515  52.558  1
624166  95.892  -55.530  52.499  1
624167  95.927  -55.545  52.440  1
624168  95.961  -55.559  52.381  1
624169  95.996  -55.574  52.321  1
624170  96.031  -55.589  52.260  1
624171  96.065  -55.603  52.200  1
624172  96.100  -55.618  52.139  1
624173  96.134  -55.632  52.078  1
624174  96.169  -55.647  52.017  1
624175  96.203  -55.662  51.956  1
624176  96.238  -55.676  51.894  1
624177  96.270  -55.687  51.833  1
624178  96.301  -55.697  51.770  1
624179  96.332  -55.708  51.708  1
624180  96.364  -55.718  51.647  1
624181  96.395  -55.727  51.587  1
624182  96.426  -55.738  51.525  1
624183  96.460  -55.758  51.461  1
624184  96.495  -55.782  51.397  1
624185  96.530  -55.806  51.333  1
624186  96.556  -55.819  51.270  1
624187  96.573  -55.818  51.207  1
624188  96.590  -55.818  51.142  1
624189  96.606  -55.817  51.078  1
624190  96.623  -55.816  51.013  1
624191  96.640  -55.815  50.951  1
624192  96.656  -55.815  50.892  1
624193  96.673  -55.814  50.834  1
624194  96.689  -55.812  50.777  1
624195  96.706  -55.812  50.723  1
624594  87.501  -51.002  56.304  5
624595  87.532  -51.025  56.319  5
624596  87.563  -51.048  56.331  5
624597  87.593  -51.072  56.345  5
624598  87.625  -51.096  56.357  5
624599  87.655  -51.119  56.368  5
624600  87.687  -51.142  56.374  5
624601  87.717  -51.165  56.377  5
624602  87.749  -51.189  56.378  5
624603  87.779  -51.212  56.378  5
624604  87.811  -51.236  56.375  5
624605  87.841  -51.259  56.371  5
624606  87.872  -51.282  56.363  5
624607  87.906  -51.302  56.352  5
624608  87.941  -51.317  56.340  5
624609  87.976  -51.332  56.326  5
624647  89.168  -52.161  57.192  4
624648  89.201  -52.181  57.183  4
624649  89.235  -52.200  57.175  4
624650  89.267  -52.220  57.166  4
624651  89.301  -52.239  57.158  4
624652  89.334  -52.258  57.151  4
624653  89.367  -52.277  57.142  4
624654  89.400  -52.296  57.138  4
624655  89.433  -52.316  57.133  4
624656  89.466  -52.335  57.128  4
624657  89.499  -52.355  57.123  4
624658  89.532  -52.374  57.120  4
624669  89.893  -52.546  57.108  4
624670  89.925  -52.554  57.110  4
624671  89.958  -52.562  57.111  4
624672  89.990  -52.570  57.112  4
624673  90.022  -52.578  57.114  4
624674  90.054  -52.586  57.117  4
624675  90.087  -52.593  57.122  4
624676  90.119  -52.602  57.125  4
624677  90.135  -52.624  57.130  4
624678  90.151  -52.647  57.134  4
624679  90.167  -52.669  57.138  4
624680  90.183  -52.691  57.143  4
624681  90.206  -52.703  57.149  4
624682  90.238  -52.703  57.154  4
624683  90.270  -52.703  57.159  4
624684  90.302  -52.703  57.161  4
624685  90.334  -52.703  57.162  4
624686  90.366  -52.703  57.164  4
624687  90.393  -52.720  57.165  4
624688  90.418  -52.743  57.166  4
624689  90.444  -52.766  57.172  4
624690  90.469  -52.788  57.167  4
624691  90.494  -52.810  57.164  4
624692  90.523  -52.832  57.165  4
624693  90.558  -52.853  57.167  4
624694  90.593  -52.873  57.166  4
624695  90.628  -52.894  57.161  4
624696  90.663  -52.915  57.140  4
624697  90.704  -52.912  57.124  4
624698  90.744  -52.905  57.108  4
624699  90.785  -52.898  57.091  4
624700  90.826  -52.901  57.073  4
624701  90.866  -52.909  57.055  4
624702  90.906  -52.916  57.031  4
624703  90.947  -52.924  57.006  4
624704  90.987  -52.932  56.982  4
624705  91.001  -52.948  56.960  4
624706  91.005  -52.968  56.939  4
624707  91.010  -52.988  56.915  4
624708  91.018  -53.007  56.887  4
624709  91.044  -53.029  56.860  4
624710  91.072  -53.049  56.832  4
624711  91.098  -53.070  56.803  4
624712  91.125  -53.091  56.773  4
624713  91.152  -53.111  56.744  4
624714  91.184  -53.135  56.712  4
624715  91.218  -53.160  56.680  4
624716  91.251  -53.184  56.647  4
624717  91.284  -53.208  56.614  4
624718  91.317  -53.233  56.581  4
624719  91.351  -53.258  56.549  4
624720  91.384  -53.282  56.515  4
624721  91.418  -53.307  56.482  4
624722  91.451  -53.331  56.449  4
624723  91.484  -53.355  56.417  4
624724  91.517  -53.380  56.385  4
624725  91.551  -53.405  56.354  4
624726  91.584  -53.429  56.322  4
624727  91.617  -53.454  56.292  4
624728  91.651  -53.478  56.263  4
624729  91.684  -53.502  56.234  4
624730  91.717  -53.527  56.205  4
624731  91.751  -53.552  56.175  4
624732  91.784  -53.576  56.146  4
624733  91.817  -53.601  56.117  4
624734  91.851  -53.625  56.086  4
624735  91.884  -53.649  56.056  4
624736  91.925  -53.662  56.025  4
624737  91.966  -53.676  55.994  4
624738  92.007  -53.690  55.963  4
624739  92.048  -53.703  55.933  4
624740  92.088  -53.716  55.902  4
624741  92.129  -53.730  55.872  4
624742  92.170  -53.744  55.842  4
624757  92.781  -53.946  55.279  1
624758  92.821  -53.960  55.272  1
624759  92.862  -53.972  55.267  1
624760  92.903  -53.986  55.262  1
624761  92.944  -54.000  55.259  1
624762  92.985  -54.013  55.258  1
624763  93.025  -54.027  55.257  1
624764  93.066  -54.040  55.256  1
624765  93.107  -54.054  55.256  1
624766  93.148  -54.067  55.259  1
624767  93.194  -54.075  55.263  1
624768  93.221  -54.092  55.261  1
624769  93.241  -54.114  55.252  1
624770  93.261  -54.136  55.236  1
624771  93.280  -54.158  55.222  1
624772  93.291  -54.179  55.208  1
624773  93.300  -54.198  55.196  1
624774  93.309  -54.218  55.186  1
624775  93.318  -54.239  55.181  1
624776  93.327  -54.258  55.178  1
624777  93.337  -54.278  55.178  1
624778  93.346  -54.298  55.180  1
624779  93.355  -54.318  55.185  1
624780  93.386  -54.327  55.192  1
624781  93.424  -54.330  55.199  1
624782  93.458  -54.337  55.204  1
624783  93.489  -54.345  55.212  1
624784  93.520  -54.353  55.217  1
624785  93.551  -54.361  55.221  1
624786  93.577  -54.371  55.224  1
624787  93.599  -54.385  55.228  1
624788  93.620  -54.398  55.237  1
624789  93.641  -54.411  55.245  1
624790  93.663  -54.424  55.251  1
624791  93.684  -54.438  55.257  1
624792  93.706  -54.452  55.261  1
624793  93.727  -54.464  55.261  1
624794  93.749  -54.478  55.255  1
624795  93.770  -54.491  55.245  1
624796  93.791  -54.505  55.233  1
624797  93.813  -54.518  55.217  1
624798  93.835  -54.531  55.201  1
624799  93.856  -54.544  55.187  1
624800  93.877  -54.558  55.175  1
624801  93.899  -54.571  55.166  1
624802  93.920  -54.584  55.161  1
624803  93.942  -54.598  55.152  1
624804  93.963  -54.611  55.138  1
624805  93.985  -54.624  55.119  1
624806  94.003  -54.634  55.096  1
624807  94.018  -54.643  55.072  1
624808  94.034  -54.652  55.056  1
624809  94.054  -54.664  55.052  1
624810  94.078  -54.681  55.053  1
624811  94.103  -54.697  55.053  1
624812  94.128  -54.714  55.052  1
624813  94.152  -54.731  55.046  1
624814  94.177  -54.747  55.036  1
624815  94.202  -54.763  55.015  1
624816  94.226  -54.780  54.993  1
624817  94.251  -54.797  54.971  1
624818  94.276  -54.813  54.952  1
624819  94.301  -54.830  54.936  1
624820  94.326  -54.847  54.914  1
624821  94.357  -54.860  54.884  1
624822  94.394  -54.872  54.853  1
624823  94.431  -54.884  54.824  1
624824  94.469  -54.897  54.796  1
624825  94.506  -54.909  54.768  1
624826  94.543  -54.921  54.739  1
624827  94.580  -54.933  54.700  1
624828  94.618  -54.945  54.655  1
624829  94.655  -54.956  54.609  1
624830  94.693  -54.969  54.560  1
624831  94.730  -54.980  54.508  1
624832  94.767  -54.993  54.456  1
624833  94.805  -55.007  54.395  1
624834  94.837  -55.025  54.333  1
624835  94.870  -55.043  54.270  1
624836  94.904  -55.060  54.209  1
624837  94.938  -55.078  54.149  1
624838  94.973  -55.096  54.091  1
624839  95.007  -55.113  54.032  1
624840  95.041  -55.131  53.979  1
624841  95.075  -55.149  53.930  1
624842  95.110  -55.166  53.879  1
624843  95.144  -55.184  53.826  1
624844  95.176  -55.198  53.771  1
624845  95.207  -55.212  53.711  1
624846  95.239  -55.226  53.648  1
624847  95.271  -55.241  53.587  1
624848  95.303  -55.255  53.526  1
624849  95.334  -55.270  53.467  1
624850  95.366  -55.284  53.409  1
624851  95.398  -55.298  53.352  1
624852  95.430  -55.312  53.294  1
624853  95.462  -55.326  53.239  1
624854  95.493  -55.341  53.190  1
624855  95.525  -55.354  53.142  1
624856  95.557  -55.368  53.096  1
624857  95.589  -55.382  53.049  1
624858  95.621  -55.395  53.000  1
624859  95.654  -55.407  52.950  1
624860  95.684  -55.417  52.901  1
624861  95.714  -55.428  52.851  1
624862  95.745  -55.439  52.798  1
624863  95.775  -55.449  52.744  1
624864  95.806  -55.460  52.689  1
624865  95.836  -55.470  52.633  1
624866  95.868  -55.482  52.574  1
624867  95.902  -55.496  52.515  1
624868  95.937  -55.511  52.456  1
624869  95.971  -55.526  52.397  1
624870  96.006  -55.540  52.336  1
624871  96.041  -55.555  52.275  1
624872  96.075  -55.569  52.214  1
624873  96.110  -55.584  52.151  1
624874  96.144  -55.599  52.090  1
624875  96.179  -55.613  52.028  1
624876  96.212  -55.626  51.966  1
624877  96.243  -55.636  51.905  1
624878  96.274  -55.646  51.843  1
624879  96.305  -55.655  51.780  1
624880  96.336  -55.666  51.718  1
624881  96.368  -55.676  51.656  1
624882  96.399  -55.686  51.594  1
624883  96.430  -55.696  51.532  1
624884  96.465  -55.721  51.468  1
624885  96.500  -55.745  51.403  1
624886  96.535  -55.769  51.339  1
624887  96.570  -55.793  51.276  1
624888  96.587  -55.793  51.212  1
624889  96.604  -55.793  51.148  1
624890  96.620  -55.792  51.082  1
624891  96.637  -55.791  51.017  1
624892  96.654  -55.790  50.955  1
624893  96.670  -55.790  50.895  1
624894  96.687  -55.788  50.837  1
624895  96.703  -55.787  50.780  1
624896  96.720  -55.787  50.724  1
625295  87.522  -50.973  56.327  5
625296  87.553  -50.995  56.342  5
625297  87.584  -51.019  56.356  5
625298  87.615  -51.042  56.370  5
625299  87.646  -51.066  56.383  5
625300  87.677  -51.089  56.393  5
625301  87.708  -51.112  56.401  5
625302  87.739  -51.136  56.403  5
625303  87.770  -51.159  56.404  5
625304  87.801  -51.183  56.403  5
625305  87.832  -51.206  56.400  5
625306  87.863  -51.230  56.394  5
625307  87.895  -51.252  56.386  5
625308  87.930  -51.267  56.373  5
625309  87.966  -51.282  56.360  5
625310  88.002  -51.299  56.345  5
625349  89.222  -52.148  57.173  4
625350  89.254  -52.167  57.165  4
625351  89.287  -52.186  57.155  4
625352  89.321  -52.205  57.147  4
625353  89.354  -52.225  57.140  4
625354  89.387  -52.244  57.132  4
625355  89.420  -52.264  57.126  4
625356  89.453  -52.283  57.122  4
625357  89.486  -52.302  57.117  4
625358  89.519  -52.321  57.113  4
625370  89.913  -52.512  57.104  4
625371  89.946  -52.521  57.107  4
625372  89.978  -52.528  57.109  4
625373  90.010  -52.537  57.112  4
625374  90.042  -52.544  57.115  4
625375  90.075  -52.553  57.119  4
625376  90.107  -52.560  57.123  4
625377  90.139  -52.568  57.127  4
625378  90.166  -52.581  57.133  4
625379  90.182  -52.603  57.138  4
625380  90.198  -52.625  57.143  4
625381  90.215  -52.647  57.148  4
625382  90.231  -52.669  57.155  4
625383  90.262  -52.671  57.162  4
625384  90.294  -52.671  57.167  4
625385  90.326  -52.671  57.171  4
625386  90.358  -52.671  57.174  4
625387  90.390  -52.671  57.176  4
625388  90.418  -52.683  57.178  4
625389  90.443  -52.706  57.183  4
625390  90.468  -52.728  57.188  4
625391  90.494  -52.750  57.181  4
625392  90.519  -52.773  57.176  4
625393  90.544  -52.796  57.174  4
625394  90.574  -52.818  57.174  4
625395  90.609  -52.838  57.174  4
625396  90.644  -52.859  57.167  4
625397  90.679  -52.879  57.153  4
625398  90.720  -52.877  57.140  4
625399  90.760  -52.869  57.128  4
625400  90.801  -52.868  57.115  4
625401  90.841  -52.875  57.099  4
625402  90.882  -52.882  57.083  4
625403  90.922  -52.890  57.059  4
625404  90.962  -52.897  57.034  4
625405  91.003  -52.905  57.010  4
625406  91.035  -52.915  56.990  4
625407  91.040  -52.935  56.970  4
625408  91.044  -52.955  56.947  4
625409  91.048  -52.975  56.921  4
625410  91.053  -52.995  56.894  4
625411  91.076  -53.015  56.867  4
625412  91.102  -53.035  56.839  4
625413  91.132  -53.057  56.810  4
625414  91.165  -53.082  56.782  4
625415  91.198  -53.107  56.751  4
625416  91.231  -53.131  56.717  4
625417  91.264  -53.156  56.684  4
625418  91.298  -53.180  56.651  4
625419  91.331  -53.205  56.618  4
625420  91.365  -53.230  56.585  4
625421  91.398  -53.254  56.550  4
625422  91.431  -53.278  56.516  4
625423  91.464  -53.303  56.482  4
625424  91.498  -53.327  56.449  4
625425  91.531  -53.352  56.416  4
625426  91.565  -53.377  56.383  4
625427  91.598  -53.401  56.351  4
625428  91.631  -53.425  56.320  4
625429  91.665  -53.450  56.290  4
625430  91.698  -53.474  56.260  4
625431  91.731  -53.499  56.229  4
625432  91.765  -53.524  56.198  4
625433  91.798  -53.548  56.168  4
625434  91.831  -53.572  56.137  4
625435  91.865  -53.597  56.106  4
625436  91.899  -53.620  56.074  4
625437  91.940  -53.634  56.042  4
625438  91.980  -53.647  56.009  4
625439  92.021  -53.661  55.977  4
625440  92.062  -53.674  55.945  4
625441  92.102  -53.687  55.913  4
625442  92.143  -53.701  55.881  4
625443  92.184  -53.715  55.849  4
625444  92.225  -53.728  55.818  4
625458  92.795  -53.917  55.274  1
625459  92.836  -53.930  55.267  1
625460  92.876  -53.944  55.261  1
625461  92.917  -53.957  55.254  1
625462  92.958  -53.971  55.248  1
625463  92.999  -53.985  55.245  1
625464  93.040  -53.997  55.243  1
625465  93.080  -54.011  55.239  1
625466  93.121  -54.025  55.236  1
625467  93.169  -54.031  55.236  1
625468  93.207  -54.042  55.236  1
625469  93.226  -54.064  55.232  1
625470  93.246  -54.086  55.221  1
625471  93.266  -54.108  55.209  1
625472  93.285  -54.130  55.196  1
625473  93.304  -54.152  55.185  1
625474  93.321  -54.173  55.175  1
625475  93.330  -54.193  55.167  1
625476  93.339  -54.214  55.163  1
625477  93.348  -54.233  55.162  1
625478  93.357  -54.253  55.164  1
625479  93.366  -54.273  55.166  1
625480  93.375  -54.293  55.169  1
625481  93.410  -54.299  55.174  1
625482  93.447  -54.304  55.178  1
625483  93.478  -54.312  55.180  1
625484  93.509  -54.320  55.185  1
625485  93.540  -54.328  55.189  1
625486  93.571  -54.336  55.193  1
625487  93.603  -54.344  55.197  1
625488  93.626  -54.356  55.202  1
625489  93.647  -54.370  55.210  1
625490  93.669  -54.383  55.221  1
625491  93.690  -54.396  55.230  1
625492  93.712  -54.409  55.236  1
625493  93.733  -54.423  55.237  1
625494  93.755  -54.436  55.231  1
625495  93.776  -54.449  55.220  1
625496  93.797  -54.462  55.206  1
625497  93.819  -54.476  55.198  1
625498  93.840  -54.489  55.189  1
625499  93.862  -54.502  55.179  1
625500  93.883  -54.516  55.170  1
625501  93.905  -54.529  55.161  1
625502  93.926  -54.543  55.152  1
625503  93.947  -54.555  55.145  1
625504  93.969  -54.569  55.133  1
625505  93.991  -54.582  55.115  1
625506  94.011  -54.595  55.094  1
625507  94.027  -54.603  55.073  1
625508  94.042  -54.612  55.056  1
625509  94.057  -54.621  55.050  1
625510  94.073  -54.629  55.050  1
625511  94.095  -54.643  55.048  1
625512  94.119  -54.659  55.045  1
625513  94.144  -54.676  55.039  1
625514  94.169  -54.693  55.030  1
625515  94.193  -54.709  55.017  1
625516  94.218  -54.725  54.994  1
625517  94.243  -54.742  54.970  1
625518  94.268  -54.759  54.948  1
625519  94.292  -54.775  54.929  1
625520  94.317  -54.792  54.910  1
625521  94.342  -54.809  54.888  1
625522  94.371  -54.823  54.857  1
625523  94.409  -54.835  54.826  1
625524  94.446  -54.847  54.796  1
625525  94.483  -54.859  54.767  1
625526  94.521  -54.872  54.740  1
625527  94.558  -54.884  54.711  1
625528  94.595  -54.896  54.672  1
625529  94.632  -54.908  54.631  1
625530  94.670  -54.920  54.586  1
625531  94.707  -54.932  54.539  1
625532  94.744  -54.944  54.490  1
625533  94.781  -54.956  54.439  1
625534  94.815  -54.974  54.380  1
625535  94.849  -54.991  54.317  1
625536  94.884  -55.010  54.254  1
625537  94.918  -55.027  54.191  1
625538  94.952  -55.044  54.131  1
625539  94.986  -55.063  54.073  1
625540  95.021  -55.080  54.015  1
625541  95.055  -55.097  53.960  1
625542  95.089  -55.116  53.906  1
625543  95.124  -55.133  53.853  1
625544  95.157  -55.150  53.799  1
625545  95.189  -55.164  53.743  1
625546  95.220  -55.179  53.683  1
625547  95.252  -55.192  53.623  1
625548  95.284  -55.207  53.565  1
625549  95.316  -55.221  53.507  1
625550  95.347  -55.235  53.451  1
625551  95.379  -55.250  53.396  1
625552  95.411  -55.264  53.340  1
625553  95.443  -55.278  53.284  1
625554  95.475  -55.292  53.234  1
625555  95.507  -55.307  53.187  1
625556  95.538  -55.321  53.143  1
625557  95.570  -55.336  53.100  1
625558  95.602  -55.350  53.056  1
625559  95.634  -55.363  53.010  1
625560  95.664  -55.373  52.961  1
625561  95.695  -55.384  52.914  1
625562  95.725  -55.395  52.865  1
625563  95.756  -55.405  52.814  1
625564  95.787  -55.416  52.762  1
625565  95.817  -55.426  52.708  1
625566  95.847  -55.437  52.651  1
625567  95.878  -55.448  52.593  1
625568  95.912  -55.463  52.533  1
625569  95.947  -55.477  52.474  1
625570  95.981  -55.492  52.415  1
625571  96.016  -55.507  52.353  1
625572  96.051  -55.521  52.291  1
625573  96.085  -55.536  52.229  1
625574  96.120  -55.550  52.165  1
625575  96.154  -55.564  52.102  1
625576  96.185  -55.574  52.040  1
625577  96.216  -55.584  51.977  1
625578  96.247  -55.594  51.916  1
625579  96.278  -55.604  51.852  1
625580  96.309  -55.614  51.789  1
625581  96.340  -55.624  51.727  1
625582  96.372  -55.634  51.664  1
625583  96.403  -55.644  51.602  1
625584  96.435  -55.658  51.539  1
625585  96.470  -55.683  51.474  1
625586  96.505  -55.707  51.410  1
625587  96.540  -55.731  51.345  1
625588  96.575  -55.756  51.282  1
625589  96.602  -55.768  51.218  1
625590  96.618  -55.768  51.154  1
625591  96.635  -55.767  51.088  1
625592  96.652  -55.766  51.023  1
625593  96.668  -55.765  50.961  1
625594  96.685  -55.764  50.901  1
625595  96.701  -55.763  50.842  1
625596  96.718  -55.762  50.784  1
625996  87.565  -50.960  56.349  5
625997  87.575  -50.966  56.365  5
625998  87.606  -50.989  56.380  5
625999  87.637  -51.013  56.395  5
626000  87.668  -51.036  56.408  5
626001  87.699  -51.060  56.419  5
626002  87.730  -51.083  56.427  5
626003  87.761  -51.106  56.430  5
626004  87.792  -51.130  56.430  5
626005  87.823  -51.153  56.428  5
626006  87.854  -51.177  56.424  5
626007  87.885  -51.200  56.418  5
626008  87.919  -51.216  56.408  5
626009  87.955  -51.232  56.395  5
626010  87.991  -51.249  56.380  5
626011  88.030  -51.268  56.363  5
626012  88.066  -51.289  56.345  5
626055  89.407  -52.211  57.121  4
626056  89.440  -52.230  57.115  4
626057  89.473  -52.249  57.111  4
626058  89.506  -52.269  57.107  4
626071  89.933  -52.479  57.102  4
626072  89.965  -52.487  57.105  4
626073  89.998  -52.495  57.108  4
626074  90.030  -52.503  57.112  4
626075  90.062  -52.511  57.116  4
626076  90.095  -52.519  57.121  4
626077  90.127  -52.527  57.125  4
626078  90.159  -52.535  57.130  4
626079  90.191  -52.543  57.137  4
626080  90.214  -52.560  57.144  4
626081  90.230  -52.582  57.149  4
626082  90.246  -52.604  57.156  4
626083  90.262  -52.626  57.163  4
626084  90.286  -52.638  57.169  4
626085  90.317  -52.638  57.176  4
626086  90.350  -52.638  57.181  4
626087  90.382  -52.638  57.184  4
626088  90.413  -52.638  57.187  4
626089  90.443  -52.646  57.190  4
626090  90.468  -52.669  57.197  4
626091  90.494  -52.691  57.200  4
626092  90.519  -52.713  57.193  4
626093  90.544  -52.736  57.184  4
626094  90.569  -52.759  57.179  4
626095  90.594  -52.782  57.176  4
626096  90.625  -52.803  57.176  4
626097  90.660  -52.823  57.170  4
626098  90.695  -52.844  57.161  4
626099  90.736  -52.841  57.153  4
626100  90.777  -52.835  57.145  4
626101  90.817  -52.841  57.133  4
626102  90.857  -52.849  57.121  4
626103  90.897  -52.857  57.108  4
626104  90.938  -52.864  57.086  4
626105  90.978  -52.871  57.060  4
626106  91.018  -52.879  57.038  4
626107  91.059  -52.886  57.019  4
626108  91.075  -52.902  57.000  4
626109  91.079  -52.922  56.979  4
626110  91.083  -52.941  56.953  4
626111  91.088  -52.962  56.927  4
626112  91.092  -52.982  56.901  4
626113  91.112  -53.004  56.873  4
626114  91.145  -53.029  56.845  4
626115  91.178  -53.054  56.818  4
626116  91.212  -53.078  56.788  4
626117  91.245  -53.103  56.756  4
626118  91.279  -53.127  56.722  4
626119  91.312  -53.151  56.689  4
626120  91.345  -53.176  56.656  4
626121  91.379  -53.201  56.622  4
626122  91.412  -53.225  56.586  4
626123  91.445  -53.250  56.551  4
626124  91.478  -53.274  56.516  4
626125  91.512  -53.299  56.482  4
626126  91.545  -53.324  56.447  4
626127  91.579  -53.348  56.414  4
626128  91.612  -53.372  56.380  4
626129  91.645  -53.397  56.349  4
626130  91.678  -53.421  56.317  4
626131  91.712  -53.446  56.286  4
626132  91.745  -53.471  56.255  4
626133  91.779  -53.495  56.223  4
626134  91.812  -53.519  56.191  4
626135  91.845  -53.544  56.159  4
626136  91.878  -53.568  56.126  4
626137  91.913  -53.591  56.093  4
626138  91.954  -53.605  56.059  4
626139  91.995  -53.618  56.025  4
626140  92.035  -53.631  55.991  4
626141  92.076  -53.645  55.958  4
626142  92.117  -53.659  55.925  4
626143  92.157  -53.672  55.891  4
626144  92.198  -53.686  55.857  4
626145  92.239  -53.699  55.825  4
626159  92.809  -53.888  55.270  1
626160  92.850  -53.901  55.261  1
626161  92.891  -53.915  55.253  1
626162  92.931  -53.928  55.244  1
626163  92.972  -53.942  55.237  1
626164  93.013  -53.956  55.232  1
626165  93.054  -53.969  55.228  1
626166  93.096  -53.981  55.222  1
626167  93.144  -53.987  55.216  1
626168  93.192  -53.993  55.211  1
626169  93.212  -54.015  55.206  1
626170  93.231  -54.036  55.200  1
626171  93.251  -54.058  55.193  1
626172  93.271  -54.080  55.181  1
626173  93.290  -54.102  55.171  1
626174  93.309  -54.124  55.162  1
626175  93.329  -54.146  55.154  1
626176  93.349  -54.168  55.149  1
626177  93.360  -54.189  55.146  1
626178  93.369  -54.208  55.147  1
626179  93.378  -54.228  55.150  1
626180  93.388  -54.248  55.152  1
626181  93.397  -54.268  55.153  1
626182  93.435  -54.272  55.155  1
626183  93.468  -54.279  55.157  1
626184  93.499  -54.287  55.157  1
626185  93.530  -54.295  55.160  1
626186  93.561  -54.303  55.163  1
626187  93.592  -54.311  55.167  1
626188  93.623  -54.319  55.172  1
626189  93.653  -54.327  55.178  1
626190  93.675  -54.341  55.186  1
626191  93.696  -54.354  55.197  1
626192  93.717  -54.367  55.207  1
626193  93.739  -54.380  55.211  1
626194  93.760  -54.394  55.208  1
626195  93.782  -54.408  55.200  1
626196  93.803  -54.421  55.189  1
626197  93.825  -54.434  55.181  1
626198  93.846  -54.447  55.181  1
626199  93.867  -54.461  55.181  1
626200  93.889  -54.474  55.176  1
626201  93.911  -54.487  55.167  1
626202  93.932  -54.500  55.156  1
626203  93.954  -54.514  55.140  1
626204  93.975  -54.527  55.128  1
626205  93.996  -54.540  55.110  1
626206  94.018  -54.553  55.088  1
626207  94.035  -54.563  55.066  1
626208  94.050  -54.571  55.049  1
626209  94.065  -54.580  55.043  1
626210  94.081  -54.589  55.047  1
626211  94.097  -54.598  55.046  1
626212  94.112  -54.606  55.042  1
626213  94.135  -54.621  55.034  1
626214  94.160  -54.638  55.023  1
626215  94.185  -54.655  55.012  1
626216  94.210  -54.671  54.997  1
626217  94.235  -54.688  54.973  1
626218  94.259  -54.704  54.949  1
626219  94.284  -54.721  54.927  1
626220  94.309  -54.737  54.908  1
626221  94.333  -54.754  54.888  1
626222  94.358  -54.771  54.865  1
626223  94.387  -54.786  54.835  1
626224  94.424  -54.798  54.803  1
626225  94.461  -54.810  54.772  1
626226  94.498  -54.822  54.741  1
626227  94.535  -54.834  54.711  1
626228  94.572  -54.847  54.682  1
626229  94.610  -54.858  54.643  1
626230  94.647  -54.870  54.601  1
626231  94.684  -54.882  54.558  1
626232  94.721  -54.894  54.513  1
626233  94.759  -54.906  54.466  1
626234  94.795  -54.925  54.416  1
626235  94.829  -54.941  54.358  1
626236  94.863  -54.959  54.296  1
626237  94.897  -54.976  54.233  1
626238  94.931  -54.994  54.172  1
626239  94.966  -55.012  54.114  1
626240  95.000  -55.029  54.062  1
626241  95.034  -55.047  54.006  1
626242  95.069  -55.065  53.946  1
626243  95.103  -55.082  53.887  1
626244  95.137  -55.100  53.830  1
626245  95.170  -55.116  53.775  1
626246  95.202  -55.130  53.721  1
626247  95.234  -55.144  53.663  1
626248  95.265  -55.159  53.605  1
626249  95.297  -55.173  53.550  1
626250  95.329  -55.187  53.494  1
626251  95.360  -55.201  53.440  1
626252  95.393  -55.216  53.386  1
626253  95.424  -55.230  53.330  1
626254  95.456  -55.244  53.278  1
626255  95.488  -55.258  53.232  1
626256  95.520  -55.273  53.189  1
626257  95.551  -55.288  53.147  1
626258  95.583  -55.303  53.107  1
626259  95.614  -55.318  53.066  1
626260  95.645  -55.330  53.022  1
626261  95.675  -55.341  52.975  1
626262  95.705  -55.351  52.928  1
626263  95.736  -55.362  52.879  1
626264  95.766  -55.373  52.829  1
626265  95.797  -55.383  52.779  1
626266  95.828  -55.394  52.726  1
626267  95.858  -55.405  52.669  1
626268  95.889  -55.415  52.611  1
626269  95.922  -55.429  52.553  1
626270  95.957  -55.444  52.495  1
626271  95.991  -55.458  52.434  1
626272  96.026  -55.473  52.372  1
626273  96.061  -55.487  52.308  1
626274  96.095  -55.502  52.244  1
626275  96.126  -55.512  52.178  1
626276  96.158  -55.522  52.114  1
626277  96.189  -55.532  52.052  1
626278  96.220  -55.542  51.988  1
626279  96.251  -55.552  51.926  1
626280  96.283  -55.562  51.862  1
626281  96.314  -55.573  51.798  1
626282  96.345  -55.583  51.735  1
626283  96.376  -55.593  51.673  1
626284  96.407  -55.602  51.610  1
626285  96.441  -55.621  51.546  1
626286  96.475  -55.646  51.482  1
626287  96.511  -55.670  51.416  1
626288  96.545  -55.694  51.352  1
626289  96.581  -55.718  51.288  1
626290  96.615  -55.743  51.224  1
626291  96.632  -55.743  51.160  1
626292  96.649  -55.742  51.094  1
626293  96.666  -55.740  51.030  1
626294  96.682  -55.740  50.967  1
626295  96.699  -55.739  50.907  1
626296  96.716  -55.738  50.848  1
626697  87.625  -50.963  56.371  5
626698  87.633  -50.966  56.389  5
626699  87.628  -50.960  56.405  5
626700  87.659  -50.983  56.420  5
626701  87.690  -51.007  56.433  5
626702  87.721  -51.030  56.445  5
626703  87.752  -51.053  56.453  5
626704  87.783  -51.077  56.457  5
626705  87.814  -51.100  56.456  5
626706  87.845  -51.124  56.454  5
626707  87.875  -51.147  56.449  5
626708  87.909  -51.166  56.442  5
626709  87.944  -51.181  56.431  5
626710  87.981  -51.199  56.415  5
626711  88.019  -51.218  56.399  5
626712  88.027  -51.263  56.381  5
626713  88.013  -51.325  56.360  5
626714  88.045  -51.348  56.339  5
626773  89.985  -52.453  57.105  4
626774  90.018  -52.462  57.109  4
626775  90.050  -52.470  57.113  4
626776  90.082  -52.477  57.117  4
626777  90.115  -52.486  57.123  4
626778  90.147  -52.493  57.128  4
626779  90.179  -52.502  57.134  4
626780  90.212  -52.510  57.142  4
626781  90.244  -52.518  57.149  4
626782  90.261  -52.539  57.155  4
626783  90.277  -52.561  57.162  4
626784  90.293  -52.583  57.170  4
626785  90.309  -52.606  57.177  4
626786  90.341  -52.606  57.185  4
626787  90.373  -52.605  57.190  4
626788  90.405  -52.605  57.193  4
626789  90.437  -52.605  57.196  4
626790  90.468  -52.609  57.199  4
626791  90.494  -52.631  57.204  4
626792  90.519  -52.654  57.205  4
626793  90.544  -52.676  57.198  4
626794  90.569  -52.699  57.189  4
626795  90.594  -52.722  57.181  4
626796  90.619  -52.744  57.176  4
626797  90.645  -52.766  57.174  4
626798  90.676  -52.788  57.170  4
626799  90.712  -52.809  57.165  4
626800  90.751  -52.806  57.161  4
626801  90.792  -52.807  57.156  4
626802  90.832  -52.815  57.147  4
626803  90.873  -52.822  57.136  4
626804  90.913  -52.830  57.124  4
626805  90.953  -52.838  57.105  4
626806  90.994  -52.845  57.084  4
626807  91.034  -52.853  57.064  4
626808  91.074  -52.860  57.048  4
626809  91.108  -52.870  57.030  4
626810  91.110  -52.895  57.008  4
626811  91.111  -52.919  56.982  4
626812  91.113  -52.944  56.957  4
626813  91.117  -52.967  56.932  4
626814  91.133  -52.981  56.906  4
626815  91.159  -53.001  56.879  4
626816  91.192  -53.025  56.853  4
626817  91.226  -53.050  56.824  4
626818  91.259  -53.074  56.793  4
626819  91.293  -53.098  56.761  4
626820  91.326  -53.123  56.727  4
626821  91.359  -53.148  56.693  4
626822  91.392  -53.172  56.659  4
626823  91.426  -53.197  56.623  4
626824  91.459  -53.221  56.586  4
626825  91.493  -53.245  56.550  4
626826  91.526  -53.270  56.515  4
626827  91.559  -53.295  56.479  4
626828  91.592  -53.319  56.446  4
626829  91.626  -53.344  56.411  4
626830  91.659  -53.368  56.378  4
626831  91.693  -53.393  56.345  4
626832  91.726  -53.418  56.313  4
626833  91.759  -53.442  56.281  4
626834  91.792  -53.466  56.248  4
626835  91.825  -53.491  56.215  4
626836  91.859  -53.515  56.181  4
626837  91.892  -53.540  56.147  4
626838  91.927  -53.562  56.112  4
626839  91.968  -53.576  56.077  4
626840  92.009  -53.590  56.042  4
626841  92.050  -53.603  56.006  4
626842  92.090  -53.616  55.971  4
626843  92.131  -53.630  55.936  4
626844  92.171  -53.643  55.901  4
626845  92.212  -53.657  55.866  4
626846  92.253  -53.670  55.832  4
626847  92.294  -53.684  55.801  4
626860  92.824  -53.860  55.265  1
626861  92.864  -53.872  55.255  1
626862  92.905  -53.886  55.245  1
626863  92.946  -53.900  55.234  1
626864  92.986  -53.913  55.225  1
626865  93.027  -53.926  55.219  1
626866  93.071  -53.937  55.213  1
626867  93.119  -53.943  55.205  1
626868  93.166  -53.949  55.197  1
626869  93.198  -53.965  55.189  1
626870  93.217  -53.987  55.181  1
626871  93.237  -54.009  55.174  1
626872  93.256  -54.030  55.167  1
626873  93.276  -54.052  55.157  1
626874  93.295  -54.074  55.149  1
626875  93.315  -54.096  55.141  1
626876  93.334  -54.118  55.134  1
626877  93.354  -54.140  55.130  1
626878  93.373  -54.162  55.129  1
626879  93.390  -54.183  55.129  1
626880  93.399  -54.203  55.132  1
626881  93.408  -54.223  55.133  1
626882  93.421  -54.241  55.134  1
626883  93.457  -54.246  55.136  1
626884  93.488  -54.254  55.136  1
626885  93.519  -54.262  55.135  1
626886  93.550  -54.270  55.137  1
626887  93.581  -54.278  55.139  1
626888  93.613  -54.286  55.143  1
626889  93.643  -54.294  55.149  1
626890  93.675  -54.302  55.155  1
626891  93.702  -54.312  55.163  1
626892  93.723  -54.326  55.173  1
626893  93.745  -54.339  55.181  1
626894  93.766  -54.352  55.183  1
626895  93.787  -54.365  55.179  1
626896  93.809  -54.379  55.171  1
626897  93.831  -54.392  55.162  1
626898  93.852  -54.405  55.160  1
626899  93.873  -54.418  55.165  1
626900  93.895  -54.432  55.169  1
626901  93.916  -54.445  55.167  1
626902  93.938  -54.458  55.157  1
626903  93.959  -54.472  55.143  1
626904  93.981  -54.485  55.124  1
626905  94.002  -54.499  55.105  1
626906  94.024  -54.511  55.083  1
626907  94.043  -54.523  55.062  1
626908  94.058  -54.531  55.047  1
626909  94.073  -54.540  55.039  1
626910  94.089  -54.549  55.037  1
626911  94.105  -54.558  55.038  1
626912  94.120  -54.566  55.035  1
626913  94.136  -54.575  55.027  1
626914  94.152  -54.583  55.017  1
626915  94.177  -54.600  55.005  1
626916  94.201  -54.617  54.991  1
626917  94.226  -54.634  54.975  1
626918  94.251  -54.650  54.953  1
626919  94.275  -54.666  54.931  1
626920  94.300  -54.683  54.910  1
626921  94.325  -54.699  54.890  1
626922  94.349  -54.716  54.870  1
626923  94.374  -54.733  54.847  1
626924  94.401  -54.749  54.816  1
626925  94.438  -54.761  54.784  1
626926  94.476  -54.773  54.750  1
626927  94.513  -54.784  54.717  1
626928  94.550  -54.797  54.684  1
626929  94.587  -54.809  54.653  1
626930  94.624  -54.821  54.614  1
626931  94.662  -54.833  54.572  1
626932  94.699  -54.845  54.529  1
626933  94.736  -54.857  54.485  1
626934  94.774  -54.873  54.439  1
626935  94.812  -54.895  54.389  1
626936  94.845  -54.912  54.331  1
626937  94.879  -54.928  54.270  1
626938  94.912  -54.946  54.211  1
626939  94.946  -54.963  54.156  1
626940  94.980  -54.979  54.104  1
626941  95.014  -54.996  54.053  1
626942  95.048  -55.014  53.998  1
626943  95.083  -55.032  53.940  1
626944  95.117  -55.049  53.881  1
626945  95.151  -55.067  53.824  1
626946  95.183  -55.082  53.767  1
626947  95.215  -55.096  53.713  1
626948  95.247  -55.110  53.658  1
626949  95.278  -55.125  53.599  1
626950  95.310  -55.138  53.543  1
626951  95.342  -55.153  53.488  1
626952  95.374  -55.168  53.434  1
626953  95.405  -55.183  53.379  1
626954  95.437  -55.198  53.324  1
626955  95.469  -55.213  53.277  1
626956  95.500  -55.228  53.235  1
626957  95.532  -55.242  53.194  1
626958  95.564  -55.257  53.154  1
626959  95.596  -55.272  53.116  1
626960  95.627  -55.287  53.077  1
626961  95.657  -55.298  53.034  1
626962  95.687  -55.308  52.989  1
626963  95.718  -55.319  52.941  1
626964  95.747  -55.329  52.891  1
626965  95.777  -55.340  52.842  1
626966  95.808  -55.350  52.794  1
626967  95.838  -55.361  52.742  1
626968  95.869  -55.371  52.686  1
626969  95.899  -55.382  52.630  1
626970  95.933  -55.395  52.573  1
626971  95.967  -55.410  52.514  1
626972  96.002  -55.424  52.452  1
626973  96.036  -55.439  52.389  1
626974  96.068  -55.450  52.323  1
626975  96.099  -55.461  52.258  1
626976  96.130  -55.470  52.192  1
626977  96.162  -55.480  52.127  1
626978  96.193  -55.491  52.064  1
626979  96.224  -55.501  52.000  1
626980  96.255  -55.511  51.937  1
626981  96.287  -55.520  51.872  1
626982  96.318  -55.531  51.808  1
626983  96.349  -55.541  51.744  1
626984  96.380  -55.551  51.681  1
626985  96.411  -55.561  51.618  1
626986  96.446  -55.583  51.555  1
626987  96.481  -55.608  51.490  1
626988  96.516  -55.632  51.424  1
626989  96.551  -55.656  51.359  1
626990  96.586  -55.680  51.296  1
626991  96.621  -55.705  51.231  1
626992  96.647  -55.717  51.167  1
626993  96.664  -55.716  51.101  1
626994  96.680  -55.715  51.037  1
626995  96.697  -55.715  50.974  1
626996  96.714  -55.714  50.914  1
627398  87.642  -50.933  56.394  5
627399  87.678  -50.958  56.412  5
627400  87.701  -50.972  56.428  5
627401  87.681  -50.954  56.444  5
627402  87.711  -50.977  56.458  5
627403  87.743  -51.001  56.470  5
627404  87.773  -51.023  56.479  5
627405  87.804  -51.047  56.482  5
627406  87.835  -51.070  56.481  5
627407  87.866  -51.094  56.477  5
627408  87.898  -51.116  56.471  5
627409  87.933  -51.131  56.463  5
627410  87.971  -51.149  56.452  5
627411  88.006  -51.171  56.435  5
627412  87.988  -51.236  56.416  5
627413  87.998  -51.279  56.396  5
627414  88.030  -51.302  56.375  5
627415  88.061  -51.324  56.351  5
627474  90.006  -52.420  57.104  4
627475  90.038  -52.428  57.109  4
627476  90.070  -52.437  57.114  4
627477  90.102  -52.444  57.120  4
627478  90.134  -52.452  57.125  4
627479  90.167  -52.460  57.132  4
627480  90.199  -52.468  57.138  4
627481  90.232  -52.476  57.146  4
627482  90.264  -52.484  57.153  4
627483  90.292  -52.496  57.160  4
627484  90.308  -52.518  57.168  4
627485  90.324  -52.540  57.177  4
627486  90.340  -52.562  57.184  4
627487  90.365  -52.572  57.191  4
627488  90.397  -52.572  57.196  4
627489  90.429  -52.572  57.200  4
627490  90.461  -52.572  57.202  4
627491  90.493  -52.572  57.204  4
627492  90.519  -52.594  57.206  4
627493  90.544  -52.617  57.205  4
627494  90.569  -52.639  57.198  4
627495  90.594  -52.662  57.190  4
627496  90.619  -52.684  57.182  4
627497  90.645  -52.707  57.175  4
627498  90.670  -52.729  57.171  4
627499  90.695  -52.752  57.169  4
627500  90.728  -52.773  57.166  4
627501  90.767  -52.773  57.163  4
627502  90.808  -52.781  57.160  4
627503  90.848  -52.788  57.155  4
627504  90.888  -52.796  57.147  4
627505  90.929  -52.803  57.135  4
627506  90.968  -52.812  57.120  4
627507  91.008  -52.820  57.104  4
627508  91.047  -52.828  57.090  4
627509  91.086  -52.836  57.076  4
627510  91.118  -52.851  57.056  4
627511  91.133  -52.882  57.034  4
627512  91.134  -52.907  57.009  4
627513  91.136  -52.932  56.984  4
627514  91.147  -52.949  56.960  4
627515  91.163  -52.963  56.935  4
627516  91.179  -52.976  56.911  4
627517  91.207  -52.997  56.887  4
627518  91.240  -53.021  56.859  4
627519  91.273  -53.046  56.830  4
627520  91.306  -53.070  56.798  4
627521  91.340  -53.095  56.764  4
627522  91.373  -53.120  56.728  4
627523  91.406  -53.144  56.695  4
627524  91.440  -53.168  56.659  4
627525  91.473  -53.193  56.622  4
627526  91.506  -53.217  56.584  4
627527  91.539  -53.242  56.548  4
627528  91.573  -53.267  56.512  4
627529  91.606  -53.291  56.478  4
627530  91.640  -53.315  56.442  4
627531  91.673  -53.340  56.408  4
627532  91.706  -53.364  56.374  4
627533  91.740  -53.389  56.340  4
627534  91.773  -53.414  56.307  4
627535  91.806  -53.438  56.273  4
627536  91.840  -53.462  56.238  4
627537  91.873  -53.487  56.203  4
627538  91.906  -53.512  56.167  4
627539  91.941  -53.534  56.132  4
627540  91.982  -53.547  56.095  4
627541  92.023  -53.561  56.058  4
627542  92.064  -53.574  56.021  4
627543  92.104  -53.587  55.984  4
627544  92.145  -53.601  55.948  4
627545  92.186  -53.615  55.911  4
627546  92.226  -53.628  55.875  4
627547  92.267  -53.641  55.840  4
627548  92.308  -53.655  55.807  4
627561  92.838  -53.830  55.260  1
627562  92.878  -53.844  55.248  1
627563  92.919  -53.857  55.237  1
627564  92.960  -53.871  55.225  1
627565  93.001  -53.885  55.214  1
627566  93.046  -53.894  55.206  1
627567  93.093  -53.900  55.198  1
627568  93.141  -53.906  55.189  1
627569  93.184  -53.915  55.179  1
627570  93.203  -53.937  55.169  1
627571  93.222  -53.959  55.159  1
627572  93.242  -53.981  55.151  1
627573  93.262  -54.003  55.143  1
627574  93.281  -54.024  55.135  1
627575  93.300  -54.046  55.127  1
627576  93.320  -54.068  55.120  1
627577  93.339  -54.090  55.114  1
627578  93.359  -54.112  55.112  1
627579  93.378  -54.134  55.110  1
627580  93.398  -54.156  55.111  1
627581  93.417  -54.178  55.113  1
627582  93.429  -54.198  55.115  1
627583  93.445  -54.214  55.116  1
627584  93.478  -54.222  55.116  1
627585  93.509  -54.229  55.116  1
627586  93.540  -54.238  55.115  1
627587  93.571  -54.245  55.116  1
627588  93.602  -54.254  55.118  1
627589  93.633  -54.261  55.123  1
627590  93.664  -54.269  55.128  1
627591  93.695  -54.277  55.133  1
627592  93.726  -54.285  55.139  1
627593  93.751  -54.297  55.148  1
627594  93.772  -54.310  55.153  1
627595  93.793  -54.323  55.154  1
627596  93.815  -54.336  55.150  1
627597  93.836  -54.350  55.143  1
627598  93.858  -54.364  55.139  1
627599  93.879  -54.377  55.142  1
627600  93.901  -54.390  55.148  1
627601  93.922  -54.403  55.153  1
627602  93.943  -54.417  55.151  1
627603  93.965  -54.430  55.141  1
627604  93.986  -54.443  55.125  1
627605  94.008  -54.456  55.104  1
627606  94.030  -54.470  55.082  1
627607  94.050  -54.483  55.060  1
627608  94.066  -54.491  55.043  1
627609  94.081  -54.500  55.034  1
627610  94.097  -54.508  55.029  1
627611  94.113  -54.518  55.027  1
627612  94.128  -54.526  55.025  1
627613  94.144  -54.535  55.019  1
627614  94.159  -54.543  55.010  1
627615  94.175  -54.552  54.999  1
627616  94.193  -54.562  54.987  1
627617  94.217  -54.579  54.975  1
627618  94.242  -54.596  54.962  1
627619  94.267  -54.612  54.944  1
627620  94.291  -54.629  54.924  1
627621  94.316  -54.645  54.902  1
627622  94.341  -54.662  54.881  1
627623  94.366  -54.678  54.860  1
627624  94.391  -54.695  54.834  1
627625  94.416  -54.711  54.802  1
627626  94.453  -54.723  54.769  1
627627  94.490  -54.735  54.734  1
627628  94.528  -54.747  54.697  1
627629  94.565  -54.759  54.659  1
627630  94.602  -54.772  54.625  1
627631  94.639  -54.784  54.585  1
627632  94.676  -54.796  54.543  1
627633  94.713  -54.808  54.500  1
627634  94.751  -54.820  54.456  1
627635  94.790  -54.844  54.410  1
627636  94.828  -54.866  54.360  1
627637  94.861  -54.882  54.303  1
627638  94.895  -54.899  54.245  1
627639  94.928  -54.916  54.191  1
627640  94.962  -54.933  54.142  1
627641  94.996  -54.950  54.094  1
627642  95.030  -54.966  54.044  1
627643  95.063  -54.983  53.988  1
627644  95.097  -55.000  53.931  1
627645  95.131  -55.016  53.874  1
627646  95.165  -55.033  53.818  1
627647  95.196  -55.048  53.762  1
627648  95.228  -55.063  53.709  1
627649  95.260  -55.078  53.652  1
627650  95.291  -55.093  53.593  1
627651  95.323  -55.107  53.536  1
627652  95.355  -55.123  53.481  1
627653  95.386  -55.137  53.427  1
627654  95.418  -55.152  53.376  1
627655  95.450  -55.167  53.328  1
627656  95.481  -55.182  53.285  1
627657  95.513  -55.197  53.245  1
627658  95.545  -55.212  53.205  1
627659  95.577  -55.226  53.164  1
627660  95.608  -55.242  53.125  1
627661  95.639  -55.254  53.085  1
627662  95.669  -55.265  53.043  1
627663  95.699  -55.276  52.996  1
627664  95.729  -55.286  52.949  1
627665  95.759  -55.297  52.902  1
627666  95.790  -55.307  52.855  1
627667  95.819  -55.317  52.807  1
627668  95.849  -55.328  52.757  1
627669  95.880  -55.339  52.704  1
627670  95.910  -55.349  52.649  1
627671  95.943  -55.362  52.592  1
627672  95.977  -55.376  52.532  1
627673  96.010  -55.389  52.468  1
627674  96.041  -55.398  52.404  1
627675  96.073  -55.408  52.337  1
627676  96.104  -55.419  52.272  1
627677  96.135  -55.429  52.205  1
627678  96.166  -55.439  52.140  1
627679  96.197  -55.449  52.076  1
627680  96.229  -55.459  52.013  1
627681  96.260  -55.469  51.949  1
627682  96.291  -55.480  51.884  1
627683  96.322  -55.489  51.819  1
627684  96.353  -55.499  51.755  1
627685  96.384  -55.509  51.691  1
627686  96.416  -55.522  51.628  1
627687  96.451  -55.546  51.564  1
627688  96.486  -55.571  51.500  1
627689  96.521  -55.595  51.433  1
627690  96.556  -55.619  51.369  1
627691  96.591  -55.643  51.305  1
627692  96.626  -55.668  51.241  1
627693  96.661  -55.692  51.177  1
627694  96.678  -55.691  51.111  1
627695  96.694  -55.690  51.046  1
627696  96.711  -55.690  50.984  1
628099  87.658  -50.903  56.415  5
628100  87.695  -50.928  56.433  5
628101  87.731  -50.952  56.450  5
628102  87.768  -50.977  56.465  5
628103  87.733  -50.948  56.480  5
628104  87.764  -50.970  56.494  5
628105  87.795  -50.994  56.503  5
628106  87.826  -51.017  56.506  5
628107  87.857  -51.041  56.505  5
628108  87.888  -51.064  56.500  5
628109  87.923  -51.081  56.493  5
628110  87.960  -51.099  56.483  5
628111  87.967  -51.144  56.470  5
628112  87.951  -51.209  56.452  5
628113  87.982  -51.232  56.431  5
628114  88.014  -51.255  56.410  5
628115  88.046  -51.277  56.387  5
628116  88.077  -51.300  56.362  5
628176  90.058  -52.395  57.110  4
628177  90.090  -52.403  57.116  4
628178  90.122  -52.411  57.122  4
628179  90.155  -52.419  57.128  4
628180  90.187  -52.427  57.135  4
628181  90.219  -52.435  57.142  4
628182  90.251  -52.443  57.151  4
628183  90.284  -52.451  57.158  4
628184  90.316  -52.459  57.165  4
628185  90.339  -52.474  57.173  4
628186  90.356  -52.497  57.182  4
628187  90.372  -52.519  57.190  4
628188  90.389  -52.540  57.197  4
628189  90.421  -52.540  57.201  4
628190  90.453  -52.540  57.204  4
628191  90.485  -52.540  57.206  4
628192  90.517  -52.540  57.207  4
628193  90.543  -52.557  57.207  4
628194  90.569  -52.580  57.204  4
628195  90.594  -52.602  57.198  4
628196  90.619  -52.625  57.190  4
628197  90.645  -52.647  57.182  4
628198  90.670  -52.670  57.175  4
628199  90.695  -52.692  57.170  4
628200  90.720  -52.715  57.168  4
628201  90.745  -52.738  57.165  4
628202  90.783  -52.747  57.162  4
628203  90.822  -52.756  57.160  4
628204  90.862  -52.764  57.156  4
628205  90.901  -52.772  57.150  4
628206  90.940  -52.780  57.142  4
628207  90.980  -52.788  57.132  4
628208  91.019  -52.797  57.123  4
628209  91.059  -52.805  57.115  4
628210  91.098  -52.813  57.104  4
628211  91.126  -52.832  57.080  4
628212  91.141  -52.863  57.057  4
628213  91.155  -52.893  57.034  4
628214  91.161  -52.917  57.010  4
628215  91.177  -52.931  56.986  4
628216  91.193  -52.944  56.964  4
628217  91.210  -52.958  56.941  4
628218  91.226  -52.972  56.919  4
628219  91.253  -52.993  56.892  4
628220  91.287  -53.017  56.864  4
628221  91.320  -53.042  56.832  4
628222  91.354  -53.067  56.799  4
628223  91.387  -53.091  56.764  4
628224  91.420  -53.115  56.730  4
628225  91.453  -53.140  56.694  4
628226  91.487  -53.164  56.656  4
628227  91.520  -53.189  56.619  4
628228  91.554  -53.214  56.583  4
628229  91.587  -53.238  56.545  4
628230  91.620  -53.262  56.510  4
628231  91.654  -53.287  56.474  4
628232  91.687  -53.311  56.438  4
628233  91.720  -53.336  56.403  4
628234  91.753  -53.361  56.368  4
628235  91.787  -53.385  56.334  4
628236  91.820  -53.409  56.298  4
628237  91.854  -53.434  56.262  4
628238  91.887  -53.458  56.225  4
628239  91.920  -53.483  56.188  4
628240  91.955  -53.505  56.151  4
628241  91.996  -53.518  56.113  4
628242  92.037  -53.531  56.074  4
628243  92.078  -53.545  56.035  4
628244  92.119  -53.559  55.996  4
628245  92.159  -53.572  55.959  4
628246  92.200  -53.586  55.921  4
628247  92.240  -53.599  55.883  4
628248  92.281  -53.612  55.847  4
628249  92.322  -53.626  55.813  4
628250  92.363  -53.640  55.781  4
628263  92.893  -53.815  55.242  1
628264  92.933  -53.828  55.229  1
628265  92.974  -53.842  55.215  1
628266  93.020  -53.850  55.203  1
628267  93.068  -53.856  55.193  1
628268  93.116  -53.862  55.183  1
628269  93.164  -53.868  55.173  1
628270  93.189  -53.887  55.162  1
628271  93.208  -53.909  55.151  1
628272  93.227  -53.931  55.140  1
628273  93.247  -53.953  55.130  1
628274  93.267  -53.975  55.123  1
628275  93.286  -53.997  55.115  1
628276  93.305  -54.018  55.108  1
628277  93.325  -54.040  55.101  1
628278  93.345  -54.062  55.095  1
628279  93.364  -54.084  55.093  1
628280  93.383  -54.106  55.091  1
628281  93.403  -54.128  55.092  1
628282  93.423  -54.150  55.094  1
628283  93.442  -54.172  55.096  1
628284  93.467  -54.189  55.097  1
628285  93.498  -54.197  55.096  1
628286  93.529  -54.204  55.096  1
628287  93.560  -54.213  55.095  1
628288  93.591  -54.220  55.095  1
628289  93.622  -54.229  55.098  1
628290  93.653  -54.236  55.102  1
628291  93.685  -54.245  55.106  1
628292  93.715  -54.252  55.111  1
628293  93.747  -54.261  55.116  1
628294  93.778  -54.268  55.123  1
628295  93.799  -54.282  55.127  1
628296  93.821  -54.295  55.128  1
628297  93.842  -54.308  55.127  1
628298  93.863  -54.321  55.123  1
628299  93.885  -54.335  55.121  1
628300  93.906  -54.348  55.123  1
628301  93.928  -54.361  55.126  1
628302  93.949  -54.374  55.128  1
628303  93.971  -54.388  55.124  1
628304  93.992  -54.401  55.114  1
628305  94.014  -54.414  55.097  1
628306  94.035  -54.428  55.077  1
628307  94.057  -54.441  55.058  1
628308  94.074  -54.451  55.042  1
628309  94.089  -54.460  55.031  1
628310  94.105  -54.468  55.026  1
628311  94.121  -54.477  55.021  1
628312  94.136  -54.486  55.017  1
628313  94.152  -54.495  55.013  1
628314  94.168  -54.503  55.006  1
628315  94.183  -54.512  54.997  1
628316  94.199  -54.521  54.987  1
628317  94.214  -54.529  54.976  1
628318  94.234  -54.541  54.967  1
628319  94.258  -54.558  54.955  1
628320  94.283  -54.574  54.939  1
628321  94.308  -54.591  54.918  1
628322  94.333  -54.607  54.895  1
628323  94.357  -54.624  54.873  1
628324  94.382  -54.640  54.852  1
628325  94.407  -54.657  54.824  1
628326  94.431  -54.674  54.790  1
628327  94.468  -54.686  54.754  1
628328  94.505  -54.698  54.717  1
628329  94.542  -54.710  54.678  1
628330  94.579  -54.722  54.638  1
628331  94.617  -54.734  54.601  1
628332  94.654  -54.746  54.561  1
628333  94.691  -54.759  54.518  1
628334  94.728  -54.771  54.473  1
628335  94.767  -54.788  54.427  1
628336  94.807  -54.815  54.379  1
628337  94.844  -54.836  54.331  1
628338  94.878  -54.853  54.278  1
628339  94.911  -54.869  54.227  1
628340  94.945  -54.886  54.178  1
628341  94.978  -54.903  54.131  1
628342  95.012  -54.920  54.085  1
628343  95.046  -54.937  54.034  1
628344  95.079  -54.953  53.976  1
628345  95.113  -54.970  53.919  1
628346  95.147  -54.987  53.864  1
628347  95.178  -55.003  53.811  1
628348  95.209  -55.018  53.758  1
628349  95.241  -55.032  53.703  1
628350  95.272  -55.047  53.646  1
628351  95.304  -55.062  53.587  1
628352  95.336  -55.077  53.530  1
628353  95.368  -55.091  53.475  1
628354  95.399  -55.107  53.422  1
628355  95.431  -55.122  53.374  1
628356  95.462  -55.136  53.333  1
628357  95.494  -55.151  53.293  1
628358  95.526  -55.166  53.255  1
628359  95.557  -55.181  53.215  1
628360  95.589  -55.196  53.174  1
628361  95.621  -55.210  53.133  1
628362  95.651  -55.222  53.092  1
628363  95.681  -55.232  53.050  1
628364  95.711  -55.243  53.006  1
628365  95.741  -55.253  52.962  1
628366  95.771  -55.263  52.917  1
628367  95.801  -55.274  52.871  1
628368  95.831  -55.285  52.823  1
628369  95.862  -55.295  52.775  1
628370  95.891  -55.306  52.723  1
628371  95.921  -55.317  52.667  1
628372  95.952  -55.326  52.608  1
628373  95.983  -55.337  52.545  1
628374  96.014  -55.347  52.481  1
628375  96.045  -55.357  52.416  1
628376  96.077  -55.367  52.349  1
628377  96.108  -55.377  52.285  1
628378  96.139  -55.387  52.220  1
628379  96.170  -55.397  52.155  1
628380  96.201  -55.408  52.091  1
628381  96.233  -55.417  52.027  1
628382  96.264  -55.427  51.963  1
628383  96.295  -55.438  51.898  1
628384  96.326  -55.448  51.833  1
628385  96.358  -55.458  51.768  1
628386  96.389  -55.467  51.704  1
628387  96.421  -55.484  51.640  1
628388  96.457  -55.508  51.575  1
628389  96.491  -55.533  51.510  1
628390  96.527  -55.557  51.445  1
628391  96.561  -55.582  51.380  1
628392  96.597  -55.606  51.316  1
628393  96.631  -55.630  51.252  1
628394  96.667  -55.655  51.188  1
628395  96.692  -55.666  51.122  1
628396  96.709  -55.665  51.058  1
628800  87.676  -50.873  56.434  5
628801  87.712  -50.898  56.452  5
628802  87.748  -50.923  56.469  5
628803  87.784  -50.947  56.485  5
628804  87.821  -50.972  56.501  5
628805  87.798  -50.951  56.514  5
628806  87.817  -50.964  56.525  5
628807  87.848  -50.988  56.528  5
628808  87.879  -51.011  56.527  5
628809  87.912  -51.030  56.522  5
628810  87.946  -51.052  56.514  5
628811  87.928  -51.118  56.501  5
628812  87.935  -51.163  56.487  5
628813  87.967  -51.186  56.468  5
628814  87.999  -51.208  56.445  5
628815  88.031  -51.228  56.421  5
628816  88.064  -51.248  56.396  5
628817  88.098  -51.267  56.370  5
628878  90.110  -52.370  57.117  4
628879  90.143  -52.377  57.123  4
628880  90.175  -52.386  57.130  4
628881  90.207  -52.393  57.138  4
628882  90.239  -52.402  57.146  4
628883  90.271  -52.409  57.155  4
628884  90.304  -52.418  57.163  4
628885  90.336  -52.426  57.169  4
628886  90.368  -52.434  57.178  4
628887  90.387  -52.454  57.186  4
628888  90.403  -52.476  57.193  4
628889  90.419  -52.498  57.200  4
628890  90.444  -52.507  57.204  4
628891  90.476  -52.507  57.206  4
628892  90.509  -52.507  57.208  4
628893  90.541  -52.507  57.208  4
628894  90.569  -52.520  57.206  4
628895  90.594  -52.543  57.203  4
628896  90.619  -52.565  57.198  4
628897  90.644  -52.587  57.190  4
628898  90.669  -52.610  57.182  4
628899  90.694  -52.633  57.175  4
628900  90.720  -52.655  57.170  4
628901  90.745  -52.678  57.167  4
628902  90.773  -52.700  57.164  4
628903  90.805  -52.719  57.161  4
628904  90.834  -52.732  57.160  4
628905  90.873  -52.741  57.157  4
628906  90.912  -52.749  57.154  4
628907  90.952  -52.757  57.152  4
628908  90.992  -52.765  57.148  4
628909  91.031  -52.773  57.143  4
628910  91.071  -52.782  57.139  4
628911  91.110  -52.790  57.125  4
628912  91.134  -52.813  57.104  4
628913  91.148  -52.843  57.080  4
628914  91.163  -52.873  57.056  4
628915  91.187  -52.897  57.033  4
628916  91.207  -52.913  57.011  4
628917  91.223  -52.926  56.990  4
628918  91.239  -52.940  56.970  4
628919  91.256  -52.954  56.950  4
628920  91.272  -52.967  56.926  4
628921  91.301  -52.988  56.897  4
628922  91.334  -53.013  56.865  4
628923  91.367  -53.038  56.832  4
628924  91.401  -53.062  56.797  4
628925  91.434  -53.087  56.764  4
628926  91.467  -53.111  56.728  4
628927  91.501  -53.136  56.690  4
628928  91.534  -53.161  56.654  4
628929  91.568  -53.185  56.617  4
628930  91.601  -53.209  56.579  4
628931  91.634  -53.234  56.543  4
628932  91.667  -53.258  56.505  4
628933  91.701  -53.283  56.468  4
628934  91.734  -53.308  56.432  4
628935  91.768  -53.332  56.396  4
628936  91.801  -53.356  56.360  4
628937  91.834  -53.381  56.323  4
628938  91.867  -53.405  56.286  4
628939  91.900  -53.430  56.248  4
628940  91.934  -53.455  56.210  4
628941  91.969  -53.476  56.170  4
628942  92.010  -53.490  56.130  4
628943  92.051  -53.502  56.089  4
628944  92.092  -53.516  56.048  4
628945  92.133  -53.530  56.009  4
628946  92.173  -53.543  55.970  4
628947  92.214  -53.557  55.931  4
628948  92.255  -53.570  55.892  4
628949  92.295  -53.584  55.855  4
628950  92.336  -53.597  55.820  4
628951  92.377  -53.611  55.786  4
628964  92.907  -53.786  55.235  1
628965  92.947  -53.800  55.221  1
628966  92.995  -53.806  55.207  1
628967  93.043  -53.812  55.192  1
628968  93.091  -53.818  55.181  1
628969  93.139  -53.824  55.170  1
628970  93.174  -53.837  55.158  1
628971  93.194  -53.859  55.146  1
628972  93.213  -53.881  55.134  1
628973  93.232  -53.903  55.122  1
628974  93.252  -53.925  55.113  1
628975  93.272  -53.947  55.104  1
628976  93.291  -53.969  55.097  1
628977  93.310  -53.991  55.089  1
628978  93.330  -54.012  55.082  1
628979  93.350  -54.034  55.077  1
628980  93.369  -54.056  55.075  1
628981  93.389  -54.078  55.073  1
628982  93.408  -54.100  55.073  1
628983  93.428  -54.122  55.074  1
628984  93.452  -54.140  55.076  1
628985  93.482  -54.154  55.076  1
628986  93.515  -54.169  55.075  1
628987  93.550  -54.179  55.075  1
628988  93.581  -54.188  55.075  1
628989  93.612  -54.195  55.075  1
628990  93.643  -54.204  55.077  1
628991  93.674  -54.211  55.081  1
628992  93.705  -54.220  55.085  1
628993  93.736  -54.227  55.089  1
628994  93.767  -54.236  55.095  1
628995  93.798  -54.243  55.100  1
628996  93.827  -54.253  55.103  1
628997  93.848  -54.266  55.106  1
628998  93.869  -54.279  55.107  1
628999  93.891  -54.292  55.106  1
629000  93.912  -54.306  55.103  1
629001  93.934  -54.320  55.101  1
629002  93.955  -54.333  55.101  1
629003  93.977  -54.346  55.098  1
629004  93.998  -54.359  55.092  1
629005  94.019  -54.373  55.083  1
629006  94.041  -54.386  55.069  1
629007  94.062  -54.399  55.054  1
629008  94.082  -54.411  55.041  1
629009  94.098  -54.420  55.032  1
629010  94.113  -54.428  55.026  1
629011  94.129  -54.437  55.022  1
629012  94.144  -54.446  55.017  1
629013  94.160  -54.455  55.013  1
629014  94.176  -54.463  55.009  1
629015  94.191  -54.472  55.003  1
629016  94.207  -54.480  54.996  1
629017  94.222  -54.489  54.988  1
629018  94.238  -54.498  54.979  1
629019  94.254  -54.506  54.969  1
629020  94.275  -54.520  54.955  1
629021  94.299  -54.536  54.937  1
629022  94.324  -54.553  54.913  1
629023  94.349  -54.570  54.888  1
629024  94.373  -54.586  54.865  1
629025  94.398  -54.602  54.842  1
629026  94.423  -54.619  54.813  1
629027  94.448  -54.636  54.778  1
629028  94.482  -54.649  54.739  1
629029  94.520  -54.661  54.700  1
629030  94.557  -54.673  54.660  1
629031  94.594  -54.685  54.618  1
629032  94.631  -54.697  54.580  1
629033  94.669  -54.709  54.538  1
629034  94.706  -54.721  54.494  1
629035  94.743  -54.734  54.448  1
629036  94.783  -54.759  54.402  1
629037  94.823  -54.786  54.355  1
629038  94.860  -54.806  54.310  1
629039  94.894  -54.823  54.261  1
629040  94.927  -54.840  54.213  1
629041  94.961  -54.856  54.166  1
629042  94.994  -54.874  54.118  1
629043  95.028  -54.891  54.068  1
629044  95.062  -54.907  54.015  1
629045  95.096  -54.924  53.957  1
629046  95.129  -54.941  53.900  1
629047  95.161  -54.957  53.846  1
629048  95.191  -54.974  53.794  1
629049  95.222  -54.990  53.742  1
629050  95.253  -55.003  53.691  1
629051  95.285  -55.018  53.636  1
629052  95.317  -55.032  53.579  1
629053  95.348  -55.046  53.523  1
629054  95.380  -55.061  53.469  1
629055  95.412  -55.075  53.419  1
629056  95.444  -55.091  53.375  1
629057  95.475  -55.106  53.338  1
629058  95.507  -55.120  53.302  1
629059  95.538  -55.135  53.264  1
629060  95.570  -55.151  53.224  1
629061  95.602  -55.165  53.183  1
629062  95.633  -55.179  53.142  1
629063  95.663  -55.189  53.099  1
629064  95.693  -55.200  53.058  1
629065  95.723  -55.210  53.018  1
629066  95.753  -55.220  52.977  1
629067  95.783  -55.231  52.933  1
629068  95.813  -55.242  52.887  1
629069  95.843  -55.252  52.838  1
629070  95.873  -55.263  52.790  1
629071  95.902  -55.275  52.738  1
629072  95.932  -55.287  52.682  1
629073  95.961  -55.297  52.622  1
629074  95.990  -55.301  52.560  1
629075  96.019  -55.306  52.495  1
629076  96.049  -55.315  52.430  1
629077  96.081  -55.326  52.365  1
629078  96.112  -55.336  52.302  1
629079  96.143  -55.345  52.237  1
629080  96.174  -55.356  52.173  1
629081  96.205  -55.366  52.109  1
629082  96.237  -55.376  52.045  1
629083  96.268  -55.386  51.981  1
629084  96.299  -55.396  51.916  1
629085  96.330  -55.406  51.850  1
629086  96.362  -55.416  51.785  1
629087  96.393  -55.426  51.720  1
629088  96.427  -55.447  51.656  1
629089  96.462  -55.471  51.591  1
629090  96.497  -55.495  51.525  1
629091  96.532  -55.520  51.460  1
629092  96.567  -55.544  51.395  1
629093  96.602  -55.568  51.331  1
629094  96.637  -55.593  51.266  1
629095  96.672  -55.617  51.203  1
629096  96.707  -55.641  51.138  1
629097  96.723  -55.640  51.072  1
629502  87.728  -50.868  56.469  5
629503  87.765  -50.892  56.487  5
629504  87.801  -50.917  56.504  5
629505  87.837  -50.942  56.519  5
629506  87.873  -50.967  56.532  5
629507  87.865  -50.957  56.548  5
629508  87.869  -50.958  56.554  5
629509  87.901  -50.980  56.550  5
629510  87.907  -51.026  56.541  5
629511  87.890  -51.092  56.528  5
629512  87.920  -51.116  56.515  5
629513  87.952  -51.137  56.500  5
629514  87.985  -51.156  56.479  5
629515  88.019  -51.176  56.456  5
629516  88.051  -51.195  56.431  5
629517  88.084  -51.215  56.404  5
629518  88.118  -51.233  56.376  5
629519  88.150  -51.253  56.348  5
629581  90.194  -52.352  57.132  4
629582  90.227  -52.360  57.141  4
629583  90.259  -52.368  57.149  4
629584  90.292  -52.376  57.158  4
629585  90.324  -52.384  57.167  4
629586  90.356  -52.392  57.172  4
629587  90.388  -52.400  57.181  4
629588  90.418  -52.411  57.189  4
629589  90.434  -52.433  57.195  4
629590  90.450  -52.455  57.202  4
629591  90.468  -52.474  57.206  4
629592  90.500  -52.474  57.207  4
629593  90.532  -52.474  57.208  4
629594  90.565  -52.474  57.207  4
629595  90.594  -52.483  57.204  4
629596  90.619  -52.506  57.202  4
629597  90.644  -52.528  57.197  4
629598  90.669  -52.550  57.189  4
629599  90.694  -52.573  57.183  4
629600  90.720  -52.596  57.175  4
629601  90.745  -52.618  57.170  4
629602  90.770  -52.641  57.167  4
629603  90.805  -52.660  57.164  4
629604  90.845  -52.678  57.161  4
629605  90.863  -52.701  57.159  4
629606  90.885  -52.717  57.158  4
629607  90.925  -52.725  57.160  4
629608  90.964  -52.734  57.165  4
629609  91.003  -52.742  57.167  4
629610  91.043  -52.750  57.164  4
629611  91.082  -52.758  57.161  4
629612  91.121  -52.766  57.145  4
629613  91.141  -52.793  57.124  4
629614  91.156  -52.823  57.101  4
629615  91.176  -52.850  57.078  4
629616  91.204  -52.870  57.057  4
629617  91.231  -52.891  57.037  4
629618  91.253  -52.907  57.021  4
629619  91.270  -52.922  57.001  4
629620  91.286  -52.935  56.985  4
629621  91.302  -52.949  56.962  4
629622  91.318  -52.963  56.931  4
629623  91.348  -52.985  56.895  4
629624  91.381  -53.009  56.864  4
629625  91.415  -53.034  56.829  4
629626  91.448  -53.058  56.797  4
629627  91.482  -53.082  56.761  4
629628  91.515  -53.107  56.724  4
629629  91.548  -53.132  56.687  4
629630  91.581  -53.156  56.650  4
629631  91.614  -53.181  56.612  4
629632  91.648  -53.205  56.575  4
629633  91.681  -53.230  56.537  4
629634  91.715  -53.255  56.499  4
629635  91.748  -53.279  56.461  4
629636  91.781  -53.303  56.424  4
629637  91.814  -53.328  56.385  4
629638  91.848  -53.352  56.347  4
629639  91.881  -53.377  56.308  4
629640  91.915  -53.402  56.270  4
629641  91.948  -53.426  56.230  4
629642  91.984  -53.447  56.187  4
629643  92.024  -53.460  56.146  4
629644  92.065  -53.474  56.104  4
629645  92.106  -53.487  56.062  4
629646  92.147  -53.501  56.021  4
629647  92.188  -53.515  55.981  4
629648  92.228  -53.527  55.940  4
629649  92.269  -53.541  55.901  4
629650  92.310  -53.555  55.863  4
629651  92.350  -53.568  55.826  4
629652  92.391  -53.582  55.791  4
629666  92.970  -53.762  55.215  1
629667  93.018  -53.768  55.199  1
629668  93.066  -53.774  55.183  1
629669  93.114  -53.780  55.170  1
629670  93.160  -53.787  55.157  1
629671  93.179  -53.809  55.144  1
629672  93.199  -53.831  55.132  1
629673  93.218  -53.853  55.119  1
629674  93.238  -53.875  55.106  1
629675  93.257  -53.897  55.096  1
629676  93.277  -53.919  55.087  1
629677  93.296  -53.941  55.079  1
629678  93.316  -53.963  55.072  1
629679  93.335  -53.985  55.064  1
629680  93.355  -54.006  55.058  1
629681  93.374  -54.028  55.057  1
629682  93.394  -54.050  55.054  1
629683  93.413  -54.072  55.054  1
629684  93.438  -54.090  55.054  1
629685  93.469  -54.104  55.055  1
629686  93.498  -54.119  55.055  1
629687  93.529  -54.134  55.054  1
629688  93.562  -54.148  55.055  1
629689  93.600  -54.161  55.055  1
629690  93.632  -54.171  55.056  1
629691  93.663  -54.179  55.059  1
629692  93.694  -54.187  55.062  1
629693  93.725  -54.195  55.066  1
629694  93.757  -54.203  55.070  1
629695  93.787  -54.211  55.074  1
629696  93.819  -54.219  55.078  1
629697  93.850  -54.226  55.083  1
629698  93.875  -54.238  55.087  1
629699  93.897  -54.251  55.090  1
629700  93.918  -54.264  55.090  1
629701  93.939  -54.277  55.084  1
629702  93.961  -54.291  55.079  1
629703  93.982  -54.304  55.075  1
629704  94.004  -54.317  55.069  1
629705  94.026  -54.330  55.062  1
629706  94.047  -54.344  55.055  1
629707  94.068  -54.357  55.044  1
629708  94.089  -54.370  55.035  1
629709  94.106  -54.380  55.027  1
629710  94.121  -54.388  55.022  1
629711  94.137  -54.397  55.019  1
629712  94.152  -54.405  55.018  1
629713  94.168  -54.414  55.014  1
629714  94.184  -54.423  55.009  1
629715  94.199  -54.432  55.006  1
629716  94.215  -54.440  55.002  1
629717  94.230  -54.449  54.996  1
629718  94.246  -54.458  54.988  1
629719  94.262  -54.466  54.979  1
629720  94.277  -54.475  54.965  1
629721  94.292  -54.483  54.949  1
629722  94.316  -54.499  54.928  1
629723  94.340  -54.515  54.904  1
629724  94.365  -54.532  54.878  1
629725  94.390  -54.548  54.854  1
629726  94.414  -54.565  54.829  1
629727  94.439  -54.581  54.800  1
629728  94.464  -54.598  54.765  1
629729  94.497  -54.612  54.725  1
629730  94.534  -54.624  54.684  1
629731  94.571  -54.636  54.642  1
629732  94.609  -54.648  54.599  1
629733  94.646  -54.660  54.559  1
629734  94.683  -54.672  54.517  1
629735  94.720  -54.684  54.471  1
629736  94.759  -54.703  54.425  1
629737  94.800  -54.730  54.380  1
629738  94.840  -54.756  54.335  1
629739  94.876  -54.777  54.292  1
629740  94.909  -54.793  54.245  1
629741  94.943  -54.810  54.198  1
629742  94.977  -54.827  54.150  1
629743  95.011  -54.844  54.101  1
629744  95.044  -54.861  54.049  1
629745  95.078  -54.878  53.995  1
629746  95.112  -54.894  53.937  1
629747  95.143  -54.911  53.880  1
629748  95.174  -54.928  53.826  1
629749  95.204  -54.944  53.774  1
629750  95.234  -54.960  53.722  1
629751  95.265  -54.975  53.673  1
629752  95.297  -54.989  53.620  1
629753  95.329  -55.003  53.567  1
629754  95.361  -55.017  53.514  1
629755  95.393  -55.032  53.465  1
629756  95.424  -55.046  53.420  1
629757  95.456  -55.060  53.381  1
629758  95.488  -55.075  53.346  1
629759  95.520  -55.090  53.309  1
629760  95.551  -55.104  53.271  1
629761  95.583  -55.119  53.233  1
629762  95.614  -55.135  53.193  1
629763  95.645  -55.146  53.154  1
629764  95.675  -55.157  53.112  1
629765  95.705  -55.166  53.072  1
629766  95.735  -55.177  53.031  1
629767  95.765  -55.188  52.990  1
629768  95.795  -55.200  52.947  1
629769  95.824  -55.211  52.902  1
629770  95.853  -55.223  52.852  1
629771  95.883  -55.235  52.802  1
629772  95.912  -55.247  52.748  1
629773  95.941  -55.259  52.692  1
629774  95.971  -55.269  52.635  1
629775  96.000  -55.273  52.575  1
629776  96.028  -55.278  52.510  1
629777  96.057  -55.282  52.447  1
629778  96.086  -55.286  52.385  1
629779  96.116  -55.294  52.321  1
629780  96.148  -55.304  52.257  1
629781  96.179  -55.314  52.193  1
629782  96.210  -55.324  52.129  1
629783  96.241  -55.334  52.065  1
629784  96.272  -55.344  52.000  1
629785  96.304  -55.354  51.934  1
629786  96.334  -55.364  51.868  1
629787  96.366  -55.374  51.803  1
629788  96.397  -55.385  51.738  1
629789  96.432  -55.409  51.673  1
629790  96.467  -55.434  51.607  1
629791  96.502  -55.458  51.541  1
629792  96.537  -55.483  51.476  1
629793  96.572  -55.507  51.411  1
629794  96.607  -55.531  51.347  1
629795  96.642  -55.555  51.282  1
629796  96.677  -55.580  51.219  1
629797  96.712  -55.604  51.153  1
629798  96.738  -55.615  51.088  1
630203  87.746  -50.838  56.483  5
630204  87.782  -50.863  56.501  5
630205  87.818  -50.887  56.518  5
630206  87.854  -50.912  56.534  5
630207  87.891  -50.936  56.548  5
630208  87.927  -50.961  56.570  5
630209  87.922  -50.972  56.577  5
630210  87.868  -51.000  56.570  5
630211  87.873  -51.046  56.555  5
630212  87.906  -51.065  56.540  5
630213  87.939  -51.085  56.525  5
630214  87.972  -51.104  56.509  5
630215  88.005  -51.123  56.487  5
630216  88.038  -51.142  56.462  5
630217  88.071  -51.161  56.436  5
630218  88.105  -51.181  56.408  5
630219  88.137  -51.200  56.380  5
630220  88.171  -51.220  56.350  5
630283  90.247  -52.327  57.142  4
630284  90.279  -52.335  57.150  4
630285  90.311  -52.343  57.159  4
630286  90.344  -52.351  57.168  4
630287  90.376  -52.358  57.176  4
630288  90.408  -52.367  57.183  4
630289  90.441  -52.375  57.190  4
630290  90.465  -52.390  57.197  4
630291  90.481  -52.412  57.202  4
630292  90.498  -52.434  57.206  4
630293  90.524  -52.441  57.207  4
630294  90.556  -52.441  57.207  4
630295  90.588  -52.441  57.205  4
630296  90.619  -52.446  57.202  4
630297  90.644  -52.468  57.200  4
630298  90.669  -52.490  57.196  4
630299  90.694  -52.513  57.189  4
630300  90.720  -52.536  57.183  4
630301  90.745  -52.559  57.176  4
630302  90.770  -52.581  57.171  4
630303  90.795  -52.603  57.169  4
630304  90.835  -52.622  57.166  4
630305  90.876  -52.640  57.162  4
630306  90.917  -52.657  57.163  4
630307  90.921  -52.683  57.166  4
630308  90.936  -52.702  57.173  4
630309  90.975  -52.710  57.183  4
630310  91.015  -52.719  57.189  4
630311  91.054  -52.727  57.188  4
630312  91.094  -52.735  57.180  4
630313  91.134  -52.743  57.163  4
630314  91.149  -52.773  57.142  4
630315  91.164  -52.803  57.121  4
630316  91.192  -52.824  57.101  4
630317  91.220  -52.844  57.081  4
630318  91.248  -52.865  57.064  4
630319  91.276  -52.885  57.051  4
630320  91.300  -52.903  57.035  4
630321  91.316  -52.917  57.020  4
630322  91.332  -52.931  56.996  4
630323  91.349  -52.944  56.962  4
630324  91.365  -52.958  56.925  4
630325  91.395  -52.981  56.892  4
630326  91.429  -53.005  56.860  4
630327  91.462  -53.030  56.827  4
630328  91.495  -53.054  56.792  4
630329  91.528  -53.079  56.756  4
630330  91.562  -53.104  56.720  4
630331  91.595  -53.128  56.683  4
630332  91.629  -53.152  56.644  4
630333  91.662  -53.177  56.607  4
630334  91.695  -53.201  56.569  4
630335  91.728  -53.226  56.529  4
630336  91.762  -53.251  56.490  4
630337  91.795  -53.275  56.451  4
630338  91.828  -53.299  56.411  4
630339  91.862  -53.324  56.371  4
630340  91.895  -53.349  56.331  4
630341  91.929  -53.373  56.290  4
630342  91.962  -53.398  56.248  4
630343  91.998  -53.418  56.205  4
630344  92.038  -53.431  56.162  4
630345  92.079  -53.445  56.118  4
630346  92.120  -53.458  56.075  4
630347  92.161  -53.472  56.033  4
630348  92.202  -53.486  55.991  4
630349  92.242  -53.499  55.949  4
630350  92.283  -53.512  55.910  4
630351  92.324  -53.526  55.871  4
630352  92.365  -53.540  55.833  4
630353  92.405  -53.553  55.797  4
630368  93.041  -53.730  55.192  1
630369  93.089  -53.736  55.175  1
630370  93.137  -53.742  55.161  1
630371  93.165  -53.759  55.147  1
630372  93.185  -53.781  55.133  1
630373  93.204  -53.803  55.119  1
630374  93.223  -53.825  55.105  1
630375  93.243  -53.847  55.092  1
630376  93.263  -53.869  55.081  1
630377  93.282  -53.891  55.071  1
630378  93.301  -53.913  55.063  1
630379  93.321  -53.935  55.055  1
630380  93.340  -53.957  55.047  1
630381  93.360  -53.979  55.041  1
630382  93.379  -54.000  55.039  1
630383  93.399  -54.022  55.036  1
630384  93.424  -54.040  55.035  1
630385  93.454  -54.054  55.035  1
630386  93.484  -54.069  55.034  1
630387  93.514  -54.084  55.034  1
630388  93.545  -54.098  55.034  1
630389  93.574  -54.113  55.036  1
630390  93.610  -54.127  55.036  1
630391  93.647  -54.141  55.038  1
630392  93.684  -54.154  55.041  1
630393  93.715  -54.162  55.043  1
630394  93.746  -54.170  55.048  1
630395  93.777  -54.178  55.051  1
630396  93.808  -54.185  55.055  1
630397  93.839  -54.194  55.059  1
630398  93.870  -54.201  55.064  1
630399  93.901  -54.210  55.068  1
630400  93.924  -54.222  55.071  1
630401  93.945  -54.236  55.072  1
630402  93.967  -54.248  55.067  1
630403  93.988  -54.262  55.063  1
630404  94.009  -54.276  55.058  1
630405  94.031  -54.289  55.053  1
630406  94.053  -54.302  55.044  1
630407  94.074  -54.315  55.037  1
630408  94.096  -54.329  55.029  1
630409  94.114  -54.339  55.022  1
630410  94.129  -54.348  55.017  1
630411  94.145  -54.357  55.013  1
630412  94.160  -54.365  55.012  1
630413  94.176  -54.374  55.012  1
630414  94.192  -54.383  55.010  1
630415  94.207  -54.392  55.006  1
630416  94.223  -54.400  55.003  1
630417  94.239  -54.408  55.000  1
630418  94.254  -54.417  54.995  1
630419  94.270  -54.426  54.987  1
630420  94.285  -54.435  54.976  1
630421  94.300  -54.443  54.960  1
630422  94.316  -54.452  54.942  1
630423  94.332  -54.461  54.920  1
630424  94.356  -54.477  54.894  1
630425  94.382  -54.494  54.869  1
630426  94.406  -54.511  54.844  1
630427  94.431  -54.527  54.817  1
630428  94.456  -54.543  54.789  1
630429  94.480  -54.560  54.753  1
630430  94.512  -54.574  54.713  1
630431  94.549  -54.587  54.673  1
630432  94.586  -54.598  54.632  1
630433  94.624  -54.610  54.590  1
630434  94.661  -54.622  54.548  1
630435  94.698  -54.634  54.501  1
630436  94.736  -54.647  54.452  1
630437  94.776  -54.674  54.405  1
630438  94.816  -54.701  54.360  1
630439  94.856  -54.728  54.318  1
630440  94.892  -54.747  54.275  1
630441  94.925  -54.764  54.228  1
630442  94.959  -54.781  54.179  1
630443  94.993  -54.797  54.129  1
630444  95.027  -54.814  54.079  1
630445  95.060  -54.831  54.027  1
630446  95.094  -54.848  53.975  1
630447  95.126  -54.865  53.917  1
630448  95.157  -54.881  53.860  1
630449  95.187  -54.897  53.806  1
630450  95.217  -54.914  53.754  1
630451  95.247  -54.931  53.703  1
630452  95.278  -54.946  53.655  1
630453  95.310  -54.960  53.606  1
630454  95.341  -54.975  53.556  1
630455  95.373  -54.988  53.509  1
630456  95.405  -55.003  53.465  1
630457  95.437  -55.017  53.424  1
630458  95.469  -55.031  53.388  1
630459  95.500  -55.045  53.353  1
630460  95.532  -55.060  53.317  1
630461  95.564  -55.074  53.281  1
630462  95.596  -55.089  53.243  1
630463  95.627  -55.103  53.205  1
630464  95.657  -55.113  53.167  1
630465  95.687  -55.124  53.126  1
630466  95.716  -55.135  53.085  1
630467  95.745  -55.148  53.044  1
630468  95.775  -55.160  53.002  1
630469  95.804  -55.171  52.958  1
630470  95.833  -55.183  52.911  1
630471  95.863  -55.195  52.862  1
630472  95.892  -55.207  52.812  1
630473  95.921  -55.218  52.759  1
630474  95.951  -55.230  52.704  1
630475  95.980  -55.241  52.648  1
630476  96.009  -55.245  52.590  1
630477  96.038  -55.249  52.530  1
630478  96.067  -55.254  52.472  1
630479  96.096  -55.258  52.411  1
630480  96.125  -55.263  52.348  1
630481  96.154  -55.267  52.283  1
630482  96.183  -55.273  52.218  1
630483  96.214  -55.282  52.152  1
630484  96.245  -55.292  52.087  1
630485  96.276  -55.303  52.021  1
630486  96.308  -55.313  51.955  1
630487  96.339  -55.323  51.888  1
630488  96.370  -55.332  51.822  1
630489  96.402  -55.348  51.756  1
630490  96.438  -55.372  51.691  1
630491  96.472  -55.396  51.625  1
630492  96.508  -55.420  51.559  1
630493  96.542  -55.445  51.493  1
630494  96.578  -55.469  51.428  1
630495  96.612  -55.493  51.364  1
630496  96.648  -55.517  51.299  1
630497  96.682  -55.542  51.235  1
630498  96.718  -55.567  51.169  1
630499  96.752  -55.590  51.105  1
630904  87.762  -50.807  56.493  5
630905  87.798  -50.832  56.511  5
630906  87.835  -50.857  56.529  5
630907  87.871  -50.882  56.547  5
630908  87.907  -50.907  56.560  5
630909  87.918  -50.945  56.573  5
630910  87.903  -50.997  56.581  5
630911  87.885  -51.041  56.577  5
630912  87.900  -51.026  56.563  5
630913  87.926  -51.032  56.548  5
630914  87.959  -51.052  56.533  5
630915  87.992  -51.070  56.514  5
630916  88.025  -51.090  56.492  5
630917  88.058  -51.109  56.466  5
630918  88.092  -51.129  56.438  5
630919  88.124  -51.148  56.409  5
630920  88.157  -51.168  56.380  5
630921  88.191  -51.186  56.349  5
630986  90.331  -52.309  57.161  4
630987  90.364  -52.318  57.169  4
630988  90.396  -52.325  57.177  4
630989  90.428  -52.333  57.184  4
630990  90.461  -52.342  57.190  4
630991  90.493  -52.349  57.196  4
630992  90.513  -52.368  57.202  4
630993  90.529  -52.390  57.205  4
630994  90.547  -52.409  57.205  4
630995  90.580  -52.409  57.205  4
630996  90.612  -52.409  57.203  4
630997  90.644  -52.409  57.200  4
630998  90.669  -52.431  57.198  4
630999  90.694  -52.453  57.195  4
631000  90.720  -52.476  57.189  4
631001  90.745  -52.499  57.184  4
631002  90.770  -52.521  57.177  4
631003  90.795  -52.543  57.174  4
631004  90.826  -52.565  57.173  4
631005  90.867  -52.583  57.171  4
631006  90.907  -52.600  57.166  4
631007  90.948  -52.619  57.168  4
631008  90.974  -52.639  57.174  4
631009  90.978  -52.665  57.184  4
631010  90.987  -52.687  57.194  4
631011  91.027  -52.695  57.198  4
631012  91.066  -52.703  57.194  4
631013  91.105  -52.712  57.185  4
631014  91.142  -52.722  57.172  4
631015  91.156  -52.753  57.158  4
631016  91.180  -52.777  57.143  4
631017  91.208  -52.797  57.127  4
631018  91.236  -52.818  57.109  4
631019  91.264  -52.838  57.092  4
631020  91.292  -52.859  57.082  4
631021  91.320  -52.879  57.069  4
631022  91.346  -52.898  57.054  4
631023  91.362  -52.913  57.028  4
631024  91.378  -52.926  56.991  4
631025  91.394  -52.940  56.954  4
631026  91.411  -52.954  56.921  4
631027  91.442  -52.977  56.889  4
631028  91.476  -53.001  56.857  4
631029  91.509  -53.026  56.823  4
631030  91.542  -53.051  56.789  4
631031  91.576  -53.075  56.753  4
631032  91.609  -53.099  56.716  4
631033  91.643  -53.124  56.677  4
631034  91.676  -53.148  56.639  4
631035  91.709  -53.173  56.599  4
631036  91.742  -53.198  56.559  4
631037  91.776  -53.222  56.518  4
631038  91.809  -53.246  56.477  4
631039  91.843  -53.271  56.436  4
631040  91.876  -53.295  56.394  4
631041  91.909  -53.320  56.352  4
631042  91.942  -53.345  56.310  4
631043  91.976  -53.369  56.266  4
631044  92.012  -53.389  56.222  4
631045  92.053  -53.402  56.177  4
631046  92.093  -53.416  56.132  4
631047  92.134  -53.430  56.088  4
631048  92.175  -53.443  56.044  4
631049  92.216  -53.456  56.002  4
631050  92.257  -53.470  55.959  4
631051  92.297  -53.483  55.918  4
631052  92.338  -53.497  55.878  4
631053  92.379  -53.511  55.840  4
631054  92.420  -53.524  55.803  4
631069  93.064  -53.692  55.185  1
631070  93.112  -53.698  55.167  1
631071  93.150  -53.709  55.151  1
631072  93.170  -53.731  55.136  1
631073  93.190  -53.753  55.121  1
631074  93.209  -53.775  55.106  1
631075  93.228  -53.797  55.091  1
631076  93.248  -53.819  55.077  1
631077  93.268  -53.841  55.066  1
631078  93.287  -53.863  55.056  1
631079  93.306  -53.885  55.047  1
631080  93.326  -53.907  55.039  1
631081  93.346  -53.928  55.031  1
631082  93.365  -53.950  55.024  1
631083  93.384  -53.972  55.021  1
631084  93.410  -53.990  55.019  1
631085  93.440  -54.004  55.018  1
631086  93.471  -54.019  55.017  1
631087  93.500  -54.033  55.016  1
631088  93.531  -54.048  55.015  1
631089  93.560  -54.063  55.017  1
631090  93.590  -54.077  55.018  1
631091  93.621  -54.091  55.019  1
631092  93.656  -54.106  55.021  1
631093  93.694  -54.120  55.023  1
631094  93.731  -54.133  55.026  1
631095  93.766  -54.145  55.030  1
631096  93.797  -54.153  55.033  1
631097  93.829  -54.160  55.037  1
631098  93.859  -54.169  55.042  1
631099  93.891  -54.176  55.046  1
631100  93.922  -54.185  55.050  1
631101  93.951  -54.194  55.053  1
631102  93.973  -54.207  55.055  1
631103  93.994  -54.220  55.052  1
631104  94.015  -54.233  55.049  1
631105  94.037  -54.247  55.045  1
631106  94.058  -54.260  55.040  1
631107  94.080  -54.273  55.033  1
631108  94.101  -54.286  55.027  1
631109  94.122  -54.299  55.022  1
631110  94.137  -54.308  55.018  1
631111  94.153  -54.317  55.013  1
631112  94.169  -54.325  55.008  1
631113  94.184  -54.334  55.004  1
631114  94.200  -54.342  55.004  1
631115  94.215  -54.352  55.001  1
631116  94.231  -54.360  54.998  1
631117  94.247  -54.368  54.997  1
631118  94.262  -54.377  54.994  1
631119  94.278  -54.386  54.989  1
631120  94.293  -54.395  54.981  1
631121  94.309  -54.403  54.970  1
631122  94.324  -54.412  54.953  1
631123  94.340  -54.421  54.935  1
631124  94.355  -54.430  54.912  1
631125  94.373  -54.439  54.886  1
631126  94.398  -54.456  54.861  1
631127  94.422  -54.473  54.836  1
631128  94.447  -54.489  54.809  1
631129  94.472  -54.505  54.781  1
631130  94.496  -54.522  54.746  1
631131  94.527  -54.536  54.706  1
631132  94.564  -54.549  54.665  1
631133  94.601  -54.561  54.624  1
631134  94.638  -54.573  54.582  1
631135  94.676  -54.585  54.538  1
631136  94.713  -54.597  54.489  1
631137  94.752  -54.618  54.438  1
631138  94.792  -54.645  54.389  1
631139  94.832  -54.671  54.343  1
631140  94.873  -54.698  54.300  1
631141  94.908  -54.718  54.258  1
631142  94.942  -54.734  54.210  1
631143  94.975  -54.751  54.160  1
631144  95.009  -54.768  54.109  1
631145  95.043  -54.784  54.058  1
631146  95.076  -54.801  54.007  1
631147  95.110  -54.818  53.955  1
631148  95.139  -54.834  53.899  1
631149  95.170  -54.851  53.844  1
631150  95.200  -54.868  53.791  1
631151  95.230  -54.884  53.740  1
631152  95.260  -54.901  53.691  1
631153  95.290  -54.917  53.646  1
631154  95.322  -54.931  53.599  1
631155  95.354  -54.946  53.553  1
631156  95.386  -54.960  53.511  1
631157  95.417  -54.974  53.471  1
631158  95.449  -54.988  53.432  1
631159  95.481  -55.002  53.396  1
631160  95.513  -55.016  53.361  1
631161  95.544  -55.031  53.327  1
631162  95.576  -55.044  53.292  1
631163  95.608  -55.059  53.256  1
631164  95.637  -55.072  53.219  1
631165  95.667  -55.084  53.180  1
631166  95.696  -55.095  53.140  1
631167  95.726  -55.107  53.099  1
631168  95.755  -55.119  53.057  1
631169  95.784  -55.131  53.014  1
631170  95.814  -55.143  52.969  1
631171  95.843  -55.154  52.922  1
631172  95.873  -55.166  52.874  1
631173  95.902  -55.178  52.824  1
631174  95.932  -55.190  52.773  1
631175  95.961  -55.202  52.719  1
631176  95.990  -55.213  52.664  1
631177  96.019  -55.217  52.608  1
631178  96.048  -55.221  52.554  1
631179  96.077  -55.226  52.502  1
631180  96.106  -55.230  52.443  1
631181  96.134  -55.235  52.381  1
631182  96.163  -55.239  52.315  1
631183  96.192  -55.244  52.248  1
631184  96.221  -55.248  52.181  1
631185  96.250  -55.252  52.114  1
631186  96.281  -55.261  52.046  1
631187  96.312  -55.271  51.979  1
631188  96.343  -55.281  51.911  1
631189  96.374  -55.292  51.843  1
631190  96.408  -55.311  51.777  1
631191  96.443  -55.335  51.712  1
631192  96.478  -55.359  51.645  1
631193  96.513  -55.383  51.579  1
631194  96.548  -55.408  51.512  1
631195  96.583  -55.432  51.447  1
631196  96.618  -55.456  51.382  1
631197  96.653  -55.480  51.317  1
631198  96.688  -55.505  51.252  1
631199  96.723  -55.529  51.187  1
631200  96.758  -55.553  51.122  1
631201  96.783  -55.564  51.059  1
631605  87.779  -50.778  56.501  5
631606  87.815  -50.802  56.518  5
631607  87.851  -50.827  56.535  5
631608  87.888  -50.851  56.553  5
631609  87.891  -50.895  56.564  5
631610  87.876  -50.947  56.573  5
631611  87.872  -50.992  56.578  5
631612  87.907  -51.013  56.574  5
631613  87.941  -51.033  56.562  5
631614  87.959  -51.022  56.548  5
631615  87.979  -51.018  56.532  5
631616  88.012  -51.037  56.514  5
631617  88.045  -51.057  56.491  5
631618  88.078  -51.076  56.466  5
631619  88.111  -51.096  56.438  5
631620  88.144  -51.114  56.408  5
631621  88.178  -51.134  56.377  5
631622  88.211  -51.153  56.345  5
631687  90.352  -52.276  57.161  4
631688  90.384  -52.284  57.170  4
631689  90.416  -52.292  57.176  4
631690  90.448  -52.300  57.183  4
631691  90.480  -52.308  57.189  4
631692  90.513  -52.316  57.195  4
631693  90.544  -52.325  57.200  4
631694  90.560  -52.347  57.203  4
631695  90.576  -52.370  57.202  4
631696  90.603  -52.376  57.201  4
631697  90.636  -52.376  57.200  4
631698  90.668  -52.376  57.197  4
631699  90.694  -52.394  57.194  4
631700  90.719  -52.416  57.192  4
631701  90.744  -52.439  57.187  4
631702  90.769  -52.462  57.182  4
631703  90.795  -52.484  57.179  4
631704  90.820  -52.506  57.178  4
631705  90.857  -52.526  57.179  4
631706  90.897  -52.543  57.179  4
631707  90.938  -52.562  57.173  4
631708  90.979  -52.580  57.175  4
631709  91.020  -52.597  57.181  4
631710  91.032  -52.621  57.192  4
631711  91.035  -52.647  57.200  4
631712  91.039  -52.672  57.202  4
631713  91.078  -52.680  57.198  4
631714  91.117  -52.688  57.189  4
631715  91.149  -52.703  57.183  4
631716  91.168  -52.731  57.178  4
631717  91.196  -52.751  57.170  4
631718  91.224  -52.771  57.158  4
631719  91.252  -52.791  57.141  4
631720  91.280  -52.812  57.120  4
631721  91.308  -52.832  57.111  4
631722  91.336  -52.853  57.098  4
631723  91.364  -52.873  57.079  4
631724  91.392  -52.894  57.050  4
631725  91.409  -52.908  57.015  4
631726  91.425  -52.922  56.980  4
631727  91.441  -52.935  56.948  4
631728  91.457  -52.949  56.918  4
631729  91.490  -52.973  56.886  4
631730  91.523  -52.998  56.854  4
631731  91.557  -53.022  56.822  4
631732  91.590  -53.046  56.787  4
631733  91.623  -53.071  56.749  4
631734  91.656  -53.095  56.710  4
631735  91.689  -53.120  56.671  4
631736  91.723  -53.145  56.630  4
631737  91.756  -53.169  56.588  4
631738  91.790  -53.193  56.546  4
631739  91.823  -53.218  56.503  4
631740  91.856  -53.242  56.460  4
631741  91.889  -53.267  56.416  4
631742  91.923  -53.292  56.372  4
631743  91.956  -53.316  56.327  4
631744  91.990  -53.340  56.283  4
631745  92.026  -53.360  56.236  4
631746  92.067  -53.374  56.190  4
631747  92.107  -53.387  56.145  4
631748  92.148  -53.401  56.099  4
631749  92.189  -53.415  56.055  4
631750  92.230  -53.427  56.012  4
631751  92.271  -53.441  55.969  4
631752  92.311  -53.455  55.926  4
631753  92.352  -53.468  55.885  4
631754  92.393  -53.482  55.846  4
631755  92.434  -53.495  55.808  4
631771  93.135  -53.660  55.160  1
631772  93.156  -53.681  55.142  1
631773  93.175  -53.703  55.125  1
631774  93.195  -53.725  55.109  1
631775  93.214  -53.747  55.094  1
631776  93.233  -53.769  55.079  1
631777  93.253  -53.791  55.064  1
631778  93.273  -53.813  55.052  1
631779  93.292  -53.834  55.042  1
631780  93.311  -53.856  55.033  1
631781  93.331  -53.878  55.024  1
631782  93.351  -53.900  55.016  1
631783  93.370  -53.922  55.008  1
631784  93.397  -53.940  55.005  1
631785  93.426  -53.954  55.003  1
631786  93.457  -53.969  55.001  1
631787  93.486  -53.983  55.000  1
631788  93.516  -53.997  54.999  1
631789  93.547  -54.013  54.998  1
631790  93.576  -54.027  54.999  1
631791  93.607  -54.041  55.000  1
631792  93.637  -54.056  55.002  1
631793  93.666  -54.071  55.004  1
631794  93.703  -54.085  55.007  1
631795  93.741  -54.098  55.009  1
631796  93.778  -54.112  55.013  1
631797  93.816  -54.126  55.017  1
631798  93.849  -54.136  55.022  1
631799  93.880  -54.144  55.026  1
631800  93.911  -54.152  55.030  1
631801  93.942  -54.160  55.034  1
631802  93.973  -54.168  55.039  1
631803  94.000  -54.178  55.040  1
631804  94.021  -54.192  55.039  1
631805  94.043  -54.204  55.037  1
631806  94.064  -54.218  55.034  1
631807  94.085  -54.232  55.031  1
631808  94.107  -54.245  55.026  1
631809  94.129  -54.258  55.023  1
631810  94.145  -54.267  55.020  1
631811  94.161  -54.276  55.018  1
631812  94.177  -54.285  55.016  1
631813  94.192  -54.294  55.011  1
631814  94.208  -54.302  55.003  1
631815  94.223  -54.311  54.998  1
631816  94.239  -54.320  54.993  1
631817  94.255  -54.328  54.989  1
631818  94.270  -54.337  54.987  1
631819  94.286  -54.345  54.984  1
631820  94.301  -54.355  54.979  1
631821  94.317  -54.363  54.972  1
631822  94.332  -54.372  54.962  1
631823  94.348  -54.380  54.947  1
631824  94.363  -54.389  54.930  1
631825  94.379  -54.398  54.909  1
631826  94.395  -54.406  54.885  1
631827  94.414  -54.418  54.862  1
631828  94.438  -54.435  54.838  1
631829  94.463  -54.452  54.812  1
631830  94.488  -54.467  54.782  1
631831  94.512  -54.484  54.747  1
631832  94.541  -54.499  54.706  1
631833  94.578  -54.511  54.663  1
631834  94.616  -54.524  54.619  1
631835  94.653  -54.536  54.575  1
631836  94.690  -54.548  54.530  1
631837  94.728  -54.563  54.481  1
631838  94.768  -54.590  54.428  1
631839  94.809  -54.616  54.377  1
631840  94.849  -54.643  54.330  1
631841  94.889  -54.669  54.286  1
631842  94.924  -54.688  54.243  1
631843  94.958  -54.705  54.195  1
631844  94.991  -54.721  54.144  1
631845  95.025  -54.738  54.092  1
631846  95.059  -54.755  54.041  1
631847  95.093  -54.772  53.990  1
631848  95.123  -54.788  53.940  1
631849  95.153  -54.805  53.886  1
631850  95.183  -54.822  53.834  1
631851  95.213  -54.838  53.784  1
631852  95.243  -54.855  53.737  1
631853  95.273  -54.872  53.692  1
631854  95.303  -54.887  53.649  1
631855  95.334  -54.903  53.605  1
631856  95.367  -54.917  53.561  1
631857  95.398  -54.931  53.520  1
631858  95.430  -54.945  53.480  1
631859  95.462  -54.960  53.440  1
631860  95.493  -54.973  53.405  1
631861  95.525  -54.988  53.370  1
631862  95.557  -55.002  53.336  1
631863  95.588  -55.016  53.302  1
631864  95.619  -55.031  53.268  1
631865  95.649  -55.044  53.232  1
631866  95.677  -55.055  53.193  1
631867  95.706  -55.067  53.154  1
631868  95.736  -55.079  53.114  1
631869  95.765  -55.091  53.071  1
631870  95.794  -55.103  53.027  1
631871  95.824  -55.114  52.982  1
631872  95.853  -55.126  52.936  1
631873  95.882  -55.138  52.890  1
631874  95.912  -55.150  52.841  1
631875  95.941  -55.162  52.790  1
631876  95.970  -55.173  52.736  1
631877  96.000  -55.184  52.682  1
631878  96.029  -55.188  52.629  1
631879  96.057  -55.193  52.581  1
631880  96.087  -55.198  52.534  1
631881  96.115  -55.202  52.479  1
631882  96.144  -55.207  52.418  1
631883  96.173  -55.211  52.353  1
631884  96.202  -55.215  52.284  1
631885  96.231  -55.220  52.214  1
631886  96.260  -55.224  52.146  1
631887  96.289  -55.229  52.076  1
631888  96.318  -55.233  52.006  1
631889  96.347  -55.239  51.937  1
631890  96.378  -55.250  51.868  1
631891  96.413  -55.273  51.801  1
631892  96.448  -55.297  51.734  1
631893  96.483  -55.321  51.667  1
631894  96.518  -55.345  51.600  1
631895  96.553  -55.370  51.533  1
631896  96.588  -55.394  51.467  1
631897  96.623  -55.419  51.402  1
631898  96.658  -55.443  51.337  1
631899  96.693  -55.467  51.271  1
631900  96.728  -55.492  51.206  1
631901  96.763  -55.516  51.140  1
631902  96.797  -55.539  51.077  1
632306  87.796  -50.748  56.503  5
632307  87.832  -50.773  56.520  5
632308  87.868  -50.797  56.536  5
632309  87.863  -50.844  56.550  5
632310  87.849  -50.896  56.562  5
632311  87.855  -50.936  56.571  5
632312  87.889  -50.956  56.572  5
632313  87.924  -50.976  56.566  5
632314  87.959  -50.997  56.558  5
632315  87.993  -51.017  56.544  5
632316  88.017  -51.019  56.528  5
632317  88.032  -51.005  56.509  5
632318  88.065  -51.023  56.486  5
632319  88.099  -51.042  56.460  5
632320  88.131  -51.062  56.432  5
632321  88.165  -51.081  56.403  5
632322  88.198  -51.101  56.371  5
632323  88.231  -51.120  56.339  5
632387  90.339  -52.235  57.150  4
632388  90.372  -52.242  57.159  4
632389  90.404  -52.251  57.167  4
632390  90.436  -52.258  57.174  4
632391  90.468  -52.267  57.181  4
632392  90.501  -52.274  57.187  4
632393  90.533  -52.283  57.192  4
632394  90.565  -52.291  57.196  4
632395  90.591  -52.304  57.199  4
632396  90.607  -52.327  57.198  4
632397  90.627  -52.343  57.197  4
632398  90.659  -52.343  57.196  4
632399  90.691  -52.343  57.193  4
632400  90.719  -52.357  57.191  4
632401  90.744  -52.379  57.189  4
632402  90.769  -52.402  57.185  4
632403  90.795  -52.424  57.181  4
632404  90.820  -52.447  57.180  4
632405  90.847  -52.469  57.181  4
632406  90.888  -52.487  57.183  4
632407  90.929  -52.505  57.184  4
632408  90.969  -52.523  57.179  4
632409  91.010  -52.540  57.179  4
632410  91.050  -52.559  57.185  4
632411  91.085  -52.578  57.193  4
632412  91.089  -52.603  57.200  4
632413  91.093  -52.628  57.202  4
632414  91.096  -52.653  57.199  4
632415  91.129  -52.665  57.193  4
632416  91.157  -52.684  57.195  4
632417  91.184  -52.704  57.197  4
632418  91.213  -52.725  57.197  4
632419  91.240  -52.745  57.189  4
632420  91.269  -52.766  57.172  4
632421  91.296  -52.786  57.149  4
632422  91.324  -52.807  57.139  4
632423  91.352  -52.827  57.125  4
632424  91.380  -52.847  57.104  4
632425  91.408  -52.868  57.074  4
632426  91.436  -52.888  57.038  4
632427  91.455  -52.903  57.009  4
632428  91.471  -52.917  56.978  4
632429  91.487  -52.931  56.947  4
632430  91.504  -52.944  56.917  4
632431  91.537  -52.969  56.888  4
632432  91.570  -52.994  56.856  4
632433  91.603  -53.018  56.821  4
632434  91.637  -53.042  56.782  4
632435  91.670  -53.067  56.742  4
632436  91.704  -53.092  56.702  4
632437  91.737  -53.116  56.661  4
632438  91.770  -53.141  56.618  4
632439  91.803  -53.165  56.574  4
632440  91.837  -53.189  56.529  4
632441  91.870  -53.214  56.484  4
632442  91.904  -53.239  56.438  4
632443  91.937  -53.263  56.391  4
632444  91.970  -53.288  56.345  4
632445  92.004  -53.312  56.298  4
632446  92.040  -53.331  56.251  4
632447  92.081  -53.345  56.204  4
632448  92.122  -53.358  56.157  4
632449  92.162  -53.372  56.111  4
632450  92.203  -53.385  56.066  4
632451  92.244  -53.399  56.021  4
632452  92.285  -53.412  55.977  4
632453  92.325  -53.426  55.934  4
632454  92.366  -53.440  55.892  4
632455  92.407  -53.452  55.852  4
632474  93.180  -53.675  55.117  1
632475  93.200  -53.697  55.100  1
632476  93.219  -53.719  55.083  1
632477  93.239  -53.741  55.067  1
632478  93.258  -53.763  55.052  1
632479  93.278  -53.784  55.040  1
632480  93.297  -53.806  55.029  1
632481  93.317  -53.828  55.019  1
632482  93.336  -53.850  55.011  1
632483  93.356  -53.872  55.002  1
632484  93.382  -53.889  54.994  1
632485  93.413  -53.904  54.990  1
632486  93.442  -53.919  54.987  1
632487  93.473  -53.933  54.985  1
632488  93.502  -53.947  54.983  1
632489  93.533  -53.963  54.982  1
632490  93.563  -53.977  54.981  1
632491  93.592  -53.991  54.983  1
632492  93.623  -54.006  54.984  1
632493  93.652  -54.021  54.987  1
632494  93.683  -54.035  54.989  1
632495  93.713  -54.050  54.991  1
632496  93.751  -54.063  54.994  1
632497  93.788  -54.077  54.997  1
632498  93.825  -54.091  55.002  1
632499  93.862  -54.104  55.007  1
632500  93.900  -54.118  55.011  1
632501  93.932  -54.127  55.016  1
632502  93.963  -54.135  55.021  1
632503  93.994  -54.143  55.025  1
632504  94.025  -54.151  55.028  1
632505  94.049  -54.163  55.029  1
632506  94.070  -54.176  55.029  1
632507  94.091  -54.189  55.027  1
632508  94.113  -54.203  55.025  1
632509  94.134  -54.216  55.023  1
632510  94.153  -54.227  55.023  1
632511  94.169  -54.236  55.025  1
632512  94.185  -54.245  55.025  1
632513  94.200  -54.254  55.025  1
632514  94.216  -54.262  55.021  1
632515  94.231  -54.271  55.011  1
632516  94.247  -54.279  54.997  1
632517  94.263  -54.288  54.987  1
632518  94.278  -54.297  54.981  1
632519  94.293  -54.305  54.978  1
632520  94.309  -54.314  54.974  1
632521  94.325  -54.323  54.969  1
632522  94.340  -54.332  54.965  1
632523  94.356  -54.340  54.956  1
632524  94.371  -54.349  54.943  1
632525  94.387  -54.358  54.927  1
632526  94.403  -54.366  54.908  1
632527  94.418  -54.375  54.887  1
632528  94.434  -54.383  54.866  1
632529  94.455  -54.397  54.843  1
632530  94.480  -54.414  54.818  1
632531  94.504  -54.430  54.788  1
632532  94.529  -54.446  54.752  1
632533  94.556  -54.462  54.709  1
632534  94.593  -54.474  54.663  1
632535  94.630  -54.486  54.617  1
632536  94.668  -54.499  54.569  1
632537  94.705  -54.511  54.523  1
632538  94.744  -54.533  54.474  1
632539  94.784  -54.560  54.423  1
632540  94.825  -54.587  54.375  1
632541  94.865  -54.614  54.327  1
632542  94.905  -54.640  54.283  1
632543  94.940  -54.659  54.236  1
632544  94.974  -54.675  54.185  1
632545  95.007  -54.692  54.133  1
632546  95.041  -54.709  54.081  1
632547  95.075  -54.725  54.028  1
632548  95.106  -54.742  53.978  1
632549  95.136  -54.759  53.929  1
632550  95.166  -54.775  53.878  1
632551  95.196  -54.792  53.829  1
632552  95.226  -54.809  53.783  1
632553  95.256  -54.825  53.742  1
632554  95.286  -54.841  53.700  1
632555  95.316  -54.858  53.658  1
632556  95.347  -54.874  53.614  1
632557  95.379  -54.888  53.571  1
632558  95.410  -54.902  53.529  1
632559  95.442  -54.916  53.488  1
632560  95.474  -54.931  53.447  1
632561  95.506  -54.945  53.411  1
632562  95.537  -54.959  53.377  1
632563  95.567  -54.973  53.344  1
632564  95.599  -54.988  53.311  1
632565  95.629  -55.002  53.278  1
632566  95.660  -55.016  53.243  1
632567  95.688  -55.028  53.207  1
632568  95.716  -55.038  53.167  1
632569  95.745  -55.050  53.127  1
632570  95.774  -55.063  53.085  1
632571  95.804  -55.074  53.041  1
632572  95.833  -55.086  52.996  1
632573  95.863  -55.097  52.950  1
632574  95.892  -55.110  52.903  1
632575  95.921  -55.121  52.851  1
632576  95.951  -55.133  52.802  1
632577  95.980  -55.145  52.754  1
632578  96.010  -55.156  52.706  1
632579  96.038  -55.160  52.659  1
632580  96.067  -55.165  52.614  1
632581  96.096  -55.169  52.567  1
632582  96.125  -55.174  52.518  1
632583  96.154  -55.179  52.462  1
632584  96.183  -55.182  52.398  1
632585  96.212  -55.187  52.329  1
632586  96.241  -55.191  52.256  1
632587  96.269  -55.196  52.185  1
632588  96.299  -55.201  52.113  1
632589  96.327  -55.205  52.039  1
632590  96.356  -55.210  51.966  1
632591  96.384  -55.217  51.895  1
632592  96.418  -55.235  51.827  1
632593  96.453  -55.260  51.758  1
632594  96.488  -55.284  51.690  1
632595  96.523  -55.308  51.622  1
632596  96.558  -55.332  51.555  1
632597  96.593  -55.357  51.489  1
632598  96.628  -55.381  51.423  1
632599  96.663  -55.405  51.358  1
632600  96.698  -55.430  51.292  1
632601  96.733  -55.454  51.226  1
632602  96.768  -55.478  51.161  1
632603  96.803  -55.503  51.097  1
632604  96.828  -55.513  51.035  1
632605  96.845  -55.512  50.974  1
633007  87.813  -50.718  56.502  5
633008  87.849  -50.742  56.517  5
633009  87.837  -50.793  56.531  5
633010  87.822  -50.845  56.544  5
633011  87.837  -50.879  56.554  5
633012  87.872  -50.899  56.561  5
633013  87.907  -50.920  56.562  5
633014  87.941  -50.940  56.557  5
633015  87.976  -50.961  56.548  5
633016  88.010  -50.982  56.535  5
633017  88.045  -51.002  56.520  5
633018  88.075  -51.015  56.501  5
633019  88.091  -51.001  56.479  5
633020  88.118  -51.010  56.453  5
633021  88.151  -51.029  56.424  5
633022  88.185  -51.048  56.394  5
633023  88.217  -51.067  56.362  5
633024  88.251  -51.087  56.330  5
633087  90.327  -52.193  57.137  4
633088  90.359  -52.202  57.147  4
633089  90.391  -52.209  57.156  4
633090  90.424  -52.217  57.164  4
633091  90.456  -52.225  57.171  4
633092  90.488  -52.233  57.177  4
633093  90.521  -52.241  57.183  4
633094  90.553  -52.249  57.187  4
633095  90.585  -52.258  57.190  4
633096  90.617  -52.265  57.194  4
633097  90.639  -52.283  57.194  4
633098  90.655  -52.305  57.192  4
633099  90.683  -52.310  57.191  4
633100  90.715  -52.310  57.189  4
633101  90.744  -52.320  57.187  4
633102  90.769  -52.342  57.186  4
633103  90.795  -52.365  57.182  4
633104  90.820  -52.387  57.180  4
633105  90.845  -52.410  57.180  4
633106  90.878  -52.430  57.182  4
633107  90.919  -52.448  57.185  4
633108  90.959  -52.466  57.187  4
633109  91.000  -52.484  57.184  4
633110  91.041  -52.502  57.184  4
633111  91.082  -52.520  57.189  4
633112  91.122  -52.537  57.195  4
633113  91.143  -52.559  57.201  4
633114  91.147  -52.585  57.205  4
633115  91.150  -52.610  57.204  4
633116  91.154  -52.635  57.203  4
633117  91.173  -52.657  57.207  4
633118  91.201  -52.678  57.213  4
633119  91.229  -52.698  57.218  4
633120  91.257  -52.719  57.217  4
633121  91.285  -52.739  57.201  4
633122  91.312  -52.760  57.178  4
633123  91.341  -52.780  57.165  4
633124  91.368  -52.800  57.150  4
633125  91.396  -52.821  57.127  4
633126  91.424  -52.841  57.096  4
633127  91.452  -52.862  57.060  4
633128  91.480  -52.882  57.038  4
633129  91.501  -52.898  57.007  4
633130  91.517  -52.913  56.974  4
633131  91.533  -52.926  56.946  4
633132  91.551  -52.941  56.920  4
633133  91.584  -52.965  56.890  4
633134  91.617  -52.989  56.855  4
633135  91.651  -53.014  56.814  4
633136  91.684  -53.038  56.775  4
633137  91.717  -53.063  56.737  4
633138  91.751  -53.088  56.695  4
633139  91.784  -53.112  56.650  4
633140  91.817  -53.136  56.602  4
633141  91.851  -53.161  56.555  4
633142  91.884  -53.186  56.507  4
633143  91.918  -53.210  56.459  4
633144  91.951  -53.235  56.410  4
633145  91.984  -53.259  56.362  4
633146  92.017  -53.283  56.314  4
633147  92.055  -53.302  56.265  4
633148  92.095  -53.316  56.218  4
633149  92.136  -53.330  56.170  4
633150  92.177  -53.343  56.123  4
633151  92.217  -53.356  56.076  4
633152  92.258  -53.370  56.031  4
633153  92.299  -53.383  55.986  4
633154  92.340  -53.397  55.942  4
633155  92.380  -53.411  55.900  4
633156  92.421  -53.424  55.859  4
633178  93.244  -53.713  55.057  1
633179  93.264  -53.735  55.042  1
633180  93.283  -53.757  55.028  1
633181  93.302  -53.778  55.016  1
633182  93.322  -53.800  55.006  1
633183  93.341  -53.822  54.996  1
633184  93.368  -53.839  54.988  1
633185  93.399  -53.853  54.980  1
633186  93.428  -53.869  54.976  1
633187  93.459  -53.883  54.973  1
633188  93.489  -53.897  54.970  1
633189  93.518  -53.912  54.968  1
633190  93.549  -53.927  54.968  1
633191  93.578  -53.941  54.966  1
633192  93.609  -53.956  54.968  1
633193  93.639  -53.970  54.970  1
633194  93.669  -53.985  54.972  1
633195  93.699  -54.000  54.974  1
633196  93.728  -54.014  54.977  1
633197  93.760  -54.029  54.979  1
633198  93.797  -54.042  54.983  1
633199  93.835  -54.056  54.988  1
633200  93.872  -54.070  54.993  1
633201  93.910  -54.084  54.998  1
633202  93.947  -54.098  55.003  1
633203  93.983  -54.110  55.009  1
633204  94.014  -54.118  55.013  1
633205  94.045  -54.126  55.018  1
633206  94.076  -54.134  55.020  1
633207  94.097  -54.148  55.022  1
633208  94.119  -54.160  55.023  1
633209  94.140  -54.174  55.025  1
633210  94.161  -54.187  55.028  1
633211  94.177  -54.196  55.034  1
633212  94.193  -54.204  55.042  1
633213  94.208  -54.214  55.046  1
633214  94.224  -54.222  55.046  1
633215  94.240  -54.231  55.040  1
633216  94.255  -54.239  55.026  1
633217  94.271  -54.248  55.009  1
633218  94.286  -54.257  54.992  1
633219  94.301  -54.265  54.979  1
633220  94.317  -54.274  54.972  1
633221  94.333  -54.283  54.968  1
633222  94.348  -54.292  54.962  1
633223  94.364  -54.300  54.959  1
633224  94.380  -54.309  54.952  1
633225  94.395  -54.317  54.941  1
633226  94.411  -54.326  54.927  1
633227  94.426  -54.335  54.911  1
633228  94.442  -54.343  54.891  1
633229  94.458  -54.352  54.872  1
633230  94.473  -54.361  54.849  1
633231  94.496  -54.376  54.823  1
633232  94.521  -54.392  54.792  1
633233  94.545  -54.408  54.754  1
633234  94.571  -54.425  54.710  1
633235  94.608  -54.437  54.663  1
633236  94.645  -54.449  54.614  1
633237  94.682  -54.461  54.565  1
633238  94.720  -54.478  54.519  1
633239  94.761  -54.505  54.471  1
633240  94.801  -54.531  54.424  1
633241  94.841  -54.558  54.379  1
633242  94.882  -54.584  54.334  1
633243  94.922  -54.611  54.288  1
633244  94.956  -54.629  54.241  1
633245  94.990  -54.646  54.191  1
633246  95.024  -54.662  54.139  1
633247  95.057  -54.679  54.088  1
633248  95.089  -54.696  54.036  1
633249  95.119  -54.712  53.985  1
633250  95.149  -54.729  53.936  1
633251  95.179  -54.746  53.885  1
633252  95.209  -54.762  53.838  1
633253  95.239  -54.778  53.795  1
633254  95.269  -54.795  53.753  1
633255  95.300  -54.812  53.711  1
633256  95.329  -54.828  53.669  1
633257  95.359  -54.845  53.624  1
633258  95.391  -54.859  53.580  1
633259  95.423  -54.874  53.535  1
633260  95.455  -54.887  53.491  1
633261  95.486  -54.902  53.451  1
633262  95.517  -54.916  53.416  1
633263  95.547  -54.931  53.383  1
633264  95.579  -54.945  53.351  1
633265  95.609  -54.960  53.319  1
633266  95.640  -54.974  53.287  1
633267  95.671  -54.988  53.254  1
633268  95.699  -55.000  53.220  1
633269  95.727  -55.011  53.180  1
633270  95.755  -55.022  53.139  1
633271  95.784  -55.034  53.097  1
633272  95.814  -55.046  53.053  1
633273  95.843  -55.057  53.009  1
633274  95.873  -55.069  52.964  1
633275  95.902  -55.081  52.915  1
633276  95.931  -55.093  52.865  1
633277  95.961  -55.105  52.818  1
633278  95.990  -55.116  52.775  1
633279  96.019  -55.128  52.732  1
633280  96.048  -55.132  52.688  1
633281  96.077  -55.137  52.645  1
633282  96.106  -55.141  52.599  1
633283  96.135  -55.146  52.550  1
633284  96.164  -55.150  52.494  1
633285  96.192  -55.154  52.431  1
633286  96.222  -55.159  52.365  1
633287  96.250  -55.163  52.297  1
633288  96.279  -55.168  52.228  1
633289  96.308  -55.173  52.155  1
633290  96.337  -55.177  52.079  1
633291  96.366  -55.187  52.003  1
633292  96.391  -55.195  51.930  1
633293  96.422  -55.203  51.859  1
633294  96.459  -55.222  51.789  1
633295  96.493  -55.246  51.719  1
633296  96.529  -55.271  51.651  1
633297  96.564  -55.295  51.583  1
633298  96.599  -55.320  51.516  1
633299  96.633  -55.344  51.449  1
633300  96.669  -55.368  51.383  1
633301  96.704  -55.392  51.316  1
633302  96.739  -55.417  51.250  1
633303  96.774  -55.441  51.184  1
633304  96.809  -55.465  51.120  1
633305  96.842  -55.488  51.057  1
633306  96.859  -55.487  50.995  1
633307  96.876  -55.486  50.933  1
633708  87.824  -50.691  56.497  5
633709  87.810  -50.743  56.511  5
633710  87.794  -50.795  56.523  5
633711  87.820  -50.822  56.534  5
633712  87.855  -50.842  56.542  5
633713  87.890  -50.863  56.548  5
633714  87.924  -50.883  56.549  5
633715  87.959  -50.904  56.543  5
633716  87.993  -50.925  56.534  5
633717  88.028  -50.945  56.522  5
633718  88.062  -50.966  56.506  5
633719  88.097  -50.986  56.488  5
633720  88.132  -51.008  56.468  5
633721  88.149  -50.997  56.443  5
633722  88.172  -50.995  56.412  5
633723  88.204  -51.015  56.382  5
633724  88.238  -51.034  56.350  5
633725  88.271  -51.054  56.318  5
633787  90.315  -52.152  57.123  4
633788  90.347  -52.160  57.134  4
633789  90.379  -52.167  57.143  4
633790  90.411  -52.176  57.152  4
633791  90.444  -52.184  57.160  4
633792  90.476  -52.192  57.166  4
633793  90.508  -52.200  57.172  4
633794  90.540  -52.208  57.177  4
633795  90.573  -52.216  57.182  4
633796  90.605  -52.224  57.184  4
633797  90.638  -52.232  57.188  4
633798  90.670  -52.240  57.187  4
633799  90.686  -52.262  57.186  4
633800  90.707  -52.277  57.185  4
633801  90.739  -52.277  57.184  4
633802  90.769  -52.283  57.183  4
633803  90.795  -52.305  57.183  4
633804  90.820  -52.327  57.181  4
633805  90.845  -52.350  57.179  4
633806  90.870  -52.373  57.179  4
633807  90.909  -52.391  57.181  4
633808  90.950  -52.409  57.185  4
633809  90.991  -52.427  57.189  4
633810  91.031  -52.445  57.188  4
633811  91.072  -52.463  57.190  4
633812  91.113  -52.481  57.194  4
633813  91.153  -52.499  57.199  4
633814  91.194  -52.517  57.205  4
633815  91.201  -52.541  57.211  4
633816  91.203  -52.568  57.213  4
633817  91.185  -52.601  57.216  4
633818  91.191  -52.628  57.222  4
633819  91.218  -52.651  57.229  4
633820  91.245  -52.672  57.235  4
633821  91.273  -52.693  57.234  4
633822  91.301  -52.713  57.219  4
633823  91.329  -52.734  57.197  4
633824  91.357  -52.754  57.180  4
633825  91.385  -52.774  57.161  4
633826  91.413  -52.794  57.138  4
633827  91.440  -52.815  57.112  4
633828  91.468  -52.835  57.084  4
633829  91.496  -52.856  57.065  4
633830  91.524  -52.876  57.035  4
633831  91.547  -52.894  57.001  4
633832  91.564  -52.908  56.973  4
633833  91.580  -52.922  56.952  4
633834  91.598  -52.936  56.925  4
633835  91.632  -52.961  56.888  4
633836  91.665  -52.985  56.845  4
633837  91.698  -53.010  56.806  4
633838  91.731  -53.035  56.770  4
633839  91.765  -53.059  56.731  4
633840  91.798  -53.083  56.683  4
633841  91.831  -53.108  56.630  4
633842  91.865  -53.132  56.579  4
633843  91.898  -53.157  56.529  4
633844  91.931  -53.182  56.479  4
633845  91.964  -53.206  56.429  4
633846  91.998  -53.230  56.378  4
633847  92.031  -53.255  56.329  4
633848  92.069  -53.273  56.280  4
633849  92.109  -53.287  56.230  4
633850  92.150  -53.301  56.181  4
633851  92.191  -53.314  56.133  4
633852  92.232  -53.327  56.085  4
633853  92.272  -53.341  56.040  4
633854  92.313  -53.355  55.994  4
633855  92.354  -53.368  55.950  4
633856  92.394  -53.382  55.907  4
633857  92.435  -53.395  55.865  4
633882  93.307  -53.751  55.005  1
633883  93.327  -53.772  54.994  1
633884  93.354  -53.789  54.983  1
633885  93.384  -53.803  54.975  1
633886  93.415  -53.819  54.967  1
633887  93.444  -53.833  54.962  1
633888  93.475  -53.847  54.959  1
633889  93.504  -53.862  54.956  1
633890  93.535  -53.877  54.954  1
633891  93.565  -53.891  54.953  1
633892  93.594  -53.906  54.952  1
633893  93.625  -53.920  54.953  1
633894  93.654  -53.935  54.956  1
633895  93.685  -53.950  54.959  1
633896  93.715  -53.964  54.961  1
633897  93.745  -53.979  54.964  1
633898  93.775  -53.993  54.966  1
633899  93.807  -54.007  54.970  1
633900  93.844  -54.021  54.975  1
633901  93.882  -54.035  54.981  1
633902  93.919  -54.049  54.986  1
633903  93.957  -54.063  54.992  1
633904  93.994  -54.076  54.997  1
633905  94.031  -54.090  55.002  1
633906  94.066  -54.101  55.008  1
633907  94.097  -54.109  55.012  1
633908  94.124  -54.119  55.017  1
633909  94.146  -54.132  55.022  1
633910  94.168  -54.145  55.028  1
633911  94.185  -54.156  55.037  1
633912  94.201  -54.164  55.049  1
633913  94.216  -54.173  55.061  1
633914  94.232  -54.182  55.066  1
633915  94.248  -54.191  55.064  1
633916  94.263  -54.199  55.056  1
633917  94.279  -54.208  55.040  1
633918  94.294  -54.217  55.019  1
633919  94.310  -54.225  54.999  1
633920  94.325  -54.234  54.984  1
633921  94.341  -54.242  54.975  1
633922  94.356  -54.251  54.970  1
633923  94.372  -54.260  54.965  1
633924  94.388  -54.269  54.964  1
633925  94.403  -54.277  54.958  1
633926  94.419  -54.286  54.948  1
633927  94.434  -54.295  54.935  1
633928  94.450  -54.303  54.918  1
633929  94.466  -54.312  54.896  1
633930  94.481  -54.320  54.874  1
633931  94.497  -54.330  54.849  1
633932  94.512  -54.338  54.821  1
633933  94.537  -54.355  54.790  1
633934  94.561  -54.370  54.752  1
633935  94.586  -54.387  54.708  1
633936  94.623  -54.400  54.661  1
633937  94.660  -54.412  54.612  1
633938  94.697  -54.424  54.564  1
633939  94.737  -54.449  54.518  1
633940  94.777  -54.475  54.473  1
633941  94.818  -54.502  54.429  1
633942  94.858  -54.529  54.387  1
633943  94.898  -54.555  54.345  1
633944  94.938  -54.582  54.299  1
633945  94.972  -54.599  54.252  1
633946  95.006  -54.616  54.203  1
633947  95.040  -54.633  54.151  1
633948  95.071  -54.649  54.099  1
633949  95.102  -54.666  54.046  1
633950  95.132  -54.683  53.995  1
633951  95.162  -54.699  53.946  1
633952  95.192  -54.715  53.897  1
633953  95.222  -54.732  53.852  1
633954  95.252  -54.749  53.810  1
633955  95.282  -54.765  53.769  1
633956  95.313  -54.782  53.728  1
633957  95.342  -54.799  53.685  1
633958  95.373  -54.815  53.639  1
633959  95.404  -54.831  53.592  1
633960  95.435  -54.845  53.545  1
633961  95.466  -54.859  53.500  1
633962  95.496  -54.874  53.460  1
633963  95.527  -54.888  53.426  1
633964  95.558  -54.903  53.393  1
633965  95.589  -54.917  53.362  1
633966  95.620  -54.931  53.331  1
633967  95.651  -54.946  53.299  1
633968  95.682  -54.960  53.266  1
633969  95.710  -54.972  53.231  1
633970  95.739  -54.983  53.191  1
633971  95.766  -54.994  53.148  1
633972  95.794  -55.006  53.105  1
633973  95.823  -55.017  53.062  1
633974  95.853  -55.029  53.019  1
633975  95.882  -55.041  52.974  1
633976  95.911  -55.053  52.927  1
633977  95.941  -55.065  52.882  1
633978  95.970  -55.076  52.840  1
633979  96.000  -55.088  52.799  1
633980  96.029  -55.100  52.759  1
633981  96.058  -55.104  52.717  1
633982  96.087  -55.109  52.674  1
633983  96.116  -55.113  52.629  1
633984  96.145  -55.117  52.578  1
633985  96.173  -55.122  52.522  1
633986  96.202  -55.126  52.461  1
633987  96.231  -55.131  52.399  1
633988  96.260  -55.135  52.337  1
633989  96.289  -55.140  52.270  1
633990  96.318  -55.145  52.196  1
633991  96.346  -55.155  52.118  1
633992  96.372  -55.165  52.040  1
633993  96.399  -55.172  51.965  1
633994  96.429  -55.180  51.893  1
633995  96.462  -55.189  51.822  1
633996  96.499  -55.209  51.751  1
633997  96.534  -55.233  51.682  1
633998  96.569  -55.257  51.614  1
633999  96.604  -55.282  51.546  1
634000  96.639  -55.306  51.478  1
634001  96.674  -55.330  51.411  1
634002  96.709  -55.354  51.344  1
634003  96.744  -55.379  51.277  1
634004  96.779  -55.404  51.210  1
634005  96.814  -55.428  51.146  1
634006  96.849  -55.452  51.083  1
634007  96.874  -55.462  51.021  1
634008  96.890  -55.461  50.958  1
634009  96.906  -55.461  50.897  1
634010  96.923  -55.459  50.836  1
634409  87.782  -50.692  56.489  5
634410  87.768  -50.744  56.502  5
634411  87.803  -50.765  56.512  5
634412  87.838  -50.785  56.521  5
634413  87.872  -50.806  56.528  5
634414  87.907  -50.826  56.532  5
634415  87.941  -50.848  56.533  5
634416  87.976  -50.868  56.526  5
634417  88.010  -50.889  56.517  5
634418  88.045  -50.909  56.504  5
634419  88.080  -50.930  56.488  5
634420  88.114  -50.951  56.471  5
634421  88.149  -50.971  56.451  5
634422  88.184  -50.992  56.425  5
634423  88.208  -50.993  56.396  5
634424  88.224  -50.982  56.366  5
634425  88.258  -51.001  56.335  5
634488  90.334  -52.118  57.118  4
634489  90.367  -52.127  57.128  4
634490  90.399  -52.134  57.138  4
634491  90.432  -52.142  57.146  4
634492  90.464  -52.151  57.154  4
634493  90.496  -52.158  57.160  4
634494  90.528  -52.167  57.165  4
634495  90.561  -52.174  57.170  4
634496  90.593  -52.183  57.175  4
634497  90.625  -52.190  57.177  4
634498  90.657  -52.199  57.180  4
634499  90.690  -52.207  57.180  4
634500  90.717  -52.219  57.180  4
634501  90.733  -52.241  57.179  4
634502  90.762  -52.245  57.178  4
634503  90.794  -52.246  57.179  4
634504  90.819  -52.268  57.180  4
634505  90.845  -52.290  57.178  4
634506  90.870  -52.313  57.178  4
634507  90.899  -52.334  57.179  4
634508  90.940  -52.352  57.182  4
634509  90.980  -52.370  57.186  4
634510  91.021  -52.388  57.191  4
634511  91.062  -52.406  57.194  4
634512  91.103  -52.424  57.197  4
634513  91.144  -52.442  57.202  4
634514  91.184  -52.460  57.208  4
634515  91.225  -52.478  57.215  4
634516  91.243  -52.503  57.224  4
634517  91.226  -52.536  57.229  4
634518  91.209  -52.570  57.234  4
634519  91.210  -52.599  57.239  4
634520  91.236  -52.621  57.247  4
634521  91.263  -52.644  57.254  4
634522  91.290  -52.666  57.251  4
634523  91.317  -52.687  57.234  4
634524  91.345  -52.707  57.213  4
634525  91.373  -52.728  57.191  4
634526  91.401  -52.748  57.169  4
634527  91.429  -52.769  57.146  4
634528  91.457  -52.789  57.122  4
634529  91.485  -52.810  57.102  4
634530  91.513  -52.830  57.084  4
634531  91.540  -52.850  57.055  4
634532  91.568  -52.871  57.026  4
634533  91.593  -52.889  57.001  4
634534  91.610  -52.904  56.979  4
634535  91.626  -52.917  56.960  4
634536  91.645  -52.932  56.920  4
634537  91.678  -52.957  56.877  4
634538  91.712  -52.982  56.836  4
634539  91.745  -53.006  56.801  4
634540  91.779  -53.030  56.766  4
634541  91.812  -53.055  56.716  4
634542  91.845  -53.079  56.658  4
634543  91.878  -53.104  56.602  4
634544  91.912  -53.129  56.550  4
634545  91.945  -53.153  56.499  4
634546  91.979  -53.177  56.447  4
634547  92.012  -53.202  56.395  4
634548  92.045  -53.227  56.344  4
634549  92.083  -53.245  56.294  4
634550  92.124  -53.258  56.243  4
634551  92.164  -53.272  56.193  4
634552  92.205  -53.285  56.144  4
634553  92.246  -53.299  56.096  4
634554  92.287  -53.312  56.049  4
634555  92.327  -53.326  56.002  4
634556  92.368  -53.339  55.957  4
634557  92.409  -53.352  55.914  4
634585  93.370  -53.753  54.973  1
634586  93.401  -53.768  54.962  1
634587  93.430  -53.783  54.955  1
634588  93.461  -53.797  54.949  1
634589  93.491  -53.812  54.945  1
634590  93.520  -53.826  54.942  1
634591  93.551  -53.841  54.941  1
634592  93.581  -53.856  54.940  1
634593  93.611  -53.870  54.939  1
634594  93.641  -53.885  54.940  1
634595  93.671  -53.900  54.943  1
634596  93.701  -53.914  54.946  1
634597  93.731  -53.928  54.949  1
634598  93.761  -53.943  54.952  1
634599  93.791  -53.958  54.954  1
634600  93.821  -53.972  54.958  1
634601  93.854  -53.987  54.963  1
634602  93.892  -54.001  54.969  1
634603  93.929  -54.014  54.975  1
634604  93.966  -54.028  54.981  1
634605  94.003  -54.041  54.987  1
634606  94.041  -54.055  54.994  1
634607  94.078  -54.069  55.001  1
634608  94.116  -54.082  55.007  1
634609  94.148  -54.092  55.014  1
634610  94.173  -54.104  55.023  1
634611  94.193  -54.116  55.034  1
634612  94.209  -54.124  55.050  1
634613  94.224  -54.133  55.067  1
634614  94.240  -54.142  55.079  1
634615  94.256  -54.151  55.083  1
634616  94.271  -54.159  55.078  1
634617  94.287  -54.168  55.069  1
634618  94.302  -54.176  55.051  1
634619  94.318  -54.185  55.027  1
634620  94.333  -54.194  55.006  1
634621  94.349  -54.202  54.990  1
634622  94.364  -54.211  54.981  1
634623  94.380  -54.220  54.975  1
634624  94.396  -54.229  54.970  1
634625  94.411  -54.237  54.969  1
634626  94.427  -54.245  54.963  1
634627  94.442  -54.254  54.954  1
634628  94.458  -54.263  54.940  1
634629  94.474  -54.272  54.921  1
634630  94.489  -54.280  54.896  1
634631  94.505  -54.289  54.872  1
634632  94.521  -54.298  54.844  1
634633  94.536  -54.307  54.816  1
634634  94.553  -54.317  54.784  1
634635  94.578  -54.333  54.747  1
634636  94.603  -54.349  54.705  1
634637  94.637  -54.362  54.660  1
634638  94.675  -54.374  54.614  1
634639  94.713  -54.393  54.568  1
634640  94.753  -54.420  54.524  1
634641  94.793  -54.446  54.482  1
634642  94.834  -54.473  54.441  1
634643  94.874  -54.499  54.400  1
634644  94.914  -54.526  54.358  1
634645  94.955  -54.553  54.314  1
634646  94.988  -54.570  54.268  1
634647  95.022  -54.587  54.218  1
634648  95.054  -54.603  54.165  1
634649  95.085  -54.620  54.113  1
634650  95.115  -54.637  54.060  1
634651  95.145  -54.653  54.007  1
634652  95.175  -54.669  53.957  1
634653  95.205  -54.686  53.912  1
634654  95.235  -54.703  53.870  1
634655  95.265  -54.719  53.829  1
634656  95.296  -54.736  53.786  1
634657  95.326  -54.753  53.744  1
634658  95.355  -54.769  53.700  1
634659  95.385  -54.786  53.653  1
634660  95.413  -54.803  53.604  1
634661  95.446  -54.816  53.556  1
634662  95.476  -54.831  53.512  1
634663  95.507  -54.845  53.471  1
634664  95.538  -54.859  53.436  1
634665  95.569  -54.874  53.403  1
634666  95.600  -54.888  53.372  1
634667  95.631  -54.903  53.342  1
634668  95.662  -54.917  53.310  1
634669  95.693  -54.931  53.277  1
634670  95.722  -54.944  53.242  1
634671  95.750  -54.956  53.202  1
634672  95.777  -54.966  53.161  1
634673  95.806  -54.978  53.119  1
634674  95.833  -54.989  53.078  1
634675  95.863  -55.000  53.035  1
634676  95.892  -55.013  52.992  1
634677  95.921  -55.025  52.948  1
634678  95.951  -55.036  52.905  1
634679  95.980  -55.048  52.864  1
634680  96.010  -55.060  52.824  1
634681  96.039  -55.072  52.784  1
634682  96.067  -55.076  52.743  1
634683  96.097  -55.081  52.700  1
634684  96.125  -55.085  52.654  1
634685  96.154  -55.089  52.603  1
634686  96.183  -55.094  52.549  1
634687  96.212  -55.098  52.494  1
634688  96.241  -55.103  52.436  1
634689  96.270  -55.107  52.377  1
634690  96.299  -55.114  52.309  1
634691  96.327  -55.124  52.235  1
634692  96.355  -55.135  52.156  1
634693  96.379  -55.142  52.077  1
634694  96.406  -55.150  52.002  1
634695  96.436  -55.157  51.930  1
634696  96.467  -55.166  51.858  1
634697  96.503  -55.176  51.787  1
634698  96.539  -55.196  51.716  1
634699  96.575  -55.220  51.647  1
634700  96.609  -55.245  51.578  1
634701  96.645  -55.269  51.511  1
634702  96.679  -55.293  51.442  1
634703  96.715  -55.317  51.374  1
634704  96.749  -55.342  51.306  1
634705  96.785  -55.366  51.239  1
634706  96.819  -55.390  51.173  1
634707  96.855  -55.414  51.110  1
634708  96.888  -55.437  51.047  1
634709  96.904  -55.436  50.984  1
634710  96.921  -55.435  50.922  1
634711  96.938  -55.434  50.861  1
634712  96.954  -55.433  50.802  1
634713  96.971  -55.433  50.745  1
635110  87.751  -50.687  56.475  5
635111  87.786  -50.708  56.487  5
635112  87.820  -50.729  56.495  5
635113  87.855  -50.749  56.502  5
635114  87.890  -50.770  56.508  5
635115  87.924  -50.791  56.512  5
635116  87.959  -50.811  56.513  5
635117  87.993  -50.832  56.506  5
635118  88.028  -50.852  56.496  5
635119  88.062  -50.873  56.483  5
635120  88.097  -50.894  56.467  5
635121  88.132  -50.914  56.450  5
635122  88.167  -50.935  56.431  5
635123  88.201  -50.955  56.404  5
635124  88.236  -50.976  56.376  5
635125  88.266  -50.990  56.347  5
635126  88.281  -50.975  56.316  5
635188  90.322  -52.077  57.102  4
635189  90.355  -52.085  57.112  4
635190  90.387  -52.093  57.121  4
635191  90.419  -52.101  57.131  4
635192  90.451  -52.109  57.139  4
635193  90.484  -52.117  57.147  4
635194  90.516  -52.125  57.153  4
635195  90.548  -52.133  57.158  4
635196  90.581  -52.141  57.163  4
635197  90.613  -52.149  57.167  4
635198  90.645  -52.157  57.170  4
635199  90.677  -52.165  57.173  4
635200  90.710  -52.174  57.173  4
635201  90.742  -52.181  57.172  4
635202  90.764  -52.198  57.173  4
635203  90.786  -52.212  57.173  4
635204  90.818  -52.212  57.174  4
635205  90.845  -52.230  57.176  4
635206  90.870  -52.253  57.176  4
635207  90.895  -52.276  57.177  4
635208  90.930  -52.296  57.180  4
635209  90.971  -52.313  57.184  4
635210  91.012  -52.331  57.189  4
635211  91.052  -52.349  57.196  4
635212  91.093  -52.367  57.202  4
635213  91.134  -52.385  57.208  4
635214  91.175  -52.403  57.215  4
635215  91.211  -52.421  57.224  4
635216  91.239  -52.445  57.232  4
635217  91.266  -52.471  57.239  4
635218  91.249  -52.505  57.250  4
635219  91.232  -52.539  57.256  4
635220  91.228  -52.568  57.262  4
635221  91.255  -52.591  57.269  4
635222  91.282  -52.613  57.275  4
635223  91.308  -52.636  57.271  4
635224  91.335  -52.658  57.250  4
635225  91.362  -52.681  57.226  4
635226  91.389  -52.701  57.201  4
635227  91.417  -52.722  57.175  4
635228  91.445  -52.742  57.151  4
635229  91.473  -52.763  57.129  4
635230  91.501  -52.783  57.115  4
635231  91.529  -52.803  57.099  4
635232  91.557  -52.824  57.075  4
635233  91.585  -52.844  57.050  4
635234  91.612  -52.865  57.026  4
635235  91.640  -52.885  57.003  4
635236  91.656  -52.899  56.983  4
635237  91.672  -52.913  56.947  4
635238  91.693  -52.929  56.905  4
635239  91.726  -52.953  56.864  4
635240  91.759  -52.978  56.829  4
635241  91.792  -53.002  56.792  4
635242  91.826  -53.026  56.742  4
635243  91.859  -53.051  56.685  4
635244  91.892  -53.076  56.626  4
635245  91.926  -53.100  56.570  4
635246  91.959  -53.125  56.517  4
635247  91.993  -53.149  56.465  4
635248  92.026  -53.173  56.411  4
635249  92.059  -53.198  56.359  4
635250  92.097  -53.216  56.308  4
635251  92.138  -53.230  56.256  4
635252  92.178  -53.243  56.205  4
635253  92.219  -53.256  56.155  4
635254  92.260  -53.270  56.106  4
635255  92.301  -53.283  56.058  4
635256  92.342  -53.297  56.010  4
635257  92.382  -53.311  55.964  4
635258  92.423  -53.324  55.920  4
635288  93.446  -53.747  54.944  1
635289  93.477  -53.762  54.938  1
635290  93.507  -53.776  54.934  1
635291  93.537  -53.791  54.931  1
635292  93.567  -53.806  54.929  1
635293  93.596  -53.820  54.927  1
635294  93.627  -53.834  54.927  1
635295  93.657  -53.849  54.928  1
635296  93.687  -53.864  54.930  1
635297  93.717  -53.878  54.933  1
635298  93.747  -53.893  54.937  1
635299  93.777  -53.907  54.940  1
635300  93.807  -53.922  54.942  1
635301  93.837  -53.937  54.947  1
635302  93.867  -53.951  54.952  1
635303  93.901  -53.966  54.958  1
635304  93.938  -53.979  54.964  1
635305  93.976  -53.993  54.972  1
635306  94.013  -54.007  54.978  1
635307  94.051  -54.020  54.987  1
635308  94.088  -54.034  54.994  1
635309  94.125  -54.048  55.002  1
635310  94.163  -54.061  55.012  1
635311  94.200  -54.076  55.024  1
635312  94.217  -54.084  55.040  1
635313  94.232  -54.093  55.059  1
635314  94.248  -54.101  55.075  1
635315  94.264  -54.110  55.084  1
635316  94.279  -54.119  55.084  1
635317  94.295  -54.128  55.079  1
635318  94.310  -54.136  55.070  1
635319  94.326  -54.145  55.050  1
635320  94.341  -54.154  55.029  1
635321  94.357  -54.162  55.011  1
635322  94.372  -54.171  54.997  1
635323  94.388  -54.179  54.987  1
635324  94.404  -54.189  54.981  1
635325  94.419  -54.197  54.975  1
635326  94.435  -54.205  54.972  1
635327  94.451  -54.214  54.967  1
635328  94.466  -54.223  54.957  1
635329  94.482  -54.232  54.941  1
635330  94.497  -54.240  54.920  1
635331  94.513  -54.249  54.894  1
635332  94.529  -54.258  54.866  1
635333  94.544  -54.267  54.837  1
635334  94.559  -54.275  54.808  1
635335  94.575  -54.283  54.778  1
635336  94.594  -54.295  54.742  1
635337  94.619  -54.311  54.701  1
635338  94.652  -54.325  54.660  1
635339  94.689  -54.337  54.616  1
635340  94.730  -54.364  54.573  1
635341  94.770  -54.391  54.532  1
635342  94.810  -54.417  54.493  1
635343  94.850  -54.444  54.453  1
635344  94.891  -54.471  54.415  1
635345  94.931  -54.497  54.373  1
635346  94.971  -54.524  54.331  1
635347  95.004  -54.540  54.285  1
635348  95.038  -54.557  54.235  1
635349  95.067  -54.574  54.180  1
635350  95.098  -54.590  54.125  1
635351  95.128  -54.606  54.070  1
635352  95.158  -54.623  54.018  1
635353  95.188  -54.640  53.973  1
635354  95.218  -54.656  53.931  1
635355  95.248  -54.673  53.889  1
635356  95.278  -54.690  53.846  1
635357  95.308  -54.706  53.802  1
635358  95.338  -54.723  53.756  1
635359  95.367  -54.740  53.709  1
635360  95.394  -54.759  53.662  1
635361  95.421  -54.775  53.615  1
635362  95.454  -54.789  53.569  1
635363  95.487  -54.803  53.526  1
635364  95.518  -54.817  53.484  1
635365  95.549  -54.831  53.447  1
635366  95.580  -54.846  53.413  1
635367  95.611  -54.860  53.382  1
635368  95.641  -54.875  53.352  1
635369  95.673  -54.889  53.321  1
635370  95.703  -54.903  53.288  1
635371  95.734  -54.916  53.254  1
635372  95.761  -54.928  53.215  1
635373  95.789  -54.939  53.176  1
635374  95.817  -54.950  53.136  1
635375  95.845  -54.961  53.095  1
635376  95.873  -54.972  53.054  1
635377  95.902  -54.984  53.013  1
635378  95.931  -54.996  52.971  1
635379  95.960  -55.008  52.930  1
635380  95.990  -55.019  52.889  1
635381  96.019  -55.032  52.849  1
635382  96.048  -55.043  52.809  1
635383  96.078  -55.048  52.768  1
635384  96.106  -55.052  52.725  1
635385  96.135  -55.057  52.681  1
635386  96.164  -55.061  52.632  1
635387  96.193  -55.066  52.581  1
635388  96.222  -55.070  52.527  1
635389  96.251  -55.075  52.468  1
635390  96.279  -55.083  52.407  1
635391  96.308  -55.093  52.337  1
635392  96.336  -55.104  52.263  1
635393  96.362  -55.112  52.190  1
635394  96.386  -55.120  52.118  1
635395  96.414  -55.128  52.046  1
635396  96.443  -55.135  51.974  1
635397  96.473  -55.143  51.901  1
635398  96.505  -55.151  51.828  1
635399  96.543  -55.163  51.755  1
635400  96.580  -55.182  51.684  1
635401  96.615  -55.207  51.613  1
635402  96.650  -55.231  51.544  1
635403  96.685  -55.256  51.475  1
635404  96.720  -55.280  51.406  1
635405  96.755  -55.304  51.338  1
635406  96.790  -55.329  51.270  1
635407  96.825  -55.353  51.203  1
635408  96.860  -55.377  51.138  1
635409  96.895  -55.401  51.074  1
635410  96.919  -55.411  51.011  1
635411  96.935  -55.410  50.948  1
635412  96.952  -55.409  50.886  1
635413  96.968  -55.408  50.826  1
635414  96.985  -55.408  50.768  1
635415  97.002  -55.407  50.712  1
635811  87.768  -50.651  56.459  5
635812  87.803  -50.672  56.468  5
635813  87.838  -50.692  56.475  5
635814  87.872  -50.713  56.481  5
635815  87.907  -50.734  56.486  5
635816  87.941  -50.754  56.488  5
635817  87.976  -50.775  56.488  5
635818  88.010  -50.795  56.480  5
635819  88.045  -50.817  56.470  5
635820  88.080  -50.837  56.457  5
635821  88.115  -50.857  56.441  5
635822  88.149  -50.878  56.425  5
635823  88.184  -50.899  56.406  5
635824  88.218  -50.920  56.380  5
635825  88.253  -50.940  56.354  5
635826  88.287  -50.961  56.325  5
635888  90.310  -52.036  57.084  4
635889  90.342  -52.044  57.094  4
635890  90.375  -52.051  57.104  4
635891  90.407  -52.060  57.114  4
635892  90.439  -52.067  57.123  4
635893  90.471  -52.076  57.131  4
635894  90.504  -52.084  57.139  4
635895  90.536  -52.092  57.145  4
635896  90.568  -52.100  57.150  4
635897  90.601  -52.108  57.154  4
635898  90.633  -52.116  57.158  4
635899  90.665  -52.123  57.162  4
635900  90.697  -52.132  57.165  4
635901  90.730  -52.140  57.166  4
635902  90.762  -52.148  57.166  4
635903  90.794  -52.156  57.166  4
635904  90.812  -52.177  57.168  4
635905  90.842  -52.179  57.169  4
635906  90.870  -52.193  57.173  4
635907  90.895  -52.216  57.175  4
635908  90.920  -52.239  57.178  4
635909  90.961  -52.256  57.182  4
635910  91.002  -52.274  57.188  4
635911  91.042  -52.293  57.194  4
635912  91.083  -52.310  57.202  4
635913  91.124  -52.328  57.211  4
635914  91.165  -52.346  57.219  4
635915  91.191  -52.366  57.231  4
635916  91.218  -52.389  57.244  4
635917  91.248  -52.415  57.251  4
635918  91.278  -52.442  57.257  4
635919  91.273  -52.474  57.271  4
635920  91.255  -52.507  57.280  4
635921  91.247  -52.539  57.285  4
635922  91.274  -52.561  57.290  4
635923  91.301  -52.584  57.290  4
635924  91.327  -52.606  57.282  4
635925  91.354  -52.628  57.261  4
635926  91.380  -52.650  57.237  4
635927  91.407  -52.672  57.210  4
635928  91.434  -52.695  57.181  4
635929  91.461  -52.716  57.154  4
635930  91.489  -52.737  57.136  4
635931  91.517  -52.757  57.124  4
635932  91.545  -52.777  57.110  4
635933  91.573  -52.797  57.093  4
635934  91.601  -52.818  57.072  4
635935  91.629  -52.838  57.047  4
635936  91.657  -52.859  57.024  4
635937  91.684  -52.879  57.001  4
635938  91.703  -52.894  56.968  4
635939  91.719  -52.908  56.927  4
635940  91.740  -52.925  56.887  4
635941  91.773  -52.949  56.849  4
635942  91.806  -52.973  56.809  4
635943  91.840  -52.998  56.761  4
635944  91.873  -53.023  56.704  4
635945  91.907  -53.047  56.644  4
635946  91.940  -53.072  56.587  4
635947  91.973  -53.096  56.534  4
635948  92.006  -53.120  56.481  4
635949  92.039  -53.145  56.428  4
635950  92.073  -53.170  56.375  4
635951  92.111  -53.187  56.323  4
635952  92.152  -53.201  56.270  4
635953  92.193  -53.214  56.218  4
635954  92.233  -53.227  56.166  4
635955  92.274  -53.241  56.116  4
635956  92.315  -53.255  56.067  4
635957  92.356  -53.268  56.018  4
635958  92.397  -53.281  55.971  4
635959  92.437  -53.295  55.926  4
635990  93.493  -53.726  54.927  1
635991  93.522  -53.740  54.923  1
635992  93.553  -53.756  54.920  1
635993  93.583  -53.770  54.918  1
635994  93.613  -53.784  54.916  1
635995  93.643  -53.799  54.916  1
635996  93.673  -53.814  54.917  1
635997  93.703  -53.828  54.919  1
635998  93.733  -53.843  54.922  1
635999  93.763  -53.857  54.926  1
636000  93.793  -53.872  54.930  1
636001  93.823  -53.887  54.933  1
636002  93.853  -53.901  54.937  1
636003  93.883  -53.916  54.942  1
636004  93.913  -53.930  54.949  1
636005  93.948  -53.944  54.955  1
636006  93.985  -53.958  54.963  1
636007  94.023  -53.972  54.971  1
636008  94.060  -53.985  54.979  1
636009  94.098  -53.999  54.988  1
636010  94.135  -54.013  54.997  1
636011  94.172  -54.027  55.009  1
636012  94.207  -54.046  55.025  1
636013  94.230  -54.059  55.044  1
636014  94.247  -54.067  55.063  1
636015  94.264  -54.075  55.077  1
636016  94.280  -54.083  55.081  1
636017  94.297  -54.091  55.079  1
636018  94.314  -54.099  55.074  1
636019  94.330  -54.107  55.065  1
636020  94.347  -54.115  55.045  1
636021  94.363  -54.123  55.029  1
636022  94.380  -54.131  55.017  1
636023  94.396  -54.139  55.008  1
636024  94.412  -54.148  54.997  1
636025  94.427  -54.157  54.988  1
636026  94.443  -54.166  54.980  1
636027  94.459  -54.174  54.975  1
636028  94.474  -54.182  54.968  1
636029  94.490  -54.192  54.955  1
636030  94.505  -54.200  54.937  1
636031  94.521  -54.209  54.914  1
636032  94.536  -54.217  54.885  1
636033  94.552  -54.226  54.858  1
636034  94.567  -54.235  54.830  1
636035  94.583  -54.243  54.801  1
636036  94.599  -54.252  54.771  1
636037  94.614  -54.261  54.737  1
636038  94.635  -54.274  54.698  1
636039  94.667  -54.288  54.658  1
636040  94.706  -54.308  54.617  1
636041  94.746  -54.335  54.578  1
636042  94.786  -54.361  54.542  1
636043  94.827  -54.388  54.505  1
636044  94.867  -54.414  54.466  1
636045  94.907  -54.442  54.429  1
636046  94.947  -54.468  54.389  1
636047  94.987  -54.494  54.348  1
636048  95.021  -54.511  54.302  1
636049  95.051  -54.527  54.250  1
636050  95.080  -54.543  54.194  1
636051  95.111  -54.560  54.137  1
636052  95.141  -54.577  54.081  1
636053  95.171  -54.593  54.031  1
636054  95.201  -54.610  53.989  1
636055  95.231  -54.627  53.947  1
636056  95.261  -54.643  53.904  1
636057  95.290  -54.660  53.860  1
636058  95.320  -54.677  53.815  1
636059  95.349  -54.694  53.768  1
636060  95.376  -54.712  53.721  1
636061  95.403  -54.731  53.675  1
636062  95.430  -54.749  53.628  1
636063  95.463  -54.762  53.582  1
636064  95.495  -54.776  53.537  1
636065  95.528  -54.789  53.495  1
636066  95.560  -54.803  53.459  1
636067  95.591  -54.818  53.426  1
636068  95.621  -54.831  53.396  1
636069  95.653  -54.846  53.367  1
636070  95.683  -54.860  53.336  1
636071  95.714  -54.875  53.304  1
636072  95.745  -54.889  53.269  1
636073  95.773  -54.900  53.232  1
636074  95.801  -54.911  53.194  1
636075  95.828  -54.922  53.154  1
636076  95.856  -54.934  53.115  1
636077  95.884  -54.944  53.076  1
636078  95.912  -54.956  53.037  1
636079  95.941  -54.968  52.996  1
636080  95.970  -54.979  52.956  1
636081  96.000  -54.991  52.915  1
636082  96.029  -55.003  52.874  1
636083  96.058  -55.015  52.833  1
636084  96.087  -55.019  52.792  1
636085  96.116  -55.024  52.748  1
636086  96.145  -55.028  52.706  1
636087  96.174  -55.033  52.660  1
636088  96.203  -55.038  52.610  1
636089  96.232  -55.042  52.557  1
636090  96.260  -55.052  52.496  1
636091  96.288  -55.062  52.433  1
636092  96.316  -55.072  52.363  1
636093  96.343  -55.082  52.292  1
636094  96.368  -55.090  52.225  1
636095  96.393  -55.098  52.160  1
636096  96.421  -55.105  52.093  1
636097  96.450  -55.112  52.022  1
636098  96.480  -55.120  51.948  1
636099  96.512  -55.129  51.873  1
636100  96.543  -55.138  51.798  1
636101  96.583  -55.150  51.725  1
636102  96.620  -55.169  51.652  1
636103  96.655  -55.194  51.582  1
636104  96.690  -55.218  51.511  1
636105  96.725  -55.242  51.441  1
636106  96.760  -55.267  51.372  1
636107  96.795  -55.291  51.304  1
636108  96.830  -55.315  51.236  1
636109  96.865  -55.340  51.170  1
636110  96.900  -55.364  51.105  1
636111  96.933  -55.386  51.040  1
636112  96.950  -55.385  50.976  1
636113  96.966  -55.384  50.913  1
636114  96.983  -55.383  50.852  1
636115  97.000  -55.383  50.794  1
636116  97.016  -55.382  50.737  1
636117  97.033  -55.381  50.681  1
636118  97.049  -55.380  50.628  1
636513  87.820  -50.635  56.445  5
636514  87.855  -50.656  56.451  5
636515  87.890  -50.677  56.457  5
636516  87.924  -50.698  56.461  5
636517  87.959  -50.718  56.462  5
636518  87.993  -50.738  56.461  5
636519  88.028  -50.760  56.452  5
636520  88.063  -50.780  56.441  5
636521  88.097  -50.801  56.428  5
636522  88.132  -50.821  56.413  5
636523  88.167  -50.842  56.396  5
636524  88.201  -50.863  56.378  5
636525  88.236  -50.883  56.353  5
636526  88.270  -50.904  56.327  5
636588  90.298  -51.994  57.065  4
636589  90.330  -52.002  57.075  4
636590  90.363  -52.011  57.085  4
636591  90.395  -52.018  57.095  4
636592  90.427  -52.026  57.105  4
636593  90.459  -52.034  57.114  4
636594  90.492  -52.042  57.122  4
636595  90.524  -52.050  57.130  4
636596  90.556  -52.058  57.136  4
636597  90.588  -52.067  57.141  4
636598  90.620  -52.074  57.146  4
636599  90.653  -52.083  57.149  4
636600  90.685  -52.090  57.153  4
636601  90.718  -52.098  57.156  4
636602  90.750  -52.107  57.158  4
636603  90.782  -52.114  57.158  4
636604  90.814  -52.123  57.160  4
636605  90.843  -52.134  57.162  4
636606  90.866  -52.146  57.165  4
636607  90.895  -52.156  57.170  4
636608  90.920  -52.179  57.174  4
636609  90.951  -52.199  57.179  4
636610  90.992  -52.217  57.185  4
636611  91.033  -52.236  57.195  4
636612  91.074  -52.253  57.205  4
636613  91.114  -52.271  57.216  4
636614  91.145  -52.291  57.225  4
636615  91.170  -52.311  57.235  4
636616  91.198  -52.333  57.250  4
636617  91.227  -52.360  57.267  4
636618  91.257  -52.387  57.272  4
636619  91.287  -52.413  57.277  4
636620  91.296  -52.443  57.293  4
636621  91.279  -52.476  57.303  4
636622  91.266  -52.509  57.308  4
636623  91.293  -52.531  57.308  4
636624  91.319  -52.553  57.301  4
636625  91.346  -52.575  57.289  4
636626  91.373  -52.598  57.266  4
636627  91.399  -52.620  57.240  4
636628  91.426  -52.643  57.213  4
636629  91.452  -52.665  57.185  4
636630  91.479  -52.687  57.157  4
636631  91.506  -52.709  57.142  4
636632  91.533  -52.731  57.131  4
636633  91.561  -52.751  57.122  4
636634  91.589  -52.772  57.110  4
636635  91.617  -52.792  57.090  4
636636  91.645  -52.813  57.061  4
636637  91.673  -52.833  57.038  4
636638  91.701  -52.854  57.010  4
636639  91.729  -52.874  56.979  4
636640  91.748  -52.889  56.942  4
636641  91.765  -52.904  56.902  4
636642  91.787  -52.920  56.861  4
636643  91.820  -52.945  56.819  4
636644  91.854  -52.970  56.774  4
636645  91.887  -52.994  56.718  4
636646  91.920  -53.019  56.660  4
636647  91.953  -53.043  56.603  4
636648  91.987  -53.067  56.550  4
636649  92.020  -53.092  56.498  4
636650  92.054  -53.117  56.445  4
636651  92.087  -53.141  56.390  4
636652  92.125  -53.158  56.337  4
636653  92.166  -53.172  56.284  4
636654  92.207  -53.185  56.231  4
636655  92.247  -53.198  56.177  4
636656  92.288  -53.212  56.127  4
636657  92.329  -53.226  56.076  4
636658  92.370  -53.239  56.027  4
636659  92.411  -53.252  55.979  4
636660  92.451  -53.266  55.932  4
636692  93.539  -53.705  54.912  1
636693  93.569  -53.720  54.910  1
636694  93.599  -53.734  54.907  1
636695  93.629  -53.749  54.906  1
636696  93.659  -53.763  54.905  1
636697  93.689  -53.778  54.907  1
636698  93.719  -53.793  54.909  1
636699  93.749  -53.807  54.912  1
636700  93.779  -53.822  54.916  1
636701  93.809  -53.837  54.920  1
636702  93.839  -53.851  54.923  1
636703  93.869  -53.866  54.929  1
636704  93.899  -53.880  54.935  1
636705  93.929  -53.895  54.941  1
636706  93.959  -53.910  54.948  1
636707  93.995  -53.923  54.956  1
636708  94.033  -53.937  54.965  1
636709  94.070  -53.950  54.973  1
636710  94.107  -53.964  54.981  1
636711  94.144  -53.978  54.993  1
636712  94.180  -53.997  55.007  1
636713  94.214  -54.018  55.025  1
636714  94.243  -54.035  55.043  1
636715  94.259  -54.043  55.059  1
636716  94.276  -54.051  55.068  1
636717  94.292  -54.059  55.069  1
636718  94.309  -54.067  55.066  1
636719  94.326  -54.075  55.060  1
636720  94.342  -54.083  55.053  1
636721  94.359  -54.091  55.038  1
636722  94.376  -54.099  55.028  1
636723  94.392  -54.107  55.023  1
636724  94.409  -54.115  55.017  1
636725  94.425  -54.123  55.007  1
636726  94.442  -54.131  54.995  1
636727  94.459  -54.139  54.985  1
636728  94.475  -54.147  54.977  1
636729  94.492  -54.155  54.967  1
636730  94.508  -54.163  54.951  1
636731  94.525  -54.171  54.931  1
636732  94.542  -54.179  54.907  1
636733  94.558  -54.187  54.877  1
636734  94.575  -54.195  54.850  1
636735  94.591  -54.203  54.823  1
636736  94.607  -54.212  54.796  1
636737  94.622  -54.220  54.767  1
636738  94.638  -54.229  54.736  1
636739  94.653  -54.238  54.699  1
636740  94.682  -54.252  54.662  1
636741  94.722  -54.279  54.624  1
636742  94.762  -54.306  54.588  1
636743  94.803  -54.333  54.555  1
636744  94.843  -54.359  54.520  1
636745  94.883  -54.386  54.482  1
636746  94.923  -54.412  54.445  1
636747  94.964  -54.439  54.407  1
636748  95.003  -54.464  54.364  1
636749  95.034  -54.480  54.317  1
636750  95.063  -54.498  54.264  1
636751  95.094  -54.515  54.206  1
636752  95.123  -54.531  54.146  1
636753  95.154  -54.548  54.091  1
636754  95.183  -54.565  54.046  1
636755  95.213  -54.581  54.005  1
636756  95.243  -54.598  53.963  1
636757  95.273  -54.615  53.919  1
636758  95.303  -54.631  53.874  1
636759  95.331  -54.649  53.827  1
636760  95.358  -54.667  53.780  1
636761  95.385  -54.685  53.735  1
636762  95.412  -54.703  53.689  1
636763  95.439  -54.721  53.642  1
636764  95.471  -54.735  53.595  1
636765  95.503  -54.749  53.549  1
636766  95.536  -54.762  53.508  1
636767  95.568  -54.776  53.474  1
636768  95.601  -54.789  53.442  1
636769  95.632  -54.803  53.411  1
636770  95.663  -54.818  53.382  1
636771  95.694  -54.832  53.352  1
636772  95.725  -54.847  53.320  1
636773  95.756  -54.861  53.287  1
636774  95.784  -54.872  53.251  1
636775  95.812  -54.884  53.214  1
636776  95.840  -54.895  53.176  1
636777  95.868  -54.906  53.139  1
636778  95.895  -54.917  53.100  1
636779  95.923  -54.928  53.062  1
636780  95.951  -54.939  53.021  1
636781  95.980  -54.951  52.980  1
636782  96.009  -54.963  52.939  1
636783  96.039  -54.975  52.897  1
636784  96.068  -54.986  52.855  1
636785  96.097  -54.991  52.813  1
636786  96.126  -54.996  52.769  1
636787  96.155  -55.000  52.725  1
636788  96.184  -55.005  52.678  1
636789  96.213  -55.010  52.629  1
636790  96.241  -55.021  52.577  1
636791  96.269  -55.031  52.518  1
636792  96.297  -55.041  52.454  1
636793  96.325  -55.051  52.386  1
636794  96.350  -55.060  52.320  1
636795  96.375  -55.068  52.260  1
636796  96.400  -55.075  52.203  1
636797  96.429  -55.083  52.143  1
636798  96.458  -55.090  52.075  1
636799  96.487  -55.097  52.000  1
636800  96.518  -55.106  51.923  1
636801  96.550  -55.115  51.846  1
636802  96.584  -55.125  51.769  1
636803  96.623  -55.137  51.694  1
636804  96.660  -55.157  51.622  1
636805  96.695  -55.181  51.550  1
636806  96.730  -55.205  51.479  1
636807  96.765  -55.229  51.409  1
636808  96.800  -55.254  51.339  1
636809  96.835  -55.278  51.270  1
636810  96.870  -55.302  51.203  1
636811  96.905  -55.326  51.138  1
636812  96.940  -55.351  51.071  1
636813  96.964  -55.360  51.007  1
636814  96.980  -55.359  50.943  1
636815  96.997  -55.358  50.880  1
636816  97.014  -55.358  50.821  1
636817  97.030  -55.357  50.764  1
636818  97.047  -55.356  50.707  1
636819  97.064  -55.354  50.652  1
636820  97.080  -55.354  50.598  1
637214  87.838  -50.599  56.419  5
637215  87.872  -50.620  56.425  5
637216  87.907  -50.641  56.429  5
637217  87.941  -50.661  56.431  5
637218  87.976  -50.682  56.432  5
637219  88.011  -50.703  56.431  5
637220  88.045  -50.723  56.423  5
637221  88.080  -50.744  56.411  5
637222  88.115  -50.764  56.398  5
637223  88.149  -50.785  56.383  5
637224  88.184  -50.806  56.367  5
637225  88.218  -50.826  56.348  5
637226  88.253  -50.847  56.324  5
637288  90.286  -51.953  57.046  4
637289  90.318  -51.960  57.057  4
637290  90.350  -51.969  57.067  4
637291  90.382  -51.977  57.076  4
637292  90.414  -51.985  57.085  4
637293  90.447  -51.993  57.095  4
637294  90.479  -52.001  57.104  4
637295  90.512  -52.009  57.112  4
637296  90.544  -52.017  57.119  4
637297  90.576  -52.025  57.125  4
637298  90.608  -52.033  57.130  4
637299  90.641  -52.041  57.134  4
637300  90.673  -52.049  57.138  4
637301  90.705  -52.057  57.142  4
637302  90.737  -52.065  57.146  4
637303  90.769  -52.073  57.148  4
637304  90.802  -52.081  57.150  4
637305  90.834  -52.089  57.153  4
637306  90.867  -52.097  57.155  4
637307  90.890  -52.113  57.161  4
637308  90.920  -52.119  57.166  4
637309  90.945  -52.142  57.173  4
637310  90.982  -52.161  57.181  4
637311  91.023  -52.179  57.191  4
637312  91.064  -52.197  57.204  4
637313  91.099  -52.215  57.218  4
637314  91.124  -52.235  57.231  4
637315  91.150  -52.255  57.242  4
637316  91.177  -52.278  57.254  4
637317  91.207  -52.305  57.268  4
637318  91.237  -52.331  57.286  4
637319  91.266  -52.358  57.293  4
637320  91.296  -52.384  57.296  4
637321  91.319  -52.412  57.305  4
637322  91.302  -52.445  57.314  4
637323  91.285  -52.478  57.317  4
637324  91.311  -52.501  57.311  4
637325  91.338  -52.523  57.305  4
637326  91.365  -52.546  57.289  4
637327  91.391  -52.568  57.265  4
637328  91.418  -52.590  57.238  4
637329  91.445  -52.612  57.212  4
637330  91.471  -52.635  57.187  4
637331  91.498  -52.657  57.160  4
637332  91.524  -52.680  57.147  4
637333  91.551  -52.702  57.136  4
637334  91.578  -52.724  57.129  4
637335  91.605  -52.745  57.119  4
637336  91.633  -52.766  57.099  4
637337  91.661  -52.786  57.069  4
637338  91.689  -52.807  57.043  4
637339  91.717  -52.827  57.012  4
637340  91.745  -52.847  56.979  4
637341  91.773  -52.868  56.942  4
637342  91.795  -52.885  56.902  4
637343  91.811  -52.899  56.860  4
637344  91.834  -52.916  56.819  4
637345  91.867  -52.941  56.775  4
637346  91.901  -52.966  56.724  4
637347  91.934  -52.990  56.670  4
637348  91.967  -53.015  56.618  4
637349  92.001  -53.039  56.566  4
637350  92.034  -53.064  56.514  4
637351  92.067  -53.089  56.460  4
637352  92.101  -53.113  56.406  4
637353  92.139  -53.129  56.352  4
637354  92.180  -53.142  56.298  4
637355  92.221  -53.156  56.243  4
637356  92.262  -53.170  56.189  4
637357  92.302  -53.183  56.138  4
637358  92.343  -53.197  56.086  4
637359  92.384  -53.210  56.035  4
637360  92.425  -53.223  55.986  4
637361  92.465  -53.237  55.938  4
637394  93.585  -53.684  54.900  1
637395  93.615  -53.699  54.897  1
637396  93.645  -53.713  54.897  1
637397  93.675  -53.728  54.895  1
637398  93.705  -53.743  54.897  1
637399  93.735  -53.757  54.900  1
637400  93.765  -53.772  54.903  1
637401  93.795  -53.786  54.907  1
637402  93.825  -53.801  54.910  1
637403  93.855  -53.816  54.914  1
637404  93.885  -53.830  54.921  1
637405  93.915  -53.844  54.928  1
637406  93.945  -53.860  54.935  1
637407  93.975  -53.874  54.942  1
637408  94.005  -53.888  54.949  1
637409  94.042  -53.902  54.959  1
637410  94.079  -53.916  54.968  1
637411  94.117  -53.929  54.976  1
637412  94.152  -53.947  54.988  1
637413  94.187  -53.969  55.003  1
637414  94.221  -53.990  55.020  1
637415  94.255  -54.011  55.035  1
637416  94.271  -54.019  55.047  1
637417  94.288  -54.027  55.051  1
637418  94.305  -54.035  55.050  1
637419  94.321  -54.043  55.048  1
637420  94.338  -54.051  55.045  1
637421  94.354  -54.059  55.042  1
637422  94.371  -54.067  55.032  1
637423  94.388  -54.076  55.029  1
637424  94.404  -54.083  55.026  1
637425  94.421  -54.091  55.021  1
637426  94.437  -54.099  55.013  1
637427  94.454  -54.107  55.003  1
637428  94.471  -54.115  54.990  1
637429  94.487  -54.123  54.978  1
637430  94.504  -54.131  54.964  1
637431  94.521  -54.139  54.946  1
637432  94.537  -54.147  54.924  1
637433  94.554  -54.155  54.900  1
637434  94.570  -54.163  54.870  1
637435  94.587  -54.171  54.844  1
637436  94.604  -54.179  54.818  1
637437  94.620  -54.187  54.793  1
637438  94.637  -54.195  54.766  1
637439  94.653  -54.203  54.737  1
637440  94.672  -54.212  54.702  1
637441  94.696  -54.225  54.667  1
637442  94.736  -54.251  54.633  1
637443  94.776  -54.277  54.600  1
637444  94.817  -54.304  54.569  1
637445  94.857  -54.330  54.535  1
637446  94.897  -54.357  54.496  1
637447  94.937  -54.383  54.458  1
637448  94.977  -54.411  54.420  1
637449  95.018  -54.437  54.376  1
637450  95.046  -54.452  54.327  1
637451  95.076  -54.468  54.273  1
637452  95.106  -54.485  54.213  1
637453  95.136  -54.502  54.154  1
637454  95.166  -54.518  54.105  1
637455  95.196  -54.535  54.062  1
637456  95.226  -54.552  54.022  1
637457  95.256  -54.568  53.980  1
637458  95.285  -54.585  53.935  1
637459  95.314  -54.602  53.889  1
637460  95.340  -54.621  53.841  1
637461  95.367  -54.639  53.795  1
637462  95.394  -54.657  53.750  1
637463  95.421  -54.675  53.703  1
637464  95.448  -54.693  53.654  1
637465  95.479  -54.708  53.607  1
637466  95.512  -54.721  53.561  1
637467  95.544  -54.735  53.522  1
637468  95.577  -54.749  53.491  1
637469  95.609  -54.762  53.459  1
637470  95.642  -54.776  53.427  1
637471  95.674  -54.790  53.397  1
637472  95.705  -54.804  53.368  1
637473  95.736  -54.818  53.339  1
637474  95.767  -54.833  53.307  1
637475  95.796  -54.845  53.271  1
637476  95.823  -54.856  53.236  1
637477  95.851  -54.867  53.200  1
637478  95.879  -54.878  53.163  1
637479  95.907  -54.889  53.125  1
637480  95.935  -54.900  53.087  1
637481  95.962  -54.912  53.047  1
637482  95.990  -54.923  53.005  1
637483  96.019  -54.934  52.963  1
637484  96.048  -54.946  52.920  1
637485  96.078  -54.958  52.877  1
637486  96.107  -54.963  52.834  1
637487  96.135  -54.968  52.788  1
637488  96.165  -54.972  52.741  1
637489  96.193  -54.979  52.693  1
637490  96.221  -54.990  52.644  1
637491  96.250  -55.000  52.592  1
637492  96.278  -55.010  52.535  1
637493  96.306  -55.020  52.475  1
637494  96.333  -55.029  52.412  1
637495  96.357  -55.038  52.353  1
637496  96.382  -55.046  52.299  1
637497  96.408  -55.054  52.247  1
637498  96.437  -55.060  52.191  1
637499  96.465  -55.067  52.127  1
637500  96.494  -55.075  52.056  1
637501  96.525  -55.083  51.980  1
637502  96.556  -55.091  51.901  1
637503  96.588  -55.101  51.821  1
637504  96.624  -55.111  51.741  1
637505  96.664  -55.124  51.667  1
637506  96.700  -55.143  51.592  1
637507  96.736  -55.167  51.521  1
637508  96.770  -55.191  51.449  1
637509  96.806  -55.217  51.378  1
637510  96.840  -55.241  51.308  1
637511  96.876  -55.265  51.240  1
637512  96.910  -55.289  51.172  1
637513  96.946  -55.314  51.105  1
637514  96.978  -55.335  51.040  1
637515  96.995  -55.334  50.974  1
637516  97.012  -55.333  50.910  1
637517  97.028  -55.332  50.850  1
637518  97.045  -55.332  50.792  1
637519  97.062  -55.330  50.733  1
637520  97.078  -55.329  50.677  1
637521  97.095  -55.329  50.623  1
637522  97.111  -55.328  50.570  1
637523  97.128  -55.327  50.518  1
637915  87.855  -50.563  56.393  5
637916  87.890  -50.584  56.397  5
637917  87.924  -50.604  56.400  5
637918  87.959  -50.625  56.401  5
637919  87.993  -50.646  56.401  5
637920  88.028  -50.666  56.398  5
637921  88.063  -50.687  56.390  5
637922  88.097  -50.707  56.379  5
637923  88.132  -50.729  56.366  5
637924  88.167  -50.749  56.351  5
637925  88.201  -50.770  56.335  5
637989  90.306  -51.920  57.036  4
637990  90.338  -51.927  57.045  4
637991  90.370  -51.935  57.055  4
637992  90.402  -51.944  57.065  4
637993  90.435  -51.951  57.075  4
637994  90.467  -51.960  57.085  4
637995  90.499  -51.967  57.092  4
637996  90.531  -51.976  57.100  4
637997  90.564  -51.983  57.107  4
637998  90.596  -51.992  57.114  4
637999  90.628  -52.000  57.119  4
638000  90.661  -52.007  57.122  4
638001  90.693  -52.016  57.127  4
638002  90.725  -52.023  57.131  4
638003  90.757  -52.032  57.135  4
638004  90.790  -52.039  57.138  4
638005  90.822  -52.048  57.141  4
638006  90.854  -52.056  57.144  4
638007  90.886  -52.064  57.149  4
638008  90.919  -52.072  57.155  4
638009  90.945  -52.082  57.163  4
638010  90.972  -52.104  57.172  4
638011  91.013  -52.122  57.184  4
638012  91.053  -52.140  57.200  4
638013  91.078  -52.160  57.217  4
638014  91.104  -52.180  57.233  4
638015  91.129  -52.199  57.246  4
638016  91.156  -52.223  57.260  4
638017  91.186  -52.249  57.273  4
638018  91.216  -52.276  57.285  4
638019  91.246  -52.302  57.301  4
638020  91.276  -52.328  57.307  4
638021  91.305  -52.355  57.308  4
638022  91.335  -52.381  57.313  4
638023  91.326  -52.414  57.319  4
638024  91.308  -52.447  57.319  4
638025  91.330  -52.471  57.309  4
638026  91.357  -52.493  57.298  4
638027  91.383  -52.515  57.282  4
638028  91.410  -52.538  57.259  4
638029  91.437  -52.560  57.231  4
638030  91.463  -52.583  57.205  4
638031  91.490  -52.605  57.182  4
638032  91.517  -52.627  57.161  4
638033  91.543  -52.650  57.147  4
638034  91.570  -52.672  57.139  4
638035  91.597  -52.694  57.131  4
638036  91.623  -52.716  57.120  4
638037  91.650  -52.739  57.102  4
638038  91.677  -52.760  57.074  4
638039  91.705  -52.780  57.044  4
638040  91.733  -52.800  57.011  4
638041  91.761  -52.821  56.976  4
638042  91.789  -52.841  56.938  4
638043  91.817  -52.862  56.898  4
638044  91.841  -52.880  56.857  4
638045  91.858  -52.894  56.817  4
638046  91.881  -52.913  56.774  4
638047  91.915  -52.937  56.727  4
638048  91.948  -52.962  56.677  4
638049  91.981  -52.986  56.628  4
638050  92.015  -53.010  56.580  4
638051  92.048  -53.035  56.532  4
638052  92.081  -53.060  56.478  4
638053  92.115  -53.084  56.422  4
638054  92.154  -53.101  56.367  4
638055  92.195  -53.114  56.312  4
638056  92.235  -53.127  56.256  4
638057  92.276  -53.141  56.201  4
638058  92.316  -53.154  56.148  4
638059  92.357  -53.168  56.095  4
638060  92.398  -53.181  56.043  4
638061  92.439  -53.195  55.993  4
638062  92.480  -53.208  55.944  4
638095  93.601  -53.649  54.892  1
638096  93.631  -53.663  54.889  1
638097  93.661  -53.678  54.888  1
638098  93.691  -53.693  54.887  1
638099  93.721  -53.707  54.888  1
638100  93.751  -53.722  54.890  1
638101  93.781  -53.736  54.894  1
638102  93.811  -53.750  54.898  1
638103  93.841  -53.766  54.902  1
638104  93.871  -53.780  54.907  1
638105  93.901  -53.794  54.913  1
638106  93.931  -53.809  54.920  1
638107  93.961  -53.824  54.928  1
638108  93.991  -53.838  54.935  1
638109  94.021  -53.853  54.944  1
638110  94.052  -53.867  54.953  1
638111  94.089  -53.881  54.963  1
638112  94.125  -53.897  54.972  1
638113  94.159  -53.919  54.983  1
638114  94.193  -53.941  54.998  1
638115  94.227  -53.962  55.014  1
638116  94.262  -53.983  55.024  1
638117  94.283  -53.995  55.032  1
638118  94.300  -54.004  55.034  1
638119  94.317  -54.011  55.034  1
638120  94.333  -54.019  55.034  1
638121  94.350  -54.027  55.036  1
638122  94.366  -54.035  55.035  1
638123  94.383  -54.043  55.029  1
638124  94.400  -54.051  55.026  1
638125  94.416  -54.059  55.024  1
638126  94.433  -54.067  55.022  1
638127  94.450  -54.076  55.019  1
638128  94.466  -54.083  55.010  1
638129  94.483  -54.091  54.994  1
638130  94.499  -54.099  54.978  1
638131  94.516  -54.107  54.960  1
638132  94.533  -54.115  54.940  1
638133  94.549  -54.123  54.918  1
638134  94.566  -54.131  54.895  1
638135  94.582  -54.139  54.867  1
638136  94.599  -54.147  54.841  1
638137  94.616  -54.155  54.817  1
638138  94.632  -54.163  54.793  1
638139  94.649  -54.171  54.769  1
638140  94.671  -54.182  54.742  1
638141  94.695  -54.195  54.708  1
638142  94.718  -54.207  54.675  1
638143  94.749  -54.223  54.643  1
638144  94.788  -54.249  54.613  1
638145  94.829  -54.276  54.583  1
638146  94.869  -54.302  54.549  1
638147  94.909  -54.329  54.509  1
638148  94.950  -54.355  54.470  1
638149  94.990  -54.382  54.430  1
638150  95.030  -54.408  54.385  1
638151  95.061  -54.426  54.334  1
638152  95.090  -54.441  54.279  1
638153  95.118  -54.455  54.220  1
638154  95.148  -54.472  54.163  1
638155  95.178  -54.489  54.119  1
638156  95.208  -54.505  54.079  1
638157  95.238  -54.522  54.039  1
638158  95.268  -54.540  53.996  1
638159  95.296  -54.557  53.950  1
638160  95.323  -54.575  53.903  1
638161  95.349  -54.593  53.854  1
638162  95.376  -54.612  53.807  1
638163  95.403  -54.630  53.760  1
638164  95.430  -54.648  53.713  1
638165  95.457  -54.666  53.664  1
638166  95.487  -54.681  53.617  1
638167  95.520  -54.694  53.574  1
638168  95.553  -54.708  53.538  1
638169  95.585  -54.721  53.507  1
638170  95.618  -54.735  53.476  1
638171  95.650  -54.749  53.446  1
638172  95.683  -54.762  53.417  1
638173  95.715  -54.776  53.389  1
638174  95.747  -54.790  53.360  1
638175  95.777  -54.804  53.329  1
638176  95.807  -54.817  53.295  1
638177  95.835  -54.828  53.260  1
638178  95.863  -54.839  53.225  1
638179  95.890  -54.850  53.189  1
638180  95.918  -54.862  53.153  1
638181  95.946  -54.873  53.114  1
638182  95.974  -54.884  53.072  1
638183  96.002  -54.895  53.029  1
638184  96.029  -54.906  52.986  1
638185  96.058  -54.918  52.944  1
638186  96.088  -54.930  52.900  1
638187  96.116  -54.935  52.854  1
638188  96.146  -54.940  52.807  1
638189  96.174  -54.948  52.758  1
638190  96.202  -54.959  52.708  1
638191  96.230  -54.969  52.658  1
638192  96.258  -54.979  52.606  1
638193  96.287  -54.989  52.552  1
638194  96.315  -55.000  52.496  1
638195  96.339  -55.007  52.439  1
638196  96.364  -55.016  52.387  1
638197  96.388  -55.023  52.339  1
638198  96.415  -55.031  52.291  1
638199  96.444  -55.038  52.238  1
638200  96.473  -55.045  52.178  1
638201  96.502  -55.052  52.110  1
638202  96.532  -55.060  52.036  1
638203  96.564  -55.069  51.958  1
638204  96.595  -55.078  51.877  1
638205  96.626  -55.086  51.794  1
638206  96.664  -55.098  51.717  1
638207  96.704  -55.111  51.640  1
638208  96.741  -55.130  51.567  1
638209  96.776  -55.154  51.494  1
638210  96.811  -55.179  51.422  1
638211  96.846  -55.203  51.350  1
638212  96.881  -55.227  51.281  1
638213  96.916  -55.251  51.211  1
638214  96.951  -55.276  51.144  1
638215  96.986  -55.300  51.077  1
638216  97.009  -55.309  51.010  1
638217  97.026  -55.308  50.945  1
638218  97.042  -55.307  50.884  1
638219  97.059  -55.306  50.824  1
638220  97.076  -55.305  50.765  1
638221  97.092  -55.304  50.708  1
638222  97.109  -55.304  50.652  1
638223  97.125  -55.303  50.598  1
638224  97.142  -55.302  50.546  1
638618  87.941  -50.568  56.369  5
638619  87.976  -50.589  56.370  5
638620  88.011  -50.610  56.369  5
638621  88.045  -50.630  56.365  5
638622  88.080  -50.650  56.357  5
638623  88.115  -50.672  56.346  5
638624  88.149  -50.692  56.333  5
638690  90.325  -51.886  57.026  4
638691  90.358  -51.894  57.035  4
638692  90.390  -51.902  57.044  4
638693  90.423  -51.910  57.054  4
638694  90.455  -51.918  57.063  4
638695  90.487  -51.926  57.072  4
638696  90.519  -51.934  57.080  4
638697  90.551  -51.942  57.087  4
638698  90.584  -51.950  57.095  4
638699  90.616  -51.958  57.101  4
638700  90.648  -51.967  57.106  4
638701  90.680  -51.974  57.110  4
638702  90.713  -51.982  57.114  4
638703  90.745  -51.990  57.119  4
638704  90.778  -51.998  57.124  4
638705  90.810  -52.006  57.128  4
638706  90.842  -52.014  57.131  4
638707  90.874  -52.023  57.135  4
638708  90.906  -52.030  57.141  4
638709  90.939  -52.039  57.149  4
638710  90.969  -52.048  57.158  4
638711  91.003  -52.065  57.171  4
638712  91.032  -52.084  57.187  4
638713  91.058  -52.105  57.207  4
638714  91.083  -52.124  57.224  4
638715  91.108  -52.144  57.241  4
638716  91.136  -52.167  57.260  4
638717  91.166  -52.194  57.278  4
638718  91.195  -52.220  57.291  4
638719  91.225  -52.246  57.300  4
638720  91.255  -52.273  57.309  4
638721  91.285  -52.299  57.311  4
638722  91.314  -52.326  57.312  4
638723  91.345  -52.352  57.316  4
638724  91.349  -52.383  57.318  4
638725  91.332  -52.416  57.316  4
638726  91.349  -52.441  57.304  4
638727  91.376  -52.463  57.289  4
638728  91.402  -52.486  57.274  4
638729  91.429  -52.508  57.254  4
638730  91.455  -52.530  57.228  4
638731  91.482  -52.553  57.201  4
638732  91.509  -52.575  57.178  4
638733  91.535  -52.597  57.158  4
638734  91.562  -52.619  57.145  4
638735  91.589  -52.642  57.135  4
638736  91.615  -52.664  57.126  4
638737  91.642  -52.687  57.116  4
638738  91.669  -52.709  57.103  4
638739  91.695  -52.731  57.077  4
638740  91.722  -52.753  57.044  4
638741  91.749  -52.775  57.008  4
638742  91.777  -52.795  56.970  4
638743  91.805  -52.816  56.932  4
638744  91.833  -52.836  56.893  4
638745  91.861  -52.857  56.852  4
638746  91.887  -52.876  56.813  4
638747  91.904  -52.890  56.772  4
638748  91.929  -52.909  56.728  4
638749  91.962  -52.933  56.683  4
638750  91.995  -52.957  56.639  4
638751  92.028  -52.982  56.595  4
638752  92.062  -53.007  56.549  4
638753  92.095  -53.031  56.495  4
638754  92.129  -53.056  56.439  4
638755  92.168  -53.072  56.381  4
638756  92.209  -53.085  56.324  4
638757  92.249  -53.098  56.267  4
638758  92.290  -53.112  56.211  4
638759  92.331  -53.126  56.157  4
638760  92.371  -53.139  56.103  4
638761  92.412  -53.152  56.049  4
638762  92.453  -53.166  55.998  4
638763  92.500  -53.173  55.948  4
638797  93.647  -53.628  54.881  1
638798  93.677  -53.642  54.879  1
638799  93.707  -53.657  54.879  1
638800  93.737  -53.672  54.880  1
638801  93.767  -53.686  54.882  1
638802  93.797  -53.700  54.886  1
638803  93.827  -53.715  54.891  1
638804  93.857  -53.730  54.895  1
638805  93.887  -53.744  54.900  1
638806  93.917  -53.759  54.907  1
638807  93.947  -53.774  54.914  1
638808  93.977  -53.788  54.922  1
638809  94.007  -53.803  54.930  1
638810  94.037  -53.817  54.940  1
638811  94.067  -53.832  54.951  1
638812  94.098  -53.847  54.962  1
638813  94.132  -53.869  54.970  1
638814  94.166  -53.891  54.978  1
638815  94.200  -53.913  54.991  1
638816  94.234  -53.934  55.003  1
638817  94.268  -53.955  55.012  1
638818  94.295  -53.972  55.017  1
638819  94.312  -53.979  55.019  1
638820  94.329  -53.988  55.021  1
638821  94.345  -53.995  55.025  1
638822  94.362  -54.004  55.031  1
638823  94.379  -54.011  55.032  1
638824  94.395  -54.019  55.027  1
638825  94.412  -54.027  55.021  1
638826  94.428  -54.035  55.020  1
638827  94.445  -54.043  55.023  1
638828  94.462  -54.051  55.024  1
638829  94.478  -54.059  55.016  1
638830  94.495  -54.067  54.998  1
638831  94.511  -54.076  54.978  1
638832  94.528  -54.083  54.956  1
638833  94.545  -54.091  54.935  1
638834  94.561  -54.099  54.913  1
638835  94.578  -54.107  54.892  1
638836  94.595  -54.115  54.867  1
638837  94.611  -54.123  54.844  1
638838  94.628  -54.131  54.823  1
638839  94.647  -54.141  54.801  1
638840  94.671  -54.153  54.779  1
638841  94.694  -54.166  54.755  1
638842  94.718  -54.178  54.722  1
638843  94.742  -54.190  54.688  1
638844  94.765  -54.202  54.656  1
638845  94.801  -54.221  54.625  1
638846  94.841  -54.247  54.596  1
638847  94.882  -54.274  54.563  1
638848  94.921  -54.301  54.522  1
638849  94.962  -54.327  54.481  1
638850  95.002  -54.354  54.436  1
638851  95.042  -54.380  54.389  1
638852  95.076  -54.401  54.337  1
638853  95.105  -54.415  54.282  1
638854  95.133  -54.430  54.225  1
638855  95.162  -54.445  54.175  1
638856  95.191  -54.460  54.134  1
638857  95.220  -54.477  54.095  1
638858  95.250  -54.493  54.054  1
638859  95.278  -54.511  54.011  1
638860  95.305  -54.529  53.964  1
638861  95.332  -54.547  53.914  1
638862  95.358  -54.565  53.865  1
638863  95.385  -54.583  53.816  1
638864  95.412  -54.602  53.769  1
638865  95.439  -54.620  53.721  1
638866  95.466  -54.638  53.673  1
638867  95.496  -54.654  53.628  1
638868  95.528  -54.668  53.589  1
638869  95.561  -54.681  53.555  1
638870  95.594  -54.694  53.525  1
638871  95.626  -54.708  53.496  1
638872  95.659  -54.721  53.467  1
638873  95.691  -54.735  53.439  1
638874  95.724  -54.749  53.412  1
638875  95.756  -54.762  53.384  1
638876  95.789  -54.776  53.355  1
638877  95.818  -54.790  53.322  1
638878  95.846  -54.800  53.288  1
638879  95.874  -54.812  53.252  1
638880  95.902  -54.823  53.216  1
638881  95.930  -54.834  53.178  1
638882  95.957  -54.845  53.139  1
638883  95.985  -54.856  53.097  1
638884  96.013  -54.867  53.055  1
638885  96.041  -54.878  53.013  1
638886  96.068  -54.890  52.971  1
638887  96.097  -54.901  52.928  1
638888  96.126  -54.907  52.880  1
638889  96.155  -54.917  52.830  1
638890  96.183  -54.928  52.779  1
638891  96.211  -54.938  52.726  1
638892  96.239  -54.948  52.674  1
638893  96.267  -54.958  52.623  1
638894  96.296  -54.969  52.568  1
638895  96.322  -54.977  52.517  1
638896  96.346  -54.985  52.469  1
638897  96.371  -54.994  52.423  1
638898  96.395  -55.001  52.380  1
638899  96.423  -55.009  52.335  1
638900  96.452  -55.016  52.284  1
638901  96.480  -55.022  52.228  1
638902  96.509  -55.030  52.161  1
638903  96.539  -55.038  52.090  1
638904  96.570  -55.046  52.016  1
638905  96.601  -55.055  51.936  1
638906  96.632  -55.063  51.851  1
638907  96.665  -55.072  51.770  1
638908  96.704  -55.085  51.693  1
638909  96.744  -55.097  51.618  1
638910  96.781  -55.117  51.543  1
638911  96.816  -55.141  51.469  1
638912  96.851  -55.166  51.396  1
638913  96.886  -55.190  51.326  1
638914  96.921  -55.214  51.254  1
638915  96.956  -55.238  51.185  1
638916  96.991  -55.263  51.117  1
638917  97.024  -55.284  51.049  1
638918  97.040  -55.282  50.984  1
638919  97.057  -55.282  50.921  1
638920  97.074  -55.281  50.860  1
638921  97.090  -55.280  50.800  1
638922  97.107  -55.279  50.741  1
638923  97.123  -55.279  50.684  1
638924  97.140  -55.278  50.629  1
638925  97.157  -55.277  50.575  1
638926  97.186  -55.276  50.523  1
639391  90.345  -51.853  57.016  4
639392  90.378  -51.860  57.025  4
639393  90.410  -51.869  57.034  4
639394  90.442  -51.876  57.043  4
639395  90.474  -51.885  57.051  4
639396  90.507  -51.893  57.059  4
639397  90.539  -51.901  57.067  4
639398  90.572  -51.909  57.074  4
639399  90.604  -51.917  57.081  4
639400  90.636  -51.925  57.088  4
639401  90.668  -51.932  57.093  4
639402  90.700  -51.941  57.097  4
639403  90.733  -51.949  57.102  4
639404  90.765  -51.957  57.107  4
639405  90.797  -51.965  57.113  4
639406  90.830  -51.973  57.118  4
639407  90.862  -51.981  57.121  4
639408  90.894  -51.989  57.125  4
639409  90.927  -51.997  57.132  4
639410  90.959  -52.005  57.142  4
639411  90.990  -52.014  57.154  4
639412  91.012  -52.029  57.169  4
639413  91.037  -52.049  57.189  4
639414  91.063  -52.069  57.209  4
639415  91.088  -52.089  57.227  4
639416  91.115  -52.111  57.247  4
639417  91.145  -52.138  57.267  4
639418  91.175  -52.164  57.284  4
639419  91.205  -52.191  57.294  4
639420  91.234  -52.217  57.302  4
639421  91.264  -52.244  57.306  4
639422  91.294  -52.271  57.306  4
639423  91.324  -52.297  57.305  4
639424  91.354  -52.323  57.305  4
639425  91.373  -52.351  57.308  4
639426  91.355  -52.385  57.307  4
639427  91.368  -52.411  57.296  4
639428  91.394  -52.433  57.277  4
639429  91.421  -52.456  57.266  4
639430  91.448  -52.477  57.252  4
639431  91.474  -52.500  57.229  4
639432  91.501  -52.522  57.200  4
639433  91.527  -52.545  57.176  4
639434  91.554  -52.567  57.154  4
639435  91.581  -52.590  57.140  4
639436  91.607  -52.612  57.129  4
639437  91.634  -52.634  57.119  4
639438  91.661  -52.656  57.110  4
639439  91.687  -52.679  57.100  4
639440  91.714  -52.701  57.075  4
639441  91.741  -52.723  57.039  4
639442  91.768  -52.746  57.004  4
639443  91.794  -52.768  56.967  4
639444  91.821  -52.789  56.928  4
639445  91.850  -52.810  56.888  4
639446  91.877  -52.830  56.850  4
639447  91.905  -52.850  56.811  4
639448  91.933  -52.871  56.771  4
639449  91.950  -52.885  56.730  4
639450  91.976  -52.905  56.690  4
639451  92.009  -52.929  56.650  4
639452  92.042  -52.954  56.609  4
639453  92.076  -52.978  56.565  4
639454  92.109  -53.003  56.513  4
639455  92.142  -53.027  56.455  4
639456  92.182  -53.042  56.395  4
639457  92.223  -53.056  56.335  4
639458  92.264  -53.070  56.278  4
639459  92.304  -53.083  56.221  4
639460  92.345  -53.097  56.165  4
639461  92.385  -53.110  56.110  4
639462  92.427  -53.123  56.055  4
639463  92.475  -53.129  56.003  4
639464  92.522  -53.136  55.952  4
639465  92.570  -53.142  55.901  4
639498  93.663  -53.592  54.874  1
639499  93.693  -53.606  54.873  1
639500  93.723  -53.621  54.872  1
639501  93.753  -53.636  54.874  1
639502  93.783  -53.650  54.876  1
639503  93.813  -53.665  54.879  1
639504  93.843  -53.680  54.884  1
639505  93.873  -53.694  54.889  1
639506  93.903  -53.709  54.894  1
639507  93.933  -53.723  54.900  1
639508  93.963  -53.738  54.908  1
639509  93.993  -53.753  54.916  1
639510  94.023  -53.767  54.925  1
639511  94.053  -53.784  54.935  1
639512  94.084  -53.803  54.947  1
639513  94.112  -53.821  54.957  1
639514  94.139  -53.841  54.965  1
639515  94.173  -53.863  54.972  1
639516  94.207  -53.884  54.983  1
639517  94.241  -53.906  54.992  1
639518  94.275  -53.927  55.000  1
639519  94.308  -53.947  55.006  1
639520  94.324  -53.955  55.009  1
639521  94.341  -53.963  55.012  1
639522  94.357  -53.972  55.017  1
639523  94.374  -53.979  55.021  1
639524  94.391  -53.988  55.022  1
639525  94.407  -53.995  55.018  1
639526  94.424  -54.004  55.015  1
639527  94.440  -54.011  55.019  1
639528  94.457  -54.019  55.025  1
639529  94.474  -54.027  55.026  1
639530  94.490  -54.035  55.019  1
639531  94.507  -54.043  54.999  1
639532  94.524  -54.051  54.976  1
639533  94.540  -54.060  54.953  1
639534  94.557  -54.067  54.931  1
639535  94.573  -54.076  54.912  1
639536  94.590  -54.083  54.892  1
639537  94.607  -54.091  54.869  1
639538  94.623  -54.099  54.850  1
639539  94.646  -54.111  54.831  1
639540  94.670  -54.123  54.812  1
639541  94.693  -54.136  54.792  1
639542  94.717  -54.148  54.771  1
639543  94.741  -54.160  54.740  1
639544  94.764  -54.173  54.705  1
639545  94.788  -54.185  54.671  1
639546  94.817  -54.201  54.639  1
639547  94.853  -54.220  54.608  1
639548  94.894  -54.245  54.575  1
639549  94.934  -54.272  54.532  1
639550  94.974  -54.299  54.487  1
639551  95.014  -54.326  54.439  1
639552  95.054  -54.352  54.390  1
639553  95.091  -54.375  54.338  1
639554  95.120  -54.389  54.285  1
639555  95.148  -54.405  54.233  1
639556  95.177  -54.419  54.188  1
639557  95.205  -54.433  54.148  1
639558  95.234  -54.449  54.109  1
639559  95.260  -54.465  54.067  1
639560  95.287  -54.483  54.021  1
639561  95.314  -54.502  53.973  1
639562  95.341  -54.520  53.922  1
639563  95.368  -54.538  53.872  1
639564  95.394  -54.556  53.823  1
639565  95.421  -54.574  53.776  1
639566  95.448  -54.593  53.729  1
639567  95.475  -54.611  53.683  1
639568  95.504  -54.627  53.640  1
639569  95.537  -54.640  53.604  1
639570  95.569  -54.654  53.573  1
639571  95.602  -54.668  53.545  1
639572  95.634  -54.681  53.517  1
639573  95.667  -54.694  53.489  1
639574  95.699  -54.708  53.462  1
639575  95.732  -54.721  53.436  1
639576  95.764  -54.735  53.409  1
639577  95.797  -54.749  53.381  1
639578  95.829  -54.762  53.350  1
639579  95.857  -54.775  53.315  1
639580  95.885  -54.786  53.279  1
639581  95.912  -54.797  53.241  1
639582  95.940  -54.809  53.202  1
639583  95.968  -54.819  53.164  1
639584  95.996  -54.831  53.123  1
639585  96.024  -54.842  53.081  1
639586  96.051  -54.853  53.040  1
639587  96.079  -54.864  52.997  1
639588  96.107  -54.875  52.955  1
639589  96.135  -54.886  52.906  1
639590  96.163  -54.896  52.856  1
639591  96.192  -54.906  52.804  1
639592  96.220  -54.916  52.752  1
639593  96.248  -54.927  52.699  1
639594  96.276  -54.938  52.649  1
639595  96.304  -54.947  52.598  1
639596  96.328  -54.955  52.550  1
639597  96.353  -54.963  52.505  1
639598  96.377  -54.971  52.462  1
639599  96.402  -54.979  52.419  1
639600  96.431  -54.986  52.375  1
639601  96.459  -54.994  52.327  1
639602  96.488  -55.000  52.272  1
639603  96.517  -55.007  52.209  1
639604  96.545  -55.015  52.140  1
639605  96.577  -55.023  52.068  1
639606  96.608  -55.032  51.991  1
639607  96.640  -55.041  51.910  1
639608  96.671  -55.050  51.832  1
639609  96.705  -55.060  51.756  1
639610  96.745  -55.072  51.678  1
639611  96.785  -55.085  51.599  1
639612  96.821  -55.104  51.522  1
639613  96.857  -55.128  51.447  1
639614  96.892  -55.152  51.374  1
639615  96.927  -55.176  51.302  1
639616  96.962  -55.201  51.230  1
639617  96.997  -55.226  51.160  1
639618  97.032  -55.250  51.092  1
639619  97.054  -55.257  51.025  1
639620  97.071  -55.257  50.960  1
639621  97.088  -55.256  50.898  1
639622  97.104  -55.255  50.837  1
639623  97.121  -55.254  50.776  1
639624  97.138  -55.254  50.718  1
639625  97.154  -55.253  50.661  1
639626  97.171  -55.252  50.607  1
639627  97.202  -55.251  50.554  1
639628  97.237  -55.250  50.501  1
640092  90.366  -51.819  57.005  4
640093  90.398  -51.827  57.013  4
640094  90.430  -51.835  57.021  4
640095  90.462  -51.843  57.030  4
640096  90.495  -51.851  57.038  4
640097  90.527  -51.860  57.046  4
640098  90.559  -51.867  57.054  4
640099  90.592  -51.876  57.061  4
640100  90.624  -51.883  57.068  4
640101  90.656  -51.891  57.075  4
640102  90.688  -51.899  57.080  4
640103  90.721  -51.907  57.084  4
640104  90.753  -51.916  57.089  4
640105  90.785  -51.923  57.094  4
640106  90.817  -51.932  57.101  4
640107  90.850  -51.939  57.107  4
640108  90.882  -51.948  57.111  4
640109  90.914  -51.955  57.117  4
640110  90.947  -51.964  57.125  4
640111  90.979  -51.972  57.136  4
640112  90.995  -51.986  57.150  4
640113  91.016  -51.995  57.165  4
640114  91.042  -52.014  57.183  4
640115  91.067  -52.033  57.200  4
640116  91.095  -52.056  57.223  4
640117  91.124  -52.083  57.248  4
640118  91.154  -52.109  57.268  4
640119  91.184  -52.136  57.281  4
640120  91.214  -52.162  57.289  4
640121  91.243  -52.189  57.297  4
640122  91.274  -52.214  57.296  4
640123  91.303  -52.241  57.296  4
640124  91.333  -52.268  57.293  4
640125  91.363  -52.294  57.292  4
640126  91.392  -52.321  57.295  4
640127  91.379  -52.354  57.296  4
640128  91.386  -52.380  57.286  4
640129  91.413  -52.403  57.267  4
640130  91.440  -52.425  57.256  4
640131  91.466  -52.448  57.245  4
640132  91.493  -52.470  57.227  4
640133  91.520  -52.493  57.203  4
640134  91.546  -52.515  57.176  4
640135  91.573  -52.537  57.151  4
640136  91.600  -52.559  57.133  4
640137  91.626  -52.582  57.120  4
640138  91.653  -52.604  57.110  4
640139  91.679  -52.626  57.102  4
640140  91.706  -52.649  57.093  4
640141  91.733  -52.671  57.069  4
640142  91.759  -52.694  57.034  4
640143  91.786  -52.716  57.000  4
640144  91.813  -52.738  56.964  4
640145  91.840  -52.760  56.925  4
640146  91.866  -52.783  56.884  4
640147  91.893  -52.803  56.847  4
640148  91.922  -52.824  56.810  4
640149  91.949  -52.844  56.772  4
640150  91.978  -52.865  56.733  4
640151  91.996  -52.880  56.695  4
640152  92.023  -52.901  56.657  4
640153  92.056  -52.926  56.617  4
640154  92.090  -52.950  56.573  4
640155  92.123  -52.974  56.523  4
640156  92.156  -52.999  56.466  4
640157  92.196  -53.013  56.405  4
640158  92.237  -53.027  56.344  4
640159  92.278  -53.041  56.287  4
640160  92.318  -53.054  56.229  4
640161  92.359  -53.068  56.172  4
640162  92.402  -53.079  56.116  4
640163  92.449  -53.086  56.061  4
640164  92.497  -53.092  56.008  4
640165  92.545  -53.098  55.956  4
640166  92.593  -53.104  55.904  4
640200  93.709  -53.571  54.867  1
640201  93.739  -53.586  54.866  1
640202  93.769  -53.600  54.867  1
640203  93.799  -53.615  54.869  1
640204  93.829  -53.630  54.873  1
640205  93.859  -53.644  54.877  1
640206  93.889  -53.659  54.882  1
640207  93.919  -53.673  54.887  1
640208  93.949  -53.687  54.894  1
640209  93.979  -53.703  54.902  1
640210  94.010  -53.722  54.910  1
640211  94.040  -53.740  54.919  1
640212  94.071  -53.759  54.930  1
640213  94.101  -53.778  54.941  1
640214  94.132  -53.797  54.952  1
640215  94.147  -53.813  54.959  1
640216  94.180  -53.834  54.965  1
640217  94.214  -53.856  54.974  1
640218  94.248  -53.878  54.981  1
640219  94.282  -53.899  54.988  1
640220  94.316  -53.921  54.995  1
640221  94.336  -53.932  54.999  1
640222  94.353  -53.939  55.003  1
640223  94.369  -53.947  55.008  1
640224  94.386  -53.955  55.010  1
640225  94.403  -53.963  55.011  1
640226  94.419  -53.972  55.009  1
640227  94.436  -53.979  55.009  1
640228  94.453  -53.988  55.014  1
640229  94.469  -53.995  55.021  1
640230  94.486  -54.004  55.021  1
640231  94.502  -54.011  55.012  1
640232  94.519  -54.019  54.993  1
640233  94.536  -54.027  54.971  1
640234  94.552  -54.035  54.949  1
640235  94.569  -54.043  54.930  1
640236  94.585  -54.051  54.912  1
640237  94.602  -54.060  54.896  1
640238  94.622  -54.070  54.875  1
640239  94.645  -54.082  54.859  1
640240  94.669  -54.094  54.843  1
640241  94.693  -54.107  54.825  1
640242  94.716  -54.119  54.808  1
640243  94.740  -54.131  54.790  1
640244  94.764  -54.143  54.762  1
640245  94.787  -54.156  54.726  1
640246  94.811  -54.168  54.689  1
640247  94.835  -54.180  54.654  1
640248  94.870  -54.198  54.621  1
640249  94.906  -54.217  54.586  1
640250  94.946  -54.244  54.541  1
640251  94.986  -54.270  54.492  1
640252  95.027  -54.297  54.442  1
640253  95.067  -54.324  54.392  1
640254  95.106  -54.350  54.341  1
640255  95.135  -54.364  54.291  1
640256  95.163  -54.379  54.243  1
640257  95.192  -54.393  54.202  1
640258  95.220  -54.408  54.161  1
640259  95.247  -54.423  54.120  1
640260  95.271  -54.439  54.076  1
640261  95.296  -54.455  54.030  1
640262  95.323  -54.474  53.979  1
640263  95.349  -54.492  53.928  1
640264  95.377  -54.510  53.877  1
640265  95.403  -54.528  53.828  1
640266  95.430  -54.546  53.782  1
640267  95.457  -54.565  53.739  1
640268  95.484  -54.583  53.696  1
640269  95.513  -54.599  53.658  1
640270  95.545  -54.613  53.623  1
640271  95.578  -54.627  53.593  1
640272  95.610  -54.640  53.566  1
640273  95.642  -54.654  53.538  1
640274  95.675  -54.668  53.511  1
640275  95.708  -54.681  53.484  1
640276  95.740  -54.694  53.459  1
640277  95.773  -54.708  53.432  1
640278  95.808  -54.718  53.404  1
640279  95.837  -54.732  53.373  1
640280  95.864  -54.750  53.339  1
640281  95.894  -54.764  53.303  1
640282  95.921  -54.776  53.264  1
640283  95.950  -54.787  53.225  1
640284  95.977  -54.798  53.189  1
640285  96.005  -54.809  53.149  1
640286  96.033  -54.821  53.108  1
640287  96.060  -54.832  53.066  1
640288  96.088  -54.843  53.023  1
640289  96.116  -54.854  52.978  1
640290  96.144  -54.865  52.931  1
640291  96.172  -54.875  52.882  1
640292  96.200  -54.885  52.831  1
640293  96.229  -54.896  52.779  1
640294  96.257  -54.906  52.728  1
640295  96.286  -54.916  52.678  1
640296  96.311  -54.925  52.631  1
640297  96.335  -54.933  52.585  1
640298  96.360  -54.941  52.541  1
640299  96.384  -54.949  52.498  1
640300  96.409  -54.957  52.455  1
640301  96.438  -54.964  52.412  1
640302  96.467  -54.971  52.366  1
640303  96.496  -54.978  52.312  1
640304  96.524  -54.985  52.250  1
640305  96.553  -54.992  52.183  1
640306  96.584  -55.000  52.112  1
640307  96.615  -55.009  52.039  1
640308  96.646  -55.018  51.965  1
640309  96.677  -55.027  51.893  1
640310  96.709  -55.035  51.821  1
640311  96.746  -55.047  51.744  1
640312  96.785  -55.059  51.665  1
640313  96.825  -55.072  51.585  1
640314  96.862  -55.091  51.505  1
640315  96.897  -55.115  51.427  1
640316  96.932  -55.139  51.353  1
640317  96.967  -55.163  51.279  1
640318  97.002  -55.188  51.207  1
640319  97.037  -55.212  51.137  1
640320  97.069  -55.232  51.069  1
640321  97.086  -55.232  51.003  1
640322  97.102  -55.231  50.940  1
640323  97.119  -55.230  50.877  1
640324  97.136  -55.229  50.815  1
640325  97.152  -55.229  50.755  1
640326  97.169  -55.228  50.697  1
640327  97.185  -55.227  50.642  1
640328  97.218  -55.226  50.586  1
640329  97.253  -55.225  50.532  1
640330  97.288  -55.223  50.479  1
640793  90.386  -51.786  56.995  4
640794  90.418  -51.794  57.002  4
640795  90.450  -51.802  57.009  4
640796  90.482  -51.810  57.017  4
640797  90.515  -51.818  57.025  4
640798  90.547  -51.826  57.032  4
640799  90.579  -51.834  57.040  4
640800  90.611  -51.842  57.047  4
640801  90.644  -51.850  57.054  4
640802  90.676  -51.858  57.061  4
640803  90.709  -51.866  57.066  4
640804  90.741  -51.874  57.070  4
640805  90.773  -51.882  57.075  4
640806  90.805  -51.890  57.081  4
640807  90.837  -51.898  57.088  4
640808  90.870  -51.906  57.096  4
640809  90.902  -51.914  57.101  4
640810  90.934  -51.922  57.109  4
640811  90.966  -51.930  57.119  4
640812  90.989  -51.942  57.132  4
640813  91.000  -51.958  57.144  4
640814  91.020  -51.968  57.158  4
640815  91.046  -51.978  57.173  4
640816  91.074  -52.001  57.189  4
640817  91.104  -52.027  57.211  4
640818  91.134  -52.054  57.233  4
640819  91.163  -52.080  57.252  4
640820  91.193  -52.107  57.267  4
640821  91.223  -52.133  57.275  4
640822  91.253  -52.159  57.280  4
640823  91.283  -52.186  57.279  4
640824  91.312  -52.212  57.279  4
640825  91.342  -52.239  57.278  4
640826  91.372  -52.265  57.277  4
640827  91.401  -52.292  57.280  4
640828  91.402  -52.322  57.282  4
640829  91.405  -52.351  57.274  4
640830  91.432  -52.373  57.257  4
640831  91.458  -52.396  57.244  4
640832  91.485  -52.418  57.235  4
640833  91.512  -52.440  57.222  4
640834  91.538  -52.462  57.201  4
640835  91.565  -52.485  57.172  4
640836  91.592  -52.507  57.146  4
640837  91.618  -52.529  57.126  4
640838  91.645  -52.552  57.110  4
640839  91.672  -52.574  57.098  4
640840  91.699  -52.597  57.087  4
640841  91.725  -52.619  57.075  4
640842  91.751  -52.641  57.056  4
640843  91.778  -52.663  57.027  4
640844  91.805  -52.686  56.995  4
640845  91.831  -52.708  56.961  4
640846  91.858  -52.731  56.923  4
640847  91.885  -52.753  56.882  4
640848  91.912  -52.775  56.844  4
640849  91.938  -52.797  56.808  4
640850  91.965  -52.819  56.772  4
640851  91.994  -52.839  56.735  4
640852  92.021  -52.860  56.698  4
640853  92.042  -52.876  56.662  4
640854  92.070  -52.897  56.621  4
640855  92.103  -52.921  56.577  4
640856  92.137  -52.946  56.528  4
640857  92.170  -52.970  56.472  4
640858  92.210  -52.985  56.411  4
640859  92.251  -52.998  56.351  4
640860  92.292  -53.012  56.294  4
640861  92.333  -53.026  56.235  4
640862  92.376  -53.035  56.177  4
640863  92.424  -53.042  56.121  4
640864  92.472  -53.048  56.065  4
640865  92.520  -53.054  56.011  4
640866  92.568  -53.060  55.958  4
640867  92.616  -53.066  55.906  4
640901  93.725  -53.536  54.862  1
640902  93.755  -53.550  54.861  1
640903  93.785  -53.565  54.862  1
640904  93.815  -53.579  54.864  1
640905  93.845  -53.594  54.867  1
640906  93.875  -53.609  54.871  1
640907  93.905  -53.623  54.876  1
640908  93.935  -53.640  54.882  1
640909  93.966  -53.659  54.889  1
640910  93.996  -53.678  54.897  1
640911  94.027  -53.697  54.905  1
640912  94.057  -53.715  54.916  1
640913  94.088  -53.734  54.927  1
640914  94.119  -53.753  54.937  1
640915  94.149  -53.772  54.946  1
640916  94.157  -53.784  54.952  1
640917  94.187  -53.806  54.958  1
640918  94.220  -53.828  54.965  1
640919  94.255  -53.850  54.970  1
640920  94.288  -53.871  54.978  1
640921  94.323  -53.892  54.984  1
640922  94.348  -53.907  54.989  1
640923  94.365  -53.916  54.995  1
640924  94.382  -53.923  54.999  1
640925  94.398  -53.932  55.000  1
640926  94.415  -53.939  55.001  1
640927  94.431  -53.947  55.001  1
640928  94.448  -53.956  55.003  1
640929  94.465  -53.963  55.008  1
640930  94.481  -53.972  55.014  1
640931  94.498  -53.979  55.013  1
640932  94.514  -53.988  55.004  1
640933  94.531  -53.995  54.988  1
640934  94.548  -54.004  54.969  1
640935  94.564  -54.011  54.951  1
640936  94.581  -54.019  54.934  1
640937  94.598  -54.027  54.918  1
640938  94.621  -54.040  54.904  1
640939  94.645  -54.052  54.885  1
640940  94.669  -54.064  54.870  1
640941  94.692  -54.077  54.856  1
640942  94.716  -54.089  54.843  1
640943  94.740  -54.101  54.829  1
640944  94.763  -54.113  54.815  1
640945  94.787  -54.126  54.785  1
640946  94.811  -54.138  54.748  1
640947  94.834  -54.151  54.710  1
640948  94.858  -54.164  54.673  1
640949  94.886  -54.178  54.637  1
640950  94.922  -54.196  54.598  1
640951  94.959  -54.216  54.550  1
640952  94.998  -54.242  54.499  1
640953  95.039  -54.269  54.447  1
640954  95.079  -54.295  54.395  1
640955  95.119  -54.322  54.346  1
640956  95.149  -54.339  54.302  1
640957  95.178  -54.354  54.257  1
640958  95.206  -54.368  54.215  1
640959  95.235  -54.383  54.173  1
640960  95.260  -54.399  54.129  1
640961  95.284  -54.414  54.084  1
640962  95.308  -54.430  54.036  1
640963  95.332  -54.446  53.984  1
640964  95.358  -54.464  53.933  1
640965  95.386  -54.483  53.882  1
640966  95.412  -54.501  53.834  1
640967  95.439  -54.519  53.791  1
640968  95.466  -54.537  53.750  1
640969  95.493  -54.555  53.712  1
640970  95.521  -54.572  53.676  1
640971  95.553  -54.586  53.643  1
640972  95.586  -54.599  53.614  1
640973  95.618  -54.613  53.587  1
640974  95.651  -54.627  53.560  1
640975  95.684  -54.640  53.533  1
640976  95.716  -54.654  53.506  1
640977  95.749  -54.668  53.480  1
640978  95.783  -54.678  53.453  1
640979  95.820  -54.684  53.426  1
640980  95.846  -54.703  53.396  1
640981  95.872  -54.721  53.362  1
640982  95.900  -54.737  53.327  1
640983  95.929  -54.751  53.291  1
640984  95.959  -54.766  53.253  1
640985  95.986  -54.777  53.215  1
640986  96.014  -54.788  53.175  1
640987  96.042  -54.800  53.132  1
640988  96.070  -54.811  53.089  1
640989  96.098  -54.822  53.045  1
640990  96.125  -54.833  52.999  1
640991  96.153  -54.844  52.954  1
640992  96.181  -54.854  52.906  1
640993  96.209  -54.865  52.857  1
640994  96.238  -54.875  52.807  1
640995  96.266  -54.885  52.757  1
640996  96.293  -54.894  52.712  1
640997  96.317  -54.903  52.666  1
640998  96.342  -54.911  52.619  1
640999  96.367  -54.919  52.576  1
641000  96.391  -54.927  52.533  1
641001  96.416  -54.934  52.489  1
641002  96.445  -54.941  52.445  1
641003  96.474  -54.949  52.400  1
641004  96.503  -54.956  52.348  1
641005  96.532  -54.963  52.287  1
641006  96.560  -54.970  52.221  1
641007  96.591  -54.978  52.153  1
641008  96.622  -54.986  52.084  1
641009  96.653  -54.995  52.015  1
641010  96.684  -55.003  51.952  1
641011  96.716  -55.013  51.884  1
641012  96.747  -55.022  51.809  1
641013  96.786  -55.034  51.730  1
641014  96.825  -55.046  51.648  1
641015  96.865  -55.059  51.564  1
641016  96.902  -55.078  51.482  1
641017  96.937  -55.102  51.405  1
641018  96.972  -55.126  51.330  1
641019  97.007  -55.151  51.256  1
641020  97.042  -55.175  51.184  1
641021  97.077  -55.199  51.115  1
641022  97.100  -55.207  51.048  1
641023  97.116  -55.206  50.983  1
641024  97.133  -55.205  50.918  1
641025  97.150  -55.204  50.855  1
641026  97.166  -55.204  50.793  1
641027  97.183  -55.203  50.734  1
641028  97.199  -55.201  50.676  1
641029  97.234  -55.201  50.620  1
641030  97.269  -55.200  50.565  1
641031  97.304  -55.198  50.510  1
641494  90.405  -51.753  56.985  4
641495  90.438  -51.760  56.991  4
641496  90.470  -51.769  56.997  4
641497  90.503  -51.776  57.004  4
641498  90.535  -51.785  57.011  4
641499  90.567  -51.792  57.018  4
641500  90.599  -51.801  57.026  4
641501  90.632  -51.809  57.033  4
641502  90.664  -51.816  57.040  4
641503  90.696  -51.825  57.047  4
641504  90.728  -51.832  57.052  4
641505  90.760  -51.841  57.057  4
641506  90.793  -51.848  57.063  4
641507  90.825  -51.857  57.069  4
641508  90.858  -51.865  57.076  4
641509  90.890  -51.873  57.085  4
641510  90.922  -51.881  57.092  4
641511  90.954  -51.888  57.101  4
641512  90.982  -51.898  57.115  4
641513  90.994  -51.914  57.129  4
641514  91.005  -51.930  57.139  4
641515  91.023  -51.942  57.148  4
641516  91.050  -51.947  57.160  4
641517  91.082  -51.972  57.176  4
641518  91.113  -51.998  57.196  4
641519  91.143  -52.024  57.216  4
641520  91.172  -52.051  57.233  4
641521  91.203  -52.077  57.248  4
641522  91.232  -52.104  57.254  4
641523  91.262  -52.130  57.257  4
641524  91.292  -52.157  57.258  4
641525  91.321  -52.183  57.259  4
641526  91.351  -52.210  57.259  4
641527  91.381  -52.236  57.260  4
641528  91.411  -52.262  57.262  4
641529  91.426  -52.291  57.264  4
641530  91.424  -52.321  57.258  4
641531  91.451  -52.343  57.244  4
641532  91.477  -52.365  57.231  4
641533  91.504  -52.388  57.223  4
641534  91.530  -52.410  57.212  4
641535  91.557  -52.432  57.193  4
641536  91.584  -52.455  57.165  4
641537  91.610  -52.477  57.139  4
641538  91.637  -52.499  57.117  4
641539  91.664  -52.521  57.100  4
641540  91.690  -52.544  57.084  4
641541  91.717  -52.566  57.070  4
641542  91.744  -52.589  57.056  4
641543  91.771  -52.611  57.038  4
641544  91.797  -52.634  57.013  4
641545  91.823  -52.656  56.983  4
641546  91.850  -52.678  56.951  4
641547  91.877  -52.700  56.915  4
641548  91.904  -52.723  56.876  4
641549  91.930  -52.745  56.840  4
641550  91.957  -52.767  56.806  4
641551  91.984  -52.790  56.770  4
641552  92.010  -52.812  56.734  4
641553  92.037  -52.833  56.699  4
641554  92.066  -52.854  56.661  4
641555  92.089  -52.871  56.622  4
641556  92.118  -52.893  56.579  4
641557  92.151  -52.917  56.530  4
641558  92.184  -52.941  56.475  4
641559  92.224  -52.956  56.415  4
641560  92.265  -52.970  56.357  4
641561  92.306  -52.983  56.298  4
641562  92.351  -52.991  56.239  4
641563  92.399  -52.998  56.181  4
641564  92.447  -53.004  56.124  4
641565  92.495  -53.010  56.068  4
641566  92.543  -53.016  56.012  4
641567  92.591  -53.022  55.959  4
641568  92.639  -53.028  55.907  4
641602  93.741  -53.500  54.858  1
641603  93.771  -53.515  54.856  1
641604  93.801  -53.529  54.857  1
641605  93.831  -53.543  54.859  1
641606  93.861  -53.559  54.862  1
641607  93.892  -53.577  54.866  1
641608  93.922  -53.596  54.871  1
641609  93.953  -53.615  54.876  1
641610  93.983  -53.634  54.883  1
641611  94.014  -53.653  54.891  1
641612  94.044  -53.672  54.901  1
641613  94.075  -53.690  54.912  1
641614  94.105  -53.709  54.922  1
641615  94.136  -53.728  54.932  1
641616  94.167  -53.747  54.940  1
641617  94.167  -53.756  54.945  1
641618  94.197  -53.778  54.950  1
641619  94.227  -53.800  54.958  1
641620  94.261  -53.822  54.962  1
641621  94.295  -53.843  54.969  1
641622  94.329  -53.864  54.975  1
641623  94.360  -53.884  54.981  1
641624  94.377  -53.891  54.988  1
641625  94.394  -53.900  54.993  1
641626  94.410  -53.907  54.995  1
641627  94.427  -53.916  54.997  1
641628  94.443  -53.923  54.997  1
641629  94.460  -53.932  54.998  1
641630  94.477  -53.939  55.002  1
641631  94.493  -53.947  55.005  1
641632  94.510  -53.956  55.003  1
641633  94.527  -53.963  54.995  1
641634  94.543  -53.972  54.984  1
641635  94.560  -53.979  54.971  1
641636  94.576  -53.988  54.957  1
641637  94.597  -53.997  54.942  1
641638  94.621  -54.010  54.928  1
641639  94.644  -54.022  54.914  1
641640  94.668  -54.035  54.896  1
641641  94.692  -54.048  54.881  1
641642  94.715  -54.060  54.870  1
641643  94.739  -54.072  54.860  1
641644  94.762  -54.084  54.849  1
641645  94.786  -54.097  54.836  1
641646  94.810  -54.109  54.805  1
641647  94.833  -54.121  54.768  1
641648  94.857  -54.134  54.730  1
641649  94.881  -54.146  54.692  1
641650  94.904  -54.158  54.654  1
641651  94.938  -54.176  54.613  1
641652  94.974  -54.195  54.563  1
641653  95.011  -54.214  54.511  1
641654  95.051  -54.241  54.458  1
641655  95.092  -54.267  54.407  1
641656  95.131  -54.294  54.359  1
641657  95.165  -54.314  54.316  1
641658  95.193  -54.328  54.271  1
641659  95.222  -54.342  54.228  1
641660  95.249  -54.358  54.183  1
641661  95.273  -54.373  54.137  1
641662  95.297  -54.389  54.089  1
641663  95.320  -54.405  54.039  1
641664  95.344  -54.421  53.987  1
641665  95.368  -54.436  53.936  1
641666  95.395  -54.455  53.888  1
641667  95.421  -54.473  53.842  1
641668  95.448  -54.491  53.801  1
641669  95.475  -54.509  53.764  1
641670  95.502  -54.527  53.729  1
641671  95.529  -54.546  53.695  1
641672  95.562  -54.559  53.664  1
641673  95.594  -54.572  53.635  1
641674  95.627  -54.586  53.608  1
641675  95.659  -54.599  53.582  1
641676  95.692  -54.613  53.556  1
641677  95.725  -54.627  53.529  1
641678  95.759  -54.637  53.502  1
641679  95.796  -54.643  53.475  1
641680  95.829  -54.654  53.449  1
641681  95.854  -54.672  53.420  1
641682  95.880  -54.690  53.388  1
641683  95.906  -54.709  53.355  1
641684  95.936  -54.723  53.321  1
641685  95.965  -54.738  53.283  1
641686  95.994  -54.753  53.242  1
641687  96.023  -54.767  53.200  1
641688  96.051  -54.778  53.156  1
641689  96.079  -54.790  53.111  1
641690  96.107  -54.800  53.066  1
641691  96.134  -54.812  53.020  1
641692  96.162  -54.823  52.975  1
641693  96.190  -54.834  52.929  1
641694  96.219  -54.844  52.881  1
641695  96.247  -54.854  52.834  1
641696  96.275  -54.864  52.787  1
641697  96.300  -54.872  52.743  1
641698  96.324  -54.881  52.699  1
641699  96.348  -54.888  52.653  1
641700  96.373  -54.897  52.608  1
641701  96.398  -54.905  52.565  1
641702  96.424  -54.913  52.521  1
641703  96.453  -54.919  52.476  1
641704  96.482  -54.926  52.429  1
641705  96.511  -54.934  52.377  1
641706  96.539  -54.941  52.320  1
641707  96.568  -54.947  52.259  1
641708  96.597  -54.955  52.196  1
641709  96.628  -54.963  52.130  1
641710  96.660  -54.972  52.061  1
641711  96.691  -54.981  52.000  1
641712  96.722  -54.990  51.938  1
641713  96.754  -54.998  51.868  1
641714  96.787  -55.008  51.792  1
641715  96.826  -55.020  51.710  1
641716  96.866  -55.033  51.626  1
641717  96.905  -55.045  51.542  1
641718  96.943  -55.064  51.459  1
641719  96.977  -55.088  51.381  1
641720  97.013  -55.113  51.306  1
641721  97.047  -55.137  51.234  1
641722  97.083  -55.162  51.163  1
641723  97.114  -55.182  51.094  1
641724  97.131  -55.181  51.028  1
641725  97.148  -55.180  50.962  1
641726  97.164  -55.179  50.897  1
641727  97.181  -55.178  50.834  1
641728  97.197  -55.177  50.771  1
641729  97.215  -55.176  50.712  1
641730  97.250  -55.176  50.655  1
641731  97.285  -55.175  50.598  1
641732  97.320  -55.173  50.542  1
641733  97.355  -55.173  50.487  1
642195  90.426  -51.719  56.974  4
642196  90.458  -51.727  56.979  4
642197  90.490  -51.735  56.985  4
642198  90.522  -51.743  56.992  4
642199  90.554  -51.751  56.998  4
642200  90.587  -51.759  57.005  4
642201  90.619  -51.767  57.012  4
642202  90.652  -51.776  57.018  4
642203  90.684  -51.783  57.026  4
642204  90.716  -51.791  57.032  4
642205  90.748  -51.799  57.039  4
642206  90.781  -51.807  57.044  4
642207  90.813  -51.815  57.050  4
642208  90.845  -51.823  57.057  4
642209  90.877  -51.832  57.064  4
642210  90.909  -51.839  57.073  4
642211  90.942  -51.848  57.082  4
642212  90.974  -51.855  57.092  4
642213  90.987  -51.871  57.106  4
642214  90.999  -51.886  57.118  4
642215  91.010  -51.902  57.128  4
642216  91.026  -51.915  57.137  4
642217  91.054  -51.920  57.147  4
642218  91.086  -51.945  57.161  4
642219  91.118  -51.970  57.178  4
642220  91.150  -51.996  57.196  4
642221  91.182  -52.022  57.212  4
642222  91.212  -52.048  57.225  4
642223  91.241  -52.075  57.230  4
642224  91.271  -52.101  57.234  4
642225  91.301  -52.127  57.237  4
642226  91.330  -52.154  57.239  4
642227  91.361  -52.180  57.239  4
642228  91.390  -52.207  57.241  4
642229  91.420  -52.233  57.244  4
642230  91.449  -52.260  57.245  4
642231  91.443  -52.291  57.239  4
642232  91.469  -52.313  57.227  4
642233  91.496  -52.335  57.214  4
642234  91.523  -52.358  57.205  4
642235  91.549  -52.380  57.195  4
642236  91.576  -52.402  57.177  4
642237  91.603  -52.424  57.154  4
642238  91.629  -52.447  57.129  4
642239  91.656  -52.469  57.106  4
642240  91.682  -52.492  57.087  4
642241  91.709  -52.514  57.068  4
642242  91.736  -52.537  57.052  4
642243  91.763  -52.559  57.036  4
642244  91.789  -52.581  57.017  4
642245  91.816  -52.603  56.995  4
642246  91.843  -52.626  56.969  4
642247  91.869  -52.648  56.939  4
642248  91.895  -52.670  56.904  4
642249  91.922  -52.693  56.869  4
642250  91.949  -52.715  56.834  4
642251  91.976  -52.738  56.801  4
642252  92.002  -52.760  56.767  4
642253  92.029  -52.782  56.732  4
642254  92.056  -52.804  56.697  4
642255  92.082  -52.827  56.660  4
642256  92.110  -52.847  56.621  4
642257  92.135  -52.866  56.577  4
642258  92.165  -52.889  56.529  4
642259  92.198  -52.913  56.475  4
642260  92.238  -52.927  56.417  4
642261  92.279  -52.941  56.360  4
642262  92.326  -52.948  56.301  4
642263  92.374  -52.954  56.242  4
642264  92.422  -52.960  56.184  4
642265  92.470  -52.966  56.126  4
642266  92.518  -52.972  56.069  4
642267  92.566  -52.978  56.014  4
642268  92.614  -52.984  55.960  4
642269  92.661  -52.990  55.908  4
642270  92.710  -52.996  55.858  4
642304  93.787  -53.479  54.853  1
642305  93.818  -53.496  54.853  1
642306  93.848  -53.515  54.855  1
642307  93.878  -53.534  54.857  1
642308  93.909  -53.552  54.861  1
642309  93.939  -53.571  54.866  1
642310  93.970  -53.590  54.871  1
642311  94.000  -53.609  54.878  1
642312  94.031  -53.628  54.886  1
642313  94.062  -53.646  54.896  1
642314  94.092  -53.665  54.905  1
642315  94.123  -53.684  54.916  1
642316  94.153  -53.703  54.925  1
642317  94.184  -53.721  54.933  1
642318  94.192  -53.733  54.938  1
642319  94.207  -53.750  54.943  1
642320  94.238  -53.772  54.950  1
642321  94.268  -53.794  54.955  1
642322  94.302  -53.815  54.961  1
642323  94.336  -53.836  54.967  1
642324  94.370  -53.858  54.974  1
642325  94.389  -53.868  54.982  1
642326  94.406  -53.875  54.988  1
642327  94.422  -53.884  54.992  1
642328  94.439  -53.891  54.995  1
642329  94.456  -53.900  54.996  1
642330  94.472  -53.907  54.998  1
642331  94.489  -53.916  55.001  1
642332  94.505  -53.923  55.004  1
642333  94.522  -53.932  55.004  1
642334  94.539  -53.939  55.000  1
642335  94.555  -53.947  54.991  1
642336  94.572  -53.956  54.981  1
642337  94.596  -53.969  54.969  1
642338  94.620  -53.981  54.957  1
642339  94.643  -53.993  54.944  1
642340  94.667  -54.005  54.928  1
642341  94.691  -54.018  54.908  1
642342  94.714  -54.030  54.894  1
642343  94.738  -54.042  54.885  1
642344  94.762  -54.055  54.877  1
642345  94.785  -54.067  54.868  1
642346  94.809  -54.079  54.852  1
642347  94.833  -54.091  54.822  1
642348  94.856  -54.104  54.787  1
642349  94.880  -54.117  54.751  1
642350  94.904  -54.129  54.714  1
642351  94.927  -54.142  54.674  1
642352  94.954  -54.155  54.629  1
642353  94.990  -54.173  54.577  1
642354  95.027  -54.192  54.524  1
642355  95.063  -54.213  54.471  1
642356  95.104  -54.239  54.420  1
642357  95.144  -54.266  54.372  1
642358  95.180  -54.288  54.330  1
642359  95.208  -54.302  54.285  1
642360  95.237  -54.317  54.239  1
642361  95.262  -54.333  54.191  1
642362  95.285  -54.348  54.143  1
642363  95.309  -54.364  54.093  1
642364  95.333  -54.380  54.042  1
642365  95.357  -54.396  53.990  1
642366  95.381  -54.412  53.940  1
642367  95.404  -54.427  53.894  1
642368  95.430  -54.446  53.853  1
642369  95.457  -54.464  53.816  1
642370  95.484  -54.482  53.782  1
642371  95.511  -54.500  53.749  1
642372  95.538  -54.518  53.717  1
642373  95.570  -54.532  53.686  1
642374  95.603  -54.546  53.659  1
642375  95.635  -54.559  53.633  1
642376  95.668  -54.572  53.607  1
642377  95.700  -54.586  53.581  1
642378  95.736  -54.596  53.554  1
642379  95.772  -54.602  53.527  1
642380  95.809  -54.610  53.501  1
642381  95.838  -54.624  53.474  1
642382  95.864  -54.643  53.447  1
642383  95.889  -54.661  53.418  1
642384  95.914  -54.679  53.387  1
642385  95.942  -54.696  53.353  1
642386  95.971  -54.710  53.313  1
642387  96.001  -54.725  53.270  1
642388  96.030  -54.740  53.225  1
642389  96.059  -54.755  53.179  1
642390  96.088  -54.768  53.134  1
642391  96.116  -54.779  53.088  1
642392  96.144  -54.790  53.041  1
642393  96.171  -54.802  52.997  1
642394  96.199  -54.812  52.951  1
642395  96.228  -54.823  52.906  1
642396  96.256  -54.833  52.861  1
642397  96.282  -54.842  52.816  1
642398  96.307  -54.850  52.773  1
642399  96.331  -54.859  52.730  1
642400  96.356  -54.866  52.684  1
642401  96.380  -54.875  52.639  1
642402  96.404  -54.882  52.594  1
642403  96.432  -54.890  52.550  1
642404  96.460  -54.897  52.504  1
642405  96.489  -54.904  52.455  1
642406  96.518  -54.911  52.403  1
642407  96.547  -54.918  52.349  1
642408  96.576  -54.925  52.292  1
642409  96.604  -54.932  52.233  1
642410  96.636  -54.941  52.170  1
642411  96.667  -54.950  52.101  1
642412  96.698  -54.958  52.039  1
642413  96.729  -54.967  51.978  1
642414  96.760  -54.975  51.911  1
642415  96.792  -54.985  51.838  1
642416  96.827  -54.995  51.759  1
642417  96.867  -55.007  51.679  1
642418  96.906  -55.020  51.598  1
642419  96.946  -55.032  51.515  1
642420  96.983  -55.051  51.437  1
642421  97.018  -55.075  51.362  1
642422  97.053  -55.100  51.287  1
642423  97.088  -55.124  51.214  1
642424  97.123  -55.148  51.144  1
642425  97.145  -55.156  51.076  1
642426  97.162  -55.155  51.008  1
642427  97.178  -55.154  50.941  1
642428  97.195  -55.153  50.876  1
642429  97.212  -55.152  50.812  1
642430  97.231  -55.151  50.751  1
642431  97.266  -55.151  50.692  1
642432  97.301  -55.149  50.633  1
642433  97.336  -55.148  50.575  1
642434  97.371  -55.148  50.518  1
642435  97.406  -55.146  50.463  1
642897  90.478  -51.694  56.967  4
642898  90.510  -51.702  56.973  4
642899  90.542  -51.710  56.979  4
642900  90.575  -51.718  56.985  4
642901  90.607  -51.725  56.991  4
642902  90.639  -51.734  56.998  4
642903  90.671  -51.742  57.005  4
642904  90.704  -51.750  57.011  4
642905  90.736  -51.758  57.018  4
642906  90.768  -51.766  57.024  4
642907  90.801  -51.774  57.030  4
642908  90.833  -51.782  57.037  4
642909  90.865  -51.790  57.044  4
642910  90.897  -51.798  57.052  4
642911  90.930  -51.806  57.061  4
642912  90.962  -51.814  57.071  4
642913  90.980  -51.827  57.081  4
642914  90.992  -51.843  57.093  4
642915  91.004  -51.859  57.106  4
642916  91.016  -51.875  57.116  4
642917  91.030  -51.888  57.126  4
642918  91.058  -51.894  57.135  4
642919  91.089  -51.917  57.147  4
642920  91.121  -51.943  57.163  4
642921  91.153  -51.969  57.178  4
642922  91.185  -51.995  57.192  4
642923  91.217  -52.020  57.205  4
642924  91.249  -52.046  57.209  4
642925  91.280  -52.072  57.213  4
642926  91.310  -52.098  57.217  4
642927  91.340  -52.125  57.220  4
642928  91.370  -52.152  57.221  4
642929  91.399  -52.178  57.223  4
642930  91.429  -52.205  57.225  4
642931  91.459  -52.230  57.227  4
642932  91.461  -52.261  57.221  4
642933  91.488  -52.283  57.210  4
642934  91.515  -52.305  57.197  4
642935  91.541  -52.327  57.187  4
642936  91.568  -52.350  57.177  4
642937  91.595  -52.372  57.161  4
642938  91.622  -52.395  57.142  4
642939  91.648  -52.417  57.120  4
642940  91.675  -52.440  57.098  4
642941  91.702  -52.462  57.078  4
642942  91.728  -52.484  57.057  4
642943  91.754  -52.506  57.038  4
642944  91.781  -52.529  57.020  4
642945  91.808  -52.551  56.999  4
642946  91.835  -52.573  56.977  4
642947  91.861  -52.596  56.953  4
642948  91.888  -52.618  56.926  4
642949  91.915  -52.641  56.893  4
642950  91.941  -52.662  56.860  4
642951  91.968  -52.685  56.828  4
642952  91.994  -52.707  56.796  4
642953  92.021  -52.730  56.763  4
642954  92.048  -52.752  56.729  4
642955  92.074  -52.775  56.694  4
642956  92.101  -52.797  56.657  4
642957  92.128  -52.819  56.618  4
642958  92.154  -52.841  56.575  4
642959  92.181  -52.862  56.527  4
642960  92.212  -52.885  56.474  4
642961  92.253  -52.898  56.417  4
642962  92.301  -52.904  56.360  4
642963  92.349  -52.910  56.302  4
642964  92.397  -52.916  56.243  4
642965  92.445  -52.923  56.186  4
642966  92.493  -52.929  56.128  4
642967  92.541  -52.934  56.070  4
642968  92.588  -52.940  56.015  4
642969  92.637  -52.946  55.961  4
642970  92.685  -52.952  55.908  4
642971  92.732  -52.958  55.858  4
643005  93.804  -53.452  54.850  1
643006  93.835  -53.471  54.849  1
643007  93.865  -53.490  54.851  1
643008  93.896  -53.509  54.854  1
643009  93.926  -53.527  54.857  1
643010  93.957  -53.546  54.862  1
643011  93.987  -53.565  54.867  1
643012  94.018  -53.584  54.874  1
643013  94.048  -53.603  54.882  1
643014  94.079  -53.621  54.891  1
643015  94.109  -53.640  54.900  1
643016  94.140  -53.659  54.910  1
643017  94.171  -53.677  54.919  1
643018  94.201  -53.696  54.925  1
643019  94.218  -53.710  54.932  1
643020  94.217  -53.721  54.938  1
643021  94.248  -53.743  54.943  1
643022  94.277  -53.765  54.949  1
643023  94.309  -53.787  54.955  1
643024  94.343  -53.808  54.961  1
643025  94.377  -53.830  54.968  1
643026  94.401  -53.844  54.977  1
643027  94.418  -53.852  54.984  1
643028  94.434  -53.860  54.990  1
643029  94.451  -53.868  54.994  1
643030  94.468  -53.875  54.997  1
643031  94.484  -53.884  55.000  1
643032  94.501  -53.891  55.003  1
643033  94.518  -53.900  55.007  1
643034  94.534  -53.907  55.009  1
643035  94.551  -53.916  55.007  1
643036  94.572  -53.926  55.001  1
643037  94.596  -53.939  54.993  1
643038  94.619  -53.951  54.985  1
643039  94.643  -53.963  54.974  1
643040  94.667  -53.976  54.959  1
643041  94.690  -53.988  54.941  1
643042  94.714  -54.001  54.920  1
643043  94.738  -54.013  54.904  1
643044  94.761  -54.026  54.894  1
643045  94.785  -54.038  54.888  1
643046  94.809  -54.050  54.881  1
643047  94.832  -54.062  54.864  1
643048  94.856  -54.075  54.837  1
643049  94.880  -54.087  54.806  1
643050  94.903  -54.099  54.774  1
643051  94.927  -54.112  54.738  1
643052  94.951  -54.124  54.693  1
643053  94.974  -54.136  54.646  1
643054  95.006  -54.153  54.591  1
643055  95.042  -54.172  54.536  1
643056  95.079  -54.191  54.483  1
643057  95.116  -54.211  54.433  1
643058  95.156  -54.238  54.388  1
643059  95.195  -54.262  54.345  1
643060  95.223  -54.277  54.298  1
643061  95.251  -54.292  54.249  1
643062  95.274  -54.308  54.199  1
643063  95.298  -54.323  54.148  1
643064  95.322  -54.339  54.097  1
643065  95.346  -54.355  54.046  1
643066  95.370  -54.371  53.995  1
643067  95.393  -54.387  53.946  1
643068  95.417  -54.403  53.903  1
643069  95.441  -54.419  53.866  1
643070  95.466  -54.436  53.833  1
643071  95.493  -54.454  53.802  1
643072  95.520  -54.472  53.770  1
643073  95.547  -54.490  53.738  1
643074  95.579  -54.505  53.709  1
643075  95.611  -54.518  53.683  1
643076  95.643  -54.532  53.659  1
643077  95.676  -54.546  53.634  1
643078  95.711  -54.555  53.608  1
643079  95.748  -54.562  53.582  1
643080  95.784  -54.569  53.556  1
643081  95.821  -54.576  53.530  1
643082  95.846  -54.594  53.505  1
643083  95.872  -54.612  53.480  1
643084  95.897  -54.630  53.452  1
643085  95.923  -54.649  53.420  1
643086  95.949  -54.667  53.384  1
643087  95.977  -54.683  53.344  1
643088  96.007  -54.697  53.300  1
643089  96.036  -54.712  53.253  1
643090  96.065  -54.728  53.206  1
643091  96.095  -54.742  53.159  1
643092  96.124  -54.757  53.111  1
643093  96.153  -54.769  53.065  1
643094  96.180  -54.781  53.019  1
643095  96.208  -54.792  52.974  1
643096  96.236  -54.802  52.931  1
643097  96.264  -54.812  52.888  1
643098  96.289  -54.820  52.845  1
643099  96.313  -54.828  52.802  1
643100  96.338  -54.836  52.758  1
643101  96.362  -54.844  52.713  1
643102  96.387  -54.853  52.668  1
643103  96.411  -54.860  52.622  1
643104  96.439  -54.868  52.576  1
643105  96.468  -54.875  52.529  1
643106  96.497  -54.881  52.477  1
643107  96.526  -54.889  52.426  1
643108  96.554  -54.896  52.373  1
643109  96.583  -54.903  52.320  1
643110  96.612  -54.909  52.264  1
643111  96.642  -54.918  52.204  1
643112  96.673  -54.926  52.136  1
643113  96.704  -54.935  52.072  1
643114  96.736  -54.944  52.010  1
643115  96.767  -54.953  51.945  1
643116  96.799  -54.962  51.876  1
643117  96.830  -54.970  51.803  1
643118  96.867  -54.981  51.726  1
643119  96.907  -54.994  51.649  1
643120  96.946  -55.007  51.569  1
643121  96.986  -55.019  51.495  1
643122  97.023  -55.038  51.421  1
643123  97.058  -55.063  51.345  1
643124  97.093  -55.087  51.270  1
643125  97.128  -55.111  51.197  1
643126  97.160  -55.130  51.126  1
643127  97.176  -55.129  51.057  1
643128  97.193  -55.129  50.989  1
643129  97.210  -55.128  50.922  1
643130  97.226  -55.127  50.856  1
643131  97.247  -55.126  50.793  1
643132  97.282  -55.126  50.732  1
643133  97.317  -55.124  50.672  1
643134  97.352  -55.123  50.612  1
643135  97.387  -55.122  50.554  1
643136  97.415  -55.121  50.497  1
643137  97.438  -55.120  50.443  1
643599  90.530  -51.669  56.961  4
643600  90.563  -51.676  56.966  4
643601  90.595  -51.685  56.972  4
643602  90.627  -51.692  56.978  4
643603  90.659  -51.700  56.984  4
643604  90.691  -51.708  56.991  4
643605  90.724  -51.716  56.997  4
643606  90.756  -51.725  57.004  4
643607  90.788  -51.732  57.010  4
643608  90.821  -51.741  57.017  4
643609  90.853  -51.748  57.023  4
643610  90.885  -51.757  57.030  4
643611  90.918  -51.764  57.039  4
643612  90.950  -51.772  57.049  4
643613  90.973  -51.784  57.058  4
643614  90.986  -51.800  57.068  4
643615  90.997  -51.815  57.079  4
643616  91.009  -51.831  57.091  4
643617  91.021  -51.847  57.103  4
643618  91.033  -51.862  57.114  4
643619  91.061  -51.867  57.124  4
643620  91.092  -51.891  57.136  4
643621  91.124  -51.916  57.150  4
643622  91.156  -51.942  57.164  4
643623  91.188  -51.967  57.177  4
643624  91.221  -51.993  57.189  4
643625  91.252  -52.019  57.193  4
643626  91.285  -52.045  57.198  4
643627  91.316  -52.070  57.202  4
643628  91.349  -52.096  57.205  4
643629  91.379  -52.123  57.207  4
643630  91.409  -52.148  57.208  4
643631  91.438  -52.175  57.209  4
643632  91.468  -52.202  57.208  4
643633  91.481  -52.230  57.204  4
643634  91.507  -52.253  57.195  4
643635  91.533  -52.275  57.182  4
643636  91.560  -52.298  57.170  4
643637  91.587  -52.320  57.159  4
643638  91.613  -52.343  57.145  4
643639  91.640  -52.365  57.129  4
643640  91.667  -52.387  57.111  4
643641  91.694  -52.409  57.091  4
643642  91.720  -52.432  57.070  4
643643  91.747  -52.454  57.048  4
643644  91.774  -52.476  57.026  4
643645  91.800  -52.499  57.007  4
643646  91.826  -52.521  56.986  4
643647  91.853  -52.543  56.964  4
643648  91.880  -52.565  56.940  4
643649  91.907  -52.588  56.914  4
643650  91.933  -52.610  56.883  4
643651  91.960  -52.633  56.852  4
643652  91.987  -52.655  56.821  4
643653  92.013  -52.678  56.790  4
643654  92.040  -52.700  56.758  4
643655  92.067  -52.722  56.724  4
643656  92.093  -52.744  56.689  4
643657  92.120  -52.766  56.652  4
643658  92.146  -52.789  56.614  4
643659  92.173  -52.811  56.572  4
643660  92.201  -52.832  56.525  4
643661  92.228  -52.853  56.472  4
643662  92.276  -52.860  56.416  4
643663  92.323  -52.866  56.359  4
643664  92.372  -52.872  56.301  4
643665  92.420  -52.879  56.244  4
643666  92.467  -52.885  56.186  4
643667  92.515  -52.891  56.129  4
643668  92.563  -52.897  56.071  4
643669  92.612  -52.903  56.016  4
643670  92.659  -52.908  55.961  4
643671  92.707  -52.914  55.909  4
643672  92.755  -52.920  55.858  4
643706  93.822  -53.427  54.847  1
643707  93.852  -53.446  54.847  1
643708  93.883  -53.465  54.848  1
643709  93.913  -53.483  54.850  1
643710  93.943  -53.502  54.853  1
643711  93.974  -53.521  54.858  1
643712  94.004  -53.540  54.863  1
643713  94.035  -53.559  54.870  1
643714  94.066  -53.577  54.877  1
643715  94.096  -53.596  54.885  1
643716  94.127  -53.615  54.894  1
643717  94.157  -53.633  54.904  1
643718  94.188  -53.652  54.912  1
643719  94.218  -53.671  54.919  1
643720  94.245  -53.688  54.926  1
643721  94.227  -53.692  54.932  1
643722  94.257  -53.714  54.938  1
643723  94.287  -53.736  54.945  1
643724  94.318  -53.759  54.951  1
643725  94.350  -53.780  54.957  1
643726  94.384  -53.802  54.964  1
643727  94.413  -53.819  54.973  1
643728  94.430  -53.828  54.981  1
643729  94.447  -53.836  54.987  1
643730  94.463  -53.844  54.993  1
643731  94.480  -53.852  54.998  1
643732  94.496  -53.860  55.002  1
643733  94.513  -53.868  55.007  1
643734  94.530  -53.875  55.015  1
643735  94.548  -53.885  55.018  1
643736  94.571  -53.897  55.015  1
643737  94.595  -53.910  55.011  1
643738  94.619  -53.922  55.007  1
643739  94.642  -53.934  55.002  1
643740  94.666  -53.946  54.991  1
643741  94.690  -53.959  54.974  1
643742  94.713  -53.971  54.954  1
643743  94.737  -53.983  54.930  1
643744  94.761  -53.996  54.911  1
643745  94.784  -54.008  54.901  1
643746  94.808  -54.020  54.896  1
643747  94.831  -54.032  54.889  1
643748  94.855  -54.045  54.874  1
643749  94.879  -54.057  54.852  1
643750  94.902  -54.070  54.825  1
643751  94.926  -54.082  54.794  1
643752  94.950  -54.095  54.757  1
643753  94.973  -54.107  54.711  1
643754  94.997  -54.119  54.660  1
643755  95.022  -54.132  54.603  1
643756  95.058  -54.151  54.547  1
643757  95.095  -54.170  54.495  1
643758  95.131  -54.189  54.448  1
643759  95.169  -54.209  54.403  1
643760  95.208  -54.236  54.357  1
643761  95.238  -54.251  54.308  1
643762  95.264  -54.267  54.256  1
643763  95.287  -54.283  54.203  1
643764  95.311  -54.298  54.151  1
643765  95.335  -54.314  54.100  1
643766  95.358  -54.330  54.050  1
643767  95.382  -54.346  54.000  1
643768  95.406  -54.362  53.956  1
643769  95.429  -54.378  53.918  1
643770  95.454  -54.394  53.883  1
643771  95.477  -54.410  53.852  1
643772  95.502  -54.427  53.822  1
643773  95.529  -54.445  53.791  1
643774  95.556  -54.463  53.760  1
643775  95.587  -54.477  53.733  1
643776  95.619  -54.491  53.708  1
643777  95.652  -54.505  53.685  1
643778  95.687  -54.514  53.661  1
643779  95.724  -54.521  53.636  1
643780  95.760  -54.528  53.611  1
643781  95.797  -54.535  53.586  1
643782  95.830  -54.546  53.561  1
643783  95.855  -54.565  53.537  1
643784  95.881  -54.583  53.512  1
643785  95.906  -54.601  53.485  1
643786  95.932  -54.619  53.452  1
643787  95.957  -54.637  53.416  1
643788  95.983  -54.655  53.375  1
643789  96.013  -54.670  53.330  1
643790  96.042  -54.684  53.282  1
643791  96.072  -54.699  53.233  1
643792  96.101  -54.715  53.185  1
643793  96.130  -54.729  53.136  1
643794  96.160  -54.744  53.089  1
643795  96.189  -54.759  53.044  1
643796  96.218  -54.771  53.000  1
643797  96.245  -54.781  52.957  1
643798  96.271  -54.790  52.915  1
643799  96.296  -54.798  52.873  1
643800  96.320  -54.806  52.829  1
643801  96.344  -54.814  52.784  1
643802  96.369  -54.822  52.738  1
643803  96.393  -54.830  52.691  1
643804  96.418  -54.838  52.643  1
643805  96.447  -54.845  52.595  1
643806  96.475  -54.853  52.547  1
643807  96.504  -54.859  52.493  1
643808  96.533  -54.866  52.439  1
643809  96.562  -54.873  52.387  1
643810  96.591  -54.881  52.336  1
643811  96.619  -54.887  52.281  1
643812  96.649  -54.895  52.222  1
643813  96.680  -54.903  52.158  1
643814  96.712  -54.913  52.094  1
643815  96.743  -54.921  52.031  1
643816  96.774  -54.930  51.969  1
643817  96.805  -54.938  51.906  1
643818  96.836  -54.947  51.840  1
643819  96.868  -54.956  51.766  1
643820  96.907  -54.969  51.692  1
643821  96.947  -54.981  51.621  1
643822  96.986  -54.994  51.554  1
643823  97.026  -55.006  51.484  1
643824  97.064  -55.025  51.408  1
643825  97.098  -55.049  51.329  1
643826  97.134  -55.073  51.253  1
643827  97.168  -55.097  51.179  1
643828  97.190  -55.104  51.109  1
643829  97.207  -55.104  51.039  1
643830  97.224  -55.103  50.970  1
643831  97.240  -55.102  50.903  1
643832  97.263  -55.101  50.838  1
643833  97.298  -55.100  50.774  1
643834  97.333  -55.099  50.713  1
643835  97.368  -55.098  50.651  1
643836  97.400  -55.097  50.592  1
643837  97.423  -55.096  50.533  1
643838  97.446  -55.095  50.477  1
644302  90.615  -51.651  56.959  4
644303  90.647  -51.659  56.965  4
644304  90.679  -51.667  56.970  4
644305  90.712  -51.675  56.976  4
644306  90.744  -51.683  56.983  4
644307  90.776  -51.691  56.990  4
644308  90.808  -51.699  56.997  4
644309  90.840  -51.707  57.003  4
644310  90.873  -51.715  57.010  4
644311  90.905  -51.723  57.017  4
644312  90.938  -51.731  57.026  4
644313  90.967  -51.740  57.036  4
644314  90.978  -51.756  57.045  4
644315  90.991  -51.772  57.055  4
644316  91.002  -51.788  57.066  4
644317  91.014  -51.804  57.077  4
644318  91.026  -51.819  57.090  4
644319  91.037  -51.835  57.102  4
644320  91.064  -51.841  57.115  4
644321  91.096  -51.863  57.128  4
644322  91.128  -51.889  57.140  4
644323  91.160  -51.915  57.152  4
644324  91.191  -51.940  57.164  4
644325  91.224  -51.966  57.176  4
644326  91.256  -51.992  57.182  4
644327  91.288  -52.017  57.186  4
644328  91.320  -52.043  57.189  4
644329  91.352  -52.069  57.192  4
644330  91.384  -52.095  57.195  4
644331  91.416  -52.120  57.195  4
644332  91.448  -52.146  57.194  4
644333  91.477  -52.173  57.193  4
644334  91.502  -52.200  57.189  4
644335  91.526  -52.223  57.180  4
644336  91.553  -52.246  57.168  4
644337  91.579  -52.268  57.156  4
644338  91.606  -52.290  57.143  4
644339  91.632  -52.312  57.129  4
644340  91.659  -52.335  57.115  4
644341  91.685  -52.357  57.100  4
644342  91.712  -52.379  57.083  4
644343  91.739  -52.402  57.063  4
644344  91.766  -52.424  57.040  4
644345  91.792  -52.446  57.017  4
644346  91.819  -52.468  56.997  4
644347  91.846  -52.490  56.975  4
644348  91.873  -52.510  56.953  4
644349  91.900  -52.531  56.929  4
644350  91.928  -52.552  56.903  4
644351  91.955  -52.572  56.873  4
644352  91.983  -52.593  56.843  4
644353  92.010  -52.613  56.813  4
644354  92.037  -52.634  56.783  4
644355  92.065  -52.655  56.751  4
644356  92.092  -52.675  56.718  4
644357  92.119  -52.696  56.683  4
644358  92.146  -52.716  56.646  4
644359  92.174  -52.737  56.608  4
644360  92.201  -52.758  56.566  4
644361  92.228  -52.778  56.520  4
644362  92.256  -52.799  56.468  4
644363  92.298  -52.822  56.413  4
644364  92.347  -52.828  56.357  4
644365  92.394  -52.835  56.300  4
644366  92.442  -52.841  56.243  4
644367  92.490  -52.847  56.186  4
644368  92.538  -52.853  56.129  4
644369  92.586  -52.859  56.072  4
644370  92.634  -52.865  56.017  4
644371  92.682  -52.871  55.962  4
644372  92.730  -52.877  55.909  4
644373  92.778  -52.882  55.859  4
644374  92.826  -52.888  55.809  4
644408  93.869  -53.421  54.845  1
644409  93.900  -53.440  54.845  1
644410  93.930  -53.458  54.847  1
644411  93.961  -53.477  54.851  1
644412  93.991  -53.496  54.856  1
644413  94.022  -53.515  54.860  1
644414  94.052  -53.533  54.866  1
644415  94.083  -53.552  54.874  1
644416  94.113  -53.571  54.881  1
644417  94.144  -53.590  54.890  1
644418  94.175  -53.608  54.898  1
644419  94.205  -53.627  54.906  1
644420  94.236  -53.646  54.914  1
644421  94.266  -53.664  54.922  1
644422  94.247  -53.667  54.928  1
644423  94.267  -53.686  54.935  1
644424  94.297  -53.708  54.941  1
644425  94.328  -53.730  54.947  1
644426  94.358  -53.752  54.954  1
644427  94.390  -53.774  54.961  1
644428  94.424  -53.795  54.969  1
644429  94.442  -53.803  54.977  1
644430  94.459  -53.812  54.985  1
644431  94.475  -53.819  54.992  1
644432  94.492  -53.828  54.999  1
644433  94.508  -53.836  55.004  1
644434  94.525  -53.844  55.009  1
644435  94.547  -53.855  55.015  1
644436  94.570  -53.867  55.019  1
644437  94.594  -53.880  55.019  1
644438  94.618  -53.892  55.019  1
644439  94.641  -53.904  55.017  1
644440  94.665  -53.916  55.011  1
644441  94.689  -53.929  55.000  1
644442  94.712  -53.941  54.984  1
644443  94.736  -53.954  54.961  1
644444  94.760  -53.966  54.936  1
644445  94.783  -53.979  54.915  1
644446  94.807  -53.991  54.905  1
644447  94.831  -54.003  54.899  1
644448  94.854  -54.016  54.892  1
644449  94.878  -54.028  54.881  1
644450  94.902  -54.040  54.867  1
644451  94.925  -54.053  54.845  1
644452  94.949  -54.065  54.813  1
644453  94.973  -54.077  54.772  1
644454  94.996  -54.089  54.726  1
644455  95.020  -54.102  54.671  1
644456  95.044  -54.114  54.614  1
644457  95.074  -54.130  54.559  1
644458  95.111  -54.149  54.508  1
644459  95.147  -54.168  54.462  1
644460  95.184  -54.187  54.415  1
644461  95.221  -54.207  54.368  1
644462  95.253  -54.226  54.315  1
644463  95.276  -54.242  54.262  1
644464  95.300  -54.258  54.208  1
644465  95.324  -54.273  54.154  1
644466  95.347  -54.289  54.104  1
644467  95.371  -54.305  54.056  1
644468  95.395  -54.321  54.010  1
644469  95.419  -54.337  53.969  1
644470  95.443  -54.353  53.933  1
644471  95.466  -54.369  53.901  1
644472  95.490  -54.385  53.871  1
644473  95.514  -54.401  53.842  1
644474  95.538  -54.417  53.812  1
644475  95.565  -54.435  53.785  1
644476  95.595  -54.451  53.760  1
644477  95.627  -54.464  53.736  1
644478  95.664  -54.473  53.713  1
644479  95.700  -54.480  53.690  1
644480  95.737  -54.487  53.665  1
644481  95.773  -54.494  53.643  1
644482  95.810  -54.502  53.618  1
644483  95.838  -54.516  53.593  1
644484  95.864  -54.534  53.569  1
644485  95.889  -54.552  53.544  1
644486  95.915  -54.571  53.516  1
644487  95.940  -54.589  53.483  1
644488  95.966  -54.607  53.446  1
644489  95.991  -54.625  53.404  1
644490  96.019  -54.642  53.359  1
644491  96.048  -54.657  53.311  1
644492  96.078  -54.671  53.261  1
644493  96.107  -54.687  53.212  1
644494  96.136  -54.702  53.162  1
644495  96.166  -54.716  53.114  1
644496  96.195  -54.731  53.070  1
644497  96.225  -54.746  53.027  1
644498  96.253  -54.759  52.984  1
644499  96.278  -54.768  52.941  1
644500  96.302  -54.776  52.898  1
644501  96.327  -54.784  52.855  1
644502  96.351  -54.792  52.809  1
644503  96.376  -54.800  52.762  1
644504  96.400  -54.808  52.714  1
644505  96.425  -54.816  52.664  1
644506  96.454  -54.823  52.613  1
644507  96.483  -54.830  52.564  1
644508  96.512  -54.837  52.509  1
644509  96.540  -54.844  52.455  1
644510  96.570  -54.851  52.401  1
644511  96.598  -54.858  52.348  1
644512  96.627  -54.865  52.294  1
644513  96.656  -54.872  52.237  1
644514  96.687  -54.881  52.176  1
644515  96.718  -54.890  52.115  1
644516  96.749  -54.898  52.054  1
644517  96.781  -54.907  51.994  1
644518  96.812  -54.916  51.933  1
644519  96.843  -54.925  51.871  1
644520  96.875  -54.933  51.807  1
644521  96.908  -54.943  51.740  1
644522  96.948  -54.956  51.676  1
644523  96.987  -54.968  51.615  1
644524  97.027  -54.981  51.549  1
644525  97.067  -54.993  51.476  1
644526  97.104  -55.012  51.399  1
644527  97.139  -55.036  51.318  1
644528  97.174  -55.060  51.239  1
644529  97.205  -55.079  51.165  1
644530  97.222  -55.079  51.093  1
644531  97.238  -55.078  51.022  1
644532  97.255  -55.077  50.953  1
644533  97.279  -55.076  50.886  1
644534  97.314  -55.075  50.821  1
644535  97.349  -55.074  50.757  1
644536  97.384  -55.073  50.693  1
644537  97.408  -55.072  50.631  1
644538  97.432  -55.071  50.572  1
644539  97.454  -55.070  50.514  1
644540  97.477  -55.069  50.458  1
645004  90.667  -51.625  56.951  4
645005  90.699  -51.634  56.956  4
645006  90.732  -51.641  56.962  4
645007  90.764  -51.650  56.969  4
645008  90.796  -51.658  56.977  4
645009  90.828  -51.666  56.983  4
645010  90.861  -51.674  56.989  4
645011  90.893  -51.682  56.996  4
645012  90.925  -51.690  57.004  4
645013  90.957  -51.697  57.014  4
645014  90.972  -51.713  57.024  4
645015  90.984  -51.729  57.033  4
645016  90.996  -51.744  57.043  4
645017  91.007  -51.760  57.054  4
645018  91.019  -51.776  57.066  4
645019  91.031  -51.791  57.079  4
645020  91.042  -51.807  57.094  4
645021  91.068  -51.814  57.111  4
645022  91.099  -51.836  57.126  4
645023  91.131  -51.862  57.138  4
645024  91.163  -51.888  57.148  4
645025  91.195  -51.913  57.158  4
645026  91.227  -51.939  57.168  4
645027  91.259  -51.964  57.173  4
645028  91.291  -51.990  57.177  4
645029  91.323  -52.016  57.180  4
645030  91.355  -52.042  57.182  4
645031  91.387  -52.067  57.184  4
645032  91.419  -52.093  57.183  4
645033  91.451  -52.119  57.181  4
645034  91.484  -52.145  57.178  4
645035  91.515  -52.170  57.173  4
645036  91.546  -52.189  57.166  4
645037  91.573  -52.210  57.155  4
645038  91.601  -52.230  57.143  4
645039  91.628  -52.251  57.129  4
645040  91.655  -52.271  57.115  4
645041  91.682  -52.292  57.101  4
645042  91.710  -52.313  57.088  4
645043  91.737  -52.333  57.073  4
645044  91.765  -52.354  57.058  4
645045  91.792  -52.374  57.034  4
645046  91.819  -52.395  57.010  4
645047  91.847  -52.416  56.988  4
645048  91.874  -52.437  56.966  4
645049  91.901  -52.457  56.944  4
645050  91.928  -52.477  56.921  4
645051  91.956  -52.498  56.892  4
645052  91.983  -52.519  56.863  4
645053  92.010  -52.540  56.834  4
645054  92.037  -52.560  56.804  4
645055  92.065  -52.581  56.775  4
645056  92.092  -52.601  56.745  4
645057  92.120  -52.622  56.712  4
645058  92.147  -52.643  56.677  4
645059  92.174  -52.663  56.640  4
645060  92.202  -52.684  56.601  4
645061  92.229  -52.704  56.560  4
645062  92.256  -52.725  56.514  4
645063  92.284  -52.746  56.464  4
645064  92.324  -52.775  56.411  4
645065  92.369  -52.791  56.356  4
645066  92.417  -52.797  56.300  4
645067  92.465  -52.803  56.244  4
645068  92.513  -52.809  56.187  4
645069  92.561  -52.815  56.129  4
645070  92.609  -52.821  56.073  4
645071  92.657  -52.827  56.018  4
645072  92.705  -52.833  55.963  4
645073  92.753  -52.839  55.910  4
645074  92.801  -52.845  55.859  4
645075  92.849  -52.851  55.810  4
645109  93.887  -53.396  54.844  1
645110  93.917  -53.415  54.844  1
645111  93.947  -53.433  54.846  1
645112  93.978  -53.452  54.849  1
645113  94.008  -53.471  54.854  1
645114  94.039  -53.490  54.858  1
645115  94.070  -53.508  54.864  1
645116  94.100  -53.527  54.872  1
645117  94.131  -53.546  54.879  1
645118  94.161  -53.564  54.886  1
645119  94.192  -53.583  54.895  1
645120  94.222  -53.602  54.903  1
645121  94.253  -53.620  54.911  1
645122  94.283  -53.639  54.918  1
645123  94.273  -53.645  54.926  1
645124  94.277  -53.657  54.932  1
645125  94.308  -53.679  54.938  1
645126  94.338  -53.701  54.944  1
645127  94.367  -53.723  54.951  1
645128  94.398  -53.746  54.958  1
645129  94.431  -53.767  54.966  1
645130  94.454  -53.780  54.974  1
645131  94.471  -53.787  54.982  1
645132  94.487  -53.796  54.991  1
645133  94.504  -53.803  54.998  1
645134  94.523  -53.813  55.003  1
645135  94.546  -53.825  55.008  1
645136  94.570  -53.838  55.012  1
645137  94.594  -53.850  55.017  1
645138  94.617  -53.863  55.021  1
645139  94.641  -53.875  55.023  1
645140  94.665  -53.887  55.021  1
645141  94.688  -53.900  55.015  1
645142  94.712  -53.912  55.005  1
645143  94.736  -53.924  54.988  1
645144  94.759  -53.937  54.964  1
645145  94.783  -53.949  54.937  1
645146  94.807  -53.961  54.916  1
645147  94.830  -53.974  54.905  1
645148  94.854  -53.986  54.899  1
645149  94.878  -53.998  54.897  1
645150  94.901  -54.010  54.893  1
645151  94.925  -54.023  54.877  1
645152  94.949  -54.035  54.855  1
645153  94.972  -54.048  54.824  1
645154  94.996  -54.060  54.782  1
645155  95.020  -54.073  54.734  1
645156  95.043  -54.085  54.679  1
645157  95.067  -54.097  54.623  1
645158  95.091  -54.110  54.570  1
645159  95.127  -54.128  54.521  1
645160  95.163  -54.147  54.474  1
645161  95.199  -54.166  54.425  1
645162  95.236  -54.185  54.378  1
645163  95.266  -54.202  54.321  1
645164  95.289  -54.218  54.266  1
645165  95.313  -54.233  54.211  1
645166  95.337  -54.249  54.158  1
645167  95.360  -54.265  54.109  1
645168  95.384  -54.280  54.064  1
645169  95.408  -54.296  54.021  1
645170  95.431  -54.312  53.983  1
645171  95.455  -54.328  53.949  1
645172  95.479  -54.344  53.919  1
645173  95.502  -54.360  53.890  1
645174  95.526  -54.376  53.862  1
645175  95.550  -54.392  53.834  1
645176  95.574  -54.408  53.810  1
645177  95.603  -54.424  53.786  1
645178  95.639  -54.431  53.763  1
645179  95.676  -54.439  53.741  1
645180  95.712  -54.446  53.720  1
645181  95.749  -54.453  53.696  1
645182  95.785  -54.461  53.673  1
645183  95.822  -54.468  53.648  1
645184  95.847  -54.486  53.624  1
645185  95.873  -54.505  53.600  1
645186  95.898  -54.523  53.574  1
645187  95.923  -54.541  53.545  1
645188  95.949  -54.559  53.511  1
645189  95.974  -54.577  53.474  1
645190  96.000  -54.596  53.431  1
645191  96.025  -54.614  53.386  1
645192  96.054  -54.629  53.339  1
645193  96.084  -54.644  53.290  1
645194  96.113  -54.659  53.240  1
645195  96.143  -54.674  53.189  1
645196  96.172  -54.689  53.141  1
645197  96.202  -54.703  53.096  1
645198  96.231  -54.718  53.051  1
645199  96.259  -54.732  53.008  1
645200  96.285  -54.745  52.966  1
645201  96.309  -54.753  52.923  1
645202  96.333  -54.762  52.880  1
645203  96.358  -54.770  52.835  1
645204  96.382  -54.778  52.786  1
645205  96.407  -54.786  52.735  1
645206  96.433  -54.793  52.683  1
645207  96.462  -54.800  52.630  1
645208  96.490  -54.808  52.579  1
645209  96.519  -54.815  52.525  1
645210  96.548  -54.822  52.472  1
645211  96.577  -54.828  52.417  1
645212  96.606  -54.836  52.362  1
645213  96.635  -54.843  52.309  1
645214  96.663  -54.850  52.256  1
645215  96.694  -54.858  52.200  1
645216  96.725  -54.867  52.141  1
645217  96.756  -54.875  52.084  1
645218  96.788  -54.884  52.025  1
645219  96.819  -54.893  51.967  1
645220  96.850  -54.902  51.908  1
645221  96.881  -54.910  51.850  1
645222  96.912  -54.919  51.790  1
645223  96.948  -54.930  51.730  1
645224  96.988  -54.942  51.671  1
645225  97.028  -54.955  51.608  1
645226  97.067  -54.967  51.538  1
645227  97.107  -54.980  51.460  1
645228  97.144  -54.999  51.381  1
645229  97.179  -55.023  51.302  1
645230  97.214  -55.047  51.225  1
645231  97.236  -55.054  51.149  1
645232  97.252  -55.053  51.075  1
645233  97.269  -55.052  51.004  1
645234  97.295  -55.050  50.935  1
645235  97.330  -55.050  50.868  1
645236  97.365  -55.049  50.802  1
645237  97.394  -55.048  50.737  1
645238  97.417  -55.047  50.673  1
645239  97.440  -55.046  50.611  1
645240  97.463  -55.045  50.552  1
645241  97.486  -55.044  50.495  1
645242  97.509  -55.044  50.438  1
645706  90.719  -51.600  56.943  4
645707  90.751  -51.608  56.949  4
645708  90.784  -51.616  56.956  4
645709  90.816  -51.624  56.963  4
645710  90.849  -51.632  56.970  4
645711  90.881  -51.641  56.977  4
645712  90.913  -51.648  56.984  4
645713  90.945  -51.656  56.992  4
645714  90.965  -51.669  57.001  4
645715  90.977  -51.685  57.012  4
645716  90.989  -51.700  57.022  4
645717  91.001  -51.716  57.031  4
645718  91.012  -51.732  57.042  4
645719  91.024  -51.748  57.056  4
645720  91.036  -51.763  57.070  4
645721  91.047  -51.779  57.088  4
645722  91.071  -51.788  57.109  4
645723  91.102  -51.809  57.127  4
645724  91.134  -51.835  57.140  4
645725  91.166  -51.860  57.147  4
645726  91.199  -51.886  57.156  4
645727  91.230  -51.912  57.163  4
645728  91.262  -51.938  57.168  4
645729  91.294  -51.964  57.172  4
645730  91.326  -51.989  57.175  4
645731  91.359  -52.014  57.177  4
645732  91.390  -52.040  57.177  4
645733  91.423  -52.066  57.175  4
645734  91.455  -52.092  57.169  4
645735  91.487  -52.117  57.163  4
645736  91.534  -52.130  57.157  4
645737  91.567  -52.145  57.150  4
645738  91.598  -52.161  57.142  4
645739  91.629  -52.177  57.130  4
645740  91.656  -52.198  57.115  4
645741  91.683  -52.218  57.102  4
645742  91.711  -52.239  57.089  4
645743  91.738  -52.259  57.075  4
645744  91.765  -52.280  57.061  4
645745  91.792  -52.301  57.049  4
645746  91.820  -52.321  57.026  4
645747  91.847  -52.342  57.003  4
645748  91.874  -52.362  56.980  4
645749  91.901  -52.384  56.958  4
645750  91.929  -52.404  56.935  4
645751  91.956  -52.424  56.913  4
645752  91.984  -52.445  56.885  4
645753  92.011  -52.465  56.856  4
645754  92.038  -52.486  56.827  4
645755  92.066  -52.507  56.798  4
645756  92.093  -52.528  56.769  4
645757  92.120  -52.548  56.740  4
645758  92.147  -52.568  56.705  4
645759  92.175  -52.589  56.670  4
645760  92.202  -52.610  56.632  4
645761  92.229  -52.631  56.594  4
645762  92.257  -52.651  56.553  4
645763  92.284  -52.672  56.508  4
645764  92.311  -52.693  56.459  4
645765  92.352  -52.722  56.408  4
645766  92.393  -52.750  56.354  4
645767  92.440  -52.759  56.300  4
645768  92.488  -52.765  56.244  4
645769  92.536  -52.771  56.187  4
645770  92.584  -52.777  56.131  4
645771  92.632  -52.783  56.074  4
645772  92.680  -52.789  56.019  4
645773  92.728  -52.795  55.965  4
645774  92.776  -52.801  55.912  4
645775  92.824  -52.807  55.861  4
645776  92.871  -52.813  55.811  4
645777  92.920  -52.819  55.763  4
645811  93.934  -53.389  54.843  1
645812  93.965  -53.408  54.845  1
645813  93.995  -53.427  54.848  1
645814  94.026  -53.446  54.852  1
645815  94.056  -53.464  54.856  1
645816  94.087  -53.483  54.862  1
645817  94.118  -53.502  54.869  1
645818  94.148  -53.520  54.876  1
645819  94.179  -53.539  54.884  1
645820  94.209  -53.558  54.892  1
645821  94.240  -53.576  54.900  1
645822  94.270  -53.595  54.908  1
645823  94.300  -53.614  54.915  1
645824  94.299  -53.622  54.922  1
645825  94.287  -53.628  54.929  1
645826  94.318  -53.650  54.936  1
645827  94.347  -53.673  54.942  1
645828  94.378  -53.695  54.948  1
645829  94.408  -53.717  54.954  1
645830  94.438  -53.739  54.961  1
645831  94.466  -53.756  54.969  1
645832  94.483  -53.764  54.978  1
645833  94.499  -53.772  54.986  1
645834  94.522  -53.784  54.992  1
645835  94.546  -53.796  54.998  1
645836  94.569  -53.808  55.001  1
645837  94.593  -53.821  55.006  1
645838  94.617  -53.833  55.012  1
645839  94.640  -53.845  55.019  1
645840  94.664  -53.858  55.022  1
645841  94.688  -53.870  55.019  1
645842  94.711  -53.882  55.013  1
645843  94.735  -53.894  55.006  1
645844  94.759  -53.907  54.987  1
645845  94.782  -53.919  54.963  1
645846  94.806  -53.932  54.936  1
645847  94.830  -53.944  54.915  1
645848  94.853  -53.957  54.905  1
645849  94.877  -53.969  54.900  1
645850  94.901  -53.981  54.901  1
645851  94.924  -53.994  54.900  1
645852  94.948  -54.006  54.883  1
645853  94.971  -54.018  54.858  1
645854  94.995  -54.031  54.825  1
645855  95.019  -54.043  54.782  1
645856  95.042  -54.055  54.734  1
645857  95.066  -54.067  54.682  1
645858  95.090  -54.080  54.629  1
645859  95.113  -54.092  54.577  1
645860  95.142  -54.107  54.528  1
645861  95.179  -54.126  54.478  1
645862  95.215  -54.145  54.427  1
645863  95.252  -54.164  54.377  1
645864  95.280  -54.181  54.321  1
645865  95.304  -54.197  54.266  1
645866  95.327  -54.212  54.213  1
645867  95.351  -54.228  54.164  1
645868  95.375  -54.243  54.119  1
645869  95.398  -54.259  54.078  1
645870  95.422  -54.275  54.036  1
645871  95.446  -54.290  54.000  1
645872  95.469  -54.306  53.967  1
645873  95.493  -54.322  53.937  1
645874  95.517  -54.337  53.908  1
645875  95.540  -54.353  53.882  1
645876  95.564  -54.369  53.857  1
645877  95.588  -54.381  53.834  1
645878  95.615  -54.390  53.811  1
645879  95.652  -54.398  53.790  1
645880  95.688  -54.405  53.771  1
645881  95.725  -54.412  53.751  1
645882  95.762  -54.420  53.728  1
645883  95.798  -54.427  53.704  1
645884  95.830  -54.439  53.678  1
645885  95.855  -54.457  53.654  1
645886  95.881  -54.475  53.630  1
645887  95.907  -54.493  53.604  1
645888  95.932  -54.511  53.574  1
645889  95.958  -54.530  53.539  1
645890  95.983  -54.548  53.502  1
645891  96.009  -54.566  53.460  1
645892  96.034  -54.584  53.415  1
645893  96.060  -54.601  53.368  1
645894  96.090  -54.616  53.318  1
645895  96.119  -54.631  53.267  1
645896  96.149  -54.646  53.215  1
645897  96.178  -54.661  53.167  1
645898  96.208  -54.675  53.120  1
645899  96.237  -54.690  53.075  1
645900  96.264  -54.704  53.031  1
645901  96.290  -54.717  52.988  1
645902  96.315  -54.730  52.945  1
645903  96.340  -54.740  52.901  1
645904  96.365  -54.747  52.855  1
645905  96.389  -54.756  52.807  1
645906  96.413  -54.764  52.756  1
645907  96.440  -54.772  52.705  1
645908  96.469  -54.778  52.653  1
645909  96.498  -54.785  52.600  1
645910  96.527  -54.792  52.549  1
645911  96.555  -54.800  52.496  1
645912  96.584  -54.806  52.441  1
645913  96.613  -54.813  52.387  1
645914  96.642  -54.821  52.337  1
645915  96.671  -54.828  52.290  1
645916  96.700  -54.835  52.237  1
645917  96.732  -54.844  52.180  1
645918  96.763  -54.853  52.124  1
645919  96.794  -54.862  52.068  1
645920  96.826  -54.870  52.012  1
645921  96.857  -54.879  51.955  1
645922  96.888  -54.887  51.899  1
645923  96.920  -54.897  51.842  1
645924  96.951  -54.905  51.782  1
645925  96.989  -54.917  51.723  1
645926  97.028  -54.929  51.661  1
645927  97.068  -54.942  51.593  1
645928  97.107  -54.954  51.516  1
645929  97.147  -54.967  51.441  1
645930  97.184  -54.985  51.365  1
645931  97.220  -55.010  51.285  1
645932  97.250  -55.028  51.206  1
645933  97.267  -55.028  51.129  1
645934  97.284  -55.027  51.056  1
645935  97.311  -55.025  50.985  1
645936  97.346  -55.025  50.916  1
645937  97.379  -55.024  50.848  1
645938  97.402  -55.023  50.781  1
645939  97.425  -55.022  50.716  1
645940  97.448  -55.021  50.652  1
645941  97.471  -55.020  50.591  1
645942  97.495  -55.019  50.532  1
645943  97.518  -55.019  50.474  1
645944  97.541  -55.018  50.418  1
646409  90.804  -51.583  56.943  4
646410  90.836  -51.591  56.950  4
646411  90.868  -51.599  56.957  4
646412  90.900  -51.607  56.964  4
646413  90.933  -51.615  56.972  4
646414  90.959  -51.625  56.980  4
646415  90.970  -51.641  56.989  4
646416  90.982  -51.657  57.000  4
646417  90.994  -51.672  57.011  4
646418  91.006  -51.688  57.021  4
646419  91.017  -51.704  57.033  4
646420  91.029  -51.720  57.047  4
646421  91.041  -51.736  57.062  4
646422  91.052  -51.752  57.083  4
646423  91.075  -51.760  57.106  4
646424  91.105  -51.782  57.128  4
646425  91.138  -51.807  57.145  4
646426  91.169  -51.833  57.150  4
646427  91.202  -51.859  57.157  4
646428  91.234  -51.885  57.162  4
646429  91.265  -51.910  57.165  4
646430  91.298  -51.936  57.168  4
646431  91.330  -51.962  57.171  4
646432  91.362  -51.988  57.173  4
646433  91.394  -52.013  57.172  4
646434  91.426  -52.039  57.168  4
646435  91.459  -52.064  57.160  4
646436  91.509  -52.075  57.151  4
646437  91.553  -52.089  57.143  4
646438  91.586  -52.105  57.137  4
646439  91.617  -52.120  57.130  4
646440  91.648  -52.136  57.119  4
646441  91.678  -52.152  57.105  4
646442  91.710  -52.167  57.091  4
646443  91.738  -52.186  57.077  4
646444  91.766  -52.206  57.064  4
646445  91.793  -52.227  57.049  4
646446  91.820  -52.247  57.037  4
646447  91.848  -52.268  57.016  4
646448  91.875  -52.289  56.995  4
646449  91.902  -52.309  56.973  4
646450  91.930  -52.330  56.950  4
646451  91.957  -52.350  56.927  4
646452  91.984  -52.371  56.906  4
646453  92.011  -52.392  56.879  4
646454  92.039  -52.412  56.851  4
646455  92.066  -52.433  56.823  4
646456  92.093  -52.453  56.795  4
646457  92.121  -52.474  56.765  4
646458  92.148  -52.495  56.735  4
646459  92.175  -52.515  56.701  4
646460  92.203  -52.536  56.665  4
646461  92.230  -52.556  56.627  4
646462  92.257  -52.578  56.588  4
646463  92.285  -52.598  56.546  4
646464  92.312  -52.619  56.503  4
646465  92.340  -52.639  56.456  4
646466  92.380  -52.668  56.406  4
646467  92.421  -52.697  56.353  4
646468  92.463  -52.721  56.299  4
646469  92.511  -52.727  56.244  4
646470  92.559  -52.733  56.188  4
646471  92.606  -52.739  56.133  4
646472  92.655  -52.745  56.077  4
646473  92.703  -52.751  56.021  4
646474  92.751  -52.757  55.967  4
646475  92.798  -52.763  55.915  4
646476  92.846  -52.769  55.864  4
646477  92.895  -52.775  55.814  4
646478  92.942  -52.782  55.766  4
646479  92.990  -52.788  55.719  4
646480  93.010  -52.809  55.672  4
646512  93.952  -53.364  54.844  1
646513  93.982  -53.383  54.845  1
646514  94.012  -53.402  54.847  1
646515  94.043  -53.420  54.850  1
646516  94.074  -53.439  54.854  1
646517  94.104  -53.458  54.860  1
646518  94.135  -53.476  54.867  1
646519  94.165  -53.495  54.875  1
646520  94.196  -53.514  54.882  1
646521  94.226  -53.532  54.890  1
646522  94.257  -53.551  54.898  1
646523  94.287  -53.570  54.906  1
646524  94.318  -53.588  54.912  1
646525  94.325  -53.599  54.919  1
646526  94.301  -53.602  54.927  1
646527  94.328  -53.622  54.934  1
646528  94.357  -53.644  54.940  1
646529  94.388  -53.666  54.945  1
646530  94.418  -53.688  54.951  1
646531  94.448  -53.710  54.957  1
646532  94.478  -53.732  54.964  1
646533  94.497  -53.742  54.972  1
646534  94.521  -53.754  54.979  1
646535  94.545  -53.766  54.985  1
646536  94.568  -53.778  54.990  1
646537  94.592  -53.791  54.994  1
646538  94.616  -53.803  54.999  1
646539  94.639  -53.816  55.006  1
646540  94.663  -53.828  55.012  1
646541  94.687  -53.841  55.015  1
646542  94.710  -53.853  55.012  1
646543  94.734  -53.865  55.005  1
646544  94.758  -53.878  54.995  1
646545  94.781  -53.890  54.978  1
646546  94.805  -53.902  54.956  1
646547  94.829  -53.915  54.931  1
646548  94.852  -53.927  54.912  1
646549  94.876  -53.939  54.905  1
646550  94.900  -53.951  54.904  1
646551  94.923  -53.964  54.906  1
646552  94.947  -53.976  54.903  1
646553  94.971  -53.988  54.885  1
646554  94.994  -54.001  54.857  1
646555  95.018  -54.013  54.820  1
646556  95.042  -54.026  54.777  1
646557  95.065  -54.038  54.730  1
646558  95.089  -54.051  54.682  1
646559  95.113  -54.063  54.632  1
646560  95.136  -54.075  54.581  1
646561  95.160  -54.088  54.531  1
646562  95.195  -54.105  54.479  1
646563  95.232  -54.124  54.427  1
646564  95.268  -54.143  54.375  1
646565  95.295  -54.160  54.321  1
646566  95.318  -54.176  54.269  1
646567  95.342  -54.191  54.220  1
646568  95.365  -54.207  54.174  1
646569  95.389  -54.223  54.132  1
646570  95.412  -54.238  54.093  1
646571  95.436  -54.254  54.054  1
646572  95.460  -54.269  54.018  1
646573  95.483  -54.285  53.985  1
646574  95.507  -54.301  53.955  1
646575  95.531  -54.316  53.927  1
646576  95.555  -54.326  53.903  1
646577  95.580  -54.336  53.879  1
646578  95.604  -54.346  53.858  1
646579  95.628  -54.357  53.837  1
646580  95.665  -54.364  53.817  1
646581  95.701  -54.371  53.800  1
646582  95.738  -54.378  53.781  1
646583  95.774  -54.386  53.758  1
646584  95.811  -54.393  53.734  1
646585  95.839  -54.408  53.709  1
646586  95.865  -54.427  53.685  1
646587  95.890  -54.445  53.661  1
646588  95.915  -54.463  53.634  1
646589  95.941  -54.481  53.602  1
646590  95.966  -54.499  53.565  1
646591  95.991  -54.518  53.529  1
646592  96.017  -54.536  53.489  1
646593  96.043  -54.554  53.444  1
646594  96.068  -54.572  53.396  1
646595  96.096  -54.588  53.345  1
646596  96.126  -54.603  53.292  1
646597  96.155  -54.618  53.240  1
646598  96.185  -54.633  53.192  1
646599  96.214  -54.648  53.145  1
646600  96.244  -54.662  53.099  1
646601  96.270  -54.676  53.054  1
646602  96.295  -54.689  53.010  1
646603  96.321  -54.701  52.967  1
646604  96.346  -54.714  52.922  1
646605  96.372  -54.725  52.877  1
646606  96.396  -54.734  52.829  1
646607  96.420  -54.741  52.780  1
646608  96.448  -54.749  52.729  1
646609  96.476  -54.756  52.678  1
646610  96.506  -54.763  52.625  1
646611  96.534  -54.770  52.573  1
646612  96.563  -54.777  52.521  1
646613  96.592  -54.784  52.467  1
646614  96.621  -54.791  52.415  1
646615  96.650  -54.798  52.369  1
646616  96.678  -54.805  52.325  1
646617  96.708  -54.812  52.276  1
646618  96.739  -54.821  52.222  1
646619  96.770  -54.830  52.167  1
646620  96.801  -54.838  52.112  1
646621  96.832  -54.847  52.056  1
646622  96.864  -54.856  52.000  1
646623  96.895  -54.865  51.946  1
646624  96.926  -54.874  51.890  1
646625  96.957  -54.882  51.830  1
646626  96.990  -54.891  51.769  1
646627  97.029  -54.903  51.706  1
646628  97.069  -54.916  51.640  1
646629  97.108  -54.928  51.568  1
646630  97.148  -54.941  51.497  1
646631  97.187  -54.953  51.422  1
646632  97.225  -54.972  51.344  1
646633  97.260  -54.997  51.267  1
646634  97.281  -55.003  51.189  1
646635  97.298  -55.001  51.110  1
646636  97.327  -55.000  51.037  1
646637  97.362  -55.000  50.965  1
646638  97.388  -54.999  50.895  1
646639  97.410  -54.998  50.826  1
646640  97.434  -54.997  50.760  1
646641  97.457  -54.996  50.695  1
646642  97.480  -54.995  50.631  1
646643  97.503  -54.994  50.571  1
646644  97.526  -54.994  50.512  1
646645  97.549  -54.993  50.454  1
647111  90.856  -51.557  56.938  4
647112  90.888  -51.566  56.945  4
647113  90.921  -51.574  56.951  4
647114  90.952  -51.582  56.961  4
647115  90.964  -51.597  56.968  4
647116  90.975  -51.613  56.978  4
647117  90.988  -51.629  56.989  4
647118  90.999  -51.645  56.999  4
647119  91.011  -51.661  57.010  4
647120  91.023  -51.676  57.022  4
647121  91.034  -51.692  57.037  4
647122  91.046  -51.708  57.054  4
647123  91.058  -51.724  57.076  4
647124  91.078  -51.734  57.100  4
647125  91.109  -51.754  57.124  4
647126  91.141  -51.780  57.143  4
647127  91.173  -51.806  57.153  4
647128  91.205  -51.832  57.160  4
647129  91.237  -51.857  57.163  4
647130  91.269  -51.883  57.165  4
647131  91.301  -51.909  57.166  4
647132  91.333  -51.935  57.169  4
647133  91.365  -51.960  57.172  4
647134  91.397  -51.986  57.168  4
647135  91.431  -52.011  57.162  4
647136  91.482  -52.021  57.152  4
647137  91.532  -52.032  57.140  4
647138  91.571  -52.048  57.130  4
647139  91.605  -52.064  57.125  4
647140  91.636  -52.080  57.119  4
647141  91.666  -52.095  57.109  4
647142  91.698  -52.111  57.096  4
647143  91.728  -52.127  57.082  4
647144  91.759  -52.142  57.067  4
647145  91.790  -52.158  57.053  4
647146  91.821  -52.174  57.039  4
647147  91.848  -52.194  57.024  4
647148  91.875  -52.214  57.005  4
647149  91.903  -52.236  56.985  4
647150  91.930  -52.256  56.964  4
647151  91.957  -52.277  56.943  4
647152  91.985  -52.297  56.919  4
647153  92.012  -52.318  56.898  4
647154  92.039  -52.339  56.873  4
647155  92.067  -52.359  56.848  4
647156  92.094  -52.380  56.821  4
647157  92.121  -52.400  56.792  4
647158  92.149  -52.421  56.762  4
647159  92.176  -52.442  56.731  4
647160  92.203  -52.462  56.698  4
647161  92.230  -52.483  56.661  4
647162  92.258  -52.503  56.623  4
647163  92.285  -52.524  56.583  4
647164  92.312  -52.545  56.542  4
647165  92.340  -52.565  56.500  4
647166  92.367  -52.586  56.454  4
647167  92.408  -52.615  56.404  4
647168  92.448  -52.644  56.352  4
647169  92.489  -52.672  56.299  4
647170  92.533  -52.689  56.245  4
647171  92.581  -52.695  56.190  4
647172  92.630  -52.701  56.135  4
647173  92.677  -52.707  56.080  4
647174  92.725  -52.713  56.025  4
647175  92.773  -52.719  55.972  4
647176  92.821  -52.725  55.920  4
647177  92.869  -52.731  55.868  4
647178  92.917  -52.738  55.818  4
647179  92.965  -52.744  55.771  4
647180  92.996  -52.760  55.723  4
647181  93.015  -52.782  55.676  4
647182  93.035  -52.803  55.629  4
647214  93.999  -53.358  54.845  1
647215  94.030  -53.376  54.846  1
647216  94.060  -53.395  54.849  1
647217  94.091  -53.414  54.853  1
647218  94.122  -53.432  54.857  1
647219  94.152  -53.451  54.865  1
647220  94.183  -53.470  54.872  1
647221  94.213  -53.488  54.880  1
647222  94.244  -53.507  54.888  1
647223  94.274  -53.526  54.896  1
647224  94.305  -53.544  54.903  1
647225  94.335  -53.563  54.911  1
647226  94.351  -53.577  54.917  1
647227  94.327  -53.579  54.925  1
647228  94.337  -53.593  54.931  1
647229  94.367  -53.615  54.937  1
647230  94.398  -53.637  54.943  1
647231  94.428  -53.660  54.949  1
647232  94.458  -53.682  54.955  1
647233  94.489  -53.703  54.960  1
647234  94.518  -53.719  54.966  1
647235  94.542  -53.733  54.973  1
647236  94.566  -53.747  54.978  1
647237  94.591  -53.760  54.982  1
647238  94.615  -53.774  54.986  1
647239  94.639  -53.786  54.992  1
647240  94.663  -53.799  54.998  1
647241  94.686  -53.811  55.003  1
647242  94.710  -53.823  55.004  1
647243  94.734  -53.835  54.999  1
647244  94.757  -53.848  54.990  1
647245  94.781  -53.860  54.979  1
647246  94.805  -53.872  54.965  1
647247  94.828  -53.885  54.946  1
647248  94.852  -53.897  54.926  1
647249  94.876  -53.910  54.913  1
647250  94.899  -53.922  54.910  1
647251  94.923  -53.935  54.910  1
647252  94.947  -53.947  54.910  1
647253  94.970  -53.959  54.902  1
647254  94.994  -53.972  54.882  1
647255  95.018  -53.984  54.850  1
647256  95.041  -53.996  54.812  1
647257  95.065  -54.008  54.768  1
647258  95.089  -54.021  54.723  1
647259  95.112  -54.033  54.678  1
647260  95.136  -54.045  54.631  1
647261  95.160  -54.058  54.581  1
647262  95.183  -54.070  54.530  1
647263  95.211  -54.085  54.476  1
647264  95.247  -54.104  54.423  1
647265  95.284  -54.123  54.372  1
647266  95.309  -54.138  54.321  1
647267  95.332  -54.154  54.274  1
647268  95.356  -54.170  54.230  1
647269  95.380  -54.185  54.187  1
647270  95.403  -54.201  54.146  1
647271  95.427  -54.217  54.109  1
647272  95.451  -54.232  54.072  1
647273  95.474  -54.248  54.036  1
647274  95.498  -54.261  54.003  1
647275  95.523  -54.271  53.973  1
647276  95.547  -54.281  53.946  1
647277  95.571  -54.292  53.923  1
647278  95.596  -54.301  53.901  1
647279  95.620  -54.312  53.881  1
647280  95.644  -54.322  53.861  1
647281  95.677  -54.330  53.843  1
647282  95.713  -54.337  53.827  1
647283  95.750  -54.345  53.809  1
647284  95.787  -54.352  53.785  1
647285  95.822  -54.361  53.761  1
647286  95.847  -54.379  53.736  1
647287  95.873  -54.397  53.712  1
647288  95.898  -54.415  53.687  1
647289  95.924  -54.433  53.660  1
647290  95.950  -54.452  53.628  1
647291  95.975  -54.470  53.595  1
647292  96.001  -54.488  53.559  1
647293  96.026  -54.506  53.519  1
647294  96.051  -54.524  53.473  1
647295  96.077  -54.543  53.423  1
647296  96.102  -54.561  53.370  1
647297  96.132  -54.575  53.316  1
647298  96.161  -54.590  53.265  1
647299  96.191  -54.605  53.216  1
647300  96.220  -54.620  53.169  1
647301  96.250  -54.635  53.122  1
647302  96.275  -54.647  53.077  1
647303  96.301  -54.660  53.033  1
647304  96.326  -54.673  52.990  1
647305  96.352  -54.686  52.944  1
647306  96.377  -54.699  52.899  1
647307  96.403  -54.711  52.854  1
647308  96.427  -54.719  52.806  1
647309  96.455  -54.727  52.755  1
647310  96.484  -54.734  52.702  1
647311  96.513  -54.740  52.651  1
647312  96.542  -54.747  52.598  1
647313  96.571  -54.755  52.546  1
647314  96.599  -54.762  52.494  1
647315  96.628  -54.768  52.445  1
647316  96.657  -54.776  52.402  1
647317  96.686  -54.783  52.360  1
647318  96.715  -54.790  52.314  1
647319  96.745  -54.798  52.264  1
647320  96.777  -54.807  52.211  1
647321  96.808  -54.815  52.157  1
647322  96.839  -54.825  52.102  1
647323  96.871  -54.833  52.046  1
647324  96.902  -54.842  51.991  1
647325  96.933  -54.850  51.935  1
647326  96.964  -54.859  51.874  1
647327  96.996  -54.869  51.812  1
647328  97.030  -54.878  51.749  1
647329  97.070  -54.891  51.683  1
647330  97.109  -54.903  51.614  1
647331  97.149  -54.916  51.545  1
647332  97.188  -54.928  51.471  1
647333  97.228  -54.941  51.396  1
647334  97.265  -54.959  51.320  1
647335  97.296  -54.977  51.243  1
647336  97.312  -54.976  51.164  1
647337  97.344  -54.975  51.088  1
647338  97.373  -54.975  51.015  1
647339  97.396  -54.974  50.943  1
647340  97.419  -54.973  50.873  1
647341  97.442  -54.972  50.804  1
647342  97.465  -54.972  50.738  1
647343  97.489  -54.970  50.674  1
647344  97.512  -54.969  50.611  1
647345  97.535  -54.969  50.551  1
647346  97.558  -54.968  50.492  1
647347  97.581  -54.967  50.433  1
647812  90.876  -51.524  56.927  4
647813  90.908  -51.532  56.934  4
647814  90.941  -51.541  56.940  4
647815  90.957  -51.554  56.948  4
647816  90.969  -51.570  56.957  4
647817  90.980  -51.586  56.966  4
647818  90.993  -51.601  56.977  4
647819  91.004  -51.617  56.988  4
647820  91.016  -51.633  56.999  4
647821  91.028  -51.649  57.012  4
647822  91.039  -51.665  57.026  4
647823  91.051  -51.681  57.044  4
647824  91.063  -51.696  57.067  4
647825  91.081  -51.707  57.092  4
647826  91.112  -51.728  57.116  4
647827  91.144  -51.753  57.138  4
647828  91.176  -51.779  57.151  4
647829  91.208  -51.804  57.159  4
647830  91.240  -51.830  57.162  4
647831  91.272  -51.856  57.161  4
647832  91.304  -51.882  57.160  4
647833  91.336  -51.907  57.160  4
647834  91.368  -51.933  57.161  4
647835  91.403  -51.957  57.159  4
647836  91.454  -51.967  57.153  4
647837  91.504  -51.979  57.142  4
647838  91.552  -51.991  57.129  4
647839  91.589  -52.007  57.119  4
647840  91.624  -52.024  57.114  4
647841  91.654  -52.039  57.107  4
647842  91.685  -52.054  57.099  4
647843  91.716  -52.070  57.088  4
647844  91.747  -52.086  57.074  4
647845  91.778  -52.101  57.058  4
647846  91.809  -52.117  57.042  4
647847  91.840  -52.133  57.028  4
647848  91.871  -52.148  57.013  4
647849  91.902  -52.164  56.995  4
647850  91.931  -52.182  56.976  4
647851  91.958  -52.202  56.956  4
647852  91.985  -52.224  56.935  4
647853  92.012  -52.244  56.913  4
647854  92.040  -52.264  56.892  4
647855  92.067  -52.285  56.867  4
647856  92.094  -52.305  56.842  4
647857  92.122  -52.327  56.817  4
647858  92.149  -52.347  56.791  4
647859  92.176  -52.368  56.762  4
647860  92.204  -52.388  56.730  4
647861  92.231  -52.409  56.695  4
647862  92.259  -52.430  56.657  4
647863  92.286  -52.450  56.619  4
647864  92.313  -52.471  56.580  4
647865  92.340  -52.491  56.539  4
647866  92.368  -52.512  56.498  4
647867  92.395  -52.533  56.452  4
647868  92.436  -52.562  56.403  4
647869  92.477  -52.590  56.352  4
647870  92.517  -52.619  56.300  4
647871  92.558  -52.647  56.247  4
647872  92.604  -52.657  56.193  4
647873  92.652  -52.663  56.138  4
647874  92.700  -52.669  56.084  4
647875  92.748  -52.675  56.031  4
647876  92.796  -52.681  55.978  4
647877  92.844  -52.687  55.926  4
647878  92.892  -52.694  55.875  4
647879  92.940  -52.700  55.825  4
647880  92.981  -52.709  55.778  4
647881  93.001  -52.731  55.729  4
647882  93.020  -52.753  55.681  4
647883  93.045  -52.772  55.634  4
647884  93.075  -52.786  55.589  4
647885  93.105  -52.800  55.545  4
647915  94.017  -53.332  54.845  1
647916  94.047  -53.351  54.846  1
647917  94.078  -53.370  54.848  1
647918  94.108  -53.388  54.852  1
647919  94.139  -53.407  54.856  1
647920  94.170  -53.426  54.863  1
647921  94.200  -53.445  54.870  1
647922  94.230  -53.463  54.878  1
647923  94.261  -53.482  54.886  1
647924  94.291  -53.501  54.893  1
647925  94.322  -53.519  54.901  1
647926  94.352  -53.538  54.909  1
647927  94.377  -53.555  54.916  1
647928  94.353  -53.556  54.923  1
647929  94.347  -53.565  54.930  1
647930  94.378  -53.587  54.937  1
647931  94.408  -53.609  54.944  1
647932  94.437  -53.631  54.951  1
647933  94.469  -53.652  54.956  1
647934  94.502  -53.672  54.960  1
647935  94.535  -53.691  54.964  1
647936  94.559  -53.705  54.969  1
647937  94.583  -53.719  54.973  1
647938  94.608  -53.733  54.975  1
647939  94.632  -53.747  54.978  1
647940  94.657  -53.760  54.982  1
647941  94.681  -53.774  54.987  1
647942  94.706  -53.787  54.991  1
647943  94.730  -53.801  54.990  1
647944  94.755  -53.815  54.983  1
647945  94.779  -53.828  54.973  1
647946  94.804  -53.842  54.963  1
647947  94.828  -53.856  54.951  1
647948  94.851  -53.868  54.937  1
647949  94.875  -53.880  54.924  1
647950  94.899  -53.892  54.917  1
647951  94.922  -53.905  54.917  1
647952  94.946  -53.917  54.917  1
647953  94.970  -53.929  54.913  1
647954  94.993  -53.942  54.900  1
647955  95.017  -53.954  54.876  1
647956  95.040  -53.966  54.843  1
647957  95.064  -53.979  54.803  1
647958  95.088  -53.991  54.761  1
647959  95.111  -54.004  54.718  1
647960  95.135  -54.016  54.676  1
647961  95.159  -54.029  54.628  1
647962  95.182  -54.041  54.577  1
647963  95.206  -54.053  54.526  1
647964  95.230  -54.066  54.473  1
647965  95.263  -54.082  54.423  1
647966  95.300  -54.101  54.377  1
647967  95.323  -54.117  54.331  1
647968  95.347  -54.133  54.287  1
647969  95.370  -54.148  54.244  1
647970  95.394  -54.164  54.201  1
647971  95.417  -54.180  54.161  1
647972  95.441  -54.195  54.126  1
647973  95.466  -54.206  54.089  1
647974  95.490  -54.216  54.054  1
647975  95.515  -54.226  54.022  1
647976  95.539  -54.236  53.992  1
647977  95.563  -54.246  53.965  1
647978  95.588  -54.257  53.944  1
647979  95.612  -54.267  53.922  1
647980  95.636  -54.277  53.903  1
647981  95.661  -54.287  53.885  1
647982  95.690  -54.296  53.868  1
647983  95.726  -54.304  53.852  1
647984  95.763  -54.311  53.834  1
647985  95.800  -54.318  53.810  1
647986  95.831  -54.330  53.785  1
647987  95.856  -54.348  53.760  1
647988  95.882  -54.367  53.735  1
647989  95.907  -54.385  53.710  1
647990  95.933  -54.403  53.683  1
647991  95.958  -54.421  53.652  1
647992  95.983  -54.439  53.620  1
647993  96.009  -54.458  53.585  1
647994  96.034  -54.476  53.545  1
647995  96.060  -54.494  53.498  1
647996  96.086  -54.512  53.447  1
647997  96.111  -54.530  53.392  1
647998  96.138  -54.547  53.339  1
647999  96.168  -54.562  53.288  1
648000  96.197  -54.577  53.238  1
648001  96.227  -54.592  53.191  1
648002  96.255  -54.606  53.145  1
648003  96.281  -54.619  53.099  1
648004  96.306  -54.632  53.055  1
648005  96.331  -54.645  53.010  1
648006  96.357  -54.658  52.964  1
648007  96.383  -54.670  52.920  1
648008  96.408  -54.683  52.874  1
648009  96.434  -54.696  52.826  1
648010  96.463  -54.704  52.776  1
648011  96.491  -54.711  52.724  1
648012  96.521  -54.718  52.672  1
648013  96.549  -54.725  52.621  1
648014  96.578  -54.732  52.569  1
648015  96.607  -54.740  52.521  1
648016  96.636  -54.746  52.475  1
648017  96.665  -54.753  52.433  1
648018  96.693  -54.760  52.392  1
648019  96.722  -54.768  52.351  1
648020  96.752  -54.775  52.306  1
648021  96.784  -54.784  52.256  1
648022  96.815  -54.793  52.204  1
648023  96.846  -54.802  52.148  1
648024  96.877  -54.810  52.092  1
648025  96.908  -54.819  52.035  1
648026  96.940  -54.828  51.977  1
648027  96.971  -54.837  51.916  1
648028  97.003  -54.845  51.854  1
648029  97.034  -54.854  51.790  1
648030  97.070  -54.865  51.725  1
648031  97.110  -54.878  51.657  1
648032  97.149  -54.890  51.589  1
648033  97.189  -54.903  51.518  1
648034  97.229  -54.915  51.446  1
648035  97.268  -54.928  51.371  1
648036  97.305  -54.946  51.296  1
648037  97.326  -54.951  51.219  1
648038  97.359  -54.950  51.142  1
648039  97.381  -54.950  51.066  1
648040  97.404  -54.949  50.993  1
648041  97.428  -54.948  50.921  1
648042  97.451  -54.947  50.850  1
648043  97.474  -54.947  50.782  1
648044  97.497  -54.945  50.718  1
648045  97.520  -54.944  50.653  1
648046  97.543  -54.944  50.592  1
648047  97.567  -54.943  50.531  1
648048  97.589  -54.942  50.471  1
648049  97.612  -54.941  50.413  1
648513  90.896  -51.490  56.916  4
648514  90.928  -51.499  56.922  4
648515  90.951  -51.510  56.928  4
648516  90.962  -51.526  56.936  4
648517  90.974  -51.542  56.945  4
648518  90.986  -51.558  56.954  4
648519  90.998  -51.574  56.965  4
648520  91.009  -51.590  56.977  4
648521  91.021  -51.605  56.987  4
648522  91.033  -51.621  57.000  4
648523  91.044  -51.637  57.014  4
648524  91.056  -51.653  57.032  4
648525  91.068  -51.669  57.055  4
648526  91.085  -51.681  57.081  4
648527  91.115  -51.700  57.105  4
648528  91.147  -51.726  57.128  4
648529  91.179  -51.752  57.143  4
648530  91.212  -51.777  57.155  4
648531  91.243  -51.803  57.158  4
648532  91.276  -51.829  57.155  4
648533  91.308  -51.854  57.150  4
648534  91.340  -51.880  57.149  4
648535  91.375  -51.903  57.148  4
648536  91.426  -51.914  57.146  4
648537  91.476  -51.925  57.139  4
648538  91.527  -51.936  57.128  4
648539  91.570  -51.950  57.115  4
648540  91.608  -51.967  57.107  4
648541  91.642  -51.983  57.101  4
648542  91.673  -51.999  57.095  4
648543  91.704  -52.014  57.087  4
648544  91.735  -52.029  57.076  4
648545  91.766  -52.045  57.063  4
648546  91.797  -52.061  57.049  4
648547  91.828  -52.076  57.033  4
648548  91.859  -52.092  57.019  4
648549  91.890  -52.108  57.004  4
648550  91.921  -52.123  56.986  4
648551  91.952  -52.139  56.967  4
648552  91.983  -52.154  56.949  4
648553  92.013  -52.170  56.928  4
648554  92.040  -52.191  56.907  4
648555  92.068  -52.211  56.887  4
648556  92.095  -52.232  56.862  4
648557  92.122  -52.252  56.838  4
648558  92.150  -52.273  56.814  4
648559  92.177  -52.294  56.788  4
648560  92.204  -52.315  56.760  4
648561  92.231  -52.335  56.727  4
648562  92.259  -52.355  56.692  4
648563  92.286  -52.376  56.656  4
648564  92.313  -52.397  56.618  4
648565  92.341  -52.418  56.578  4
648566  92.368  -52.438  56.537  4
648567  92.395  -52.459  56.497  4
648568  92.423  -52.479  56.451  4
648569  92.463  -52.508  56.403  4
648570  92.504  -52.537  56.353  4
648571  92.545  -52.565  56.302  4
648572  92.585  -52.594  56.249  4
648573  92.627  -52.619  56.196  4
648574  92.675  -52.625  56.142  4
648575  92.723  -52.631  56.090  4
648576  92.771  -52.637  56.037  4
648577  92.819  -52.644  55.985  4
648578  92.867  -52.650  55.934  4
648579  92.915  -52.656  55.883  4
648580  92.963  -52.662  55.833  4
648581  92.986  -52.681  55.786  4
648582  93.006  -52.703  55.738  4
648583  93.031  -52.722  55.690  4
648584  93.061  -52.736  55.642  4
648585  93.091  -52.750  55.595  4
648586  93.121  -52.765  55.551  4
648587  93.151  -52.780  55.508  4
648588  93.181  -52.794  55.465  4
648617  94.064  -53.326  54.846  1
648618  94.095  -53.345  54.849  1
648619  94.126  -53.363  54.852  1
648620  94.156  -53.382  54.856  1
648621  94.187  -53.401  54.862  1
648622  94.217  -53.419  54.868  1
648623  94.248  -53.438  54.875  1
648624  94.278  -53.457  54.883  1
648625  94.309  -53.475  54.891  1
648626  94.339  -53.494  54.899  1
648627  94.369  -53.513  54.907  1
648628  94.400  -53.531  54.915  1
648629  94.380  -53.534  54.922  1
648630  94.357  -53.537  54.929  1
648631  94.388  -53.559  54.937  1
648632  94.417  -53.581  54.945  1
648633  94.449  -53.602  54.952  1
648634  94.482  -53.621  54.957  1
648635  94.514  -53.641  54.960  1
648636  94.547  -53.660  54.963  1
648637  94.576  -53.678  54.966  1
648638  94.601  -53.691  54.969  1
648639  94.625  -53.705  54.968  1
648640  94.649  -53.719  54.970  1
648641  94.674  -53.732  54.973  1
648642  94.698  -53.747  54.975  1
648643  94.723  -53.760  54.976  1
648644  94.747  -53.774  54.975  1
648645  94.772  -53.787  54.968  1
648646  94.796  -53.801  54.958  1
648647  94.821  -53.815  54.950  1
648648  94.845  -53.828  54.942  1
648649  94.870  -53.842  54.933  1
648650  94.894  -53.856  54.927  1
648651  94.918  -53.870  54.926  1
648652  94.943  -53.884  54.928  1
648653  94.967  -53.897  54.925  1
648654  94.992  -53.911  54.916  1
648655  95.016  -53.925  54.896  1
648656  95.040  -53.937  54.869  1
648657  95.063  -53.950  54.835  1
648658  95.087  -53.962  54.796  1
648659  95.111  -53.974  54.757  1
648660  95.134  -53.986  54.716  1
648661  95.158  -53.999  54.675  1
648662  95.182  -54.011  54.627  1
648663  95.205  -54.023  54.575  1
648664  95.229  -54.036  54.524  1
648665  95.253  -54.048  54.473  1
648666  95.279  -54.062  54.428  1
648667  95.314  -54.080  54.386  1
648668  95.337  -54.096  54.343  1
648669  95.361  -54.112  54.300  1
648670  95.385  -54.127  54.257  1
648671  95.409  -54.141  54.216  1
648672  95.433  -54.151  54.176  1
648673  95.458  -54.160  54.141  1
648674  95.482  -54.171  54.106  1
648675  95.506  -54.181  54.072  1
648676  95.531  -54.192  54.039  1
648677  95.555  -54.201  54.010  1
648678  95.580  -54.212  53.985  1
648679  95.604  -54.222  53.964  1
648680  95.628  -54.232  53.942  1
648681  95.653  -54.242  53.924  1
648682  95.677  -54.253  53.907  1
648683  95.702  -54.263  53.890  1
648684  95.739  -54.270  53.873  1
648685  95.775  -54.277  53.855  1
648686  95.812  -54.284  53.830  1
648687  95.839  -54.301  53.804  1
648688  95.865  -54.319  53.778  1
648689  95.890  -54.337  53.754  1
648690  95.916  -54.355  53.730  1
648691  95.941  -54.373  53.704  1
648692  95.967  -54.392  53.675  1
648693  95.992  -54.410  53.643  1
648694  96.018  -54.428  53.607  1
648695  96.043  -54.446  53.566  1
648696  96.068  -54.464  53.520  1
648697  96.094  -54.483  53.468  1
648698  96.119  -54.501  53.413  1
648699  96.145  -54.519  53.360  1
648700  96.174  -54.534  53.309  1
648701  96.203  -54.549  53.259  1
648702  96.233  -54.565  53.212  1
648703  96.260  -54.578  53.165  1
648704  96.286  -54.591  53.120  1
648705  96.312  -54.604  53.075  1
648706  96.337  -54.617  53.029  1
648707  96.363  -54.629  52.983  1
648708  96.388  -54.642  52.938  1
648709  96.415  -54.655  52.891  1
648710  96.443  -54.667  52.841  1
648711  96.472  -54.679  52.792  1
648712  96.500  -54.687  52.742  1
648713  96.528  -54.695  52.692  1
648714  96.557  -54.703  52.642  1
648715  96.586  -54.710  52.593  1
648716  96.614  -54.717  52.547  1
648717  96.643  -54.724  52.505  1
648718  96.672  -54.731  52.464  1
648719  96.701  -54.738  52.424  1
648720  96.730  -54.745  52.385  1
648721  96.759  -54.753  52.343  1
648722  96.790  -54.761  52.297  1
648723  96.821  -54.770  52.245  1
648724  96.853  -54.779  52.190  1
648725  96.884  -54.787  52.133  1
648726  96.915  -54.797  52.075  1
648727  96.947  -54.805  52.016  1
648728  96.978  -54.814  51.955  1
648729  97.009  -54.822  51.894  1
648730  97.040  -54.831  51.832  1
648731  97.072  -54.840  51.770  1
648732  97.110  -54.852  51.705  1
648733  97.150  -54.865  51.638  1
648734  97.189  -54.877  51.569  1
648735  97.229  -54.890  51.498  1
648736  97.269  -54.902  51.425  1
648737  97.308  -54.914  51.350  1
648738  97.341  -54.926  51.277  1
648739  97.367  -54.925  51.201  1
648740  97.390  -54.925  51.119  1
648741  97.413  -54.924  51.042  1
648742  97.436  -54.923  50.969  1
648743  97.459  -54.922  50.898  1
648744  97.483  -54.922  50.829  1
648745  97.506  -54.920  50.763  1
648746  97.529  -54.919  50.697  1
648747  97.552  -54.919  50.634  1
648748  97.575  -54.918  50.572  1
648749  97.598  -54.917  50.511  1
648750  97.621  -54.916  50.452  1
648751  97.644  -54.916  50.395  1
649214  90.916  -51.457  56.904  4
649215  90.944  -51.467  56.909  4
649216  90.956  -51.483  56.916  4
649217  90.967  -51.499  56.924  4
649218  90.979  -51.515  56.933  4
649219  90.991  -51.530  56.943  4
649220  91.003  -51.546  56.953  4
649221  91.014  -51.562  56.965  4
649222  91.026  -51.578  56.975  4
649223  91.038  -51.594  56.988  4
649224  91.049  -51.609  57.002  4
649225  91.062  -51.625  57.019  4
649226  91.073  -51.641  57.041  4
649227  91.088  -51.654  57.066  4
649228  91.118  -51.673  57.090  4
649229  91.151  -51.699  57.115  4
649230  91.183  -51.725  57.129  4
649231  91.215  -51.750  57.139  4
649232  91.247  -51.776  57.144  4
649233  91.279  -51.801  57.142  4
649234  91.311  -51.827  57.135  4
649235  91.348  -51.850  57.134  4
649236  91.398  -51.860  57.132  4
649237  91.448  -51.872  57.129  4
649238  91.499  -51.882  57.122  4
649239  91.549  -51.893  57.112  4
649240  91.589  -51.910  57.101  4
649241  91.626  -51.926  57.094  4
649242  91.661  -51.943  57.089  4
649243  91.692  -51.958  57.083  4
649244  91.723  -51.973  57.076  4
649245  91.754  -51.989  57.066  4
649246  91.785  -52.004  57.052  4
649247  91.816  -52.020  57.038  4
649248  91.847  -52.036  57.023  4
649249  91.878  -52.051  57.009  4
649250  91.909  -52.067  56.994  4
649251  91.940  -52.083  56.977  4
649252  91.970  -52.098  56.960  4
649253  92.001  -52.114  56.942  4
649254  92.032  -52.129  56.922  4
649255  92.063  -52.145  56.900  4
649256  92.094  -52.160  56.881  4
649257  92.123  -52.179  56.858  4
649258  92.150  -52.199  56.834  4
649259  92.177  -52.220  56.810  4
649260  92.205  -52.240  56.785  4
649261  92.232  -52.261  56.757  4
649262  92.260  -52.282  56.725  4
649263  92.287  -52.302  56.691  4
649264  92.314  -52.323  56.655  4
649265  92.341  -52.343  56.618  4
649266  92.369  -52.365  56.578  4
649267  92.396  -52.385  56.538  4
649268  92.423  -52.405  56.498  4
649269  92.450  -52.426  56.453  4
649270  92.491  -52.455  56.404  4
649271  92.532  -52.484  56.354  4
649272  92.573  -52.512  56.303  4
649273  92.613  -52.541  56.252  4
649274  92.654  -52.569  56.200  4
649275  92.698  -52.587  56.148  4
649276  92.746  -52.593  56.096  4
649277  92.794  -52.600  56.045  4
649278  92.842  -52.606  55.994  4
649279  92.889  -52.612  55.943  4
649280  92.938  -52.618  55.893  4
649281  92.972  -52.631  55.843  4
649282  92.991  -52.653  55.796  4
649283  93.017  -52.671  55.747  4
649284  93.047  -52.686  55.699  4
649285  93.077  -52.700  55.651  4
649286  93.107  -52.715  55.604  4
649287  93.137  -52.729  55.559  4
649288  93.167  -52.744  55.515  4
649289  93.197  -52.759  55.472  4
649290  93.227  -52.777  55.430  4
649291  93.258  -52.795  55.388  4
649318  94.082  -53.301  54.848  1
649319  94.112  -53.319  54.849  1
649320  94.143  -53.338  54.851  1
649321  94.174  -53.357  54.856  1
649322  94.204  -53.375  54.861  1
649323  94.235  -53.394  54.867  1
649324  94.265  -53.413  54.874  1
649325  94.295  -53.431  54.882  1
649326  94.326  -53.450  54.890  1
649327  94.356  -53.469  54.897  1
649328  94.387  -53.487  54.905  1
649329  94.417  -53.506  54.913  1
649330  94.406  -53.512  54.921  1
649331  94.382  -53.513  54.928  1
649332  94.398  -53.530  54.936  1
649333  94.428  -53.551  54.946  1
649334  94.461  -53.571  54.953  1
649335  94.494  -53.590  54.958  1
649336  94.527  -53.610  54.962  1
649337  94.559  -53.630  54.963  1
649338  94.592  -53.650  54.964  1
649339  94.618  -53.664  54.965  1
649340  94.642  -53.678  54.963  1
649341  94.667  -53.691  54.963  1
649342  94.691  -53.705  54.964  1
649343  94.715  -53.719  54.965  1
649344  94.740  -53.732  54.965  1
649345  94.764  -53.746  54.964  1
649346  94.789  -53.760  54.960  1
649347  94.813  -53.774  54.954  1
649348  94.838  -53.787  54.951  1
649349  94.862  -53.801  54.944  1
649350  94.887  -53.815  54.939  1
649351  94.911  -53.828  54.936  1
649352  94.935  -53.842  54.936  1
649353  94.960  -53.856  54.933  1
649354  94.984  -53.870  54.924  1
649355  95.009  -53.884  54.908  1
649356  95.033  -53.897  54.889  1
649357  95.058  -53.911  54.864  1
649358  95.082  -53.925  54.832  1
649359  95.107  -53.938  54.796  1
649360  95.131  -53.952  54.759  1
649361  95.156  -53.966  54.720  1
649362  95.180  -53.979  54.678  1
649363  95.204  -53.994  54.630  1
649364  95.229  -54.007  54.577  1
649365  95.252  -54.019  54.525  1
649366  95.276  -54.031  54.477  1
649367  95.300  -54.043  54.437  1
649368  95.328  -54.059  54.397  1
649369  95.352  -54.075  54.356  1
649370  95.376  -54.085  54.314  1
649371  95.400  -54.095  54.271  1
649372  95.425  -54.106  54.230  1
649373  95.449  -54.116  54.191  1
649374  95.474  -54.126  54.157  1
649375  95.498  -54.136  54.122  1
649376  95.523  -54.147  54.089  1
649377  95.547  -54.157  54.057  1
649378  95.571  -54.167  54.028  1
649379  95.596  -54.177  54.003  1
649380  95.620  -54.188  53.982  1
649381  95.644  -54.198  53.961  1
649382  95.669  -54.207  53.944  1
649383  95.693  -54.218  53.928  1
649384  95.718  -54.228  53.911  1
649385  95.751  -54.236  53.893  1
649386  95.788  -54.243  53.871  1
649387  95.823  -54.252  53.844  1
649388  95.848  -54.270  53.816  1
649389  95.874  -54.289  53.790  1
649390  95.899  -54.307  53.766  1
649391  95.924  -54.325  53.742  1
649392  95.950  -54.343  53.717  1
649393  95.975  -54.361  53.689  1
649394  96.001  -54.380  53.658  1
649395  96.026  -54.398  53.623  1
649396  96.052  -54.416  53.582  1
649397  96.077  -54.434  53.535  1
649398  96.103  -54.452  53.482  1
649399  96.128  -54.471  53.427  1
649400  96.154  -54.489  53.376  1
649401  96.180  -54.507  53.326  1
649402  96.209  -54.521  53.279  1
649403  96.239  -54.536  53.231  1
649404  96.266  -54.550  53.184  1
649405  96.292  -54.563  53.138  1
649406  96.317  -54.576  53.093  1
649407  96.342  -54.588  53.048  1
649408  96.369  -54.601  53.000  1
649409  96.396  -54.613  52.953  1
649410  96.424  -54.626  52.904  1
649411  96.452  -54.638  52.854  1
649412  96.480  -54.651  52.805  1
649413  96.509  -54.662  52.757  1
649414  96.537  -54.670  52.710  1
649415  96.566  -54.678  52.663  1
649416  96.594  -54.686  52.618  1
649417  96.622  -54.694  52.574  1
649418  96.651  -54.702  52.534  1
649419  96.680  -54.709  52.495  1
649420  96.709  -54.715  52.456  1
649421  96.737  -54.723  52.417  1
649422  96.766  -54.730  52.377  1
649423  96.797  -54.738  52.333  1
649424  96.828  -54.747  52.283  1
649425  96.860  -54.756  52.229  1
649426  96.891  -54.765  52.172  1
649427  96.922  -54.773  52.113  1
649428  96.953  -54.782  52.055  1
649429  96.984  -54.791  51.996  1
649430  97.016  -54.800  51.937  1
649431  97.047  -54.809  51.878  1
649432  97.079  -54.817  51.819  1
649433  97.111  -54.826  51.756  1
649434  97.151  -54.839  51.690  1
649435  97.190  -54.851  51.622  1
649436  97.230  -54.864  51.551  1
649437  97.270  -54.876  51.477  1
649438  97.310  -54.887  51.403  1
649439  97.350  -54.897  51.331  1
649440  97.375  -54.900  51.255  1
649441  97.398  -54.900  51.172  1
649442  97.422  -54.899  51.094  1
649443  97.445  -54.898  51.020  1
649444  97.468  -54.897  50.947  1
649445  97.491  -54.897  50.877  1
649446  97.514  -54.896  50.811  1
649447  97.537  -54.894  50.744  1
649448  97.560  -54.894  50.679  1
649449  97.583  -54.893  50.617  1
649450  97.606  -54.892  50.554  1
649451  97.630  -54.891  50.494  1
649452  97.653  -54.891  50.436  1
649453  97.676  -54.890  50.377  1
649454  97.699  -54.889  50.320  1
649455  97.720  -54.882  50.265  1
649915  90.936  -51.424  56.893  4
649916  90.949  -51.439  56.900  4
649917  90.961  -51.455  56.906  4
649918  90.972  -51.471  56.913  4
649919  90.984  -51.487  56.921  4
649920  90.996  -51.503  56.931  4
649921  91.008  -51.519  56.942  4
649922  91.019  -51.534  56.952  4
649923  91.031  -51.550  56.963  4
649924  91.043  -51.566  56.975  4
649925  91.054  -51.581  56.989  4
649926  91.067  -51.597  57.006  4
649927  91.078  -51.613  57.026  4
649928  91.092  -51.628  57.050  4
649929  91.122  -51.646  57.073  4
649930  91.154  -51.672  57.097  4
649931  91.186  -51.697  57.111  4
649932  91.218  -51.723  57.120  4
649933  91.250  -51.749  57.125  4
649934  91.282  -51.775  57.124  4
649935  91.319  -51.796  57.116  4
649936  91.370  -51.807  57.116  4
649937  91.421  -51.818  57.114  4
649938  91.471  -51.829  57.111  4
649939  91.522  -51.840  57.105  4
649940  91.569  -51.852  57.097  4
649941  91.607  -51.869  57.087  4
649942  91.645  -51.885  57.081  4
649943  91.680  -51.902  57.078  4
649944  91.711  -51.918  57.073  4
649945  91.742  -51.933  57.066  4
649946  91.773  -51.948  57.055  4
649947  91.804  -51.964  57.042  4
649948  91.835  -51.979  57.027  4
649949  91.866  -51.995  57.013  4
649950  91.896  -52.011  56.999  4
649951  91.927  -52.026  56.985  4
649952  91.958  -52.042  56.969  4
649953  91.989  -52.058  56.952  4
649954  92.020  -52.073  56.935  4
649955  92.051  -52.089  56.916  4
649956  92.082  -52.104  56.896  4
649957  92.113  -52.120  56.876  4
649958  92.144  -52.135  56.854  4
649959  92.175  -52.150  56.830  4
649960  92.205  -52.167  56.806  4
649961  92.233  -52.187  56.781  4
649962  92.260  -52.208  56.753  4
649963  92.287  -52.228  56.723  4
649964  92.314  -52.249  56.690  4
649965  92.342  -52.270  56.655  4
649966  92.369  -52.290  56.618  4
649967  92.397  -52.311  56.580  4
649968  92.424  -52.331  56.540  4
649969  92.451  -52.352  56.499  4
649970  92.479  -52.373  56.455  4
649971  92.519  -52.402  56.406  4
649972  92.560  -52.430  56.355  4
649973  92.600  -52.459  56.305  4
649974  92.641  -52.487  56.255  4
649975  92.682  -52.516  56.204  4
649976  92.722  -52.545  56.153  4
649977  92.769  -52.556  56.104  4
649978  92.816  -52.562  56.054  4
649979  92.865  -52.568  56.005  4
649980  92.913  -52.574  55.954  4
649981  92.957  -52.581  55.905  4
649982  92.977  -52.603  55.855  4
649983  93.003  -52.621  55.807  4
649984  93.033  -52.636  55.758  4
649985  93.063  -52.650  55.710  4
649986  93.093  -52.665  55.661  4
649987  93.123  -52.679  55.614  4
649988  93.153  -52.695  55.567  4
649989  93.184  -52.714  55.523  4
649990  93.214  -52.733  55.480  4
649991  93.245  -52.751  55.437  4
649992  93.275  -52.770  55.395  4
650020  94.130  -53.294  54.850  1
650021  94.160  -53.313  54.851  1
650022  94.191  -53.331  54.856  1
650023  94.221  -53.350  54.860  1
650024  94.252  -53.369  54.866  1
650025  94.282  -53.387  54.873  1
650026  94.313  -53.406  54.880  1
650027  94.343  -53.425  54.888  1
650028  94.373  -53.443  54.896  1
650029  94.404  -53.462  54.903  1
650030  94.435  -53.481  54.911  1
650031  94.432  -53.490  54.919  1
650032  94.408  -53.491  54.928  1
650033  94.408  -53.501  54.937  1
650034  94.441  -53.520  54.947  1
650035  94.474  -53.540  54.955  1
650036  94.506  -53.559  54.960  1
650037  94.539  -53.579  54.962  1
650038  94.572  -53.599  54.963  1
650039  94.605  -53.618  54.964  1
650040  94.635  -53.636  54.962  1
650041  94.659  -53.650  54.959  1
650042  94.684  -53.664  54.959  1
650043  94.708  -53.678  54.958  1
650044  94.733  -53.691  54.958  1
650045  94.757  -53.705  54.959  1
650046  94.781  -53.719  54.958  1
650047  94.806  -53.732  54.957  1
650048  94.830  -53.746  54.958  1
650049  94.855  -53.759  54.957  1
650050  94.879  -53.774  54.951  1
650051  94.904  -53.787  54.945  1
650052  94.928  -53.801  54.942  1
650053  94.953  -53.815  54.941  1
650054  94.977  -53.828  54.934  1
650055  95.001  -53.842  54.918  1
650056  95.026  -53.856  54.899  1
650057  95.050  -53.869  54.882  1
650058  95.075  -53.884  54.860  1
650059  95.099  -53.897  54.831  1
650060  95.124  -53.911  54.800  1
650061  95.148  -53.925  54.765  1
650062  95.173  -53.938  54.728  1
650063  95.197  -53.952  54.686  1
650064  95.222  -53.966  54.639  1
650065  95.246  -53.979  54.587  1
650066  95.270  -53.994  54.534  1
650067  95.295  -54.007  54.486  1
650068  95.319  -54.022  54.449  1
650069  95.340  -54.037  54.411  1
650070  95.367  -54.044  54.370  1
650071  95.392  -54.051  54.327  1
650072  95.417  -54.061  54.285  1
650073  95.441  -54.071  54.244  1
650074  95.465  -54.082  54.206  1
650075  95.490  -54.091  54.173  1
650076  95.514  -54.102  54.139  1
650077  95.539  -54.112  54.105  1
650078  95.563  -54.122  54.074  1
650079  95.588  -54.132  54.045  1
650080  95.612  -54.142  54.018  1
650081  95.636  -54.153  53.998  1
650082  95.661  -54.163  53.979  1
650083  95.685  -54.173  53.962  1
650084  95.709  -54.183  53.947  1
650085  95.734  -54.194  53.931  1
650086  95.764  -54.202  53.912  1
650087  95.801  -54.210  53.888  1
650088  95.831  -54.223  53.857  1
650089  95.856  -54.241  53.827  1
650090  95.882  -54.259  53.800  1
650091  95.908  -54.277  53.775  1
650092  95.933  -54.295  53.752  1
650093  95.959  -54.314  53.728  1
650094  95.984  -54.332  53.700  1
650095  96.010  -54.350  53.671  1
650096  96.035  -54.368  53.635  1
650097  96.060  -54.386  53.594  1
650098  96.086  -54.405  53.547  1
650099  96.111  -54.423  53.495  1
650100  96.137  -54.441  53.440  1
650101  96.162  -54.459  53.390  1
650102  96.188  -54.477  53.342  1
650103  96.216  -54.494  53.296  1
650104  96.245  -54.508  53.250  1
650105  96.271  -54.522  53.203  1
650106  96.297  -54.535  53.154  1
650107  96.322  -54.547  53.106  1
650108  96.349  -54.560  53.059  1
650109  96.377  -54.572  53.012  1
650110  96.404  -54.585  52.965  1
650111  96.432  -54.597  52.916  1
650112  96.460  -54.609  52.868  1
650113  96.489  -54.622  52.821  1
650114  96.518  -54.635  52.774  1
650115  96.546  -54.644  52.729  1
650116  96.575  -54.652  52.686  1
650117  96.603  -54.660  52.644  1
650118  96.631  -54.668  52.602  1
650119  96.660  -54.677  52.562  1
650120  96.688  -54.685  52.524  1
650121  96.716  -54.693  52.486  1
650122  96.745  -54.700  52.447  1
650123  96.773  -54.708  52.407  1
650124  96.804  -54.715  52.364  1
650125  96.835  -54.724  52.317  1
650126  96.866  -54.733  52.265  1
650127  96.898  -54.742  52.208  1
650128  96.929  -54.750  52.151  1
650129  96.960  -54.759  52.094  1
650130  96.992  -54.768  52.037  1
650131  97.023  -54.777  51.982  1
650132  97.054  -54.786  51.926  1
650133  97.085  -54.794  51.869  1
650134  97.117  -54.803  51.808  1
650135  97.152  -54.812  51.743  1
650136  97.192  -54.823  51.674  1
650137  97.233  -54.834  51.602  1
650138  97.273  -54.845  51.528  1
650139  97.314  -54.856  51.454  1
650140  97.353  -54.866  51.382  1
650141  97.387  -54.862  51.306  1
650142  97.407  -54.875  51.226  1
650143  97.430  -54.874  51.147  1
650144  97.453  -54.873  51.070  1
650145  97.476  -54.872  50.997  1
650146  97.500  -54.872  50.925  1
650147  97.523  -54.871  50.859  1
650148  97.545  -54.869  50.792  1
650149  97.569  -54.869  50.726  1
650150  97.592  -54.868  50.662  1
650151  97.615  -54.867  50.598  1
650152  97.638  -54.866  50.537  1
650153  97.661  -54.866  50.478  1
650154  97.684  -54.865  50.418  1
650155  97.707  -54.862  50.360  1
650156  97.728  -54.855  50.302  1
650157  97.749  -54.849  50.246  1
650158  97.771  -54.842  50.191  1
650159  97.792  -54.836  50.138  1
650616  90.942  -51.396  56.883  4
650617  90.954  -51.412  56.890  4
650618  90.966  -51.428  56.896  4
650619  90.977  -51.443  56.902  4
650620  90.990  -51.459  56.910  4
650621  91.001  -51.475  56.919  4
650622  91.013  -51.490  56.930  4
650623  91.024  -51.506  56.940  4
650624  91.036  -51.522  56.951  4
650625  91.048  -51.538  56.962  4
650626  91.060  -51.553  56.976  4
650627  91.072  -51.569  56.991  4
650628  91.083  -51.585  57.009  4
650629  91.095  -51.601  57.032  4
650630  91.125  -51.619  57.054  4
650631  91.157  -51.644  57.072  4
650632  91.189  -51.670  57.088  4
650633  91.221  -51.696  57.098  4
650634  91.253  -51.722  57.104  4
650635  91.292  -51.742  57.104  4
650636  91.342  -51.754  57.098  4
650637  91.393  -51.764  57.098  4
650638  91.443  -51.776  57.097  4
650639  91.494  -51.786  57.094  4
650640  91.544  -51.797  57.088  4
650641  91.588  -51.811  57.082  4
650642  91.625  -51.829  57.074  4
650643  91.663  -51.845  57.071  4
650644  91.699  -51.862  57.069  4
650645  91.730  -51.877  57.065  4
650646  91.760  -51.892  57.058  4
650647  91.792  -51.908  57.047  4
650648  91.822  -51.923  57.032  4
650649  91.854  -51.939  57.017  4
650650  91.884  -51.954  57.003  4
650651  91.915  -51.970  56.990  4
650652  91.946  -51.986  56.976  4
650653  91.977  -52.001  56.961  4
650654  92.008  -52.017  56.945  4
650655  92.039  -52.032  56.928  4
650656  92.070  -52.048  56.910  4
650657  92.101  -52.064  56.891  4
650658  92.132  -52.079  56.871  4
650659  92.163  -52.095  56.851  4
650660  92.194  -52.110  56.828  4
650661  92.225  -52.125  56.805  4
650662  92.255  -52.141  56.780  4
650663  92.287  -52.156  56.753  4
650664  92.315  -52.175  56.723  4
650665  92.343  -52.195  56.690  4
650666  92.370  -52.217  56.655  4
650667  92.397  -52.237  56.618  4
650668  92.424  -52.258  56.580  4
650669  92.451  -52.278  56.540  4
650670  92.479  -52.299  56.500  4
650671  92.506  -52.320  56.456  4
650672  92.547  -52.348  56.407  4
650673  92.587  -52.377  56.356  4
650674  92.628  -52.405  56.306  4
650675  92.669  -52.434  56.257  4
650676  92.710  -52.463  56.208  4
650677  92.750  -52.492  56.160  4
650678  92.791  -52.518  56.112  4
650679  92.840  -52.524  56.064  4
650680  92.887  -52.530  56.016  4
650681  92.935  -52.536  55.967  4
650682  92.963  -52.554  55.917  4
650683  92.989  -52.571  55.868  4
650684  93.019  -52.585  55.820  4
650685  93.049  -52.600  55.771  4
650686  93.079  -52.615  55.722  4
650687  93.110  -52.633  55.673  4
650688  93.140  -52.651  55.624  4
650689  93.170  -52.670  55.578  4
650690  93.201  -52.689  55.533  4
650691  93.231  -52.707  55.489  4
650692  93.262  -52.726  55.445  4
650693  93.292  -52.745  55.403  4
650721  94.147  -53.269  54.851  1
650722  94.178  -53.287  54.853  1
650723  94.208  -53.306  54.856  1
650724  94.239  -53.325  54.860  1
650725  94.269  -53.343  54.866  1
650726  94.299  -53.362  54.872  1
650727  94.330  -53.381  54.878  1
650728  94.360  -53.399  54.885  1
650729  94.391  -53.418  54.894  1
650730  94.421  -53.437  54.901  1
650731  94.452  -53.456  54.909  1
650732  94.458  -53.467  54.918  1
650733  94.434  -53.468  54.927  1
650734  94.432  -53.475  54.937  1
650735  94.454  -53.490  54.946  1
650736  94.486  -53.509  54.955  1
650737  94.519  -53.529  54.958  1
650738  94.552  -53.549  54.960  1
650739  94.584  -53.568  54.960  1
650740  94.617  -53.587  54.960  1
650741  94.650  -53.607  54.959  1
650742  94.676  -53.622  54.956  1
650743  94.701  -53.636  54.955  1
650744  94.725  -53.650  54.955  1
650745  94.750  -53.664  54.956  1
650746  94.774  -53.678  54.958  1
650747  94.799  -53.691  54.960  1
650748  94.823  -53.705  54.963  1
650749  94.847  -53.719  54.969  1
650750  94.872  -53.732  54.965  1
650751  94.896  -53.746  54.956  1
650752  94.921  -53.759  54.946  1
650753  94.945  -53.774  54.940  1
650754  94.970  -53.787  54.934  1
650755  94.994  -53.801  54.929  1
650756  95.019  -53.815  54.908  1
650757  95.043  -53.828  54.889  1
650758  95.067  -53.842  54.873  1
650759  95.092  -53.856  54.855  1
650760  95.116  -53.869  54.832  1
650761  95.141  -53.883  54.806  1
650762  95.165  -53.897  54.772  1
650763  95.190  -53.911  54.736  1
650764  95.214  -53.925  54.695  1
650765  95.239  -53.938  54.648  1
650766  95.263  -53.952  54.596  1
650767  95.287  -53.966  54.544  1
650768  95.309  -53.985  54.496  1
650769  95.330  -54.004  54.459  1
650770  95.349  -54.019  54.422  1
650771  95.375  -54.026  54.382  1
650772  95.401  -54.033  54.340  1
650773  95.426  -54.040  54.298  1
650774  95.453  -54.047  54.258  1
650775  95.478  -54.054  54.222  1
650776  95.505  -54.060  54.188  1
650777  95.530  -54.067  54.154  1
650778  95.555  -54.077  54.120  1
650779  95.580  -54.088  54.089  1
650780  95.604  -54.098  54.059  1
650781  95.628  -54.108  54.033  1
650782  95.653  -54.118  54.011  1
650783  95.677  -54.129  53.991  1
650784  95.701  -54.138  53.975  1
650785  95.726  -54.149  53.961  1
650786  95.750  -54.159  53.947  1
650787  95.776  -54.169  53.929  1
650788  95.813  -54.176  53.908  1
650789  95.840  -54.193  53.875  1
650790  95.866  -54.211  53.840  1
650791  95.891  -54.229  53.808  1
650792  95.916  -54.248  53.781  1
650793  95.942  -54.266  53.758  1
650794  95.967  -54.284  53.735  1
650795  95.992  -54.302  53.710  1
650796  96.018  -54.320  53.680  1
650797  96.044  -54.339  53.645  1
650798  96.069  -54.357  53.603  1
650799  96.095  -54.375  53.555  1
650800  96.120  -54.393  53.505  1
650801  96.146  -54.411  53.451  1
650802  96.171  -54.430  53.402  1
650803  96.196  -54.448  53.355  1
650804  96.222  -54.466  53.311  1
650805  96.251  -54.481  53.266  1
650806  96.277  -54.494  53.220  1
650807  96.303  -54.506  53.170  1
650808  96.330  -54.519  53.120  1
650809  96.358  -54.531  53.072  1
650810  96.385  -54.543  53.025  1
650811  96.412  -54.556  52.978  1
650812  96.440  -54.568  52.931  1
650813  96.469  -54.581  52.884  1
650814  96.498  -54.593  52.839  1
650815  96.526  -54.606  52.794  1
650816  96.555  -54.618  52.751  1
650817  96.584  -54.627  52.712  1
650818  96.612  -54.635  52.672  1
650819  96.640  -54.643  52.632  1
650820  96.669  -54.651  52.593  1
650821  96.697  -54.659  52.555  1
650822  96.725  -54.668  52.518  1
650823  96.753  -54.675  52.479  1
650824  96.782  -54.684  52.439  1
650825  96.811  -54.691  52.396  1
650826  96.842  -54.699  52.349  1
650827  96.874  -54.707  52.298  1
650828  96.905  -54.715  52.245  1
650829  96.937  -54.724  52.189  1
650830  96.968  -54.732  52.133  1
650831  97.000  -54.740  52.078  1
650832  97.031  -54.749  52.023  1
650833  97.063  -54.757  51.966  1
650834  97.094  -54.765  51.909  1
650835  97.125  -54.774  51.848  1
650836  97.156  -54.781  51.786  1
650837  97.196  -54.792  51.721  1
650838  97.237  -54.803  51.651  1
650839  97.277  -54.814  51.576  1
650840  97.317  -54.825  51.501  1
650841  97.357  -54.834  51.428  1
650842  97.390  -54.830  51.356  1
650843  97.422  -54.829  51.279  1
650844  97.440  -54.844  51.199  1
650845  97.462  -54.848  51.121  1
650846  97.485  -54.847  51.046  1
650847  97.508  -54.847  50.974  1
650848  97.531  -54.846  50.906  1
650849  97.554  -54.845  50.840  1
650850  97.577  -54.844  50.773  1
650851  97.600  -54.843  50.708  1
650852  97.624  -54.842  50.644  1
650853  97.647  -54.841  50.581  1
650854  97.670  -54.840  50.521  1
650855  97.693  -54.840  50.460  1
650856  97.715  -54.834  50.400  1
650857  97.736  -54.828  50.341  1
650858  97.757  -54.822  50.284  1
650859  97.779  -54.815  50.228  1
650860  97.800  -54.809  50.173  1
650861  97.832  -54.810  50.118  1
650862  97.873  -54.819  50.065  1
650863  97.913  -54.828  50.013  1
651318  90.959  -51.384  56.879  4
651319  90.971  -51.399  56.885  4
651320  90.982  -51.415  56.891  4
651321  90.995  -51.431  56.898  4
651322  91.006  -51.447  56.908  4
651323  91.018  -51.462  56.918  4
651324  91.030  -51.478  56.928  4
651325  91.041  -51.494  56.938  4
651326  91.053  -51.510  56.949  4
651327  91.065  -51.526  56.962  4
651328  91.077  -51.542  56.976  4
651329  91.088  -51.557  56.992  4
651330  91.100  -51.573  57.012  4
651331  91.129  -51.591  57.031  4
651332  91.161  -51.617  57.048  4
651333  91.192  -51.643  57.061  4
651334  91.225  -51.669  57.071  4
651335  91.264  -51.689  57.078  4
651336  91.314  -51.700  57.081  4
651337  91.365  -51.710  57.079  4
651338  91.416  -51.722  57.082  4
651339  91.466  -51.732  57.081  4
651340  91.516  -51.744  57.077  4
651341  91.567  -51.754  57.072  4
651342  91.606  -51.771  57.067  4
651343  91.644  -51.788  57.061  4
651344  91.681  -51.804  57.060  4
651345  91.718  -51.821  57.058  4
651346  91.748  -51.837  57.055  4
651347  91.780  -51.852  57.049  4
651348  91.810  -51.867  57.038  4
651349  91.842  -51.883  57.021  4
651350  91.872  -51.898  57.007  4
651351  91.903  -51.914  56.992  4
651352  91.934  -51.929  56.978  4
651353  91.965  -51.945  56.965  4
651354  91.996  -51.960  56.951  4
651355  92.027  -51.976  56.935  4
651356  92.058  -51.992  56.918  4
651357  92.089  -52.007  56.902  4
651358  92.120  -52.023  56.884  4
651359  92.151  -52.039  56.867  4
651360  92.181  -52.054  56.849  4
651361  92.213  -52.069  56.828  4
651362  92.243  -52.085  56.805  4
651363  92.274  -52.100  56.780  4
651364  92.305  -52.116  56.753  4
651365  92.336  -52.131  56.723  4
651366  92.367  -52.147  56.689  4
651367  92.398  -52.163  56.654  4
651368  92.425  -52.183  56.617  4
651369  92.452  -52.205  56.579  4
651370  92.480  -52.225  56.540  4
651371  92.507  -52.246  56.499  4
651372  92.534  -52.266  56.454  4
651373  92.575  -52.295  56.407  4
651374  92.615  -52.324  56.357  4
651375  92.656  -52.352  56.309  4
651376  92.697  -52.381  56.261  4
651377  92.737  -52.409  56.213  4
651378  92.778  -52.438  56.166  4
651379  92.818  -52.467  56.120  4
651380  92.862  -52.487  56.074  4
651381  92.910  -52.492  56.029  4
651382  92.948  -52.504  55.981  4
651383  92.975  -52.521  55.931  4
651384  93.005  -52.535  55.883  4
651385  93.035  -52.551  55.834  4
651386  93.066  -52.570  55.785  4
651387  93.096  -52.589  55.735  4
651388  93.127  -52.607  55.686  4
651389  93.157  -52.626  55.636  4
651390  93.188  -52.645  55.589  4
651391  93.218  -52.663  55.544  4
651392  93.249  -52.682  55.499  4
651393  93.279  -52.701  55.455  4
651394  93.310  -52.719  55.413  4
651422  94.164  -53.243  54.853  1
651423  94.195  -53.262  54.853  1
651424  94.225  -53.281  54.856  1
651425  94.256  -53.300  54.859  1
651426  94.286  -53.318  54.864  1
651427  94.317  -53.337  54.870  1
651428  94.347  -53.356  54.876  1
651429  94.378  -53.374  54.882  1
651430  94.408  -53.393  54.890  1
651431  94.439  -53.412  54.897  1
651432  94.469  -53.430  54.906  1
651433  94.484  -53.444  54.916  1
651434  94.460  -53.446  54.926  1
651435  94.465  -53.455  54.937  1
651436  94.481  -53.466  54.944  1
651437  94.499  -53.478  54.951  1
651438  94.532  -53.498  54.955  1
651439  94.564  -53.518  54.955  1
651440  94.597  -53.537  54.955  1
651441  94.630  -53.557  54.953  1
651442  94.663  -53.577  54.954  1
651443  94.693  -53.595  54.951  1
651444  94.718  -53.609  54.950  1
651445  94.742  -53.622  54.950  1
651446  94.767  -53.636  54.953  1
651447  94.791  -53.650  54.956  1
651448  94.816  -53.663  54.960  1
651449  94.840  -53.678  54.966  1
651450  94.864  -53.691  54.969  1
651451  94.889  -53.705  54.963  1
651452  94.913  -53.719  54.950  1
651453  94.938  -53.732  54.937  1
651454  94.962  -53.746  54.926  1
651455  94.987  -53.759  54.917  1
651456  95.012  -53.773  54.905  1
651457  95.036  -53.787  54.887  1
651458  95.060  -53.801  54.874  1
651459  95.085  -53.815  54.864  1
651460  95.109  -53.828  54.851  1
651461  95.133  -53.842  54.832  1
651462  95.158  -53.856  54.807  1
651463  95.182  -53.869  54.777  1
651464  95.207  -53.883  54.741  1
651465  95.232  -53.897  54.701  1
651466  95.256  -53.911  54.655  1
651467  95.277  -53.930  54.604  1
651468  95.298  -53.948  54.553  1
651469  95.320  -53.967  54.505  1
651470  95.340  -53.985  54.466  1
651471  95.359  -54.000  54.432  1
651472  95.383  -54.009  54.394  1
651473  95.409  -54.016  54.353  1
651474  95.435  -54.022  54.311  1
651475  95.461  -54.029  54.272  1
651476  95.486  -54.036  54.236  1
651477  95.513  -54.044  54.203  1
651478  95.538  -54.051  54.168  1
651479  95.564  -54.057  54.134  1
651480  95.590  -54.064  54.103  1
651481  95.616  -54.071  54.073  1
651482  95.642  -54.078  54.046  1
651483  95.668  -54.085  54.023  1
651484  95.693  -54.094  54.000  1
651485  95.718  -54.104  53.982  1
651486  95.742  -54.114  53.969  1
651487  95.766  -54.124  53.957  1
651488  95.791  -54.135  53.941  1
651489  95.823  -54.145  53.922  1
651490  95.848  -54.163  53.889  1
651491  95.874  -54.181  53.854  1
651492  95.899  -54.199  53.818  1
651493  95.925  -54.217  53.786  1
651494  95.951  -54.236  53.758  1
651495  95.976  -54.254  53.735  1
651496  96.002  -54.272  53.710  1
651497  96.027  -54.290  53.680  1
651498  96.052  -54.308  53.645  1
651499  96.078  -54.327  53.603  1
651500  96.103  -54.345  53.557  1
651501  96.129  -54.363  53.508  1
651502  96.154  -54.381  53.456  1
651503  96.180  -54.399  53.410  1
651504  96.205  -54.417  53.366  1
651505  96.231  -54.436  53.324  1
651506  96.257  -54.453  53.281  1
651507  96.284  -54.465  53.235  1
651508  96.311  -54.477  53.187  1
651509  96.338  -54.490  53.135  1
651510  96.366  -54.502  53.087  1
651511  96.393  -54.515  53.040  1
651512  96.421  -54.527  52.994  1
651513  96.449  -54.540  52.948  1
651514  96.477  -54.552  52.901  1
651515  96.506  -54.565  52.858  1
651516  96.535  -54.577  52.815  1
651517  96.564  -54.590  52.774  1
651518  96.593  -54.601  52.738  1
651519  96.621  -54.609  52.702  1
651520  96.649  -54.618  52.663  1
651521  96.678  -54.626  52.625  1
651522  96.706  -54.634  52.588  1
651523  96.734  -54.642  52.550  1
651524  96.762  -54.650  52.511  1
651525  96.791  -54.658  52.470  1
651526  96.820  -54.664  52.426  1
651527  96.851  -54.670  52.378  1
651528  96.882  -54.678  52.329  1
651529  96.913  -54.687  52.277  1
651530  96.945  -54.695  52.223  1
651531  96.976  -54.703  52.167  1
651532  97.008  -54.712  52.111  1
651533  97.039  -54.720  52.055  1
651534  97.071  -54.728  51.998  1
651535  97.102  -54.736  51.940  1
651536  97.134  -54.744  51.878  1
651537  97.164  -54.752  51.817  1
651538  97.200  -54.761  51.753  1
651539  97.240  -54.772  51.685  1
651540  97.281  -54.783  51.615  1
651541  97.321  -54.794  51.543  1
651542  97.360  -54.802  51.471  1
651543  97.394  -54.798  51.400  1
651544  97.428  -54.793  51.325  1
651545  97.455  -54.798  51.248  1
651546  97.473  -54.813  51.170  1
651547  97.494  -54.822  51.095  1
651548  97.516  -54.822  51.023  1
651549  97.539  -54.821  50.954  1
651550  97.563  -54.820  50.887  1
651551  97.586  -54.818  50.821  1
651552  97.609  -54.818  50.756  1
651553  97.632  -54.817  50.691  1
651554  97.655  -54.816  50.627  1
651555  97.678  -54.815  50.566  1
651556  97.701  -54.814  50.504  1
651557  97.723  -54.808  50.444  1
651558  97.744  -54.801  50.383  1
651559  97.766  -54.794  50.324  1
651560  97.787  -54.788  50.265  1
651561  97.808  -54.781  50.209  1
651562  97.846  -54.787  50.154  1
651563  97.886  -54.796  50.098  1
651564  97.923  -54.804  50.045  1
652019  90.964  -51.356  56.870  4
652020  90.976  -51.372  56.875  4
652021  90.988  -51.387  56.881  4
652022  91.000  -51.403  56.888  4
652023  91.011  -51.419  56.896  4
652024  91.023  -51.435  56.906  4
652025  91.035  -51.451  56.916  4
652026  91.046  -51.466  56.926  4
652027  91.058  -51.482  56.936  4
652028  91.070  -51.498  56.948  4
652029  91.082  -51.514  56.961  4
652030  91.093  -51.530  56.976  4
652031  91.105  -51.546  56.993  4
652032  91.132  -51.564  57.009  4
652033  91.164  -51.590  57.023  4
652034  91.196  -51.616  57.035  4
652035  91.236  -51.635  57.044  4
652036  91.287  -51.646  57.052  4
652037  91.337  -51.657  57.057  4
652038  91.387  -51.668  57.060  4
652039  91.438  -51.679  57.065  4
652040  91.489  -51.690  57.064  4
652041  91.539  -51.701  57.060  4
652042  91.587  -51.713  57.056  4
652043  91.625  -51.730  57.052  4
652044  91.662  -51.747  57.046  4
652045  91.700  -51.764  57.046  4
652046  91.736  -51.781  57.044  4
652047  91.768  -51.796  57.042  4
652048  91.798  -51.811  57.037  4
652049  91.829  -51.827  57.027  4
652050  91.860  -51.842  57.010  4
652051  91.891  -51.858  56.995  4
652052  91.922  -51.873  56.980  4
652053  91.953  -51.889  56.966  4
652054  91.984  -51.904  56.954  4
652055  92.015  -51.920  56.941  4
652056  92.046  -51.935  56.926  4
652057  92.077  -51.951  56.910  4
652058  92.107  -51.967  56.895  4
652059  92.139  -51.982  56.880  4
652060  92.169  -51.998  56.865  4
652061  92.201  -52.014  56.848  4
652062  92.231  -52.029  56.828  4
652063  92.262  -52.044  56.805  4
652064  92.293  -52.060  56.780  4
652065  92.324  -52.075  56.751  4
652066  92.355  -52.091  56.721  4
652067  92.386  -52.106  56.688  4
652068  92.417  -52.122  56.653  4
652069  92.448  -52.137  56.616  4
652070  92.479  -52.153  56.577  4
652071  92.507  -52.172  56.540  4
652072  92.534  -52.192  56.497  4
652073  92.562  -52.213  56.452  4
652074  92.602  -52.242  56.405  4
652075  92.643  -52.271  56.357  4
652076  92.684  -52.299  56.311  4
652077  92.724  -52.327  56.264  4
652078  92.765  -52.356  56.218  4
652079  92.806  -52.385  56.173  4
652080  92.846  -52.414  56.129  4
652081  92.887  -52.443  56.087  4
652082  92.933  -52.455  56.042  4
652083  92.961  -52.471  55.995  4
652084  92.992  -52.489  55.946  4
652085  93.022  -52.507  55.898  4
652086  93.053  -52.526  55.850  4
652087  93.083  -52.545  55.800  4
652088  93.114  -52.563  55.749  4
652089  93.144  -52.582  55.699  4
652090  93.174  -52.601  55.650  4
652091  93.205  -52.620  55.601  4
652092  93.235  -52.638  55.556  4
652093  93.266  -52.657  55.510  4
652094  93.296  -52.676  55.465  4
652095  93.327  -52.694  55.423  4
652123  94.182  -53.218  54.854  1
652124  94.212  -53.237  54.854  1
652125  94.243  -53.256  54.856  1
652126  94.273  -53.274  54.858  1
652127  94.303  -53.293  54.863  1
652128  94.334  -53.312  54.868  1
652129  94.364  -53.330  54.874  1
652130  94.395  -53.349  54.879  1
652131  94.425  -53.368  54.886  1
652132  94.456  -53.386  54.893  1
652133  94.487  -53.405  54.902  1
652134  94.510  -53.422  54.911  1
652135  94.486  -53.424  54.921  1
652136  94.498  -53.433  54.930  1
652137  94.513  -53.445  54.936  1
652138  94.530  -53.456  54.941  1
652139  94.546  -53.468  54.945  1
652140  94.576  -53.487  54.946  1
652141  94.609  -53.506  54.945  1
652142  94.642  -53.526  54.944  1
652143  94.675  -53.546  54.944  1
652144  94.707  -53.565  54.943  1
652145  94.735  -53.581  54.943  1
652146  94.759  -53.595  54.944  1
652147  94.784  -53.609  54.947  1
652148  94.808  -53.622  54.951  1
652149  94.833  -53.636  54.956  1
652150  94.857  -53.650  54.965  1
652151  94.882  -53.663  54.962  1
652152  94.906  -53.678  54.952  1
652153  94.930  -53.691  54.938  1
652154  94.955  -53.705  54.922  1
652155  94.979  -53.719  54.908  1
652156  95.004  -53.732  54.896  1
652157  95.028  -53.746  54.881  1
652158  95.053  -53.759  54.869  1
652159  95.077  -53.773  54.862  1
652160  95.102  -53.787  54.855  1
652161  95.126  -53.801  54.845  1
652162  95.150  -53.815  54.828  1
652163  95.175  -53.828  54.803  1
652164  95.199  -53.842  54.775  1
652165  95.224  -53.856  54.740  1
652166  95.245  -53.875  54.701  1
652167  95.266  -53.893  54.658  1
652168  95.288  -53.912  54.609  1
652169  95.309  -53.930  54.559  1
652170  95.331  -53.949  54.513  1
652171  95.350  -53.965  54.476  1
652172  95.369  -53.980  54.442  1
652173  95.391  -53.992  54.405  1
652174  95.417  -53.999  54.364  1
652175  95.443  -54.006  54.323  1
652176  95.469  -54.013  54.284  1
652177  95.494  -54.019  54.249  1
652178  95.521  -54.026  54.217  1
652179  95.546  -54.033  54.182  1
652180  95.572  -54.040  54.147  1
652181  95.598  -54.047  54.116  1
652182  95.624  -54.054  54.088  1
652183  95.651  -54.060  54.060  1
652184  95.676  -54.067  54.034  1
652185  95.702  -54.074  54.007  1
652186  95.728  -54.081  53.986  1
652187  95.754  -54.088  53.972  1
652188  95.780  -54.095  53.961  1
652189  95.806  -54.102  53.948  1
652190  95.832  -54.115  53.930  1
652191  95.857  -54.133  53.900  1
652192  95.883  -54.151  53.866  1
652193  95.908  -54.170  53.829  1
652194  95.934  -54.188  53.792  1
652195  95.959  -54.206  53.759  1
652196  95.984  -54.225  53.732  1
652197  96.010  -54.243  53.705  1
652198  96.035  -54.261  53.674  1
652199  96.061  -54.279  53.638  1
652200  96.086  -54.298  53.596  1
652201  96.112  -54.316  53.551  1
652202  96.137  -54.334  53.505  1
652203  96.163  -54.353  53.457  1
652204  96.188  -54.371  53.413  1
652205  96.214  -54.389  53.372  1
652206  96.239  -54.408  53.332  1
652207  96.265  -54.425  53.290  1
652208  96.292  -54.436  53.245  1
652209  96.320  -54.449  53.197  1
652210  96.347  -54.461  53.148  1
652211  96.374  -54.474  53.101  1
652212  96.402  -54.486  53.055  1
652213  96.429  -54.499  53.009  1
652214  96.457  -54.511  52.963  1
652215  96.486  -54.524  52.918  1
652216  96.515  -54.536  52.874  1
652217  96.544  -54.549  52.833  1
652218  96.573  -54.562  52.797  1
652219  96.601  -54.574  52.765  1
652220  96.630  -54.583  52.730  1
652221  96.658  -54.592  52.693  1
652222  96.687  -54.600  52.657  1
652223  96.715  -54.609  52.621  1
652224  96.743  -54.616  52.584  1
652225  96.771  -54.624  52.543  1
652226  96.800  -54.632  52.500  1
652227  96.830  -54.637  52.453  1
652228  96.860  -54.643  52.405  1
652229  96.891  -54.649  52.356  1
652230  96.922  -54.658  52.305  1
652231  96.954  -54.666  52.252  1
652232  96.985  -54.674  52.197  1
652233  97.016  -54.682  52.140  1
652234  97.048  -54.690  52.082  1
652235  97.079  -54.699  52.024  1
652236  97.110  -54.707  51.965  1
652237  97.142  -54.715  51.904  1
652238  97.173  -54.723  51.842  1
652239  97.204  -54.730  51.779  1
652240  97.244  -54.741  51.715  1
652241  97.285  -54.753  51.650  1
652242  97.325  -54.763  51.582  1
652243  97.364  -54.770  51.512  1
652244  97.397  -54.766  51.441  1
652245  97.431  -54.762  51.368  1
652246  97.465  -54.758  51.293  1
652247  97.488  -54.767  51.218  1
652248  97.506  -54.782  51.144  1
652249  97.525  -54.797  51.073  1
652250  97.548  -54.796  51.003  1
652251  97.571  -54.795  50.936  1
652252  97.594  -54.793  50.869  1
652253  97.617  -54.793  50.804  1
652254  97.641  -54.792  50.738  1
652255  97.664  -54.791  50.673  1
652256  97.687  -54.790  50.611  1
652257  97.709  -54.787  50.550  1
652258  97.730  -54.781  50.488  1
652259  97.752  -54.774  50.426  1
652260  97.773  -54.768  50.365  1
652261  97.795  -54.761  50.305  1
652262  97.818  -54.756  50.247  1
652263  97.859  -54.765  50.191  1
652264  97.899  -54.773  50.134  1
652265  97.933  -54.781  50.078  1
652266  97.968  -54.788  50.025  1
652720  90.969  -51.328  56.861  4
652721  90.981  -51.344  56.866  4
652722  90.993  -51.360  56.871  4
652723  91.005  -51.376  56.877  4
652724  91.016  -51.391  56.885  4
652725  91.028  -51.407  56.894  4
652726  91.040  -51.423  56.904  4
652727  91.051  -51.439  56.913  4
652728  91.063  -51.455  56.923  4
652729  91.075  -51.471  56.933  4
652730  91.087  -51.486  56.945  4
652731  91.098  -51.502  56.958  4
652732  91.110  -51.518  56.973  4
652733  91.135  -51.537  56.987  4
652734  91.167  -51.563  56.998  4
652735  91.208  -51.581  57.009  4
652736  91.258  -51.593  57.018  4
652737  91.309  -51.603  57.026  4
652738  91.360  -51.615  57.033  4
652739  91.410  -51.625  57.040  4
652740  91.461  -51.636  57.047  4
652741  91.511  -51.647  57.047  4
652742  91.562  -51.658  57.043  4
652743  91.605  -51.672  57.039  4
652744  91.643  -51.689  57.035  4
652745  91.680  -51.707  57.030  4
652746  91.718  -51.723  57.028  4
652747  91.755  -51.740  57.027  4
652748  91.786  -51.756  57.025  4
652749  91.817  -51.771  57.020  4
652750  91.848  -51.786  57.013  4
652751  91.879  -51.802  56.997  4
652752  91.910  -51.817  56.982  4
652753  91.941  -51.833  56.967  4
652754  91.972  -51.848  56.954  4
652755  92.003  -51.864  56.943  4
652756  92.034  -51.879  56.932  4
652757  92.065  -51.895  56.918  4
652758  92.095  -51.910  56.903  4
652759  92.127  -51.926  56.889  4
652760  92.157  -51.942  56.875  4
652761  92.189  -51.957  56.861  4
652762  92.219  -51.973  56.846  4
652763  92.250  -51.988  56.827  4
652764  92.281  -52.004  56.803  4
652765  92.312  -52.019  56.777  4
652766  92.343  -52.035  56.748  4
652767  92.374  -52.050  56.718  4
652768  92.405  -52.066  56.685  4
652769  92.436  -52.081  56.650  4
652770  92.466  -52.097  56.614  4
652771  92.498  -52.112  56.577  4
652772  92.528  -52.128  56.537  4
652773  92.560  -52.143  56.495  4
652774  92.590  -52.160  56.450  4
652775  92.630  -52.188  56.403  4
652776  92.670  -52.217  56.357  4
652777  92.710  -52.248  56.313  4
652778  92.750  -52.278  56.267  4
652779  92.790  -52.308  56.223  4
652780  92.830  -52.339  56.179  4
652781  92.869  -52.368  56.138  4
652782  92.909  -52.399  56.098  4
652783  92.947  -52.427  56.056  4
652784  92.978  -52.445  56.010  4
652785  93.008  -52.464  55.962  4
652786  93.039  -52.483  55.915  4
652787  93.069  -52.501  55.866  4
652788  93.100  -52.520  55.816  4
652789  93.131  -52.538  55.765  4
652790  93.161  -52.557  55.715  4
652791  93.192  -52.576  55.665  4
652792  93.222  -52.594  55.616  4
652793  93.253  -52.613  55.568  4
652794  93.283  -52.632  55.522  4
652795  93.314  -52.650  55.478  4
652796  93.344  -52.669  55.435  4
652824  94.199  -53.193  54.856  1
652825  94.229  -53.212  54.856  1
652826  94.260  -53.230  54.856  1
652827  94.290  -53.249  54.857  1
652828  94.321  -53.268  54.861  1
652829  94.351  -53.286  54.866  1
652830  94.382  -53.305  54.871  1
652831  94.412  -53.324  54.876  1
652832  94.443  -53.342  54.882  1
652833  94.473  -53.361  54.889  1
652834  94.504  -53.380  54.897  1
652835  94.535  -53.399  54.906  1
652836  94.514  -53.402  54.914  1
652837  94.531  -53.413  54.922  1
652838  94.546  -53.424  54.926  1
652839  94.562  -53.436  54.931  1
652840  94.578  -53.447  54.933  1
652841  94.594  -53.458  54.934  1
652842  94.622  -53.475  54.934  1
652843  94.654  -53.495  54.934  1
652844  94.687  -53.515  54.933  1
652845  94.720  -53.534  54.932  1
652846  94.752  -53.553  54.931  1
652847  94.776  -53.567  54.932  1
652848  94.801  -53.581  54.934  1
652849  94.825  -53.595  54.939  1
652850  94.850  -53.609  54.944  1
652851  94.875  -53.622  54.948  1
652852  94.899  -53.636  54.944  1
652853  94.923  -53.650  54.933  1
652854  94.948  -53.663  54.918  1
652855  94.972  -53.677  54.901  1
652856  94.996  -53.691  54.885  1
652857  95.021  -53.705  54.870  1
652858  95.045  -53.719  54.859  1
652859  95.070  -53.732  54.853  1
652860  95.095  -53.746  54.851  1
652861  95.119  -53.759  54.847  1
652862  95.143  -53.773  54.837  1
652863  95.168  -53.787  54.821  1
652864  95.192  -53.801  54.795  1
652865  95.213  -53.819  54.768  1
652866  95.235  -53.838  54.735  1
652867  95.256  -53.856  54.698  1
652868  95.277  -53.875  54.658  1
652869  95.299  -53.894  54.612  1
652870  95.320  -53.912  54.563  1
652871  95.341  -53.930  54.520  1
652872  95.360  -53.946  54.486  1
652873  95.379  -53.961  54.454  1
652874  95.399  -53.975  54.418  1
652875  95.425  -53.982  54.377  1
652876  95.451  -53.988  54.336  1
652877  95.477  -53.995  54.297  1
652878  95.502  -54.002  54.262  1
652879  95.529  -54.009  54.229  1
652880  95.555  -54.016  54.193  1
652881  95.581  -54.022  54.158  1
652882  95.607  -54.029  54.125  1
652883  95.632  -54.036  54.095  1
652884  95.659  -54.043  54.067  1
652885  95.684  -54.051  54.039  1
652886  95.710  -54.057  54.011  1
652887  95.736  -54.064  53.987  1
652888  95.761  -54.071  53.969  1
652889  95.787  -54.078  53.956  1
652890  95.812  -54.085  53.944  1
652891  95.838  -54.094  53.927  1
652892  95.866  -54.106  53.905  1
652893  95.891  -54.124  53.874  1
652894  95.916  -54.142  53.838  1
652895  95.942  -54.160  53.799  1
652896  95.967  -54.179  53.761  1
652897  95.993  -54.197  53.728  1
652898  96.018  -54.215  53.695  1
652899  96.044  -54.233  53.662  1
652900  96.069  -54.251  53.625  1
652901  96.095  -54.270  53.584  1
652902  96.120  -54.289  53.541  1
652903  96.146  -54.307  53.499  1
652904  96.171  -54.325  53.456  1
652905  96.196  -54.343  53.414  1
652906  96.222  -54.361  53.375  1
652907  96.247  -54.380  53.336  1
652908  96.273  -54.398  53.295  1
652909  96.300  -54.409  53.252  1
652910  96.328  -54.421  53.205  1
652911  96.355  -54.433  53.158  1
652912  96.383  -54.445  53.113  1
652913  96.410  -54.458  53.068  1
652914  96.438  -54.470  53.023  1
652915  96.466  -54.483  52.979  1
652916  96.495  -54.495  52.935  1
652917  96.523  -54.508  52.892  1
652918  96.552  -54.520  52.853  1
652919  96.581  -54.533  52.820  1
652920  96.610  -54.545  52.789  1
652921  96.639  -54.558  52.756  1
652922  96.667  -54.567  52.721  1
652923  96.695  -54.574  52.686  1
652924  96.724  -54.583  52.650  1
652925  96.752  -54.591  52.613  1
652926  96.781  -54.599  52.571  1
652927  96.810  -54.605  52.526  1
652928  96.840  -54.610  52.478  1
652929  96.870  -54.615  52.428  1
652930  96.899  -54.621  52.377  1
652931  96.931  -54.628  52.326  1
652932  96.962  -54.637  52.273  1
652933  96.994  -54.645  52.219  1
652934  97.025  -54.653  52.163  1
652935  97.056  -54.662  52.105  1
652936  97.088  -54.670  52.048  1
652937  97.119  -54.678  51.990  1
652938  97.150  -54.687  51.929  1
652939  97.181  -54.693  51.868  1
652940  97.212  -54.701  51.807  1
652941  97.248  -54.710  51.746  1
652942  97.288  -54.721  51.683  1
652943  97.328  -54.732  51.617  1
652944  97.367  -54.738  51.548  1
652945  97.401  -54.734  51.478  1
652946  97.435  -54.730  51.407  1
652947  97.468  -54.726  51.335  1
652948  97.503  -54.721  51.263  1
652949  97.521  -54.736  51.193  1
652950  97.539  -54.751  51.122  1
652951  97.558  -54.766  51.052  1
652952  97.580  -54.770  50.984  1
652953  97.603  -54.769  50.918  1
652954  97.626  -54.768  50.852  1
652955  97.649  -54.767  50.787  1
652956  97.672  -54.766  50.721  1
652957  97.695  -54.765  50.657  1
652958  97.717  -54.760  50.596  1
652959  97.738  -54.753  50.533  1
652960  97.759  -54.746  50.471  1
652961  97.781  -54.740  50.409  1
652962  97.803  -54.734  50.347  1
652963  97.831  -54.734  50.288  1
652964  97.872  -54.742  50.229  1
652965  97.909  -54.750  50.171  1
652966  97.944  -54.757  50.114  1
652967  97.978  -54.765  50.058  1
652968  98.012  -54.771  50.004  1
653422  90.986  -51.316  56.856  4
653423  90.998  -51.332  56.861  4
653424  91.010  -51.348  56.866  4
653425  91.021  -51.364  56.873  4
653426  91.033  -51.380  56.882  4
653427  91.045  -51.395  56.891  4
653428  91.057  -51.411  56.900  4
653429  91.069  -51.427  56.909  4
653430  91.080  -51.443  56.919  4
653431  91.092  -51.459  56.930  4
653432  91.104  -51.475  56.942  4
653433  91.115  -51.490  56.956  4
653434  91.139  -51.510  56.967  4
653435  91.180  -51.528  56.978  4
653436  91.231  -51.539  56.986  4
653437  91.281  -51.550  56.994  4
653438  91.332  -51.561  57.003  4
653439  91.382  -51.572  57.013  4
653440  91.433  -51.583  57.022  4
653441  91.484  -51.594  57.027  4
653442  91.534  -51.605  57.027  4
653443  91.585  -51.616  57.024  4
653444  91.624  -51.632  57.020  4
653445  91.661  -51.649  57.017  4
653446  91.699  -51.666  57.012  4
653447  91.736  -51.682  57.010  4
653448  91.774  -51.700  57.009  4
653449  91.805  -51.715  57.007  4
653450  91.836  -51.730  57.002  4
653451  91.867  -51.746  56.996  4
653452  91.898  -51.761  56.981  4
653453  91.929  -51.777  56.967  4
653454  91.960  -51.792  56.954  4
653455  91.991  -51.808  56.943  4
653456  92.021  -51.823  56.933  4
653457  92.053  -51.839  56.923  4
653458  92.083  -51.854  56.910  4
653459  92.115  -51.870  56.897  4
653460  92.145  -51.885  56.883  4
653461  92.176  -51.901  56.871  4
653462  92.207  -51.917  56.858  4
653463  92.238  -51.932  56.842  4
653464  92.269  -51.948  56.824  4
653465  92.300  -51.963  56.800  4
653466  92.331  -51.979  56.774  4
653467  92.362  -51.994  56.745  4
653468  92.393  -52.010  56.715  4
653469  92.424  -52.025  56.683  4
653470  92.454  -52.041  56.648  4
653471  92.486  -52.056  56.613  4
653472  92.518  -52.074  56.575  4
653473  92.553  -52.093  56.535  4
653474  92.583  -52.111  56.494  4
653475  92.611  -52.131  56.449  4
653476  92.643  -52.160  56.403  4
653477  92.683  -52.190  56.359  4
653478  92.722  -52.221  56.316  4
653479  92.762  -52.251  56.271  4
653480  92.802  -52.280  56.227  4
653481  92.842  -52.311  56.185  4
653482  92.881  -52.341  56.146  4
653483  92.921  -52.371  56.108  4
653484  92.961  -52.402  56.067  4
653485  92.993  -52.421  56.024  4
653486  93.023  -52.440  55.978  4
653487  93.054  -52.459  55.932  4
653488  93.085  -52.478  55.882  4
653489  93.116  -52.496  55.831  4
653490  93.146  -52.515  55.782  4
653491  93.177  -52.534  55.730  4
653492  93.207  -52.552  55.679  4
653493  93.238  -52.571  55.630  4
653494  93.269  -52.589  55.582  4
653495  93.299  -52.608  55.535  4
653496  93.330  -52.626  55.490  4
653497  93.360  -52.645  55.447  4
653498  93.391  -52.663  55.404  4
653525  94.216  -53.168  54.857  1
653526  94.247  -53.186  54.857  1
653527  94.277  -53.205  54.857  1
653528  94.308  -53.224  54.857  1
653529  94.338  -53.242  54.859  1
653530  94.368  -53.261  54.863  1
653531  94.399  -53.280  54.868  1
653532  94.429  -53.299  54.872  1
653533  94.460  -53.317  54.878  1
653534  94.491  -53.336  54.885  1
653535  94.521  -53.355  54.893  1
653536  94.552  -53.374  54.900  1
653537  94.547  -53.381  54.907  1
653538  94.563  -53.392  54.913  1
653539  94.579  -53.403  54.915  1
653540  94.595  -53.415  54.919  1
653541  94.611  -53.426  54.921  1
653542  94.627  -53.437  54.922  1
653543  94.643  -53.449  54.922  1
653544  94.667  -53.465  54.922  1
653545  94.700  -53.484  54.920  1
653546  94.733  -53.503  54.918  1
653547  94.765  -53.523  54.917  1
653548  94.793  -53.540  54.918  1
653549  94.818  -53.553  54.920  1
653550  94.842  -53.567  54.922  1
653551  94.867  -53.581  54.927  1
653552  94.892  -53.595  54.926  1
653553  94.916  -53.609  54.919  1
653554  94.941  -53.622  54.908  1
653555  94.965  -53.636  54.894  1
653556  94.989  -53.650  54.879  1
653557  95.014  -53.663  54.863  1
653558  95.038  -53.677  54.850  1
653559  95.062  -53.690  54.844  1
653560  95.087  -53.705  54.841  1
653561  95.112  -53.719  54.838  1
653562  95.136  -53.732  54.833  1
653563  95.161  -53.746  54.823  1
653564  95.182  -53.764  54.805  1
653565  95.203  -53.783  54.782  1
653566  95.225  -53.801  54.757  1
653567  95.246  -53.820  54.727  1
653568  95.267  -53.838  54.691  1
653569  95.288  -53.857  54.651  1
653570  95.310  -53.875  54.609  1
653571  95.331  -53.894  54.564  1
653572  95.351  -53.911  54.525  1
653573  95.370  -53.926  54.496  1
653574  95.389  -53.941  54.467  1
653575  95.407  -53.957  54.432  1
653576  95.433  -53.964  54.392  1
653577  95.459  -53.971  54.351  1
653578  95.485  -53.978  54.311  1
653579  95.511  -53.985  54.274  1
653580  95.537  -53.991  54.239  1
653581  95.563  -53.999  54.202  1
653582  95.589  -54.006  54.165  1
653583  95.615  -54.013  54.130  1
653584  95.640  -54.019  54.099  1
653585  95.666  -54.026  54.070  1
653586  95.691  -54.033  54.041  1
653587  95.716  -54.041  54.011  1
653588  95.741  -54.048  53.984  1
653589  95.767  -54.054  53.962  1
653590  95.792  -54.061  53.946  1
653591  95.817  -54.068  53.933  1
653592  95.842  -54.076  53.917  1
653593  95.870  -54.088  53.896  1
653594  95.898  -54.100  53.869  1
653595  95.925  -54.114  53.836  1
653596  95.950  -54.132  53.799  1
653597  95.976  -54.151  53.760  1
653598  96.001  -54.170  53.723  1
653599  96.027  -54.188  53.686  1
653600  96.052  -54.206  53.649  1
653601  96.078  -54.224  53.610  1
653602  96.103  -54.242  53.570  1
653603  96.128  -54.261  53.530  1
653604  96.154  -54.279  53.491  1
653605  96.179  -54.297  53.450  1
653606  96.205  -54.316  53.411  1
653607  96.230  -54.334  53.374  1
653608  96.256  -54.352  53.336  1
653609  96.281  -54.370  53.297  1
653610  96.309  -54.382  53.256  1
653611  96.336  -54.393  53.210  1
653612  96.364  -54.405  53.166  1
653613  96.391  -54.417  53.123  1
653614  96.418  -54.429  53.080  1
653615  96.446  -54.441  53.037  1
653616  96.474  -54.454  52.995  1
653617  96.503  -54.466  52.952  1
653618  96.532  -54.479  52.912  1
653619  96.561  -54.491  52.873  1
653620  96.590  -54.504  52.841  1
653621  96.619  -54.517  52.810  1
653622  96.648  -54.529  52.779  1
653623  96.676  -54.541  52.747  1
653624  96.704  -54.549  52.713  1
653625  96.733  -54.557  52.677  1
653626  96.761  -54.565  52.639  1
653627  96.790  -54.573  52.596  1
653628  96.820  -54.578  52.550  1
653629  96.850  -54.583  52.501  1
653630  96.879  -54.589  52.450  1
653631  96.909  -54.594  52.399  1
653632  96.939  -54.599  52.348  1
653633  96.970  -54.608  52.295  1
653634  97.002  -54.616  52.242  1
653635  97.033  -54.624  52.186  1
653636  97.065  -54.633  52.129  1
653637  97.096  -54.641  52.073  1
653638  97.127  -54.649  52.014  1
653639  97.159  -54.657  51.955  1
653640  97.189  -54.665  51.896  1
653641  97.221  -54.671  51.836  1
653642  97.251  -54.679  51.776  1
653643  97.292  -54.690  51.715  1
653644  97.332  -54.701  51.651  1
653645  97.370  -54.706  51.582  1
653646  97.404  -54.702  51.514  1
653647  97.438  -54.698  51.446  1
653648  97.472  -54.694  51.378  1
653649  97.506  -54.690  51.311  1
653650  97.536  -54.690  51.244  1
653651  97.555  -54.705  51.174  1
653652  97.573  -54.720  51.104  1
653653  97.591  -54.735  51.035  1
653654  97.611  -54.744  50.968  1
653655  97.635  -54.743  50.902  1
653656  97.658  -54.742  50.837  1
653657  97.680  -54.741  50.772  1
653658  97.703  -54.739  50.707  1
653659  97.725  -54.733  50.646  1
653660  97.746  -54.726  50.581  1
653661  97.768  -54.720  50.519  1
653662  97.789  -54.713  50.456  1
653663  97.810  -54.707  50.393  1
653664  97.845  -54.711  50.332  1
653665  97.885  -54.719  50.271  1
653666  97.919  -54.726  50.212  1
653667  97.954  -54.734  50.153  1
653668  97.988  -54.740  50.095  1
653669  98.014  -54.740  50.040  1
653670  98.041  -54.741  49.985  1
654123  90.991  -51.289  56.846  4
654124  91.003  -51.305  56.850  4
654125  91.015  -51.320  56.856  4
654126  91.026  -51.336  56.862  4
654127  91.038  -51.352  56.870  4
654128  91.050  -51.368  56.879  4
654129  91.062  -51.384  56.887  4
654130  91.074  -51.399  56.895  4
654131  91.085  -51.415  56.905  4
654132  91.097  -51.431  56.916  4
654133  91.109  -51.446  56.927  4
654134  91.120  -51.462  56.939  4
654135  91.152  -51.475  56.949  4
654136  91.203  -51.485  56.958  4
654137  91.253  -51.497  56.966  4
654138  91.304  -51.507  56.974  4
654139  91.355  -51.519  56.982  4
654140  91.405  -51.529  56.994  4
654141  91.455  -51.540  57.002  4
654142  91.506  -51.551  57.006  4
654143  91.557  -51.562  57.005  4
654144  91.604  -51.575  57.003  4
654145  91.642  -51.591  56.999  4
654146  91.679  -51.608  56.998  4
654147  91.717  -51.625  56.994  4
654148  91.755  -51.642  56.991  4
654149  91.792  -51.659  56.990  4
654150  91.824  -51.674  56.988  4
654151  91.855  -51.690  56.984  4
654152  91.886  -51.705  56.977  4
654153  91.917  -51.721  56.965  4
654154  91.948  -51.736  56.953  4
654155  91.979  -51.752  56.942  4
654156  92.009  -51.767  56.933  4
654157  92.040  -51.783  56.924  4
654158  92.071  -51.798  56.915  4
654159  92.102  -51.814  56.903  4
654160  92.133  -51.829  56.890  4
654161  92.164  -51.845  56.878  4
654162  92.195  -51.860  56.866  4
654163  92.226  -51.876  56.852  4
654164  92.257  -51.891  56.837  4
654165  92.288  -51.907  56.818  4
654166  92.319  -51.923  56.796  4
654167  92.350  -51.938  56.769  4
654168  92.381  -51.954  56.741  4
654169  92.413  -51.971  56.712  4
654170  92.447  -51.990  56.681  4
654171  92.481  -52.010  56.647  4
654172  92.515  -52.029  56.610  4
654173  92.549  -52.048  56.574  4
654174  92.575  -52.065  56.534  4
654175  92.601  -52.083  56.493  4
654176  92.632  -52.105  56.449  4
654177  92.662  -52.133  56.404  4
654178  92.695  -52.163  56.361  4
654179  92.734  -52.193  56.318  4
654180  92.774  -52.223  56.274  4
654181  92.814  -52.253  56.232  4
654182  92.854  -52.283  56.191  4
654183  92.894  -52.314  56.152  4
654184  92.933  -52.344  56.114  4
654185  92.973  -52.374  56.075  4
654186  93.008  -52.398  56.035  4
654187  93.039  -52.416  55.993  4
654188  93.069  -52.435  55.947  4
654189  93.100  -52.454  55.899  4
654190  93.131  -52.472  55.848  4
654191  93.161  -52.491  55.797  4
654192  93.192  -52.509  55.746  4
654193  93.222  -52.528  55.694  4
654194  93.253  -52.546  55.645  4
654195  93.284  -52.565  55.597  4
654196  93.314  -52.584  55.549  4
654197  93.345  -52.603  55.503  4
654198  93.376  -52.622  55.460  4
654199  93.406  -52.640  55.416  4
654226  94.234  -53.142  54.859  1
654227  94.264  -53.161  54.858  1
654228  94.294  -53.180  54.857  1
654229  94.325  -53.198  54.857  1
654230  94.355  -53.217  54.858  1
654231  94.386  -53.236  54.861  1
654232  94.416  -53.255  54.865  1
654233  94.447  -53.273  54.869  1
654234  94.477  -53.292  54.874  1
654235  94.508  -53.311  54.881  1
654236  94.539  -53.330  54.889  1
654237  94.569  -53.349  54.894  1
654238  94.580  -53.360  54.897  1
654239  94.596  -53.371  54.901  1
654240  94.612  -53.383  54.903  1
654241  94.628  -53.394  54.905  1
654242  94.643  -53.405  54.907  1
654243  94.660  -53.417  54.908  1
654244  94.676  -53.428  54.908  1
654245  94.691  -53.440  54.907  1
654246  94.712  -53.453  54.906  1
654247  94.745  -53.473  54.903  1
654248  94.778  -53.493  54.901  1
654249  94.811  -53.512  54.902  1
654250  94.835  -53.526  54.903  1
654251  94.859  -53.540  54.903  1
654252  94.884  -53.553  54.906  1
654253  94.909  -53.567  54.901  1
654254  94.933  -53.581  54.893  1
654255  94.958  -53.595  54.883  1
654256  94.982  -53.609  54.871  1
654257  95.006  -53.622  54.859  1
654258  95.031  -53.636  54.847  1
654259  95.055  -53.650  54.836  1
654260  95.079  -53.663  54.832  1
654261  95.104  -53.677  54.830  1
654262  95.129  -53.690  54.826  1
654263  95.150  -53.709  54.819  1
654264  95.172  -53.728  54.809  1
654265  95.193  -53.746  54.791  1
654266  95.214  -53.765  54.769  1
654267  95.236  -53.783  54.743  1
654268  95.257  -53.802  54.712  1
654269  95.278  -53.820  54.678  1
654270  95.300  -53.839  54.641  1
654271  95.321  -53.857  54.603  1
654272  95.342  -53.876  54.563  1
654273  95.361  -53.891  54.531  1
654274  95.380  -53.907  54.505  1
654275  95.399  -53.922  54.480  1
654276  95.417  -53.938  54.449  1
654277  95.441  -53.947  54.411  1
654278  95.467  -53.954  54.369  1
654279  95.493  -53.961  54.326  1
654280  95.519  -53.968  54.285  1
654281  95.544  -53.975  54.247  1
654282  95.570  -53.982  54.208  1
654283  95.595  -53.988  54.168  1
654284  95.620  -53.996  54.130  1
654285  95.645  -54.003  54.098  1
654286  95.671  -54.010  54.069  1
654287  95.696  -54.016  54.040  1
654288  95.722  -54.023  54.009  1
654289  95.747  -54.031  53.979  1
654290  95.772  -54.038  53.954  1
654291  95.798  -54.044  53.934  1
654292  95.823  -54.051  53.917  1
654293  95.848  -54.059  53.902  1
654294  95.875  -54.070  53.882  1
654295  95.903  -54.082  53.857  1
654296  95.931  -54.094  53.827  1
654297  95.958  -54.107  53.794  1
654298  95.984  -54.123  53.756  1
654299  96.010  -54.142  53.717  1
654300  96.035  -54.160  53.678  1
654301  96.060  -54.178  53.640  1
654302  96.086  -54.196  53.601  1
654303  96.111  -54.214  53.562  1
654304  96.137  -54.233  53.524  1
654305  96.162  -54.251  53.486  1
654306  96.188  -54.270  53.447  1
654307  96.213  -54.288  53.410  1
654308  96.239  -54.306  53.373  1
654309  96.264  -54.324  53.336  1
654310  96.290  -54.342  53.299  1
654311  96.317  -54.355  53.260  1
654312  96.344  -54.366  53.216  1
654313  96.372  -54.377  53.175  1
654314  96.399  -54.389  53.134  1
654315  96.427  -54.400  53.094  1
654316  96.454  -54.412  53.055  1
654317  96.483  -54.425  53.014  1
654318  96.512  -54.438  52.973  1
654319  96.541  -54.450  52.930  1
654320  96.570  -54.463  52.891  1
654321  96.598  -54.475  52.857  1
654322  96.627  -54.488  52.826  1
654323  96.656  -54.500  52.797  1
654324  96.685  -54.513  52.768  1
654325  96.714  -54.524  52.738  1
654326  96.742  -54.532  52.702  1
654327  96.770  -54.540  52.662  1
654328  96.800  -54.546  52.619  1
654329  96.829  -54.552  52.573  1
654330  96.859  -54.557  52.523  1
654331  96.889  -54.562  52.472  1
654332  96.919  -54.568  52.421  1
654333  96.949  -54.573  52.371  1
654334  96.979  -54.579  52.319  1
654335  97.010  -54.587  52.265  1
654336  97.041  -54.595  52.210  1
654337  97.073  -54.603  52.154  1
654338  97.104  -54.612  52.097  1
654339  97.136  -54.620  52.037  1
654340  97.167  -54.627  51.981  1
654341  97.198  -54.635  51.924  1
654342  97.229  -54.643  51.865  1
654343  97.260  -54.650  51.805  1
654344  97.296  -54.659  51.744  1
654345  97.336  -54.670  51.682  1
654346  97.374  -54.674  51.616  1
654347  97.407  -54.670  51.551  1
654348  97.441  -54.666  51.485  1
654349  97.475  -54.662  51.421  1
654350  97.509  -54.658  51.357  1
654351  97.538  -54.662  51.292  1
654352  97.563  -54.669  51.225  1
654353  97.586  -54.677  51.156  1
654354  97.606  -54.689  51.088  1
654355  97.624  -54.704  51.021  1
654356  97.643  -54.718  50.954  1
654357  97.666  -54.717  50.888  1
654358  97.689  -54.716  50.823  1
654359  97.711  -54.712  50.759  1
654360  97.733  -54.706  50.696  1
654361  97.754  -54.699  50.632  1
654362  97.776  -54.693  50.568  1
654363  97.797  -54.686  50.505  1
654364  97.818  -54.680  50.441  1
654365  97.858  -54.687  50.379  1
654366  97.895  -54.696  50.316  1
654367  97.929  -54.703  50.256  1
654368  97.963  -54.709  50.195  1
654369  97.990  -54.710  50.135  1
654370  98.017  -54.710  50.077  1
654371  98.043  -54.711  50.021  1
654372  98.071  -54.711  49.966  1
654824  90.997  -51.261  56.838  4
654825  91.008  -51.277  56.841  4
654826  91.020  -51.293  56.845  4
654827  91.031  -51.309  56.851  4
654828  91.043  -51.324  56.858  4
654829  91.055  -51.340  56.866  4
654830  91.067  -51.356  56.874  4
654831  91.079  -51.371  56.882  4
654832  91.090  -51.387  56.892  4
654833  91.102  -51.403  56.901  4
654834  91.130  -51.418  56.912  4
654835  91.166  -51.433  56.923  4
654836  91.202  -51.447  56.932  4
654837  91.240  -51.459  56.940  4
654838  91.284  -51.462  56.948  4
654839  91.327  -51.465  56.956  4
654840  91.377  -51.475  56.965  4
654841  91.428  -51.487  56.977  4
654842  91.478  -51.497  56.984  4
654843  91.529  -51.509  56.986  4
654844  91.579  -51.519  56.985  4
654845  91.623  -51.534  56.983  4
654846  91.660  -51.550  56.980  4
654847  91.698  -51.568  56.979  4
654848  91.735  -51.584  56.976  4
654849  91.773  -51.601  56.974  4
654850  91.811  -51.618  56.973  4
654851  91.843  -51.634  56.970  4
654852  91.874  -51.649  56.966  4
654853  91.905  -51.665  56.961  4
654854  91.936  -51.680  56.950  4
654855  91.966  -51.696  56.940  4
654856  91.997  -51.711  56.931  4
654857  92.028  -51.727  56.923  4
654858  92.059  -51.742  56.916  4
654859  92.090  -51.758  56.908  4
654860  92.121  -51.773  56.897  4
654861  92.152  -51.789  56.883  4
654862  92.183  -51.804  56.872  4
654863  92.214  -51.820  56.860  4
654864  92.245  -51.835  56.847  4
654865  92.276  -51.851  56.832  4
654866  92.308  -51.868  56.814  4
654867  92.342  -51.888  56.791  4
654868  92.376  -51.907  56.765  4
654869  92.410  -51.926  56.738  4
654870  92.444  -51.945  56.710  4
654871  92.478  -51.964  56.680  4
654872  92.512  -51.983  56.647  4
654873  92.546  -52.002  56.610  4
654874  92.567  -52.018  56.574  4
654875  92.592  -52.036  56.535  4
654876  92.623  -52.055  56.494  4
654877  92.653  -52.078  56.450  4
654878  92.683  -52.107  56.405  4
654879  92.713  -52.136  56.362  4
654880  92.747  -52.165  56.320  4
654881  92.787  -52.195  56.277  4
654882  92.827  -52.226  56.236  4
654883  92.866  -52.256  56.197  4
654884  92.906  -52.286  56.158  4
654885  92.946  -52.316  56.120  4
654886  92.986  -52.346  56.082  4
654887  93.023  -52.374  56.044  4
654888  93.054  -52.393  56.004  4
654889  93.085  -52.412  55.961  4
654890  93.115  -52.430  55.913  4
654891  93.146  -52.449  55.863  4
654892  93.177  -52.467  55.812  4
654893  93.207  -52.486  55.761  4
654894  93.238  -52.505  55.710  4
654895  93.269  -52.523  55.661  4
654896  93.299  -52.542  55.612  4
654897  93.330  -52.560  55.564  4
654898  93.360  -52.579  55.518  4
654899  93.391  -52.597  55.473  4
654900  93.422  -52.616  55.430  4
654927  94.249  -53.119  54.862  1
654928  94.279  -53.138  54.860  1
654929  94.310  -53.156  54.857  1
654930  94.341  -53.175  54.856  1
654931  94.371  -53.193  54.857  1
654932  94.402  -53.212  54.859  1
654933  94.432  -53.230  54.862  1
654934  94.463  -53.249  54.866  1
654935  94.494  -53.267  54.870  1
654936  94.525  -53.286  54.877  1
654937  94.555  -53.305  54.883  1
654938  94.585  -53.324  54.886  1
654939  94.612  -53.339  54.887  1
654940  94.629  -53.351  54.889  1
654941  94.644  -53.361  54.891  1
654942  94.661  -53.373  54.892  1
654943  94.676  -53.384  54.894  1
654944  94.692  -53.396  54.895  1
654945  94.708  -53.407  54.894  1
654946  94.724  -53.418  54.893  1
654947  94.740  -53.430  54.891  1
654948  94.758  -53.442  54.888  1
654949  94.790  -53.462  54.886  1
654950  94.823  -53.481  54.884  1
654951  94.852  -53.499  54.883  1
654952  94.877  -53.512  54.883  1
654953  94.901  -53.526  54.883  1
654954  94.926  -53.540  54.878  1
654955  94.950  -53.553  54.871  1
654956  94.975  -53.567  54.862  1
654957  94.999  -53.581  54.853  1
654958  95.024  -53.594  54.844  1
654959  95.048  -53.609  54.837  1
654960  95.072  -53.622  54.829  1
654961  95.097  -53.636  54.824  1
654962  95.119  -53.654  54.820  1
654963  95.140  -53.672  54.814  1
654964  95.161  -53.691  54.807  1
654965  95.183  -53.709  54.797  1
654966  95.204  -53.728  54.778  1
654967  95.226  -53.747  54.755  1
654968  95.247  -53.765  54.728  1
654969  95.268  -53.784  54.696  1
654970  95.289  -53.802  54.664  1
654971  95.311  -53.821  54.633  1
654972  95.332  -53.839  54.598  1
654973  95.353  -53.857  54.564  1
654974  95.372  -53.872  54.536  1
654975  95.390  -53.888  54.512  1
654976  95.409  -53.903  54.488  1
654977  95.427  -53.918  54.459  1
654978  95.449  -53.930  54.422  1
654979  95.474  -53.937  54.382  1
654980  95.499  -53.944  54.337  1
654981  95.525  -53.951  54.292  1
654982  95.550  -53.958  54.250  1
654983  95.576  -53.965  54.209  1
654984  95.601  -53.972  54.167  1
654985  95.626  -53.979  54.128  1
654986  95.651  -53.986  54.091  1
654987  95.676  -53.993  54.062  1
654988  95.702  -54.000  54.034  1
654989  95.727  -54.007  54.003  1
654990  95.752  -54.014  53.973  1
654991  95.777  -54.021  53.945  1
654992  95.803  -54.028  53.921  1
654993  95.828  -54.035  53.899  1
654994  95.853  -54.042  53.881  1
654995  95.880  -54.051  53.860  1
654996  95.907  -54.063  53.837  1
654997  95.935  -54.076  53.812  1
654998  95.963  -54.088  53.781  1
654999  95.990  -54.101  53.747  1
655000  96.018  -54.113  53.710  1
655001  96.043  -54.132  53.671  1
655002  96.069  -54.151  53.633  1
655003  96.094  -54.169  53.594  1
655004  96.120  -54.187  53.557  1
655005  96.145  -54.205  53.522  1
655006  96.171  -54.223  53.484  1
655007  96.196  -54.242  53.446  1
655008  96.222  -54.260  53.409  1
655009  96.247  -54.279  53.373  1
655010  96.272  -54.297  53.338  1
655011  96.298  -54.315  53.301  1
655012  96.325  -54.328  53.264  1
655013  96.353  -54.339  53.222  1
655014  96.380  -54.351  53.185  1
655015  96.407  -54.361  53.147  1
655016  96.435  -54.373  53.109  1
655017  96.463  -54.384  53.072  1
655018  96.492  -54.396  53.032  1
655019  96.521  -54.409  52.990  1
655020  96.549  -54.421  52.948  1
655021  96.578  -54.434  52.908  1
655022  96.607  -54.446  52.873  1
655023  96.636  -54.459  52.842  1
655024  96.665  -54.472  52.813  1
655025  96.694  -54.484  52.785  1
655026  96.723  -54.497  52.757  1
655027  96.751  -54.506  52.723  1
655028  96.780  -54.515  52.683  1
655029  96.809  -54.520  52.640  1
655030  96.839  -54.525  52.594  1
655031  96.869  -54.530  52.545  1
655032  96.899  -54.536  52.494  1
655033  96.929  -54.541  52.443  1
655034  96.958  -54.546  52.391  1
655035  96.988  -54.552  52.339  1
655036  97.019  -54.558  52.286  1
655037  97.050  -54.566  52.231  1
655038  97.081  -54.574  52.175  1
655039  97.113  -54.583  52.119  1
655040  97.144  -54.591  52.061  1
655041  97.175  -54.599  52.005  1
655042  97.206  -54.606  51.947  1
655043  97.237  -54.613  51.889  1
655044  97.268  -54.621  51.830  1
655045  97.299  -54.628  51.770  1
655046  97.340  -54.640  51.710  1
655047  97.377  -54.643  51.650  1
655048  97.411  -54.638  51.587  1
655049  97.445  -54.634  51.525  1
655050  97.477  -54.632  51.463  1
655051  97.506  -54.637  51.402  1
655052  97.534  -54.642  51.339  1
655053  97.561  -54.648  51.273  1
655054  97.585  -54.655  51.209  1
655055  97.608  -54.662  51.143  1
655056  97.632  -54.669  51.075  1
655057  97.655  -54.677  51.007  1
655058  97.676  -54.688  50.941  1
655059  97.698  -54.691  50.875  1
655060  97.719  -54.685  50.812  1
655061  97.740  -54.678  50.748  1
655062  97.762  -54.672  50.684  1
655063  97.783  -54.665  50.619  1
655064  97.805  -54.659  50.555  1
655065  97.831  -54.656  50.491  1
655066  97.871  -54.665  50.427  1
655067  97.905  -54.672  50.363  1
655068  97.939  -54.679  50.301  1
655069  97.966  -54.679  50.238  1
655070  97.993  -54.680  50.177  1
655071  98.019  -54.680  50.117  1
655072  98.046  -54.681  50.059  1
655073  98.073  -54.681  50.002  1
655074  98.100  -54.681  49.947  1
655526  91.013  -51.249  56.831  4
655527  91.025  -51.265  56.835  4
655528  91.037  -51.280  56.840  4
655529  91.048  -51.296  56.846  4
655530  91.060  -51.312  56.854  4
655531  91.072  -51.327  56.862  4
655532  91.084  -51.343  56.869  4
655533  91.111  -51.359  56.878  4
655534  91.147  -51.373  56.887  4
655535  91.183  -51.388  56.898  4
655536  91.219  -51.403  56.908  4
655537  91.255  -51.417  56.917  4
655538  91.291  -51.431  56.925  4
655539  91.328  -51.444  56.932  4
655540  91.372  -51.447  56.941  4
655541  91.416  -51.450  56.951  4
655542  91.459  -51.453  56.963  4
655543  91.503  -51.457  56.968  4
655544  91.552  -51.465  56.969  4
655545  91.602  -51.477  56.967  4
655546  91.641  -51.493  56.965  4
655547  91.678  -51.510  56.963  4
655548  91.716  -51.527  56.962  4
655549  91.754  -51.544  56.960  4
655550  91.792  -51.560  56.958  4
655551  91.829  -51.578  56.956  4
655552  91.862  -51.593  56.954  4
655553  91.892  -51.609  56.950  4
655554  91.924  -51.624  56.946  4
655555  91.954  -51.640  56.936  4
655556  91.985  -51.655  56.928  4
655557  92.016  -51.671  56.921  4
655558  92.047  -51.686  56.915  4
655559  92.078  -51.702  56.908  4
655560  92.109  -51.717  56.902  4
655561  92.140  -51.733  56.891  4
655562  92.171  -51.748  56.878  4
655563  92.203  -51.766  56.867  4
655564  92.237  -51.785  56.855  4
655565  92.271  -51.804  56.841  4
655566  92.305  -51.823  56.827  4
655567  92.339  -51.842  56.809  4
655568  92.373  -51.861  56.786  4
655569  92.407  -51.880  56.761  4
655570  92.441  -51.900  56.736  4
655571  92.475  -51.919  56.710  4
655572  92.509  -51.938  56.680  4
655573  92.538  -51.956  56.647  4
655574  92.559  -51.972  56.611  4
655575  92.582  -51.988  56.575  4
655576  92.613  -52.007  56.536  4
655577  92.644  -52.028  56.495  4
655578  92.674  -52.052  56.452  4
655579  92.704  -52.081  56.408  4
655580  92.734  -52.110  56.365  4
655581  92.764  -52.139  56.323  4
655582  92.799  -52.168  56.282  4
655583  92.839  -52.199  56.241  4
655584  92.878  -52.228  56.202  4
655585  92.918  -52.258  56.164  4
655586  92.958  -52.289  56.127  4
655587  92.998  -52.319  56.089  4
655588  93.038  -52.349  56.051  4
655589  93.069  -52.369  56.013  4
655590  93.100  -52.387  55.972  4
655591  93.131  -52.406  55.926  4
655592  93.161  -52.425  55.878  4
655593  93.192  -52.443  55.826  4
655594  93.222  -52.462  55.776  4
655595  93.253  -52.481  55.726  4
655596  93.284  -52.499  55.676  4
655597  93.314  -52.518  55.627  4
655598  93.345  -52.537  55.579  4
655599  93.375  -52.555  55.533  4
655600  93.406  -52.574  55.487  4
655601  93.437  -52.593  55.445  4
655628  94.264  -53.095  54.864  1
655629  94.294  -53.114  54.861  1
655630  94.325  -53.132  54.858  1
655631  94.356  -53.151  54.857  1
655632  94.387  -53.170  54.857  1
655633  94.417  -53.189  54.858  1
655634  94.448  -53.207  54.860  1
655635  94.478  -53.226  54.862  1
655636  94.508  -53.244  54.866  1
655637  94.537  -53.262  54.870  1
655638  94.567  -53.280  54.875  1
655639  94.596  -53.299  54.876  1
655640  94.625  -53.317  54.876  1
655641  94.653  -53.325  54.877  1
655642  94.673  -53.338  54.879  1
655643  94.692  -53.352  54.881  1
655644  94.709  -53.364  54.882  1
655645  94.725  -53.375  54.882  1
655646  94.741  -53.386  54.881  1
655647  94.757  -53.398  54.879  1
655648  94.773  -53.409  54.877  1
655649  94.788  -53.421  54.874  1
655650  94.805  -53.431  54.871  1
655651  94.835  -53.450  54.868  1
655652  94.868  -53.470  54.866  1
655653  94.894  -53.484  54.866  1
655654  94.918  -53.499  54.865  1
655655  94.943  -53.512  54.862  1
655656  94.967  -53.526  54.857  1
655657  94.992  -53.540  54.851  1
655658  95.016  -53.553  54.845  1
655659  95.041  -53.567  54.841  1
655660  95.065  -53.581  54.839  1
655661  95.087  -53.599  54.833  1
655662  95.108  -53.617  54.824  1
655663  95.130  -53.636  54.815  1
655664  95.151  -53.654  54.806  1
655665  95.172  -53.673  54.797  1
655666  95.194  -53.691  54.783  1
655667  95.215  -53.710  54.763  1
655668  95.237  -53.728  54.740  1
655669  95.258  -53.747  54.711  1
655670  95.279  -53.766  54.680  1
655671  95.301  -53.784  54.650  1
655672  95.322  -53.803  54.624  1
655673  95.343  -53.822  54.595  1
655674  95.362  -53.838  54.566  1
655675  95.381  -53.853  54.541  1
655676  95.400  -53.868  54.518  1
655677  95.419  -53.884  54.493  1
655678  95.441  -53.899  54.463  1
655679  95.463  -53.912  54.427  1
655680  95.480  -53.920  54.389  1
655681  95.505  -53.927  54.344  1
655682  95.530  -53.934  54.296  1
655683  95.555  -53.941  54.252  1
655684  95.581  -53.948  54.209  1
655685  95.606  -53.955  54.166  1
655686  95.631  -53.962  54.125  1
655687  95.657  -53.969  54.086  1
655688  95.682  -53.976  54.055  1
655689  95.707  -53.983  54.026  1
655690  95.733  -53.990  53.996  1
655691  95.758  -53.997  53.966  1
655692  95.783  -54.004  53.937  1
655693  95.808  -54.011  53.912  1
655694  95.834  -54.018  53.888  1
655695  95.859  -54.025  53.867  1
655696  95.885  -54.033  53.844  1
655697  95.912  -54.045  53.821  1
655698  95.940  -54.057  53.796  1
655699  95.968  -54.070  53.769  1
655700  95.995  -54.082  53.737  1
655701  96.023  -54.095  53.703  1
655702  96.051  -54.107  53.664  1
655703  96.077  -54.123  53.627  1
655704  96.103  -54.141  53.591  1
655705  96.128  -54.159  53.556  1
655706  96.154  -54.177  53.523  1
655707  96.179  -54.196  53.488  1
655708  96.204  -54.214  53.449  1
655709  96.230  -54.232  53.412  1
655710  96.255  -54.251  53.376  1
655711  96.281  -54.269  53.340  1
655712  96.306  -54.287  53.304  1
655713  96.333  -54.301  53.268  1
655714  96.361  -54.312  53.230  1
655715  96.388  -54.323  53.196  1
655716  96.415  -54.335  53.162  1
655717  96.443  -54.345  53.126  1
655718  96.473  -54.356  53.088  1
655719  96.502  -54.368  53.048  1
655720  96.531  -54.381  53.007  1
655721  96.559  -54.393  52.965  1
655722  96.588  -54.405  52.924  1
655723  96.616  -54.418  52.888  1
655724  96.645  -54.430  52.856  1
655725  96.674  -54.443  52.828  1
655726  96.702  -54.455  52.800  1
655727  96.731  -54.468  52.773  1
655728  96.760  -54.480  52.741  1
655729  96.789  -54.488  52.702  1
655730  96.819  -54.493  52.659  1
655731  96.849  -54.499  52.613  1
655732  96.879  -54.504  52.565  1
655733  96.908  -54.509  52.515  1
655734  96.938  -54.515  52.463  1
655735  96.968  -54.520  52.410  1
655736  96.998  -54.525  52.357  1
655737  97.028  -54.530  52.304  1
655738  97.058  -54.537  52.251  1
655739  97.090  -54.546  52.197  1
655740  97.121  -54.554  52.141  1
655741  97.153  -54.562  52.085  1
655742  97.183  -54.569  52.029  1
655743  97.215  -54.577  51.972  1
655744  97.245  -54.584  51.914  1
655745  97.277  -54.592  51.857  1
655746  97.307  -54.599  51.800  1
655747  97.344  -54.609  51.743  1
655748  97.380  -54.611  51.685  1
655749  97.414  -54.606  51.624  1
655750  97.446  -54.606  51.563  1
655751  97.474  -54.612  51.503  1
655752  97.502  -54.617  51.444  1
655753  97.531  -54.622  51.383  1
655754  97.559  -54.627  51.319  1
655755  97.583  -54.634  51.258  1
655756  97.607  -54.641  51.194  1
655757  97.630  -54.648  51.129  1
655758  97.654  -54.656  51.063  1
655759  97.677  -54.662  50.996  1
655760  97.704  -54.662  50.930  1
655761  97.727  -54.658  50.866  1
655762  97.748  -54.652  50.802  1
655763  97.770  -54.645  50.738  1
655764  97.791  -54.638  50.673  1
655765  97.813  -54.632  50.608  1
655766  97.844  -54.634  50.542  1
655767  97.881  -54.641  50.477  1
655768  97.915  -54.648  50.411  1
655769  97.942  -54.649  50.347  1
655770  97.968  -54.649  50.283  1
655771  97.996  -54.649  50.220  1
655772  98.022  -54.649  50.158  1
655773  98.049  -54.650  50.098  1
655774  98.076  -54.650  50.039  1
655775  98.103  -54.651  49.983  1
655776  98.130  -54.651  49.928  1
656227  91.018  -51.221  56.822  4
656228  91.030  -51.237  56.825  4
656229  91.042  -51.252  56.829  4
656230  91.053  -51.268  56.836  4
656231  91.065  -51.284  56.843  4
656232  91.092  -51.299  56.850  4
656233  91.129  -51.314  56.857  4
656234  91.164  -51.328  56.865  4
656235  91.201  -51.343  56.873  4
656236  91.236  -51.358  56.884  4
656237  91.273  -51.372  56.894  4
656238  91.308  -51.387  56.902  4
656239  91.345  -51.401  56.910  4
656240  91.380  -51.416  56.918  4
656241  91.417  -51.429  56.928  4
656242  91.461  -51.433  56.938  4
656243  91.504  -51.436  56.948  4
656244  91.548  -51.439  56.952  4
656245  91.591  -51.442  56.951  4
656246  91.628  -51.448  56.950  4
656247  91.661  -51.455  56.948  4
656248  91.697  -51.469  56.947  4
656249  91.734  -51.486  56.947  4
656250  91.772  -51.503  56.946  4
656251  91.810  -51.520  56.943  4
656252  91.848  -51.537  56.941  4
656253  91.880  -51.553  56.939  4
656254  91.912  -51.568  56.937  4
656255  91.942  -51.584  56.933  4
656256  91.973  -51.599  56.924  4
656257  92.004  -51.615  56.917  4
656258  92.035  -51.630  56.912  4
656259  92.066  -51.646  56.907  4
656260  92.098  -51.663  56.901  4
656261  92.132  -51.682  56.895  4
656262  92.166  -51.701  56.884  4
656263  92.200  -51.720  56.872  4
656264  92.234  -51.739  56.862  4
656265  92.268  -51.758  56.850  4
656266  92.302  -51.778  56.837  4
656267  92.336  -51.797  56.823  4
656268  92.370  -51.816  56.805  4
656269  92.404  -51.835  56.783  4
656270  92.438  -51.854  56.759  4
656271  92.472  -51.873  56.735  4
656272  92.506  -51.893  56.710  4
656273  92.530  -51.909  56.681  4
656274  92.551  -51.925  56.648  4
656275  92.573  -51.941  56.613  4
656276  92.603  -51.960  56.576  4
656277  92.634  -51.980  56.538  4
656278  92.665  -52.000  56.497  4
656279  92.695  -52.026  56.455  4
656280  92.725  -52.054  56.412  4
656281  92.755  -52.083  56.369  4
656282  92.785  -52.112  56.327  4
656283  92.815  -52.141  56.287  4
656284  92.851  -52.170  56.247  4
656285  92.890  -52.201  56.209  4
656286  92.930  -52.231  56.171  4
656287  92.970  -52.261  56.133  4
656288  93.010  -52.291  56.095  4
656289  93.050  -52.321  56.057  4
656290  93.084  -52.346  56.019  4
656291  93.115  -52.364  55.979  4
656292  93.146  -52.383  55.936  4
656293  93.177  -52.401  55.890  4
656294  93.207  -52.420  55.840  4
656295  93.238  -52.438  55.790  4
656296  93.268  -52.457  55.740  4
656297  93.299  -52.476  55.690  4
656298  93.330  -52.494  55.642  4
656299  93.360  -52.513  55.594  4
656300  93.391  -52.531  55.548  4
656301  93.422  -52.550  55.502  4
656302  93.452  -52.568  55.459  4
656329  94.279  -53.071  54.866  1
656330  94.310  -53.090  54.862  1
656331  94.341  -53.109  54.859  1
656332  94.371  -53.127  54.857  1
656333  94.401  -53.145  54.857  1
656334  94.430  -53.164  54.855  1
656335  94.460  -53.183  54.856  1
656336  94.489  -53.201  54.858  1
656337  94.519  -53.219  54.860  1
656338  94.548  -53.237  54.862  1
656339  94.577  -53.255  54.865  1
656340  94.607  -53.273  54.865  1
656341  94.636  -53.292  54.866  1
656342  94.665  -53.307  54.867  1
656343  94.693  -53.313  54.868  1
656344  94.715  -53.324  54.869  1
656345  94.734  -53.337  54.869  1
656346  94.753  -53.350  54.869  1
656347  94.771  -53.364  54.867  1
656348  94.789  -53.377  54.866  1
656349  94.806  -53.388  54.864  1
656350  94.821  -53.399  54.860  1
656351  94.837  -53.411  54.857  1
656352  94.853  -53.422  54.854  1
656353  94.881  -53.439  54.852  1
656354  94.911  -53.457  54.851  1
656355  94.935  -53.471  54.851  1
656356  94.960  -53.484  54.850  1
656357  94.984  -53.498  54.847  1
656358  95.009  -53.512  54.843  1
656359  95.033  -53.526  54.841  1
656360  95.055  -53.543  54.840  1
656361  95.076  -53.562  54.841  1
656362  95.098  -53.581  54.834  1
656363  95.119  -53.599  54.824  1
656364  95.140  -53.618  54.811  1
656365  95.162  -53.636  54.798  1
656366  95.183  -53.655  54.785  1
656367  95.205  -53.673  54.768  1
656368  95.226  -53.692  54.746  1
656369  95.248  -53.710  54.721  1
656370  95.269  -53.729  54.694  1
656371  95.290  -53.747  54.667  1
656372  95.312  -53.766  54.642  1
656373  95.333  -53.784  54.623  1
656374  95.354  -53.803  54.598  1
656375  95.373  -53.818  54.572  1
656376  95.391  -53.834  54.546  1
656377  95.410  -53.849  54.521  1
656378  95.434  -53.864  54.495  1
656379  95.458  -53.879  54.464  1
656380  95.482  -53.894  54.427  1
656381  95.497  -53.902  54.384  1
656382  95.513  -53.910  54.342  1
656383  95.536  -53.917  54.297  1
656384  95.561  -53.925  54.252  1
656385  95.586  -53.932  54.207  1
656386  95.612  -53.938  54.164  1
656387  95.637  -53.945  54.122  1
656388  95.662  -53.953  54.082  1
656389  95.687  -53.960  54.048  1
656390  95.712  -53.966  54.018  1
656391  95.738  -53.973  53.990  1
656392  95.763  -53.980  53.960  1
656393  95.789  -53.988  53.932  1
656394  95.814  -53.994  53.905  1
656395  95.839  -54.001  53.882  1
656396  95.865  -54.008  53.858  1
656397  95.890  -54.016  53.834  1
656398  95.917  -54.027  53.809  1
656399  95.945  -54.039  53.784  1
656400  95.972  -54.052  53.758  1
656401  96.000  -54.064  53.728  1
656402  96.028  -54.076  53.696  1
656403  96.055  -54.088  53.660  1
656404  96.083  -54.101  53.624  1
656405  96.111  -54.113  53.589  1
656406  96.136  -54.132  53.556  1
656407  96.162  -54.150  53.524  1
656408  96.187  -54.168  53.490  1
656409  96.213  -54.186  53.453  1
656410  96.238  -54.204  53.417  1
656411  96.264  -54.223  53.381  1
656412  96.289  -54.242  53.346  1
656413  96.315  -54.260  53.311  1
656414  96.341  -54.273  53.277  1
656415  96.369  -54.285  53.242  1
656416  96.396  -54.296  53.211  1
656417  96.424  -54.308  53.177  1
656418  96.453  -54.318  53.141  1
656419  96.483  -54.328  53.103  1
656420  96.512  -54.340  53.062  1
656421  96.541  -54.352  53.022  1
656422  96.570  -54.365  52.981  1
656423  96.598  -54.377  52.941  1
656424  96.626  -54.390  52.903  1
656425  96.655  -54.402  52.870  1
656426  96.684  -54.415  52.839  1
656427  96.713  -54.427  52.811  1
656428  96.741  -54.440  52.786  1
656429  96.770  -54.452  52.755  1
656430  96.800  -54.459  52.718  1
656431  96.828  -54.466  52.677  1
656432  96.859  -54.471  52.632  1
656433  96.888  -54.477  52.584  1
656434  96.918  -54.482  52.534  1
656435  96.948  -54.487  52.481  1
656436  96.978  -54.493  52.427  1
656437  97.008  -54.499  52.373  1
656438  97.037  -54.504  52.322  1
656439  97.067  -54.509  52.271  1
656440  97.098  -54.516  52.218  1
656441  97.130  -54.524  52.163  1
656442  97.161  -54.533  52.108  1
656443  97.192  -54.540  52.053  1
656444  97.223  -54.548  51.997  1
656445  97.254  -54.555  51.940  1
656446  97.285  -54.562  51.884  1
656447  97.316  -54.570  51.830  1
656448  97.348  -54.577  51.776  1
656449  97.384  -54.579  51.719  1
656450  97.414  -54.580  51.659  1
656451  97.442  -54.586  51.600  1
656452  97.470  -54.591  51.542  1
656453  97.499  -54.596  51.484  1
656454  97.527  -54.602  51.425  1
656455  97.556  -54.606  51.364  1
656456  97.582  -54.612  51.306  1
656457  97.605  -54.620  51.244  1
656458  97.629  -54.627  51.179  1
656459  97.654  -54.630  51.115  1
656460  97.680  -54.629  51.050  1
656461  97.706  -54.628  50.985  1
656462  97.732  -54.627  50.921  1
656463  97.756  -54.624  50.858  1
656464  97.778  -54.618  50.794  1
656465  97.799  -54.612  50.729  1
656466  97.820  -54.605  50.662  1
656467  97.856  -54.611  50.594  1
656468  97.891  -54.618  50.528  1
656469  97.918  -54.618  50.461  1
656470  97.944  -54.618  50.395  1
656471  97.971  -54.618  50.329  1
656472  97.998  -54.619  50.265  1
656473  98.025  -54.619  50.201  1
656474  98.052  -54.620  50.139  1
656475  98.079  -54.620  50.079  1
656476  98.105  -54.621  50.021  1
656477  98.132  -54.621  49.964  1
656907  90.552  -50.904  56.851  9
656908  90.585  -50.923  56.836  9
656909  90.618  -50.942  56.821  9
656910  90.651  -50.961  56.805  9
656911  90.684  -50.978  56.789  9
656912  90.717  -50.986  56.771  9
656913  90.749  -50.994  56.752  9
656914  90.781  -51.001  56.733  9
656929  91.035  -51.209  56.816  4
656930  91.047  -51.225  56.820  4
656931  91.074  -51.240  56.825  4
656932  91.110  -51.255  56.832  4
656933  91.146  -51.269  56.839  4
656934  91.182  -51.284  56.846  4
656935  91.218  -51.298  56.853  4
656936  91.254  -51.313  56.861  4
656937  91.290  -51.327  56.871  4
656938  91.326  -51.342  56.880  4
656939  91.362  -51.356  56.888  4
656940  91.398  -51.371  56.896  4
656941  91.434  -51.386  56.905  4
656942  91.470  -51.400  56.914  4
656943  91.506  -51.415  56.924  4
656944  91.549  -51.418  56.932  4
656945  91.593  -51.421  56.935  4
656946  91.629  -51.428  56.934  4
656947  91.661  -51.434  56.933  4
656948  91.694  -51.442  56.932  4
656949  91.726  -51.449  56.931  4
656950  91.758  -51.456  56.932  4
656951  91.791  -51.463  56.931  4
656952  91.828  -51.479  56.929  4
656953  91.866  -51.496  56.928  4
656954  91.899  -51.512  56.926  4
656955  91.930  -51.528  56.923  4
656956  91.961  -51.543  56.919  4
656957  91.993  -51.559  56.914  4
656958  92.027  -51.579  56.908  4
656959  92.061  -51.598  56.903  4
656960  92.095  -51.617  56.899  4
656961  92.129  -51.637  56.894  4
656962  92.163  -51.656  56.888  4
656963  92.197  -51.675  56.876  4
656964  92.231  -51.694  56.866  4
656965  92.265  -51.713  56.856  4
656966  92.299  -51.732  56.845  4
656967  92.333  -51.751  56.832  4
656968  92.367  -51.771  56.818  4
656969  92.401  -51.790  56.799  4
656970  92.435  -51.809  56.778  4
656971  92.469  -51.829  56.756  4
656972  92.501  -51.847  56.733  4
656973  92.522  -51.863  56.711  4
656974  92.544  -51.878  56.683  4
656975  92.564  -51.894  56.650  4
656976  92.593  -51.913  56.614  4
656977  92.624  -51.933  56.578  4
656978  92.655  -51.953  56.540  4
656979  92.686  -51.973  56.501  4
656980  92.716  -51.999  56.460  4
656981  92.746  -52.028  56.416  4
656982  92.776  -52.057  56.374  4
656983  92.806  -52.086  56.333  4
656984  92.836  -52.114  56.293  4
656985  92.866  -52.143  56.254  4
656986  92.903  -52.174  56.215  4
656987  92.943  -52.204  56.178  4
656988  92.983  -52.233  56.139  4
656989  93.022  -52.264  56.102  4
656990  93.062  -52.294  56.064  4
656991  93.100  -52.321  56.026  4
656992  93.131  -52.340  55.986  4
656993  93.161  -52.358  55.944  4
656994  93.192  -52.377  55.901  4
656995  93.222  -52.396  55.852  4
656996  93.253  -52.415  55.803  4
656997  93.284  -52.434  55.754  4
656998  93.314  -52.452  55.705  4
656999  93.345  -52.471  55.657  4
657000  93.375  -52.489  55.609  4
657001  93.406  -52.508  55.563  4
657002  93.437  -52.526  55.518  4
657003  93.468  -52.545  55.474  4
657030  94.294  -53.048  54.868  1
657031  94.324  -53.066  54.863  1
657032  94.353  -53.084  54.860  1
657033  94.383  -53.102  54.857  1
657034  94.412  -53.121  54.856  1
657035  94.441  -53.139  54.853  1
657036  94.471  -53.158  54.853  1
657037  94.500  -53.176  54.853  1
657038  94.530  -53.194  54.853  1
657039  94.559  -53.212  54.854  1
657040  94.588  -53.230  54.855  1
657041  94.618  -53.248  54.856  1
657042  94.647  -53.267  54.856  1
657043  94.676  -53.285  54.856  1
657044  94.704  -53.295  54.857  1
657045  94.732  -53.302  54.858  1
657046  94.758  -53.309  54.858  1
657047  94.776  -53.323  54.858  1
657048  94.795  -53.336  54.855  1
657049  94.814  -53.349  54.854  1
657050  94.832  -53.363  54.852  1
657051  94.851  -53.377  54.849  1
657052  94.870  -53.389  54.846  1
657053  94.886  -53.401  54.843  1
657054  94.902  -53.412  54.842  1
657055  94.926  -53.428  54.841  1
657056  94.953  -53.443  54.843  1
657057  94.977  -53.457  54.842  1
657058  95.001  -53.471  54.840  1
657059  95.024  -53.488  54.839  1
657060  95.045  -53.507  54.840  1
657061  95.066  -53.525  54.841  1
657062  95.088  -53.544  54.842  1
657063  95.109  -53.562  54.835  1
657064  95.130  -53.581  54.824  1
657065  95.151  -53.599  54.809  1
657066  95.173  -53.618  54.790  1
657067  95.194  -53.637  54.772  1
657068  95.216  -53.655  54.753  1
657069  95.237  -53.674  54.728  1
657070  95.259  -53.692  54.702  1
657071  95.280  -53.711  54.678  1
657072  95.301  -53.729  54.657  1
657073  95.323  -53.748  54.640  1
657074  95.344  -53.766  54.625  1
657075  95.364  -53.784  54.604  1
657076  95.383  -53.799  54.580  1
657077  95.403  -53.814  54.553  1
657078  95.427  -53.830  54.526  1
657079  95.451  -53.845  54.496  1
657080  95.476  -53.860  54.463  1
657081  95.500  -53.875  54.424  1
657082  95.516  -53.883  54.379  1
657083  95.531  -53.891  54.337  1
657084  95.547  -53.900  54.294  1
657085  95.566  -53.908  54.250  1
657086  95.592  -53.915  54.207  1
657087  95.617  -53.922  54.164  1
657088  95.642  -53.928  54.122  1
657089  95.668  -53.936  54.082  1
657090  95.693  -53.943  54.049  1
657091  95.718  -53.950  54.019  1
657092  95.743  -53.957  53.990  1
657093  95.769  -53.963  53.960  1
657094  95.794  -53.971  53.931  1
657095  95.819  -53.978  53.905  1
657096  95.844  -53.985  53.882  1
657097  95.870  -53.991  53.858  1
657098  95.895  -53.999  53.832  1
657099  95.922  -54.009  53.806  1
657100  95.950  -54.021  53.779  1
657101  95.977  -54.033  53.751  1
657102  96.005  -54.046  53.721  1
657103  96.033  -54.058  53.691  1
657104  96.060  -54.070  53.656  1
657105  96.088  -54.082  53.622  1
657106  96.116  -54.095  53.589  1
657107  96.144  -54.107  53.557  1
657108  96.170  -54.122  53.526  1
657109  96.196  -54.140  53.493  1
657110  96.221  -54.159  53.457  1
657111  96.247  -54.177  53.422  1
657112  96.272  -54.195  53.388  1
657113  96.298  -54.214  53.353  1
657114  96.323  -54.232  53.320  1
657115  96.349  -54.246  53.287  1
657116  96.377  -54.258  53.256  1
657117  96.404  -54.269  53.226  1
657118  96.433  -54.279  53.193  1
657119  96.463  -54.290  53.158  1
657120  96.493  -54.301  53.120  1
657121  96.522  -54.312  53.079  1
657122  96.551  -54.324  53.040  1
657123  96.580  -54.337  52.999  1
657124  96.608  -54.349  52.958  1
657125  96.637  -54.362  52.920  1
657126  96.665  -54.374  52.885  1
657127  96.694  -54.387  52.853  1
657128  96.723  -54.399  52.823  1
657129  96.753  -54.409  52.799  1
657130  96.783  -54.419  52.768  1
657131  96.813  -54.427  52.732  1
657132  96.841  -54.433  52.691  1
657133  96.871  -54.440  52.648  1
657134  96.899  -54.447  52.600  1
657135  96.929  -54.454  52.549  1
657136  96.957  -54.461  52.497  1
657137  96.987  -54.466  52.442  1
657138  97.017  -54.471  52.389  1
657139  97.047  -54.477  52.338  1
657140  97.077  -54.482  52.289  1
657141  97.107  -54.487  52.240  1
657142  97.138  -54.496  52.187  1
657143  97.169  -54.504  52.133  1
657144  97.200  -54.511  52.076  1
657145  97.231  -54.518  52.021  1
657146  97.262  -54.526  51.966  1
657147  97.293  -54.533  51.911  1
657148  97.324  -54.540  51.859  1
657149  97.355  -54.548  51.806  1
657150  97.382  -54.554  51.751  1
657151  97.410  -54.560  51.693  1
657152  97.439  -54.565  51.636  1
657153  97.467  -54.571  51.579  1
657154  97.495  -54.576  51.522  1
657155  97.523  -54.581  51.465  1
657156  97.552  -54.587  51.406  1
657157  97.580  -54.591  51.352  1
657158  97.604  -54.599  51.291  1
657159  97.630  -54.598  51.227  1
657160  97.656  -54.596  51.164  1
657161  97.682  -54.596  51.101  1
657162  97.709  -54.595  51.038  1
657163  97.735  -54.594  50.976  1
657164  97.761  -54.593  50.914  1
657165  97.786  -54.591  50.850  1
657166  97.807  -54.584  50.785  1
657167  97.830  -54.579  50.717  1
657168  97.867  -54.587  50.647  1
657169  97.893  -54.587  50.579  1
657170  97.920  -54.588  50.512  1
657171  97.947  -54.588  50.444  1
657172  97.974  -54.589  50.376  1
657173  98.001  -54.589  50.309  1
657174  98.027  -54.589  50.244  1
657175  98.055  -54.590  50.181  1
657176  98.081  -54.590  50.119  1
657177  98.108  -54.590  50.059  1
657178  98.135  -54.590  50.000  1
657179  98.162  -54.591  49.943  1
657606  90.506  -50.832  56.873  9
657607  90.539  -50.851  56.861  9
657608  90.572  -50.870  56.848  9
657609  90.605  -50.890  56.834  9
657610  90.638  -50.909  56.820  9
657611  90.671  -50.929  56.804  9
657612  90.704  -50.945  56.788  9
657613  90.736  -50.952  56.771  9
657614  90.769  -50.961  56.753  9
657615  90.801  -50.968  56.734  9
657616  90.833  -50.976  56.715  9
657617  90.866  -50.985  56.697  9
657631  91.091  -51.196  56.811  4
657632  91.128  -51.210  56.815  4
657633  91.163  -51.224  56.821  4
657634  91.200  -51.239  56.829  4
657635  91.235  -51.253  56.835  4
657636  91.272  -51.268  56.841  4
657637  91.307  -51.283  56.849  4
657638  91.344  -51.297  56.857  4
657639  91.379  -51.312  56.866  4
657640  91.416  -51.326  56.875  4
657641  91.451  -51.341  56.882  4
657642  91.488  -51.356  56.891  4
657643  91.523  -51.370  56.899  4
657644  91.560  -51.384  56.907  4
657645  91.595  -51.399  56.915  4
657646  91.629  -51.407  56.918  4
657647  91.661  -51.414  56.917  4
657648  91.694  -51.421  56.916  4
657649  91.726  -51.428  56.916  4
657650  91.758  -51.435  56.916  4
657651  91.791  -51.442  56.918  4
657652  91.823  -51.450  56.917  4
657653  91.856  -51.456  56.915  4
657654  91.889  -51.463  56.914  4
657655  91.922  -51.476  56.912  4
657656  91.956  -51.495  56.909  4
657657  91.990  -51.515  56.906  4
657658  92.024  -51.534  56.903  4
657659  92.058  -51.553  56.898  4
657660  92.092  -51.572  56.895  4
657661  92.126  -51.591  56.891  4
657662  92.160  -51.610  56.885  4
657663  92.194  -51.629  56.878  4
657664  92.228  -51.649  56.869  4
657665  92.262  -51.668  56.859  4
657666  92.296  -51.687  56.850  4
657667  92.330  -51.707  56.840  4
657668  92.364  -51.725  56.827  4
657669  92.398  -51.744  56.812  4
657670  92.432  -51.764  56.793  4
657671  92.466  -51.783  56.772  4
657672  92.493  -51.801  56.751  4
657673  92.514  -51.816  56.730  4
657674  92.535  -51.832  56.709  4
657675  92.556  -51.848  56.683  4
657676  92.584  -51.866  56.649  4
657677  92.615  -51.885  56.614  4
657678  92.645  -51.905  56.578  4
657679  92.676  -51.925  56.541  4
657680  92.707  -51.945  56.504  4
657681  92.737  -51.973  56.464  4
657682  92.767  -52.001  56.423  4
657683  92.797  -52.030  56.381  4
657684  92.827  -52.059  56.341  4
657685  92.857  -52.088  56.301  4
657686  92.886  -52.117  56.261  4
657687  92.917  -52.146  56.223  4
657688  92.955  -52.176  56.185  4
657689  92.995  -52.206  56.147  4
657690  93.035  -52.236  56.109  4
657691  93.074  -52.267  56.071  4
657692  93.114  -52.296  56.032  4
657693  93.146  -52.317  55.993  4
657694  93.177  -52.335  55.953  4
657695  93.207  -52.354  55.910  4
657696  93.238  -52.372  55.864  4
657697  93.268  -52.391  55.816  4
657698  93.299  -52.409  55.767  4
657699  93.330  -52.428  55.719  4
657700  93.360  -52.447  55.671  4
657701  93.391  -52.465  55.624  4
657702  93.422  -52.484  55.578  4
657703  93.452  -52.503  55.533  4
657704  93.483  -52.521  55.489  4
657731  94.306  -53.023  54.869  1
657732  94.335  -53.041  54.864  1
657733  94.364  -53.059  54.859  1
657734  94.394  -53.078  54.855  1
657735  94.423  -53.096  54.852  1
657736  94.452  -53.114  54.850  1
657737  94.482  -53.132  54.848  1
657738  94.511  -53.151  54.847  1
657739  94.540  -53.169  54.847  1
657740  94.570  -53.187  54.846  1
657741  94.599  -53.205  54.846  1
657742  94.628  -53.223  54.847  1
657743  94.658  -53.242  54.846  1
657744  94.687  -53.261  54.846  1
657745  94.716  -53.277  54.847  1
657746  94.744  -53.283  54.847  1
657747  94.771  -53.289  54.847  1
657748  94.799  -53.295  54.846  1
657749  94.819  -53.308  54.844  1
657750  94.837  -53.322  54.842  1
657751  94.856  -53.335  54.841  1
657752  94.875  -53.349  54.838  1
657753  94.893  -53.362  54.835  1
657754  94.912  -53.376  54.833  1
657755  94.931  -53.389  54.832  1
657756  94.950  -53.402  54.833  1
657757  94.970  -53.416  54.836  1
657758  94.992  -53.433  54.837  1
657759  95.013  -53.452  54.836  1
657760  95.035  -53.470  54.836  1
657761  95.056  -53.489  54.838  1
657762  95.077  -53.507  54.837  1
657763  95.099  -53.526  54.836  1
657764  95.120  -53.544  54.830  1
657765  95.141  -53.563  54.819  1
657766  95.163  -53.581  54.802  1
657767  95.184  -53.600  54.780  1
657768  95.205  -53.618  54.757  1
657769  95.227  -53.637  54.734  1
657770  95.248  -53.656  54.710  1
657771  95.270  -53.675  54.685  1
657772  95.291  -53.693  54.665  1
657773  95.312  -53.711  54.652  1
657774  95.334  -53.730  54.643  1
657775  95.355  -53.748  54.633  1
657776  95.374  -53.764  54.613  1
657777  95.396  -53.779  54.589  1
657778  95.420  -53.795  54.561  1
657779  95.443  -53.810  54.531  1
657780  95.468  -53.825  54.497  1
657781  95.493  -53.841  54.460  1
657782  95.518  -53.856  54.419  1
657783  95.534  -53.865  54.373  1
657784  95.550  -53.873  54.331  1
657785  95.565  -53.882  54.289  1
657786  95.581  -53.890  54.248  1
657787  95.597  -53.898  54.207  1
657788  95.622  -53.905  54.164  1
657789  95.648  -53.912  54.123  1
657790  95.673  -53.919  54.086  1
657791  95.698  -53.926  54.053  1
657792  95.724  -53.933  54.024  1
657793  95.749  -53.940  53.995  1
657794  95.774  -53.947  53.964  1
657795  95.800  -53.954  53.936  1
657796  95.825  -53.961  53.909  1
657797  95.850  -53.968  53.886  1
657798  95.875  -53.975  53.863  1
657799  95.901  -53.982  53.836  1
657800  95.926  -53.991  53.808  1
657801  95.954  -54.003  53.779  1
657802  95.982  -54.015  53.749  1
657803  96.010  -54.028  53.719  1
657804  96.038  -54.040  53.689  1
657805  96.065  -54.052  53.656  1
657806  96.093  -54.064  53.621  1
657807  96.121  -54.077  53.588  1
657808  96.149  -54.089  53.558  1
657809  96.176  -54.101  53.527  1
657810  96.204  -54.113  53.495  1
657811  96.230  -54.131  53.462  1
657812  96.255  -54.149  53.428  1
657813  96.281  -54.167  53.395  1
657814  96.306  -54.185  53.363  1
657815  96.331  -54.204  53.332  1
657816  96.358  -54.219  53.300  1
657817  96.385  -54.230  53.269  1
657818  96.413  -54.242  53.241  1
657819  96.443  -54.252  53.211  1
657820  96.473  -54.262  53.177  1
657821  96.503  -54.273  53.138  1
657822  96.533  -54.284  53.098  1
657823  96.561  -54.296  53.060  1
657824  96.590  -54.309  53.018  1
657825  96.618  -54.321  52.975  1
657826  96.647  -54.334  52.936  1
657827  96.675  -54.346  52.901  1
657828  96.705  -54.357  52.868  1
657829  96.735  -54.367  52.837  1
657830  96.766  -54.377  52.811  1
657831  96.796  -54.386  52.780  1
657832  96.825  -54.395  52.744  1
657833  96.855  -54.402  52.704  1
657834  96.884  -54.408  52.661  1
657835  96.912  -54.415  52.613  1
657836  96.942  -54.422  52.562  1
657837  96.970  -54.429  52.511  1
657838  97.000  -54.436  52.456  1
657839  97.028  -54.442  52.404  1
657840  97.058  -54.449  52.354  1
657841  97.087  -54.455  52.306  1
657842  97.116  -54.461  52.258  1
657843  97.147  -54.467  52.207  1
657844  97.177  -54.474  52.155  1
657845  97.209  -54.482  52.099  1
657846  97.239  -54.489  52.044  1
657847  97.270  -54.497  51.990  1
657848  97.300  -54.505  51.936  1
657849  97.330  -54.512  51.884  1
657850  97.360  -54.520  51.832  1
657851  97.386  -54.523  51.779  1
657852  97.412  -54.527  51.723  1
657853  97.440  -54.533  51.668  1
657854  97.468  -54.540  51.613  1
657855  97.496  -54.546  51.558  1
657856  97.524  -54.552  51.502  1
657857  97.551  -54.558  51.445  1
657858  97.579  -54.564  51.393  1
657859  97.606  -54.565  51.334  1
657860  97.633  -54.564  51.271  1
657861  97.659  -54.563  51.209  1
657862  97.685  -54.562  51.148  1
657863  97.711  -54.562  51.086  1
657864  97.737  -54.561  51.026  1
657865  97.764  -54.560  50.965  1
657866  97.790  -54.559  50.903  1
657867  97.815  -54.557  50.839  1
657868  97.842  -54.556  50.773  1
657869  97.869  -54.557  50.703  1
657870  97.896  -54.557  50.631  1
657871  97.923  -54.558  50.562  1
657872  97.950  -54.558  50.492  1
657873  97.977  -54.558  50.423  1
657874  98.003  -54.558  50.355  1
657875  98.030  -54.559  50.288  1
657876  98.057  -54.559  50.222  1
657877  98.084  -54.559  50.159  1
657878  98.110  -54.560  50.098  1
657879  98.138  -54.560  50.037  1
657880  98.164  -54.561  49.979  1
657881  98.191  -54.561  49.924  1
658306  90.493  -50.779  56.876  9
658307  90.526  -50.798  56.867  9
658308  90.559  -50.818  56.857  9
658309  90.592  -50.837  56.845  9
658310  90.625  -50.857  56.832  9
658311  90.658  -50.876  56.818  9
658312  90.691  -50.895  56.804  9
658313  90.724  -50.911  56.789  9
658314  90.756  -50.919  56.772  9
658315  90.789  -50.927  56.754  9
658316  90.821  -50.935  56.735  9
658317  90.853  -50.943  56.716  9
658318  90.886  -50.951  56.697  9
658319  90.904  -50.964  56.679  9
658332  91.145  -51.165  56.802  4
658333  91.181  -51.180  56.805  4
658334  91.217  -51.194  56.811  4
658335  91.253  -51.208  56.817  4
658336  91.289  -51.224  56.823  4
658337  91.325  -51.238  56.829  4
658338  91.361  -51.252  56.836  4
658339  91.397  -51.267  56.844  4
658340  91.433  -51.281  56.853  4
658341  91.469  -51.296  56.861  4
658342  91.505  -51.311  56.868  4
658343  91.538  -51.325  56.875  4
658344  91.569  -51.340  56.882  4
658345  91.600  -51.354  56.890  4
658346  91.631  -51.368  56.896  4
658347  91.662  -51.383  56.899  4
658348  91.694  -51.396  56.899  4
658349  91.726  -51.405  56.899  4
658350  91.758  -51.412  56.900  4
658351  91.791  -51.419  56.901  4
658352  91.823  -51.426  56.903  4
658353  91.856  -51.434  56.903  4
658354  91.888  -51.440  56.902  4
658355  91.921  -51.447  56.902  4
658356  91.953  -51.455  56.898  4
658357  91.987  -51.469  56.895  4
658358  92.021  -51.488  56.894  4
658359  92.055  -51.507  56.891  4
658360  92.089  -51.527  56.888  4
658361  92.123  -51.546  56.885  4
658362  92.157  -51.565  56.880  4
658363  92.191  -51.584  56.875  4
658364  92.225  -51.603  56.868  4
658365  92.259  -51.622  56.860  4
658366  92.293  -51.642  56.852  4
658367  92.327  -51.661  56.842  4
658368  92.361  -51.680  56.831  4
658369  92.395  -51.700  56.819  4
658370  92.429  -51.719  56.804  4
658371  92.463  -51.738  56.785  4
658372  92.486  -51.754  56.766  4
658373  92.506  -51.769  56.746  4
658374  92.527  -51.785  56.725  4
658375  92.549  -51.801  56.705  4
658376  92.574  -51.818  56.679  4
658377  92.605  -51.838  56.647  4
658378  92.636  -51.858  56.612  4
658379  92.666  -51.878  56.577  4
658380  92.697  -51.898  56.542  4
658381  92.728  -51.917  56.506  4
658382  92.758  -51.946  56.468  4
658383  92.788  -51.975  56.430  4
658384  92.817  -52.004  56.390  4
658385  92.848  -52.033  56.349  4
658386  92.877  -52.062  56.309  4
658387  92.908  -52.091  56.271  4
658388  92.937  -52.120  56.232  4
658389  92.968  -52.148  56.194  4
658390  93.007  -52.179  56.156  4
658391  93.047  -52.208  56.118  4
658392  93.086  -52.239  56.079  4
658393  93.127  -52.269  56.041  4
658394  93.161  -52.293  56.002  4
658395  93.192  -52.311  55.962  4
658396  93.222  -52.330  55.920  4
658397  93.253  -52.349  55.874  4
658398  93.284  -52.368  55.827  4
658399  93.314  -52.386  55.779  4
658400  93.345  -52.405  55.732  4
658401  93.375  -52.423  55.685  4
658402  93.406  -52.442  55.638  4
658403  93.437  -52.460  55.592  4
658404  93.468  -52.479  55.548  4
658405  93.498  -52.497  55.504  4
658432  94.316  -52.998  54.870  1
658433  94.345  -53.016  54.864  1
658434  94.375  -53.035  54.858  1
658435  94.404  -53.053  54.853  1
658436  94.433  -53.071  54.850  1
658437  94.463  -53.089  54.846  1
658438  94.492  -53.107  54.844  1
658439  94.522  -53.126  54.842  1
658440  94.551  -53.144  54.840  1
658441  94.580  -53.162  54.839  1
658442  94.610  -53.180  54.838  1
658443  94.639  -53.198  54.838  1
658444  94.669  -53.217  54.837  1
658445  94.698  -53.236  54.836  1
658446  94.728  -53.254  54.837  1
658447  94.756  -53.265  54.837  1
658448  94.783  -53.271  54.836  1
658449  94.811  -53.277  54.835  1
658450  94.838  -53.283  54.834  1
658451  94.861  -53.294  54.832  1
658452  94.880  -53.308  54.831  1
658453  94.898  -53.321  54.829  1
658454  94.917  -53.334  54.826  1
658455  94.935  -53.348  54.824  1
658456  94.954  -53.361  54.823  1
658457  94.973  -53.374  54.826  1
658458  94.989  -53.390  54.830  1
658459  95.002  -53.408  54.832  1
658460  95.018  -53.427  54.833  1
658461  95.040  -53.446  54.834  1
658462  95.062  -53.465  54.835  1
658463  95.084  -53.484  54.832  1
658464  95.106  -53.503  54.829  1
658465  95.127  -53.522  54.823  1
658466  95.149  -53.541  54.810  1
658467  95.171  -53.561  54.791  1
658468  95.193  -53.580  54.768  1
658469  95.215  -53.599  54.740  1
658470  95.237  -53.618  54.715  1
658471  95.259  -53.637  54.694  1
658472  95.280  -53.656  54.674  1
658473  95.302  -53.675  54.659  1
658474  95.323  -53.693  54.651  1
658475  95.345  -53.712  54.646  1
658476  95.366  -53.729  54.635  1
658477  95.389  -53.745  54.615  1
658478  95.413  -53.760  54.591  1
658479  95.436  -53.775  54.562  1
658480  95.460  -53.791  54.531  1
658481  95.485  -53.806  54.496  1
658482  95.510  -53.822  54.456  1
658483  95.535  -53.837  54.412  1
658484  95.553  -53.846  54.368  1
658485  95.568  -53.854  54.325  1
658486  95.584  -53.863  54.285  1
658487  95.600  -53.871  54.246  1
658488  95.615  -53.879  54.206  1
658489  95.631  -53.888  54.164  1
658490  95.653  -53.895  54.125  1
658491  95.679  -53.902  54.091  1
658492  95.704  -53.910  54.060  1
658493  95.729  -53.916  54.032  1
658494  95.754  -53.923  54.002  1
658495  95.779  -53.930  53.971  1
658496  95.805  -53.938  53.943  1
658497  95.830  -53.944  53.916  1
658498  95.855  -53.951  53.892  1
658499  95.881  -53.958  53.868  1
658500  95.906  -53.965  53.841  1
658501  95.932  -53.972  53.811  1
658502  95.959  -53.985  53.781  1
658503  95.987  -53.997  53.750  1
658504  96.015  -54.010  53.721  1
658505  96.042  -54.022  53.690  1
658506  96.070  -54.034  53.657  1
658507  96.098  -54.046  53.623  1
658508  96.125  -54.059  53.590  1
658509  96.153  -54.071  53.560  1
658510  96.181  -54.083  53.531  1
658511  96.208  -54.095  53.500  1
658512  96.236  -54.107  53.468  1
658513  96.263  -54.122  53.436  1
658514  96.289  -54.140  53.404  1
658515  96.314  -54.158  53.374  1
658516  96.340  -54.176  53.345  1
658517  96.366  -54.192  53.315  1
658518  96.393  -54.203  53.286  1
658519  96.422  -54.214  53.258  1
658520  96.453  -54.224  53.228  1
658521  96.483  -54.235  53.195  1
658522  96.513  -54.245  53.159  1
658523  96.543  -54.256  53.119  1
658524  96.571  -54.268  53.080  1
658525  96.600  -54.281  53.036  1
658526  96.628  -54.293  52.992  1
658527  96.658  -54.305  52.952  1
658528  96.688  -54.314  52.917  1
658529  96.718  -54.324  52.885  1
658530  96.748  -54.334  52.854  1
658531  96.779  -54.344  52.824  1
658532  96.809  -54.354  52.791  1
658533  96.838  -54.362  52.755  1
658534  96.868  -54.369  52.715  1
658535  96.896  -54.376  52.670  1
658536  96.926  -54.383  52.623  1
658537  96.954  -54.389  52.573  1
658538  96.983  -54.396  52.523  1
658539  97.013  -54.403  52.470  1
658540  97.041  -54.410  52.418  1
658541  97.071  -54.417  52.369  1
658542  97.099  -54.424  52.321  1
658543  97.129  -54.430  52.275  1
658544  97.157  -54.437  52.226  1
658545  97.184  -54.446  52.174  1
658546  97.215  -54.453  52.120  1
658547  97.245  -54.461  52.066  1
658548  97.275  -54.468  52.012  1
658549  97.305  -54.477  51.960  1
658550  97.335  -54.484  51.908  1
658551  97.366  -54.492  51.858  1
658552  97.391  -54.495  51.806  1
658553  97.416  -54.496  51.753  1
658554  97.441  -54.500  51.699  1
658555  97.469  -54.507  51.646  1
658556  97.497  -54.513  51.592  1
658557  97.525  -54.519  51.537  1
658558  97.553  -54.525  51.482  1
658559  97.581  -54.531  51.430  1
658560  97.607  -54.531  51.373  1
658561  97.634  -54.530  51.313  1
658562  97.660  -54.530  51.252  1
658563  97.686  -54.529  51.192  1
658564  97.713  -54.528  51.132  1
658565  97.739  -54.527  51.073  1
658566  97.766  -54.527  51.013  1
658567  97.792  -54.526  50.953  1
658568  97.819  -54.525  50.891  1
658569  97.845  -54.526  50.826  1
658570  97.872  -54.527  50.756  1
658571  97.899  -54.527  50.684  1
658572  97.926  -54.527  50.612  1
658573  97.952  -54.527  50.542  1
658574  97.979  -54.528  50.472  1
658575  98.006  -54.528  50.402  1
658576  98.033  -54.529  50.334  1
658577  98.060  -54.529  50.267  1
658578  98.087  -54.529  50.202  1
658579  98.113  -54.530  50.139  1
658580  98.140  -54.530  50.078  1
658581  98.167  -54.530  50.018  1
658582  98.194  -54.530  49.961  1
658583  98.221  -54.531  49.906  1
659006  90.480  -50.727  56.877  9
659007  90.513  -50.746  56.869  9
659008  90.546  -50.765  56.861  9
659009  90.579  -50.785  56.852  9
659010  90.612  -50.804  56.842  9
659011  90.645  -50.823  56.829  9
659012  90.678  -50.842  56.816  9
659013  90.712  -50.862  56.802  9
659014  90.744  -50.878  56.788  9
659015  90.777  -50.886  56.771  9
659016  90.809  -50.894  56.754  9
659017  90.841  -50.901  56.736  9
659018  90.873  -50.910  56.716  9
659019  90.898  -50.920  56.698  9
659020  90.909  -50.936  56.679  9
659021  90.921  -50.952  56.660  9
659034  91.234  -51.149  56.796  4
659035  91.270  -51.164  56.800  4
659036  91.306  -51.179  56.806  4
659037  91.342  -51.193  56.811  4
659038  91.378  -51.208  56.817  4
659039  91.414  -51.222  56.824  4
659040  91.448  -51.236  56.831  4
659041  91.480  -51.251  56.839  4
659042  91.511  -51.265  56.848  4
659043  91.542  -51.280  56.854  4
659044  91.573  -51.294  56.860  4
659045  91.604  -51.309  56.866  4
659046  91.635  -51.323  56.872  4
659047  91.666  -51.337  56.878  4
659048  91.698  -51.352  56.881  4
659049  91.729  -51.366  56.882  4
659050  91.760  -51.380  56.883  4
659051  91.791  -51.394  56.885  4
659052  91.823  -51.403  56.886  4
659053  91.856  -51.410  56.888  4
659054  91.888  -51.418  56.889  4
659055  91.921  -51.425  56.888  4
659056  91.953  -51.431  56.886  4
659057  91.986  -51.439  56.884  4
659058  92.018  -51.446  56.882  4
659059  92.052  -51.462  56.882  4
659060  92.086  -51.481  56.880  4
659061  92.120  -51.500  56.877  4
659062  92.154  -51.520  56.874  4
659063  92.188  -51.539  56.868  4
659064  92.222  -51.558  56.864  4
659065  92.256  -51.578  56.858  4
659066  92.290  -51.597  56.851  4
659067  92.324  -51.616  56.843  4
659068  92.358  -51.635  56.834  4
659069  92.392  -51.654  56.822  4
659070  92.426  -51.673  56.809  4
659071  92.456  -51.691  56.794  4
659072  92.478  -51.707  56.775  4
659073  92.498  -51.722  56.757  4
659074  92.519  -51.738  56.738  4
659075  92.541  -51.754  56.718  4
659076  92.565  -51.771  56.697  4
659077  92.595  -51.791  56.671  4
659078  92.626  -51.810  56.641  4
659079  92.657  -51.830  56.609  4
659080  92.688  -51.850  56.576  4
659081  92.718  -51.870  56.542  4
659082  92.748  -51.891  56.508  4
659083  92.779  -51.920  56.471  4
659084  92.808  -51.949  56.436  4
659085  92.839  -51.978  56.398  4
659086  92.868  -52.007  56.359  4
659087  92.899  -52.036  56.319  4
659088  92.928  -52.064  56.281  4
659089  92.958  -52.093  56.242  4
659090  92.988  -52.122  56.203  4
659091  93.019  -52.151  56.166  4
659092  93.059  -52.181  56.128  4
659093  93.099  -52.211  56.089  4
659094  93.139  -52.242  56.050  4
659095  93.177  -52.269  56.011  4
659096  93.207  -52.288  55.971  4
659097  93.237  -52.306  55.930  4
659098  93.268  -52.325  55.885  4
659099  93.299  -52.343  55.839  4
659100  93.330  -52.362  55.792  4
659101  93.360  -52.380  55.745  4
659102  93.391  -52.399  55.697  4
659103  93.421  -52.418  55.652  4
659104  93.452  -52.437  55.606  4
659105  93.483  -52.456  55.562  4
659106  93.513  -52.474  55.519  4
659134  94.356  -52.991  54.863  1
659135  94.386  -53.010  54.857  1
659136  94.415  -53.028  54.851  1
659137  94.445  -53.046  54.847  1
659138  94.474  -53.064  54.842  1
659139  94.503  -53.082  54.839  1
659140  94.533  -53.101  54.837  1
659141  94.562  -53.119  54.833  1
659142  94.591  -53.137  54.831  1
659143  94.621  -53.155  54.829  1
659144  94.650  -53.174  54.828  1
659145  94.679  -53.192  54.827  1
659146  94.709  -53.211  54.827  1
659147  94.738  -53.229  54.826  1
659148  94.767  -53.247  54.826  1
659149  94.795  -53.253  54.825  1
659150  94.823  -53.259  54.824  1
659151  94.850  -53.265  54.824  1
659152  94.878  -53.272  54.822  1
659153  94.903  -53.280  54.821  1
659154  94.922  -53.293  54.819  1
659155  94.941  -53.307  54.817  1
659156  94.959  -53.320  54.815  1
659157  94.978  -53.333  54.815  1
659158  94.996  -53.347  54.819  1
659159  95.010  -53.365  54.824  1
659160  95.023  -53.383  54.826  1
659161  95.037  -53.402  54.828  1
659162  95.050  -53.420  54.829  1
659163  95.064  -53.438  54.829  1
659164  95.086  -53.457  54.826  1
659165  95.108  -53.476  54.821  1
659166  95.130  -53.495  54.813  1
659167  95.152  -53.514  54.798  1
659168  95.174  -53.534  54.777  1
659169  95.195  -53.552  54.753  1
659170  95.217  -53.571  54.723  1
659171  95.239  -53.590  54.698  1
659172  95.261  -53.609  54.679  1
659173  95.283  -53.629  54.664  1
659174  95.305  -53.648  54.654  1
659175  95.330  -53.669  54.649  1
659176  95.357  -53.691  54.645  1
659177  95.382  -53.710  54.634  1
659178  95.406  -53.725  54.615  1
659179  95.429  -53.741  54.589  1
659180  95.453  -53.756  54.558  1
659181  95.478  -53.772  54.525  1
659182  95.502  -53.787  54.489  1
659183  95.528  -53.802  54.448  1
659184  95.552  -53.817  54.403  1
659185  95.571  -53.828  54.358  1
659186  95.587  -53.836  54.317  1
659187  95.602  -53.844  54.278  1
659188  95.618  -53.853  54.241  1
659189  95.633  -53.861  54.204  1
659190  95.649  -53.869  54.165  1
659191  95.665  -53.878  54.129  1
659192  95.684  -53.885  54.097  1
659193  95.709  -53.893  54.069  1
659194  95.735  -53.900  54.041  1
659195  95.760  -53.907  54.011  1
659196  95.785  -53.913  53.980  1
659197  95.811  -53.920  53.951  1
659198  95.836  -53.928  53.923  1
659199  95.861  -53.935  53.898  1
659200  95.886  -53.941  53.873  1
659201  95.911  -53.948  53.846  1
659202  95.937  -53.956  53.816  1
659203  95.964  -53.966  53.785  1
659204  95.992  -53.979  53.754  1
659205  96.020  -53.991  53.726  1
659206  96.047  -54.004  53.695  1
659207  96.075  -54.016  53.661  1
659208  96.103  -54.028  53.626  1
659209  96.130  -54.041  53.593  1
659210  96.158  -54.053  53.563  1
659211  96.186  -54.065  53.536  1
659212  96.214  -54.077  53.506  1
659213  96.241  -54.089  53.475  1
659214  96.269  -54.102  53.444  1
659215  96.297  -54.114  53.414  1
659216  96.323  -54.130  53.386  1
659217  96.348  -54.148  53.359  1
659218  96.374  -54.165  53.332  1
659219  96.402  -54.176  53.303  1
659220  96.433  -54.186  53.275  1
659221  96.463  -54.196  53.244  1
659222  96.493  -54.207  53.211  1
659223  96.523  -54.217  53.175  1
659224  96.553  -54.228  53.138  1
659225  96.582  -54.240  53.097  1
659226  96.610  -54.252  53.052  1
659227  96.640  -54.263  53.008  1
659228  96.670  -54.273  52.968  1
659229  96.700  -54.282  52.932  1
659230  96.731  -54.292  52.900  1
659231  96.761  -54.301  52.868  1
659232  96.792  -54.311  52.835  1
659233  96.822  -54.321  52.800  1
659234  96.852  -54.330  52.763  1
659235  96.881  -54.336  52.723  1
659236  96.909  -54.343  52.678  1
659237  96.939  -54.350  52.630  1
659238  96.967  -54.357  52.581  1
659239  96.997  -54.364  52.532  1
659240  97.025  -54.370  52.482  1
659241  97.054  -54.377  52.432  1
659242  97.083  -54.384  52.383  1
659243  97.112  -54.391  52.335  1
659244  97.140  -54.399  52.288  1
659245  97.165  -54.410  52.239  1
659246  97.191  -54.417  52.190  1
659247  97.220  -54.425  52.138  1
659248  97.250  -54.433  52.085  1
659249  97.281  -54.440  52.033  1
659250  97.311  -54.448  51.982  1
659251  97.341  -54.455  51.931  1
659252  97.371  -54.464  51.882  1
659253  97.396  -54.466  51.832  1
659254  97.421  -54.467  51.782  1
659255  97.445  -54.470  51.730  1
659256  97.471  -54.474  51.677  1
659257  97.499  -54.480  51.623  1
659258  97.527  -54.486  51.569  1
659259  97.555  -54.493  51.516  1
659260  97.582  -54.498  51.464  1
659261  97.608  -54.497  51.410  1
659262  97.635  -54.496  51.352  1
659263  97.661  -54.496  51.293  1
659264  97.687  -54.495  51.234  1
659265  97.714  -54.494  51.176  1
659266  97.740  -54.493  51.118  1
659267  97.768  -54.493  51.058  1
659268  97.797  -54.494  51.000  1
659269  97.825  -54.495  50.940  1
659270  97.849  -54.496  50.876  1
659271  97.875  -54.496  50.807  1
659272  97.901  -54.496  50.737  1
659273  97.928  -54.497  50.664  1
659274  97.955  -54.497  50.593  1
659275  97.982  -54.498  50.521  1
659276  98.009  -54.498  50.450  1
659277  98.035  -54.499  50.381  1
659278  98.063  -54.499  50.313  1
659279  98.089  -54.499  50.247  1
659280  98.116  -54.499  50.182  1
659281  98.143  -54.499  50.119  1
659282  98.170  -54.500  50.058  1
659283  98.197  -54.500  50.000  1
659284  98.223  -54.501  49.944  1
659706  90.469  -50.680  56.875  9
659707  90.500  -50.694  56.868  9
659708  90.533  -50.713  56.862  9
659709  90.566  -50.732  56.855  9
659710  90.599  -50.751  56.847  9
659711  90.632  -50.771  56.838  9
659712  90.665  -50.790  56.826  9
659713  90.698  -50.810  56.814  9
659714  90.731  -50.829  56.801  9
659715  90.764  -50.845  56.786  9
659716  90.797  -50.852  56.771  9
659717  90.829  -50.860  56.754  9
659718  90.861  -50.868  56.736  9
659719  90.891  -50.877  56.717  9
659720  90.903  -50.893  56.699  9
659721  90.915  -50.909  56.680  9
659722  90.926  -50.924  56.661  9
659723  90.938  -50.940  56.643  9
659735  91.288  -51.119  56.786  4
659736  91.323  -51.134  56.790  4
659737  91.359  -51.149  56.795  4
659738  91.390  -51.163  56.800  4
659739  91.421  -51.177  56.805  4
659740  91.452  -51.191  56.811  4
659741  91.484  -51.205  56.817  4
659742  91.515  -51.220  56.825  4
659743  91.546  -51.234  56.833  4
659744  91.577  -51.249  56.838  4
659745  91.608  -51.263  56.844  4
659746  91.639  -51.277  56.849  4
659747  91.670  -51.292  56.855  4
659748  91.702  -51.306  56.860  4
659749  91.733  -51.321  56.865  4
659750  91.764  -51.335  56.866  4
659751  91.795  -51.349  56.867  4
659752  91.826  -51.363  56.869  4
659753  91.857  -51.378  56.870  4
659754  91.888  -51.392  56.872  4
659755  91.921  -51.402  56.874  4
659756  91.953  -51.409  56.874  4
659757  91.986  -51.415  56.872  4
659758  92.018  -51.423  56.870  4
659759  92.051  -51.430  56.869  4
659760  92.083  -51.437  56.869  4
659761  92.117  -51.456  56.868  4
659762  92.151  -51.475  56.864  4
659763  92.185  -51.494  56.860  4
659764  92.219  -51.512  56.856  4
659765  92.253  -51.532  56.852  4
659766  92.287  -51.551  56.848  4
659767  92.321  -51.570  56.842  4
659768  92.355  -51.590  56.834  4
659769  92.389  -51.609  56.825  4
659770  92.423  -51.628  56.812  4
659771  92.448  -51.645  56.798  4
659772  92.470  -51.660  56.782  4
659773  92.491  -51.676  56.764  4
659774  92.511  -51.691  56.746  4
659775  92.532  -51.707  56.728  4
659776  92.555  -51.723  56.709  4
659777  92.586  -51.744  56.688  4
659778  92.617  -51.763  56.663  4
659779  92.647  -51.783  56.634  4
659780  92.677  -51.803  56.604  4
659781  92.708  -51.823  56.573  4
659782  92.739  -51.842  56.542  4
659783  92.770  -51.865  56.510  4
659784  92.799  -51.894  56.476  4
659785  92.830  -51.923  56.441  4
659786  92.859  -51.951  56.405  4
659787  92.889  -51.980  56.368  4
659788  92.919  -52.009  56.330  4
659789  92.949  -52.038  56.292  4
659790  92.979  -52.067  56.253  4
659791  93.009  -52.095  56.214  4
659792  93.039  -52.124  56.177  4
659793  93.071  -52.154  56.139  4
659794  93.111  -52.184  56.100  4
659795  93.151  -52.214  56.061  4
659796  93.191  -52.244  56.022  4
659797  93.222  -52.264  55.980  4
659798  93.253  -52.283  55.940  4
659799  93.284  -52.301  55.896  4
659800  93.314  -52.320  55.851  4
659801  93.345  -52.339  55.804  4
659802  93.375  -52.357  55.758  4
659803  93.406  -52.376  55.710  4
659804  93.437  -52.394  55.666  4
659805  93.468  -52.413  55.620  4
659806  93.498  -52.431  55.576  4
659807  93.529  -52.450  55.533  4
659836  94.396  -52.985  54.856  1
659837  94.426  -53.003  54.849  1
659838  94.455  -53.021  54.844  1
659839  94.484  -53.039  54.838  1
659840  94.514  -53.057  54.835  1
659841  94.543  -53.076  54.831  1
659842  94.572  -53.094  54.827  1
659843  94.602  -53.112  54.824  1
659844  94.631  -53.131  54.821  1
659845  94.661  -53.149  54.819  1
659846  94.690  -53.167  54.818  1
659847  94.719  -53.186  54.817  1
659848  94.749  -53.204  54.817  1
659849  94.778  -53.222  54.815  1
659850  94.807  -53.235  54.814  1
659851  94.834  -53.241  54.814  1
659852  94.862  -53.248  54.814  1
659853  94.890  -53.254  54.813  1
659854  94.917  -53.260  54.811  1
659855  94.945  -53.266  54.810  1
659856  94.964  -53.279  54.808  1
659857  94.983  -53.292  54.807  1
659858  95.001  -53.306  54.807  1
659859  95.017  -53.322  54.810  1
659860  95.031  -53.340  54.815  1
659861  95.044  -53.358  54.818  1
659862  95.057  -53.377  54.818  1
659863  95.071  -53.394  54.818  1
659864  95.085  -53.412  54.816  1
659865  95.098  -53.430  54.811  1
659866  95.111  -53.449  54.805  1
659867  95.132  -53.468  54.796  1
659868  95.154  -53.487  54.783  1
659869  95.176  -53.506  54.764  1
659870  95.198  -53.525  54.738  1
659871  95.220  -53.544  54.706  1
659872  95.242  -53.563  54.685  1
659873  95.266  -53.584  54.667  1
659874  95.293  -53.606  54.655  1
659875  95.320  -53.629  54.648  1
659876  95.347  -53.651  54.644  1
659877  95.374  -53.674  54.640  1
659878  95.399  -53.691  54.630  1
659879  95.422  -53.706  54.611  1
659880  95.446  -53.722  54.585  1
659881  95.470  -53.737  54.551  1
659882  95.495  -53.752  54.515  1
659883  95.520  -53.767  54.477  1
659884  95.545  -53.782  54.436  1
659885  95.569  -53.797  54.391  1
659886  95.590  -53.809  54.347  1
659887  95.605  -53.818  54.307  1
659888  95.621  -53.826  54.271  1
659889  95.636  -53.834  54.236  1
659890  95.652  -53.843  54.201  1
659891  95.668  -53.851  54.166  1
659892  95.683  -53.860  54.133  1
659893  95.699  -53.868  54.103  1
659894  95.715  -53.875  54.076  1
659895  95.740  -53.883  54.049  1
659896  95.765  -53.890  54.019  1
659897  95.791  -53.897  53.987  1
659898  95.816  -53.903  53.956  1
659899  95.841  -53.911  53.929  1
659900  95.867  -53.918  53.902  1
659901  95.892  -53.925  53.876  1
659902  95.917  -53.932  53.849  1
659903  95.943  -53.939  53.819  1
659904  95.969  -53.948  53.789  1
659905  95.996  -53.960  53.759  1
659906  96.024  -53.973  53.731  1
659907  96.052  -53.985  53.700  1
659908  96.080  -53.997  53.666  1
659909  96.107  -54.010  53.631  1
659910  96.135  -54.022  53.596  1
659911  96.163  -54.035  53.565  1
659912  96.190  -54.047  53.539  1
659913  96.218  -54.059  53.512  1
659914  96.246  -54.071  53.482  1
659915  96.273  -54.084  53.453  1
659916  96.301  -54.096  53.425  1
659917  96.329  -54.108  53.398  1
659918  96.357  -54.121  53.373  1
659919  96.382  -54.138  53.350  1
659920  96.412  -54.148  53.321  1
659921  96.442  -54.158  53.291  1
659922  96.472  -54.169  53.259  1
659923  96.503  -54.179  53.224  1
659924  96.533  -54.189  53.190  1
659925  96.563  -54.200  53.154  1
659926  96.593  -54.211  53.112  1
659927  96.623  -54.220  53.068  1
659928  96.653  -54.230  53.024  1
659929  96.683  -54.240  52.983  1
659930  96.714  -54.249  52.947  1
659931  96.744  -54.259  52.913  1
659932  96.774  -54.269  52.879  1
659933  96.805  -54.279  52.844  1
659934  96.835  -54.289  52.807  1
659935  96.865  -54.297  52.770  1
659936  96.893  -54.304  52.730  1
659937  96.923  -54.311  52.685  1
659938  96.951  -54.317  52.638  1
659939  96.980  -54.324  52.591  1
659940  97.010  -54.331  52.542  1
659941  97.038  -54.338  52.493  1
659942  97.068  -54.345  52.445  1
659943  97.096  -54.352  52.397  1
659944  97.122  -54.361  52.349  1
659945  97.148  -54.372  52.300  1
659946  97.173  -54.381  52.253  1
659947  97.199  -54.389  52.205  1
659948  97.226  -54.397  52.154  1
659949  97.256  -54.405  52.103  1
659950  97.286  -54.412  52.052  1
659951  97.316  -54.420  52.003  1
659952  97.347  -54.427  51.953  1
659953  97.377  -54.435  51.906  1
659954  97.401  -54.437  51.857  1
659955  97.426  -54.439  51.806  1
659956  97.450  -54.441  51.755  1
659957  97.474  -54.443  51.703  1
659958  97.500  -54.447  51.649  1
659959  97.528  -54.453  51.596  1
659960  97.556  -54.460  51.545  1
659961  97.584  -54.464  51.495  1
659962  97.610  -54.463  51.442  1
659963  97.636  -54.462  51.387  1
659964  97.663  -54.461  51.332  1
659965  97.689  -54.461  51.275  1
659966  97.716  -54.461  51.218  1
659967  97.745  -54.461  51.160  1
659968  97.775  -54.462  51.102  1
659969  97.804  -54.463  51.044  1
659970  97.829  -54.464  50.984  1
659971  97.853  -54.465  50.922  1
659972  97.877  -54.466  50.856  1
659973  97.904  -54.466  50.790  1
659974  97.931  -54.467  50.716  1
659975  97.958  -54.467  50.642  1
659976  97.985  -54.467  50.570  1
659977  98.011  -54.467  50.499  1
659978  98.038  -54.468  50.429  1
659979  98.065  -54.468  50.361  1
659980  98.092  -54.469  50.293  1
659981  98.119  -54.469  50.227  1
659982  98.146  -54.470  50.163  1
659983  98.172  -54.470  50.100  1
659984  98.199  -54.470  50.040  1
659985  98.226  -54.471  49.983  1
659986  98.253  -54.471  49.926  1
660407  90.487  -50.644  56.864  9
660408  90.521  -50.665  56.859  9
660409  90.555  -50.685  56.854  9
660410  90.586  -50.699  56.848  9
660411  90.619  -50.718  56.842  9
660412  90.652  -50.738  56.832  9
660413  90.685  -50.757  56.823  9
660414  90.718  -50.776  56.811  9
660415  90.751  -50.795  56.799  9
660416  90.784  -50.811  56.785  9
660417  90.816  -50.819  56.770  9
660418  90.849  -50.827  56.754  9
660419  90.881  -50.835  56.735  9
660420  90.896  -50.849  56.717  9
660421  90.908  -50.865  56.699  9
660422  90.920  -50.881  56.680  9
660423  90.931  -50.897  56.661  9
660424  90.943  -50.913  56.642  9
660425  90.955  -50.929  56.625  9
660437  91.363  -51.103  56.779  4
660438  91.394  -51.117  56.785  4
660439  91.425  -51.132  56.789  4
660440  91.456  -51.146  56.793  4
660441  91.488  -51.161  56.798  4
660442  91.519  -51.174  56.804  4
660443  91.550  -51.189  56.811  4
660444  91.581  -51.203  56.819  4
660445  91.612  -51.218  56.823  4
660446  91.643  -51.232  56.829  4
660447  91.674  -51.246  56.834  4
660448  91.706  -51.261  56.839  4
660449  91.737  -51.275  56.844  4
660450  91.768  -51.290  56.849  4
660451  91.799  -51.304  56.851  4
660452  91.830  -51.318  56.852  4
660453  91.861  -51.333  56.853  4
660454  91.892  -51.346  56.855  4
660455  91.924  -51.361  56.857  4
660456  91.954  -51.375  56.859  4
660457  91.986  -51.390  56.859  4
660458  92.018  -51.399  56.858  4
660459  92.050  -51.407  56.856  4
660460  92.083  -51.414  56.855  4
660461  92.115  -51.421  56.856  4
660462  92.148  -51.429  56.854  4
660463  92.182  -51.448  56.851  4
660464  92.216  -51.468  56.847  4
660465  92.250  -51.487  56.844  4
660466  92.284  -51.506  56.841  4
660467  92.318  -51.525  56.837  4
660468  92.352  -51.544  56.831  4
660469  92.386  -51.563  56.824  4
660470  92.420  -51.582  56.815  4
660471  92.440  -51.598  56.802  4
660472  92.461  -51.614  56.785  4
660473  92.483  -51.629  56.769  4
660474  92.503  -51.645  56.752  4
660475  92.524  -51.660  56.734  4
660476  92.546  -51.676  56.717  4
660477  92.576  -51.696  56.698  4
660478  92.606  -51.716  56.677  4
660479  92.637  -51.735  56.656  4
660480  92.668  -51.755  56.628  4
660481  92.699  -51.776  56.599  4
660482  92.729  -51.795  56.570  4
660483  92.760  -51.815  56.541  4
660484  92.790  -51.838  56.511  4
660485  92.820  -51.867  56.480  4
660486  92.850  -51.896  56.447  4
660487  92.880  -51.925  56.412  4
660488  92.910  -51.954  56.377  4
660489  92.940  -51.982  56.341  4
660490  92.970  -52.011  56.303  4
660491  93.000  -52.040  56.266  4
660492  93.030  -52.069  56.228  4
660493  93.060  -52.098  56.191  4
660494  93.090  -52.127  56.153  4
660495  93.124  -52.156  56.113  4
660496  93.163  -52.186  56.072  4
660497  93.203  -52.217  56.033  4
660498  93.237  -52.240  55.992  4
660499  93.268  -52.259  55.951  4
660500  93.299  -52.277  55.908  4
660501  93.330  -52.296  55.862  4
660502  93.360  -52.315  55.816  4
660503  93.391  -52.333  55.771  4
660504  93.421  -52.352  55.724  4
660505  93.452  -52.371  55.679  4
660506  93.483  -52.389  55.634  4
660507  93.513  -52.408  55.590  4
660508  93.544  -52.427  55.547  4
660537  94.407  -52.960  54.854  1
660538  94.436  -52.978  54.846  1
660539  94.466  -52.996  54.840  1
660540  94.495  -53.014  54.834  1
660541  94.525  -53.032  54.829  1
660542  94.554  -53.051  54.825  1
660543  94.583  -53.069  54.821  1
660544  94.613  -53.088  54.816  1
660545  94.642  -53.106  54.813  1
660546  94.672  -53.124  54.811  1
660547  94.701  -53.142  54.809  1
660548  94.731  -53.161  54.808  1
660549  94.760  -53.179  54.807  1
660550  94.789  -53.197  54.806  1
660551  94.819  -53.215  54.805  1
660552  94.846  -53.223  54.804  1
660553  94.874  -53.230  54.804  1
660554  94.901  -53.236  54.803  1
660555  94.929  -53.242  54.801  1
660556  94.957  -53.248  54.800  1
660557  94.984  -53.254  54.800  1
660558  95.006  -53.264  54.801  1
660559  95.024  -53.279  54.801  1
660560  95.038  -53.297  54.802  1
660561  95.051  -53.315  54.805  1
660562  95.065  -53.333  54.807  1
660563  95.078  -53.351  54.806  1
660564  95.092  -53.369  54.804  1
660565  95.105  -53.387  54.800  1
660566  95.119  -53.405  54.793  1
660567  95.132  -53.424  54.786  1
660568  95.145  -53.442  54.777  1
660569  95.159  -53.460  54.765  1
660570  95.178  -53.478  54.746  1
660571  95.202  -53.499  54.722  1
660572  95.229  -53.521  54.693  1
660573  95.256  -53.543  54.673  1
660574  95.283  -53.566  54.659  1
660575  95.310  -53.589  54.650  1
660576  95.337  -53.611  54.645  1
660577  95.364  -53.634  54.641  1
660578  95.391  -53.656  54.634  1
660579  95.415  -53.672  54.627  1
660580  95.439  -53.687  54.606  1
660581  95.462  -53.703  54.579  1
660582  95.487  -53.718  54.544  1
660583  95.512  -53.733  54.505  1
660584  95.537  -53.748  54.466  1
660585  95.562  -53.763  54.422  1
660586  95.587  -53.778  54.377  1
660587  95.608  -53.791  54.334  1
660588  95.624  -53.799  54.296  1
660589  95.639  -53.807  54.262  1
660590  95.655  -53.816  54.230  1
660591  95.671  -53.824  54.199  1
660592  95.686  -53.832  54.167  1
660593  95.702  -53.841  54.138  1
660594  95.718  -53.849  54.109  1
660595  95.733  -53.857  54.082  1
660596  95.749  -53.866  54.055  1
660597  95.771  -53.873  54.026  1
660598  95.796  -53.880  53.993  1
660599  95.821  -53.887  53.959  1
660600  95.847  -53.894  53.933  1
660601  95.872  -53.901  53.905  1
660602  95.897  -53.908  53.878  1
660603  95.922  -53.915  53.850  1
660604  95.948  -53.922  53.820  1
660605  95.974  -53.930  53.791  1
660606  96.002  -53.942  53.761  1
660607  96.029  -53.955  53.733  1
660608  96.057  -53.967  53.703  1
660609  96.085  -53.979  53.669  1
660610  96.112  -53.991  53.633  1
660611  96.140  -54.004  53.598  1
660612  96.168  -54.016  53.567  1
660613  96.195  -54.029  53.541  1
660614  96.223  -54.041  53.516  1
660615  96.251  -54.053  53.488  1
660616  96.278  -54.066  53.460  1
660617  96.306  -54.078  53.434  1
660618  96.334  -54.090  53.409  1
660619  96.362  -54.102  53.385  1
660620  96.391  -54.111  53.363  1
660621  96.421  -54.122  53.334  1
660622  96.452  -54.132  53.303  1
660623  96.482  -54.143  53.270  1
660624  96.512  -54.153  53.236  1
660625  96.542  -54.164  53.201  1
660626  96.572  -54.172  53.166  1
660627  96.604  -54.179  53.126  1
660628  96.636  -54.188  53.082  1
660629  96.666  -54.198  53.038  1
660630  96.696  -54.207  52.997  1
660631  96.727  -54.217  52.959  1
660632  96.757  -54.226  52.923  1
660633  96.787  -54.236  52.887  1
660634  96.817  -54.246  52.850  1
660635  96.848  -54.256  52.813  1
660636  96.878  -54.265  52.776  1
660637  96.906  -54.272  52.736  1
660638  96.936  -54.279  52.692  1
660639  96.964  -54.286  52.646  1
660640  96.994  -54.292  52.600  1
660641  97.022  -54.299  52.553  1
660642  97.051  -54.306  52.505  1
660643  97.079  -54.314  52.458  1
660644  97.104  -54.324  52.410  1
660645  97.130  -54.334  52.362  1
660646  97.155  -54.345  52.314  1
660647  97.181  -54.353  52.268  1
660648  97.207  -54.361  52.219  1
660649  97.233  -54.369  52.170  1
660650  97.261  -54.377  52.120  1
660651  97.292  -54.384  52.071  1
660652  97.322  -54.392  52.023  1
660653  97.352  -54.399  51.975  1
660654  97.382  -54.407  51.929  1
660655  97.406  -54.409  51.880  1
660656  97.431  -54.411  51.829  1
660657  97.455  -54.413  51.778  1
660658  97.479  -54.414  51.726  1
660659  97.504  -54.417  51.674  1
660660  97.530  -54.421  51.622  1
660661  97.558  -54.427  51.573  1
660662  97.585  -54.430  51.524  1
660663  97.611  -54.429  51.473  1
660664  97.638  -54.429  51.420  1
660665  97.665  -54.428  51.366  1
660666  97.694  -54.429  51.311  1
660667  97.724  -54.430  51.255  1
660668  97.753  -54.430  51.198  1
660669  97.783  -54.432  51.140  1
660670  97.810  -54.433  51.083  1
660671  97.834  -54.433  51.025  1
660672  97.858  -54.434  50.964  1
660673  97.881  -54.436  50.901  1
660674  97.907  -54.436  50.836  1
660675  97.934  -54.436  50.765  1
660676  97.960  -54.436  50.692  1
660677  97.987  -54.437  50.619  1
660678  98.014  -54.437  50.547  1
660679  98.041  -54.438  50.477  1
660680  98.068  -54.438  50.407  1
660681  98.094  -54.439  50.339  1
660682  98.122  -54.439  50.272  1
660683  98.148  -54.439  50.207  1
660684  98.175  -54.439  50.143  1
660685  98.202  -54.440  50.081  1
660686  98.229  -54.440  50.022  1
660687  98.255  -54.440  49.965  1
661107  90.469  -50.588  56.857  9
661108  90.504  -50.608  56.854  9
661109  90.539  -50.629  56.849  9
661110  90.574  -50.649  56.844  9
661111  90.608  -50.670  56.841  9
661112  90.639  -50.685  56.836  9
661113  90.672  -50.704  56.827  9
661114  90.705  -50.723  56.818  9
661115  90.738  -50.743  56.808  9
661116  90.771  -50.762  56.796  9
661117  90.804  -50.777  56.783  9
661118  90.836  -50.785  56.768  9
661119  90.869  -50.794  56.753  9
661120  90.889  -50.806  56.736  9
661121  90.901  -50.822  56.718  9
661122  90.913  -50.838  56.699  9
661123  90.925  -50.853  56.680  9
661124  90.937  -50.869  56.661  9
661125  90.962  -50.884  56.642  9
661126  90.999  -50.898  56.625  9
661138  91.398  -51.072  56.770  4
661139  91.429  -51.086  56.775  4
661140  91.460  -51.101  56.778  4
661141  91.492  -51.115  56.781  4
661142  91.523  -51.130  56.786  4
661143  91.554  -51.144  56.791  4
661144  91.585  -51.158  56.798  4
661145  91.616  -51.172  56.805  4
661146  91.647  -51.186  56.809  4
661147  91.678  -51.201  56.814  4
661148  91.710  -51.215  56.818  4
661149  91.740  -51.230  56.823  4
661150  91.772  -51.244  56.829  4
661151  91.803  -51.258  56.833  4
661152  91.834  -51.273  56.835  4
661153  91.865  -51.287  56.836  4
661154  91.896  -51.302  56.838  4
661155  91.927  -51.315  56.841  4
661156  91.958  -51.330  56.843  4
661157  91.990  -51.344  56.845  4
661158  92.021  -51.359  56.844  4
661159  92.052  -51.373  56.843  4
661160  92.083  -51.387  56.842  4
661161  92.115  -51.398  56.842  4
661162  92.147  -51.405  56.842  4
661163  92.180  -51.412  56.841  4
661164  92.213  -51.422  56.838  4
661165  92.247  -51.441  56.835  4
661166  92.281  -51.461  56.833  4
661167  92.315  -51.480  56.829  4
661168  92.349  -51.499  56.825  4
661169  92.383  -51.519  56.819  4
661170  92.412  -51.536  56.811  4
661171  92.433  -51.552  56.803  4
661172  92.453  -51.567  56.789  4
661173  92.475  -51.583  56.772  4
661174  92.496  -51.598  56.755  4
661175  92.516  -51.614  56.738  4
661176  92.537  -51.629  56.721  4
661177  92.566  -51.649  56.703  4
661178  92.597  -51.669  56.686  4
661179  92.628  -51.688  56.667  4
661180  92.658  -51.708  56.645  4
661181  92.689  -51.728  56.620  4
661182  92.720  -51.747  56.593  4
661183  92.751  -51.767  56.566  4
661184  92.781  -51.788  56.539  4
661185  92.811  -51.812  56.511  4
661186  92.841  -51.841  56.483  4
661187  92.871  -51.870  56.453  4
661188  92.901  -51.898  56.420  4
661189  92.931  -51.927  56.386  4
661190  92.961  -51.956  56.352  4
661191  92.991  -51.985  56.315  4
661192  93.021  -52.014  56.279  4
661193  93.051  -52.043  56.243  4
661194  93.081  -52.072  56.207  4
661195  93.111  -52.101  56.168  4
661196  93.141  -52.130  56.127  4
661197  93.176  -52.159  56.085  4
661198  93.215  -52.189  56.045  4
661199  93.253  -52.217  56.004  4
661200  93.283  -52.235  55.962  4
661201  93.314  -52.254  55.919  4
661202  93.345  -52.272  55.875  4
661203  93.375  -52.291  55.828  4
661204  93.406  -52.310  55.782  4
661205  93.437  -52.328  55.737  4
661206  93.467  -52.347  55.693  4
661207  93.498  -52.365  55.648  4
661208  93.529  -52.384  55.604  4
661209  93.559  -52.402  55.561  4
661239  94.448  -52.953  54.843  1
661240  94.477  -52.971  54.836  1
661241  94.506  -52.989  54.830  1
661242  94.536  -53.007  54.824  1
661243  94.565  -53.026  54.819  1
661244  94.594  -53.045  54.814  1
661245  94.624  -53.063  54.809  1
661246  94.653  -53.081  54.805  1
661247  94.682  -53.099  54.802  1
661248  94.712  -53.117  54.800  1
661249  94.741  -53.136  54.798  1
661250  94.770  -53.154  54.797  1
661251  94.800  -53.172  54.797  1
661252  94.829  -53.190  54.795  1
661253  94.858  -53.205  54.794  1
661254  94.886  -53.211  54.794  1
661255  94.913  -53.217  54.793  1
661256  94.941  -53.223  54.792  1
661257  94.968  -53.230  54.791  1
661258  94.996  -53.236  54.791  1
661259  95.024  -53.242  54.792  1
661260  95.046  -53.255  54.792  1
661261  95.060  -53.273  54.793  1
661262  95.074  -53.292  54.793  1
661263  95.088  -53.311  54.793  1
661264  95.101  -53.329  54.791  1
661265  95.115  -53.347  54.786  1
661266  95.129  -53.366  54.780  1
661267  95.142  -53.384  54.774  1
661268  95.156  -53.402  54.766  1
661269  95.170  -53.421  54.757  1
661270  95.184  -53.440  54.743  1
661271  95.198  -53.458  54.725  1
661272  95.219  -53.481  54.704  1
661273  95.246  -53.503  54.682  1
661274  95.273  -53.526  54.665  1
661275  95.300  -53.548  54.655  1
661276  95.327  -53.571  54.650  1
661277  95.354  -53.593  54.645  1
661278  95.381  -53.615  54.640  1
661279  95.408  -53.637  54.634  1
661280  95.431  -53.653  54.624  1
661281  95.455  -53.668  54.602  1
661282  95.479  -53.683  54.573  1
661283  95.505  -53.698  54.538  1
661284  95.529  -53.713  54.499  1
661285  95.554  -53.728  54.457  1
661286  95.580  -53.744  54.414  1
661287  95.604  -53.759  54.371  1
661288  95.627  -53.772  54.328  1
661289  95.642  -53.781  54.290  1
661290  95.658  -53.789  54.258  1
661291  95.674  -53.797  54.231  1
661292  95.689  -53.806  54.203  1
661293  95.705  -53.814  54.173  1
661294  95.721  -53.822  54.145  1
661295  95.736  -53.831  54.114  1
661296  95.752  -53.839  54.086  1
661297  95.767  -53.847  54.059  1
661298  95.783  -53.856  54.030  1
661299  95.802  -53.863  53.996  1
661300  95.827  -53.870  53.962  1
661301  95.852  -53.877  53.934  1
661302  95.878  -53.885  53.906  1
661303  95.903  -53.891  53.879  1
661304  95.928  -53.898  53.849  1
661305  95.953  -53.905  53.819  1
661306  95.979  -53.913  53.789  1
661307  96.006  -53.924  53.761  1
661308  96.034  -53.937  53.732  1
661309  96.061  -53.949  53.704  1
661310  96.089  -53.961  53.670  1
661311  96.117  -53.973  53.634  1
661312  96.145  -53.986  53.601  1
661313  96.172  -53.998  53.569  1
661314  96.200  -54.010  53.543  1
661315  96.228  -54.022  53.519  1
661316  96.255  -54.035  53.493  1
661317  96.283  -54.048  53.467  1
661318  96.311  -54.060  53.442  1
661319  96.339  -54.070  53.420  1
661320  96.370  -54.077  53.397  1
661321  96.400  -54.086  53.374  1
661322  96.430  -54.097  53.346  1
661323  96.460  -54.107  53.314  1
661324  96.490  -54.118  53.280  1
661325  96.521  -54.129  53.246  1
661326  96.550  -54.136  53.210  1
661327  96.580  -54.143  53.174  1
661328  96.612  -54.151  53.133  1
661329  96.645  -54.158  53.092  1
661330  96.678  -54.166  53.050  1
661331  96.709  -54.175  53.009  1
661332  96.740  -54.185  52.970  1
661333  96.770  -54.194  52.932  1
661334  96.800  -54.204  52.894  1
661335  96.830  -54.214  52.859  1
661336  96.861  -54.223  52.822  1
661337  96.890  -54.232  52.784  1
661338  96.920  -54.239  52.745  1
661339  96.949  -54.246  52.703  1
661340  96.977  -54.253  52.657  1
661341  97.007  -54.260  52.611  1
661342  97.035  -54.267  52.566  1
661343  97.061  -54.276  52.520  1
661344  97.087  -54.286  52.472  1
661345  97.112  -54.297  52.425  1
661346  97.138  -54.307  52.377  1
661347  97.163  -54.317  52.329  1
661348  97.189  -54.325  52.282  1
661349  97.215  -54.333  52.233  1
661350  97.241  -54.340  52.185  1
661351  97.267  -54.348  52.137  1
661352  97.297  -54.356  52.089  1
661353  97.327  -54.364  52.042  1
661354  97.358  -54.371  51.995  1
661355  97.387  -54.378  51.949  1
661356  97.412  -54.380  51.900  1
661357  97.436  -54.383  51.850  1
661358  97.460  -54.384  51.800  1
661359  97.485  -54.386  51.748  1
661360  97.509  -54.388  51.698  1
661361  97.533  -54.390  51.647  1
661362  97.559  -54.394  51.599  1
661363  97.586  -54.396  51.551  1
661364  97.613  -54.395  51.502  1
661365  97.643  -54.396  51.450  1
661366  97.672  -54.398  51.396  1
661367  97.702  -54.399  51.343  1
661368  97.731  -54.399  51.288  1
661369  97.760  -54.400  51.232  1
661370  97.790  -54.401  51.175  1
661371  97.814  -54.402  51.119  1
661372  97.839  -54.403  51.062  1
661373  97.862  -54.404  51.003  1
661374  97.886  -54.405  50.942  1
661375  97.910  -54.406  50.878  1
661376  97.936  -54.406  50.810  1
661377  97.963  -54.406  50.739  1
661378  97.990  -54.407  50.666  1
661379  98.017  -54.407  50.594  1
661380  98.043  -54.408  50.523  1
661381  98.070  -54.408  50.453  1
661382  98.097  -54.408  50.384  1
661383  98.124  -54.408  50.317  1
661384  98.151  -54.409  50.250  1
661385  98.178  -54.409  50.185  1
661386  98.205  -54.410  50.123  1
661387  98.231  -54.410  50.062  1
661388  98.258  -54.410  50.004  1
661389  98.285  -54.411  49.948  1
661808  90.487  -50.551  56.844  9
661809  90.521  -50.572  56.841  9
661810  90.556  -50.592  56.838  9
661811  90.591  -50.613  56.835  9
661812  90.625  -50.634  56.833  9
661813  90.660  -50.654  56.828  9
661814  90.692  -50.671  56.822  9
661815  90.725  -50.691  56.814  9
661816  90.758  -50.710  56.804  9
661817  90.792  -50.729  56.793  9
661818  90.824  -50.744  56.780  9
661819  90.857  -50.752  56.766  9
661820  90.883  -50.763  56.752  9
661821  90.894  -50.778  56.735  9
661822  90.906  -50.794  56.717  9
661823  90.918  -50.810  56.699  9
661824  90.944  -50.825  56.680  9
661825  90.980  -50.839  56.661  9
661826  91.016  -50.854  56.642  9
661827  91.052  -50.869  56.624  9
661841  91.496  -51.070  56.767  4
661842  91.527  -51.084  56.770  4
661843  91.558  -51.099  56.774  4
661844  91.589  -51.113  56.779  4
661845  91.620  -51.127  56.785  4
661846  91.651  -51.141  56.791  4
661847  91.682  -51.155  56.796  4
661848  91.714  -51.170  56.800  4
661849  91.744  -51.184  56.804  4
661850  91.776  -51.199  56.808  4
661851  91.807  -51.213  56.814  4
661852  91.838  -51.227  56.819  4
661853  91.869  -51.242  56.819  4
661854  91.900  -51.256  56.821  4
661855  91.931  -51.271  56.823  4
661856  91.962  -51.285  56.826  4
661857  91.994  -51.299  56.829  4
661858  92.025  -51.313  56.831  4
661859  92.056  -51.327  56.829  4
661860  92.087  -51.342  56.828  4
661861  92.118  -51.356  56.827  4
661862  92.149  -51.371  56.827  4
661863  92.180  -51.385  56.827  4
661864  92.212  -51.396  56.827  4
661865  92.244  -51.403  56.824  4
661866  92.278  -51.415  56.820  4
661867  92.312  -51.434  56.818  4
661868  92.346  -51.453  56.815  4
661869  92.380  -51.473  56.811  4
661870  92.404  -51.489  56.805  4
661871  92.425  -51.505  56.796  4
661872  92.445  -51.521  56.786  4
661873  92.466  -51.536  56.773  4
661874  92.488  -51.552  56.758  4
661875  92.508  -51.567  56.742  4
661876  92.529  -51.583  56.725  4
661877  92.557  -51.601  56.707  4
661878  92.587  -51.621  56.690  4
661879  92.618  -51.641  56.674  4
661880  92.649  -51.660  56.655  4
661881  92.680  -51.681  56.635  4
661882  92.710  -51.700  56.612  4
661883  92.741  -51.720  56.587  4
661884  92.772  -51.740  56.561  4
661885  92.802  -51.760  56.536  4
661886  92.833  -51.785  56.511  4
661887  92.862  -51.814  56.485  4
661888  92.893  -51.843  56.456  4
661889  92.922  -51.872  56.425  4
661890  92.952  -51.901  56.393  4
661891  92.982  -51.930  56.360  4
661892  93.012  -51.959  56.327  4
661893  93.042  -51.988  56.294  4
661894  93.072  -52.017  56.259  4
661895  93.102  -52.045  56.222  4
661896  93.132  -52.074  56.183  4
661897  93.162  -52.103  56.142  4
661898  93.192  -52.132  56.099  4
661899  93.227  -52.161  56.057  4
661900  93.267  -52.192  56.016  4
661901  93.299  -52.211  55.973  4
661902  93.330  -52.230  55.930  4
661903  93.360  -52.249  55.886  4
661904  93.391  -52.268  55.840  4
661905  93.421  -52.286  55.794  4
661906  93.452  -52.305  55.749  4
661907  93.483  -52.323  55.705  4
661908  93.513  -52.342  55.662  4
661909  93.544  -52.360  55.618  4
661910  93.574  -52.379  55.575  4
661941  94.487  -52.946  54.833  1
661942  94.517  -52.964  54.826  1
661943  94.546  -52.982  54.819  1
661944  94.575  -53.001  54.813  1
661945  94.605  -53.020  54.807  1
661946  94.634  -53.038  54.801  1
661947  94.664  -53.056  54.796  1
661948  94.693  -53.074  54.794  1
661949  94.722  -53.092  54.791  1
661950  94.752  -53.111  54.789  1
661951  94.781  -53.129  54.787  1
661952  94.811  -53.147  54.786  1
661953  94.840  -53.166  54.785  1
661954  94.870  -53.184  54.784  1
661955  94.897  -53.193  54.783  1
661956  94.925  -53.199  54.782  1
661957  94.953  -53.205  54.782  1
661958  94.980  -53.211  54.781  1
661959  95.008  -53.218  54.780  1
661960  95.035  -53.224  54.781  1
661961  95.063  -53.235  54.782  1
661962  95.087  -53.255  54.782  1
661963  95.100  -53.273  54.781  1
661964  95.114  -53.292  54.779  1
661965  95.127  -53.311  54.774  1
661966  95.141  -53.329  54.767  1
661967  95.155  -53.348  54.759  1
661968  95.169  -53.366  54.751  1
661969  95.183  -53.384  54.743  1
661970  95.196  -53.402  54.732  1
661971  95.210  -53.421  54.718  1
661972  95.225  -53.441  54.702  1
661973  95.243  -53.463  54.685  1
661974  95.263  -53.486  54.671  1
661975  95.290  -53.508  54.665  1
661976  95.317  -53.531  54.662  1
661977  95.344  -53.553  54.657  1
661978  95.372  -53.575  54.650  1
661979  95.398  -53.598  54.643  1
661980  95.424  -53.618  54.639  1
661981  95.448  -53.634  54.623  1
661982  95.472  -53.649  54.598  1
661983  95.497  -53.664  54.568  1
661984  95.522  -53.679  54.533  1
661985  95.547  -53.694  54.494  1
661986  95.571  -53.709  54.451  1
661987  95.597  -53.725  54.410  1
661988  95.621  -53.739  54.368  1
661989  95.645  -53.753  54.327  1
661990  95.661  -53.762  54.288  1
661991  95.676  -53.770  54.257  1
661992  95.692  -53.778  54.233  1
661993  95.707  -53.787  54.209  1
661994  95.723  -53.795  54.180  1
661995  95.739  -53.803  54.151  1
661996  95.754  -53.812  54.120  1
661997  95.770  -53.820  54.090  1
661998  95.785  -53.828  54.062  1
661999  95.801  -53.837  54.033  1
662000  95.817  -53.845  53.999  1
662001  95.832  -53.853  53.966  1
662002  95.858  -53.860  53.938  1
662003  95.883  -53.868  53.910  1
662004  95.908  -53.875  53.882  1
662005  95.934  -53.882  53.852  1
662006  95.959  -53.888  53.820  1
662007  95.984  -53.896  53.788  1
662008  96.011  -53.906  53.758  1
662009  96.039  -53.919  53.730  1
662010  96.066  -53.931  53.701  1
662011  96.094  -53.943  53.669  1
662012  96.122  -53.955  53.635  1
662013  96.150  -53.968  53.602  1
662014  96.177  -53.980  53.570  1
662015  96.205  -53.992  53.544  1
662016  96.233  -54.004  53.521  1
662017  96.260  -54.016  53.497  1
662018  96.288  -54.029  53.473  1
662019  96.318  -54.037  53.450  1
662020  96.348  -54.044  53.430  1
662021  96.379  -54.051  53.409  1
662022  96.409  -54.062  53.384  1
662023  96.439  -54.073  53.356  1
662024  96.469  -54.082  53.325  1
662025  96.499  -54.093  53.290  1
662026  96.529  -54.101  53.255  1
662027  96.558  -54.107  53.218  1
662028  96.588  -54.115  53.180  1
662029  96.619  -54.123  53.139  1
662030  96.653  -54.130  53.100  1
662031  96.686  -54.138  53.060  1
662032  96.719  -54.145  53.020  1
662033  96.752  -54.152  52.980  1
662034  96.783  -54.162  52.942  1
662035  96.813  -54.171  52.903  1
662036  96.843  -54.181  52.868  1
662037  96.874  -54.191  52.830  1
662038  96.903  -54.200  52.793  1
662039  96.933  -54.207  52.754  1
662040  96.961  -54.214  52.713  1
662041  96.991  -54.220  52.668  1
662042  97.018  -54.229  52.622  1
662043  97.043  -54.239  52.577  1
662044  97.069  -54.249  52.531  1
662045  97.094  -54.259  52.484  1
662046  97.120  -54.270  52.437  1
662047  97.145  -54.279  52.391  1
662048  97.171  -54.289  52.343  1
662049  97.197  -54.297  52.296  1
662050  97.223  -54.305  52.249  1
662051  97.249  -54.312  52.201  1
662052  97.275  -54.320  52.153  1
662053  97.303  -54.328  52.106  1
662054  97.333  -54.336  52.059  1
662055  97.363  -54.343  52.013  1
662056  97.392  -54.350  51.966  1
662057  97.417  -54.352  51.917  1
662058  97.441  -54.354  51.869  1
662059  97.465  -54.355  51.819  1
662060  97.490  -54.358  51.769  1
662061  97.514  -54.360  51.719  1
662062  97.538  -54.361  51.669  1
662063  97.563  -54.364  51.622  1
662064  97.591  -54.364  51.575  1
662065  97.620  -54.365  51.525  1
662066  97.650  -54.366  51.474  1
662067  97.679  -54.367  51.422  1
662068  97.709  -54.367  51.370  1
662069  97.738  -54.368  51.315  1
662070  97.768  -54.370  51.261  1
662071  97.795  -54.370  51.205  1
662072  97.819  -54.371  51.150  1
662073  97.843  -54.372  51.094  1
662074  97.866  -54.373  51.037  1
662075  97.890  -54.374  50.977  1
662076  97.914  -54.375  50.914  1
662077  97.939  -54.376  50.850  1
662078  97.966  -54.376  50.781  1
662079  97.993  -54.377  50.712  1
662080  98.019  -54.377  50.640  1
662081  98.046  -54.377  50.568  1
662082  98.073  -54.377  50.498  1
662083  98.100  -54.378  50.430  1
662084  98.127  -54.378  50.362  1
662085  98.154  -54.379  50.294  1
662086  98.180  -54.379  50.228  1
662087  98.207  -54.380  50.165  1
662088  98.234  -54.380  50.103  1
662089  98.261  -54.380  50.044  1
662090  98.287  -54.383  49.987  1
662509  90.504  -50.515  56.829  9
662510  90.539  -50.535  56.828  9
662511  90.574  -50.556  56.827  9
662512  90.608  -50.577  56.825  9
662513  90.643  -50.597  56.823  9
662514  90.677  -50.618  56.820  9
662515  90.712  -50.639  56.815  9
662516  90.746  -50.659  56.808  9
662517  90.779  -50.676  56.799  9
662518  90.811  -50.696  56.789  9
662519  90.844  -50.710  56.778  9
662520  90.876  -50.719  56.764  9
662521  90.888  -50.735  56.750  9
662522  90.899  -50.751  56.734  9
662523  90.925  -50.766  56.716  9
662524  90.961  -50.780  56.698  9
662525  90.997  -50.795  56.679  9
662526  91.032  -50.809  56.661  9
662527  91.064  -50.823  56.642  9
662528  91.095  -50.838  56.624  9
662529  91.126  -50.852  56.608  9
662543  91.562  -51.053  56.759  4
662544  91.593  -51.067  56.763  4
662545  91.624  -51.082  56.767  4
662546  91.655  -51.096  56.772  4
662547  91.686  -51.110  56.778  4
662548  91.717  -51.124  56.782  4
662549  91.748  -51.139  56.786  4
662550  91.780  -51.153  56.790  4
662551  91.811  -51.168  56.794  4
662552  91.842  -51.182  56.799  4
662553  91.873  -51.196  56.804  4
662554  91.904  -51.211  56.806  4
662555  91.935  -51.225  56.807  4
662556  91.966  -51.240  56.809  4
662557  91.998  -51.254  56.811  4
662558  92.029  -51.268  56.814  4
662559  92.060  -51.282  56.817  4
662560  92.091  -51.296  56.815  4
662561  92.122  -51.311  56.813  4
662562  92.153  -51.325  56.812  4
662563  92.184  -51.340  56.812  4
662564  92.216  -51.354  56.812  4
662565  92.247  -51.368  56.812  4
662566  92.278  -51.383  56.809  4
662567  92.309  -51.395  56.805  4
662568  92.343  -51.409  56.803  4
662569  92.375  -51.427  56.800  4
662570  92.395  -51.443  56.795  4
662571  92.417  -51.458  56.788  4
662572  92.438  -51.474  56.778  4
662573  92.458  -51.490  56.768  4
662574  92.480  -51.505  56.756  4
662575  92.501  -51.521  56.741  4
662576  92.521  -51.536  56.726  4
662577  92.547  -51.554  56.710  4
662578  92.578  -51.574  56.694  4
662579  92.609  -51.594  56.677  4
662580  92.639  -51.613  56.661  4
662581  92.670  -51.633  56.643  4
662582  92.700  -51.653  56.625  4
662583  92.731  -51.672  56.604  4
662584  92.762  -51.693  56.580  4
662585  92.792  -51.713  56.555  4
662586  92.823  -51.732  56.532  4
662587  92.853  -51.759  56.509  4
662588  92.883  -51.788  56.486  4
662589  92.913  -51.816  56.459  4
662590  92.943  -51.846  56.430  4
662591  92.973  -51.875  56.399  4
662592  93.003  -51.904  56.368  4
662593  93.033  -51.932  56.337  4
662594  93.063  -51.961  56.305  4
662595  93.093  -51.990  56.272  4
662596  93.123  -52.019  56.237  4
662597  93.153  -52.048  56.200  4
662598  93.183  -52.076  56.159  4
662599  93.213  -52.105  56.117  4
662600  93.243  -52.134  56.072  4
662601  93.280  -52.164  56.028  4
662602  93.314  -52.188  55.985  4
662603  93.345  -52.206  55.941  4
662604  93.375  -52.225  55.898  4
662605  93.406  -52.243  55.852  4
662606  93.436  -52.262  55.806  4
662607  93.467  -52.281  55.762  4
662608  93.498  -52.299  55.718  4
662609  93.529  -52.318  55.675  4
662610  93.558  -52.336  55.632  4
662611  93.587  -52.355  55.590  4
662645  94.586  -52.976  54.807  1
662646  94.616  -52.995  54.800  1
662647  94.645  -53.013  54.794  1
662648  94.675  -53.031  54.789  1
662649  94.704  -53.049  54.785  1
662650  94.733  -53.067  54.782  1
662651  94.763  -53.086  54.779  1
662652  94.792  -53.104  54.777  1
662653  94.821  -53.123  54.775  1
662654  94.851  -53.141  54.774  1
662655  94.880  -53.159  54.772  1
662656  94.909  -53.175  54.771  1
662657  94.937  -53.181  54.770  1
662658  94.964  -53.187  54.770  1
662659  94.992  -53.194  54.769  1
662660  95.020  -53.200  54.769  1
662661  95.047  -53.206  54.770  1
662662  95.075  -53.214  54.771  1
662663  95.104  -53.236  54.770  1
662664  95.126  -53.255  54.768  1
662665  95.140  -53.274  54.763  1
662666  95.154  -53.292  54.756  1
662667  95.168  -53.311  54.748  1
662668  95.181  -53.330  54.738  1
662669  95.195  -53.348  54.729  1
662670  95.209  -53.366  54.720  1
662671  95.222  -53.384  54.709  1
662672  95.236  -53.403  54.697  1
662673  95.252  -53.423  54.684  1
662674  95.270  -53.446  54.672  1
662675  95.288  -53.468  54.667  1
662676  95.307  -53.490  54.669  1
662677  95.334  -53.512  54.666  1
662678  95.361  -53.535  54.661  1
662679  95.388  -53.558  54.655  1
662680  95.415  -53.580  54.647  1
662681  95.441  -53.599  54.634  1
662682  95.464  -53.614  54.617  1
662683  95.489  -53.629  54.594  1
662684  95.514  -53.644  54.563  1
662685  95.539  -53.659  54.527  1
662686  95.564  -53.675  54.487  1
662687  95.589  -53.690  54.447  1
662688  95.614  -53.705  54.410  1
662689  95.639  -53.720  54.371  1
662690  95.664  -53.735  54.331  1
662691  95.679  -53.744  54.292  1
662692  95.695  -53.752  54.260  1
662693  95.710  -53.760  54.238  1
662694  95.726  -53.769  54.217  1
662695  95.742  -53.777  54.188  1
662696  95.757  -53.785  54.157  1
662697  95.773  -53.794  54.126  1
662698  95.789  -53.802  54.095  1
662699  95.804  -53.810  54.064  1
662700  95.820  -53.819  54.034  1
662701  95.835  -53.827  54.003  1
662702  95.851  -53.835  53.971  1
662703  95.867  -53.844  53.944  1
662704  95.888  -53.851  53.916  1
662705  95.914  -53.858  53.888  1
662706  95.939  -53.865  53.857  1
662707  95.964  -53.872  53.823  1
662708  95.989  -53.879  53.788  1
662709  96.016  -53.888  53.757  1
662710  96.043  -53.900  53.728  1
662711  96.071  -53.913  53.699  1
662712  96.099  -53.925  53.669  1
662713  96.126  -53.937  53.637  1
662714  96.154  -53.949  53.604  1
662715  96.182  -53.962  53.572  1
662716  96.209  -53.974  53.545  1
662717  96.237  -53.986  53.522  1
662718  96.266  -53.996  53.500  1
662719  96.297  -54.004  53.478  1
662720  96.327  -54.010  53.456  1
662721  96.358  -54.018  53.436  1
662722  96.388  -54.026  53.415  1
662723  96.417  -54.037  53.390  1
662724  96.448  -54.048  53.363  1
662725  96.478  -54.057  53.332  1
662726  96.507  -54.064  53.298  1
662727  96.537  -54.072  53.262  1
662728  96.567  -54.079  53.224  1
662729  96.596  -54.087  53.185  1
662730  96.627  -54.095  53.145  1
662731  96.660  -54.102  53.108  1
662732  96.693  -54.109  53.069  1
662733  96.727  -54.117  53.030  1
662734  96.760  -54.124  52.991  1
662735  96.793  -54.132  52.951  1
662736  96.826  -54.138  52.914  1
662737  96.856  -54.148  52.878  1
662738  96.886  -54.158  52.840  1
662739  96.916  -54.167  52.802  1
662740  96.946  -54.174  52.763  1
662741  96.974  -54.181  52.722  1
662742  97.001  -54.191  52.678  1
662743  97.026  -54.201  52.633  1
662744  97.051  -54.211  52.587  1
662745  97.077  -54.221  52.542  1
662746  97.102  -54.232  52.496  1
662747  97.127  -54.242  52.450  1
662748  97.153  -54.252  52.404  1
662749  97.179  -54.261  52.357  1
662750  97.205  -54.268  52.310  1
662751  97.231  -54.276  52.264  1
662752  97.257  -54.284  52.216  1
662753  97.283  -54.292  52.168  1
662754  97.309  -54.300  52.121  1
662755  97.338  -54.308  52.075  1
662756  97.368  -54.315  52.029  1
662757  97.397  -54.321  51.982  1
662758  97.422  -54.323  51.934  1
662759  97.446  -54.325  51.886  1
662760  97.470  -54.327  51.837  1
662761  97.495  -54.329  51.788  1
662762  97.519  -54.331  51.739  1
662763  97.544  -54.333  51.689  1
662764  97.571  -54.333  51.643  1
662765  97.598  -54.333  51.596  1
662766  97.628  -54.334  51.546  1
662767  97.657  -54.335  51.496  1
662768  97.687  -54.336  51.445  1
662769  97.716  -54.337  51.393  1
662770  97.746  -54.338  51.341  1
662771  97.775  -54.339  51.287  1
662772  97.800  -54.339  51.233  1
662773  97.823  -54.341  51.178  1
662774  97.847  -54.342  51.123  1
662775  97.871  -54.342  51.067  1
662776  97.894  -54.343  51.009  1
662777  97.919  -54.345  50.948  1
662778  97.942  -54.345  50.884  1
662779  97.968  -54.346  50.819  1
662780  97.995  -54.346  50.752  1
662781  98.022  -54.346  50.683  1
662782  98.049  -54.347  50.612  1
662783  98.076  -54.347  50.542  1
662784  98.102  -54.348  50.473  1
662785  98.130  -54.348  50.405  1
662786  98.156  -54.348  50.338  1
662787  98.183  -54.348  50.271  1
662788  98.210  -54.349  50.207  1
662789  98.237  -54.349  50.145  1
662790  98.264  -54.350  50.085  1
662791  98.289  -54.366  50.026  1
662792  98.314  -54.384  49.969  1
663209  90.487  -50.458  56.812  9
663210  90.522  -50.478  56.814  9
663211  90.556  -50.500  56.814  9
663212  90.591  -50.520  56.814  9
663213  90.625  -50.541  56.814  9
663214  90.660  -50.561  56.813  9
663215  90.694  -50.582  56.811  9
663216  90.729  -50.603  56.807  9
663217  90.764  -50.623  56.802  9
663218  90.799  -50.644  56.794  9
663219  90.831  -50.663  56.784  9
663220  90.864  -50.677  56.774  9
663221  90.881  -50.691  56.761  9
663222  90.906  -50.706  56.747  9
663223  90.943  -50.721  56.732  9
663224  90.974  -50.735  56.715  9
663225  91.005  -50.750  56.697  9
663226  91.036  -50.763  56.678  9
663227  91.068  -50.778  56.660  9
663228  91.099  -50.792  56.642  9
663229  91.130  -50.807  56.624  9
663230  91.161  -50.821  56.608  9
663245  91.628  -51.036  56.752  4
663246  91.659  -51.051  56.755  4
663247  91.690  -51.065  56.760  4
663248  91.721  -51.080  56.765  4
663249  91.752  -51.093  56.769  4
663250  91.784  -51.108  56.773  4
663251  91.815  -51.122  56.776  4
663252  91.846  -51.136  56.780  4
663253  91.877  -51.151  56.784  4
663254  91.908  -51.165  56.789  4
663255  91.939  -51.180  56.792  4
663256  91.969  -51.194  56.793  4
663257  92.000  -51.208  56.794  4
663258  92.030  -51.223  56.797  4
663259  92.060  -51.237  56.799  4
663260  92.090  -51.252  56.801  4
663261  92.121  -51.266  56.800  4
663262  92.151  -51.280  56.799  4
663263  92.181  -51.295  56.798  4
663264  92.211  -51.309  56.797  4
663265  92.241  -51.324  56.797  4
663266  92.272  -51.338  56.796  4
663267  92.302  -51.352  56.793  4
663268  92.333  -51.367  56.790  4
663269  92.363  -51.381  56.786  4
663270  92.388  -51.396  56.782  4
663271  92.409  -51.412  56.777  4
663272  92.430  -51.428  56.770  4
663273  92.450  -51.443  56.760  4
663274  92.472  -51.459  56.750  4
663275  92.493  -51.474  56.738  4
663276  92.513  -51.490  56.724  4
663277  92.537  -51.506  56.710  4
663278  92.568  -51.526  56.695  4
663279  92.598  -51.546  56.680  4
663280  92.629  -51.566  56.665  4
663281  92.660  -51.586  56.648  4
663282  92.691  -51.606  56.631  4
663283  92.721  -51.625  56.613  4
663284  92.752  -51.645  56.594  4
663285  92.783  -51.665  56.572  4
663286  92.813  -51.685  56.550  4
663287  92.844  -51.704  56.529  4
663288  92.874  -51.732  56.507  4
663289  92.904  -51.762  56.486  4
663290  92.934  -51.791  56.461  4
663291  92.964  -51.819  56.433  4
663292  92.994  -51.848  56.404  4
663293  93.024  -51.877  56.375  4
663294  93.054  -51.906  56.347  4
663295  93.084  -51.935  56.316  4
663296  93.114  -51.964  56.284  4
663297  93.144  -51.992  56.251  4
663298  93.174  -52.021  56.215  4
663299  93.204  -52.051  56.175  4
663300  93.234  -52.080  56.134  4
663301  93.264  -52.108  56.087  4
663302  93.294  -52.137  56.042  4
663303  93.329  -52.164  55.998  4
663304  93.360  -52.183  55.954  4
663305  93.391  -52.202  55.910  4
663306  93.421  -52.220  55.864  4
663307  93.451  -52.239  55.819  4
663308  93.481  -52.257  55.775  4
663309  93.510  -52.275  55.731  4
663310  93.540  -52.293  55.688  4
663311  93.569  -52.311  55.646  4
663312  93.599  -52.330  55.605  4
663349  94.685  -53.006  54.782  1
663350  94.714  -53.024  54.777  1
663351  94.744  -53.042  54.773  1
663352  94.773  -53.060  54.770  1
663353  94.803  -53.079  54.767  1
663354  94.832  -53.098  54.765  1
663355  94.861  -53.116  54.763  1
663356  94.891  -53.134  54.761  1
663357  94.920  -53.152  54.760  1
663358  94.949  -53.163  54.759  1
663359  94.976  -53.169  54.758  1
663360  95.004  -53.176  54.757  1
663361  95.031  -53.182  54.755  1
663362  95.059  -53.188  54.757  1
663363  95.087  -53.194  54.758  1
663364  95.115  -53.214  54.757  1
663365  95.144  -53.236  54.753  1
663366  95.166  -53.256  54.746  1
663367  95.180  -53.274  54.737  1
663368  95.194  -53.292  54.728  1
663369  95.207  -53.311  54.716  1
663370  95.222  -53.330  54.706  1
663371  95.235  -53.348  54.697  1
663372  95.249  -53.366  54.688  1
663373  95.262  -53.385  54.678  1
663374  95.278  -53.405  54.669  1
663375  95.297  -53.427  54.663  1
663376  95.315  -53.450  54.665  1
663377  95.334  -53.472  54.671  1
663378  95.352  -53.495  54.669  1
663379  95.379  -53.518  54.663  1
663380  95.405  -53.540  54.657  1
663381  95.432  -53.562  54.649  1
663382  95.457  -53.580  54.630  1
663383  95.481  -53.595  54.609  1
663384  95.507  -53.610  54.584  1
663385  95.531  -53.625  54.553  1
663386  95.556  -53.640  54.518  1
663387  95.581  -53.655  54.481  1
663388  95.606  -53.670  54.444  1
663389  95.631  -53.685  54.411  1
663390  95.656  -53.700  54.374  1
663391  95.681  -53.715  54.334  1
663392  95.698  -53.725  54.295  1
663393  95.713  -53.733  54.264  1
663394  95.729  -53.741  54.243  1
663395  95.745  -53.750  54.224  1
663396  95.760  -53.758  54.196  1
663397  95.776  -53.766  54.166  1
663398  95.792  -53.775  54.132  1
663399  95.807  -53.783  54.098  1
663400  95.823  -53.791  54.065  1
663401  95.838  -53.800  54.035  1
663402  95.854  -53.808  54.006  1
663403  95.870  -53.816  53.978  1
663404  95.885  -53.825  53.953  1
663405  95.901  -53.833  53.926  1
663406  95.919  -53.841  53.897  1
663407  95.945  -53.848  53.865  1
663408  95.970  -53.855  53.828  1
663409  95.995  -53.862  53.790  1
663410  96.021  -53.869  53.756  1
663411  96.048  -53.882  53.727  1
663412  96.076  -53.894  53.699  1
663413  96.104  -53.907  53.670  1
663414  96.131  -53.919  53.639  1
663415  96.159  -53.931  53.608  1
663416  96.187  -53.944  53.576  1
663417  96.215  -53.956  53.548  1
663418  96.245  -53.963  53.524  1
663419  96.275  -53.970  53.502  1
663420  96.306  -53.978  53.482  1
663421  96.336  -53.985  53.461  1
663422  96.366  -53.992  53.441  1
663423  96.396  -54.002  53.420  1
663424  96.427  -54.012  53.395  1
663425  96.456  -54.022  53.367  1
663426  96.486  -54.029  53.336  1
663427  96.515  -54.036  53.303  1
663428  96.545  -54.044  53.267  1
663429  96.575  -54.051  53.229  1
663430  96.604  -54.059  53.191  1
663431  96.635  -54.066  53.152  1
663432  96.668  -54.073  53.114  1
663433  96.701  -54.081  53.077  1
663434  96.734  -54.088  53.039  1
663435  96.767  -54.096  53.001  1
663436  96.801  -54.103  52.961  1
663437  96.834  -54.110  52.923  1
663438  96.867  -54.118  52.886  1
663439  96.899  -54.126  52.850  1
663440  96.930  -54.135  52.812  1
663441  96.957  -54.143  52.772  1
663442  96.983  -54.153  52.732  1
663443  97.008  -54.164  52.688  1
663444  97.034  -54.173  52.644  1
663445  97.059  -54.184  52.599  1
663446  97.085  -54.194  52.554  1
663447  97.110  -54.204  52.509  1
663448  97.136  -54.214  52.463  1
663449  97.161  -54.224  52.417  1
663450  97.187  -54.233  52.371  1
663451  97.213  -54.240  52.324  1
663452  97.239  -54.248  52.278  1
663453  97.264  -54.256  52.230  1
663454  97.291  -54.264  52.183  1
663455  97.316  -54.271  52.136  1
663456  97.344  -54.279  52.090  1
663457  97.374  -54.287  52.043  1
663458  97.402  -54.293  51.996  1
663459  97.427  -54.295  51.949  1
663460  97.451  -54.297  51.902  1
663461  97.475  -54.298  51.855  1
663462  97.500  -54.301  51.807  1
663463  97.526  -54.301  51.757  1
663464  97.552  -54.301  51.708  1
663465  97.579  -54.302  51.663  1
663466  97.606  -54.303  51.615  1
663467  97.636  -54.304  51.566  1
663468  97.665  -54.305  51.516  1
663469  97.695  -54.305  51.466  1
663470  97.724  -54.306  51.415  1
663471  97.753  -54.308  51.365  1
663472  97.781  -54.308  51.311  1
663473  97.804  -54.309  51.258  1
663474  97.828  -54.310  51.204  1
663475  97.852  -54.311  51.150  1
663476  97.875  -54.312  51.096  1
663477  97.899  -54.313  51.039  1
663478  97.923  -54.314  50.981  1
663479  97.946  -54.315  50.918  1
663480  97.971  -54.316  50.855  1
663481  97.998  -54.316  50.791  1
663482  98.025  -54.317  50.723  1
663483  98.052  -54.317  50.654  1
663484  98.078  -54.317  50.584  1
663485  98.105  -54.317  50.516  1
663486  98.132  -54.317  50.448  1
663487  98.159  -54.318  50.381  1
663488  98.185  -54.318  50.314  1
663489  98.213  -54.319  50.249  1
663490  98.239  -54.319  50.186  1
663491  98.266  -54.330  50.125  1
663492  98.291  -54.348  50.066  1
663493  98.316  -54.367  50.008  1
663910  90.504  -50.422  56.795  9
663911  90.539  -50.443  56.798  9
663912  90.574  -50.463  56.800  9
663913  90.608  -50.484  56.801  9
663914  90.643  -50.504  56.802  9
663915  90.677  -50.525  56.802  9
663916  90.712  -50.546  56.801  9
663917  90.747  -50.566  56.799  9
663918  90.781  -50.587  56.795  9
663919  90.816  -50.608  56.788  9
663920  90.850  -50.629  56.779  9
663921  90.883  -50.647  56.770  9
663922  90.912  -50.661  56.758  9
663923  90.943  -50.676  56.744  9
663924  90.973  -50.690  56.729  9
663925  91.003  -50.704  56.713  9
663926  91.033  -50.719  56.696  9
663927  91.064  -50.733  56.678  9
663928  91.094  -50.748  56.660  9
663929  91.124  -50.762  56.642  9
663930  91.154  -50.776  56.625  9
663931  91.184  -50.791  56.608  9
663947  91.668  -51.020  56.745  4
663948  91.699  -51.035  56.749  4
663949  91.729  -51.049  56.754  4
663950  91.759  -51.064  56.757  4
663951  91.789  -51.078  56.759  4
663952  91.819  -51.092  56.763  4
663953  91.850  -51.107  56.767  4
663954  91.880  -51.121  56.770  4
663955  91.910  -51.136  56.776  4
663956  91.940  -51.150  56.778  4
663957  91.970  -51.164  56.779  4
663958  92.001  -51.179  56.781  4
663959  92.031  -51.193  56.783  4
663960  92.061  -51.208  56.785  4
663961  92.091  -51.222  56.786  4
663962  92.122  -51.236  56.786  4
663963  92.152  -51.251  56.784  4
663964  92.182  -51.265  56.783  4
663965  92.212  -51.280  56.782  4
663966  92.242  -51.294  56.781  4
663967  92.273  -51.309  56.780  4
663968  92.303  -51.323  56.775  4
663969  92.334  -51.337  56.771  4
663970  92.364  -51.352  56.767  4
663971  92.394  -51.366  56.762  4
663972  92.422  -51.381  56.758  4
663973  92.443  -51.396  56.752  4
663974  92.463  -51.412  56.742  4
663975  92.485  -51.428  56.731  4
663976  92.506  -51.443  56.720  4
663977  92.527  -51.459  56.707  4
663978  92.558  -51.479  56.694  4
663979  92.589  -51.499  56.680  4
663980  92.620  -51.519  56.666  4
663981  92.650  -51.538  56.651  4
663982  92.681  -51.558  56.635  4
663983  92.712  -51.578  56.619  4
663984  92.742  -51.597  56.602  4
663985  92.773  -51.618  56.584  4
663986  92.804  -51.638  56.564  4
663987  92.835  -51.657  56.545  4
663988  92.865  -51.678  56.525  4
663989  92.895  -51.707  56.505  4
663990  92.925  -51.735  56.484  4
663991  92.955  -51.764  56.461  4
663992  92.985  -51.793  56.435  4
663993  93.015  -51.822  56.408  4
663994  93.045  -51.851  56.381  4
663995  93.075  -51.879  56.355  4
663996  93.105  -51.908  56.326  4
663997  93.135  -51.937  56.296  4
663998  93.165  -51.967  56.263  4
663999  93.195  -51.995  56.227  4
664000  93.225  -52.024  56.190  4
664001  93.255  -52.053  56.149  4
664002  93.285  -52.082  56.102  4
664003  93.314  -52.111  56.056  4
664004  93.345  -52.139  56.011  4
664005  93.374  -52.158  55.967  4
664006  93.404  -52.177  55.922  4
664007  93.433  -52.195  55.877  4
664008  93.463  -52.214  55.832  4
664009  93.492  -52.232  55.788  4
664010  93.521  -52.250  55.745  4
664011  93.551  -52.268  55.702  4
664012  93.580  -52.286  55.660  4
664013  93.609  -52.305  55.619  4
664051  94.725  -52.999  54.769  1
664052  94.755  -53.017  54.764  1
664053  94.784  -53.035  54.761  1
664054  94.814  -53.054  54.757  1
664055  94.843  -53.073  54.755  1
664056  94.873  -53.091  54.752  1
664057  94.902  -53.109  54.750  1
664058  94.931  -53.127  54.749  1
664059  94.960  -53.145  54.747  1
664060  94.988  -53.151  54.745  1
664061  95.016  -53.158  54.745  1
664062  95.043  -53.164  54.742  1
664063  95.071  -53.170  54.743  1
664064  95.098  -53.176  54.743  1
664065  95.127  -53.193  54.742  1
664066  95.156  -53.214  54.737  1
664067  95.185  -53.236  54.728  1
664068  95.206  -53.256  54.718  1
664069  95.220  -53.274  54.707  1
664070  95.234  -53.292  54.696  1
664071  95.248  -53.311  54.688  1
664072  95.261  -53.330  54.681  1
664073  95.275  -53.348  54.674  1
664074  95.289  -53.367  54.668  1
664075  95.305  -53.387  54.661  1
664076  95.324  -53.410  54.657  1
664077  95.342  -53.432  54.662  1
664078  95.360  -53.455  54.665  1
664079  95.379  -53.477  54.665  1
664080  95.397  -53.499  54.663  1
664081  95.422  -53.522  54.657  1
664082  95.450  -53.544  54.646  1
664083  95.474  -53.560  54.627  1
664084  95.499  -53.575  54.599  1
664085  95.524  -53.590  54.570  1
664086  95.549  -53.606  54.540  1
664087  95.573  -53.621  54.508  1
664088  95.599  -53.636  54.475  1
664089  95.623  -53.651  54.442  1
664090  95.649  -53.666  54.411  1
664091  95.673  -53.681  54.375  1
664092  95.698  -53.697  54.336  1
664093  95.716  -53.706  54.298  1
664094  95.732  -53.715  54.267  1
664095  95.747  -53.723  54.249  1
664096  95.763  -53.731  54.234  1
664097  95.778  -53.740  54.206  1
664098  95.794  -53.748  54.174  1
664099  95.810  -53.756  54.138  1
664100  95.825  -53.765  54.101  1
664101  95.841  -53.773  54.065  1
664102  95.856  -53.781  54.034  1
664103  95.872  -53.790  54.007  1
664104  95.888  -53.798  53.984  1
664105  95.903  -53.806  53.962  1
664106  95.919  -53.815  53.936  1
664107  95.935  -53.823  53.905  1
664108  95.950  -53.831  53.869  1
664109  95.975  -53.838  53.830  1
664110  96.001  -53.845  53.791  1
664111  96.026  -53.853  53.759  1
664112  96.053  -53.864  53.732  1
664113  96.081  -53.876  53.704  1
664114  96.108  -53.888  53.675  1
664115  96.136  -53.900  53.645  1
664116  96.164  -53.913  53.614  1
664117  96.193  -53.922  53.583  1
664118  96.223  -53.930  53.552  1
664119  96.254  -53.937  53.526  1
664120  96.284  -53.944  53.504  1
664121  96.314  -53.951  53.483  1
664122  96.344  -53.959  53.464  1
664123  96.375  -53.966  53.446  1
664124  96.405  -53.977  53.424  1
664125  96.435  -53.985  53.397  1
664126  96.464  -53.993  53.369  1
664127  96.494  -54.001  53.338  1
664128  96.523  -54.008  53.305  1
664129  96.553  -54.016  53.270  1
664130  96.583  -54.023  53.234  1
664131  96.612  -54.030  53.197  1
664132  96.643  -54.038  53.158  1
664133  96.676  -54.045  53.120  1
664134  96.709  -54.053  53.084  1
664135  96.742  -54.060  53.048  1
664136  96.775  -54.067  53.010  1
664137  96.808  -54.075  52.971  1
664138  96.841  -54.082  52.932  1
664139  96.875  -54.090  52.895  1
664140  96.908  -54.097  52.859  1
664141  96.940  -54.106  52.821  1
664142  96.965  -54.116  52.782  1
664143  96.991  -54.126  52.742  1
664144  97.016  -54.136  52.699  1
664145  97.041  -54.146  52.656  1
664146  97.067  -54.157  52.612  1
664147  97.092  -54.167  52.567  1
664148  97.118  -54.177  52.522  1
664149  97.143  -54.187  52.477  1
664150  97.169  -54.196  52.431  1
664151  97.195  -54.204  52.385  1
664152  97.221  -54.212  52.338  1
664153  97.247  -54.220  52.291  1
664154  97.273  -54.227  52.243  1
664155  97.299  -54.236  52.196  1
664156  97.324  -54.243  52.149  1
664157  97.351  -54.251  52.103  1
664158  97.379  -54.259  52.056  1
664159  97.407  -54.264  52.009  1
664160  97.432  -54.266  51.964  1
664161  97.456  -54.268  51.916  1
664162  97.481  -54.270  51.869  1
664163  97.508  -54.270  51.821  1
664164  97.534  -54.270  51.773  1
664165  97.561  -54.271  51.725  1
664166  97.587  -54.271  51.679  1
664167  97.613  -54.272  51.633  1
664168  97.643  -54.273  51.585  1
664169  97.672  -54.274  51.537  1
664170  97.702  -54.275  51.487  1
664171  97.731  -54.276  51.436  1
664172  97.760  -54.276  51.386  1
664173  97.785  -54.277  51.334  1
664174  97.809  -54.279  51.283  1
664175  97.832  -54.279  51.230  1
664176  97.856  -54.280  51.178  1
664177  97.880  -54.281  51.125  1
664178  97.903  -54.283  51.070  1
664179  97.927  -54.283  51.011  1
664180  97.951  -54.284  50.951  1
664181  97.974  -54.285  50.889  1
664182  98.001  -54.286  50.827  1
664183  98.027  -54.286  50.762  1
664184  98.054  -54.286  50.694  1
664185  98.081  -54.287  50.625  1
664186  98.108  -54.287  50.557  1
664187  98.135  -54.287  50.491  1
664188  98.161  -54.288  50.424  1
664189  98.189  -54.288  50.357  1
664190  98.215  -54.289  50.291  1
664191  98.242  -54.294  50.228  1
664192  98.267  -54.312  50.166  1
664193  98.293  -54.331  50.106  1
664194  98.318  -54.349  50.048  1
664195  98.343  -54.367  49.992  1
664611  90.518  -50.390  56.778  9
664612  90.553  -50.412  56.782  9
664613  90.587  -50.432  56.785  9
664614  90.622  -50.453  56.787  9
664615  90.656  -50.474  56.789  9
664616  90.691  -50.494  56.790  9
664617  90.725  -50.516  56.790  9
664618  90.760  -50.536  56.789  9
664619  90.794  -50.557  56.786  9
664620  90.829  -50.578  56.781  9
664621  90.863  -50.599  56.773  9
664622  90.897  -50.620  56.765  9
664623  90.932  -50.641  56.753  9
664624  90.962  -50.659  56.741  9
664625  90.994  -50.677  56.727  9
664626  91.024  -50.694  56.711  9
664627  91.048  -50.707  56.695  9
664628  91.078  -50.720  56.677  9
664629  91.107  -50.733  56.660  9
664630  91.137  -50.747  56.642  9
664631  91.166  -50.760  56.625  9
664632  91.195  -50.773  56.609  9
664649  91.700  -51.005  56.739  4
664650  91.730  -51.020  56.743  4
664651  91.760  -51.034  56.746  4
664652  91.790  -51.049  56.748  4
664653  91.820  -51.063  56.751  4
664654  91.851  -51.077  56.754  4
664655  91.881  -51.092  56.758  4
664656  91.911  -51.106  56.763  4
664657  91.941  -51.121  56.765  4
664658  91.971  -51.135  56.766  4
664659  92.002  -51.149  56.767  4
664660  92.032  -51.164  56.769  4
664661  92.062  -51.178  56.770  4
664662  92.092  -51.193  56.773  4
664663  92.123  -51.207  56.771  4
664664  92.153  -51.221  56.770  4
664665  92.183  -51.236  56.769  4
664666  92.213  -51.250  56.767  4
664667  92.244  -51.265  56.765  4
664668  92.274  -51.279  56.763  4
664669  92.304  -51.293  56.759  4
664670  92.335  -51.308  56.754  4
664671  92.365  -51.322  56.749  4
664672  92.395  -51.337  56.744  4
664673  92.425  -51.351  56.740  4
664674  92.455  -51.365  56.734  4
664675  92.477  -51.381  56.723  4
664676  92.498  -51.396  56.714  4
664677  92.518  -51.412  56.703  4
664678  92.549  -51.431  56.691  4
664679  92.579  -51.451  56.679  4
664680  92.610  -51.471  56.666  4
664681  92.641  -51.491  56.653  4
664682  92.671  -51.511  56.638  4
664683  92.702  -51.531  56.623  4
664684  92.733  -51.550  56.607  4
664685  92.764  -51.570  56.590  4
664686  92.794  -51.590  56.573  4
664687  92.825  -51.609  56.555  4
664688  92.856  -51.630  56.538  4
664689  92.886  -51.651  56.521  4
664690  92.916  -51.680  56.502  4
664691  92.946  -51.709  56.482  4
664692  92.976  -51.738  56.460  4
664693  93.006  -51.766  56.437  4
664694  93.036  -51.795  56.412  4
664695  93.066  -51.824  56.388  4
664696  93.096  -51.853  56.362  4
664697  93.126  -51.882  56.335  4
664698  93.156  -51.911  56.305  4
664699  93.186  -51.940  56.272  4
664700  93.216  -51.969  56.238  4
664701  93.246  -51.998  56.201  4
664702  93.276  -52.026  56.160  4
664703  93.305  -52.055  56.114  4
664704  93.333  -52.086  56.069  4
664705  93.366  -52.114  56.024  4
664706  93.394  -52.133  55.979  4
664707  93.420  -52.152  55.934  4
664708  93.447  -52.170  55.889  4
664709  93.474  -52.189  55.845  4
664710  93.502  -52.207  55.802  4
664711  93.532  -52.225  55.758  4
664712  93.561  -52.243  55.716  4
664713  93.590  -52.261  55.674  4
664714  93.620  -52.280  55.632  4
664715  93.649  -52.298  55.591  4
664752  94.736  -52.974  54.761  1
664753  94.766  -52.992  54.756  1
664754  94.795  -53.011  54.752  1
664755  94.824  -53.029  54.748  1
664756  94.854  -53.048  54.745  1
664757  94.883  -53.066  54.742  1
664758  94.912  -53.084  54.739  1
664759  94.942  -53.102  54.737  1
664760  94.971  -53.120  54.735  1
664761  95.000  -53.133  54.733  1
664762  95.027  -53.139  54.733  1
664763  95.055  -53.145  54.730  1
664764  95.083  -53.151  54.728  1
664765  95.110  -53.158  54.727  1
664766  95.138  -53.172  54.725  1
664767  95.167  -53.193  54.720  1
664768  95.196  -53.214  54.711  1
664769  95.225  -53.236  54.699  1
664770  95.246  -53.256  54.688  1
664771  95.260  -53.274  54.678  1
664772  95.274  -53.293  54.672  1
664773  95.287  -53.311  54.668  1
664774  95.301  -53.330  54.663  1
664775  95.315  -53.349  54.659  1
664776  95.332  -53.369  54.654  1
664777  95.350  -53.392  54.651  1
664778  95.369  -53.415  54.655  1
664779  95.387  -53.437  54.660  1
664780  95.405  -53.459  54.663  1
664781  95.424  -53.482  54.663  1
664782  95.442  -53.504  54.656  1
664783  95.466  -53.525  54.638  1
664784  95.491  -53.540  54.614  1
664785  95.516  -53.556  54.585  1
664786  95.541  -53.571  54.555  1
664787  95.566  -53.586  54.527  1
664788  95.591  -53.601  54.499  1
664789  95.616  -53.616  54.469  1
664790  95.641  -53.631  54.441  1
664791  95.666  -53.646  54.411  1
664792  95.691  -53.662  54.374  1
664793  95.716  -53.677  54.336  1
664794  95.735  -53.687  54.299  1
664795  95.750  -53.696  54.272  1
664796  95.766  -53.704  54.256  1
664797  95.781  -53.712  54.243  1
664798  95.797  -53.721  54.217  1
664799  95.813  -53.729  54.183  1
664800  95.828  -53.737  54.145  1
664801  95.844  -53.746  54.104  1
664802  95.860  -53.754  54.065  1
664803  95.875  -53.762  54.033  1
664804  95.891  -53.771  54.007  1
664805  95.906  -53.779  53.987  1
664806  95.922  -53.787  53.966  1
664807  95.938  -53.796  53.940  1
664808  95.953  -53.804  53.908  1
664809  95.969  -53.813  53.871  1
664810  95.984  -53.821  53.830  1
664811  96.006  -53.828  53.792  1
664812  96.031  -53.836  53.763  1
664813  96.058  -53.846  53.737  1
664814  96.086  -53.858  53.711  1
664815  96.113  -53.870  53.682  1
664816  96.141  -53.882  53.652  1
664817  96.171  -53.890  53.621  1
664818  96.202  -53.897  53.588  1
664819  96.232  -53.904  53.558  1
664820  96.262  -53.911  53.529  1
664821  96.293  -53.919  53.504  1
664822  96.323  -53.925  53.484  1
664823  96.354  -53.933  53.466  1
664824  96.384  -53.941  53.447  1
664825  96.413  -53.950  53.424  1
664826  96.443  -53.957  53.397  1
664827  96.472  -53.965  53.368  1
664828  96.502  -53.972  53.337  1
664829  96.532  -53.980  53.305  1
664830  96.561  -53.988  53.272  1
664831  96.591  -53.994  53.238  1
664832  96.620  -54.002  53.201  1
664833  96.650  -54.010  53.164  1
664834  96.683  -54.017  53.126  1
664835  96.717  -54.025  53.089  1
664836  96.750  -54.032  53.054  1
664837  96.783  -54.039  53.018  1
664838  96.816  -54.047  52.981  1
664839  96.849  -54.054  52.940  1
664840  96.882  -54.062  52.903  1
664841  96.914  -54.070  52.867  1
664842  96.946  -54.078  52.830  1
664843  96.973  -54.091  52.792  1
664844  96.999  -54.101  52.752  1
664845  97.024  -54.111  52.710  1
664846  97.049  -54.120  52.668  1
664847  97.075  -54.130  52.624  1
664848  97.100  -54.140  52.580  1
664849  97.125  -54.150  52.535  1
664850  97.151  -54.160  52.490  1
664851  97.177  -54.168  52.444  1
664852  97.203  -54.176  52.398  1
664853  97.229  -54.183  52.352  1
664854  97.254  -54.192  52.303  1
664855  97.281  -54.199  52.255  1
664856  97.306  -54.207  52.209  1
664857  97.332  -54.215  52.162  1
664858  97.358  -54.223  52.116  1
664859  97.385  -54.230  52.069  1
664860  97.413  -54.236  52.022  1
664861  97.437  -54.238  51.977  1
664862  97.463  -54.239  51.929  1
664863  97.490  -54.239  51.882  1
664864  97.516  -54.239  51.836  1
664865  97.542  -54.240  51.788  1
664866  97.569  -54.240  51.742  1
664867  97.595  -54.241  51.696  1
664868  97.621  -54.242  51.650  1
664869  97.650  -54.242  51.603  1
664870  97.680  -54.243  51.555  1
664871  97.709  -54.244  51.506  1
664872  97.739  -54.245  51.456  1
664873  97.766  -54.246  51.407  1
664874  97.790  -54.247  51.357  1
664875  97.813  -54.248  51.307  1
664876  97.837  -54.248  51.255  1
664877  97.861  -54.250  51.202  1
664878  97.884  -54.251  51.150  1
664879  97.908  -54.251  51.096  1
664880  97.932  -54.252  51.039  1
664881  97.955  -54.254  50.980  1
664882  97.979  -54.254  50.921  1
664883  98.003  -54.255  50.860  1
664884  98.030  -54.256  50.797  1
664885  98.057  -54.256  50.732  1
664886  98.084  -54.257  50.665  1
664887  98.110  -54.257  50.599  1
664888  98.138  -54.257  50.532  1
664889  98.164  -54.258  50.466  1
664890  98.191  -54.258  50.400  1
664891  98.218  -54.258  50.335  1
664892  98.243  -54.276  50.271  1
664893  98.269  -54.295  50.209  1
664894  98.294  -54.313  50.148  1
664895  98.319  -54.332  50.089  1
664896  98.345  -54.350  50.032  1
665312  90.531  -50.361  56.760  9
665313  90.566  -50.381  56.765  9
665314  90.600  -50.403  56.769  9
665315  90.635  -50.423  56.772  9
665316  90.670  -50.444  56.775  9
665317  90.704  -50.465  56.778  9
665318  90.739  -50.485  56.779  9
665319  90.773  -50.506  56.778  9
665320  90.808  -50.527  56.777  9
665321  90.842  -50.548  56.773  9
665322  90.876  -50.570  56.767  9
665323  90.910  -50.591  56.759  9
665324  90.945  -50.613  56.749  9
665325  90.978  -50.634  56.737  9
665326  91.010  -50.653  56.724  9
665327  91.041  -50.670  56.709  9
665328  91.072  -50.688  56.693  9
665329  91.103  -50.705  56.677  9
665330  91.134  -50.723  56.659  9
665331  91.165  -50.740  56.643  9
665332  91.189  -50.753  56.626  9
665333  91.214  -50.765  56.609  9
665353  91.803  -51.033  56.737  4
665354  91.832  -51.047  56.740  4
665355  91.862  -51.060  56.743  4
665356  91.891  -51.074  56.747  4
665357  91.921  -51.087  56.750  4
665358  91.950  -51.101  56.753  4
665359  91.980  -51.114  56.754  4
665360  92.009  -51.127  56.755  4
665361  92.038  -51.141  56.756  4
665362  92.068  -51.154  56.757  4
665363  92.097  -51.168  56.759  4
665364  92.127  -51.181  56.758  4
665365  92.156  -51.194  56.756  4
665366  92.186  -51.208  56.754  4
665367  92.215  -51.221  56.752  4
665368  92.245  -51.235  56.749  4
665369  92.275  -51.249  56.747  4
665370  92.305  -51.264  56.742  4
665371  92.336  -51.278  56.737  4
665372  92.366  -51.293  56.733  4
665373  92.396  -51.307  56.727  4
665374  92.426  -51.321  56.722  4
665375  92.456  -51.336  56.717  4
665376  92.487  -51.350  56.706  4
665377  92.511  -51.365  56.697  4
665378  92.539  -51.384  56.686  4
665379  92.570  -51.404  56.675  4
665380  92.600  -51.424  56.663  4
665381  92.631  -51.443  56.652  4
665382  92.662  -51.463  56.639  4
665383  92.693  -51.483  56.625  4
665384  92.723  -51.503  56.610  4
665385  92.754  -51.523  56.594  4
665386  92.784  -51.543  56.579  4
665387  92.815  -51.562  56.564  4
665388  92.846  -51.582  56.548  4
665389  92.876  -51.602  56.531  4
665390  92.907  -51.625  56.515  4
665391  92.937  -51.653  56.498  4
665392  92.967  -51.682  56.479  4
665393  92.997  -51.711  56.459  4
665394  93.027  -51.740  56.437  4
665395  93.057  -51.769  56.414  4
665396  93.087  -51.798  56.393  4
665397  93.117  -51.827  56.369  4
665398  93.147  -51.856  56.343  4
665399  93.177  -51.885  56.313  4
665400  93.207  -51.913  56.280  4
665401  93.236  -51.942  56.247  4
665402  93.267  -51.971  56.211  4
665403  93.294  -52.001  56.169  4
665404  93.322  -52.032  56.123  4
665405  93.350  -52.062  56.079  4
665406  93.389  -52.088  56.036  4
665407  93.415  -52.107  55.992  4
665408  93.442  -52.125  55.947  4
665409  93.469  -52.144  55.902  4
665410  93.496  -52.162  55.857  4
665411  93.522  -52.181  55.815  4
665412  93.549  -52.199  55.771  4
665413  93.576  -52.218  55.729  4
665414  93.603  -52.236  55.687  4
665415  93.631  -52.255  55.646  4
665416  93.660  -52.274  55.604  4
665453  94.747  -52.949  54.755  1
665454  94.776  -52.968  54.749  1
665455  94.806  -52.986  54.744  1
665456  94.835  -53.004  54.740  1
665457  94.864  -53.023  54.736  1
665458  94.894  -53.041  54.732  1
665459  94.923  -53.059  54.728  1
665460  94.953  -53.077  54.726  1
665461  94.982  -53.095  54.723  1
665462  95.012  -53.114  54.721  1
665463  95.039  -53.121  54.720  1
665464  95.067  -53.127  54.716  1
665465  95.094  -53.133  54.713  1
665466  95.122  -53.139  54.710  1
665467  95.150  -53.151  54.707  1
665468  95.179  -53.172  54.702  1
665469  95.208  -53.193  54.693  1
665470  95.237  -53.215  54.683  1
665471  95.265  -53.236  54.671  1
665472  95.286  -53.256  54.664  1
665473  95.300  -53.275  54.660  1
665474  95.314  -53.293  54.657  1
665475  95.328  -53.311  54.654  1
665476  95.341  -53.330  54.650  1
665477  95.358  -53.352  54.646  1
665478  95.377  -53.374  54.646  1
665479  95.395  -53.396  54.649  1
665480  95.414  -53.419  54.656  1
665481  95.432  -53.441  54.662  1
665482  95.451  -53.464  54.663  1
665483  95.469  -53.486  54.653  1
665484  95.486  -53.505  54.630  1
665485  95.509  -53.521  54.602  1
665486  95.533  -53.537  54.572  1
665487  95.558  -53.552  54.541  1
665488  95.583  -53.567  54.513  1
665489  95.608  -53.582  54.488  1
665490  95.633  -53.597  54.462  1
665491  95.658  -53.612  54.436  1
665492  95.683  -53.627  54.405  1
665493  95.708  -53.642  54.368  1
665494  95.733  -53.657  54.329  1
665495  95.753  -53.669  54.293  1
665496  95.769  -53.678  54.269  1
665497  95.784  -53.686  54.259  1
665498  95.800  -53.694  54.247  1
665499  95.816  -53.703  54.220  1
665500  95.831  -53.711  54.188  1
665501  95.847  -53.719  54.150  1
665502  95.863  -53.728  54.108  1
665503  95.878  -53.736  54.065  1
665504  95.894  -53.744  54.029  1
665505  95.909  -53.753  54.004  1
665506  95.925  -53.761  53.983  1
665507  95.941  -53.769  53.962  1
665508  95.956  -53.778  53.937  1
665509  95.972  -53.786  53.907  1
665510  95.987  -53.794  53.869  1
665511  96.003  -53.803  53.828  1
665512  96.019  -53.811  53.792  1
665513  96.037  -53.819  53.765  1
665514  96.062  -53.828  53.741  1
665515  96.090  -53.840  53.716  1
665516  96.119  -53.849  53.689  1
665517  96.150  -53.856  53.658  1
665518  96.180  -53.863  53.626  1
665519  96.210  -53.871  53.593  1
665520  96.241  -53.878  53.563  1
665521  96.271  -53.885  53.533  1
665522  96.302  -53.892  53.505  1
665523  96.332  -53.900  53.483  1
665524  96.362  -53.907  53.466  1
665525  96.392  -53.914  53.447  1
665526  96.421  -53.922  53.423  1
665527  96.451  -53.929  53.395  1
665528  96.480  -53.937  53.367  1
665529  96.510  -53.944  53.336  1
665530  96.540  -53.951  53.305  1
665531  96.569  -53.959  53.273  1
665532  96.599  -53.966  53.240  1
665533  96.628  -53.974  53.205  1
665534  96.658  -53.982  53.168  1
665535  96.691  -53.989  53.131  1
665536  96.724  -53.996  53.094  1
665537  96.757  -54.004  53.058  1
665538  96.791  -54.011  53.023  1
665539  96.824  -54.019  52.986  1
665540  96.856  -54.026  52.946  1
665541  96.888  -54.035  52.911  1
665542  96.920  -54.043  52.876  1
665543  96.952  -54.051  52.840  1
665544  96.980  -54.063  52.802  1
665545  97.007  -54.076  52.763  1
665546  97.033  -54.086  52.721  1
665547  97.058  -54.096  52.679  1
665548  97.083  -54.106  52.635  1
665549  97.109  -54.116  52.591  1
665550  97.134  -54.125  52.546  1
665551  97.159  -54.135  52.502  1
665552  97.186  -54.133  52.456  1
665553  97.212  -54.142  52.410  1
665554  97.238  -54.151  52.364  1
665555  97.263  -54.160  52.315  1
665556  97.289  -54.168  52.267  1
665557  97.315  -54.177  52.221  1
665558  97.341  -54.185  52.175  1
665559  97.366  -54.194  52.128  1
665560  97.392  -54.202  52.081  1
665561  97.419  -54.207  52.035  1
665562  97.445  -54.207  51.989  1
665563  97.471  -54.207  51.941  1
665564  97.498  -54.208  51.894  1
665565  97.524  -54.209  51.849  1
665566  97.550  -54.209  51.803  1
665567  97.577  -54.210  51.759  1
665568  97.603  -54.211  51.714  1
665569  97.630  -54.211  51.668  1
665570  97.658  -54.211  51.620  1
665571  97.687  -54.213  51.573  1
665572  97.717  -54.214  51.526  1
665573  97.746  -54.214  51.476  1
665574  97.770  -54.215  51.428  1
665575  97.794  -54.216  51.379  1
665576  97.818  -54.217  51.329  1
665577  97.842  -54.218  51.278  1
665578  97.865  -54.219  51.226  1
665579  97.889  -54.220  51.174  1
665580  97.913  -54.221  51.121  1
665581  97.936  -54.222  51.065  1
665582  97.960  -54.223  51.008  1
665583  97.984  -54.224  50.951  1
665584  98.007  -54.225  50.892  1
665585  98.033  -54.226  50.831  1
665586  98.060  -54.226  50.768  1
665587  98.086  -54.226  50.703  1
665588  98.113  -54.226  50.638  1
665589  98.140  -54.227  50.573  1
665590  98.167  -54.227  50.507  1
665591  98.194  -54.227  50.441  1
665592  98.220  -54.240  50.377  1
665593  98.245  -54.258  50.313  1
665594  98.271  -54.277  50.250  1
665595  98.296  -54.295  50.189  1
665596  98.321  -54.314  50.130  1
665597  98.347  -54.333  50.073  1
665598  98.372  -54.351  50.018  1
666014  90.579  -50.352  56.749  9
666015  90.614  -50.372  56.754  9
666016  90.648  -50.393  56.758  9
666017  90.683  -50.414  56.762  9
666018  90.717  -50.434  56.765  9
666019  90.752  -50.456  56.767  9
666020  90.786  -50.476  56.767  9
666021  90.820  -50.498  56.767  9
666022  90.855  -50.519  56.764  9
666023  90.889  -50.541  56.759  9
666024  90.923  -50.562  56.752  9
666025  90.957  -50.583  56.743  9
666026  90.992  -50.605  56.732  9
666027  91.026  -50.626  56.720  9
666028  91.059  -50.646  56.706  9
666029  91.089  -50.663  56.691  9
666030  91.120  -50.681  56.675  9
666031  91.151  -50.698  56.659  9
666032  91.182  -50.716  56.643  9
666033  91.213  -50.733  56.627  9
666057  91.910  -51.065  56.737  4
666058  91.939  -51.079  56.740  4
666059  91.968  -51.092  56.742  4
666060  91.998  -51.105  56.743  4
666061  92.027  -51.119  56.744  4
666062  92.057  -51.133  56.744  4
666063  92.086  -51.146  56.745  4
666064  92.116  -51.159  56.747  4
666065  92.145  -51.173  56.745  4
666066  92.174  -51.186  56.742  4
666067  92.204  -51.199  56.740  4
666068  92.233  -51.213  56.738  4
666069  92.263  -51.226  56.735  4
666070  92.292  -51.240  56.733  4
666071  92.321  -51.253  56.727  4
666072  92.351  -51.266  56.722  4
666073  92.380  -51.280  56.717  4
666074  92.410  -51.293  56.712  4
666075  92.439  -51.307  56.705  4
666076  92.469  -51.320  56.700  4
666077  92.498  -51.334  56.691  4
666078  92.527  -51.347  56.681  4
666079  92.560  -51.357  56.670  4
666080  92.591  -51.376  56.660  4
666081  92.621  -51.396  56.648  4
666082  92.652  -51.416  56.638  4
666083  92.683  -51.436  56.625  4
666084  92.713  -51.456  56.612  4
666085  92.744  -51.475  56.597  4
666086  92.775  -51.495  56.583  4
666087  92.805  -51.515  56.569  4
666088  92.836  -51.535  56.556  4
666089  92.867  -51.555  56.541  4
666090  92.898  -51.575  56.524  4
666091  92.928  -51.598  56.509  4
666092  92.958  -51.627  56.493  4
666093  92.988  -51.656  56.475  4
666094  93.018  -51.685  56.455  4
666095  93.048  -51.714  56.435  4
666096  93.078  -51.743  56.414  4
666097  93.108  -51.772  56.395  4
666098  93.138  -51.801  56.373  4
666099  93.167  -51.829  56.348  4
666100  93.198  -51.858  56.318  4
666101  93.227  -51.887  56.287  4
666102  93.255  -51.917  56.254  4
666103  93.283  -51.948  56.218  4
666104  93.310  -51.978  56.177  4
666105  93.338  -52.008  56.132  4
666106  93.376  -52.039  56.089  4
666107  93.410  -52.062  56.047  4
666108  93.437  -52.080  56.003  4
666109  93.464  -52.099  55.959  4
666110  93.491  -52.117  55.915  4
666111  93.517  -52.136  55.870  4
666112  93.544  -52.155  55.827  4
666113  93.571  -52.174  55.784  4
666114  93.598  -52.192  55.741  4
666115  93.625  -52.211  55.700  4
666116  93.651  -52.229  55.658  4
666117  93.678  -52.248  55.618  4
666154  94.758  -52.925  54.748  1
666155  94.787  -52.943  54.742  1
666156  94.817  -52.961  54.737  1
666157  94.846  -52.979  54.731  1
666158  94.875  -52.998  54.727  1
666159  94.905  -53.016  54.722  1
666160  94.934  -53.034  54.718  1
666161  94.963  -53.052  54.714  1
666162  94.993  -53.070  54.711  1
666163  95.022  -53.089  54.708  1
666164  95.051  -53.103  54.705  1
666165  95.078  -53.109  54.701  1
666166  95.106  -53.115  54.697  1
666167  95.134  -53.122  54.694  1
666168  95.162  -53.129  54.690  1
666169  95.190  -53.151  54.684  1
666170  95.219  -53.172  54.676  1
666171  95.248  -53.194  54.667  1
666172  95.277  -53.215  54.659  1
666173  95.306  -53.237  54.653  1
666174  95.326  -53.257  54.649  1
666175  95.340  -53.275  54.646  1
666176  95.354  -53.293  54.643  1
666177  95.368  -53.312  54.640  1
666178  95.385  -53.333  54.638  1
666179  95.404  -53.356  54.641  1
666180  95.422  -53.379  54.648  1
666181  95.441  -53.401  54.658  1
666182  95.459  -53.424  54.665  1
666183  95.477  -53.443  54.662  1
666184  95.494  -53.462  54.647  1
666185  95.512  -53.481  54.622  1
666186  95.530  -53.499  54.589  1
666187  95.550  -53.517  54.559  1
666188  95.576  -53.532  54.527  1
666189  95.601  -53.547  54.498  1
666190  95.625  -53.562  54.475  1
666191  95.651  -53.577  54.451  1
666192  95.675  -53.593  54.427  1
666193  95.700  -53.608  54.397  1
666194  95.725  -53.623  54.360  1
666195  95.750  -53.638  54.319  1
666196  95.772  -53.651  54.283  1
666197  95.788  -53.659  54.261  1
666198  95.803  -53.668  54.255  1
666199  95.819  -53.676  54.241  1
666200  95.834  -53.684  54.218  1
666201  95.850  -53.693  54.186  1
666202  95.866  -53.701  54.148  1
666203  95.881  -53.709  54.106  1
666204  95.897  -53.718  54.062  1
666205  95.912  -53.726  54.022  1
666206  95.928  -53.734  53.992  1
666207  95.944  -53.743  53.968  1
666208  95.959  -53.751  53.946  1
666209  95.975  -53.759  53.923  1
666210  95.990  -53.768  53.894  1
666211  96.006  -53.776  53.861  1
666212  96.022  -53.784  53.822  1
666213  96.037  -53.793  53.789  1
666214  96.052  -53.801  53.763  1
666215  96.067  -53.809  53.739  1
666216  96.098  -53.816  53.715  1
666217  96.128  -53.824  53.687  1
666218  96.158  -53.831  53.657  1
666219  96.188  -53.839  53.627  1
666220  96.218  -53.847  53.595  1
666221  96.248  -53.854  53.565  1
666222  96.278  -53.861  53.535  1
666223  96.308  -53.869  53.507  1
666224  96.338  -53.876  53.482  1
666225  96.369  -53.883  53.465  1
666226  96.400  -53.888  53.445  1
666227  96.430  -53.895  53.420  1
666228  96.459  -53.901  53.394  1
666229  96.488  -53.909  53.366  1
666230  96.518  -53.916  53.335  1
666231  96.548  -53.923  53.304  1
666232  96.578  -53.931  53.274  1
666233  96.607  -53.938  53.242  1
666234  96.637  -53.946  53.208  1
666235  96.666  -53.954  53.173  1
666236  96.699  -53.960  53.136  1
666237  96.732  -53.968  53.099  1
666238  96.765  -53.976  53.063  1
666239  96.798  -53.983  53.028  1
666240  96.830  -53.991  52.991  1
666241  96.862  -54.000  52.953  1
666242  96.894  -54.008  52.919  1
666243  96.927  -54.016  52.885  1
666244  96.958  -54.024  52.850  1
666245  96.987  -54.036  52.813  1
666246  97.015  -54.049  52.773  1
666247  97.041  -54.061  52.732  1
666248  97.067  -54.071  52.689  1
666249  97.092  -54.081  52.646  1
666250  97.117  -54.091  52.602  1
666251  97.142  -54.101  52.557  1
666252  97.168  -54.107  52.512  1
666253  97.195  -54.104  52.467  1
666254  97.222  -54.107  52.420  1
666255  97.247  -54.116  52.373  1
666256  97.274  -54.124  52.325  1
666257  97.299  -54.132  52.279  1
666258  97.325  -54.142  52.232  1
666259  97.351  -54.150  52.185  1
666260  97.376  -54.159  52.138  1
666261  97.402  -54.167  52.092  1
666262  97.428  -54.171  52.046  1
666263  97.453  -54.176  52.000  1
666264  97.479  -54.177  51.953  1
666265  97.506  -54.178  51.907  1
666266  97.532  -54.178  51.863  1
666267  97.558  -54.179  51.818  1
666268  97.585  -54.179  51.774  1
666269  97.611  -54.179  51.730  1
666270  97.638  -54.180  51.683  1
666271  97.665  -54.181  51.637  1
666272  97.695  -54.182  51.591  1
666273  97.724  -54.182  51.544  1
666274  97.751  -54.184  51.495  1
666275  97.775  -54.185  51.447  1
666276  97.798  -54.185  51.399  1
666277  97.822  -54.186  51.350  1
666278  97.846  -54.188  51.300  1
666279  97.870  -54.189  51.249  1
666280  97.893  -54.189  51.198  1
666281  97.917  -54.190  51.145  1
666282  97.941  -54.192  51.089  1
666283  97.964  -54.192  51.034  1
666284  97.988  -54.193  50.978  1
666285  98.012  -54.194  50.921  1
666286  98.035  -54.195  50.863  1
666287  98.062  -54.195  50.803  1
666288  98.089  -54.196  50.741  1
666289  98.116  -54.196  50.676  1
666290  98.143  -54.197  50.612  1
666291  98.169  -54.197  50.547  1
666292  98.196  -54.204  50.482  1
666293  98.221  -54.223  50.418  1
666294  98.247  -54.241  50.354  1
666295  98.272  -54.260  50.292  1
666296  98.298  -54.278  50.231  1
666297  98.323  -54.296  50.171  1
666298  98.349  -54.315  50.113  1
666299  98.374  -54.333  50.058  1
666715  90.592  -50.321  56.733  9
666716  90.627  -50.342  56.739  9
666717  90.661  -50.363  56.743  9
666718  90.696  -50.384  56.747  9
666719  90.730  -50.405  56.751  9
666720  90.765  -50.425  56.754  9
666721  90.799  -50.447  56.756  9
666722  90.833  -50.469  56.757  9
666723  90.868  -50.490  56.755  9
666724  90.902  -50.511  56.750  9
666725  90.936  -50.533  56.744  9
666726  90.970  -50.554  56.737  9
666727  91.005  -50.575  56.727  9
666728  91.039  -50.597  56.716  9
666729  91.073  -50.619  56.703  9
666730  91.106  -50.639  56.689  9
666731  91.137  -50.657  56.674  9
666732  91.168  -50.674  56.658  9
666733  91.199  -50.691  56.643  9
666734  91.230  -50.709  56.628  9
666760  91.987  -51.084  56.732  4
666761  92.016  -51.097  56.733  4
666762  92.046  -51.111  56.733  4
666763  92.075  -51.124  56.733  4
666764  92.104  -51.137  56.734  4
666765  92.134  -51.151  56.734  4
666766  92.163  -51.164  56.733  4
666767  92.193  -51.177  56.730  4
666768  92.222  -51.191  56.727  4
666769  92.251  -51.205  56.724  4
666770  92.281  -51.218  56.721  4
666771  92.310  -51.231  56.718  4
666772  92.340  -51.245  56.713  4
666773  92.369  -51.258  56.707  4
666774  92.399  -51.271  56.702  4
666775  92.428  -51.285  56.696  4
666776  92.457  -51.299  56.689  4
666777  92.487  -51.312  56.684  4
666778  92.516  -51.325  56.674  4
666779  92.546  -51.339  56.665  4
666780  92.575  -51.352  56.656  4
666781  92.605  -51.365  56.645  4
666782  92.642  -51.368  56.634  4
666783  92.673  -51.388  56.623  4
666784  92.704  -51.408  56.611  4
666785  92.734  -51.428  56.598  4
666786  92.765  -51.448  56.585  4
666787  92.796  -51.468  56.572  4
666788  92.827  -51.487  56.559  4
666789  92.857  -51.507  56.548  4
666790  92.888  -51.527  56.533  4
666791  92.919  -51.547  56.517  4
666792  92.949  -51.572  56.502  4
666793  92.979  -51.600  56.486  4
666794  93.009  -51.630  56.469  4
666795  93.039  -51.659  56.451  4
666796  93.069  -51.688  56.433  4
666797  93.098  -51.716  56.415  4
666798  93.129  -51.745  56.395  4
666799  93.158  -51.774  56.374  4
666800  93.189  -51.803  56.349  4
666801  93.216  -51.833  56.322  4
666802  93.243  -51.863  56.293  4
666803  93.271  -51.894  56.260  4
666804  93.299  -51.924  56.225  4
666805  93.326  -51.954  56.186  4
666806  93.357  -51.985  56.143  4
666807  93.402  -52.014  56.099  4
666808  93.432  -52.036  56.056  4
666809  93.459  -52.054  56.014  4
666810  93.486  -52.073  55.970  4
666811  93.512  -52.092  55.926  4
666812  93.539  -52.110  55.882  4
666813  93.566  -52.129  55.838  4
666814  93.593  -52.147  55.796  4
666815  93.620  -52.166  55.754  4
666816  93.646  -52.184  55.712  4
666817  93.673  -52.203  55.671  4
666818  93.700  -52.221  55.630  4
666856  94.798  -52.918  54.735  1
666857  94.827  -52.936  54.729  1
666858  94.856  -52.954  54.723  1
666859  94.886  -52.973  54.718  1
666860  94.915  -52.991  54.712  1
666861  94.945  -53.009  54.707  1
666862  94.974  -53.027  54.702  1
666863  95.003  -53.046  54.698  1
666864  95.033  -53.064  54.695  1
666865  95.062  -53.082  54.690  1
666866  95.090  -53.091  54.685  1
666867  95.118  -53.098  54.681  1
666868  95.145  -53.104  54.678  1
666869  95.173  -53.110  54.674  1
666870  95.202  -53.129  54.667  1
666871  95.231  -53.151  54.661  1
666872  95.260  -53.173  54.654  1
666873  95.288  -53.194  54.648  1
666874  95.317  -53.216  54.643  1
666875  95.346  -53.237  54.639  1
666876  95.367  -53.257  54.636  1
666877  95.380  -53.275  54.633  1
666878  95.394  -53.294  54.631  1
666879  95.412  -53.316  54.631  1
666880  95.430  -53.339  54.635  1
666881  95.449  -53.361  54.644  1
666882  95.467  -53.382  54.655  1
666883  95.485  -53.401  54.660  1
666884  95.502  -53.420  54.653  1
666885  95.520  -53.439  54.636  1
666886  95.538  -53.458  54.607  1
666887  95.555  -53.476  54.578  1
666888  95.573  -53.495  54.549  1
666889  95.593  -53.512  54.517  1
666890  95.618  -53.527  54.485  1
666891  95.642  -53.543  54.459  1
666892  95.668  -53.558  54.437  1
666893  95.692  -53.573  54.415  1
666894  95.718  -53.588  54.385  1
666895  95.743  -53.603  54.348  1
666896  95.767  -53.618  54.307  1
666897  95.790  -53.632  54.271  1
666898  95.806  -53.640  54.249  1
666899  95.821  -53.649  54.244  1
666900  95.837  -53.657  54.229  1
666901  95.852  -53.665  54.210  1
666902  95.868  -53.674  54.180  1
666903  95.884  -53.682  54.142  1
666904  95.899  -53.690  54.100  1
666905  95.915  -53.699  54.057  1
666906  95.931  -53.707  54.013  1
666907  95.946  -53.715  53.978  1
666908  95.962  -53.724  53.951  1
666909  95.977  -53.732  53.928  1
666910  95.993  -53.740  53.904  1
666911  96.009  -53.749  53.878  1
666912  96.024  -53.757  53.848  1
666913  96.040  -53.766  53.813  1
666914  96.054  -53.774  53.781  1
666915  96.058  -53.781  53.756  1
666916  96.072  -53.787  53.732  1
666917  96.103  -53.794  53.707  1
666918  96.133  -53.801  53.681  1
666919  96.164  -53.809  53.652  1
666920  96.194  -53.816  53.624  1
666921  96.224  -53.823  53.594  1
666922  96.254  -53.831  53.565  1
666923  96.284  -53.838  53.536  1
666924  96.314  -53.846  53.507  1
666925  96.344  -53.853  53.481  1
666926  96.376  -53.859  53.462  1
666927  96.408  -53.864  53.442  1
666928  96.438  -53.870  53.419  1
666929  96.467  -53.877  53.393  1
666930  96.497  -53.883  53.365  1
666931  96.526  -53.890  53.335  1
666932  96.556  -53.896  53.305  1
666933  96.586  -53.903  53.275  1
666934  96.615  -53.910  53.245  1
666935  96.645  -53.917  53.212  1
666936  96.674  -53.925  53.178  1
666937  96.707  -53.932  53.142  1
666938  96.740  -53.940  53.105  1
666939  96.772  -53.948  53.069  1
666940  96.804  -53.956  53.033  1
666941  96.836  -53.964  52.996  1
666942  96.868  -53.972  52.960  1
666943  96.900  -53.981  52.928  1
666944  96.933  -53.989  52.895  1
666945  96.965  -53.997  52.860  1
666946  96.994  -54.008  52.822  1
666947  97.021  -54.022  52.783  1
666948  97.048  -54.035  52.742  1
666949  97.075  -54.047  52.700  1
666950  97.100  -54.056  52.657  1
666951  97.125  -54.066  52.613  1
666952  97.151  -54.076  52.568  1
666953  97.177  -54.080  52.523  1
666954  97.204  -54.077  52.477  1
666955  97.231  -54.075  52.430  1
666956  97.257  -54.080  52.382  1
666957  97.283  -54.088  52.335  1
666958  97.309  -54.098  52.289  1
666959  97.334  -54.106  52.243  1
666960  97.360  -54.115  52.195  1
666961  97.386  -54.123  52.148  1
666962  97.412  -54.129  52.102  1
666963  97.437  -54.133  52.056  1
666964  97.463  -54.138  52.011  1
666965  97.488  -54.142  51.965  1
666966  97.514  -54.146  51.920  1
666967  97.540  -54.148  51.876  1
666968  97.566  -54.148  51.833  1
666969  97.593  -54.148  51.790  1
666970  97.619  -54.149  51.746  1
666971  97.646  -54.150  51.700  1
666972  97.672  -54.151  51.653  1
666973  97.702  -54.151  51.607  1
666974  97.731  -54.152  51.560  1
666975  97.755  -54.153  51.514  1
666976  97.779  -54.154  51.466  1
666977  97.803  -54.155  51.418  1
666978  97.826  -54.156  51.370  1
666979  97.850  -54.157  51.320  1
666980  97.874  -54.157  51.270  1
666981  97.898  -54.159  51.218  1
666982  97.922  -54.160  51.166  1
666983  97.945  -54.160  51.112  1
666984  97.969  -54.162  51.058  1
666985  97.993  -54.163  51.003  1
666986  98.016  -54.164  50.948  1
666987  98.040  -54.164  50.892  1
666988  98.065  -54.165  50.834  1
666989  98.092  -54.166  50.775  1
666990  98.119  -54.166  50.713  1
666991  98.145  -54.167  50.649  1
666992  98.172  -54.168  50.586  1
666993  98.198  -54.186  50.522  1
666994  98.223  -54.205  50.458  1
666995  98.248  -54.223  50.396  1
666996  98.274  -54.242  50.334  1
666997  98.299  -54.261  50.272  1
666998  98.324  -54.279  50.213  1
666999  98.350  -54.297  50.154  1
667416  90.606  -50.291  56.715  9
667417  90.640  -50.312  56.723  9
667418  90.675  -50.333  56.728  9
667419  90.709  -50.354  56.733  9
667420  90.743  -50.375  56.737  9
667421  90.778  -50.397  56.741  9
667422  90.812  -50.418  56.744  9
667423  90.846  -50.439  56.746  9
667424  90.880  -50.461  56.744  9
667425  90.915  -50.482  56.741  9
667426  90.949  -50.503  56.736  9
667427  90.983  -50.525  56.730  9
667428  91.017  -50.546  56.722  9
667429  91.051  -50.568  56.711  9
667430  91.086  -50.589  56.700  9
667431  91.120  -50.610  56.686  9
667432  91.154  -50.632  56.672  9
667433  91.185  -50.650  56.657  9
667434  91.216  -50.667  56.643  9
667435  91.247  -50.685  56.629  9
667462  92.034  -51.089  56.724  4
667463  92.064  -51.102  56.724  4
667464  92.093  -51.116  56.724  4
667465  92.123  -51.129  56.724  4
667466  92.152  -51.142  56.724  4
667467  92.181  -51.156  56.721  4
667468  92.211  -51.169  56.717  4
667469  92.240  -51.183  56.714  4
667470  92.270  -51.196  56.710  4
667471  92.299  -51.209  56.708  4
667472  92.329  -51.223  56.704  4
667473  92.358  -51.236  56.699  4
667474  92.387  -51.249  56.692  4
667475  92.417  -51.263  56.686  4
667476  92.446  -51.277  56.680  4
667477  92.476  -51.290  56.674  4
667478  92.505  -51.303  56.668  4
667479  92.535  -51.317  56.659  4
667480  92.564  -51.331  56.650  4
667481  92.594  -51.343  56.641  4
667482  92.623  -51.357  56.631  4
667483  92.652  -51.371  56.620  4
667484  92.683  -51.384  56.610  4
667485  92.725  -51.381  56.598  4
667486  92.756  -51.400  56.586  4
667487  92.786  -51.420  56.573  4
667488  92.817  -51.440  56.561  4
667489  92.848  -51.460  56.551  4
667490  92.878  -51.480  56.539  4
667491  92.909  -51.500  56.525  4
667492  92.940  -51.519  56.511  4
667493  92.970  -51.546  56.495  4
667494  93.000  -51.575  56.479  4
667495  93.029  -51.603  56.463  4
667496  93.060  -51.632  56.447  4
667497  93.089  -51.661  56.430  4
667498  93.120  -51.690  56.413  4
667499  93.149  -51.719  56.395  4
667500  93.177  -51.749  56.374  4
667501  93.205  -51.779  56.351  4
667502  93.232  -51.810  56.325  4
667503  93.260  -51.840  56.297  4
667504  93.287  -51.870  56.266  4
667505  93.315  -51.901  56.232  4
667506  93.342  -51.931  56.195  4
667507  93.383  -51.961  56.153  4
667508  93.427  -51.991  56.110  4
667509  93.454  -52.010  56.066  4
667510  93.481  -52.028  56.024  4
667511  93.507  -52.047  55.981  4
667512  93.534  -52.065  55.936  4
667513  93.561  -52.084  55.893  4
667514  93.588  -52.102  55.850  4
667515  93.615  -52.121  55.808  4
667516  93.641  -52.139  55.766  4
667517  93.668  -52.158  55.724  4
667518  93.695  -52.177  55.682  4
667519  93.722  -52.195  55.642  4
667557  94.809  -52.893  54.729  1
667558  94.838  -52.911  54.722  1
667559  94.867  -52.929  54.715  1
667560  94.897  -52.948  54.709  1
667561  94.926  -52.966  54.703  1
667562  94.956  -52.984  54.697  1
667563  94.985  -53.003  54.692  1
667564  95.015  -53.021  54.687  1
667565  95.044  -53.039  54.683  1
667566  95.073  -53.057  54.677  1
667567  95.102  -53.073  54.672  1
667568  95.130  -53.079  54.667  1
667569  95.157  -53.086  54.663  1
667570  95.185  -53.092  54.658  1
667571  95.213  -53.108  54.653  1
667572  95.242  -53.129  54.650  1
667573  95.271  -53.151  54.645  1
667574  95.300  -53.173  54.639  1
667575  95.329  -53.195  54.634  1
667576  95.358  -53.216  54.630  1
667577  95.387  -53.237  54.627  1
667578  95.406  -53.257  54.624  1
667579  95.420  -53.276  54.623  1
667580  95.439  -53.298  54.625  1
667581  95.457  -53.321  54.629  1
667582  95.475  -53.339  54.638  1
667583  95.492  -53.358  54.648  1
667584  95.510  -53.377  54.650  1
667585  95.528  -53.396  54.640  1
667586  95.545  -53.415  54.622  1
667587  95.563  -53.433  54.593  1
667588  95.581  -53.452  54.569  1
667589  95.598  -53.471  54.541  1
667590  95.616  -53.490  54.508  1
667591  95.635  -53.509  54.473  1
667592  95.660  -53.524  54.442  1
667593  95.685  -53.539  54.420  1
667594  95.710  -53.554  54.399  1
667595  95.735  -53.569  54.371  1
667596  95.760  -53.584  54.335  1
667597  95.784  -53.599  54.295  1
667598  95.809  -53.614  54.258  1
667599  95.824  -53.622  54.233  1
667600  95.840  -53.631  54.225  1
667601  95.855  -53.639  54.212  1
667602  95.871  -53.647  54.193  1
667603  95.887  -53.656  54.166  1
667604  95.902  -53.664  54.131  1
667605  95.918  -53.672  54.091  1
667606  95.934  -53.681  54.047  1
667607  95.949  -53.689  54.003  1
667608  95.965  -53.697  53.964  1
667609  95.980  -53.706  53.933  1
667610  95.996  -53.714  53.906  1
667611  96.012  -53.722  53.880  1
667612  96.027  -53.731  53.857  1
667613  96.042  -53.739  53.833  1
667614  96.045  -53.746  53.801  1
667615  96.049  -53.753  53.771  1
667616  96.053  -53.761  53.746  1
667617  96.075  -53.766  53.722  1
667618  96.108  -53.772  53.697  1
667619  96.139  -53.778  53.672  1
667620  96.169  -53.785  53.646  1
667621  96.199  -53.793  53.620  1
667622  96.230  -53.800  53.593  1
667623  96.260  -53.808  53.565  1
667624  96.290  -53.816  53.536  1
667625  96.320  -53.823  53.506  1
667626  96.350  -53.830  53.479  1
667627  96.383  -53.835  53.460  1
667628  96.415  -53.840  53.440  1
667629  96.446  -53.845  53.417  1
667630  96.475  -53.852  53.392  1
667631  96.505  -53.858  53.365  1
667632  96.535  -53.865  53.336  1
667633  96.564  -53.871  53.306  1
667634  96.594  -53.878  53.277  1
667635  96.623  -53.884  53.248  1
667636  96.653  -53.891  53.216  1
667637  96.682  -53.897  53.184  1
667638  96.714  -53.904  53.148  1
667639  96.746  -53.913  53.111  1
667640  96.778  -53.921  53.074  1
667641  96.810  -53.929  53.039  1
667642  96.842  -53.938  53.002  1
667643  96.874  -53.945  52.968  1
667644  96.906  -53.954  52.935  1
667645  96.939  -53.962  52.903  1
667646  96.971  -53.970  52.868  1
667647  97.001  -53.980  52.832  1
667648  97.028  -53.994  52.794  1
667649  97.055  -54.007  52.754  1
667650  97.083  -54.021  52.710  1
667651  97.108  -54.032  52.667  1
667652  97.134  -54.041  52.623  1
667653  97.159  -54.051  52.578  1
667654  97.185  -54.053  52.533  1
667655  97.213  -54.051  52.486  1
667656  97.240  -54.048  52.440  1
667657  97.267  -54.044  52.392  1
667658  97.293  -54.054  52.345  1
667659  97.319  -54.062  52.298  1
667660  97.345  -54.071  52.252  1
667661  97.370  -54.079  52.204  1
667662  97.396  -54.085  52.156  1
667663  97.421  -54.090  52.112  1
667664  97.447  -54.095  52.066  1
667665  97.472  -54.099  52.021  1
667666  97.498  -54.104  51.976  1
667667  97.523  -54.108  51.933  1
667668  97.549  -54.113  51.890  1
667669  97.575  -54.117  51.848  1
667670  97.601  -54.118  51.806  1
667671  97.627  -54.119  51.762  1
667672  97.654  -54.119  51.716  1
667673  97.680  -54.120  51.670  1
667674  97.710  -54.120  51.624  1
667675  97.736  -54.121  51.577  1
667676  97.760  -54.123  51.532  1
667677  97.784  -54.123  51.484  1
667678  97.807  -54.124  51.436  1
667679  97.831  -54.126  51.389  1
667680  97.855  -54.126  51.340  1
667681  97.878  -54.127  51.289  1
667682  97.902  -54.128  51.238  1
667683  97.926  -54.129  51.186  1
667684  97.950  -54.130  51.135  1
667685  97.973  -54.131  51.083  1
667686  97.997  -54.132  51.030  1
667687  98.021  -54.133  50.976  1
667688  98.044  -54.134  50.921  1
667689  98.068  -54.135  50.865  1
667690  98.094  -54.135  50.809  1
667691  98.121  -54.135  50.748  1
667692  98.148  -54.136  50.686  1
667693  98.174  -54.151  50.624  1
667694  98.199  -54.169  50.561  1
667695  98.225  -54.187  50.499  1
667696  98.250  -54.206  50.437  1
667697  98.276  -54.224  50.375  1
667698  98.301  -54.243  50.314  1
667699  98.326  -54.261  50.255  1
667700  98.352  -54.279  50.196  1
668118  90.653  -50.282  56.706  9
668119  90.688  -50.303  56.713  9
668120  90.722  -50.325  56.718  9
668121  90.756  -50.346  56.723  9
668122  90.791  -50.367  56.728  9
668123  90.825  -50.388  56.732  9
668124  90.859  -50.410  56.734  9
668125  90.893  -50.431  56.734  9
668126  90.928  -50.453  56.732  9
668127  90.962  -50.474  56.728  9
668128  90.996  -50.496  56.723  9
668129  91.030  -50.517  56.716  9
668130  91.065  -50.538  56.706  9
668131  91.099  -50.560  56.696  9
668132  91.133  -50.582  56.684  9
668133  91.167  -50.603  56.671  9
668134  91.201  -50.624  56.658  9
668135  91.233  -50.643  56.645  9
668165  92.111  -51.108  56.715  4
668166  92.141  -51.121  56.714  4
668167  92.170  -51.134  56.713  4
668168  92.200  -51.148  56.711  4
668169  92.229  -51.161  56.706  4
668170  92.259  -51.174  56.702  4
668171  92.288  -51.188  56.698  4
668172  92.317  -51.201  56.694  4
668173  92.347  -51.215  56.690  4
668174  92.376  -51.228  56.685  4
668175  92.406  -51.241  56.678  4
668176  92.435  -51.255  56.672  4
668177  92.465  -51.268  56.665  4
668178  92.494  -51.281  56.659  4
668179  92.524  -51.295  56.653  4
668180  92.553  -51.309  56.645  4
668181  92.582  -51.322  56.636  4
668182  92.612  -51.335  56.627  4
668183  92.641  -51.349  56.618  4
668184  92.671  -51.362  56.608  4
668185  92.700  -51.375  56.598  4
668186  92.730  -51.389  56.586  4
668187  92.765  -51.395  56.574  4
668188  92.807  -51.393  56.562  4
668189  92.838  -51.412  56.551  4
668190  92.868  -51.432  56.541  4
668191  92.899  -51.452  56.530  4
668192  92.930  -51.472  56.517  4
668193  92.960  -51.492  56.503  4
668194  92.991  -51.519  56.488  4
668195  93.020  -51.548  56.473  4
668196  93.051  -51.577  56.457  4
668197  93.080  -51.606  56.442  4
668198  93.111  -51.635  56.426  4
668199  93.138  -51.665  56.410  4
668200  93.165  -51.695  56.392  4
668201  93.193  -51.725  56.374  4
668202  93.221  -51.756  56.352  4
668203  93.248  -51.786  56.327  4
668204  93.276  -51.816  56.299  4
668205  93.303  -51.847  56.270  4
668206  93.331  -51.877  56.238  4
668207  93.364  -51.907  56.203  4
668208  93.409  -51.937  56.164  4
668209  93.449  -51.965  56.121  4
668210  93.476  -51.983  56.077  4
668211  93.502  -52.002  56.034  4
668212  93.529  -52.020  55.991  4
668213  93.556  -52.039  55.947  4
668214  93.583  -52.058  55.904  4
668215  93.610  -52.076  55.861  4
668216  93.636  -52.095  55.819  4
668217  93.663  -52.114  55.777  4
668218  93.690  -52.132  55.734  4
668219  93.717  -52.151  55.694  4
668220  93.744  -52.169  55.653  4
668258  94.820  -52.868  54.723  1
668259  94.849  -52.886  54.716  1
668260  94.878  -52.904  54.708  1
668261  94.908  -52.923  54.700  1
668262  94.937  -52.941  54.695  1
668263  94.966  -52.960  54.689  1
668264  94.996  -52.978  54.682  1
668265  95.025  -52.996  54.677  1
668266  95.054  -53.014  54.672  1
668267  95.084  -53.032  54.666  1
668268  95.113  -53.051  54.660  1
668269  95.141  -53.061  54.655  1
668270  95.169  -53.067  54.651  1
668271  95.197  -53.073  54.646  1
668272  95.225  -53.087  54.642  1
668273  95.254  -53.108  54.640  1
668274  95.282  -53.130  54.637  1
668275  95.312  -53.151  54.633  1
668276  95.340  -53.173  54.629  1
668277  95.370  -53.195  54.624  1
668278  95.398  -53.216  54.620  1
668279  95.427  -53.238  54.617  1
668280  95.447  -53.258  54.615  1
668281  95.465  -53.279  54.618  1
668282  95.483  -53.297  54.622  1
668283  95.500  -53.316  54.628  1
668284  95.518  -53.335  54.634  1
668285  95.536  -53.354  54.634  1
668286  95.553  -53.373  54.622  1
668287  95.571  -53.392  54.602  1
668288  95.589  -53.410  54.579  1
668289  95.606  -53.429  54.561  1
668290  95.624  -53.448  54.535  1
668291  95.641  -53.467  54.499  1
668292  95.659  -53.486  54.461  1
668293  95.677  -53.504  54.426  1
668294  95.702  -53.519  54.402  1
668295  95.727  -53.534  54.381  1
668296  95.752  -53.549  54.355  1
668297  95.777  -53.565  54.321  1
668298  95.802  -53.580  54.282  1
668299  95.827  -53.595  54.244  1
668300  95.843  -53.603  54.216  1
668301  95.859  -53.612  54.205  1
668302  95.874  -53.620  54.193  1
668303  95.890  -53.628  54.174  1
668304  95.905  -53.637  54.148  1
668305  95.921  -53.645  54.116  1
668306  95.937  -53.653  54.078  1
668307  95.952  -53.662  54.036  1
668308  95.968  -53.670  53.992  1
668309  95.983  -53.678  53.951  1
668310  95.999  -53.687  53.918  1
668311  96.015  -53.695  53.890  1
668312  96.029  -53.703  53.864  1
668313  96.033  -53.711  53.839  1
668314  96.036  -53.718  53.817  1
668315  96.040  -53.725  53.790  1
668316  96.044  -53.733  53.761  1
668317  96.047  -53.740  53.735  1
668318  96.079  -53.745  53.710  1
668319  96.112  -53.750  53.686  1
668320  96.145  -53.755  53.663  1
668321  96.175  -53.762  53.640  1
668322  96.205  -53.770  53.615  1
668323  96.235  -53.778  53.591  1
668324  96.265  -53.785  53.565  1
668325  96.296  -53.793  53.536  1
668326  96.326  -53.800  53.506  1
668327  96.357  -53.806  53.478  1
668328  96.389  -53.811  53.459  1
668329  96.422  -53.816  53.438  1
668330  96.454  -53.821  53.416  1
668331  96.484  -53.827  53.392  1
668332  96.513  -53.834  53.366  1
668333  96.543  -53.840  53.337  1
668334  96.573  -53.847  53.308  1
668335  96.602  -53.853  53.279  1
668336  96.631  -53.859  53.250  1
668337  96.661  -53.866  53.220  1
668338  96.689  -53.872  53.189  1
668339  96.720  -53.878  53.154  1
668340  96.752  -53.886  53.117  1
668341  96.784  -53.894  53.081  1
668342  96.816  -53.902  53.045  1
668343  96.849  -53.910  53.008  1
668344  96.881  -53.919  52.974  1
668345  96.912  -53.927  52.942  1
668346  96.945  -53.935  52.910  1
668347  96.977  -53.943  52.877  1
668348  97.008  -53.953  52.842  1
668349  97.035  -53.966  52.805  1
668350  97.063  -53.979  52.764  1
668351  97.090  -53.993  52.720  1
668352  97.117  -54.007  52.678  1
668353  97.142  -54.016  52.634  1
668354  97.167  -54.026  52.589  1
668355  97.194  -54.026  52.543  1
668356  97.222  -54.023  52.497  1
668357  97.249  -54.020  52.450  1
668358  97.276  -54.017  52.402  1
668359  97.303  -54.018  52.355  1
668360  97.328  -54.027  52.309  1
668361  97.354  -54.035  52.263  1
668362  97.380  -54.043  52.215  1
668363  97.405  -54.048  52.168  1
668364  97.431  -54.052  52.123  1
668365  97.456  -54.057  52.077  1
668366  97.482  -54.060  52.032  1
668367  97.508  -54.065  51.989  1
668368  97.533  -54.070  51.946  1
668369  97.559  -54.074  51.905  1
668370  97.584  -54.079  51.863  1
668371  97.610  -54.083  51.821  1
668372  97.635  -54.088  51.778  1
668373  97.662  -54.088  51.733  1
668374  97.688  -54.089  51.688  1
668375  97.717  -54.090  51.642  1
668376  97.741  -54.091  51.595  1
668377  97.764  -54.091  51.549  1
668378  97.788  -54.093  51.501  1
668379  97.812  -54.094  51.453  1
668380  97.836  -54.095  51.405  1
668381  97.859  -54.095  51.357  1
668382  97.883  -54.097  51.308  1
668383  97.907  -54.098  51.258  1
668384  97.930  -54.098  51.206  1
668385  97.954  -54.099  51.158  1
668386  97.978  -54.101  51.107  1
668387  98.002  -54.101  51.056  1
668388  98.025  -54.102  51.004  1
668389  98.049  -54.104  50.951  1
668390  98.073  -54.104  50.897  1
668391  98.097  -54.105  50.842  1
668392  98.124  -54.105  50.783  1
668393  98.150  -54.114  50.722  1
668394  98.175  -54.133  50.661  1
668395  98.201  -54.151  50.600  1
668396  98.226  -54.170  50.539  1
668397  98.252  -54.189  50.477  1
668398  98.277  -54.207  50.416  1
668399  98.303  -54.225  50.356  1
668400  98.328  -54.244  50.297  1
668401  98.354  -54.262  50.239  1
668819  90.667  -50.253  56.690  9
668820  90.701  -50.274  56.697  9
668821  90.735  -50.295  56.703  9
668822  90.769  -50.316  56.709  9
668823  90.803  -50.338  56.714  9
668824  90.837  -50.359  56.719  9
668825  90.872  -50.381  56.722  9
668826  90.906  -50.402  56.722  9
668827  90.940  -50.423  56.722  9
668828  90.974  -50.445  56.719  9
668829  91.009  -50.466  56.715  9
668830  91.043  -50.488  56.710  9
668831  91.077  -50.509  56.703  9
668832  91.111  -50.531  56.693  9
668833  91.146  -50.552  56.682  9
668834  91.180  -50.573  56.671  9
668835  91.214  -50.594  56.659  9
668836  91.248  -50.616  56.647  9
668868  92.189  -51.126  56.704  4
668869  92.218  -51.139  56.701  4
668870  92.247  -51.152  56.695  4
668871  92.277  -51.166  56.690  4
668872  92.306  -51.180  56.686  4
668873  92.336  -51.193  56.681  4
668874  92.365  -51.206  56.677  4
668875  92.395  -51.220  56.671  4
668876  92.424  -51.233  56.665  4
668877  92.453  -51.246  56.658  4
668878  92.483  -51.260  56.650  4
668879  92.512  -51.273  56.645  4
668880  92.542  -51.287  56.640  4
668881  92.571  -51.300  56.632  4
668882  92.601  -51.314  56.623  4
668883  92.630  -51.327  56.614  4
668884  92.660  -51.340  56.606  4
668885  92.689  -51.354  56.596  4
668886  92.719  -51.367  56.587  4
668887  92.748  -51.381  56.576  4
668888  92.778  -51.394  56.564  4
668889  92.807  -51.407  56.552  4
668890  92.848  -51.406  56.542  4
668891  92.889  -51.405  56.530  4
668892  92.920  -51.425  56.519  4
668893  92.951  -51.444  56.508  4
668894  92.982  -51.464  56.495  4
668895  93.012  -51.493  56.481  4
668896  93.042  -51.522  56.467  4
668897  93.071  -51.550  56.452  4
668898  93.099  -51.581  56.438  4
668899  93.127  -51.611  56.422  4
668900  93.154  -51.641  56.406  4
668901  93.182  -51.672  56.389  4
668902  93.209  -51.702  56.371  4
668903  93.236  -51.732  56.350  4
668904  93.264  -51.763  56.327  4
668905  93.292  -51.793  56.300  4
668906  93.319  -51.823  56.274  4
668907  93.347  -51.854  56.244  4
668908  93.390  -51.884  56.210  4
668909  93.434  -51.913  56.173  4
668910  93.471  -51.939  56.132  4
668911  93.497  -51.957  56.087  4
668912  93.524  -51.976  56.043  4
668913  93.551  -51.995  56.001  4
668914  93.578  -52.013  55.958  4
668915  93.605  -52.032  55.915  4
668916  93.631  -52.050  55.872  4
668917  93.658  -52.069  55.829  4
668918  93.685  -52.087  55.787  4
668919  93.712  -52.106  55.745  4
668920  93.739  -52.124  55.704  4
668921  93.765  -52.143  55.663  4
668961  94.889  -52.879  54.702  1
668962  94.918  -52.897  54.694  1
668963  94.948  -52.916  54.687  1
668964  94.977  -52.935  54.681  1
668965  95.006  -52.953  54.674  1
668966  95.036  -52.971  54.667  1
668967  95.065  -52.989  54.662  1
668968  95.095  -53.007  54.656  1
668969  95.124  -53.026  54.651  1
668970  95.153  -53.043  54.645  1
668971  95.181  -53.049  54.640  1
668972  95.208  -53.055  54.636  1
668973  95.236  -53.066  54.632  1
668974  95.265  -53.087  54.631  1
668975  95.294  -53.109  54.629  1
668976  95.323  -53.130  54.626  1
668977  95.352  -53.152  54.622  1
668978  95.381  -53.173  54.618  1
668979  95.410  -53.195  54.614  1
668980  95.439  -53.217  54.611  1
668981  95.468  -53.239  54.611  1
668982  95.488  -53.257  54.612  1
668983  95.509  -53.273  54.615  1
668984  95.526  -53.292  54.617  1
668985  95.544  -53.311  54.618  1
668986  95.561  -53.330  54.614  1
668987  95.579  -53.349  54.601  1
668988  95.597  -53.368  54.581  1
668989  95.614  -53.386  54.569  1
668990  95.632  -53.405  54.554  1
668991  95.650  -53.424  54.529  1
668992  95.667  -53.443  54.493  1
668993  95.685  -53.462  54.451  1
668994  95.702  -53.480  54.411  1
668995  95.720  -53.499  54.383  1
668996  95.744  -53.515  54.361  1
668997  95.769  -53.530  54.337  1
668998  95.795  -53.545  54.306  1
668999  95.819  -53.560  54.268  1
669000  95.844  -53.575  54.230  1
669001  95.862  -53.585  54.200  1
669002  95.877  -53.593  54.183  1
669003  95.893  -53.602  54.172  1
669004  95.908  -53.610  54.154  1
669005  95.924  -53.618  54.130  1
669006  95.940  -53.627  54.100  1
669007  95.955  -53.635  54.065  1
669008  95.970  -53.643  54.025  1
669009  95.986  -53.652  53.982  1
669010  96.002  -53.660  53.940  1
669011  96.016  -53.668  53.905  1
669012  96.020  -53.675  53.876  1
669013  96.024  -53.683  53.849  1
669014  96.027  -53.690  53.825  1
669015  96.031  -53.697  53.805  1
669016  96.035  -53.705  53.780  1
669017  96.039  -53.712  53.752  1
669018  96.050  -53.719  53.726  1
669019  96.083  -53.724  53.701  1
669020  96.116  -53.729  53.677  1
669021  96.149  -53.734  53.655  1
669022  96.181  -53.740  53.634  1
669023  96.211  -53.747  53.611  1
669024  96.241  -53.754  53.588  1
669025  96.271  -53.762  53.562  1
669026  96.301  -53.769  53.534  1
669027  96.331  -53.777  53.505  1
669028  96.364  -53.782  53.477  1
669029  96.396  -53.787  53.457  1
669030  96.429  -53.791  53.437  1
669031  96.461  -53.797  53.416  1
669032  96.492  -53.802  53.393  1
669033  96.521  -53.809  53.366  1
669034  96.551  -53.815  53.338  1
669035  96.581  -53.822  53.309  1
669036  96.610  -53.828  53.282  1
669037  96.640  -53.834  53.253  1
669038  96.668  -53.841  53.223  1
669039  96.696  -53.847  53.193  1
669040  96.727  -53.853  53.159  1
669041  96.758  -53.860  53.124  1
669042  96.790  -53.867  53.087  1
669043  96.822  -53.875  53.050  1
669044  96.855  -53.883  53.012  1
669045  96.887  -53.891  52.980  1
669046  96.919  -53.900  52.949  1
669047  96.951  -53.908  52.918  1
669048  96.983  -53.916  52.886  1
669049  97.015  -53.925  52.852  1
669050  97.042  -53.938  52.814  1
669051  97.069  -53.952  52.774  1
669052  97.096  -53.966  52.731  1
669053  97.123  -53.979  52.688  1
669054  97.151  -53.991  52.645  1
669055  97.176  -54.001  52.600  1
669056  97.203  -53.998  52.554  1
669057  97.230  -53.996  52.507  1
669058  97.257  -53.993  52.459  1
669059  97.285  -53.990  52.412  1
669060  97.312  -53.988  52.365  1
669061  97.338  -53.991  52.320  1
669062  97.364  -54.000  52.274  1
669063  97.389  -54.004  52.226  1
669064  97.415  -54.009  52.178  1
669065  97.441  -54.013  52.133  1
669066  97.466  -54.018  52.088  1
669067  97.492  -54.022  52.044  1
669068  97.517  -54.027  52.001  1
669069  97.543  -54.032  51.960  1
669070  97.568  -54.036  51.919  1
669071  97.594  -54.040  51.879  1
669072  97.619  -54.044  51.837  1
669073  97.645  -54.049  51.794  1
669074  97.670  -54.054  51.749  1
669075  97.696  -54.058  51.705  1
669076  97.722  -54.059  51.659  1
669077  97.745  -54.060  51.612  1
669078  97.769  -54.061  51.565  1
669079  97.793  -54.062  51.517  1
669080  97.816  -54.063  51.470  1
669081  97.840  -54.064  51.423  1
669082  97.864  -54.065  51.375  1
669083  97.887  -54.066  51.327  1
669084  97.911  -54.067  51.278  1
669085  97.935  -54.068  51.228  1
669086  97.958  -54.069  51.182  1
669087  97.982  -54.070  51.133  1
669088  98.006  -54.071  51.083  1
669089  98.030  -54.072  51.031  1
669090  98.054  -54.073  50.978  1
669091  98.077  -54.073  50.926  1
669092  98.101  -54.075  50.872  1
669093  98.127  -54.079  50.815  1
669094  98.152  -54.097  50.756  1
669095  98.177  -54.115  50.697  1
669096  98.203  -54.134  50.638  1
669097  98.228  -54.152  50.577  1
669098  98.253  -54.170  50.516  1
669099  98.279  -54.189  50.457  1
669100  98.304  -54.207  50.396  1
669101  98.330  -54.226  50.338  1
669102  98.355  -54.245  50.280  1
669521  90.714  -50.244  56.682  9
669522  90.748  -50.265  56.688  9
669523  90.782  -50.287  56.694  9
669524  90.816  -50.309  56.700  9
669525  90.851  -50.330  56.705  9
669526  90.885  -50.351  56.709  9
669527  90.919  -50.373  56.711  9
669528  90.953  -50.394  56.712  9
669529  90.988  -50.415  56.710  9
669530  91.022  -50.437  56.708  9
669531  91.056  -50.459  56.703  9
669532  91.090  -50.480  56.698  9
669533  91.124  -50.501  56.690  9
669534  91.159  -50.522  56.681  9
669535  91.193  -50.544  56.671  9
669536  91.227  -50.566  56.660  9
669571  92.266  -51.144  56.686  4
669572  92.295  -51.158  56.680  4
669573  92.325  -51.171  56.675  4
669574  92.354  -51.184  56.670  4
669575  92.383  -51.198  56.665  4
669576  92.413  -51.211  56.659  4
669577  92.442  -51.224  56.652  4
669578  92.472  -51.238  56.645  4
669579  92.501  -51.252  56.637  4
669580  92.531  -51.265  56.631  4
669581  92.560  -51.278  56.627  4
669582  92.590  -51.292  56.619  4
669583  92.619  -51.305  56.610  4
669584  92.649  -51.318  56.602  4
669585  92.678  -51.332  56.594  4
669586  92.708  -51.346  56.585  4
669587  92.737  -51.359  56.576  4
669588  92.766  -51.372  56.566  4
669589  92.796  -51.386  56.555  4
669590  92.825  -51.399  56.543  4
669591  92.855  -51.412  56.533  4
669592  92.887  -51.421  56.523  4
669593  92.931  -51.418  56.511  4
669594  92.972  -51.417  56.499  4
669595  93.003  -51.437  56.487  4
669596  93.032  -51.466  56.475  4
669597  93.060  -51.497  56.462  4
669598  93.087  -51.527  56.447  4
669599  93.115  -51.557  56.435  4
669600  93.142  -51.587  56.418  4
669601  93.170  -51.618  56.401  4
669602  93.198  -51.648  56.385  4
669603  93.225  -51.678  56.367  4
669604  93.253  -51.709  56.347  4
669605  93.280  -51.739  56.326  4
669606  93.308  -51.769  56.302  4
669607  93.335  -51.800  56.276  4
669608  93.372  -51.830  56.247  4
669609  93.416  -51.860  56.215  4
669610  93.460  -51.890  56.179  4
669611  93.492  -51.913  56.140  4
669612  93.519  -51.931  56.098  4
669613  93.546  -51.950  56.052  4
669614  93.573  -51.968  56.009  4
669615  93.600  -51.987  55.966  4
669616  93.626  -52.005  55.923  4
669617  93.653  -52.024  55.880  4
669618  93.680  -52.042  55.838  4
669619  93.707  -52.061  55.796  4
669620  93.733  -52.080  55.755  4
669621  93.760  -52.098  55.714  4
669622  93.787  -52.117  55.673  4
669663  94.929  -52.872  54.689  1
669664  94.959  -52.891  54.682  1
669665  94.988  -52.910  54.675  1
669666  95.017  -52.928  54.667  1
669667  95.047  -52.946  54.660  1
669668  95.076  -52.964  54.655  1
669669  95.105  -52.982  54.649  1
669670  95.135  -53.001  54.643  1
669671  95.164  -53.019  54.637  1
669672  95.193  -53.031  54.632  1
669673  95.220  -53.037  54.627  1
669674  95.248  -53.045  54.624  1
669675  95.277  -53.066  54.621  1
669676  95.306  -53.088  54.620  1
669677  95.335  -53.109  54.618  1
669678  95.364  -53.131  54.615  1
669679  95.392  -53.152  54.612  1
669680  95.421  -53.173  54.609  1
669681  95.453  -53.195  54.607  1
669682  95.484  -53.218  54.608  1
669683  95.500  -53.240  54.608  1
669684  95.522  -53.257  54.608  1
669685  95.543  -53.273  54.607  1
669686  95.564  -53.290  54.603  1
669687  95.586  -53.308  54.596  1
669688  95.604  -53.325  54.581  1
669689  95.622  -53.344  54.564  1
669690  95.640  -53.363  54.557  1
669691  95.658  -53.382  54.547  1
669692  95.675  -53.401  54.525  1
669693  95.693  -53.420  54.491  1
669694  95.710  -53.438  54.445  1
669695  95.728  -53.457  54.400  1
669696  95.746  -53.476  54.365  1
669697  95.763  -53.495  54.339  1
669698  95.787  -53.511  54.315  1
669699  95.812  -53.526  54.287  1
669700  95.836  -53.541  54.253  1
669701  95.862  -53.556  54.217  1
669702  95.880  -53.566  54.184  1
669703  95.895  -53.574  54.165  1
669704  95.911  -53.583  54.152  1
669705  95.926  -53.591  54.134  1
669706  95.942  -53.599  54.112  1
669707  95.958  -53.608  54.084  1
669708  95.973  -53.616  54.051  1
669709  95.989  -53.625  54.013  1
669710  96.004  -53.633  53.972  1
669711  96.008  -53.640  53.930  1
669712  96.011  -53.648  53.894  1
669713  96.015  -53.655  53.863  1
669714  96.019  -53.662  53.836  1
669715  96.022  -53.670  53.813  1
669716  96.026  -53.677  53.795  1
669717  96.030  -53.684  53.772  1
669718  96.033  -53.692  53.745  1
669719  96.054  -53.698  53.719  1
669720  96.087  -53.703  53.693  1
669721  96.120  -53.708  53.669  1
669722  96.153  -53.712  53.648  1
669723  96.186  -53.718  53.628  1
669724  96.217  -53.724  53.606  1
669725  96.247  -53.731  53.584  1
669726  96.277  -53.739  53.558  1
669727  96.307  -53.747  53.530  1
669728  96.338  -53.753  53.502  1
669729  96.371  -53.758  53.477  1
669730  96.403  -53.762  53.456  1
669731  96.436  -53.768  53.436  1
669732  96.468  -53.772  53.415  1
669733  96.500  -53.778  53.393  1
669734  96.530  -53.784  53.367  1
669735  96.559  -53.791  53.339  1
669736  96.589  -53.797  53.310  1
669737  96.618  -53.803  53.283  1
669738  96.647  -53.809  53.253  1
669739  96.675  -53.816  53.225  1
669740  96.702  -53.822  53.195  1
669741  96.733  -53.828  53.161  1
669742  96.765  -53.835  53.126  1
669743  96.797  -53.842  53.090  1
669744  96.829  -53.849  53.053  1
669745  96.861  -53.856  53.017  1
669746  96.893  -53.865  52.984  1
669747  96.925  -53.872  52.953  1
669748  96.957  -53.881  52.923  1
669749  96.989  -53.889  52.891  1
669750  97.021  -53.897  52.857  1
669751  97.049  -53.910  52.821  1
669752  97.076  -53.924  52.782  1
669753  97.103  -53.938  52.740  1
669754  97.131  -53.951  52.698  1
669755  97.158  -53.965  52.655  1
669756  97.184  -53.974  52.611  1
669757  97.212  -53.971  52.565  1
669758  97.239  -53.969  52.516  1
669759  97.266  -53.966  52.469  1
669760  97.294  -53.963  52.421  1
669761  97.321  -53.960  52.375  1
669762  97.348  -53.957  52.331  1
669763  97.374  -53.962  52.285  1
669764  97.399  -53.966  52.237  1
669765  97.424  -53.972  52.189  1
669766  97.449  -53.979  52.143  1
669767  97.474  -53.984  52.099  1
669768  97.500  -53.990  52.056  1
669769  97.525  -53.996  52.014  1
669770  97.550  -54.001  51.972  1
669771  97.575  -54.007  51.933  1
669772  97.600  -54.013  51.894  1
669773  97.626  -54.019  51.853  1
669774  97.651  -54.025  51.809  1
669775  97.676  -54.031  51.764  1
669776  97.703  -54.033  51.720  1
669777  97.724  -54.038  51.674  1
669778  97.745  -54.040  51.628  1
669779  97.769  -54.041  51.582  1
669780  97.792  -54.042  51.534  1
669781  97.816  -54.043  51.488  1
669782  97.840  -54.044  51.441  1
669783  97.864  -54.044  51.394  1
669784  97.887  -54.045  51.347  1
669785  97.911  -54.046  51.299  1
669786  97.935  -54.047  51.251  1
669787  97.959  -54.048  51.205  1
669788  97.983  -54.048  51.157  1
669789  98.006  -54.049  51.108  1
669790  98.030  -54.050  51.057  1
669791  98.054  -54.051  51.005  1
669792  98.078  -54.051  50.953  1
669793  98.101  -54.052  50.901  1
669794  98.128  -54.060  50.846  1
669795  98.153  -54.079  50.789  1
669796  98.179  -54.098  50.731  1
669797  98.204  -54.116  50.673  1
669798  98.230  -54.135  50.614  1
669799  98.255  -54.153  50.554  1
669800  98.281  -54.172  50.496  1
669801  98.306  -54.190  50.437  1
669802  98.332  -54.208  50.379  1
669803  98.357  -54.227  50.323  1
670223  90.761  -50.237  56.674  9
670224  90.795  -50.258  56.680  9
670225  90.829  -50.279  56.686  9
670226  90.863  -50.301  56.692  9
670227  90.897  -50.322  56.697  9
670228  90.932  -50.343  56.700  9
670229  90.966  -50.365  56.702  9
670230  91.000  -50.386  56.702  9
670231  91.034  -50.408  56.700  9
670232  91.069  -50.429  56.697  9
670233  91.103  -50.450  56.693  9
670234  91.137  -50.472  56.687  9
670235  91.171  -50.494  56.680  9
670236  91.206  -50.515  56.672  9
670274  92.343  -51.163  56.665  4
670275  92.372  -51.176  56.659  4
670276  92.402  -51.190  56.653  4
670277  92.431  -51.203  56.647  4
670278  92.461  -51.216  56.639  4
670279  92.490  -51.230  56.632  4
670280  92.520  -51.243  56.624  4
670281  92.549  -51.256  56.618  4
670282  92.579  -51.270  56.613  4
670283  92.608  -51.284  56.606  4
670284  92.638  -51.297  56.598  4
670285  92.667  -51.310  56.590  4
670286  92.696  -51.324  56.583  4
670287  92.726  -51.337  56.574  4
670288  92.755  -51.350  56.565  4
670289  92.785  -51.364  56.556  4
670290  92.814  -51.378  56.546  4
670291  92.844  -51.390  56.535  4
670292  92.873  -51.404  56.525  4
670293  92.903  -51.418  56.515  4
670294  92.932  -51.431  56.504  4
670295  92.971  -51.433  56.492  4
670296  93.013  -51.429  56.480  4
670297  93.048  -51.443  56.469  4
670298  93.076  -51.473  56.456  4
670299  93.103  -51.503  56.443  4
670300  93.131  -51.534  56.430  4
670301  93.158  -51.564  56.414  4
670302  93.186  -51.594  56.397  4
670303  93.214  -51.625  56.380  4
670304  93.241  -51.655  56.363  4
670305  93.269  -51.685  56.344  4
670306  93.296  -51.716  56.323  4
670307  93.324  -51.746  56.303  4
670308  93.353  -51.776  56.276  4
670309  93.397  -51.807  56.248  4
670310  93.441  -51.836  56.217  4
670311  93.485  -51.866  56.183  4
670312  93.514  -51.886  56.146  4
670313  93.541  -51.905  56.105  4
670314  93.568  -51.923  56.059  4
670315  93.594  -51.942  56.016  4
670316  93.621  -51.960  55.973  4
670317  93.648  -51.979  55.930  4
670318  93.675  -51.998  55.887  4
670319  93.702  -52.017  55.845  4
670320  93.728  -52.035  55.803  4
670321  93.756  -52.054  55.763  4
670322  93.782  -52.072  55.722  4
670323  93.809  -52.091  55.681  4
670365  94.969  -52.866  54.676  1
670366  94.998  -52.885  54.669  1
670367  95.028  -52.903  54.661  1
670368  95.057  -52.921  54.655  1
670369  95.087  -52.939  54.649  1
670370  95.116  -52.957  54.643  1
670371  95.145  -52.976  54.637  1
670372  95.175  -52.994  54.631  1
670373  95.204  -53.013  54.626  1
670374  95.232  -53.019  54.621  1
670375  95.260  -53.026  54.618  1
670376  95.288  -53.045  54.615  1
670377  95.317  -53.067  54.613  1
670378  95.346  -53.088  54.611  1
670379  95.375  -53.110  54.609  1
670380  95.404  -53.131  54.608  1
670381  95.434  -53.152  54.608  1
670382  95.469  -53.175  54.609  1
670383  95.500  -53.198  54.610  1
670384  95.516  -53.220  54.608  1
670385  95.534  -53.241  54.606  1
670386  95.555  -53.258  54.600  1
670387  95.577  -53.274  54.592  1
670388  95.598  -53.291  54.580  1
670389  95.619  -53.308  54.564  1
670390  95.640  -53.324  54.550  1
670391  95.662  -53.341  54.545  1
670392  95.683  -53.358  54.538  1
670393  95.700  -53.377  54.521  1
670394  95.718  -53.396  54.489  1
670395  95.736  -53.415  54.442  1
670396  95.754  -53.433  54.392  1
670397  95.771  -53.452  54.350  1
670398  95.789  -53.471  54.320  1
670399  95.807  -53.490  54.293  1
670400  95.829  -53.506  54.266  1
670401  95.854  -53.521  54.236  1
670402  95.879  -53.537  54.204  1
670403  95.898  -53.548  54.171  1
670404  95.914  -53.556  54.149  1
670405  95.930  -53.565  54.133  1
670406  95.945  -53.573  54.116  1
670407  95.961  -53.581  54.095  1
670408  95.976  -53.590  54.069  1
670409  95.991  -53.598  54.038  1
670410  95.994  -53.605  54.002  1
670411  95.999  -53.612  53.963  1
670412  96.002  -53.620  53.922  1
670413  96.006  -53.628  53.884  1
670414  96.010  -53.634  53.851  1
670415  96.013  -53.642  53.824  1
670416  96.017  -53.650  53.801  1
670417  96.021  -53.656  53.786  1
670418  96.024  -53.664  53.763  1
670419  96.028  -53.672  53.738  1
670420  96.058  -53.677  53.712  1
670421  96.091  -53.681  53.687  1
670422  96.124  -53.687  53.663  1
670423  96.157  -53.691  53.641  1
670424  96.190  -53.697  53.619  1
670425  96.223  -53.701  53.597  1
670426  96.253  -53.709  53.576  1
670427  96.283  -53.716  53.552  1
670428  96.313  -53.724  53.525  1
670429  96.345  -53.729  53.498  1
670430  96.377  -53.734  53.476  1
670431  96.410  -53.739  53.454  1
670432  96.442  -53.744  53.435  1
670433  96.475  -53.748  53.415  1
670434  96.508  -53.753  53.393  1
670435  96.538  -53.759  53.367  1
670436  96.568  -53.766  53.339  1
670437  96.597  -53.772  53.311  1
670438  96.626  -53.778  53.282  1
670439  96.654  -53.784  53.253  1
670440  96.681  -53.791  53.225  1
670441  96.709  -53.797  53.195  1
670442  96.740  -53.803  53.163  1
670443  96.771  -53.810  53.127  1
670444  96.803  -53.817  53.092  1
670445  96.835  -53.824  53.055  1
670446  96.867  -53.831  53.019  1
670447  96.899  -53.838  52.986  1
670448  96.931  -53.846  52.956  1
670449  96.963  -53.854  52.926  1
670450  96.995  -53.862  52.894  1
670451  97.027  -53.870  52.860  1
670452  97.055  -53.883  52.825  1
670453  97.083  -53.896  52.787  1
670454  97.110  -53.910  52.746  1
670455  97.137  -53.923  52.705  1
670456  97.164  -53.935  52.662  1
670457  97.190  -53.946  52.618  1
670458  97.216  -53.955  52.573  1
670459  97.243  -53.952  52.524  1
670460  97.271  -53.950  52.477  1
670461  97.298  -53.947  52.429  1
670462  97.325  -53.944  52.384  1
670463  97.352  -53.941  52.340  1
670464  97.378  -53.944  52.293  1
670465  97.403  -53.950  52.246  1
670466  97.429  -53.955  52.198  1
670467  97.454  -53.961  52.153  1
670468  97.479  -53.967  52.108  1
670469  97.504  -53.972  52.066  1
670470  97.529  -53.979  52.024  1
670471  97.555  -53.985  51.983  1
670472  97.580  -53.991  51.944  1
670473  97.605  -53.996  51.907  1
670474  97.630  -54.002  51.866  1
670475  97.656  -54.006  51.823  1
670476  97.682  -54.008  51.778  1
670477  97.709  -54.010  51.733  1
670478  97.733  -54.014  51.688  1
670479  97.749  -54.021  51.642  1
670480  97.767  -54.024  51.598  1
670481  97.791  -54.025  51.552  1
670482  97.814  -54.026  51.506  1
670483  97.839  -54.026  51.461  1
670484  97.862  -54.027  51.415  1
670485  97.886  -54.028  51.367  1
670486  97.910  -54.029  51.321  1
670487  97.933  -54.029  51.274  1
670488  97.957  -54.030  51.227  1
670489  97.981  -54.031  51.180  1
670490  98.005  -54.032  51.132  1
670491  98.028  -54.032  51.083  1
670492  98.053  -54.033  51.031  1
670493  98.076  -54.034  50.979  1
670494  98.100  -54.035  50.929  1
670495  98.131  -54.044  50.875  1
670496  98.155  -54.062  50.821  1
670497  98.180  -54.080  50.765  1
670498  98.206  -54.098  50.707  1
670499  98.231  -54.117  50.649  1
670500  98.257  -54.135  50.591  1
670501  98.282  -54.154  50.534  1
670502  98.308  -54.173  50.477  1
670503  98.333  -54.191  50.420  1
670504  98.359  -54.209  50.365  1
670925  90.808  -50.228  56.667  9
670926  90.842  -50.250  56.675  9
670927  90.876  -50.271  56.681  9
670928  90.910  -50.293  56.686  9
670929  90.945  -50.314  56.690  9
670930  90.979  -50.336  56.692  9
670931  91.013  -50.357  56.693  9
670932  91.047  -50.378  56.693  9
670933  91.082  -50.400  56.692  9
670934  91.116  -50.422  56.689  9
670935  91.150  -50.443  56.685  9
670936  91.184  -50.464  56.679  9
670977  92.438  -51.184  56.643  4
670978  92.461  -51.196  56.636  4
670979  92.484  -51.208  56.628  4
670980  92.509  -51.221  56.620  4
670981  92.538  -51.235  56.612  4
670982  92.568  -51.248  56.606  4
670983  92.597  -51.262  56.601  4
670984  92.626  -51.275  56.595  4
670985  92.656  -51.288  56.587  4
670986  92.685  -51.302  56.579  4
670987  92.715  -51.315  56.572  4
670988  92.744  -51.329  56.565  4
670989  92.774  -51.342  56.556  4
670990  92.803  -51.356  56.548  4
670991  92.833  -51.369  56.539  4
670992  92.862  -51.382  56.529  4
670993  92.892  -51.396  56.519  4
670994  92.921  -51.409  56.506  4
670995  92.950  -51.422  56.497  4
670996  92.980  -51.436  56.486  4
670997  93.010  -51.448  56.474  4
670998  93.053  -51.444  56.462  4
670999  93.092  -51.450  56.450  4
671000  93.120  -51.480  56.438  4
671001  93.147  -51.510  56.425  4
671002  93.174  -51.541  56.409  4
671003  93.202  -51.571  56.393  4
671004  93.229  -51.601  56.375  4
671005  93.257  -51.631  56.357  4
671006  93.285  -51.662  56.339  4
671007  93.312  -51.692  56.319  4
671008  93.340  -51.722  56.298  4
671009  93.379  -51.753  56.274  4
671010  93.423  -51.782  56.247  4
671011  93.467  -51.813  56.218  4
671012  93.509  -51.842  56.185  4
671013  93.536  -51.860  56.149  4
671014  93.563  -51.879  56.108  4
671015  93.589  -51.898  56.064  4
671016  93.616  -51.916  56.021  4
671017  93.643  -51.935  55.979  4
671018  93.670  -51.953  55.936  4
671019  93.697  -51.972  55.893  4
671020  93.723  -51.990  55.851  4
671021  93.751  -52.009  55.810  4
671022  93.777  -52.027  55.770  4
671023  93.804  -52.046  55.729  4
671024  93.831  -52.064  55.688  4
671067  95.010  -52.860  54.664  1
671068  95.039  -52.878  54.657  1
671069  95.068  -52.896  54.651  1
671070  95.098  -52.914  54.644  1
671071  95.127  -52.932  54.638  1
671072  95.157  -52.951  54.632  1
671073  95.186  -52.970  54.626  1
671074  95.215  -52.988  54.621  1
671075  95.244  -53.001  54.616  1
671076  95.271  -53.007  54.614  1
671077  95.300  -53.023  54.610  1
671078  95.329  -53.045  54.608  1
671079  95.357  -53.067  54.606  1
671080  95.387  -53.088  54.606  1
671081  95.415  -53.110  54.606  1
671082  95.450  -53.132  54.608  1
671083  95.485  -53.154  54.611  1
671084  95.517  -53.177  54.611  1
671085  95.533  -53.200  54.609  1
671086  95.548  -53.223  54.604  1
671087  95.568  -53.242  54.596  1
671088  95.589  -53.258  54.585  1
671089  95.610  -53.275  54.573  1
671090  95.632  -53.292  54.551  1
671091  95.653  -53.308  54.534  1
671092  95.674  -53.325  54.528  1
671093  95.696  -53.342  54.522  1
671094  95.717  -53.358  54.508  1
671095  95.739  -53.375  54.482  1
671096  95.760  -53.392  54.440  1
671097  95.779  -53.410  54.390  1
671098  95.797  -53.429  54.342  1
671099  95.814  -53.448  54.303  1
671100  95.832  -53.466  54.271  1
671101  95.850  -53.485  54.243  1
671102  95.871  -53.502  54.217  1
671103  95.896  -53.517  54.190  1
671104  95.917  -53.529  54.161  1
671105  95.933  -53.537  54.133  1
671106  95.948  -53.546  54.116  1
671107  95.964  -53.554  54.099  1
671108  95.978  -53.562  54.079  1
671109  95.982  -53.570  54.055  1
671110  95.986  -53.577  54.025  1
671111  95.989  -53.584  53.990  1
671112  95.993  -53.592  53.953  1
671113  95.997  -53.599  53.913  1
671114  96.001  -53.606  53.874  1
671115  96.005  -53.614  53.840  1
671116  96.008  -53.621  53.811  1
671117  96.012  -53.629  53.789  1
671118  96.016  -53.636  53.774  1
671119  96.019  -53.643  53.754  1
671120  96.029  -53.650  53.729  1
671121  96.062  -53.656  53.703  1
671122  96.095  -53.660  53.678  1
671123  96.128  -53.665  53.655  1
671124  96.161  -53.670  53.632  1
671125  96.194  -53.675  53.610  1
671126  96.227  -53.680  53.589  1
671127  96.259  -53.685  53.567  1
671128  96.289  -53.693  53.544  1
671129  96.319  -53.700  53.518  1
671130  96.352  -53.705  53.493  1
671131  96.384  -53.710  53.471  1
671132  96.416  -53.715  53.452  1
671133  96.449  -53.719  53.432  1
671134  96.482  -53.724  53.413  1
671135  96.514  -53.729  53.391  1
671136  96.546  -53.734  53.366  1
671137  96.576  -53.740  53.338  1
671138  96.605  -53.747  53.310  1
671139  96.632  -53.753  53.281  1
671140  96.660  -53.759  53.251  1
671141  96.688  -53.766  53.224  1
671142  96.716  -53.772  53.195  1
671143  96.746  -53.778  53.162  1
671144  96.778  -53.785  53.128  1
671145  96.810  -53.792  53.092  1
671146  96.842  -53.799  53.056  1
671147  96.874  -53.806  53.019  1
671148  96.905  -53.813  52.988  1
671149  96.937  -53.820  52.958  1
671150  96.969  -53.827  52.927  1
671151  97.002  -53.835  52.896  1
671152  97.033  -53.844  52.862  1
671153  97.063  -53.855  52.828  1
671154  97.090  -53.869  52.790  1
671155  97.117  -53.882  52.751  1
671156  97.143  -53.893  52.710  1
671157  97.169  -53.903  52.668  1
671158  97.195  -53.915  52.623  1
671159  97.221  -53.925  52.579  1
671160  97.247  -53.936  52.530  1
671161  97.274  -53.935  52.483  1
671162  97.301  -53.932  52.437  1
671163  97.328  -53.929  52.392  1
671164  97.356  -53.927  52.347  1
671165  97.382  -53.926  52.301  1
671166  97.407  -53.932  52.254  1
671167  97.433  -53.938  52.207  1
671168  97.458  -53.944  52.163  1
671169  97.483  -53.950  52.118  1
671170  97.508  -53.956  52.076  1
671171  97.533  -53.961  52.034  1
671172  97.559  -53.967  51.994  1
671173  97.584  -53.973  51.954  1
671174  97.609  -53.978  51.916  1
671175  97.636  -53.980  51.877  1
671176  97.662  -53.982  51.835  1
671177  97.689  -53.985  51.791  1
671178  97.716  -53.987  51.746  1
671179  97.741  -53.990  51.702  1
671180  97.756  -53.998  51.657  1
671181  97.774  -54.004  51.614  1
671182  97.791  -54.007  51.570  1
671183  97.813  -54.008  51.526  1
671184  97.837  -54.009  51.482  1
671185  97.861  -54.010  51.436  1
671186  97.884  -54.010  51.389  1
671187  97.908  -54.011  51.344  1
671188  97.932  -54.012  51.296  1
671189  97.956  -54.013  51.250  1
671190  97.980  -54.013  51.204  1
671191  98.003  -54.014  51.156  1
671192  98.027  -54.015  51.106  1
671193  98.051  -54.016  51.056  1
671194  98.075  -54.017  51.005  1
671195  98.100  -54.019  50.954  1
671196  98.133  -54.028  50.903  1
671197  98.157  -54.044  50.850  1
671198  98.182  -54.063  50.796  1
671199  98.208  -54.081  50.740  1
671200  98.233  -54.099  50.683  1
671201  98.258  -54.118  50.628  1
671202  98.284  -54.136  50.571  1
671203  98.309  -54.155  50.515  1
671204  98.335  -54.173  50.460  1
671205  98.360  -54.192  50.405  1
671628  90.889  -50.242  56.670  9
671629  90.924  -50.264  56.675  9
671630  90.957  -50.285  56.680  9
671631  90.992  -50.306  56.684  9
671632  91.026  -50.328  56.686  9
671633  91.060  -50.349  56.687  9
671634  91.094  -50.371  56.686  9
671635  91.129  -50.392  56.685  9
671680  92.534  -51.206  56.617  4
671681  92.557  -51.218  56.608  4
671682  92.580  -51.230  56.602  4
671683  92.602  -51.243  56.595  4
671684  92.626  -51.255  56.589  4
671685  92.648  -51.268  56.584  4
671686  92.674  -51.280  56.576  4
671687  92.704  -51.293  56.569  4
671688  92.733  -51.307  56.562  4
671689  92.763  -51.321  56.555  4
671690  92.792  -51.334  56.548  4
671691  92.821  -51.347  56.540  4
671692  92.851  -51.361  56.531  4
671693  92.880  -51.374  56.522  4
671694  92.910  -51.387  56.512  4
671695  92.939  -51.401  56.501  4
671696  92.969  -51.414  56.492  4
671697  92.998  -51.428  56.481  4
671698  93.027  -51.441  56.469  4
671699  93.057  -51.454  56.457  4
671700  93.093  -51.459  56.444  4
671701  93.135  -51.456  56.433  4
671702  93.163  -51.487  56.419  4
671703  93.191  -51.517  56.403  4
671704  93.218  -51.547  56.387  4
671705  93.246  -51.578  56.370  4
671706  93.273  -51.608  56.351  4
671707  93.301  -51.638  56.334  4
671708  93.328  -51.669  56.314  4
671709  93.360  -51.699  56.293  4
671710  93.404  -51.729  56.270  4
671711  93.448  -51.759  56.244  4
671712  93.492  -51.789  56.217  4
671713  93.531  -51.816  56.185  4
671714  93.558  -51.835  56.148  4
671715  93.584  -51.853  56.108  4
671716  93.611  -51.871  56.066  4
671717  93.638  -51.890  56.025  4
671718  93.665  -51.908  55.984  4
671719  93.692  -51.927  55.941  4
671720  93.718  -51.945  55.899  4
671721  93.746  -51.964  55.857  4
671722  93.772  -51.982  55.816  4
671723  93.799  -52.001  55.776  4
671724  93.826  -52.020  55.735  4
671725  93.853  -52.039  55.694  4
671768  95.020  -52.835  54.661  1
671769  95.050  -52.853  54.653  1
671770  95.079  -52.871  54.647  1
671771  95.108  -52.889  54.640  1
671772  95.138  -52.907  54.634  1
671773  95.167  -52.926  54.627  1
671774  95.196  -52.944  54.622  1
671775  95.226  -52.963  54.617  1
671776  95.255  -52.981  54.613  1
671777  95.283  -52.989  54.610  1
671778  95.311  -53.002  54.607  1
671779  95.340  -53.024  54.605  1
671780  95.369  -53.045  54.605  1
671781  95.398  -53.067  54.604  1
671782  95.431  -53.089  54.605  1
671783  95.466  -53.111  54.608  1
671784  95.501  -53.134  54.611  1
671785  95.533  -53.157  54.611  1
671786  95.549  -53.180  54.608  1
671787  95.564  -53.202  54.601  1
671788  95.581  -53.226  54.592  1
671789  95.602  -53.242  54.580  1
671790  95.623  -53.259  54.567  1
671791  95.644  -53.276  54.541  1
671792  95.666  -53.292  54.520  1
671793  95.687  -53.309  54.509  1
671794  95.708  -53.326  54.501  1
671795  95.730  -53.342  54.488  1
671796  95.751  -53.359  54.466  1
671797  95.772  -53.376  54.431  1
671798  95.794  -53.393  54.384  1
671799  95.815  -53.409  54.336  1
671800  95.836  -53.426  54.293  1
671801  95.858  -53.443  54.256  1
671802  95.875  -53.462  54.225  1
671803  95.893  -53.480  54.198  1
671804  95.913  -53.498  54.173  1
671805  95.935  -53.511  54.147  1
671806  95.951  -53.519  54.119  1
671807  95.966  -53.527  54.100  1
671808  95.969  -53.535  54.083  1
671809  95.973  -53.542  54.064  1
671810  95.977  -53.549  54.042  1
671811  95.980  -53.557  54.012  1
671812  95.984  -53.564  53.978  1
671813  95.988  -53.571  53.942  1
671814  95.991  -53.579  53.902  1
671815  95.995  -53.586  53.863  1
671816  95.999  -53.593  53.828  1
671817  96.003  -53.601  53.798  1
671818  96.007  -53.609  53.776  1
671819  96.010  -53.615  53.762  1
671820  96.014  -53.623  53.742  1
671821  96.033  -53.629  53.717  1
671822  96.065  -53.634  53.692  1
671823  96.099  -53.639  53.668  1
671824  96.131  -53.643  53.645  1
671825  96.165  -53.649  53.623  1
671826  96.197  -53.653  53.600  1
671827  96.231  -53.659  53.579  1
671828  96.263  -53.663  53.558  1
671829  96.295  -53.670  53.535  1
671830  96.326  -53.676  53.510  1
671831  96.359  -53.681  53.487  1
671832  96.391  -53.686  53.467  1
671833  96.424  -53.690  53.448  1
671834  96.456  -53.695  53.429  1
671835  96.488  -53.700  53.410  1
671836  96.521  -53.705  53.389  1
671837  96.553  -53.709  53.364  1
671838  96.584  -53.715  53.336  1
671839  96.611  -53.722  53.307  1
671840  96.639  -53.728  53.279  1
671841  96.667  -53.734  53.249  1
671842  96.695  -53.740  53.221  1
671843  96.723  -53.747  53.193  1
671844  96.753  -53.753  53.162  1
671845  96.785  -53.760  53.129  1
671846  96.816  -53.767  53.093  1
671847  96.849  -53.774  53.057  1
671848  96.880  -53.781  53.020  1
671849  96.912  -53.788  52.988  1
671850  96.944  -53.795  52.958  1
671851  96.976  -53.802  52.928  1
671852  97.008  -53.809  52.897  1
671853  97.040  -53.816  52.864  1
671854  97.070  -53.827  52.831  1
671855  97.096  -53.840  52.792  1
671856  97.122  -53.850  52.752  1
671857  97.148  -53.862  52.712  1
671858  97.174  -53.872  52.670  1
671859  97.200  -53.883  52.627  1
671860  97.226  -53.894  52.583  1
671861  97.252  -53.904  52.535  1
671862  97.278  -53.915  52.488  1
671863  97.305  -53.917  52.442  1
671864  97.332  -53.915  52.398  1
671865  97.359  -53.912  52.353  1
671866  97.386  -53.910  52.307  1
671867  97.412  -53.915  52.260  1
671868  97.437  -53.921  52.217  1
671869  97.462  -53.927  52.173  1
671870  97.487  -53.932  52.129  1
671871  97.512  -53.938  52.086  1
671872  97.537  -53.944  52.044  1
671873  97.563  -53.950  52.004  1
671874  97.589  -53.953  51.964  1
671875  97.616  -53.955  51.925  1
671876  97.642  -53.957  51.886  1
671877  97.669  -53.960  51.846  1
671878  97.696  -53.962  51.803  1
671879  97.722  -53.964  51.759  1
671880  97.749  -53.966  51.716  1
671881  97.765  -53.974  51.672  1
671882  97.781  -53.982  51.631  1
671883  97.798  -53.986  51.590  1
671884  97.815  -53.989  51.546  1
671885  97.835  -53.991  51.502  1
671886  97.859  -53.992  51.457  1
671887  97.883  -53.993  51.412  1
671888  97.907  -53.994  51.366  1
671889  97.930  -53.994  51.319  1
671890  97.954  -53.995  51.273  1
671891  97.978  -53.996  51.227  1
671892  98.002  -53.997  51.179  1
671893  98.025  -53.998  51.130  1
671894  98.049  -53.999  51.081  1
671895  98.073  -54.000  51.030  1
671896  98.101  -54.004  50.981  1
671897  98.134  -54.013  50.931  1
671898  98.159  -54.026  50.879  1
671899  98.184  -54.045  50.827  1
671900  98.210  -54.063  50.772  1
671901  98.235  -54.082  50.717  1
671902  98.261  -54.101  50.663  1
671903  98.286  -54.119  50.607  1
671904  98.311  -54.137  50.553  1
671905  98.337  -54.156  50.498  1
671906  98.362  -54.174  50.444  1
672383  92.630  -51.227  56.592  4
672384  92.653  -51.240  56.585  4
672385  92.675  -51.252  56.578  4
672386  92.699  -51.265  56.573  4
672387  92.721  -51.277  56.566  4
672388  92.744  -51.289  56.559  4
672389  92.767  -51.302  56.553  4
672390  92.790  -51.314  56.547  4
672391  92.813  -51.326  56.541  4
672392  92.840  -51.339  56.533  4
672393  92.869  -51.352  56.524  4
672394  92.899  -51.365  56.516  4
672395  92.928  -51.379  56.505  4
672396  92.957  -51.393  56.496  4
672397  92.987  -51.406  56.487  4
672398  93.016  -51.419  56.476  4
672399  93.046  -51.433  56.464  4
672400  93.075  -51.446  56.452  4
672401  93.105  -51.459  56.438  4
672402  93.134  -51.473  56.426  4
672403  93.176  -51.471  56.412  4
672404  93.207  -51.494  56.396  4
672405  93.234  -51.524  56.380  4
672406  93.262  -51.554  56.363  4
672407  93.289  -51.584  56.345  4
672408  93.317  -51.615  56.328  4
672409  93.344  -51.645  56.308  4
672410  93.386  -51.675  56.288  4
672411  93.430  -51.705  56.265  4
672412  93.474  -51.735  56.240  4
672413  93.517  -51.766  56.214  4
672414  93.553  -51.790  56.184  4
672415  93.579  -51.808  56.147  4
672416  93.606  -51.826  56.107  4
672417  93.633  -51.845  56.067  4
672418  93.660  -51.863  56.027  4
672419  93.687  -51.882  55.986  4
672420  93.713  -51.901  55.945  4
672421  93.741  -51.920  55.903  4
672422  93.767  -51.938  55.861  4
672423  93.794  -51.957  55.820  4
672424  93.821  -51.975  55.780  4
672425  93.848  -51.994  55.740  4
672426  93.874  -52.012  55.700  4
672469  95.031  -52.810  54.658  1
672470  95.060  -52.828  54.650  1
672471  95.090  -52.846  54.643  1
672472  95.119  -52.864  54.636  1
672473  95.148  -52.883  54.629  1
672474  95.178  -52.901  54.623  1
672475  95.207  -52.919  54.618  1
672476  95.237  -52.938  54.613  1
672477  95.266  -52.956  54.609  1
672478  95.295  -52.971  54.606  1
672479  95.323  -52.981  54.605  1
672480  95.352  -53.003  54.603  1
672481  95.381  -53.024  54.603  1
672482  95.413  -53.046  54.602  1
672483  95.448  -53.069  54.603  1
672484  95.482  -53.091  54.605  1
672485  95.518  -53.114  54.607  1
672486  95.550  -53.136  54.606  1
672487  95.565  -53.159  54.602  1
672488  95.581  -53.182  54.594  1
672489  95.597  -53.205  54.585  1
672490  95.614  -53.227  54.574  1
672491  95.635  -53.243  54.559  1
672492  95.657  -53.260  54.534  1
672493  95.678  -53.277  54.507  1
672494  95.699  -53.293  54.489  1
672495  95.721  -53.310  54.476  1
672496  95.742  -53.327  54.463  1
672497  95.763  -53.343  54.444  1
672498  95.784  -53.360  54.417  1
672499  95.806  -53.377  54.374  1
672500  95.827  -53.393  54.329  1
672501  95.848  -53.410  54.284  1
672502  95.870  -53.427  54.243  1
672503  95.891  -53.443  54.209  1
672504  95.912  -53.460  54.180  1
672505  95.934  -53.477  54.156  1
672506  95.953  -53.492  54.131  1
672507  95.957  -53.499  54.105  1
672508  95.960  -53.507  54.086  1
672509  95.964  -53.515  54.069  1
672510  95.968  -53.521  54.051  1
672511  95.972  -53.529  54.029  1
672512  95.975  -53.537  54.000  1
672513  95.979  -53.543  53.966  1
672514  95.983  -53.551  53.930  1
672515  95.986  -53.559  53.892  1
672516  95.990  -53.565  53.854  1
672517  95.994  -53.573  53.818  1
672518  95.997  -53.581  53.787  1
672519  96.002  -53.587  53.763  1
672520  96.005  -53.595  53.748  1
672521  96.009  -53.603  53.727  1
672522  96.037  -53.608  53.703  1
672523  96.070  -53.612  53.679  1
672524  96.103  -53.618  53.656  1
672525  96.135  -53.622  53.634  1
672526  96.169  -53.628  53.613  1
672527  96.201  -53.632  53.590  1
672528  96.235  -53.637  53.567  1
672529  96.267  -53.642  53.547  1
672530  96.301  -53.647  53.525  1
672531  96.333  -53.652  53.502  1
672532  96.365  -53.657  53.480  1
672533  96.398  -53.662  53.462  1
672534  96.431  -53.665  53.443  1
672535  96.463  -53.670  53.424  1
672536  96.496  -53.675  53.407  1
672537  96.528  -53.679  53.386  1
672538  96.560  -53.684  53.360  1
672539  96.588  -53.690  53.332  1
672540  96.618  -53.697  53.304  1
672541  96.646  -53.703  53.276  1
672542  96.674  -53.709  53.245  1
672543  96.701  -53.715  53.218  1
672544  96.729  -53.722  53.191  1
672545  96.759  -53.728  53.162  1
672546  96.791  -53.735  53.129  1
672547  96.823  -53.742  53.093  1
672548  96.855  -53.749  53.056  1
672549  96.887  -53.756  53.020  1
672550  96.919  -53.763  52.987  1
672551  96.950  -53.770  52.957  1
672552  96.982  -53.777  52.928  1
672553  97.014  -53.784  52.897  1
672554  97.047  -53.790  52.865  1
672555  97.076  -53.798  52.832  1
672556  97.101  -53.809  52.792  1
672557  97.127  -53.819  52.751  1
672558  97.153  -53.830  52.711  1
672559  97.179  -53.841  52.670  1
672560  97.205  -53.851  52.628  1
672561  97.231  -53.862  52.585  1
672562  97.257  -53.873  52.539  1
672563  97.283  -53.884  52.492  1
672564  97.309  -53.894  52.447  1
672565  97.335  -53.900  52.402  1
672566  97.363  -53.897  52.359  1
672567  97.390  -53.894  52.314  1
672568  97.416  -53.898  52.268  1
672569  97.441  -53.903  52.225  1
672570  97.466  -53.910  52.181  1
672571  97.491  -53.916  52.139  1
672572  97.516  -53.922  52.096  1
672573  97.542  -53.925  52.054  1
672574  97.569  -53.928  52.014  1
672575  97.596  -53.930  51.974  1
672576  97.623  -53.932  51.935  1
672577  97.649  -53.934  51.896  1
672578  97.675  -53.936  51.856  1
672579  97.702  -53.938  51.814  1
672580  97.729  -53.941  51.772  1
672581  97.755  -53.943  51.730  1
672582  97.773  -53.950  51.689  1
672583  97.789  -53.958  51.649  1
672584  97.805  -53.966  51.610  1
672585  97.822  -53.969  51.567  1
672586  97.840  -53.972  51.523  1
672587  97.858  -53.975  51.479  1
672588  97.881  -53.976  51.434  1
672589  97.905  -53.976  51.389  1
672590  97.929  -53.977  51.342  1
672591  97.952  -53.979  51.296  1
672592  97.976  -53.979  51.249  1
672593  98.000  -53.980  51.203  1
672594  98.024  -53.981  51.155  1
672595  98.048  -53.982  51.106  1
672596  98.071  -53.982  51.056  1
672597  98.102  -53.989  51.008  1
672598  98.135  -53.998  50.958  1
672599  98.160  -54.009  50.907  1
672600  98.185  -54.027  50.856  1
672601  98.211  -54.046  50.804  1
672602  98.236  -54.064  50.750  1
672603  98.262  -54.082  50.696  1
672604  98.287  -54.101  50.643  1
672605  98.313  -54.120  50.589  1
672606  98.338  -54.138  50.536  1
672607  98.364  -54.157  50.483  1
673086  92.715  -51.243  56.570  4
673087  92.746  -51.260  56.565  4
673088  92.772  -51.274  56.558  4
673089  92.794  -51.287  56.551  4
673090  92.817  -51.299  56.545  4
673091  92.841  -51.311  56.539  4
673092  92.863  -51.323  56.533  4
673093  92.886  -51.335  56.527  4
673094  92.909  -51.348  56.518  4
673095  92.932  -51.360  56.510  4
673096  92.955  -51.372  56.500  4
673097  92.978  -51.384  56.492  4
673098  93.005  -51.397  56.482  4
673099  93.035  -51.411  56.472  4
673100  93.064  -51.425  56.460  4
673101  93.093  -51.437  56.447  4
673102  93.123  -51.451  56.433  4
673103  93.152  -51.465  56.419  4
673104  93.182  -51.478  56.405  4
673105  93.215  -51.486  56.389  4
673106  93.250  -51.500  56.373  4
673107  93.278  -51.531  56.357  4
673108  93.305  -51.561  56.339  4
673109  93.333  -51.591  56.322  4
673110  93.367  -51.622  56.302  4
673111  93.412  -51.652  56.282  4
673112  93.455  -51.682  56.260  4
673113  93.499  -51.712  56.236  4
673114  93.543  -51.742  56.211  4
673115  93.574  -51.763  56.181  4
673116  93.602  -51.782  56.144  4
673117  93.628  -51.801  56.106  4
673118  93.655  -51.819  56.068  4
673119  93.682  -51.838  56.028  4
673120  93.708  -51.856  55.988  4
673121  93.735  -51.875  55.947  4
673122  93.762  -51.893  55.905  4
673123  93.789  -51.912  55.864  4
673124  93.816  -51.930  55.823  4
673125  93.843  -51.949  55.783  4
673126  93.869  -51.967  55.744  4
673127  93.896  -51.986  55.704  4
673170  95.049  -52.784  54.655  1
673171  95.075  -52.803  54.648  1
673172  95.102  -52.821  54.640  1
673173  95.130  -52.840  54.632  1
673174  95.159  -52.858  54.625  1
673175  95.189  -52.876  54.619  1
673176  95.218  -52.894  54.614  1
673177  95.247  -52.913  54.609  1
673178  95.277  -52.931  54.605  1
673179  95.306  -52.949  54.603  1
673180  95.334  -52.960  54.603  1
673181  95.363  -52.982  54.602  1
673182  95.394  -53.003  54.601  1
673183  95.429  -53.026  54.600  1
673184  95.464  -53.048  54.599  1
673185  95.499  -53.070  54.599  1
673186  95.534  -53.093  54.600  1
673187  95.566  -53.115  54.600  1
673188  95.582  -53.139  54.595  1
673189  95.598  -53.161  54.587  1
673190  95.613  -53.184  54.577  1
673191  95.629  -53.208  54.563  1
673192  95.648  -53.227  54.546  1
673193  95.669  -53.244  54.522  1
673194  95.690  -53.261  54.496  1
673195  95.711  -53.277  54.470  1
673196  95.733  -53.294  54.449  1
673197  95.754  -53.311  54.432  1
673198  95.775  -53.327  54.416  1
673199  95.797  -53.344  54.392  1
673200  95.818  -53.361  54.359  1
673201  95.839  -53.377  54.320  1
673202  95.861  -53.394  54.277  1
673203  95.882  -53.411  54.234  1
673204  95.904  -53.427  54.197  1
673205  95.925  -53.444  54.164  1
673206  95.946  -53.461  54.137  1
673207  95.956  -53.470  54.115  1
673208  95.962  -53.475  54.092  1
673209  95.965  -53.483  54.073  1
673210  95.969  -53.490  54.056  1
673211  95.972  -53.498  54.038  1
673212  95.976  -53.505  54.016  1
673213  95.979  -53.513  53.989  1
673214  95.982  -53.520  53.955  1
673215  95.986  -53.527  53.920  1
673216  95.989  -53.535  53.883  1
673217  95.992  -53.543  53.845  1
673218  95.996  -53.550  53.809  1
673219  96.000  -53.558  53.777  1
673220  96.003  -53.565  53.750  1
673221  96.006  -53.572  53.732  1
673222  96.014  -53.577  53.710  1
673223  96.048  -53.580  53.687  1
673224  96.086  -53.583  53.665  1
673225  96.120  -53.587  53.643  1
673226  96.154  -53.592  53.622  1
673227  96.187  -53.596  53.601  1
673228  96.221  -53.600  53.578  1
673229  96.255  -53.605  53.555  1
673230  96.289  -53.609  53.534  1
673231  96.323  -53.613  53.513  1
673232  96.340  -53.621  53.492  1
673233  96.373  -53.626  53.473  1
673234  96.405  -53.631  53.454  1
673235  96.438  -53.635  53.436  1
673236  96.471  -53.640  53.418  1
673237  96.503  -53.643  53.400  1
673238  96.536  -53.648  53.379  1
673239  96.566  -53.654  53.354  1
673240  96.587  -53.665  53.327  1
673241  96.616  -53.672  53.299  1
673242  96.645  -53.678  53.270  1
673243  96.675  -53.684  53.241  1
673244  96.704  -53.690  53.215  1
673245  96.734  -53.697  53.190  1
673246  96.767  -53.702  53.161  1
673247  96.800  -53.708  53.128  1
673248  96.832  -53.714  53.094  1
673249  96.865  -53.720  53.056  1
673250  96.897  -53.726  53.019  1
673251  96.930  -53.732  52.986  1
673252  96.962  -53.737  52.956  1
673253  96.995  -53.744  52.928  1
673254  97.028  -53.750  52.897  1
673255  97.058  -53.757  52.866  1
673256  97.083  -53.769  52.832  1
673257  97.108  -53.779  52.791  1
673258  97.134  -53.790  52.749  1
673259  97.159  -53.800  52.709  1
673260  97.185  -53.809  52.670  1
673261  97.211  -53.820  52.629  1
673262  97.236  -53.831  52.587  1
673263  97.262  -53.841  52.542  1
673264  97.288  -53.852  52.496  1
673265  97.314  -53.863  52.452  1
673266  97.340  -53.873  52.408  1
673267  97.366  -53.882  52.365  1
673268  97.393  -53.879  52.321  1
673269  97.420  -53.881  52.277  1
673270  97.445  -53.887  52.233  1
673271  97.470  -53.892  52.190  1
673272  97.496  -53.897  52.149  1
673273  97.522  -53.900  52.107  1
673274  97.549  -53.902  52.065  1
673275  97.576  -53.904  52.024  1
673276  97.602  -53.907  51.984  1
673277  97.629  -53.909  51.946  1
673278  97.655  -53.911  51.907  1
673279  97.682  -53.913  51.867  1
673280  97.709  -53.916  51.827  1
673281  97.735  -53.918  51.786  1
673282  97.762  -53.920  51.745  1
673283  97.782  -53.926  51.707  1
673284  97.797  -53.934  51.668  1
673285  97.813  -53.942  51.628  1
673286  97.829  -53.948  51.586  1
673287  97.847  -53.951  51.543  1
673288  97.865  -53.954  51.499  1
673289  97.882  -53.957  51.454  1
673290  97.903  -53.960  51.409  1
673291  97.927  -53.960  51.364  1
673292  97.951  -53.961  51.319  1
673293  97.974  -53.962  51.274  1
673294  97.999  -53.963  51.227  1
673295  98.022  -53.963  51.179  1
673296  98.046  -53.964  51.131  1
673297  98.070  -53.966  51.083  1
673298  98.103  -53.974  51.034  1
673299  98.136  -53.983  50.985  1
673300  98.165  -53.992  50.935  1
673301  98.187  -54.010  50.885  1
673302  98.213  -54.028  50.833  1
673303  98.238  -54.047  50.780  1
673304  98.264  -54.065  50.728  1
673305  98.289  -54.084  50.675  1
673306  98.314  -54.102  50.623  1
673307  98.340  -54.120  50.571  1
673308  98.365  -54.139  50.520  1
673789  92.794  -51.253  56.550  4
673790  92.825  -51.271  56.543  4
673791  92.856  -51.288  56.537  4
673792  92.886  -51.305  56.532  4
673793  92.914  -51.321  56.526  4
673794  92.936  -51.333  56.520  4
673795  92.959  -51.345  56.512  4
673796  92.982  -51.357  56.503  4
673797  93.005  -51.369  56.495  4
673798  93.028  -51.382  56.486  4
673799  93.051  -51.394  56.477  4
673800  93.074  -51.406  56.467  4
673801  93.097  -51.418  56.454  4
673802  93.120  -51.431  56.441  4
673803  93.143  -51.443  56.428  4
673804  93.170  -51.456  56.414  4
673805  93.200  -51.469  56.398  4
673806  93.229  -51.483  56.382  4
673807  93.259  -51.497  56.366  4
673808  93.294  -51.507  56.350  4
673809  93.321  -51.537  56.332  4
673810  93.349  -51.568  56.315  4
673811  93.393  -51.598  56.295  4
673812  93.437  -51.628  56.275  4
673813  93.481  -51.658  56.254  4
673814  93.525  -51.688  56.231  4
673815  93.569  -51.718  56.206  4
673816  93.596  -51.738  56.176  4
673817  93.623  -51.756  56.140  4
673818  93.650  -51.775  56.104  4
673819  93.677  -51.793  56.066  4
673820  93.703  -51.811  56.027  4
673821  93.730  -51.830  55.988  4
673822  93.757  -51.848  55.947  4
673823  93.784  -51.867  55.906  4
673824  93.811  -51.885  55.865  4
673825  93.838  -51.904  55.825  4
673826  93.864  -51.923  55.785  4
673827  93.891  -51.942  55.746  4
673828  93.918  -51.960  55.707  4
673871  95.070  -52.758  54.653  1
673872  95.098  -52.776  54.645  1
673873  95.124  -52.795  54.638  1
673874  95.151  -52.813  54.629  1
673875  95.178  -52.832  54.622  1
673876  95.204  -52.850  54.616  1
673877  95.232  -52.869  54.610  1
673878  95.258  -52.888  54.605  1
673879  95.287  -52.906  54.602  1
673880  95.317  -52.924  54.601  1
673881  95.346  -52.941  54.601  1
673882  95.376  -52.960  54.600  1
673883  95.410  -52.982  54.599  1
673884  95.445  -53.005  54.596  1
673885  95.480  -53.027  54.594  1
673886  95.515  -53.050  54.592  1
673887  95.550  -53.073  54.592  1
673888  95.583  -53.095  54.593  1
673889  95.598  -53.118  54.590  1
673890  95.614  -53.141  54.582  1
673891  95.629  -53.164  54.568  1
673892  95.645  -53.187  54.551  1
673893  95.661  -53.210  54.532  1
673894  95.681  -53.227  54.509  1
673895  95.703  -53.244  54.482  1
673896  95.724  -53.261  54.453  1
673897  95.745  -53.278  54.426  1
673898  95.767  -53.295  54.405  1
673899  95.788  -53.311  54.386  1
673900  95.809  -53.328  54.365  1
673901  95.831  -53.345  54.339  1
673902  95.852  -53.361  54.307  1
673903  95.873  -53.378  54.269  1
673904  95.895  -53.395  54.228  1
673905  95.916  -53.411  54.187  1
673906  95.938  -53.428  54.152  1
673907  95.954  -53.442  54.123  1
673908  95.960  -53.447  54.099  1
673909  95.965  -53.453  54.077  1
673910  95.971  -53.459  54.060  1
673911  95.975  -53.466  54.044  1
673912  95.978  -53.474  54.024  1
673913  95.982  -53.481  54.003  1
673914  95.985  -53.488  53.976  1
673915  95.989  -53.496  53.945  1
673916  95.992  -53.503  53.911  1
673917  95.995  -53.511  53.874  1
673918  95.999  -53.518  53.837  1
673919  96.003  -53.526  53.801  1
673920  96.006  -53.533  53.769  1
673921  96.009  -53.540  53.739  1
673922  96.018  -53.545  53.715  1
673923  96.028  -53.549  53.692  1
673924  96.048  -53.552  53.671  1
673925  96.091  -53.554  53.651  1
673926  96.132  -53.556  53.630  1
673927  96.175  -53.557  53.609  1
673928  96.212  -53.561  53.588  1
673929  96.246  -53.565  53.565  1
673930  96.279  -53.569  53.541  1
673931  96.313  -53.574  53.521  1
673932  96.347  -53.577  53.500  1
673933  96.363  -53.587  53.481  1
673934  96.381  -53.596  53.463  1
673935  96.413  -53.599  53.445  1
673936  96.446  -53.604  53.428  1
673937  96.478  -53.609  53.410  1
673938  96.511  -53.613  53.392  1
673939  96.543  -53.618  53.371  1
673940  96.567  -53.627  53.347  1
673941  96.588  -53.637  53.320  1
673942  96.613  -53.646  53.292  1
673943  96.643  -53.653  53.263  1
673944  96.673  -53.659  53.234  1
673945  96.702  -53.665  53.208  1
673946  96.736  -53.669  53.184  1
673947  96.778  -53.670  53.157  1
673948  96.813  -53.674  53.125  1
673949  96.846  -53.680  53.090  1
673950  96.878  -53.686  53.053  1
673951  96.911  -53.692  53.015  1
673952  96.944  -53.698  52.983  1
673953  96.976  -53.704  52.955  1
673954  97.009  -53.709  52.927  1
673955  97.041  -53.715  52.897  1
673956  97.066  -53.728  52.865  1
673957  97.091  -53.739  52.829  1
673958  97.115  -53.750  52.788  1
673959  97.141  -53.761  52.747  1
673960  97.166  -53.771  52.708  1
673961  97.192  -53.781  52.669  1
673962  97.218  -53.791  52.629  1
673963  97.243  -53.801  52.589  1
673964  97.268  -53.811  52.544  1
673965  97.294  -53.822  52.501  1
673966  97.319  -53.831  52.458  1
673967  97.345  -53.842  52.415  1
673968  97.371  -53.853  52.371  1
673969  97.397  -53.863  52.328  1
673970  97.424  -53.863  52.286  1
673971  97.449  -53.869  52.242  1
673972  97.475  -53.872  52.200  1
673973  97.502  -53.875  52.159  1
673974  97.529  -53.877  52.118  1
673975  97.556  -53.879  52.075  1
673976  97.582  -53.882  52.034  1
673977  97.609  -53.884  51.995  1
673978  97.636  -53.885  51.959  1
673979  97.662  -53.888  51.919  1
673980  97.688  -53.890  51.880  1
673981  97.715  -53.892  51.841  1
673982  97.742  -53.894  51.800  1
673983  97.769  -53.897  51.761  1
673984  97.790  -53.902  51.724  1
673985  97.805  -53.910  51.685  1
673986  97.821  -53.918  51.645  1
673987  97.837  -53.926  51.604  1
673988  97.854  -53.932  51.561  1
673989  97.871  -53.935  51.518  1
673990  97.889  -53.937  51.474  1
673991  97.907  -53.940  51.429  1
673992  97.926  -53.943  51.385  1
673993  97.949  -53.944  51.342  1
673994  97.973  -53.944  51.297  1
673995  97.997  -53.945  51.252  1
673996  98.021  -53.946  51.205  1
673997  98.044  -53.947  51.157  1
673998  98.071  -53.950  51.110  1
673999  98.104  -53.959  51.061  1
674000  98.136  -53.968  51.011  1
674001  98.169  -53.977  50.962  1
674002  98.189  -53.992  50.913  1
674003  98.215  -54.010  50.862  1
674004  98.240  -54.029  50.811  1
674005  98.266  -54.048  50.760  1
674006  98.291  -54.066  50.708  1
674007  98.316  -54.085  50.657  1
674008  98.342  -54.103  50.606  1
674009  98.367  -54.121  50.555  1
674491  92.842  -51.246  56.536  4
674492  92.873  -51.264  56.530  4
674493  92.904  -51.281  56.525  4
674494  92.935  -51.299  56.520  4
674495  92.966  -51.316  56.514  4
674496  92.997  -51.334  56.506  4
674497  93.027  -51.351  56.497  4
674498  93.055  -51.367  56.489  4
674499  93.078  -51.379  56.481  4
674500  93.101  -51.391  56.472  4
674501  93.124  -51.403  56.462  4
674502  93.147  -51.415  56.449  4
674503  93.170  -51.428  56.436  4
674504  93.193  -51.440  56.423  4
674505  93.216  -51.453  56.408  4
674506  93.238  -51.465  56.393  4
674507  93.262  -51.477  56.377  4
674508  93.284  -51.489  56.360  4
674509  93.307  -51.502  56.342  4
674510  93.337  -51.514  56.325  4
674511  93.374  -51.544  56.308  4
674512  93.419  -51.575  56.289  4
674513  93.463  -51.604  56.269  4
674514  93.506  -51.635  56.247  4
674515  93.550  -51.665  56.224  4
674516  93.591  -51.693  56.199  4
674517  93.618  -51.711  56.169  4
674518  93.645  -51.730  56.134  4
674519  93.672  -51.748  56.099  4
674520  93.699  -51.767  56.063  4
674521  93.725  -51.785  56.025  4
674522  93.752  -51.804  55.985  4
674523  93.779  -51.823  55.945  4
674524  93.805  -51.841  55.905  4
674525  93.833  -51.860  55.865  4
674526  93.859  -51.878  55.825  4
674527  93.886  -51.897  55.785  4
674528  93.913  -51.915  55.746  4
674529  93.940  -51.934  55.707  4
674572  95.093  -52.731  54.651  1
674573  95.119  -52.750  54.643  1
674574  95.146  -52.769  54.635  1
674575  95.173  -52.788  54.626  1
674576  95.199  -52.806  54.619  1
674577  95.227  -52.825  54.612  1
674578  95.253  -52.843  54.606  1
674579  95.280  -52.862  54.600  1
674580  95.307  -52.881  54.597  1
674581  95.333  -52.900  54.596  1
674582  95.360  -52.919  54.596  1
674583  95.392  -52.940  54.595  1
674584  95.426  -52.962  54.592  1
674585  95.461  -52.985  54.588  1
674586  95.496  -53.007  54.585  1
674587  95.531  -53.029  54.584  1
674588  95.566  -53.052  54.588  1
674589  95.599  -53.074  54.590  1
674590  95.615  -53.098  54.588  1
674591  95.630  -53.120  54.578  1
674592  95.646  -53.143  54.560  1
674593  95.662  -53.167  54.538  1
674594  95.677  -53.189  54.517  1
674595  95.694  -53.211  54.493  1
674596  95.715  -53.228  54.467  1
674597  95.737  -53.245  54.437  1
674598  95.758  -53.261  54.407  1
674599  95.779  -53.278  54.380  1
674600  95.801  -53.295  54.358  1
674601  95.822  -53.311  54.339  1
674602  95.843  -53.329  54.317  1
674603  95.865  -53.346  54.292  1
674604  95.886  -53.362  54.260  1
674605  95.907  -53.379  54.221  1
674606  95.928  -53.396  54.179  1
674607  95.950  -53.412  54.141  1
674608  95.958  -53.419  54.109  1
674609  95.963  -53.425  54.084  1
674610  95.969  -53.431  54.062  1
674611  95.975  -53.437  54.044  1
674612  95.980  -53.443  54.028  1
674613  95.985  -53.449  54.010  1
674614  95.988  -53.456  53.990  1
674615  95.992  -53.464  53.965  1
674616  95.995  -53.471  53.934  1
674617  95.999  -53.479  53.900  1
674618  96.002  -53.487  53.865  1
674619  96.006  -53.494  53.828  1
674620  96.009  -53.501  53.792  1
674621  96.013  -53.509  53.759  1
674622  96.023  -53.512  53.727  1
674623  96.033  -53.517  53.700  1
674624  96.043  -53.521  53.675  1
674625  96.053  -53.524  53.654  1
674626  96.091  -53.527  53.634  1
674627  96.133  -53.528  53.614  1
674628  96.175  -53.530  53.593  1
674629  96.218  -53.531  53.573  1
674630  96.259  -53.533  53.550  1
674631  96.302  -53.534  53.527  1
674632  96.337  -53.538  53.505  1
674633  96.372  -53.543  53.486  1
674634  96.387  -53.552  53.469  1
674635  96.401  -53.562  53.452  1
674636  96.421  -53.569  53.435  1
674637  96.454  -53.574  53.418  1
674638  96.486  -53.578  53.401  1
674639  96.519  -53.582  53.383  1
674640  96.547  -53.589  53.362  1
674641  96.569  -53.599  53.338  1
674642  96.590  -53.610  53.311  1
674643  96.611  -53.621  53.283  1
674644  96.641  -53.628  53.255  1
674645  96.670  -53.634  53.227  1
674646  96.700  -53.640  53.201  1
674647  96.742  -53.640  53.176  1
674648  96.783  -53.641  53.151  1
674649  96.824  -53.641  53.120  1
674650  96.859  -53.646  53.085  1
674651  96.892  -53.652  53.049  1
674652  96.925  -53.658  53.011  1
674653  96.957  -53.664  52.979  1
674654  96.990  -53.670  52.950  1
674655  97.022  -53.676  52.922  1
674656  97.049  -53.686  52.893  1
674657  97.074  -53.697  52.859  1
674658  97.098  -53.709  52.822  1
674659  97.123  -53.721  52.782  1
674660  97.148  -53.732  52.742  1
674661  97.173  -53.742  52.704  1
674662  97.199  -53.752  52.666  1
674663  97.224  -53.762  52.628  1
674664  97.250  -53.772  52.589  1
674665  97.276  -53.782  52.546  1
674666  97.301  -53.793  52.503  1
674667  97.326  -53.803  52.461  1
674668  97.352  -53.813  52.419  1
674669  97.378  -53.823  52.377  1
674670  97.403  -53.833  52.335  1
674671  97.428  -53.843  52.294  1
674672  97.455  -53.847  52.252  1
674673  97.482  -53.849  52.210  1
674674  97.509  -53.851  52.169  1
674675  97.535  -53.853  52.128  1
674676  97.562  -53.856  52.085  1
674677  97.589  -53.858  52.044  1
674678  97.615  -53.860  52.006  1
674679  97.642  -53.863  51.971  1
674680  97.668  -53.865  51.933  1
674681  97.695  -53.867  51.895  1
674682  97.722  -53.869  51.855  1
674683  97.748  -53.872  51.814  1
674684  97.775  -53.874  51.775  1
674685  97.798  -53.878  51.739  1
674686  97.814  -53.886  51.700  1
674687  97.829  -53.894  51.660  1
674688  97.845  -53.902  51.619  1
674689  97.861  -53.910  51.578  1
674690  97.878  -53.914  51.535  1
674691  97.896  -53.917  51.493  1
674692  97.914  -53.920  51.451  1
674693  97.931  -53.922  51.408  1
674694  97.949  -53.925  51.365  1
674695  97.971  -53.927  51.321  1
674696  97.995  -53.928  51.276  1
674697  98.019  -53.928  51.231  1
674698  98.043  -53.929  51.183  1
674699  98.072  -53.935  51.136  1
674700  98.105  -53.944  51.087  1
674701  98.137  -53.953  51.038  1
674702  98.170  -53.962  50.989  1
674703  98.191  -53.975  50.940  1
674704  98.216  -53.993  50.891  1
674705  98.242  -54.011  50.841  1
674706  98.267  -54.030  50.791  1
674707  98.293  -54.048  50.740  1
674708  98.318  -54.067  50.690  1
674709  98.343  -54.085  50.640  1
674710  98.369  -54.104  50.589  1
675193  92.890  -51.240  56.524  4
675194  92.921  -51.257  56.519  4
675195  92.951  -51.274  56.513  4
675196  92.983  -51.292  56.508  4
675197  93.013  -51.309  56.500  4
675198  93.045  -51.327  56.491  4
675199  93.075  -51.344  56.483  4
675200  93.107  -51.362  56.475  4
675201  93.137  -51.380  56.466  4
675202  93.168  -51.397  56.456  4
675203  93.197  -51.413  56.444  4
675204  93.220  -51.425  56.430  4
675205  93.243  -51.437  56.417  4
675206  93.266  -51.450  56.403  4
675207  93.289  -51.462  56.387  4
675208  93.311  -51.475  56.372  4
675209  93.335  -51.487  56.354  4
675210  93.357  -51.499  56.337  4
675211  93.380  -51.511  56.320  4
675212  93.404  -51.523  56.300  4
675213  93.444  -51.550  56.281  4
675214  93.488  -51.581  56.261  4
675215  93.532  -51.611  56.240  4
675216  93.576  -51.641  56.217  4
675217  93.613  -51.666  56.190  4
675218  93.640  -51.685  56.161  4
675219  93.666  -51.703  56.127  4
675220  93.694  -51.722  56.093  4
675221  93.720  -51.741  56.058  4
675222  93.747  -51.760  56.021  4
675223  93.774  -51.778  55.981  4
675224  93.801  -51.796  55.942  4
675225  93.828  -51.815  55.902  4
675226  93.854  -51.833  55.863  4
675227  93.881  -51.852  55.823  4
675228  93.908  -51.870  55.784  4
675229  93.935  -51.889  55.745  4
675273  95.114  -52.709  54.650  1
675274  95.140  -52.728  54.641  1
675275  95.167  -52.747  54.631  1
675276  95.194  -52.767  54.623  1
675277  95.220  -52.786  54.615  1
675278  95.247  -52.805  54.608  1
675279  95.274  -52.824  54.601  1
675280  95.301  -52.843  54.595  1
675281  95.327  -52.862  54.591  1
675282  95.354  -52.881  54.589  1
675283  95.381  -52.900  54.588  1
675284  95.408  -52.919  54.587  1
675285  95.443  -52.941  54.584  1
675286  95.477  -52.964  54.579  1
675287  95.513  -52.986  54.575  1
675288  95.547  -53.009  54.578  1
675289  95.582  -53.031  54.583  1
675290  95.615  -53.054  54.585  1
675291  95.631  -53.076  54.582  1
675292  95.647  -53.100  54.571  1
675293  95.662  -53.123  54.552  1
675294  95.678  -53.146  54.528  1
675295  95.694  -53.169  54.503  1
675296  95.709  -53.192  54.478  1
675297  95.728  -53.212  54.452  1
675298  95.749  -53.229  54.423  1
675299  95.770  -53.245  54.392  1
675300  95.792  -53.262  54.361  1
675301  95.813  -53.279  54.335  1
675302  95.834  -53.295  54.314  1
675303  95.855  -53.312  54.294  1
675304  95.877  -53.329  54.272  1
675305  95.898  -53.346  54.245  1
675306  95.919  -53.362  54.212  1
675307  95.941  -53.379  54.173  1
675308  95.956  -53.391  54.131  1
675309  95.961  -53.397  54.097  1
675310  95.967  -53.403  54.069  1
675311  95.972  -53.408  54.046  1
675312  95.978  -53.415  54.027  1
675313  95.984  -53.421  54.011  1
675314  95.989  -53.426  53.994  1
675315  95.995  -53.432  53.976  1
675316  95.998  -53.440  53.952  1
675317  96.002  -53.447  53.923  1
675318  96.005  -53.455  53.890  1
675319  96.008  -53.462  53.854  1
675320  96.012  -53.469  53.817  1
675321  96.017  -53.476  53.780  1
675322  96.027  -53.480  53.746  1
675323  96.038  -53.483  53.713  1
675324  96.048  -53.488  53.685  1
675325  96.058  -53.492  53.659  1
675326  96.068  -53.496  53.636  1
675327  96.092  -53.499  53.616  1
675328  96.134  -53.501  53.595  1
675329  96.176  -53.502  53.575  1
675330  96.218  -53.504  53.554  1
675331  96.260  -53.505  53.532  1
675332  96.302  -53.507  53.509  1
675333  96.344  -53.509  53.487  1
675334  96.380  -53.512  53.468  1
675335  96.411  -53.516  53.451  1
675336  96.425  -53.526  53.436  1
675337  96.439  -53.536  53.418  1
675338  96.461  -53.543  53.402  1
675339  96.494  -53.547  53.387  1
675340  96.526  -53.552  53.370  1
675341  96.549  -53.562  53.349  1
675342  96.570  -53.572  53.325  1
675343  96.591  -53.583  53.298  1
675344  96.612  -53.594  53.271  1
675345  96.639  -53.602  53.245  1
675346  96.668  -53.609  53.219  1
675347  96.705  -53.611  53.193  1
675348  96.747  -53.611  53.167  1
675349  96.789  -53.612  53.141  1
675350  96.830  -53.612  53.113  1
675351  96.872  -53.613  53.079  1
675352  96.905  -53.618  53.044  1
675353  96.938  -53.624  53.007  1
675354  96.971  -53.630  52.973  1
675355  97.003  -53.636  52.944  1
675356  97.032  -53.645  52.916  1
675357  97.056  -53.656  52.885  1
675358  97.081  -53.668  52.851  1
675359  97.106  -53.679  52.813  1
675360  97.131  -53.690  52.774  1
675361  97.155  -53.703  52.736  1
675362  97.180  -53.713  52.699  1
675363  97.206  -53.723  52.663  1
675364  97.231  -53.734  52.626  1
675365  97.257  -53.744  52.588  1
675366  97.283  -53.753  52.548  1
675367  97.308  -53.764  52.506  1
675368  97.333  -53.774  52.464  1
675369  97.359  -53.784  52.423  1
675370  97.385  -53.794  52.382  1
675371  97.410  -53.804  52.341  1
675372  97.432  -53.815  52.300  1
675373  97.460  -53.820  52.259  1
675374  97.489  -53.826  52.218  1
675375  97.515  -53.828  52.177  1
675376  97.542  -53.831  52.135  1
675377  97.569  -53.833  52.094  1
675378  97.595  -53.835  52.054  1
675379  97.622  -53.838  52.018  1
675380  97.649  -53.839  51.982  1
675381  97.675  -53.841  51.946  1
675382  97.702  -53.844  51.908  1
675383  97.728  -53.846  51.868  1
675384  97.755  -53.848  51.828  1
675385  97.782  -53.850  51.789  1
675386  97.806  -53.853  51.752  1
675387  97.822  -53.862  51.713  1
675388  97.838  -53.870  51.674  1
675389  97.854  -53.878  51.634  1
675390  97.869  -53.886  51.594  1
675391  97.885  -53.894  51.553  1
675392  97.903  -53.897  51.512  1
675393  97.921  -53.900  51.471  1
675394  97.938  -53.903  51.429  1
675395  97.956  -53.906  51.388  1
675396  97.973  -53.909  51.345  1
675397  97.994  -53.910  51.301  1
675398  98.017  -53.911  51.257  1
675399  98.041  -53.912  51.211  1
675400  98.073  -53.920  51.164  1
675401  98.106  -53.929  51.114  1
675402  98.138  -53.938  51.064  1
675403  98.171  -53.947  51.016  1
675404  98.196  -53.958  50.967  1
675405  98.218  -53.976  50.919  1
675406  98.243  -53.994  50.870  1
675407  98.269  -54.013  50.820  1
675408  98.294  -54.031  50.771  1
675409  98.319  -54.049  50.721  1
675410  98.345  -54.068  50.672  1
675411  98.370  -54.086  50.623  1
675896  92.969  -51.250  56.507  4
675897  93.000  -51.268  56.502  4
675898  93.030  -51.285  56.493  4
675899  93.062  -51.302  56.486  4
675900  93.092  -51.320  56.477  4
675901  93.124  -51.338  56.469  4
675902  93.154  -51.356  56.460  4
675903  93.186  -51.373  56.450  4
675904  93.216  -51.390  56.438  4
675905  93.248  -51.408  56.424  4
675906  93.278  -51.425  56.412  4
675907  93.309  -51.443  56.398  4
675908  93.339  -51.459  56.383  4
675909  93.362  -51.472  56.367  4
675910  93.384  -51.484  56.349  4
675911  93.408  -51.496  56.331  4
675912  93.431  -51.509  56.313  4
675913  93.453  -51.521  56.294  4
675914  93.477  -51.533  56.273  4
675915  93.513  -51.557  56.253  4
675916  93.557  -51.587  56.232  4
675917  93.602  -51.617  56.208  4
675918  93.635  -51.641  56.181  4
675919  93.661  -51.659  56.152  4
675920  93.689  -51.678  56.119  4
675921  93.715  -51.696  56.085  4
675922  93.742  -51.715  56.051  4
675923  93.769  -51.733  56.014  4
675924  93.796  -51.752  55.975  4
675925  93.823  -51.770  55.936  4
675926  93.849  -51.788  55.897  4
675927  93.876  -51.807  55.859  4
675928  93.903  -51.826  55.820  4
675929  93.930  -51.845  55.781  4
675930  93.957  -51.863  55.743  4
675974  95.134  -52.691  54.647  1
675975  95.161  -52.710  54.638  1
675976  95.188  -52.729  54.628  1
675977  95.214  -52.748  54.619  1
675978  95.241  -52.767  54.611  1
675979  95.268  -52.786  54.603  1
675980  95.295  -52.805  54.596  1
675981  95.321  -52.824  54.590  1
675982  95.348  -52.843  54.584  1
675983  95.375  -52.863  54.579  1
675984  95.401  -52.882  54.578  1
675985  95.428  -52.901  54.577  1
675986  95.459  -52.921  54.574  1
675987  95.494  -52.944  54.568  1
675988  95.529  -52.966  54.565  1
675989  95.563  -52.988  54.571  1
675990  95.599  -53.010  54.575  1
675991  95.631  -53.033  54.576  1
675992  95.648  -53.056  54.573  1
675993  95.663  -53.079  54.562  1
675994  95.679  -53.102  54.542  1
675995  95.694  -53.125  54.518  1
675996  95.710  -53.148  54.492  1
675997  95.726  -53.171  54.464  1
675998  95.742  -53.195  54.438  1
675999  95.761  -53.213  54.409  1
676000  95.782  -53.230  54.378  1
676001  95.804  -53.246  54.346  1
676002  95.825  -53.263  54.315  1
676003  95.846  -53.280  54.291  1
676004  95.868  -53.296  54.270  1
676005  95.889  -53.313  54.248  1
676006  95.910  -53.330  54.223  1
676007  95.932  -53.346  54.194  1
676008  95.953  -53.363  54.160  1
676009  95.959  -53.369  54.117  1
676010  95.965  -53.375  54.083  1
676011  95.970  -53.380  54.053  1
676012  95.976  -53.386  54.028  1
676013  95.982  -53.393  54.008  1
676014  95.987  -53.398  53.992  1
676015  95.993  -53.404  53.977  1
676016  95.999  -53.409  53.960  1
676017  96.005  -53.415  53.937  1
676018  96.008  -53.423  53.911  1
676019  96.011  -53.430  53.880  1
676020  96.015  -53.437  53.844  1
676021  96.022  -53.443  53.804  1
676022  96.032  -53.447  53.766  1
676023  96.042  -53.451  53.731  1
676024  96.052  -53.455  53.697  1
676025  96.062  -53.459  53.669  1
676026  96.073  -53.463  53.642  1
676027  96.083  -53.468  53.618  1
676028  96.093  -53.471  53.596  1
676029  96.135  -53.473  53.575  1
676030  96.177  -53.474  53.555  1
676031  96.219  -53.476  53.534  1
676032  96.261  -53.478  53.512  1
676033  96.296  -53.481  53.489  1
676034  96.328  -53.486  53.468  1
676035  96.361  -53.490  53.449  1
676036  96.393  -53.493  53.431  1
676037  96.426  -53.498  53.417  1
676038  96.458  -53.502  53.399  1
676039  96.476  -53.510  53.383  1
676040  96.502  -53.516  53.370  1
676041  96.529  -53.524  53.354  1
676042  96.550  -53.534  53.333  1
676043  96.572  -53.545  53.309  1
676044  96.593  -53.556  53.282  1
676045  96.614  -53.567  53.258  1
676046  96.636  -53.577  53.233  1
676047  96.670  -53.581  53.208  1
676048  96.712  -53.581  53.181  1
676049  96.753  -53.582  53.155  1
676050  96.794  -53.583  53.129  1
676051  96.836  -53.583  53.101  1
676052  96.877  -53.584  53.068  1
676053  96.919  -53.584  53.033  1
676054  96.952  -53.590  52.998  1
676055  96.984  -53.596  52.965  1
676056  97.015  -53.603  52.935  1
676057  97.039  -53.615  52.906  1
676058  97.064  -53.627  52.874  1
676059  97.089  -53.638  52.840  1
676060  97.113  -53.650  52.803  1
676061  97.138  -53.661  52.765  1
676062  97.163  -53.672  52.728  1
676063  97.187  -53.684  52.693  1
676064  97.213  -53.695  52.658  1
676065  97.238  -53.705  52.623  1
676066  97.264  -53.715  52.587  1
676067  97.290  -53.725  52.548  1
676068  97.315  -53.735  52.508  1
676069  97.341  -53.745  52.467  1
676070  97.366  -53.756  52.427  1
676071  97.392  -53.766  52.386  1
676072  97.415  -53.775  52.347  1
676073  97.437  -53.786  52.306  1
676074  97.464  -53.791  52.266  1
676075  97.493  -53.797  52.224  1
676076  97.521  -53.803  52.182  1
676077  97.548  -53.807  52.141  1
676078  97.575  -53.809  52.101  1
676079  97.602  -53.812  52.063  1
676080  97.629  -53.814  52.029  1
676081  97.655  -53.816  51.993  1
676082  97.681  -53.819  51.957  1
676083  97.708  -53.821  51.920  1
676084  97.735  -53.823  51.881  1
676085  97.761  -53.825  51.841  1
676086  97.788  -53.828  51.802  1
676087  97.815  -53.830  51.764  1
676088  97.830  -53.838  51.727  1
676089  97.846  -53.846  51.688  1
676090  97.862  -53.854  51.649  1
676091  97.877  -53.862  51.610  1
676092  97.893  -53.870  51.571  1
676093  97.910  -53.876  51.531  1
676094  97.927  -53.879  51.490  1
676095  97.945  -53.882  51.449  1
676096  97.963  -53.885  51.409  1
676097  97.981  -53.888  51.367  1
676098  97.998  -53.891  51.325  1
676099  98.016  -53.894  51.282  1
676100  98.041  -53.897  51.237  1
676101  98.074  -53.905  51.190  1
676102  98.106  -53.914  51.140  1
676103  98.139  -53.923  51.091  1
676104  98.171  -53.932  51.042  1
676105  98.200  -53.941  50.995  1
676106  98.220  -53.958  50.946  1
676107  98.245  -53.976  50.898  1
676108  98.271  -53.994  50.850  1
676109  98.296  -54.013  50.801  1
676110  98.321  -54.032  50.752  1
676111  98.347  -54.050  50.704  1
676112  98.372  -54.069  50.656  1
676113  98.397  -54.087  50.608  1
676598  93.017  -51.243  56.496  4
676599  93.048  -51.261  56.487  4
676600  93.079  -51.278  56.479  4
676601  93.110  -51.296  56.471  4
676602  93.141  -51.314  56.462  4
676603  93.171  -51.331  56.453  4
676604  93.203  -51.349  56.444  4
676605  93.233  -51.366  56.432  4
676606  93.264  -51.384  56.419  4
676607  93.295  -51.401  56.405  4
676608  93.326  -51.418  56.392  4
676609  93.357  -51.436  56.377  4
676610  93.388  -51.453  56.361  4
676611  93.419  -51.471  56.343  4
676612  93.450  -51.488  56.326  4
676613  93.481  -51.506  56.307  4
676614  93.504  -51.518  56.287  4
676615  93.526  -51.530  56.267  4
676616  93.550  -51.542  56.246  4
676617  93.583  -51.563  56.224  4
676618  93.627  -51.594  56.200  4
676619  93.656  -51.614  56.173  4
676620  93.684  -51.633  56.143  4
676621  93.710  -51.651  56.110  4
676622  93.737  -51.670  56.077  4
676623  93.764  -51.688  56.042  4
676624  93.791  -51.707  56.006  4
676625  93.818  -51.725  55.969  4
676626  93.844  -51.744  55.930  4
676627  93.871  -51.763  55.892  4
676628  93.898  -51.781  55.853  4
676629  93.925  -51.800  55.815  4
676630  93.952  -51.818  55.776  4
676631  93.978  -51.837  55.738  4
676676  95.182  -52.691  54.635  1
676677  95.208  -52.710  54.625  1
676678  95.235  -52.729  54.615  1
676679  95.262  -52.748  54.607  1
676680  95.288  -52.767  54.598  1
676681  95.315  -52.787  54.590  1
676682  95.342  -52.806  54.583  1
676683  95.369  -52.825  54.576  1
676684  95.395  -52.844  54.570  1
676685  95.422  -52.863  54.566  1
676686  95.449  -52.882  54.564  1
676687  95.476  -52.901  54.561  1
676688  95.510  -52.923  54.556  1
676689  95.545  -52.945  54.555  1
676690  95.580  -52.968  54.559  1
676691  95.615  -52.990  54.562  1
676692  95.648  -53.013  54.563  1
676693  95.664  -53.035  54.561  1
676694  95.679  -53.059  54.550  1
676695  95.695  -53.082  54.531  1
676696  95.711  -53.104  54.509  1
676697  95.727  -53.128  54.482  1
676698  95.742  -53.151  54.453  1
676699  95.758  -53.174  54.424  1
676700  95.774  -53.197  54.396  1
676701  95.795  -53.214  54.365  1
676702  95.816  -53.230  54.331  1
676703  95.838  -53.247  54.297  1
676704  95.859  -53.264  54.269  1
676705  95.880  -53.280  54.246  1
676706  95.902  -53.297  54.223  1
676707  95.923  -53.314  54.199  1
676708  95.944  -53.330  54.172  1
676709  95.957  -53.341  54.141  1
676710  95.963  -53.347  54.100  1
676711  95.968  -53.352  54.066  1
676712  95.974  -53.358  54.035  1
676713  95.979  -53.364  54.009  1
676714  95.985  -53.370  53.988  1
676715  95.991  -53.376  53.972  1
676716  95.996  -53.381  53.959  1
676717  96.002  -53.387  53.943  1
676718  96.008  -53.393  53.921  1
676719  96.014  -53.399  53.895  1
676720  96.018  -53.405  53.865  1
676721  96.027  -53.411  53.828  1
676722  96.037  -53.415  53.788  1
676723  96.047  -53.418  53.747  1
676724  96.057  -53.423  53.712  1
676725  96.067  -53.427  53.680  1
676726  96.077  -53.430  53.650  1
676727  96.087  -53.435  53.622  1
676728  96.097  -53.439  53.598  1
676729  96.107  -53.443  53.575  1
676730  96.135  -53.446  53.552  1
676731  96.178  -53.447  53.532  1
676732  96.211  -53.451  53.512  1
676733  96.244  -53.455  53.490  1
676734  96.276  -53.459  53.468  1
676735  96.309  -53.463  53.448  1
676736  96.341  -53.467  53.429  1
676737  96.374  -53.471  53.411  1
676738  96.406  -53.475  53.395  1
676739  96.439  -53.479  53.378  1
676740  96.472  -53.483  53.362  1
676741  96.504  -53.487  53.350  1
676742  96.530  -53.494  53.335  1
676743  96.552  -53.505  53.315  1
676744  96.573  -53.515  53.291  1
676745  96.594  -53.525  53.265  1
676746  96.615  -53.536  53.243  1
676747  96.637  -53.546  53.221  1
676748  96.674  -53.550  53.196  1
676749  96.716  -53.552  53.169  1
676750  96.758  -53.553  53.141  1
676751  96.800  -53.553  53.116  1
676752  96.841  -53.554  53.087  1
676753  96.883  -53.555  53.055  1
676754  96.925  -53.556  53.020  1
676755  96.965  -53.556  52.987  1
676756  96.998  -53.562  52.955  1
676757  97.023  -53.574  52.924  1
676758  97.047  -53.585  52.894  1
676759  97.072  -53.596  52.862  1
676760  97.097  -53.608  52.828  1
676761  97.121  -53.620  52.793  1
676762  97.146  -53.631  52.756  1
676763  97.171  -53.643  52.721  1
676764  97.195  -53.654  52.687  1
676765  97.220  -53.666  52.654  1
676766  97.245  -53.676  52.620  1
676767  97.271  -53.686  52.586  1
676768  97.297  -53.697  52.549  1
676769  97.322  -53.706  52.510  1
676770  97.348  -53.716  52.470  1
676771  97.373  -53.727  52.430  1
676772  97.397  -53.737  52.391  1
676773  97.419  -53.747  52.352  1
676774  97.441  -53.757  52.311  1
676775  97.469  -53.763  52.271  1
676776  97.497  -53.769  52.229  1
676777  97.525  -53.775  52.187  1
676778  97.553  -53.780  52.147  1
676779  97.581  -53.785  52.109  1
676780  97.608  -53.789  52.072  1
676781  97.635  -53.791  52.037  1
676782  97.662  -53.793  52.003  1
676783  97.688  -53.795  51.967  1
676784  97.715  -53.797  51.930  1
676785  97.741  -53.800  51.891  1
676786  97.768  -53.802  51.851  1
676787  97.795  -53.804  51.813  1
676788  97.821  -53.806  51.776  1
676789  97.839  -53.814  51.740  1
676790  97.855  -53.822  51.703  1
676791  97.870  -53.830  51.665  1
676792  97.886  -53.838  51.627  1
676793  97.901  -53.846  51.589  1
676794  97.917  -53.854  51.549  1
676795  97.934  -53.859  51.510  1
676796  97.952  -53.862  51.469  1
676797  97.969  -53.865  51.430  1
676798  97.987  -53.868  51.389  1
676799  98.005  -53.871  51.348  1
676800  98.023  -53.875  51.306  1
676801  98.042  -53.882  51.262  1
676802  98.075  -53.891  51.215  1
676803  98.107  -53.899  51.167  1
676804  98.140  -53.908  51.117  1
676805  98.172  -53.916  51.069  1
676806  98.205  -53.925  51.021  1
676807  98.221  -53.940  50.973  1
676808  98.247  -53.959  50.926  1
676809  98.272  -53.977  50.879  1
676810  98.298  -53.996  50.831  1
676811  98.323  -54.014  50.783  1
676812  98.349  -54.032  50.735  1
676813  98.374  -54.051  50.688  1
676814  98.400  -54.070  50.641  1
677301  93.095  -51.254  56.472  4
677302  93.127  -51.271  56.464  4
677303  93.157  -51.289  56.456  4
677304  93.189  -51.307  56.447  4
677305  93.219  -51.324  56.437  4
677306  93.251  -51.342  56.425  4
677307  93.281  -51.359  56.412  4
677308  93.312  -51.377  56.399  4
677309  93.343  -51.394  56.385  4
677310  93.374  -51.412  56.371  4
677311  93.405  -51.429  56.355  4
677312  93.436  -51.446  56.337  4
677313  93.467  -51.464  56.320  4
677314  93.498  -51.481  56.300  4
677315  93.529  -51.499  56.281  4
677316  93.560  -51.516  56.260  4
677317  93.591  -51.534  56.238  4
677318  93.622  -51.552  56.215  4
677319  93.651  -51.569  56.192  4
677320  93.679  -51.588  56.164  4
677321  93.705  -51.606  56.134  4
677322  93.732  -51.625  56.101  4
677323  93.759  -51.644  56.068  4
677324  93.785  -51.663  56.033  4
677325  93.812  -51.682  55.998  4
677326  93.839  -51.701  55.961  4
677327  93.866  -51.720  55.923  4
677328  93.893  -51.739  55.885  4
677329  93.919  -51.758  55.847  4
677330  93.946  -51.778  55.808  4
677331  93.973  -51.797  55.771  4
677332  93.999  -51.816  55.733  4
677377  95.202  -52.672  54.633  1
677378  95.229  -52.691  54.622  1
677379  95.256  -52.711  54.611  1
677380  95.282  -52.730  54.602  1
677381  95.309  -52.749  54.593  1
677382  95.336  -52.768  54.584  1
677383  95.362  -52.787  54.576  1
677384  95.389  -52.806  54.568  1
677385  95.416  -52.825  54.561  1
677386  95.443  -52.844  54.556  1
677387  95.469  -52.863  54.551  1
677388  95.496  -52.882  54.547  1
677389  95.526  -52.902  54.542  1
677390  95.561  -52.925  54.542  1
677391  95.596  -52.948  54.545  1
677392  95.631  -52.970  54.547  1
677393  95.665  -52.992  54.547  1
677394  95.680  -53.015  54.544  1
677395  95.696  -53.038  54.534  1
677396  95.711  -53.061  54.516  1
677397  95.727  -53.084  54.494  1
677398  95.743  -53.107  54.471  1
677399  95.759  -53.130  54.440  1
677400  95.774  -53.153  54.408  1
677401  95.790  -53.176  54.378  1
677402  95.808  -53.198  54.348  1
677403  95.829  -53.214  54.314  1
677404  95.850  -53.231  54.279  1
677405  95.872  -53.248  54.249  1
677406  95.893  -53.264  54.222  1
677407  95.914  -53.281  54.197  1
677408  95.936  -53.298  54.173  1
677409  95.955  -53.313  54.146  1
677410  95.960  -53.319  54.115  1
677411  95.966  -53.324  54.080  1
677412  95.972  -53.330  54.046  1
677413  95.977  -53.336  54.016  1
677414  95.983  -53.342  53.989  1
677415  95.989  -53.348  53.968  1
677416  95.994  -53.353  53.951  1
677417  96.000  -53.359  53.940  1
677418  96.006  -53.365  53.923  1
677419  96.012  -53.371  53.901  1
677420  96.020  -53.378  53.877  1
677421  96.029  -53.386  53.846  1
677422  96.039  -53.389  53.809  1
677423  96.049  -53.393  53.768  1
677424  96.059  -53.396  53.727  1
677425  96.070  -53.400  53.692  1
677426  96.080  -53.404  53.660  1
677427  96.090  -53.408  53.630  1
677428  96.100  -53.411  53.602  1
677429  96.111  -53.415  53.577  1
677430  96.121  -53.418  53.554  1
677431  96.136  -53.422  53.531  1
677432  96.164  -53.424  53.510  1
677433  96.192  -53.426  53.490  1
677434  96.225  -53.430  53.468  1
677435  96.257  -53.433  53.447  1
677436  96.290  -53.437  53.427  1
677437  96.322  -53.441  53.409  1
677438  96.355  -53.445  53.390  1
677439  96.387  -53.449  53.375  1
677440  96.420  -53.452  53.357  1
677441  96.452  -53.456  53.341  1
677442  96.485  -53.459  53.327  1
677443  96.517  -53.463  53.311  1
677444  96.550  -53.467  53.292  1
677445  96.574  -53.476  53.270  1
677446  96.595  -53.487  53.247  1
677447  96.616  -53.497  53.225  1
677448  96.638  -53.507  53.205  1
677449  96.671  -53.512  53.183  1
677450  96.714  -53.514  53.156  1
677451  96.756  -53.515  53.127  1
677452  96.798  -53.517  53.100  1
677453  96.841  -53.518  53.071  1
677454  96.883  -53.520  53.040  1
677455  96.926  -53.521  53.007  1
677456  96.965  -53.526  52.976  1
677457  96.999  -53.534  52.944  1
677458  97.030  -53.544  52.912  1
677459  97.055  -53.556  52.881  1
677460  97.080  -53.567  52.849  1
677461  97.104  -53.578  52.816  1
677462  97.129  -53.590  52.782  1
677463  97.154  -53.602  52.748  1
677464  97.178  -53.613  52.714  1
677465  97.203  -53.625  52.681  1
677466  97.228  -53.636  52.649  1
677467  97.252  -53.647  52.616  1
677468  97.278  -53.657  52.584  1
677469  97.304  -53.668  52.548  1
677470  97.329  -53.678  52.511  1
677471  97.355  -53.687  52.471  1
677472  97.379  -53.698  52.433  1
677473  97.401  -53.709  52.396  1
677474  97.423  -53.719  52.358  1
677475  97.445  -53.728  52.318  1
677476  97.473  -53.734  52.277  1
677477  97.501  -53.740  52.235  1
677478  97.529  -53.746  52.193  1
677479  97.558  -53.751  52.154  1
677480  97.585  -53.757  52.116  1
677481  97.613  -53.762  52.079  1
677482  97.642  -53.768  52.045  1
677483  97.668  -53.770  52.010  1
677484  97.695  -53.772  51.975  1
677485  97.721  -53.775  51.938  1
677486  97.748  -53.777  51.900  1
677487  97.775  -53.779  51.860  1
677488  97.801  -53.781  51.822  1
677489  97.828  -53.784  51.788  1
677490  97.847  -53.790  51.752  1
677491  97.863  -53.798  51.717  1
677492  97.878  -53.806  51.680  1
677493  97.894  -53.814  51.643  1
677494  97.910  -53.822  51.605  1
677495  97.926  -53.830  51.567  1
677496  97.941  -53.838  51.529  1
677497  97.959  -53.841  51.490  1
677498  97.977  -53.844  51.450  1
677499  97.994  -53.847  51.410  1
677500  98.012  -53.854  51.370  1
677501  98.030  -53.860  51.328  1
677502  98.048  -53.867  51.285  1
677503  98.076  -53.875  51.240  1
677504  98.108  -53.884  51.192  1
677505  98.141  -53.893  51.144  1
677506  98.173  -53.901  51.095  1
677507  98.206  -53.910  51.048  1
677508  98.225  -53.924  51.000  1
677509  98.248  -53.941  50.953  1
677510  98.274  -53.960  50.907  1
677511  98.299  -53.978  50.860  1
677512  98.324  -53.997  50.813  1
677513  98.350  -54.015  50.766  1
677514  98.375  -54.033  50.720  1
677515  98.401  -54.052  50.674  1
677516  98.426  -54.070  50.630  1
678003  93.144  -51.247  56.457  4
678004  93.174  -51.265  56.449  4
678005  93.206  -51.283  56.441  4
678006  93.236  -51.300  56.431  4
678007  93.268  -51.318  56.417  4
678008  93.298  -51.335  56.405  4
678009  93.330  -51.352  56.393  4
678010  93.360  -51.370  56.379  4
678011  93.392  -51.387  56.364  4
678012  93.422  -51.405  56.349  4
678013  93.453  -51.422  56.331  4
678014  93.484  -51.440  56.313  4
678015  93.515  -51.457  56.294  4
678016  93.546  -51.475  56.275  4
678017  93.577  -51.492  56.253  4
678018  93.608  -51.509  56.231  4
678019  93.639  -51.528  56.207  4
678020  93.670  -51.545  56.182  4
678021  93.698  -51.564  56.153  4
678022  93.725  -51.584  56.123  4
678023  93.752  -51.603  56.091  4
678024  93.779  -51.623  56.057  4
678025  93.805  -51.643  56.023  4
678026  93.833  -51.663  55.988  4
678027  93.859  -51.682  55.952  4
678028  93.887  -51.702  55.914  4
678029  93.913  -51.721  55.876  4
678030  93.940  -51.740  55.839  4
678031  93.967  -51.759  55.802  4
678032  93.993  -51.778  55.765  4
678033  94.020  -51.797  55.727  4
678079  95.250  -52.673  54.617  1
678080  95.276  -52.692  54.606  1
678081  95.303  -52.711  54.596  1
678082  95.330  -52.730  54.587  1
678083  95.356  -52.749  54.577  1
678084  95.383  -52.768  54.569  1
678085  95.410  -52.787  54.560  1
678086  95.437  -52.807  54.552  1
678087  95.463  -52.825  54.545  1
678088  95.490  -52.844  54.539  1
678089  95.517  -52.863  54.532  1
678090  95.544  -52.882  54.528  1
678091  95.578  -52.904  54.528  1
678092  95.612  -52.927  54.531  1
678093  95.647  -52.949  54.531  1
678094  95.681  -52.972  54.531  1
678095  95.696  -52.995  54.526  1
678096  95.712  -53.017  54.515  1
678097  95.728  -53.041  54.497  1
678098  95.744  -53.064  54.475  1
678099  95.759  -53.087  54.453  1
678100  95.775  -53.110  54.423  1
678101  95.791  -53.132  54.389  1
678102  95.807  -53.156  54.357  1
678103  95.822  -53.179  54.327  1
678104  95.841  -53.198  54.293  1
678105  95.863  -53.214  54.258  1
678106  95.884  -53.232  54.228  1
678107  95.905  -53.248  54.200  1
678108  95.926  -53.265  54.173  1
678109  95.948  -53.282  54.146  1
678110  95.958  -53.291  54.118  1
678111  95.964  -53.296  54.088  1
678112  95.970  -53.302  54.055  1
678113  95.975  -53.308  54.023  1
678114  95.981  -53.314  53.995  1
678115  95.986  -53.320  53.970  1
678116  95.992  -53.325  53.948  1
678117  95.998  -53.331  53.930  1
678118  96.004  -53.337  53.917  1
678119  96.013  -53.346  53.899  1
678120  96.022  -53.353  53.878  1
678121  96.031  -53.361  53.854  1
678122  96.040  -53.369  53.823  1
678123  96.050  -53.373  53.785  1
678124  96.060  -53.377  53.744  1
678125  96.071  -53.380  53.705  1
678126  96.081  -53.383  53.670  1
678127  96.091  -53.387  53.638  1
678128  96.101  -53.391  53.610  1
678129  96.111  -53.395  53.582  1
678130  96.121  -53.399  53.557  1
678131  96.132  -53.402  53.533  1
678132  96.148  -53.405  53.510  1
678133  96.175  -53.407  53.489  1
678134  96.203  -53.409  53.469  1
678135  96.231  -53.411  53.447  1
678136  96.258  -53.414  53.426  1
678137  96.286  -53.415  53.407  1
678138  96.313  -53.418  53.388  1
678139  96.341  -53.420  53.370  1
678140  96.369  -53.421  53.354  1
678141  96.400  -53.425  53.336  1
678142  96.433  -53.429  53.319  1
678143  96.465  -53.433  53.304  1
678144  96.498  -53.437  53.287  1
678145  96.531  -53.440  53.269  1
678146  96.563  -53.444  53.250  1
678147  96.596  -53.448  53.228  1
678148  96.618  -53.458  53.207  1
678149  96.639  -53.468  53.188  1
678150  96.668  -53.475  53.167  1
678151  96.711  -53.477  53.141  1
678152  96.753  -53.478  53.112  1
678153  96.796  -53.480  53.084  1
678154  96.838  -53.481  53.056  1
678155  96.872  -53.490  53.025  1
678156  96.906  -53.498  52.994  1
678157  96.941  -53.506  52.962  1
678158  96.975  -53.515  52.931  1
678159  97.009  -53.524  52.899  1
678160  97.043  -53.532  52.867  1
678161  97.077  -53.540  52.836  1
678162  97.111  -53.549  52.804  1
678163  97.137  -53.560  52.773  1
678164  97.161  -53.571  52.740  1
678165  97.186  -53.584  52.707  1
678166  97.211  -53.595  52.675  1
678167  97.235  -53.606  52.643  1
678168  97.260  -53.618  52.613  1
678169  97.285  -53.628  52.580  1
678170  97.310  -53.639  52.547  1
678171  97.336  -53.649  52.510  1
678172  97.362  -53.659  52.473  1
678173  97.383  -53.669  52.437  1
678174  97.405  -53.680  52.402  1
678175  97.427  -53.690  52.366  1
678176  97.449  -53.700  52.324  1
678177  97.477  -53.706  52.283  1
678178  97.505  -53.711  52.241  1
678179  97.533  -53.717  52.199  1
678180  97.562  -53.722  52.160  1
678181  97.590  -53.728  52.123  1
678182  97.618  -53.734  52.086  1
678183  97.646  -53.740  52.051  1
678184  97.674  -53.745  52.016  1
678185  97.701  -53.749  51.981  1
678186  97.728  -53.751  51.945  1
678187  97.754  -53.753  51.907  1
678188  97.781  -53.756  51.868  1
678189  97.808  -53.758  51.832  1
678190  97.835  -53.760  51.798  1
678191  97.855  -53.766  51.764  1
678192  97.871  -53.774  51.730  1
678193  97.887  -53.781  51.694  1
678194  97.902  -53.790  51.658  1
678195  97.918  -53.798  51.621  1
678196  97.934  -53.806  51.584  1
678197  97.950  -53.814  51.547  1
678198  97.965  -53.822  51.510  1
678199  97.984  -53.827  51.470  1
678200  98.002  -53.833  51.430  1
678201  98.019  -53.840  51.390  1
678202  98.037  -53.847  51.349  1
678203  98.056  -53.853  51.307  1
678204  98.077  -53.860  51.262  1
678205  98.109  -53.869  51.216  1
678206  98.142  -53.878  51.169  1
678207  98.174  -53.887  51.122  1
678208  98.207  -53.895  51.074  1
678209  98.230  -53.907  51.027  1
678210  98.250  -53.923  50.981  1
678211  98.276  -53.942  50.935  1
678212  98.301  -53.960  50.890  1
678213  98.326  -53.979  50.843  1
678214  98.352  -53.997  50.797  1
678215  98.377  -54.016  50.751  1
678216  98.403  -54.035  50.706  1
678217  98.428  -54.053  50.662  1
678705  93.192  -51.240  56.442  4
678706  93.222  -51.258  56.433  4
678707  93.254  -51.276  56.423  4
678708  93.284  -51.293  56.411  4
678709  93.315  -51.311  56.398  4
678710  93.346  -51.328  56.385  4
678711  93.377  -51.346  56.372  4
678712  93.408  -51.363  56.357  4
678713  93.439  -51.381  56.342  4
678714  93.470  -51.398  56.325  4
678715  93.501  -51.415  56.307  4
678716  93.532  -51.433  56.288  4
678717  93.563  -51.450  56.268  4
678718  93.594  -51.468  56.247  4
678719  93.625  -51.485  56.224  4
678720  93.656  -51.503  56.199  4
678721  93.687  -51.521  56.172  4
678722  93.717  -51.538  56.143  4
678723  93.744  -51.559  56.112  4
678724  93.771  -51.578  56.080  4
678725  93.797  -51.598  56.047  4
678726  93.825  -51.618  56.013  4
678727  93.851  -51.638  55.978  4
678728  93.878  -51.657  55.942  4
678729  93.905  -51.677  55.904  4
678730  93.932  -51.697  55.867  4
678731  93.959  -51.716  55.830  4
678732  93.986  -51.736  55.794  4
678733  94.013  -51.756  55.757  4
678780  95.270  -52.654  54.613  1
678781  95.297  -52.673  54.602  1
678782  95.324  -52.692  54.591  1
678783  95.350  -52.711  54.581  1
678784  95.377  -52.731  54.570  1
678785  95.404  -52.750  54.562  1
678786  95.430  -52.769  54.552  1
678787  95.457  -52.788  54.543  1
678788  95.484  -52.807  54.535  1
678789  95.511  -52.825  54.527  1
678790  95.538  -52.844  54.520  1
678791  95.564  -52.863  54.514  1
678792  95.594  -52.884  54.512  1
678793  95.628  -52.906  54.514  1
678794  95.663  -52.929  54.515  1
678795  95.697  -52.951  54.513  1
678796  95.713  -52.974  54.507  1
678797  95.729  -52.997  54.493  1
678798  95.744  -53.020  54.474  1
678799  95.760  -53.043  54.454  1
678800  95.776  -53.066  54.432  1
678801  95.792  -53.089  54.403  1
678802  95.807  -53.112  54.370  1
678803  95.823  -53.136  54.336  1
678804  95.838  -53.158  54.306  1
678805  95.854  -53.181  54.271  1
678806  95.875  -53.198  54.237  1
678807  95.896  -53.215  54.207  1
678808  95.917  -53.232  54.178  1
678809  95.939  -53.248  54.149  1
678810  95.956  -53.263  54.121  1
678811  95.962  -53.268  54.093  1
678812  95.967  -53.274  54.062  1
678813  95.973  -53.280  54.031  1
678814  95.979  -53.286  54.002  1
678815  95.984  -53.292  53.975  1
678816  95.990  -53.297  53.949  1
678817  95.997  -53.305  53.926  1
678818  96.007  -53.312  53.907  1
678819  96.016  -53.321  53.890  1
678820  96.024  -53.328  53.870  1
678821  96.033  -53.336  53.847  1
678822  96.042  -53.344  53.821  1
678823  96.051  -53.352  53.790  1
678824  96.061  -53.356  53.754  1
678825  96.071  -53.360  53.715  1
678826  96.082  -53.364  53.679  1
678827  96.092  -53.367  53.647  1
678828  96.102  -53.371  53.616  1
678829  96.112  -53.374  53.588  1
678830  96.122  -53.378  53.562  1
678831  96.132  -53.382  53.536  1
678832  96.143  -53.386  53.512  1
678833  96.159  -53.389  53.490  1
678834  96.187  -53.390  53.469  1
678835  96.215  -53.393  53.448  1
678836  96.242  -53.395  53.427  1
678837  96.269  -53.397  53.406  1
678838  96.297  -53.399  53.385  1
678839  96.325  -53.401  53.366  1
678840  96.353  -53.403  53.349  1
678841  96.380  -53.405  53.332  1
678842  96.407  -53.407  53.315  1
678843  96.435  -53.409  53.297  1
678844  96.463  -53.411  53.281  1
678845  96.490  -53.413  53.264  1
678846  96.518  -53.415  53.247  1
678847  96.546  -53.418  53.229  1
678848  96.577  -53.421  53.209  1
678849  96.609  -53.424  53.189  1
678850  96.640  -53.429  53.171  1
678851  96.666  -53.437  53.149  1
678852  96.708  -53.439  53.125  1
678853  96.745  -53.445  53.098  1
678854  96.780  -53.453  53.069  1
678855  96.814  -53.462  53.041  1
678856  96.848  -53.470  53.012  1
678857  96.882  -53.479  52.981  1
678858  96.916  -53.487  52.950  1
678859  96.950  -53.496  52.920  1
678860  96.984  -53.504  52.889  1
678861  97.019  -53.512  52.857  1
678862  97.053  -53.521  52.826  1
678863  97.087  -53.529  52.795  1
678864  97.121  -53.538  52.765  1
678865  97.156  -53.546  52.733  1
678866  97.190  -53.555  52.701  1
678867  97.218  -53.565  52.669  1
678868  97.243  -53.577  52.639  1
678869  97.267  -53.588  52.608  1
678870  97.292  -53.599  52.577  1
678871  97.317  -53.610  52.544  1
678872  97.343  -53.620  52.508  1
678873  97.366  -53.631  52.473  1
678874  97.387  -53.641  52.439  1
678875  97.409  -53.651  52.406  1
678876  97.431  -53.662  52.371  1
678877  97.453  -53.672  52.330  1
678878  97.481  -53.677  52.288  1
678879  97.510  -53.683  52.246  1
678880  97.538  -53.688  52.205  1
678881  97.566  -53.694  52.165  1
678882  97.594  -53.700  52.129  1
678883  97.622  -53.706  52.093  1
678884  97.650  -53.711  52.056  1
678885  97.678  -53.717  52.019  1
678886  97.706  -53.722  51.984  1
678887  97.734  -53.728  51.949  1
678888  97.761  -53.731  51.912  1
678889  97.788  -53.733  51.875  1
678890  97.814  -53.735  51.840  1
678891  97.841  -53.737  51.806  1
678892  97.864  -53.741  51.774  1
678893  97.879  -53.750  51.741  1
678894  97.895  -53.758  51.707  1
678895  97.911  -53.766  51.673  1
678896  97.927  -53.774  51.638  1
678897  97.942  -53.781  51.602  1
678898  97.956  -53.791  51.565  1
678899  97.969  -53.801  51.529  1
678900  97.991  -53.813  51.490  1
678901  98.009  -53.819  51.450  1
678902  98.027  -53.826  51.410  1
678903  98.045  -53.832  51.369  1
678904  98.063  -53.839  51.327  1
678905  98.081  -53.846  51.283  1
678906  98.110  -53.854  51.239  1
678907  98.143  -53.863  51.194  1
678908  98.175  -53.872  51.148  1
678909  98.208  -53.880  51.101  1
678910  98.235  -53.891  51.054  1
678911  98.252  -53.906  51.009  1
678912  98.277  -53.925  50.963  1
678913  98.303  -53.943  50.919  1
678914  98.328  -53.961  50.873  1
678915  98.354  -53.980  50.828  1
678916  98.379  -53.998  50.783  1
678917  98.405  -54.016  50.739  1
678918  98.430  -54.035  50.695  1
679408  93.271  -51.252  56.416  4
679409  93.301  -51.269  56.403  4
679410  93.333  -51.287  56.391  4
679411  93.363  -51.304  56.378  4
679412  93.395  -51.321  56.365  4
679413  93.425  -51.339  56.350  4
679414  93.457  -51.356  56.335  4
679415  93.487  -51.374  56.318  4
679416  93.518  -51.391  56.300  4
679417  93.549  -51.409  56.281  4
679418  93.580  -51.426  56.260  4
679419  93.611  -51.443  56.238  4
679420  93.642  -51.461  56.215  4
679421  93.673  -51.478  56.189  4
679422  93.704  -51.497  56.163  4
679423  93.735  -51.514  56.133  4
679424  93.763  -51.533  56.102  4
679425  93.789  -51.553  56.070  4
679426  93.817  -51.572  56.036  4
679427  93.843  -51.592  56.002  4
679428  93.870  -51.612  55.968  4
679429  93.897  -51.631  55.932  4
679430  93.924  -51.651  55.894  4
679431  93.951  -51.672  55.857  4
679432  93.978  -51.691  55.821  4
679433  94.005  -51.711  55.785  4
679434  94.032  -51.731  55.749  4
679481  95.291  -52.635  54.609  1
679482  95.318  -52.654  54.597  1
679483  95.344  -52.674  54.586  1
679484  95.371  -52.693  54.575  1
679485  95.398  -52.712  54.564  1
679486  95.424  -52.731  54.554  1
679487  95.451  -52.750  54.544  1
679488  95.478  -52.769  54.534  1
679489  95.505  -52.788  54.525  1
679490  95.531  -52.807  54.517  1
679491  95.558  -52.826  54.509  1
679492  95.585  -52.845  54.501  1
679493  95.612  -52.864  54.497  1
679494  95.644  -52.885  54.497  1
679495  95.680  -52.908  54.497  1
679496  95.713  -52.930  54.495  1
679497  95.729  -52.954  54.487  1
679498  95.745  -52.976  54.472  1
679499  95.761  -53.000  54.452  1
679500  95.776  -53.023  54.434  1
679501  95.792  -53.045  54.411  1
679502  95.808  -53.069  54.383  1
679503  95.823  -53.092  54.351  1
679504  95.839  -53.115  54.318  1
679505  95.855  -53.138  54.287  1
679506  95.871  -53.161  54.251  1
679507  95.887  -53.183  54.217  1
679508  95.909  -53.199  54.186  1
679509  95.930  -53.216  54.157  1
679510  95.951  -53.233  54.127  1
679511  95.960  -53.240  54.098  1
679512  95.965  -53.246  54.069  1
679513  95.971  -53.252  54.039  1
679514  95.977  -53.258  54.010  1
679515  95.982  -53.264  53.982  1
679516  95.991  -53.271  53.955  1
679517  96.000  -53.280  53.928  1
679518  96.009  -53.287  53.904  1
679519  96.018  -53.295  53.883  1
679520  96.027  -53.303  53.861  1
679521  96.036  -53.311  53.839  1
679522  96.044  -53.319  53.814  1
679523  96.053  -53.327  53.787  1
679524  96.062  -53.335  53.756  1
679525  96.072  -53.339  53.722  1
679526  96.082  -53.343  53.687  1
679527  96.093  -53.347  53.654  1
679528  96.103  -53.351  53.624  1
679529  96.113  -53.354  53.595  1
679530  96.123  -53.358  53.568  1
679531  96.133  -53.361  53.541  1
679532  96.144  -53.365  53.516  1
679533  96.154  -53.369  53.492  1
679534  96.171  -53.372  53.470  1
679535  96.198  -53.374  53.448  1
679536  96.226  -53.376  53.428  1
679537  96.253  -53.378  53.406  1
679538  96.281  -53.380  53.385  1
679539  96.309  -53.382  53.366  1
679540  96.336  -53.384  53.346  1
679541  96.364  -53.386  53.328  1
679542  96.391  -53.389  53.313  1
679543  96.419  -53.390  53.294  1
679544  96.447  -53.393  53.277  1
679545  96.474  -53.395  53.260  1
679546  96.502  -53.397  53.244  1
679547  96.530  -53.399  53.227  1
679548  96.557  -53.401  53.210  1
679549  96.585  -53.403  53.191  1
679550  96.612  -53.405  53.171  1
679551  96.640  -53.407  53.152  1
679552  96.666  -53.410  53.132  1
679553  96.696  -53.418  53.109  1
679554  96.729  -53.426  53.083  1
679555  96.762  -53.434  53.055  1
679556  96.796  -53.443  53.027  1
679557  96.829  -53.451  52.999  1
679558  96.862  -53.459  52.969  1
679559  96.895  -53.468  52.940  1
679560  96.928  -53.477  52.910  1
679561  96.961  -53.485  52.879  1
679562  96.995  -53.493  52.849  1
679563  97.029  -53.502  52.818  1
679564  97.063  -53.510  52.788  1
679565  97.097  -53.518  52.758  1
679566  97.131  -53.527  52.727  1
679567  97.165  -53.535  52.696  1
679568  97.199  -53.543  52.664  1
679569  97.234  -53.552  52.634  1
679570  97.268  -53.561  52.603  1
679571  97.300  -53.570  52.573  1
679572  97.324  -53.581  52.540  1
679573  97.348  -53.591  52.506  1
679574  97.370  -53.602  52.472  1
679575  97.391  -53.612  52.439  1
679576  97.413  -53.623  52.407  1
679577  97.435  -53.633  52.373  1
679578  97.458  -53.643  52.334  1
679579  97.486  -53.648  52.291  1
679580  97.514  -53.654  52.249  1
679581  97.542  -53.659  52.208  1
679582  97.570  -53.665  52.170  1
679583  97.598  -53.671  52.133  1
679584  97.626  -53.677  52.096  1
679585  97.654  -53.682  52.059  1
679586  97.682  -53.688  52.023  1
679587  97.711  -53.693  51.987  1
679588  97.739  -53.700  51.952  1
679589  97.767  -53.705  51.916  1
679590  97.794  -53.709  51.881  1
679591  97.821  -53.712  51.847  1
679592  97.848  -53.714  51.814  1
679593  97.872  -53.718  51.783  1
679594  97.887  -53.725  51.752  1
679595  97.903  -53.734  51.719  1
679596  97.919  -53.742  51.686  1
679597  97.934  -53.750  51.651  1
679598  97.946  -53.760  51.616  1
679599  97.959  -53.771  51.581  1
679600  97.971  -53.781  51.546  1
679601  97.996  -53.796  51.508  1
679602  98.016  -53.805  51.469  1
679603  98.034  -53.812  51.430  1
679604  98.052  -53.819  51.388  1
679605  98.070  -53.825  51.347  1
679606  98.088  -53.831  51.305  1
679607  98.111  -53.839  51.263  1
679608  98.144  -53.848  51.219  1
679609  98.176  -53.856  51.174  1
679610  98.209  -53.866  51.127  1
679611  98.240  -53.875  51.080  1
679612  98.255  -53.889  51.035  1
679613  98.279  -53.907  50.991  1
679614  98.304  -53.925  50.947  1
679615  98.330  -53.944  50.902  1
679616  98.355  -53.962  50.858  1
679617  98.381  -53.981  50.814  1
679618  98.406  -53.999  50.770  1
679619  98.432  -54.018  50.728  1
679620  98.457  -54.036  50.686  1
680110  93.319  -51.245  56.395  4
680111  93.349  -51.262  56.382  4
680112  93.380  -51.280  56.370  4
680113  93.411  -51.297  56.358  4
680114  93.442  -51.315  56.343  4
680115  93.473  -51.332  56.327  4
680116  93.504  -51.349  56.310  4
680117  93.535  -51.367  56.292  4
680118  93.566  -51.384  56.273  4
680119  93.597  -51.402  56.252  4
680120  93.628  -51.419  56.229  4
680121  93.659  -51.437  56.205  4
680122  93.690  -51.454  56.180  4
680123  93.721  -51.472  56.152  4
680124  93.752  -51.490  56.122  4
680125  93.781  -51.508  56.091  4
680126  93.808  -51.528  56.058  4
680127  93.835  -51.547  56.025  4
680128  93.862  -51.567  55.991  4
680129  93.889  -51.587  55.957  4
680130  93.916  -51.606  55.921  4
680131  93.943  -51.626  55.884  4
680132  93.970  -51.646  55.847  4
680133  93.997  -51.666  55.811  4
680134  94.024  -51.685  55.776  4
680135  94.051  -51.705  55.741  4
680183  95.338  -52.636  54.592  1
680184  95.365  -52.655  54.580  1
680185  95.392  -52.674  54.569  1
680186  95.418  -52.693  54.557  1
680187  95.445  -52.712  54.547  1
680188  95.472  -52.731  54.536  1
680189  95.498  -52.750  54.526  1
680190  95.525  -52.769  54.516  1
680191  95.552  -52.788  54.507  1
680192  95.579  -52.807  54.497  1
680193  95.606  -52.826  54.489  1
680194  95.632  -52.845  54.483  1
680195  95.661  -52.865  54.480  1
680196  95.696  -52.888  54.479  1
680197  95.730  -52.910  54.476  1
680198  95.746  -52.933  54.467  1
680199  95.761  -52.956  54.451  1
680200  95.777  -52.979  54.431  1
680201  95.793  -53.002  54.412  1
680202  95.809  -53.025  54.391  1
680203  95.824  -53.048  54.365  1
680204  95.840  -53.071  54.334  1
680205  95.855  -53.094  54.299  1
680206  95.871  -53.117  54.267  1
680207  95.887  -53.140  54.231  1
680208  95.903  -53.164  54.197  1
680209  95.921  -53.183  54.166  1
680210  95.943  -53.200  54.136  1
680211  95.958  -53.212  54.106  1
680212  95.963  -53.218  54.077  1
680213  95.969  -53.224  54.049  1
680214  95.976  -53.230  54.019  1
680215  95.985  -53.239  53.990  1
680216  95.993  -53.246  53.962  1
680217  96.003  -53.255  53.934  1
680218  96.011  -53.262  53.907  1
680219  96.020  -53.270  53.882  1
680220  96.029  -53.278  53.858  1
680221  96.038  -53.286  53.832  1
680222  96.047  -53.294  53.806  1
680223  96.055  -53.302  53.779  1
680224  96.064  -53.310  53.751  1
680225  96.074  -53.317  53.721  1
680226  96.083  -53.323  53.690  1
680227  96.093  -53.327  53.659  1
680228  96.103  -53.330  53.630  1
680229  96.114  -53.334  53.600  1
680230  96.124  -53.338  53.573  1
680231  96.134  -53.341  53.547  1
680232  96.145  -53.345  53.521  1
680233  96.155  -53.349  53.495  1
680234  96.165  -53.352  53.472  1
680235  96.182  -53.355  53.450  1
680236  96.209  -53.358  53.428  1
680237  96.237  -53.359  53.407  1
680238  96.265  -53.361  53.385  1
680239  96.293  -53.364  53.365  1
680240  96.320  -53.366  53.345  1
680241  96.348  -53.368  53.326  1
680242  96.375  -53.370  53.308  1
680243  96.403  -53.372  53.292  1
680244  96.431  -53.374  53.274  1
680245  96.458  -53.376  53.256  1
680246  96.486  -53.378  53.240  1
680247  96.514  -53.380  53.224  1
680248  96.541  -53.382  53.207  1
680249  96.569  -53.384  53.190  1
680250  96.596  -53.386  53.172  1
680251  96.624  -53.389  53.153  1
680252  96.652  -53.390  53.134  1
680253  96.676  -53.395  53.114  1
680254  96.697  -53.401  53.091  1
680255  96.728  -53.408  53.067  1
680256  96.761  -53.417  53.041  1
680257  96.795  -53.426  53.014  1
680258  96.828  -53.434  52.986  1
680259  96.861  -53.443  52.958  1
680260  96.894  -53.451  52.929  1
680261  96.927  -53.459  52.901  1
680262  96.960  -53.468  52.871  1
680263  96.994  -53.476  52.841  1
680264  97.027  -53.484  52.811  1
680265  97.060  -53.493  52.781  1
680266  97.093  -53.501  52.752  1
680267  97.126  -53.509  52.722  1
680268  97.160  -53.518  52.691  1
680269  97.193  -53.526  52.660  1
680270  97.226  -53.534  52.629  1
680271  97.259  -53.543  52.598  1
680272  97.293  -53.551  52.568  1
680273  97.326  -53.559  52.536  1
680274  97.353  -53.568  52.504  1
680275  97.374  -53.575  52.471  1
680276  97.395  -53.584  52.438  1
680277  97.417  -53.594  52.406  1
680278  97.439  -53.605  52.374  1
680279  97.462  -53.614  52.335  1
680280  97.490  -53.619  52.293  1
680281  97.518  -53.625  52.252  1
680282  97.546  -53.631  52.211  1
680283  97.574  -53.637  52.173  1
680284  97.602  -53.642  52.136  1
680285  97.631  -53.648  52.098  1
680286  97.659  -53.653  52.062  1
680287  97.686  -53.659  52.026  1
680288  97.715  -53.665  51.990  1
680289  97.743  -53.671  51.955  1
680290  97.771  -53.676  51.920  1
680291  97.799  -53.682  51.886  1
680292  97.827  -53.687  51.853  1
680293  97.854  -53.691  51.822  1
680294  97.880  -53.693  51.792  1
680295  97.896  -53.702  51.761  1
680296  97.912  -53.709  51.730  1
680297  97.924  -53.720  51.697  1
680298  97.936  -53.730  51.664  1
680299  97.949  -53.740  51.629  1
680300  97.961  -53.751  51.596  1
680301  97.973  -53.761  51.561  1
680302  97.998  -53.776  51.525  1
680303  98.023  -53.791  51.486  1
680304  98.041  -53.797  51.447  1
680305  98.060  -53.804  51.407  1
680306  98.078  -53.811  51.367  1
680307  98.096  -53.818  51.327  1
680308  98.113  -53.824  51.286  1
680309  98.145  -53.833  51.243  1
680310  98.177  -53.841  51.198  1
680311  98.210  -53.850  51.152  1
680312  98.242  -53.859  51.105  1
680313  98.260  -53.872  51.061  1
680314  98.281  -53.889  51.018  1
680315  98.306  -53.908  50.974  1
680316  98.332  -53.926  50.931  1
680317  98.357  -53.944  50.888  1
680318  98.382  -53.963  50.846  1
680319  98.408  -53.982  50.802  1
680320  98.433  -54.000  50.761  1
680321  98.458  -54.019  50.720  1
680322  98.484  -54.037  50.679  1
680323  98.509  -54.055  50.639  1
680812  93.366  -51.238  56.374  4
680813  93.398  -51.255  56.362  4
680814  93.428  -51.273  56.349  4
680815  93.460  -51.290  56.335  4
680816  93.490  -51.308  56.319  4
680817  93.521  -51.325  56.301  4
680818  93.552  -51.343  56.283  4
680819  93.583  -51.360  56.264  4
680820  93.614  -51.378  56.243  4
680821  93.645  -51.395  56.219  4
680822  93.676  -51.412  56.195  4
680823  93.707  -51.430  56.170  4
680824  93.738  -51.448  56.141  4
680825  93.769  -51.465  56.111  4
680826  93.800  -51.483  56.080  4
680827  93.827  -51.503  56.047  4
680828  93.854  -51.522  56.014  4
680829  93.881  -51.542  55.980  4
680830  93.908  -51.562  55.946  4
680831  93.935  -51.581  55.910  4
680832  93.962  -51.601  55.874  4
680833  93.989  -51.621  55.837  4
680834  94.015  -51.641  55.801  4
680835  94.043  -51.660  55.766  4
680885  95.386  -52.636  54.574  1
680886  95.412  -52.655  54.562  1
680887  95.439  -52.674  54.550  1
680888  95.466  -52.694  54.539  1
680889  95.492  -52.713  54.528  1
680890  95.519  -52.731  54.517  1
680891  95.546  -52.750  54.506  1
680892  95.572  -52.769  54.496  1
680893  95.600  -52.788  54.486  1
680894  95.626  -52.807  54.477  1
680895  95.653  -52.826  54.469  1
680896  95.680  -52.846  54.464  1
680897  95.712  -52.867  54.461  1
680898  95.746  -52.889  54.456  1
680899  95.762  -52.913  54.447  1
680900  95.778  -52.935  54.430  1
680901  95.794  -52.958  54.410  1
680902  95.809  -52.982  54.390  1
680903  95.825  -53.004  54.371  1
680904  95.840  -53.028  54.348  1
680905  95.856  -53.051  54.317  1
680906  95.872  -53.073  54.280  1
680907  95.888  -53.097  54.246  1
680908  95.903  -53.120  54.211  1
680909  95.919  -53.142  54.178  1
680910  95.935  -53.166  54.146  1
680911  95.955  -53.184  54.116  1
680912  95.961  -53.190  54.086  1
680913  95.969  -53.198  54.057  1
680914  95.978  -53.205  54.029  1
680915  95.987  -53.214  54.000  1
680916  95.996  -53.221  53.971  1
680917  96.005  -53.230  53.942  1
680918  96.014  -53.237  53.914  1
680919  96.023  -53.245  53.887  1
680920  96.031  -53.253  53.861  1
680921  96.040  -53.261  53.835  1
680922  96.049  -53.269  53.808  1
680923  96.058  -53.277  53.780  1
680924  96.067  -53.285  53.752  1
680925  96.076  -53.292  53.724  1
680926  96.085  -53.300  53.695  1
680927  96.094  -53.306  53.666  1
680928  96.104  -53.310  53.636  1
680929  96.114  -53.314  53.607  1
680930  96.125  -53.317  53.578  1
680931  96.135  -53.321  53.552  1
680932  96.145  -53.324  53.526  1
680933  96.156  -53.328  53.500  1
680934  96.166  -53.332  53.475  1
680935  96.176  -53.336  53.450  1
680936  96.193  -53.339  53.429  1
680937  96.221  -53.341  53.408  1
680938  96.249  -53.342  53.387  1
680939  96.276  -53.345  53.365  1
680940  96.304  -53.347  53.344  1
680941  96.332  -53.349  53.325  1
680942  96.359  -53.351  53.305  1
680943  96.387  -53.353  53.287  1
680944  96.414  -53.355  53.270  1
680945  96.442  -53.358  53.253  1
680946  96.470  -53.359  53.236  1
680947  96.498  -53.361  53.219  1
680948  96.525  -53.364  53.203  1
680949  96.552  -53.365  53.187  1
680950  96.580  -53.368  53.171  1
680951  96.608  -53.370  53.154  1
680952  96.636  -53.372  53.134  1
680953  96.663  -53.374  53.116  1
680954  96.685  -53.380  53.096  1
680955  96.707  -53.386  53.074  1
680956  96.729  -53.392  53.051  1
680957  96.760  -53.400  53.027  1
680958  96.794  -53.408  53.001  1
680959  96.827  -53.417  52.973  1
680960  96.860  -53.425  52.946  1
680961  96.893  -53.433  52.918  1
680962  96.926  -53.442  52.890  1
680963  96.959  -53.450  52.861  1
680964  96.993  -53.458  52.832  1
680965  97.026  -53.467  52.803  1
680966  97.059  -53.475  52.774  1
680967  97.092  -53.483  52.745  1
680968  97.125  -53.492  52.716  1
680969  97.159  -53.500  52.686  1
680970  97.192  -53.509  52.655  1
680971  97.225  -53.517  52.625  1
680972  97.258  -53.525  52.594  1
680973  97.292  -53.534  52.564  1
680974  97.325  -53.542  52.532  1
680975  97.361  -53.549  52.500  1
680976  97.380  -53.558  52.467  1
680977  97.401  -53.565  52.434  1
680978  97.422  -53.573  52.402  1
680979  97.444  -53.581  52.369  1
680980  97.465  -53.589  52.332  1
680981  97.495  -53.596  52.292  1
680982  97.523  -53.600  52.252  1
680983  97.550  -53.606  52.212  1
680984  97.579  -53.611  52.174  1
680985  97.607  -53.616  52.138  1
680986  97.635  -53.621  52.099  1
680987  97.663  -53.626  52.063  1
680988  97.691  -53.631  52.027  1
680989  97.719  -53.637  51.992  1
680990  97.747  -53.642  51.958  1
680991  97.775  -53.648  51.924  1
680992  97.803  -53.653  51.892  1
680993  97.831  -53.659  51.861  1
680994  97.860  -53.665  51.831  1
680995  97.887  -53.670  51.801  1
680996  97.902  -53.679  51.771  1
680997  97.914  -53.690  51.740  1
680998  97.927  -53.700  51.708  1
680999  97.939  -53.710  51.676  1
681000  97.951  -53.721  51.642  1
681001  97.963  -53.731  51.610  1
681002  97.975  -53.741  51.576  1
681003  98.000  -53.756  51.540  1
681004  98.025  -53.771  51.502  1
681005  98.049  -53.784  51.464  1
681006  98.067  -53.791  51.424  1
681007  98.085  -53.797  51.386  1
681008  98.103  -53.803  51.348  1
681009  98.121  -53.810  51.307  1
681010  98.146  -53.818  51.265  1
681011  98.178  -53.826  51.221  1
681012  98.211  -53.835  51.175  1
681013  98.243  -53.844  51.130  1
681014  98.265  -53.856  51.086  1
681015  98.282  -53.872  51.044  1
681016  98.308  -53.890  51.001  1
681017  98.333  -53.909  50.959  1
681018  98.359  -53.927  50.918  1
681019  98.384  -53.945  50.876  1
681020  98.410  -53.964  50.834  1
681021  98.435  -53.982  50.793  1
681022  98.460  -54.001  50.752  1
681023  98.486  -54.019  50.711  1
681024  98.511  -54.038  50.672  1
681025  98.536  -54.057  50.634  1
681514  93.415  -51.231  56.354  4
681515  93.445  -51.249  56.341  4
681516  93.476  -51.266  56.326  4
681517  93.507  -51.284  56.310  4
681518  93.538  -51.301  56.293  4
681519  93.569  -51.318  56.274  4
681520  93.600  -51.336  56.254  4
681521  93.631  -51.353  56.233  4
681522  93.662  -51.371  56.209  4
681523  93.693  -51.388  56.184  4
681524  93.724  -51.406  56.158  4
681525  93.755  -51.424  56.130  4
681526  93.786  -51.441  56.100  4
681527  93.817  -51.459  56.068  4
681528  93.846  -51.477  56.035  4
681529  93.873  -51.497  56.002  4
681530  93.900  -51.516  55.969  4
681531  93.927  -51.536  55.934  4
681532  93.954  -51.556  55.899  4
681533  93.981  -51.575  55.863  4
681534  94.007  -51.595  55.827  4
681535  94.035  -51.615  55.791  4
681587  95.433  -52.637  54.555  1
681588  95.460  -52.656  54.543  1
681589  95.486  -52.675  54.531  1
681590  95.513  -52.694  54.520  1
681591  95.540  -52.713  54.508  1
681592  95.566  -52.731  54.497  1
681593  95.593  -52.750  54.485  1
681594  95.620  -52.770  54.475  1
681595  95.647  -52.789  54.465  1
681596  95.674  -52.808  54.455  1
681597  95.700  -52.827  54.447  1
681598  95.728  -52.847  54.442  1
681599  95.763  -52.869  54.435  1
681600  95.778  -52.892  54.424  1
681601  95.794  -52.915  54.406  1
681602  95.810  -52.938  54.387  1
681603  95.826  -52.961  54.369  1
681604  95.841  -52.984  54.350  1
681605  95.857  -53.007  54.326  1
681606  95.873  -53.030  54.294  1
681607  95.888  -53.053  54.258  1
681608  95.904  -53.076  54.222  1
681609  95.920  -53.099  54.188  1
681610  95.935  -53.122  54.157  1
681611  95.950  -53.145  54.128  1
681612  95.963  -53.164  54.098  1
681613  95.972  -53.173  54.067  1
681614  95.980  -53.180  54.037  1
681615  95.989  -53.189  54.010  1
681616  95.998  -53.196  53.981  1
681617  96.007  -53.204  53.952  1
681618  96.016  -53.212  53.923  1
681619  96.025  -53.220  53.895  1
681620  96.034  -53.228  53.868  1
681621  96.042  -53.236  53.840  1
681622  96.051  -53.244  53.814  1
681623  96.060  -53.252  53.785  1
681624  96.069  -53.259  53.757  1
681625  96.078  -53.267  53.728  1
681626  96.087  -53.275  53.699  1
681627  96.096  -53.283  53.670  1
681628  96.105  -53.289  53.642  1
681629  96.115  -53.293  53.613  1
681630  96.125  -53.297  53.585  1
681631  96.135  -53.301  53.557  1
681632  96.146  -53.305  53.530  1
681633  96.156  -53.308  53.505  1
681634  96.166  -53.311  53.479  1
681635  96.177  -53.315  53.454  1
681636  96.187  -53.319  53.430  1
681637  96.205  -53.322  53.408  1
681638  96.233  -53.324  53.387  1
681639  96.260  -53.326  53.366  1
681640  96.288  -53.328  53.344  1
681641  96.316  -53.330  53.323  1
681642  96.343  -53.333  53.303  1
681643  96.371  -53.334  53.284  1
681644  96.398  -53.336  53.266  1
681645  96.426  -53.339  53.249  1
681646  96.454  -53.341  53.232  1
681647  96.481  -53.342  53.215  1
681648  96.509  -53.345  53.198  1
681649  96.536  -53.347  53.183  1
681650  96.564  -53.349  53.167  1
681651  96.592  -53.351  53.151  1
681652  96.619  -53.353  53.134  1
681653  96.647  -53.355  53.115  1
681654  96.673  -53.358  53.096  1
681655  96.694  -53.364  53.078  1
681656  96.717  -53.371  53.058  1
681657  96.739  -53.377  53.036  1
681658  96.760  -53.383  53.011  1
681659  96.793  -53.391  52.987  1
681660  96.826  -53.399  52.961  1
681661  96.859  -53.408  52.934  1
681662  96.892  -53.416  52.907  1
681663  96.925  -53.424  52.880  1
681664  96.958  -53.433  52.852  1
681665  96.992  -53.441  52.824  1
681666  97.025  -53.449  52.795  1
681667  97.058  -53.458  52.767  1
681668  97.091  -53.466  52.739  1
681669  97.124  -53.474  52.711  1
681670  97.158  -53.483  52.682  1
681671  97.191  -53.491  52.651  1
681672  97.224  -53.499  52.622  1
681673  97.257  -53.508  52.591  1
681674  97.291  -53.516  52.561  1
681675  97.324  -53.524  52.529  1
681676  97.357  -53.533  52.497  1
681677  97.388  -53.540  52.464  1
681678  97.406  -53.549  52.430  1
681679  97.428  -53.556  52.398  1
681680  97.449  -53.564  52.364  1
681681  97.470  -53.571  52.328  1
681682  97.496  -53.580  52.290  1
681683  97.527  -53.590  52.252  1
681684  97.557  -53.596  52.213  1
681685  97.585  -53.602  52.176  1
681686  97.613  -53.607  52.140  1
681687  97.641  -53.612  52.103  1
681688  97.669  -53.618  52.066  1
681689  97.697  -53.622  52.031  1
681690  97.725  -53.628  51.997  1
681691  97.753  -53.633  51.964  1
681692  97.781  -53.638  51.932  1
681693  97.809  -53.643  51.901  1
681694  97.837  -53.648  51.870  1
681695  97.865  -53.653  51.840  1
681696  97.890  -53.656  51.810  1
681697  97.904  -53.659  51.780  1
681698  97.917  -53.669  51.749  1
681699  97.929  -53.680  51.718  1
681700  97.941  -53.690  51.686  1
681701  97.953  -53.700  51.654  1
681702  97.965  -53.711  51.622  1
681703  97.978  -53.722  51.588  1
681704  98.002  -53.736  51.553  1
681705  98.027  -53.751  51.516  1
681706  98.053  -53.766  51.478  1
681707  98.075  -53.776  51.439  1
681708  98.092  -53.783  51.402  1
681709  98.110  -53.790  51.364  1
681710  98.129  -53.796  51.325  1
681711  98.147  -53.803  51.284  1
681712  98.179  -53.812  51.242  1
681713  98.212  -53.820  51.198  1
681714  98.244  -53.829  51.153  1
681715  98.270  -53.840  51.111  1
681716  98.286  -53.855  51.069  1
681717  98.309  -53.872  51.028  1
681718  98.335  -53.891  50.987  1
681719  98.360  -53.910  50.947  1
681720  98.386  -53.928  50.906  1
681721  98.411  -53.947  50.865  1
681722  98.437  -53.965  50.824  1
681723  98.462  -53.983  50.784  1
681724  98.488  -54.002  50.744  1
681725  98.513  -54.020  50.705  1
681726  98.538  -54.038  50.667  1
681727  98.564  -54.057  50.631  1
682217  93.493  -51.242  56.317  4
682218  93.524  -51.259  56.301  4
682219  93.555  -51.277  56.284  4
682220  93.586  -51.294  56.265  4
682221  93.617  -51.312  56.245  4
682222  93.648  -51.329  56.223  4
682223  93.679  -51.346  56.199  4
682224  93.710  -51.364  56.174  4
682225  93.741  -51.381  56.147  4
682226  93.772  -51.399  56.118  4
682227  93.803  -51.417  56.088  4
682228  93.834  -51.434  56.057  4
682229  93.865  -51.452  56.024  4
682230  93.892  -51.472  55.991  4
682231  93.919  -51.491  55.956  4
682232  93.945  -51.511  55.922  4
682233  93.973  -51.531  55.887  4
682234  93.999  -51.550  55.851  4
682235  94.027  -51.570  55.815  4
682289  95.480  -52.637  54.536  1
682290  95.507  -52.656  54.525  1
682291  95.534  -52.675  54.512  1
682292  95.560  -52.694  54.499  1
682293  95.587  -52.713  54.487  1
682294  95.614  -52.732  54.476  1
682295  95.641  -52.751  54.464  1
682296  95.668  -52.770  54.453  1
682297  95.694  -52.789  54.442  1
682298  95.721  -52.808  54.432  1
682299  95.748  -52.827  54.423  1
682300  95.779  -52.848  54.415  1
682301  95.795  -52.872  54.401  1
682302  95.811  -52.894  54.382  1
682303  95.826  -52.917  54.363  1
682304  95.842  -52.941  54.345  1
682305  95.858  -52.963  54.324  1
682306  95.873  -52.986  54.299  1
682307  95.887  -53.009  54.268  1
682308  95.901  -53.031  54.233  1
682309  95.915  -53.054  54.199  1
682310  95.930  -53.076  54.167  1
682311  95.944  -53.098  54.137  1
682312  95.958  -53.121  54.107  1
682313  95.972  -53.143  54.078  1
682314  95.983  -53.155  54.048  1
682315  95.992  -53.164  54.020  1
682316  96.001  -53.171  53.991  1
682317  96.010  -53.179  53.964  1
682318  96.018  -53.187  53.935  1
682319  96.027  -53.195  53.905  1
682320  96.036  -53.203  53.877  1
682321  96.045  -53.211  53.849  1
682322  96.054  -53.219  53.821  1
682323  96.062  -53.227  53.794  1
682324  96.072  -53.234  53.764  1
682325  96.081  -53.242  53.735  1
682326  96.089  -53.250  53.705  1
682327  96.098  -53.258  53.676  1
682328  96.107  -53.266  53.647  1
682329  96.116  -53.273  53.620  1
682330  96.126  -53.277  53.592  1
682331  96.136  -53.280  53.563  1
682332  96.147  -53.284  53.535  1
682333  96.157  -53.288  53.509  1
682334  96.167  -53.292  53.484  1
682335  96.177  -53.295  53.459  1
682336  96.188  -53.299  53.434  1
682337  96.198  -53.302  53.410  1
682338  96.217  -53.305  53.388  1
682339  96.244  -53.308  53.366  1
682340  96.272  -53.310  53.345  1
682341  96.300  -53.311  53.324  1
682342  96.327  -53.314  53.302  1
682343  96.355  -53.316  53.282  1
682344  96.382  -53.317  53.263  1
682345  96.410  -53.320  53.246  1
682346  96.438  -53.322  53.229  1
682347  96.465  -53.324  53.211  1
682348  96.493  -53.326  53.194  1
682349  96.520  -53.328  53.178  1
682350  96.548  -53.330  53.162  1
682351  96.576  -53.333  53.147  1
682352  96.603  -53.334  53.132  1
682353  96.631  -53.336  53.114  1
682354  96.658  -53.339  53.097  1
682355  96.682  -53.343  53.079  1
682356  96.704  -53.349  53.061  1
682357  96.726  -53.355  53.042  1
682358  96.748  -53.361  53.021  1
682359  96.770  -53.368  52.997  1
682360  96.792  -53.374  52.973  1
682361  96.825  -53.382  52.949  1
682362  96.858  -53.390  52.924  1
682363  96.891  -53.399  52.898  1
682364  96.924  -53.407  52.871  1
682365  96.957  -53.415  52.843  1
682366  96.991  -53.424  52.817  1
682367  97.024  -53.432  52.789  1
682368  97.057  -53.440  52.762  1
682369  97.090  -53.449  52.735  1
682370  97.123  -53.457  52.707  1
682371  97.157  -53.465  52.677  1
682372  97.190  -53.474  52.648  1
682373  97.223  -53.482  52.619  1
682374  97.256  -53.490  52.588  1
682375  97.290  -53.499  52.558  1
682376  97.323  -53.507  52.527  1
682377  97.356  -53.515  52.494  1
682378  97.393  -53.522  52.461  1
682379  97.412  -53.531  52.428  1
682380  97.434  -53.539  52.395  1
682381  97.455  -53.546  52.361  1
682382  97.476  -53.554  52.325  1
682383  97.497  -53.562  52.289  1
682384  97.527  -53.571  52.252  1
682385  97.558  -53.581  52.214  1
682386  97.589  -53.590  52.178  1
682387  97.618  -53.598  52.143  1
682388  97.647  -53.603  52.107  1
682389  97.675  -53.609  52.070  1
682390  97.703  -53.613  52.036  1
682391  97.731  -53.618  52.003  1
682392  97.759  -53.624  51.971  1
682393  97.787  -53.629  51.941  1
682394  97.815  -53.634  51.911  1
682395  97.843  -53.639  51.880  1
682396  97.871  -53.644  51.849  1
682397  97.890  -53.642  51.819  1
682398  97.907  -53.639  51.789  1
682399  97.919  -53.650  51.758  1
682400  97.931  -53.660  51.727  1
682401  97.943  -53.670  51.695  1
682402  97.955  -53.681  51.664  1
682403  97.967  -53.691  51.632  1
682404  97.980  -53.702  51.600  1
682405  98.004  -53.716  51.566  1
682406  98.029  -53.731  51.529  1
682407  98.055  -53.746  51.491  1
682408  98.081  -53.761  51.453  1
682409  98.100  -53.769  51.416  1
682410  98.118  -53.775  51.378  1
682411  98.136  -53.782  51.340  1
682412  98.154  -53.789  51.301  1
682413  98.180  -53.797  51.260  1
682414  98.213  -53.805  51.218  1
682415  98.245  -53.814  51.175  1
682416  98.275  -53.824  51.134  1
682417  98.290  -53.838  51.094  1
682418  98.311  -53.855  51.055  1
682419  98.337  -53.873  51.015  1
682420  98.362  -53.892  50.976  1
682421  98.387  -53.910  50.936  1
682422  98.413  -53.928  50.896  1
682423  98.438  -53.947  50.855  1
682424  98.463  -53.966  50.815  1
682425  98.489  -53.984  50.775  1
682426  98.514  -54.003  50.736  1
682427  98.540  -54.021  50.698  1
682428  98.565  -54.040  50.662  1
682429  98.591  -54.058  50.627  1
682919  93.542  -51.235  56.293  4
682920  93.572  -51.252  56.275  4
682921  93.604  -51.270  56.256  4
682922  93.634  -51.287  56.236  4
682923  93.665  -51.305  56.214  4
682924  93.696  -51.322  56.189  4
682925  93.727  -51.340  56.164  4
682926  93.758  -51.357  56.136  4
682927  93.789  -51.374  56.107  4
682928  93.820  -51.393  56.076  4
682929  93.851  -51.410  56.045  4
682930  93.882  -51.428  56.012  4
682931  93.911  -51.446  55.979  4
682932  93.937  -51.466  55.944  4
682933  93.965  -51.486  55.910  4
682934  93.991  -51.506  55.875  4
682935  94.018  -51.525  55.840  4
682991  95.526  -52.631  54.518  1
682992  95.553  -52.650  54.505  1
682993  95.580  -52.670  54.492  1
682994  95.607  -52.690  54.479  1
682995  95.634  -52.709  54.467  1
682996  95.661  -52.730  54.454  1
682997  95.687  -52.750  54.441  1
682998  95.714  -52.769  54.429  1
682999  95.741  -52.789  54.417  1
683000  95.768  -52.809  54.406  1
683001  95.796  -52.828  54.395  1
683002  95.811  -52.850  54.378  1
683003  95.825  -52.873  54.358  1
683004  95.839  -52.895  54.338  1
683005  95.853  -52.918  54.318  1
683006  95.868  -52.940  54.296  1
683007  95.882  -52.963  54.270  1
683008  95.896  -52.985  54.240  1
683009  95.910  -53.007  54.208  1
683010  95.924  -53.030  54.176  1
683011  95.939  -53.052  54.146  1
683012  95.953  -53.075  54.117  1
683013  95.967  -53.098  54.088  1
683014  95.981  -53.120  54.059  1
683015  95.994  -53.139  54.030  1
683016  96.003  -53.146  54.002  1
683017  96.012  -53.154  53.973  1
683018  96.021  -53.162  53.946  1
683019  96.030  -53.170  53.917  1
683020  96.038  -53.178  53.887  1
683021  96.047  -53.186  53.858  1
683022  96.056  -53.193  53.830  1
683023  96.065  -53.201  53.802  1
683024  96.074  -53.209  53.774  1
683025  96.083  -53.217  53.744  1
683026  96.092  -53.225  53.715  1
683027  96.100  -53.233  53.685  1
683028  96.109  -53.241  53.656  1
683029  96.118  -53.248  53.627  1
683030  96.127  -53.257  53.599  1
683031  96.137  -53.261  53.571  1
683032  96.148  -53.264  53.543  1
683033  96.158  -53.267  53.515  1
683034  96.168  -53.271  53.489  1
683035  96.178  -53.275  53.464  1
683036  96.188  -53.279  53.438  1
683037  96.198  -53.283  53.413  1
683038  96.209  -53.286  53.390  1
683039  96.228  -53.289  53.368  1
683040  96.256  -53.291  53.345  1
683041  96.284  -53.293  53.324  1
683042  96.311  -53.295  53.303  1
683043  96.338  -53.297  53.283  1
683044  96.366  -53.299  53.262  1
683045  96.394  -53.302  53.244  1
683046  96.421  -53.303  53.226  1
683047  96.449  -53.305  53.208  1
683048  96.476  -53.308  53.191  1
683049  96.504  -53.309  53.174  1
683050  96.532  -53.311  53.158  1
683051  96.559  -53.314  53.142  1
683052  96.587  -53.316  53.128  1
683053  96.615  -53.317  53.113  1
683054  96.642  -53.320  53.096  1
683055  96.670  -53.322  53.079  1
683056  96.692  -53.328  53.062  1
683057  96.714  -53.334  53.045  1
683058  96.736  -53.340  53.026  1
683059  96.757  -53.346  53.006  1
683060  96.780  -53.352  52.984  1
683061  96.801  -53.358  52.961  1
683062  96.824  -53.364  52.938  1
683063  96.857  -53.373  52.914  1
683064  96.890  -53.381  52.889  1
683065  96.923  -53.389  52.863  1
683066  96.956  -53.398  52.837  1
683067  96.990  -53.406  52.810  1
683068  97.023  -53.415  52.783  1
683069  97.056  -53.423  52.757  1
683070  97.089  -53.431  52.731  1
683071  97.122  -53.440  52.703  1
683072  97.156  -53.448  52.674  1
683073  97.189  -53.456  52.645  1
683074  97.222  -53.465  52.617  1
683075  97.255  -53.474  52.587  1
683076  97.289  -53.482  52.557  1
683077  97.322  -53.490  52.527  1
683078  97.355  -53.499  52.494  1
683079  97.388  -53.507  52.461  1
683080  97.432  -53.510  52.428  1
683081  97.439  -53.521  52.395  1
683082  97.460  -53.530  52.361  1
683083  97.481  -53.537  52.325  1
683084  97.503  -53.545  52.289  1
683085  97.527  -53.553  52.253  1
683086  97.558  -53.562  52.217  1
683087  97.588  -53.571  52.182  1
683088  97.619  -53.581  52.146  1
683089  97.650  -53.590  52.110  1
683090  97.681  -53.599  52.075  1
683091  97.709  -53.604  52.041  1
683092  97.737  -53.609  52.009  1
683093  97.765  -53.615  51.980  1
683094  97.793  -53.620  51.951  1
683095  97.821  -53.625  51.921  1
683096  97.849  -53.630  51.890  1
683097  97.874  -53.632  51.858  1
683098  97.890  -53.628  51.827  1
683099  97.908  -53.623  51.797  1
683100  97.921  -53.630  51.766  1
683101  97.933  -53.640  51.735  1
683102  97.945  -53.650  51.705  1
683103  97.957  -53.661  51.673  1
683104  97.970  -53.672  51.642  1
683105  97.982  -53.681  51.611  1
683106  98.006  -53.696  51.578  1
683107  98.031  -53.711  51.542  1
683108  98.057  -53.726  51.504  1
683109  98.083  -53.740  51.467  1
683110  98.107  -53.755  51.429  1
683111  98.125  -53.761  51.393  1
683112  98.143  -53.768  51.355  1
683113  98.161  -53.775  51.316  1
683114  98.181  -53.781  51.277  1
683115  98.214  -53.791  51.237  1
683116  98.246  -53.799  51.197  1
683117  98.279  -53.808  51.157  1
683118  98.295  -53.822  51.119  1
683119  98.313  -53.838  51.081  1
683120  98.338  -53.856  51.042  1
683121  98.364  -53.874  51.004  1
683122  98.389  -53.893  50.965  1
683123  98.415  -53.911  50.925  1
683124  98.440  -53.930  50.886  1
683125  98.465  -53.948  50.846  1
683126  98.491  -53.966  50.806  1
683127  98.516  -53.985  50.767  1
683128  98.541  -54.004  50.729  1
683129  98.567  -54.022  50.692  1
683130  98.592  -54.041  50.657  1
683621  93.589  -51.228  56.266  4
683622  93.620  -51.246  56.247  4
683623  93.651  -51.263  56.226  4
683624  93.682  -51.280  56.203  4
683625  93.713  -51.298  56.179  4
683626  93.744  -51.315  56.153  4
683627  93.775  -51.333  56.125  4
683628  93.806  -51.350  56.095  4
683629  93.837  -51.368  56.064  4
683630  93.868  -51.386  56.032  4
683631  93.899  -51.403  56.000  4
683632  93.929  -51.421  55.966  4
683633  93.957  -51.440  55.933  4
683634  93.983  -51.460  55.898  4
683635  94.010  -51.480  55.863  4
683636  94.037  -51.500  55.828  4
683692  95.545  -52.606  54.512  1
683693  95.572  -52.625  54.497  1
683694  95.599  -52.645  54.483  1
683695  95.625  -52.665  54.470  1
683696  95.653  -52.684  54.457  1
683697  95.679  -52.704  54.444  1
683698  95.706  -52.724  54.430  1
683699  95.733  -52.744  54.416  1
683700  95.760  -52.763  54.402  1
683701  95.787  -52.783  54.389  1
683702  95.806  -52.805  54.376  1
683703  95.819  -52.827  54.357  1
683704  95.834  -52.850  54.335  1
683705  95.848  -52.872  54.314  1
683706  95.862  -52.894  54.292  1
683707  95.876  -52.916  54.268  1
683708  95.891  -52.939  54.242  1
683709  95.905  -52.962  54.214  1
683710  95.919  -52.984  54.185  1
683711  95.933  -53.007  54.156  1
683712  95.948  -53.029  54.126  1
683713  95.962  -53.051  54.097  1
683714  95.976  -53.073  54.070  1
683715  95.990  -53.096  54.042  1
683716  96.005  -53.119  54.012  1
683717  96.014  -53.129  53.984  1
683718  96.023  -53.137  53.956  1
683719  96.032  -53.145  53.927  1
683720  96.041  -53.153  53.898  1
683721  96.049  -53.161  53.869  1
683722  96.058  -53.168  53.840  1
683723  96.067  -53.176  53.811  1
683724  96.076  -53.184  53.783  1
683725  96.085  -53.192  53.754  1
683726  96.094  -53.200  53.725  1
683727  96.103  -53.208  53.695  1
683728  96.112  -53.216  53.666  1
683729  96.120  -53.223  53.637  1
683730  96.129  -53.232  53.608  1
683731  96.138  -53.239  53.580  1
683732  96.148  -53.244  53.551  1
683733  96.159  -53.248  53.523  1
683734  96.169  -53.251  53.496  1
683735  96.179  -53.255  53.470  1
683736  96.189  -53.258  53.445  1
683737  96.199  -53.262  53.419  1
683738  96.209  -53.266  53.394  1
683739  96.220  -53.270  53.371  1
683740  96.240  -53.272  53.348  1
683741  96.267  -53.274  53.326  1
683742  96.295  -53.277  53.305  1
683743  96.322  -53.278  53.284  1
683744  96.350  -53.280  53.264  1
683745  96.378  -53.283  53.243  1
683746  96.405  -53.285  53.225  1
683747  96.433  -53.286  53.206  1
683748  96.460  -53.289  53.189  1
683749  96.488  -53.291  53.172  1
683750  96.516  -53.293  53.155  1
683751  96.543  -53.295  53.138  1
683752  96.571  -53.297  53.122  1
683753  96.599  -53.299  53.108  1
683754  96.626  -53.301  53.093  1
683755  96.654  -53.303  53.078  1
683756  96.679  -53.307  53.062  1
683757  96.701  -53.313  53.046  1
683758  96.723  -53.319  53.029  1
683759  96.745  -53.325  53.012  1
683760  96.767  -53.331  52.993  1
683761  96.789  -53.337  52.971  1
683762  96.811  -53.343  52.949  1
683763  96.833  -53.349  52.927  1
683764  96.856  -53.355  52.904  1
683765  96.889  -53.364  52.880  1
683766  96.922  -53.372  52.856  1
683767  96.955  -53.380  52.830  1
683768  96.989  -53.389  52.804  1
683769  97.022  -53.397  52.778  1
683770  97.055  -53.405  52.753  1
683771  97.088  -53.415  52.727  1
683772  97.121  -53.423  52.700  1
683773  97.155  -53.431  52.672  1
683774  97.188  -53.440  52.643  1
683775  97.221  -53.448  52.615  1
683776  97.254  -53.456  52.586  1
683777  97.288  -53.465  52.557  1
683778  97.321  -53.473  52.527  1
683779  97.354  -53.481  52.495  1
683780  97.387  -53.490  52.462  1
683781  97.426  -53.496  52.429  1
683782  97.454  -53.502  52.395  1
683783  97.466  -53.512  52.362  1
683784  97.487  -53.520  52.327  1
683785  97.509  -53.527  52.291  1
683786  97.530  -53.536  52.255  1
683787  97.558  -53.544  52.220  1
683788  97.588  -53.553  52.186  1
683789  97.619  -53.563  52.151  1
683790  97.650  -53.572  52.115  1
683791  97.681  -53.581  52.080  1
683792  97.712  -53.591  52.047  1
683793  97.743  -53.600  52.016  1
683794  97.771  -53.606  51.987  1
683795  97.799  -53.611  51.958  1
683796  97.827  -53.616  51.929  1
683797  97.855  -53.621  51.898  1
683798  97.874  -53.618  51.866  1
683799  97.891  -53.614  51.835  1
683800  97.908  -53.609  51.804  1
683801  97.923  -53.609  51.774  1
683802  97.935  -53.620  51.744  1
683803  97.948  -53.631  51.714  1
683804  97.960  -53.641  51.683  1
683805  97.972  -53.651  51.652  1
683806  97.984  -53.662  51.621  1
683807  98.008  -53.676  51.588  1
683808  98.033  -53.691  51.552  1
683809  98.059  -53.706  51.516  1
683810  98.085  -53.721  51.480  1
683811  98.110  -53.735  51.445  1
683812  98.133  -53.747  51.408  1
683813  98.151  -53.754  51.371  1
683814  98.169  -53.760  51.333  1
683815  98.186  -53.767  51.295  1
683816  98.214  -53.775  51.257  1
683817  98.247  -53.784  51.218  1
683818  98.279  -53.793  51.180  1
683819  98.300  -53.806  51.144  1
683820  98.315  -53.820  51.107  1
683821  98.340  -53.838  51.068  1
683822  98.365  -53.856  51.031  1
683823  98.391  -53.875  50.993  1
683824  98.416  -53.894  50.953  1
683825  98.442  -53.912  50.915  1
683826  98.467  -53.931  50.876  1
683827  98.493  -53.949  50.837  1
683828  98.518  -53.967  50.797  1
683829  98.544  -53.986  50.758  1
683830  98.569  -54.004  50.721  1
683831  98.594  -54.023  50.686  1
684323  93.637  -51.221  56.238  4
684324  93.669  -51.239  56.216  4
684325  93.699  -51.256  56.193  4
684326  93.730  -51.274  56.168  4
684327  93.761  -51.291  56.141  4
684328  93.792  -51.309  56.113  4
684329  93.823  -51.326  56.083  4
684330  93.854  -51.344  56.052  4
684331  93.885  -51.362  56.020  4
684332  93.916  -51.379  55.988  4
684333  93.947  -51.396  55.954  4
684334  93.975  -51.415  55.920  4
684335  94.002  -51.435  55.886  4
684336  94.029  -51.455  55.851  4
684393  95.563  -52.581  54.504  1
684394  95.591  -52.600  54.490  1
684395  95.617  -52.620  54.474  1
684396  95.644  -52.640  54.461  1
684397  95.671  -52.659  54.447  1
684398  95.698  -52.679  54.432  1
684399  95.725  -52.699  54.418  1
684400  95.752  -52.719  54.403  1
684401  95.779  -52.738  54.387  1
684402  95.801  -52.759  54.372  1
684403  95.814  -52.782  54.356  1
684404  95.828  -52.803  54.336  1
684405  95.842  -52.825  54.314  1
684406  95.857  -52.848  54.292  1
684407  95.871  -52.871  54.269  1
684408  95.885  -52.893  54.244  1
684409  95.899  -52.916  54.218  1
684410  95.913  -52.938  54.191  1
684411  95.928  -52.960  54.164  1
684412  95.942  -52.983  54.136  1
684413  95.956  -53.005  54.108  1
684414  95.970  -53.028  54.080  1
684415  95.985  -53.050  54.052  1
684416  95.999  -53.073  54.024  1
684417  96.013  -53.095  53.995  1
684418  96.025  -53.112  53.968  1
684419  96.034  -53.120  53.938  1
684420  96.043  -53.127  53.910  1
684421  96.052  -53.136  53.881  1
684422  96.061  -53.143  53.851  1
684423  96.070  -53.151  53.822  1
684424  96.079  -53.159  53.793  1
684425  96.087  -53.167  53.764  1
684426  96.096  -53.175  53.735  1
684427  96.105  -53.183  53.705  1
684428  96.114  -53.191  53.675  1
684429  96.123  -53.198  53.646  1
684430  96.131  -53.207  53.618  1
684431  96.141  -53.214  53.589  1
684432  96.150  -53.223  53.561  1
684433  96.159  -53.227  53.532  1
684434  96.170  -53.231  53.503  1
684435  96.180  -53.235  53.477  1
684436  96.190  -53.238  53.451  1
684437  96.200  -53.242  53.426  1
684438  96.210  -53.245  53.401  1
684439  96.221  -53.249  53.376  1
684440  96.231  -53.253  53.353  1
684441  96.251  -53.255  53.329  1
684442  96.278  -53.258  53.307  1
684443  96.306  -53.260  53.286  1
684444  96.334  -53.262  53.266  1
684445  96.362  -53.264  53.245  1
684446  96.389  -53.266  53.224  1
684447  96.417  -53.268  53.206  1
684448  96.444  -53.270  53.187  1
684449  96.472  -53.272  53.170  1
684450  96.500  -53.274  53.153  1
684451  96.527  -53.277  53.136  1
684452  96.555  -53.278  53.120  1
684453  96.583  -53.280  53.105  1
684454  96.610  -53.283  53.090  1
684455  96.638  -53.285  53.077  1
684456  96.665  -53.286  53.062  1
684457  96.689  -53.292  53.047  1
684458  96.711  -53.298  53.031  1
684459  96.733  -53.304  53.015  1
684460  96.754  -53.310  52.998  1
684461  96.777  -53.316  52.981  1
684462  96.798  -53.322  52.960  1
684463  96.820  -53.328  52.939  1
684464  96.842  -53.334  52.917  1
684465  96.864  -53.340  52.895  1
684466  96.888  -53.346  52.873  1
684467  96.921  -53.355  52.849  1
684468  96.954  -53.364  52.823  1
684469  96.987  -53.372  52.798  1
684470  97.021  -53.380  52.774  1
684471  97.054  -53.389  52.749  1
684472  97.087  -53.397  52.724  1
684473  97.120  -53.405  52.698  1
684474  97.154  -53.414  52.670  1
684475  97.187  -53.422  52.642  1
684476  97.220  -53.430  52.615  1
684477  97.253  -53.439  52.585  1
684478  97.287  -53.447  52.557  1
684479  97.320  -53.455  52.527  1
684480  97.353  -53.464  52.495  1
684481  97.386  -53.472  52.463  1
684482  97.419  -53.480  52.430  1
684483  97.476  -53.480  52.397  1
684484  97.475  -53.494  52.364  1
684485  97.493  -53.502  52.329  1
684486  97.514  -53.511  52.294  1
684487  97.535  -53.518  52.258  1
684488  97.557  -53.526  52.224  1
684489  97.588  -53.535  52.190  1
684490  97.619  -53.545  52.156  1
684491  97.650  -53.554  52.121  1
684492  97.680  -53.563  52.086  1
684493  97.712  -53.573  52.053  1
684494  97.742  -53.582  52.022  1
684495  97.773  -53.592  51.993  1
684496  97.804  -53.601  51.964  1
684497  97.833  -53.607  51.936  1
684498  97.858  -53.609  51.905  1
684499  97.874  -53.605  51.872  1
684500  97.891  -53.599  51.841  1
684501  97.909  -53.595  51.811  1
684502  97.925  -53.590  51.782  1
684503  97.938  -53.600  51.752  1
684504  97.950  -53.611  51.722  1
684505  97.962  -53.621  51.692  1
684506  97.974  -53.631  51.661  1
684507  97.987  -53.642  51.630  1
684508  98.010  -53.656  51.597  1
684509  98.035  -53.671  51.564  1
684510  98.061  -53.686  51.529  1
684511  98.086  -53.700  51.494  1
684512  98.112  -53.715  51.460  1
684513  98.138  -53.731  51.423  1
684514  98.158  -53.740  51.387  1
684515  98.176  -53.747  51.350  1
684516  98.194  -53.753  51.313  1
684517  98.215  -53.760  51.276  1
684518  98.248  -53.769  51.239  1
684519  98.280  -53.778  51.202  1
684520  98.305  -53.789  51.166  1
684521  98.320  -53.803  51.131  1
684522  98.342  -53.821  51.094  1
684523  98.367  -53.839  51.057  1
684524  98.392  -53.857  51.020  1
684525  98.418  -53.876  50.981  1
684526  98.443  -53.894  50.943  1
684527  98.469  -53.913  50.904  1
684528  98.494  -53.932  50.864  1
684529  98.520  -53.950  50.825  1
684530  98.545  -53.969  50.787  1
684531  98.571  -53.987  50.749  1
684532  98.596  -54.005  50.713  1
685025  93.685  -51.215  56.206  4
685026  93.716  -51.232  56.183  4
685027  93.747  -51.249  56.156  4
685028  93.778  -51.267  56.129  4
685029  93.809  -51.284  56.101  4
685030  93.840  -51.302  56.071  4
685031  93.871  -51.319  56.040  4
685032  93.902  -51.337  56.008  4
685033  93.933  -51.355  55.975  4
685034  93.964  -51.372  55.942  4
685035  93.994  -51.390  55.908  4
685036  94.021  -51.410  55.874  4
685094  95.583  -52.555  54.497  1
685095  95.609  -52.575  54.483  1
685096  95.636  -52.594  54.467  1
685097  95.663  -52.614  54.453  1
685098  95.690  -52.634  54.437  1
685099  95.717  -52.653  54.421  1
685100  95.744  -52.674  54.406  1
685101  95.771  -52.694  54.390  1
685102  95.796  -52.713  54.372  1
685103  95.809  -52.736  54.355  1
685104  95.823  -52.758  54.337  1
685105  95.837  -52.780  54.317  1
685106  95.851  -52.802  54.295  1
685107  95.866  -52.825  54.272  1
685108  95.880  -52.847  54.248  1
685109  95.894  -52.869  54.223  1
685110  95.908  -52.892  54.198  1
685111  95.922  -52.914  54.171  1
685112  95.937  -52.937  54.144  1
685113  95.951  -52.959  54.117  1
685114  95.965  -52.982  54.090  1
685115  95.979  -53.004  54.062  1
685116  95.993  -53.026  54.035  1
685117  96.008  -53.049  54.006  1
685118  96.022  -53.071  53.977  1
685119  96.036  -53.094  53.950  1
685120  96.045  -53.102  53.920  1
685121  96.054  -53.111  53.892  1
685122  96.063  -53.118  53.863  1
685123  96.072  -53.126  53.834  1
685124  96.081  -53.134  53.804  1
685125  96.090  -53.142  53.775  1
685126  96.099  -53.150  53.747  1
685127  96.107  -53.158  53.717  1
685128  96.116  -53.166  53.688  1
685129  96.125  -53.173  53.658  1
685130  96.134  -53.182  53.629  1
685131  96.143  -53.189  53.600  1
685132  96.152  -53.198  53.572  1
685133  96.161  -53.205  53.543  1
685134  96.170  -53.211  53.514  1
685135  96.180  -53.214  53.486  1
685136  96.191  -53.218  53.459  1
685137  96.201  -53.222  53.433  1
685138  96.211  -53.225  53.408  1
685151  96.511  -53.258  53.135  1
685152  96.539  -53.260  53.118  1
685153  96.567  -53.261  53.103  1
685154  96.594  -53.264  53.088  1
685155  96.621  -53.266  53.074  1
685156  96.649  -53.268  53.060  1
685157  96.676  -53.270  53.046  1
685158  96.698  -53.277  53.032  1
685159  96.720  -53.283  53.017  1
685160  96.742  -53.289  53.002  1
685161  96.764  -53.295  52.985  1
685162  96.786  -53.301  52.969  1
685163  96.808  -53.307  52.949  1
685164  96.830  -53.313  52.929  1
685165  96.852  -53.319  52.908  1
685166  96.874  -53.325  52.887  1
685167  96.895  -53.331  52.865  1
685168  96.920  -53.338  52.843  1
685169  96.953  -53.346  52.817  1
685170  96.986  -53.355  52.794  1
685173  97.086  -53.380  52.721  1
685174  97.119  -53.388  52.695  1
685175  97.153  -53.396  52.668  1
685176  97.186  -53.405  52.641  1
685177  97.219  -53.413  52.614  1
685178  97.252  -53.421  52.585  1
685179  97.286  -53.430  52.557  1
685180  97.319  -53.438  52.527  1
685181  97.352  -53.446  52.496  1
685182  97.385  -53.455  52.464  1
685183  97.418  -53.463  52.432  1
685184  97.458  -53.469  52.398  1
685185  97.498  -53.472  52.365  1
685186  97.499  -53.486  52.332  1
685187  97.520  -53.493  52.297  1
685188  97.541  -53.501  52.262  1
685189  97.563  -53.509  52.227  1
685190  97.588  -53.517  52.193  1
685191  97.618  -53.527  52.161  1
685192  97.650  -53.536  52.126  1
685193  97.680  -53.546  52.092  1
685194  97.711  -53.555  52.059  1
685195  97.742  -53.564  52.028  1
685196  97.773  -53.574  51.999  1
685197  97.804  -53.583  51.970  1
685198  97.835  -53.592  51.941  1
685199  97.858  -53.595  51.910  1
685200  97.875  -53.590  51.878  1
685201  97.892  -53.586  51.848  1
685202  97.909  -53.581  51.819  1
685203  97.926  -53.576  51.789  1
685204  97.940  -53.581  51.759  1
685205  97.952  -53.590  51.730  1
685206  97.964  -53.601  51.700  1
685207  97.977  -53.612  51.670  1
685208  97.989  -53.622  51.639  1
685209  98.012  -53.636  51.607  1
685210  98.037  -53.651  51.575  1
685211  98.063  -53.665  51.542  1
685212  98.088  -53.681  51.508  1
685213  98.114  -53.696  51.474  1
685214  98.140  -53.710  51.439  1
685215  98.165  -53.725  51.402  1
685216  98.183  -53.732  51.367  1
685217  98.202  -53.739  51.331  1
685218  98.219  -53.746  51.295  1
685219  98.249  -53.754  51.259  1
685220  98.281  -53.762  51.224  1
685221  98.309  -53.773  51.188  1
685222  98.325  -53.787  51.154  1
685223  98.343  -53.803  51.118  1
685224  98.369  -53.822  51.081  1
685225  98.394  -53.840  51.045  1
685226  98.420  -53.859  51.008  1
685227  98.445  -53.877  50.969  1
685228  98.471  -53.895  50.930  1
685229  98.496  -53.914  50.891  1
685230  98.521  -53.932  50.852  1
685231  98.547  -53.950  50.813  1
685232  98.572  -53.969  50.775  1
685233  98.597  -53.988  50.738  1
685796  95.628  -52.550  54.475  1
685797  95.655  -52.569  54.459  1
685798  95.682  -52.589  54.444  1
685799  95.709  -52.609  54.427  1
685800  95.736  -52.628  54.410  1
685801  95.763  -52.648  54.393  1
685802  95.790  -52.668  54.376  1
685803  95.804  -52.690  54.358  1
685804  95.818  -52.713  54.340  1
685805  95.832  -52.735  54.321  1
685806  95.846  -52.756  54.300  1
685807  95.861  -52.778  54.278  1
685808  95.875  -52.801  54.255  1
685809  95.889  -52.823  54.230  1
685810  95.903  -52.846  54.204  1
685811  95.917  -52.869  54.179  1
685812  95.932  -52.891  54.153  1
685813  95.946  -52.913  54.127  1
685814  95.960  -52.935  54.100  1
685815  95.974  -52.958  54.072  1
685816  95.988  -52.981  54.044  1
685817  96.003  -53.003  54.018  1
685818  96.017  -53.026  53.990  1
685819  96.031  -53.048  53.960  1
685820  96.045  -53.070  53.931  1
685821  96.056  -53.086  53.903  1
685822  96.065  -53.093  53.874  1
685823  96.075  -53.101  53.846  1
685824  96.083  -53.109  53.816  1
685825  96.092  -53.117  53.787  1
685826  96.101  -53.125  53.757  1
685827  96.110  -53.132  53.729  1
685828  96.119  -53.141  53.700  1
685829  96.127  -53.148  53.671  1
685830  96.136  -53.157  53.641  1
685831  96.145  -53.164  53.612  1
685832  96.154  -53.172  53.583  1
685833  96.163  -53.180  53.555  1
685834  96.172  -53.188  53.526  1
685856  96.633  -53.249  53.058  1
685857  96.661  -53.252  53.044  1
685858  96.686  -53.255  53.030  1
685859  96.708  -53.261  53.016  1
685860  96.730  -53.267  53.002  1
685861  96.751  -53.273  52.988  1
685862  96.773  -53.280  52.973  1
685863  96.796  -53.286  52.957  1
685864  96.817  -53.292  52.938  1
685865  96.839  -53.298  52.919  1
685866  96.861  -53.304  52.899  1
685867  96.883  -53.310  52.879  1
685876  97.152  -53.379  52.666  1
685877  97.185  -53.387  52.640  1
685878  97.218  -53.396  52.613  1
685879  97.251  -53.404  52.585  1
685880  97.285  -53.412  52.557  1
685881  97.318  -53.421  52.528  1
685882  97.351  -53.429  52.497  1
685883  97.384  -53.437  52.465  1
685884  97.417  -53.446  52.434  1
685885  97.450  -53.454  52.401  1
685886  97.517  -53.451  52.368  1
685887  97.519  -53.464  52.334  1
685888  97.525  -53.476  52.300  1
685889  97.546  -53.483  52.265  1
685890  97.568  -53.492  52.231  1
685891  97.589  -53.499  52.198  1
685892  97.618  -53.509  52.165  1
685893  97.649  -53.518  52.130  1
685894  97.680  -53.527  52.098  1
685895  97.711  -53.537  52.065  1
685896  97.742  -53.546  52.034  1
685897  97.773  -53.556  52.004  1
685898  97.804  -53.565  51.974  1
685899  97.835  -53.574  51.944  1
685900  97.861  -53.581  51.914  1
685901  97.875  -53.577  51.883  1
685902  97.892  -53.572  51.853  1
685903  97.909  -53.567  51.825  1
685904  97.926  -53.562  51.797  1
685905  97.942  -53.560  51.768  1
685906  97.954  -53.571  51.738  1
685907  97.966  -53.581  51.708  1
685908  97.979  -53.592  51.678  1
685909  97.991  -53.602  51.648  1
685910  98.014  -53.616  51.617  1
685911  98.039  -53.631  51.586  1
685912  98.065  -53.646  51.555  1
685913  98.090  -53.661  51.522  1
685914  98.116  -53.675  51.489  1
685915  98.142  -53.690  51.454  1
685916  98.167  -53.706  51.419  1
685917  98.191  -53.719  51.384  1
685918  98.209  -53.725  51.348  1
685919  98.227  -53.731  51.313  1
685920  98.249  -53.739  51.277  1
685921  98.282  -53.747  51.244  1
685922  98.314  -53.756  51.209  1
685923  98.330  -53.771  51.175  1
685924  98.346  -53.786  51.140  1
685925  98.370  -53.804  51.104  1
685926  98.396  -53.822  51.069  1
685927  98.421  -53.841  51.032  1
685928  98.447  -53.860  50.994  1
685929  98.472  -53.878  50.956  1
685930  98.498  -53.896  50.917  1
685931  98.523  -53.915  50.878  1
685932  98.549  -53.933  50.838  1
685933  98.574  -53.952  50.799  1
685934  98.599  -53.970  50.763  1
685935  98.625  -53.988  50.727  1
686497  95.647  -52.525  54.467  1
686498  95.674  -52.544  54.451  1
686499  95.701  -52.564  54.435  1
686500  95.728  -52.584  54.417  1
686501  95.755  -52.603  54.399  1
686502  95.781  -52.623  54.381  1
686503  95.800  -52.644  54.363  1
686504  95.813  -52.666  54.345  1
686505  95.827  -52.689  54.325  1
686506  95.841  -52.711  54.306  1
686507  95.855  -52.733  54.284  1
686508  95.870  -52.756  54.262  1
686509  95.883  -52.778  54.238  1
686510  95.897  -52.800  54.213  1
686511  95.912  -52.822  54.188  1
686512  95.926  -52.844  54.163  1
686513  95.940  -52.867  54.137  1
686514  95.954  -52.890  54.111  1
686515  95.969  -52.912  54.084  1
686516  95.983  -52.935  54.057  1
686517  95.997  -52.957  54.029  1
686518  96.011  -52.979  54.002  1
686519  96.026  -53.002  53.973  1
686520  96.040  -53.024  53.945  1
686521  96.054  -53.047  53.916  1
686522  96.068  -53.068  53.887  1
686523  96.077  -53.076  53.858  1
686524  96.086  -53.084  53.829  1
686525  96.094  -53.092  53.800  1
686526  96.103  -53.100  53.770  1
686527  96.112  -53.107  53.741  1
686528  96.121  -53.116  53.712  1
686529  96.130  -53.123  53.684  1
686530  96.138  -53.132  53.654  1
686561  96.739  -53.252  52.990  1
686562  96.761  -53.258  52.976  1
686563  96.783  -53.264  52.962  1
686564  96.805  -53.270  52.946  1
686565  96.827  -53.277  52.928  1
686566  96.849  -53.283  52.910  1
686578  97.184  -53.370  52.638  1
686579  97.217  -53.378  52.612  1
686580  97.250  -53.386  52.586  1
686581  97.284  -53.395  52.557  1
686582  97.317  -53.403  52.528  1
686583  97.350  -53.411  52.498  1
686584  97.383  -53.420  52.467  1
686585  97.416  -53.428  52.436  1
686586  97.449  -53.437  52.404  1
686587  97.491  -53.443  52.372  1
686588  97.542  -53.442  52.337  1
686589  97.540  -53.456  52.303  1
686590  97.552  -53.467  52.270  1
686591  97.574  -53.474  52.236  1
686592  97.595  -53.482  52.204  1
686593  97.618  -53.490  52.170  1
686594  97.649  -53.499  52.136  1
686595  97.680  -53.509  52.103  1
686596  97.711  -53.518  52.071  1
686597  97.742  -53.527  52.040  1
686598  97.773  -53.537  52.010  1
686599  97.803  -53.546  51.980  1
686600  97.835  -53.556  51.948  1
686601  97.865  -53.565  51.920  1
686602  97.877  -53.562  51.889  1
686603  97.892  -53.558  51.860  1
686604  97.910  -53.553  51.833  1
686605  97.926  -53.549  51.805  1
686606  97.943  -53.543  51.776  1
686607  97.956  -53.551  51.747  1
686608  97.969  -53.562  51.718  1
686609  97.981  -53.571  51.689  1
686610  97.993  -53.582  51.659  1
686611  98.016  -53.596  51.629  1
686612  98.041  -53.611  51.599  1
686613  98.067  -53.626  51.568  1
686614  98.092  -53.640  51.536  1
686615  98.118  -53.656  51.504  1
686616  98.144  -53.671  51.470  1
686617  98.169  -53.685  51.435  1
686618  98.195  -53.700  51.400  1
686619  98.216  -53.711  51.366  1
686620  98.234  -53.718  51.332  1
686621  98.252  -53.724  51.296  1
686622  98.283  -53.733  51.263  1
686623  98.315  -53.741  51.230  1
686624  98.335  -53.755  51.196  1
686625  98.350  -53.769  51.162  1
686626  98.372  -53.786  51.127  1
686627  98.397  -53.805  51.092  1
686628  98.423  -53.823  51.055  1
686629  98.448  -53.842  51.018  1
686630  98.474  -53.860  50.980  1
686631  98.499  -53.878  50.941  1
686632  98.525  -53.897  50.902  1
686633  98.550  -53.916  50.862  1
686634  98.576  -53.934  50.823  1
686635  98.601  -53.953  50.787  1
686636  98.627  -53.971  50.750  1
687198  95.666  -52.499  54.461  1
687199  95.693  -52.518  54.444  1
687200  95.720  -52.538  54.426  1
687201  95.747  -52.558  54.408  1
687202  95.773  -52.578  54.390  1
687203  95.795  -52.599  54.371  1
687204  95.808  -52.621  54.352  1
687205  95.822  -52.644  54.332  1
687206  95.836  -52.666  54.311  1
687207  95.850  -52.687  54.291  1
687208  95.865  -52.709  54.268  1
687209  95.878  -52.732  54.245  1
687210  95.892  -52.754  54.222  1
687211  95.906  -52.776  54.197  1
687212  95.920  -52.799  54.173  1
687213  95.935  -52.821  54.148  1
687214  95.949  -52.844  54.121  1
687215  95.963  -52.866  54.095  1
687216  95.977  -52.888  54.069  1
687217  95.991  -52.911  54.042  1
687218  96.006  -52.933  54.015  1
687219  96.020  -52.956  53.987  1
687220  96.034  -52.978  53.958  1
687221  96.048  -53.001  53.930  1
687222  96.063  -53.023  53.901  1
687223  96.077  -53.045  53.872  1
687224  96.088  -53.059  53.843  1
687225  96.097  -53.067  53.814  1
687226  96.106  -53.075  53.784  1
687227  96.114  -53.082  53.754  1
687264  96.793  -53.249  52.951  1
687265  96.814  -53.255  52.936  1
687281  97.249  -53.369  52.587  1
687282  97.283  -53.377  52.560  1
687283  97.316  -53.386  52.530  1
687284  97.349  -53.394  52.500  1
687285  97.382  -53.402  52.470  1
687286  97.415  -53.411  52.440  1
687287  97.448  -53.420  52.407  1
687288  97.481  -53.428  52.375  1
687289  97.549  -53.424  52.342  1
687290  97.564  -53.434  52.308  1
687291  97.562  -53.449  52.275  1
687292  97.579  -53.457  52.242  1
687293  97.600  -53.465  52.209  1
687294  97.621  -53.473  52.176  1
687295  97.649  -53.481  52.143  1
687296  97.679  -53.491  52.110  1
687297  97.711  -53.500  52.078  1
687298  97.741  -53.509  52.047  1
687299  97.772  -53.519  52.017  1
687300  97.803  -53.528  51.987  1
687301  97.834  -53.537  51.955  1
687302  97.865  -53.547  51.926  1
687303  97.882  -53.547  51.897  1
687304  97.893  -53.544  51.869  1
687305  97.910  -53.539  51.842  1
687306  97.927  -53.534  51.813  1
687307  97.944  -53.530  51.785  1
687308  97.959  -53.531  51.757  1
687309  97.971  -53.541  51.728  1
687310  97.983  -53.552  51.700  1
687311  97.996  -53.562  51.671  1
687312  98.018  -53.576  51.642  1
687313  98.043  -53.591  51.611  1
687314  98.069  -53.606  51.581  1
687315  98.094  -53.621  51.550  1
687316  98.120  -53.636  51.518  1
687317  98.146  -53.650  51.486  1
687318  98.171  -53.665  51.452  1
687319  98.197  -53.681  51.417  1
687320  98.222  -53.695  51.384  1
687321  98.242  -53.703  51.350  1
687322  98.260  -53.710  51.316  1
687323  98.284  -53.718  51.283  1
687324  98.316  -53.726  51.250  1
687325  98.340  -53.738  51.217  1
687326  98.355  -53.753  51.184  1
687327  98.374  -53.769  51.149  1
687328  98.400  -53.787  51.114  1
687329  98.425  -53.806  51.078  1
687330  98.450  -53.824  51.041  1
687331  98.476  -53.843  51.003  1
687332  98.501  -53.861  50.964  1
687333  98.526  -53.879  50.926  1
687334  98.552  -53.898  50.886  1
687335  98.577  -53.916  50.847  1
687336  98.603  -53.935  50.810  1
687337  98.628  -53.954  50.773  1
687900  95.711  -52.493  54.438  1
687901  95.739  -52.513  54.418  1
687902  95.765  -52.533  54.400  1
687903  95.790  -52.553  54.381  1
687904  95.803  -52.575  54.361  1
687905  95.817  -52.597  54.341  1
687906  95.831  -52.620  54.321  1
687907  95.845  -52.642  54.300  1
687908  95.860  -52.664  54.278  1
687909  95.873  -52.686  54.256  1
687910  95.887  -52.709  54.232  1
687911  95.901  -52.731  54.209  1
687912  95.915  -52.753  54.184  1
687913  95.930  -52.775  54.159  1
687914  95.944  -52.797  54.135  1
687915  95.958  -52.820  54.107  1
687916  95.972  -52.842  54.082  1
687917  95.986  -52.865  54.055  1
687918  96.001  -52.888  54.028  1
687919  96.015  -52.910  54.001  1
687920  96.029  -52.932  53.973  1
687921  96.043  -52.954  53.943  1
687922  96.057  -52.977  53.915  1
687923  96.072  -53.000  53.886  1
687924  96.086  -53.022  53.857  1
687983  97.282  -53.361  52.562  1
687984  97.315  -53.369  52.533  1
687985  97.348  -53.377  52.503  1
687986  97.381  -53.386  52.473  1
687987  97.414  -53.394  52.443  1
687988  97.447  -53.402  52.412  1
687989  97.480  -53.411  52.380  1
687990  97.523  -53.415  52.347  1
687991  97.587  -53.411  52.314  1
687992  97.585  -53.426  52.281  1
687993  97.585  -53.440  52.249  1
687994  97.606  -53.448  52.216  1
687995  97.628  -53.455  52.183  1
687996  97.649  -53.463  52.151  1
687997  97.679  -53.473  52.118  1
687998  97.710  -53.482  52.086  1
687999  97.741  -53.491  52.056  1
688000  97.772  -53.501  52.026  1
688001  97.803  -53.510  51.996  1
688002  97.834  -53.519  51.965  1
688003  97.865  -53.529  51.935  1
688004  97.887  -53.532  51.907  1
688005  97.898  -53.529  51.879  1
688006  97.910  -53.525  51.851  1
688007  97.927  -53.521  51.824  1
688008  97.944  -53.516  51.796  1
688009  97.961  -53.511  51.767  1
688010  97.973  -53.521  51.740  1
688011  97.986  -53.532  51.712  1
688012  97.998  -53.542  51.683  1
688013  98.020  -53.556  51.654  1
688014  98.045  -53.571  51.625  1
688015  98.071  -53.586  51.595  1
688016  98.096  -53.601  51.563  1
688017  98.122  -53.615  51.533  1
688018  98.148  -53.631  51.502  1
688019  98.173  -53.646  51.469  1
688020  98.199  -53.660  51.346  7
688021  98.224  -53.675  51.311  7
688022  98.249  -53.690  51.277  7
688023  98.267  -53.696  51.243  7
688024  98.285  -53.703  51.208  7
688025  98.317  -53.712  51.173  7
688026  98.345  -53.722  51.139  7
688027  98.360  -53.737  51.104  7
688028  98.376  -53.751  51.068  7
688029  98.401  -53.769  51.031  7
688030  98.426  -53.788  50.993  7
688031  98.452  -53.806  50.954  7
688032  98.477  -53.825  50.913  7
688033  98.503  -53.844  50.873  7
688034  98.528  -53.862  50.833  7
688035  98.554  -53.881  50.792  7
688036  98.579  -53.899  50.751  7
688037  98.604  -53.917  50.710  7
688038  98.630  -53.936  50.672  7
688602  95.757  -52.488  54.412  1
688603  95.784  -52.508  54.392  1
688604  95.799  -52.530  54.373  1
688605  95.812  -52.552  54.352  1
688606  95.826  -52.574  54.331  1
688607  95.840  -52.597  54.310  1
688608  95.854  -52.619  54.289  1
688609  95.869  -52.641  54.266  1
688610  95.882  -52.663  54.243  1
688611  95.896  -52.685  54.220  1
688612  95.910  -52.707  54.196  1
688613  95.924  -52.729  54.171  1
688614  95.939  -52.752  54.146  1
688615  95.952  -52.774  54.122  1
688616  95.967  -52.797  54.096  1
688617  95.981  -52.819  54.069  1
688618  95.995  -52.841  54.043  1
688619  96.009  -52.863  54.015  1
688620  96.024  -52.886  53.988  1
688621  96.038  -52.909  53.960  1
688689  97.446  -53.385  52.417  1
688690  97.479  -53.393  52.385  1
688691  97.513  -53.402  52.353  1
688692  97.582  -53.397  52.320  1
688693  97.608  -53.404  52.288  1
688694  97.606  -53.418  52.256  1
688695  97.611  -53.430  52.224  1
688696  97.633  -53.438  52.191  1
688697  97.654  -53.446  52.159  1
688698  97.679  -53.455  52.127  1
688699  97.710  -53.464  52.095  1
688700  97.741  -53.473  52.065  1
688701  97.772  -53.483  52.035  1
688702  97.803  -53.492  52.005  1
688703  97.833  -53.501  51.975  1
688704  97.864  -53.511  51.946  1
688705  97.891  -53.518  51.917  1
688706  97.902  -53.514  51.889  1
688707  97.914  -53.511  51.862  1
688708  97.928  -53.506  51.835  1
688709  97.944  -53.502  51.807  1
688710  97.961  -53.497  51.779  1
688711  97.975  -53.502  51.752  1
688712  97.988  -53.512  51.724  1
688713  98.000  -53.522  51.696  1
688714  98.022  -53.536  51.668  1
688715  98.048  -53.551  51.639  1
688716  98.073  -53.566  51.609  1
688717  98.098  -53.581  51.579  1
688718  98.124  -53.596  51.462  7
688719  98.150  -53.610  51.429  7
688720  98.175  -53.625  51.396  7
688721  98.201  -53.640  51.362  7
688722  98.226  -53.655  51.327  7
688723  98.252  -53.670  51.293  7
688724  98.275  -53.682  51.259  7
688725  98.292  -53.688  51.225  7
688726  98.318  -53.697  51.191  7
688727  98.349  -53.706  51.157  7
688728  98.365  -53.720  51.122  7
688729  98.380  -53.734  51.086  7
688730  98.403  -53.752  51.050  7
688731  98.428  -53.771  51.013  7
688732  98.453  -53.789  50.973  7
688733  98.479  -53.807  50.934  7
688734  98.504  -53.826  50.894  7
688735  98.530  -53.844  50.854  7
688736  98.555  -53.863  50.813  7
688737  98.581  -53.882  50.772  7
688738  98.606  -53.900  50.732  7
688739  98.632  -53.918  50.693  7
689304  95.794  -52.484  54.386  1
689305  95.807  -52.506  54.365  1
689306  95.821  -52.528  54.344  1
689307  95.835  -52.551  54.322  1
689308  95.849  -52.573  54.301  1
689309  95.864  -52.595  54.279  1
689310  95.877  -52.617  54.255  1
689311  95.891  -52.640  54.232  1
689312  95.905  -52.662  54.208  1
689313  95.919  -52.684  54.184  1
689314  95.934  -52.706  54.160  1
689315  95.947  -52.728  54.135  1
689316  95.961  -52.750  54.109  1
689317  95.975  -52.773  54.084  1
689318  95.989  -52.795  54.058  1
689319  96.004  -52.818  54.031  1
689396  97.628  -53.411  52.232  1
689397  97.639  -53.421  52.201  1
689398  97.660  -53.429  52.169  1
689399  97.681  -53.437  52.136  1
689400  97.710  -53.446  52.105  1
689401  97.741  -53.455  52.074  1
689402  97.772  -53.465  52.045  1
689403  97.802  -53.474  52.016  1
689404  97.833  -53.483  51.986  1
689405  97.864  -53.493  51.957  1
689406  97.895  -53.502  51.928  1
689407  97.908  -53.499  51.900  1
689408  97.919  -53.496  51.874  1
689409  97.930  -53.492  51.847  1
689410  97.945  -53.488  51.819  1
689411  97.962  -53.483  51.791  1
689412  97.978  -53.481  51.765  1
689413  97.990  -53.492  51.737  1
689414  98.002  -53.502  51.710  1
689415  98.024  -53.516  51.682  1
689416  98.050  -53.531  51.653  1
689417  98.075  -53.546  51.624  1
689418  98.100  -53.561  51.506  7
689419  98.126  -53.575  51.475  7
689420  98.152  -53.590  51.442  7
689421  98.177  -53.606  51.410  7
689422  98.203  -53.620  51.376  7
689423  98.228  -53.635  51.343  7
689424  98.253  -53.650  51.309  7
689425  98.279  -53.665  51.275  7
689426  98.300  -53.675  51.242  7
689427  98.319  -53.681  51.208  7
689428  98.352  -53.690  51.175  7
689429  98.370  -53.704  51.140  7
689430  98.385  -53.719  51.105  7
689431  98.405  -53.734  51.069  7
689432  98.430  -53.753  51.031  7
689433  98.455  -53.772  50.992  7
689434  98.481  -53.790  50.953  7
689435  98.506  -53.808  50.914  7
689436  98.531  -53.827  50.874  7
689437  98.557  -53.845  50.833  7
689438  98.582  -53.864  50.793  7
689439  98.608  -53.882  50.753  7
689440  98.633  -53.900  50.714  7
690008  95.844  -52.528  54.314  1
690009  95.859  -52.550  54.292  1
690010  95.872  -52.572  54.269  1
690011  95.886  -52.594  54.246  1
690012  95.900  -52.616  54.222  1
690013  95.914  -52.638  54.198  1
690014  95.928  -52.660  54.174  1
690015  95.942  -52.683  54.150  1
690016  95.956  -52.705  54.125  1
690100  97.687  -53.419  52.057  7
690101  97.710  -53.427  52.027  7
690102  97.740  -53.437  51.997  7
690103  97.771  -53.446  51.968  7
690104  97.802  -53.455  51.940  7
690105  97.833  -53.465  51.910  7
690106  97.864  -53.474  51.881  7
690107  97.895  -53.483  51.853  7
690108  97.912  -53.484  51.826  7
690109  97.923  -53.480  51.799  7
690110  97.935  -53.477  51.772  7
690111  97.946  -53.474  51.745  7
690112  97.962  -53.469  51.717  7
690113  97.979  -53.465  51.690  7
690114  97.992  -53.472  51.663  7
690115  98.004  -53.483  51.635  7
690116  98.026  -53.496  51.607  7
690117  98.052  -53.511  51.577  7
690118  98.077  -53.526  51.548  7
690119  98.102  -53.540  51.518  7
690120  98.128  -53.556  51.487  7
690121  98.154  -53.571  51.455  7
690122  98.179  -53.585  51.423  7
690123  98.205  -53.600  51.391  7
690124  98.230  -53.615  51.358  7
690125  98.255  -53.630  51.325  7
690126  98.281  -53.645  51.291  7
690127  98.307  -53.660  51.258  7
690128  98.325  -53.667  51.225  7
690129  98.353  -53.675  51.192  7
690130  98.374  -53.687  51.159  7
690131  98.390  -53.702  51.125  7
690132  98.406  -53.717  51.088  7
690133  98.432  -53.735  51.049  7
690134  98.457  -53.754  51.011  7
690135  98.483  -53.772  50.972  7
690136  98.508  -53.791  50.932  7
690137  98.533  -53.809  50.892  7
690138  98.559  -53.828  50.852  7
690139  98.584  -53.846  50.812  7
690140  98.609  -53.865  50.773  7
690141  98.635  -53.883  50.734  7
690800  97.671  -53.395  52.096  7
690801  97.692  -53.402  52.065  7
690802  97.714  -53.410  52.035  7
690803  97.740  -53.418  52.005  7
690804  97.771  -53.428  51.976  7
690805  97.802  -53.437  51.948  7
690806  97.833  -53.446  51.919  7
690807  97.864  -53.456  51.890  7
690808  97.894  -53.465  51.863  7
690809  97.917  -53.469  51.836  7
690810  97.928  -53.465  51.809  7
690811  97.939  -53.462  51.783  7
690812  97.950  -53.458  51.756  7
690813  97.962  -53.455  51.728  7
690814  97.980  -53.451  51.701  7
690815  97.994  -53.452  51.674  7
690816  98.007  -53.462  51.647  7
690817  98.028  -53.476  51.618  7
690818  98.054  -53.491  51.589  7
690819  98.079  -53.505  51.560  7
690820  98.104  -53.521  51.529  7
690821  98.130  -53.536  51.499  7
690822  98.156  -53.550  51.468  7
690823  98.181  -53.565  51.435  7
690824  98.207  -53.581  51.403  7
690825  98.232  -53.595  51.371  7
690826  98.257  -53.610  51.338  7
690827  98.283  -53.625  51.306  7
690828  98.309  -53.640  51.274  7
690829  98.333  -53.653  51.241  7
690830  98.354  -53.660  51.209  7
690831  98.379  -53.672  51.176  7
690832  98.395  -53.686  51.141  7
690833  98.411  -53.700  51.105  7
690834  98.433  -53.718  51.065  7
690835  98.458  -53.736  51.028  7
690836  98.484  -53.755  50.989  7
690837  98.509  -53.773  50.949  7
690838  98.535  -53.791  50.910  7
690839  98.560  -53.810  50.871  7
690840  98.586  -53.828  50.831  7
690841  98.611  -53.847  50.791  7
690842  98.637  -53.866  50.752  7
691501  97.693  -53.373  52.103  7
691502  97.698  -53.385  52.072  7
691503  97.719  -53.393  52.042  7
691504  97.740  -53.400  52.013  7
691505  97.771  -53.410  51.985  7
691506  97.802  -53.419  51.957  7
691507  97.832  -53.428  51.928  7
691508  97.863  -53.438  51.900  7
691509  97.894  -53.447  51.873  7
691510  97.922  -53.454  51.846  7
691511  97.933  -53.451  51.819  7
691512  97.944  -53.447  51.793  7
691513  97.955  -53.444  51.767  7
691514  97.966  -53.440  51.740  7
691515  97.980  -53.437  51.712  7
691516  97.997  -53.432  51.685  7
691517  98.009  -53.443  51.658  7
691518  98.030  -53.456  51.630  7
691519  98.056  -53.471  51.601  7
691520  98.081  -53.486  51.572  7
691521  98.106  -53.501  51.541  7
691522  98.132  -53.515  51.512  7
691523  98.157  -53.531  51.480  7
691524  98.183  -53.546  51.448  7
691525  98.209  -53.560  51.416  7
691526  98.234  -53.575  51.384  7
691527  98.260  -53.590  51.352  7
691528  98.285  -53.605  51.320  7
691529  98.311  -53.620  51.289  7
691530  98.336  -53.634  51.257  7
691531  98.358  -53.646  51.226  7
691532  98.384  -53.655  51.193  7
691533  98.400  -53.669  51.158  7
691534  98.415  -53.684  51.121  7
691535  98.435  -53.700  51.082  7
691536  98.460  -53.719  51.045  7
691537  98.486  -53.737  51.006  7
691538  98.511  -53.756  50.967  7
691539  98.536  -53.774  50.928  7
691540  98.562  -53.793  50.889  7
691541  98.587  -53.811  50.849  7
691542  98.613  -53.829  50.810  7
691543  98.638  -53.848  50.771  7
692202  97.716  -53.350  52.112  7
692203  97.714  -53.364  52.081  7
692204  97.725  -53.376  52.052  7
692205  97.746  -53.383  52.023  7
692206  97.771  -53.392  51.995  7
692207  97.801  -53.401  51.967  7
692208  97.832  -53.410  51.939  7
692209  97.863  -53.420  51.911  7
692210  97.894  -53.429  51.884  7
692211  97.925  -53.438  51.858  7
692212  97.938  -53.436  51.831  7
692213  97.949  -53.433  51.805  7
692214  97.960  -53.429  51.778  7
692215  97.971  -53.426  51.751  7
692216  97.983  -53.422  51.725  7
692217  97.997  -53.418  51.698  7
692218  98.011  -53.423  51.670  7
692219  98.032  -53.436  51.642  7
692220  98.058  -53.451  51.614  7
692221  98.083  -53.466  51.584  7
692222  98.108  -53.480  51.555  7
692223  98.134  -53.496  51.524  7
692224  98.159  -53.511  51.493  7
692225  98.185  -53.525  51.462  7
692226  98.211  -53.540  51.430  7
692227  98.236  -53.556  51.398  7
692228  98.262  -53.570  51.365  7
692229  98.287  -53.585  51.334  7
692230  98.313  -53.599  51.303  7
692231  98.338  -53.615  51.273  7
692232  98.364  -53.630  51.242  7
692233  98.388  -53.639  51.210  7
692234  98.405  -53.653  51.175  7
692235  98.420  -53.668  51.136  7
692236  98.437  -53.683  51.098  7
692237  98.462  -53.701  51.061  7
692238  98.488  -53.719  51.023  7
692239  98.513  -53.738  50.984  7
692240  98.538  -53.756  50.945  7
692241  98.564  -53.775  50.906  7
692242  98.589  -53.794  50.868  7
692243  98.615  -53.812  50.829  7
692244  98.640  -53.830  50.790  7
692903  97.739  -53.328  52.121  7
692904  97.737  -53.342  52.090  7
692905  97.736  -53.357  52.061  7
692906  97.752  -53.366  52.033  7
692907  97.773  -53.374  52.006  7
692908  97.801  -53.383  51.979  7
692909  97.832  -53.392  51.951  7
692910  97.863  -53.402  51.923  7
692911  97.894  -53.411  51.897  7
692912  97.925  -53.420  51.871  7
692913  97.942  -53.421  51.845  7
692914  97.953  -53.418  51.819  7
692915  97.965  -53.414  51.792  7
692916  97.976  -53.411  51.765  7
692917  97.987  -53.407  51.738  7
692918  97.998  -53.404  51.712  7
692919  98.013  -53.403  51.685  7
692920  98.034  -53.416  51.657  7
692921  98.060  -53.431  51.628  7
692922  98.085  -53.446  51.598  7
692923  98.110  -53.461  51.567  7
692924  98.136  -53.476  51.537  7
692925  98.161  -53.490  51.506  7
692926  98.187  -53.505  51.475  7
692927  98.213  -53.521  51.443  7
692928  98.238  -53.535  51.411  7
692929  98.264  -53.550  51.379  7
692930  98.289  -53.565  51.348  7
692931  98.315  -53.580  51.318  7
692932  98.340  -53.595  51.288  7
692933  98.366  -53.609  51.258  7
692934  98.391  -53.624  51.226  7
692935  98.410  -53.637  51.191  7
692936  98.425  -53.651  51.153  7
692937  98.440  -53.665  51.115  7
692938  98.463  -53.684  51.077  7
692939  98.489  -53.702  51.039  7
692940  98.514  -53.720  51.002  7
692941  98.540  -53.739  50.964  7
692942  98.565  -53.757  50.925  7
692943  98.591  -53.776  50.886  7
692944  98.616  -53.794  50.848  7
692945  98.642  -53.813  50.810  7
692946  98.667  -53.831  50.772  7
693604  97.762  -53.306  52.130  7
693605  97.760  -53.321  52.101  7
693606  97.758  -53.335  52.072  7
693607  97.757  -53.349  52.044  7
693608  97.779  -53.357  52.016  7
693609  97.801  -53.364  51.991  7
693610  97.832  -53.374  51.962  7
693611  97.863  -53.383  51.937  7
693612  97.893  -53.393  51.911  7
693613  97.925  -53.402  51.885  7
693614  97.947  -53.406  51.861  7
693615  97.958  -53.402  51.836  7
693616  97.969  -53.399  51.809  7
693617  97.981  -53.396  51.781  7
693618  97.992  -53.393  51.754  7
693619  98.003  -53.389  51.726  7
693620  98.015  -53.385  51.700  7
693621  98.036  -53.396  51.672  7
693622  98.061  -53.411  51.642  7
693623  98.087  -53.426  51.612  7
693624  98.112  -53.441  51.581  7
693625  98.138  -53.455  51.551  7
693626  98.163  -53.471  51.520  7
693627  98.189  -53.485  51.488  7
693628  98.215  -53.500  51.456  7
693629  98.240  -53.515  51.425  7
693630  98.266  -53.530  51.393  7
693631  98.291  -53.545  51.362  7
693632  98.317  -53.561  51.333  7
693633  98.344  -53.576  51.303  7
693634  98.370  -53.592  51.273  7
693635  98.396  -53.606  51.242  7
693636  98.414  -53.620  51.207  7
693637  98.430  -53.635  51.170  7
693638  98.445  -53.650  51.132  7
693639  98.465  -53.665  51.094  7
693640  98.491  -53.684  51.057  7
693641  98.516  -53.703  51.019  7
693642  98.541  -53.722  50.982  7
693643  98.567  -53.740  50.943  7
693644  98.592  -53.758  50.906  7
693645  98.618  -53.777  50.868  7
693646  98.643  -53.795  50.829  7
693647  98.668  -53.814  50.792  7
694305  97.785  -53.283  52.140  7
694306  97.783  -53.298  52.111  7
694307  97.782  -53.312  52.083  7
694308  97.780  -53.327  52.056  7
694309  97.784  -53.339  52.029  7
694310  97.806  -53.347  52.003  7
694311  97.831  -53.355  51.976  7
694312  97.862  -53.365  51.951  7
694313  97.893  -53.374  51.925  7
694314  97.924  -53.383  51.901  7
694315  97.952  -53.391  51.879  7
694316  97.963  -53.387  51.856  7
694317  97.974  -53.384  51.828  7
694318  97.986  -53.380  51.801  7
694319  97.997  -53.377  51.771  7
694320  98.008  -53.374  51.743  7
694321  98.019  -53.371  51.716  7
694322  98.041  -53.380  51.688  7
694323  98.068  -53.396  51.658  7
694324  98.094  -53.411  51.626  7
694325  98.120  -53.427  51.596  7
694326  98.146  -53.442  51.565  7
694327  98.172  -53.457  51.535  7
694328  98.198  -53.473  51.503  7
694329  98.224  -53.488  51.470  7
694330  98.250  -53.503  51.439  7
694331  98.276  -53.519  51.408  7
694332  98.302  -53.534  51.377  7
694333  98.328  -53.550  51.348  7
694334  98.355  -53.565  51.319  7
694335  98.386  -53.574  51.289  7
694336  98.415  -53.584  51.257  7
694337  98.421  -53.602  51.223  7
694338  98.435  -53.618  51.186  7
694339  98.450  -53.633  51.149  7
694340  98.467  -53.648  51.111  7
694341  98.493  -53.667  51.074  7
694342  98.518  -53.685  51.037  7
694343  98.544  -53.703  50.999  7
694344  98.569  -53.722  50.962  7
694345  98.594  -53.740  50.925  7
694346  98.620  -53.759  50.887  7
694347  98.645  -53.778  50.849  7
694348  98.670  -53.797  50.812  7
694349  98.694  -53.817  50.774  7
695006  97.770  -53.272  52.151  7
695007  97.806  -53.276  52.122  7
695008  97.805  -53.290  52.095  7
695009  97.803  -53.305  52.068  7
695010  97.801  -53.319  52.042  7
695011  97.811  -53.330  52.016  7
695012  97.832  -53.338  51.990  7
695013  97.862  -53.347  51.965  7
695014  97.893  -53.356  51.940  7
695015  97.924  -53.365  51.918  7
695016  97.955  -53.375  51.897  7
695017  97.967  -53.373  51.875  7
695018  97.979  -53.369  51.848  7
695019  97.990  -53.366  51.819  7
695020  98.001  -53.362  51.788  7
695021  98.013  -53.359  51.759  7
695022  98.024  -53.355  51.730  7
695023  98.051  -53.370  51.701  7
695024  98.078  -53.385  51.671  7
695025  98.104  -53.400  51.640  7
695026  98.130  -53.415  51.609  7
695027  98.156  -53.431  51.578  7
695028  98.182  -53.446  51.546  7
695029  98.209  -53.462  51.515  7
695030  98.235  -53.477  51.483  7
695031  98.261  -53.493  51.451  7
695032  98.287  -53.509  51.420  7
695033  98.313  -53.524  51.390  7
695034  98.345  -53.532  51.360  7
695035  98.376  -53.541  51.332  7
695036  98.408  -53.550  51.302  7
695037  98.427  -53.562  51.270  7
695038  98.434  -53.579  51.237  7
695039  98.439  -53.603  51.202  7
695040  98.455  -53.617  51.164  7
695041  98.471  -53.631  51.127  7
695042  98.494  -53.649  51.091  7
695043  98.520  -53.668  51.054  7
695044  98.545  -53.686  51.017  7
695045  98.571  -53.705  50.980  7
695046  98.596  -53.723  50.942  7
695047  98.622  -53.741  50.904  7
695048  98.647  -53.760  50.867  7
695049  98.671  -53.780  50.830  7
695050  98.696  -53.800  50.792  7
695051  98.720  -53.820  50.755  7
695052  98.744  -53.840  50.718  7
695053  98.769  -53.860  50.681  7
695054  98.795  -53.879  50.646  7
695055  98.822  -53.888  50.612  7
695707  97.744  -53.264  52.162  7
695708  97.828  -53.254  52.134  7
695709  97.827  -53.268  52.106  7
695710  97.826  -53.283  52.080  7
695711  97.824  -53.297  52.054  7
695712  97.822  -53.311  52.030  7
695713  97.838  -53.321  52.005  7
695714  97.862  -53.329  51.980  7
695715  97.893  -53.338  51.956  7
695716  97.924  -53.347  51.935  7
695717  97.955  -53.357  51.916  7
695718  97.972  -53.358  51.894  7
695719  97.984  -53.354  51.867  7
695720  97.995  -53.351  51.837  7
695721  98.006  -53.347  51.805  7
695722  98.017  -53.344  51.774  7
695723  98.033  -53.346  51.744  7
695724  98.060  -53.360  51.714  7
695725  98.088  -53.375  51.683  7
695726  98.115  -53.389  51.652  7
695727  98.141  -53.405  51.620  7
695728  98.167  -53.421  51.590  7
695729  98.193  -53.436  51.558  7
695730  98.219  -53.451  51.526  7
695731  98.245  -53.467  51.495  7
695732  98.272  -53.482  51.463  7
695733  98.303  -53.491  51.432  7
695734  98.335  -53.499  51.402  7
695735  98.366  -53.509  51.372  7
695736  98.398  -53.518  51.344  7
695737  98.429  -53.526  51.314  7
695738  98.438  -53.541  51.283  7
695739  98.447  -53.556  51.251  7
695740  98.448  -53.583  51.216  7
695741  98.460  -53.600  51.179  7
695742  98.476  -53.615  51.143  7
695743  98.496  -53.631  51.106  7
695744  98.521  -53.650  51.070  7
695745  98.547  -53.668  51.033  7
695746  98.572  -53.687  50.996  7
695747  98.597  -53.706  50.959  7
695748  98.623  -53.724  50.921  7
695749  98.648  -53.743  50.884  7
695750  98.672  -53.762  50.846  7
695751  98.697  -53.783  50.809  7
695752  98.721  -53.803  50.772  7
695753  98.746  -53.823  50.735  7
695754  98.770  -53.843  50.698  7
695755  98.797  -53.859  50.663  7
695756  98.824  -53.868  50.628  7
695757  98.850  -53.877  50.594  7
695758  98.877  -53.886  50.561  7
696408  97.718  -53.255  52.172  7
696409  97.803  -53.245  52.145  7
696410  97.851  -53.245  52.118  7
696411  97.849  -53.260  52.092  7
696412  97.847  -53.274  52.066  7
696413  97.846  -53.289  52.043  7
696414  97.844  -53.303  52.018  7
696415  97.865  -53.311  51.994  7
696416  97.892  -53.320  51.972  7
696417  97.924  -53.329  51.952  7
696418  97.954  -53.339  51.934  7
696419  97.977  -53.342  51.912  7
696420  97.989  -53.339  51.884  7
696421  98.000  -53.336  51.853  7
696422  98.011  -53.333  51.821  7
696423  98.022  -53.329  51.790  7
696424  98.042  -53.336  51.758  7
696425  98.070  -53.350  51.725  7
696426  98.097  -53.365  51.694  7
696427  98.124  -53.380  51.662  7
696428  98.152  -53.394  51.631  7
696429  98.178  -53.410  51.601  7
696430  98.204  -53.425  51.570  7
696431  98.230  -53.440  51.538  7
696432  98.262  -53.449  51.506  7
696433  98.293  -53.458  51.474  7
696434  98.324  -53.467  51.443  7
696435  98.356  -53.476  51.413  7
696436  98.388  -53.485  51.383  7
696437  98.420  -53.493  51.355  7
696438  98.440  -53.505  51.325  7
696439  98.449  -53.520  51.295  7
696440  98.459  -53.535  51.264  7
696441  98.461  -53.559  51.230  7
696442  98.464  -53.584  51.194  7
696443  98.480  -53.599  51.157  7
696444  98.498  -53.614  51.121  7
696445  98.523  -53.632  51.085  7
696446  98.549  -53.651  51.049  7
696447  98.574  -53.669  51.012  7
696448  98.599  -53.688  50.975  7
696449  98.625  -53.706  50.938  7
696450  98.649  -53.726  50.900  7
696451  98.674  -53.746  50.863  7
696452  98.699  -53.766  50.825  7
696453  98.723  -53.786  50.788  7
696454  98.747  -53.806  50.752  7
696455  98.772  -53.826  50.715  7
696456  98.799  -53.838  50.679  7
696457  98.826  -53.847  50.644  7
696458  98.852  -53.856  50.609  7
696459  98.878  -53.866  50.577  7
696460  98.905  -53.875  50.545  7
697109  97.700  -53.244  52.184  7
697110  97.777  -53.237  52.156  7
697111  97.861  -53.227  52.130  7
697112  97.872  -53.238  52.104  7
697113  97.870  -53.252  52.079  7
697114  97.869  -53.267  52.057  7
697115  97.867  -53.281  52.033  7
697116  97.871  -53.294  52.012  7
697117  97.892  -53.302  51.992  7
697118  97.923  -53.311  51.973  7
697119  97.954  -53.321  51.954  7
697120  97.982  -53.327  51.932  7
697121  97.993  -53.324  51.903  7
697122  98.004  -53.321  51.871  7
697123  98.015  -53.317  51.837  7
697124  98.027  -53.314  51.804  7
697125  98.052  -53.326  51.771  7
697126  98.079  -53.340  51.737  7
697127  98.106  -53.355  51.705  7
697128  98.134  -53.370  51.673  7
697129  98.161  -53.384  51.642  7
697130  98.188  -53.399  51.612  7
697131  98.218  -53.409  51.581  7
697132  98.249  -53.418  51.549  7
697133  98.281  -53.427  51.516  7
697134  98.311  -53.437  51.485  7
697135  98.343  -53.446  51.454  7
697136  98.374  -53.455  51.425  7
697137  98.405  -53.465  51.395  7
697138  98.436  -53.474  51.366  7
697139  98.452  -53.484  51.336  7
697140  98.461  -53.499  51.305  7
697141  98.471  -53.514  51.274  7
697142  98.474  -53.536  51.242  7
697143  98.475  -53.563  51.207  7
697144  98.485  -53.582  51.171  7
697145  98.501  -53.596  51.135  7
697146  98.525  -53.615  51.099  7
697147  98.550  -53.634  51.064  7
697148  98.576  -53.652  51.028  7
697149  98.601  -53.670  50.991  7
697150  98.627  -53.689  50.955  7
697151  98.651  -53.709  50.917  7
697152  98.675  -53.728  50.880  7
697153  98.700  -53.749  50.842  7
697154  98.724  -53.769  50.805  7
697155  98.748  -53.789  50.769  7
697156  98.774  -53.808  50.732  7
697157  98.801  -53.818  50.696  7
697158  98.828  -53.827  50.660  7
697159  98.854  -53.836  50.626  7
697160  98.880  -53.845  50.592  7
697161  98.907  -53.854  50.559  7
697162  98.933  -53.863  50.528  7
697810  97.699  -53.227  52.196  7
697811  97.750  -53.228  52.168  7
697812  97.835  -53.219  52.141  7
697813  97.895  -53.216  52.116  7
697814  97.893  -53.230  52.093  7
697815  97.891  -53.245  52.071  7
697816  97.890  -53.259  52.048  7
697817  97.888  -53.273  52.030  7
697818  97.897  -53.284  52.014  7
697819  97.923  -53.292  51.996  7
697820  97.954  -53.302  51.976  7
697821  97.985  -53.311  51.953  7
697822  97.998  -53.309  51.922  7
697823  98.009  -53.306  51.888  7
697824  98.020  -53.302  51.853  7
697825  98.033  -53.301  51.818  7
697826  98.061  -53.316  51.783  7
697827  98.088  -53.330  51.749  7
697828  98.115  -53.346  51.716  7
697829  98.143  -53.360  51.684  7
697830  98.170  -53.374  51.653  7
697831  98.197  -53.386  51.622  7
697832  98.225  -53.396  51.591  7
697833  98.256  -53.406  51.559  7
697834  98.287  -53.415  51.527  7
697835  98.318  -53.424  51.495  7
697836  98.349  -53.433  51.465  7
697837  98.380  -53.443  51.436  7
697838  98.412  -53.452  51.405  7
697839  98.442  -53.462  51.376  7
697840  98.461  -53.465  51.346  7
697841  98.473  -53.478  51.315  7
697842  98.482  -53.493  51.285  7
697843  98.487  -53.513  51.254  7
697844  98.488  -53.540  51.221  7
697845  98.490  -53.566  51.185  7
697846  98.505  -53.581  51.149  7
697847  98.526  -53.597  51.115  7
697848  98.552  -53.615  51.080  7
697849  98.577  -53.634  51.044  7
697850  98.603  -53.653  51.008  7
697851  98.628  -53.672  50.971  7
697852  98.652  -53.692  50.934  7
697853  98.676  -53.712  50.897  7
697854  98.701  -53.731  50.860  7
697855  98.725  -53.752  50.823  7
697856  98.750  -53.772  50.786  7
697857  98.777  -53.788  50.749  7
697858  98.803  -53.797  50.713  7
697859  98.830  -53.806  50.677  7
697860  98.856  -53.816  50.642  7
697861  98.882  -53.825  50.608  7
697862  98.909  -53.834  50.575  7
697863  98.935  -53.843  50.544  7
697864  98.961  -53.852  50.513  7
697865  98.988  -53.862  50.482  7
698511  97.698  -53.209  52.208  7
698512  97.731  -53.217  52.181  7
698513  97.809  -53.210  52.156  7
698514  97.893  -53.201  52.131  7
698515  97.916  -53.208  52.108  7
698516  97.915  -53.222  52.087  7
698517  97.913  -53.236  52.067  7
698518  97.911  -53.251  52.052  7
698519  97.910  -53.265  52.038  7
698520  97.924  -53.275  52.020  7
698521  97.954  -53.284  51.999  7
698522  97.985  -53.293  51.975  7
698523  98.003  -53.295  51.941  7
698524  98.014  -53.291  51.905  7
698525  98.025  -53.288  51.869  7
698526  98.042  -53.291  51.831  7
698527  98.070  -53.306  51.795  7
698528  98.097  -53.321  51.760  7
698529  98.125  -53.336  51.727  7
698530  98.152  -53.350  51.694  7
698531  98.178  -53.361  51.663  7
698532  98.205  -53.373  51.631  7
698533  98.232  -53.384  51.600  7
698534  98.263  -53.393  51.569  7
698535  98.294  -53.403  51.537  7
698536  98.325  -53.412  51.506  7
698537  98.356  -53.421  51.476  7
698538  98.387  -53.430  51.446  7
698539  98.418  -53.440  51.415  7
698540  98.446  -53.448  51.386  7
698541  98.465  -53.452  51.356  7
698542  98.484  -53.457  51.326  7
698543  98.493  -53.471  51.297  7
698544  98.500  -53.490  51.266  7
698545  98.501  -53.517  51.234  7
698546  98.502  -53.543  51.199  7
698547  98.510  -53.564  51.164  7
698548  98.528  -53.580  51.130  7
698549  98.554  -53.598  51.095  7
698550  98.579  -53.617  51.060  7
698551  98.604  -53.635  51.024  7
698552  98.629  -53.655  50.987  7
698553  98.654  -53.675  50.950  7
698554  98.678  -53.694  50.914  7
698555  98.703  -53.715  50.877  7
698556  98.727  -53.734  50.840  7
698557  98.751  -53.755  50.803  7
698558  98.778  -53.768  50.766  7
698559  98.805  -53.777  50.730  7
698560  98.831  -53.786  50.694  7
698561  98.858  -53.795  50.659  7
698562  98.884  -53.804  50.624  7
698563  98.911  -53.813  50.591  7
698564  98.937  -53.822  50.559  7
698565  98.963  -53.832  50.527  7
698566  98.990  -53.841  50.495  7
699212  97.697  -53.192  52.221  7
699213  97.730  -53.200  52.194  7
699214  97.783  -53.201  52.169  7
699215  97.867  -53.192  52.146  7
699216  97.939  -53.186  52.123  7
699217  97.938  -53.200  52.103  7
699218  97.936  -53.214  52.085  7
699219  97.934  -53.229  52.072  7
699220  97.933  -53.243  52.059  7
699221  97.931  -53.258  52.042  7
699222  97.953  -53.266  52.020  7
699223  97.984  -53.275  51.993  7
699224  98.007  -53.280  51.957  7
699225  98.018  -53.276  51.920  7
699226  98.030  -53.273  51.881  7
699227  98.052  -53.281  51.844  7
699228  98.079  -53.296  51.807  7
699229  98.106  -53.311  51.771  7
699230  98.134  -53.326  51.737  7
699231  98.160  -53.337  51.705  7
699232  98.187  -53.349  51.672  7
699233  98.213  -53.360  51.641  7
699234  98.240  -53.371  51.610  7
699235  98.270  -53.381  51.579  7
699236  98.301  -53.390  51.547  7
699237  98.332  -53.399  51.516  7
699238  98.363  -53.409  51.486  7
699239  98.394  -53.418  51.457  7
699240  98.425  -53.427  51.427  7
699241  98.449  -53.434  51.397  7
699242  98.469  -53.439  51.367  7
699243  98.489  -53.443  51.338  7
699244  98.505  -53.450  51.309  7
699245  98.513  -53.467  51.278  7
699246  98.514  -53.493  51.247  7
699247  98.515  -53.521  51.214  7
699248  98.516  -53.547  51.180  7
699249  98.530  -53.562  51.145  7
699250  98.555  -53.581  51.110  7
699251  98.581  -53.599  51.076  7
699252  98.606  -53.618  51.040  7
699253  98.631  -53.637  51.005  7
699254  98.655  -53.658  50.967  7
699255  98.679  -53.678  50.931  7
699256  98.704  -53.697  50.894  7
699257  98.728  -53.718  50.857  7
699258  98.753  -53.737  50.820  7
699259  98.780  -53.747  50.783  7
699260  98.807  -53.756  50.747  7
699261  98.833  -53.766  50.712  7
699262  98.860  -53.775  50.676  7
699263  98.886  -53.784  50.641  7
699264  98.913  -53.793  50.607  7
699265  98.939  -53.802  50.573  7
699266  98.966  -53.812  50.541  7
699267  98.992  -53.821  50.509  7
699913  97.696  -53.174  52.235  7
699914  97.729  -53.183  52.208  7
699915  97.762  -53.191  52.183  7
699916  97.842  -53.183  52.161  7
699917  97.926  -53.173  52.139  7
699918  97.960  -53.178  52.120  7
699919  97.959  -53.192  52.102  7
699920  97.957  -53.207  52.090  7
699921  97.955  -53.221  52.077  7
699922  97.954  -53.236  52.060  7
699923  97.957  -53.248  52.038  7
699924  97.984  -53.257  52.009  7
699925  98.012  -53.264  51.972  7
699926  98.023  -53.261  51.933  7
699927  98.034  -53.258  51.893  7
699928  98.061  -53.271  51.854  7
699929  98.088  -53.286  51.817  7
699930  98.116  -53.301  51.781  7
699931  98.142  -53.312  51.747  7
699932  98.169  -53.324  51.714  7
699933  98.196  -53.335  51.681  7
699934  98.222  -53.346  51.650  7
699935  98.248  -53.358  51.619  7
699936  98.276  -53.369  51.588  7
699937  98.307  -53.378  51.557  7
699938  98.339  -53.387  51.526  7
699939  98.369  -53.396  51.496  7
699940  98.401  -53.406  51.467  7
699941  98.432  -53.415  51.438  7
699942  98.453  -53.421  51.408  7
699943  98.473  -53.425  51.378  7
699944  98.492  -53.430  51.349  7
699945  98.512  -53.434  51.319  7
699946  98.525  -53.444  51.290  7
699947  98.527  -53.471  51.259  7
699948  98.528  -53.497  51.226  7
699949  98.529  -53.524  51.192  7
699950  98.535  -53.546  51.158  7
699951  98.557  -53.563  51.124  7
699952  98.582  -53.581  51.090  7
699953  98.607  -53.600  51.055  7
699954  98.632  -53.621  51.019  7
699955  98.656  -53.640  50.983  7
699956  98.680  -53.661  50.946  7
699957  98.705  -53.681  50.910  7
699958  98.729  -53.700  50.873  7
699959  98.756  -53.718  50.836  7
699960  98.782  -53.727  50.799  7
699961  98.808  -53.736  50.762  7
699962  98.835  -53.745  50.727  7
699963  98.861  -53.754  50.691  7
699964  98.888  -53.763  50.656  7
699965  98.914  -53.772  50.621  7
699966  98.941  -53.781  50.587  7
699967  98.967  -53.791  50.553  7
699968  98.994  -53.800  50.521  7
699969  99.020  -53.809  50.488  7
700614  97.695  -53.157  52.247  7
700615  97.728  -53.165  52.222  7
700616  97.761  -53.173  52.198  7
700617  97.815  -53.175  52.176  7
700618  97.900  -53.165  52.155  7
700619  97.984  -53.156  52.139  7
700620  97.982  -53.170  52.119  7
700621  97.980  -53.184  52.103  7
700622  97.979  -53.198  52.089  7
700623  97.977  -53.213  52.071  7
700624  97.975  -53.227  52.048  7
700625  97.984  -53.239  52.020  7
700626  98.015  -53.248  51.984  7
700627  98.028  -53.246  51.943  7
700628  98.043  -53.247  51.903  7
700629  98.070  -53.261  51.863  7
700630  98.098  -53.277  51.825  7
700631  98.124  -53.288  51.790  7
700632  98.151  -53.299  51.756  7
700633  98.177  -53.311  51.723  7
700634  98.204  -53.322  51.690  7
700635  98.230  -53.333  51.659  7
700636  98.256  -53.345  51.628  7
700637  98.283  -53.356  51.597  7
700638  98.314  -53.366  51.567  7
700639  98.345  -53.375  51.536  7
700640  98.376  -53.384  51.505  7
700641  98.407  -53.393  51.476  7
700642  98.438  -53.402  51.448  7
700643  98.457  -53.407  51.419  7
700644  98.477  -53.411  51.389  7
700645  98.496  -53.416  51.359  7
700646  98.516  -53.421  51.330  7
700647  98.535  -53.425  51.301  7
700648  98.540  -53.447  51.271  7
700649  98.541  -53.474  51.238  7
700650  98.541  -53.501  51.204  7
700651  98.543  -53.527  51.171  7
700652  98.559  -53.546  51.138  7
700653  98.584  -53.564  51.103  7
700654  98.609  -53.584  51.068  7
700655  98.633  -53.603  51.033  7
700656  98.658  -53.624  50.997  7
700657  98.682  -53.643  50.961  7
700658  98.707  -53.663  50.925  7
700659  98.731  -53.684  50.888  7
700660  98.758  -53.697  50.851  7
700661  98.784  -53.706  50.814  7
700662  98.810  -53.715  50.776  7
700663  98.837  -53.725  50.741  7
700664  98.863  -53.734  50.705  7
700665  98.890  -53.743  50.669  7
700666  98.916  -53.752  50.633  7
700667  98.943  -53.761  50.599  7
700668  98.969  -53.771  50.565  7
700669  98.996  -53.780  50.531  7
700670  99.022  -53.789  50.497  7
701315  97.694  -53.140  52.260  7
701316  97.727  -53.148  52.235  7
701317  97.760  -53.157  52.212  7
701318  97.794  -53.165  52.190  7
701319  97.874  -53.157  52.173  7
701320  97.958  -53.147  52.158  7
701321  98.005  -53.148  52.136  7
701322  98.003  -53.162  52.117  7
701323  98.002  -53.176  52.101  7
701324  98.000  -53.191  52.081  7
701325  97.998  -53.205  52.055  7
701326  97.996  -53.220  52.026  7
701327  98.014  -53.230  51.991  7
701328  98.033  -53.231  51.951  7
701329  98.052  -53.237  51.910  7
701330  98.080  -53.252  51.871  7
701331  98.106  -53.264  51.833  7
701332  98.133  -53.275  51.798  7
701333  98.159  -53.286  51.763  7
701334  98.185  -53.298  51.731  7
701335  98.212  -53.309  51.699  7
701336  98.238  -53.321  51.667  7
701337  98.265  -53.332  51.637  7
701338  98.292  -53.343  51.606  7
701339  98.320  -53.353  51.575  7
701340  98.352  -53.362  51.544  7
701341  98.383  -53.372  51.515  7
701342  98.414  -53.381  51.486  7
701343  98.442  -53.389  51.457  7
701344  98.461  -53.393  51.428  7
701345  98.481  -53.398  51.398  7
701346  98.500  -53.402  51.369  7
701347  98.520  -53.407  51.340  7
701348  98.533  -53.419  51.311  7
701349  98.542  -53.437  51.281  7
701350  98.551  -53.455  51.248  7
701351  98.555  -53.477  51.215  7
701352  98.556  -53.505  51.183  7
701353  98.561  -53.528  51.151  7
701354  98.586  -53.546  51.116  7
701355  98.610  -53.566  51.080  7
701356  98.635  -53.587  51.045  7
701357  98.659  -53.606  51.009  7
701358  98.684  -53.627  50.973  7
701359  98.708  -53.646  50.937  7
701360  98.732  -53.666  50.901  7
701361  98.760  -53.677  50.864  7
701362  98.786  -53.686  50.827  7
701363  98.812  -53.695  50.789  7
701364  98.839  -53.704  50.753  7
701365  98.865  -53.713  50.716  7
701366  98.891  -53.722  50.680  7
701367  98.918  -53.731  50.644  7
701368  98.944  -53.741  50.609  7
701369  98.971  -53.750  50.574  7
701370  98.997  -53.759  50.540  7
701371  99.024  -53.769  50.505  7
702016  97.693  -53.123  52.272  7
702017  97.726  -53.131  52.247  7
702018  97.759  -53.139  52.224  7
702019  97.793  -53.148  52.205  7
702020  97.848  -53.148  52.191  7
702021  97.932  -53.139  52.175  7
702022  98.017  -53.129  52.154  7
702023  98.026  -53.140  52.132  7
702024  98.024  -53.154  52.112  7
702025  98.023  -53.169  52.090  7
702026  98.021  -53.183  52.061  7
702027  98.019  -53.198  52.030  7
702028  98.018  -53.212  51.995  7
702029  98.037  -53.216  51.957  7
702030  98.062  -53.227  51.917  7
702031  98.088  -53.239  51.877  7
702032  98.114  -53.250  51.841  7
702033  98.141  -53.261  51.806  7
702034  98.167  -53.273  51.772  7
702035  98.194  -53.284  51.740  7
702036  98.221  -53.295  51.708  7
702037  98.247  -53.307  51.677  7
702038  98.274  -53.318  51.646  7
702039  98.300  -53.330  51.615  7
702040  98.327  -53.341  51.584  7
702041  98.358  -53.350  51.554  7
702042  98.389  -53.359  51.524  7
702043  98.421  -53.369  51.496  7
702044  98.446  -53.376  51.467  7
702045  98.465  -53.380  51.438  7
702046  98.485  -53.384  51.409  7
702047  98.504  -53.389  51.380  7
702048  98.519  -53.399  51.351  7
702049  98.527  -53.418  51.321  7
702050  98.536  -53.435  51.291  7
702051  98.545  -53.452  51.261  7
702052  98.554  -53.471  51.228  7
702053  98.563  -53.488  51.196  7
702054  98.570  -53.509  51.164  7
702055  98.587  -53.529  51.130  7
702056  98.612  -53.549  51.093  7
702057  98.636  -53.569  51.057  7
702058  98.660  -53.590  51.021  7
702059  98.685  -53.609  50.985  7
702060  98.709  -53.629  50.950  7
702061  98.735  -53.647  50.913  7
702062  98.761  -53.656  50.876  7
702063  98.788  -53.665  50.839  7
702064  98.814  -53.675  50.802  7
702065  98.841  -53.684  50.766  7
702066  98.867  -53.693  50.728  7
702067  98.894  -53.702  50.692  7
702068  98.920  -53.711  50.655  7
702069  98.946  -53.721  50.620  7
702070  98.973  -53.730  50.584  7
702071  98.999  -53.739  50.549  7
702072  99.026  -53.748  50.514  7
702073  99.052  -53.757  50.480  7
702717  97.692  -53.105  52.284  7
702718  97.725  -53.114  52.259  7
702719  97.758  -53.122  52.236  7
702720  97.792  -53.130  52.217  7
702721  97.825  -53.139  52.205  7
702722  97.907  -53.130  52.192  7
702723  97.991  -53.120  52.173  7
702724  98.049  -53.118  52.149  7
702725  98.048  -53.132  52.125  7
702726  98.046  -53.146  52.098  7
702727  98.044  -53.161  52.064  7
702728  98.042  -53.175  52.031  7
702729  98.040  -53.189  51.996  7
702730  98.043  -53.203  51.960  7
702731  98.070  -53.214  51.921  7
702732  98.096  -53.226  51.884  7
702733  98.123  -53.237  51.849  7
702734  98.149  -53.248  51.815  7
702735  98.176  -53.260  51.782  7
702736  98.203  -53.271  51.750  7
702737  98.229  -53.283  51.719  7
702738  98.255  -53.294  51.688  7
702739  98.282  -53.305  51.656  7
702740  98.308  -53.317  51.625  7
702741  98.335  -53.328  51.594  7
702742  98.365  -53.338  51.564  7
702743  98.396  -53.347  51.534  7
702744  98.427  -53.356  51.506  7
702745  98.450  -53.362  51.478  7
702746  98.469  -53.367  51.449  7
702747  98.489  -53.371  51.419  7
702748  98.504  -53.380  51.391  7
702749  98.513  -53.398  51.362  7
702750  98.522  -53.415  51.333  7
702751  98.531  -53.433  51.303  7
702752  98.539  -53.451  51.273  7
702753  98.549  -53.468  51.242  7
702754  98.558  -53.486  51.209  7
702755  98.570  -53.496  51.176  7
702756  98.588  -53.512  51.143  7
702757  98.613  -53.532  51.106  7
702758  98.637  -53.552  51.069  7
702759  98.662  -53.572  51.033  7
702760  98.686  -53.593  50.998  7
702761  98.711  -53.612  50.962  7
702762  98.736  -53.627  50.926  7
702763  98.763  -53.636  50.888  7
702764  98.790  -53.645  50.851  7
702765  98.816  -53.654  50.814  7
702766  98.843  -53.663  50.778  7
702767  98.869  -53.672  50.740  7
702768  98.896  -53.681  50.703  7
702769  98.922  -53.690  50.666  7
702770  98.948  -53.700  50.630  7
702771  98.975  -53.709  50.594  7
702772  99.001  -53.719  50.558  7
702773  99.027  -53.728  50.523  7
702774  99.054  -53.737  50.487  7
703418  97.691  -53.088  52.296  7
703419  97.724  -53.096  52.271  7
703420  97.757  -53.104  52.248  7
703421  97.791  -53.113  52.229  7
703422  97.824  -53.121  52.215  7
703423  97.880  -53.121  52.203  7
703424  97.965  -53.111  52.184  7
703425  98.050  -53.102  52.160  7
703426  98.071  -53.110  52.133  7
703427  98.069  -53.124  52.103  7
703428  98.067  -53.139  52.067  7
703429  98.066  -53.153  52.033  7
703430  98.064  -53.167  51.998  7
703431  98.069  -53.182  51.963  7
703432  98.088  -53.197  51.927  7
703433  98.107  -53.211  51.892  7
703434  98.131  -53.223  51.860  7
703435  98.158  -53.235  51.827  7
703436  98.184  -53.246  51.795  7
703437  98.211  -53.258  51.762  7
703438  98.237  -53.269  51.731  7
703439  98.264  -53.280  51.699  7
703440  98.290  -53.292  51.668  7
703441  98.317  -53.304  51.637  7
703442  98.343  -53.315  51.606  7
703443  98.372  -53.325  51.576  7
703444  98.403  -53.335  51.546  7
703445  98.434  -53.344  51.517  7
703446  98.454  -53.349  51.489  7
703447  98.474  -53.353  51.461  7
703448  98.490  -53.361  51.432  7
703449  98.499  -53.379  51.403  7
703450  98.508  -53.396  51.375  7
703451  98.516  -53.414  51.346  7
703452  98.525  -53.431  51.316  7
703453  98.534  -53.448  51.286  7
703454  98.546  -53.455  51.255  7
703455  98.559  -53.467  51.222  7
703456  98.577  -53.483  51.189  7
703457  98.594  -53.498  51.154  7
703458  98.614  -53.515  51.118  7
703459  98.639  -53.535  51.081  7
703460  98.663  -53.556  51.046  7
703461  98.688  -53.575  51.010  7
703462  98.712  -53.595  50.973  7
703463  98.738  -53.606  50.937  7
703464  98.765  -53.615  50.900  7
703465  98.791  -53.625  50.863  7
703466  98.818  -53.634  50.825  7
703467  98.844  -53.643  50.789  7
703468  98.871  -53.652  50.752  7
703469  98.897  -53.661  50.714  7
703470  98.924  -53.670  50.677  7
703471  98.950  -53.680  50.640  7
703472  98.977  -53.689  50.603  7
703473  99.003  -53.698  50.567  7
703474  99.029  -53.707  50.530  7
703475  99.056  -53.716  50.495  7
704119  97.700  -53.073  52.307  7
704120  97.723  -53.079  52.282  7
704121  97.756  -53.087  52.259  7
704122  97.790  -53.095  52.239  7
704123  97.823  -53.104  52.224  7
704124  97.856  -53.112  52.210  7
704125  97.939  -53.103  52.190  7
704126  98.023  -53.093  52.166  7
704127  98.093  -53.088  52.138  7
704128  98.092  -53.102  52.106  7
704129  98.090  -53.117  52.070  7
704130  98.088  -53.131  52.036  7
704131  98.087  -53.145  52.002  7
704132  98.097  -53.160  51.968  7
704133  98.116  -53.174  51.934  7
704134  98.135  -53.189  51.902  7
704135  98.154  -53.204  51.871  7
704136  98.173  -53.219  51.841  7
704137  98.193  -53.233  51.810  7
704138  98.219  -53.245  51.777  7
704139  98.246  -53.256  51.745  7
704140  98.272  -53.267  51.713  7
704141  98.299  -53.279  51.681  7
704142  98.325  -53.290  51.650  7
704143  98.352  -53.302  51.619  7
704144  98.378  -53.313  51.589  7
704145  98.410  -53.322  51.558  7
704146  98.438  -53.330  51.529  7
704147  98.458  -53.335  51.501  7
704148  98.476  -53.342  51.473  7
704149  98.485  -53.359  51.444  7
704150  98.493  -53.377  51.416  7
704151  98.502  -53.395  51.388  7
704152  98.512  -53.409  51.360  7
704153  98.523  -53.418  51.331  7
704154  98.534  -53.426  51.299  7
704155  98.548  -53.437  51.267  7
704156  98.566  -53.453  51.234  7
704157  98.583  -53.468  51.199  7
704158  98.600  -53.484  51.164  7
704159  98.618  -53.499  51.129  7
704160  98.640  -53.518  51.093  7
704161  98.664  -53.538  51.058  7
704162  98.689  -53.559  51.022  7
704163  98.714  -53.577  50.985  7
704164  98.740  -53.586  50.949  7
704165  98.767  -53.595  50.912  7
704166  98.793  -53.604  50.874  7
704167  98.819  -53.613  50.837  7
704168  98.846  -53.622  50.800  7
704169  98.873  -53.631  50.762  7
704170  98.899  -53.640  50.725  7
704171  98.926  -53.650  50.687  7
704172  98.952  -53.659  50.650  7
704173  98.979  -53.668  50.613  7
704174  99.005  -53.678  50.576  7
704175  99.031  -53.687  50.539  7
704176  99.058  -53.696  50.502  7
704820  97.709  -53.057  52.318  7
704821  97.731  -53.064  52.293  7
704822  97.755  -53.070  52.268  7
704823  97.789  -53.078  52.247  7
704824  97.822  -53.086  52.229  7
704825  97.855  -53.095  52.212  7
704826  97.913  -53.095  52.191  7
704827  97.997  -53.085  52.165  7
704828  98.082  -53.075  52.137  7
704829  98.115  -53.080  52.106  7
704830  98.113  -53.094  52.074  7
704831  98.111  -53.108  52.042  7
704832  98.110  -53.123  52.009  7
704833  98.125  -53.138  51.977  7
704834  98.144  -53.152  51.945  7
704835  98.163  -53.167  51.913  7
704836  98.182  -53.182  51.884  7
704837  98.201  -53.197  51.857  7
704838  98.220  -53.211  51.827  7
704839  98.239  -53.227  51.794  7
704840  98.258  -53.241  51.761  7
704841  98.281  -53.255  51.729  7
704842  98.307  -53.266  51.697  7
704843  98.334  -53.277  51.664  7
704844  98.360  -53.289  51.633  7
704845  98.386  -53.300  51.603  7
704846  98.416  -53.310  51.572  7
704847  98.442  -53.317  51.543  7
704848  98.461  -53.322  51.515  7
704849  98.471  -53.339  51.486  7
704850  98.479  -53.358  51.457  7
704851  98.489  -53.371  51.429  7
704852  98.500  -53.379  51.402  7
704853  98.511  -53.387  51.373  7
704854  98.522  -53.396  51.344  7
704855  98.537  -53.408  51.312  7
704856  98.554  -53.424  51.278  7
704857  98.572  -53.440  51.244  7
704858  98.589  -53.455  51.209  7
704859  98.607  -53.471  51.174  7
704860  98.624  -53.486  51.139  7
704861  98.642  -53.502  51.103  7
704862  98.666  -53.521  51.069  7
704863  98.690  -53.541  51.034  7
704864  98.716  -53.556  50.997  7
704865  98.742  -53.565  50.960  7
704866  98.769  -53.574  50.922  7
704867  98.795  -53.584  50.884  7
704868  98.821  -53.593  50.847  7
704869  98.848  -53.602  50.810  7
704870  98.874  -53.611  50.772  7
704871  98.901  -53.620  50.734  7
704872  98.927  -53.630  50.697  7
704873  98.954  -53.639  50.659  7
704874  98.980  -53.648  50.621  7
704875  99.007  -53.657  50.584  7
704876  99.033  -53.666  50.546  7
704877  99.060  -53.675  50.508  7
705521  97.719  -53.042  52.328  7
705522  97.740  -53.048  52.302  7
705523  97.762  -53.054  52.278  7
705524  97.788  -53.060  52.255  7
705525  97.821  -53.069  52.234  7
705526  97.854  -53.077  52.214  7
705527  97.887  -53.086  52.191  7
705528  97.971  -53.076  52.165  7
705529  98.056  -53.067  52.138  7
705530  98.138  -53.057  52.109  7
705531  98.136  -53.072  52.078  7
705532  98.135  -53.086  52.049  7
705533  98.134  -53.101  52.017  7
705534  98.153  -53.116  51.986  7
705535  98.172  -53.130  51.955  7
705536  98.191  -53.145  51.926  7
705537  98.210  -53.160  51.899  7
705538  98.229  -53.174  51.874  7
705539  98.248  -53.189  51.845  7
705540  98.268  -53.204  51.813  7
705541  98.287  -53.219  51.779  7
705542  98.305  -53.233  51.746  7
705543  98.324  -53.248  51.713  7
705544  98.344  -53.263  51.681  7
705545  98.368  -53.275  51.648  7
705546  98.395  -53.286  51.617  7
705547  98.423  -53.298  51.587  7
705548  98.446  -53.304  51.557  7
705549  98.456  -53.321  51.527  7
705550  98.466  -53.333  51.498  7
705551  98.477  -53.341  51.470  7
705552  98.488  -53.349  51.443  7
705553  98.499  -53.357  51.415  7
705554  98.510  -53.365  51.386  7
705555  98.525  -53.379  51.354  7
705556  98.543  -53.394  51.322  7
705557  98.561  -53.410  51.288  7
705558  98.578  -53.425  51.253  7
705559  98.595  -53.441  51.218  7
705560  98.613  -53.456  51.182  7
705561  98.631  -53.472  51.147  7
705562  98.648  -53.487  51.113  7
705563  98.667  -53.504  51.079  7
705564  98.692  -53.524  51.045  7
705565  98.718  -53.536  51.008  7
705566  98.744  -53.545  50.970  7
705567  98.771  -53.554  50.931  7
705568  98.797  -53.563  50.893  7
705569  98.823  -53.572  50.855  7
705570  98.850  -53.581  50.818  7
705571  98.876  -53.590  50.780  7
705572  98.903  -53.599  50.742  7
705573  98.929  -53.609  50.705  7
705574  98.955  -53.618  50.667  7
705575  98.982  -53.628  50.628  7
705576  99.009  -53.637  50.591  7
705577  99.035  -53.646  50.552  7
705578  99.062  -53.655  50.513  7
706222  97.728  -53.026  52.337  7
706223  97.750  -53.032  52.311  7
706224  97.772  -53.039  52.288  7
706225  97.794  -53.045  52.265  7
706226  97.820  -53.052  52.240  7
706227  97.853  -53.060  52.217  7
706228  97.886  -53.069  52.193  7
706229  97.945  -53.068  52.167  7
706230  98.030  -53.058  52.141  7
706231  98.114  -53.048  52.113  7
706232  98.159  -53.050  52.084  7
706233  98.157  -53.064  52.057  7
706234  98.162  -53.079  52.027  7
706235  98.181  -53.093  51.996  7
706236  98.200  -53.108  51.967  7
706237  98.219  -53.123  51.939  7
706238  98.238  -53.138  51.913  7
706239  98.257  -53.152  51.889  7
706240  98.276  -53.167  51.862  7
706241  98.295  -53.182  51.831  7
706242  98.314  -53.197  51.797  7
706243  98.334  -53.211  51.763  7
706244  98.353  -53.227  51.730  7
706245  98.372  -53.241  51.697  7
706246  98.391  -53.256  51.664  7
706247  98.410  -53.270  51.633  7
706248  98.430  -53.285  51.603  7
706249  98.443  -53.294  51.572  7
706250  98.454  -53.302  51.540  7
706251  98.465  -53.311  51.510  7
706252  98.476  -53.319  51.481  7
706253  98.487  -53.327  51.454  7
706254  98.498  -53.335  51.425  7
706255  98.514  -53.349  51.395  7
706256  98.532  -53.365  51.362  7
706257  98.550  -53.380  51.329  7
706258  98.567  -53.396  51.295  7
706259  98.584  -53.411  51.260  7
706260  98.602  -53.427  51.224  7
706261  98.619  -53.443  51.189  7
706262  98.637  -53.458  51.154  7
706263  98.654  -53.474  51.121  7
706264  98.672  -53.489  51.087  7
706265  98.693  -53.506  51.052  7
706266  98.719  -53.515  51.015  7
706267  98.746  -53.524  50.977  7
706268  98.772  -53.534  50.938  7
706269  98.799  -53.543  50.900  7
706270  98.826  -53.552  50.861  7
706271  98.852  -53.561  50.824  7
706272  98.878  -53.570  50.786  7
706273  98.905  -53.580  50.748  7
706274  98.931  -53.589  50.710  7
706275  98.957  -53.598  50.671  7
706276  98.984  -53.607  50.633  7
706277  99.010  -53.616  50.594  7
706278  99.037  -53.625  50.555  7
706279  99.063  -53.634  50.517  7
706923  97.737  -53.011  52.346  7
706924  97.759  -53.017  52.322  7
706925  97.782  -53.023  52.297  7
706926  97.803  -53.029  52.273  7
706927  97.825  -53.035  52.248  7
706928  97.852  -53.043  52.224  7
706929  97.885  -53.051  52.200  7
706930  97.919  -53.060  52.174  7
706931  98.004  -53.050  52.147  7
706932  98.088  -53.040  52.120  7
706933  98.173  -53.030  52.094  7
706934  98.180  -53.042  52.067  7
706935  98.190  -53.057  52.037  7
706936  98.209  -53.071  52.007  7
706937  98.228  -53.086  51.979  7
706938  98.247  -53.101  51.952  7
706939  98.266  -53.116  51.926  7
706940  98.285  -53.130  51.903  7
706941  98.304  -53.145  51.878  7
706942  98.323  -53.160  51.849  7
706943  98.343  -53.175  51.815  7
706944  98.361  -53.189  51.780  7
706945  98.378  -53.206  51.745  7
706946  98.396  -53.222  51.712  7
706947  98.413  -53.238  51.681  7
706948  98.430  -53.254  51.650  7
706949  98.437  -53.265  51.619  7
706950  98.442  -53.272  51.587  7
706951  98.453  -53.280  51.554  7
706952  98.464  -53.289  51.521  7
706953  98.476  -53.297  51.491  7
706954  98.486  -53.305  51.462  7
706955  98.503  -53.320  51.432  7
706956  98.521  -53.336  51.402  7
706957  98.538  -53.351  51.369  7
706958  98.556  -53.367  51.335  7
706959  98.573  -53.382  51.300  7
706960  98.591  -53.398  51.266  7
706961  98.608  -53.413  51.230  7
706962  98.626  -53.429  51.195  7
706963  98.643  -53.444  51.161  7
706964  98.661  -53.459  51.127  7
706965  98.678  -53.472  51.093  7
706966  98.698  -53.484  51.058  7
706967  98.721  -53.495  51.021  7
706968  98.748  -53.504  50.983  7
706969  98.774  -53.513  50.944  7
706970  98.801  -53.522  50.905  7
706971  98.827  -53.531  50.867  7
706972  98.854  -53.540  50.830  7
706973  98.880  -53.549  50.792  7
706974  98.907  -53.559  50.754  7
706975  98.933  -53.568  50.715  7
706976  98.959  -53.577  50.676  7
706977  98.986  -53.587  50.638  7
706978  99.012  -53.596  50.599  7
706979  99.039  -53.605  50.560  7
706980  99.065  -53.614  50.521  7
706981  99.092  -53.623  50.483  7
707624  97.747  -52.996  52.356  7
707625  97.769  -53.002  52.332  7
707626  97.791  -53.008  52.307  7
707627  97.813  -53.014  52.282  7
707628  97.835  -53.020  52.258  7
707629  97.857  -53.026  52.234  7
707630  97.884  -53.034  52.209  7
707631  97.918  -53.042  52.184  7
707632  97.978  -53.041  52.158  7
707633  98.062  -53.032  52.132  7
707634  98.147  -53.022  52.106  7
707635  98.204  -53.020  52.079  7
707636  98.218  -53.035  52.050  7
707637  98.237  -53.049  52.019  7
707638  98.256  -53.064  51.991  7
707639  98.275  -53.079  51.964  7
707640  98.292  -53.095  51.939  7
707641  98.310  -53.111  51.917  7
707642  98.327  -53.127  51.891  7
707643  98.344  -53.143  51.862  7
707644  98.362  -53.159  51.829  7
707645  98.379  -53.175  51.795  7
707646  98.396  -53.192  51.761  7
707647  98.414  -53.208  51.730  7
707648  98.431  -53.223  51.698  7
707649  98.448  -53.239  51.666  7
707650  98.441  -53.244  51.633  7
707651  98.441  -53.250  51.600  7
707652  98.452  -53.258  51.567  7
707653  98.463  -53.267  51.534  7
707654  98.475  -53.275  51.502  7
707655  98.492  -53.290  51.471  7
707656  98.509  -53.306  51.440  7
707657  98.527  -53.321  51.408  7
707658  98.545  -53.337  51.373  7
707659  98.562  -53.352  51.340  7
707660  98.579  -53.368  51.306  7
707661  98.597  -53.383  51.271  7
707662  98.615  -53.396  51.237  7
707663  98.633  -53.409  51.201  7
707664  98.651  -53.422  51.168  7
707665  98.668  -53.435  51.132  7
707666  98.688  -53.446  51.097  7
707667  98.708  -53.458  51.062  7
707668  98.726  -53.474  51.026  7
707669  98.749  -53.483  50.989  7
707670  98.776  -53.493  50.949  7
707671  98.802  -53.502  50.911  7
707672  98.829  -53.511  50.872  7
707673  98.855  -53.520  50.834  7
707674  98.882  -53.529  50.797  7
707675  98.909  -53.539  50.759  7
707676  98.935  -53.548  50.720  7
707677  98.961  -53.557  50.681  7
707678  98.988  -53.566  50.642  7
707679  99.014  -53.575  50.603  7
707680  99.041  -53.584  50.565  7
707681  99.067  -53.593  50.525  7
707682  99.093  -53.603  50.486  7
707683  99.120  -53.612  50.446  7
708325  97.756  -52.981  52.365  7
708326  97.779  -52.987  52.341  7
708327  97.800  -52.993  52.316  7
708328  97.822  -52.999  52.291  7
708329  97.844  -53.005  52.268  7
708330  97.866  -53.011  52.244  7
708331  97.888  -53.017  52.219  7
708332  97.917  -53.025  52.194  7
708333  97.951  -53.032  52.170  7
708334  98.036  -53.023  52.146  7
708335  98.121  -53.013  52.120  7
708336  98.205  -53.004  52.093  7
708337  98.241  -53.016  52.063  7
708338  98.258  -53.032  52.032  7
708339  98.276  -53.048  52.003  7
708340  98.293  -53.064  51.976  7
708341  98.310  -53.080  51.951  7
708342  98.327  -53.096  51.928  7
708343  98.345  -53.113  51.902  7
708344  98.362  -53.129  51.873  7
708345  98.379  -53.145  51.841  7
708346  98.396  -53.161  51.808  7
708347  98.414  -53.177  51.776  7
708348  98.431  -53.193  51.745  7
708349  98.448  -53.209  51.713  7
708350  98.453  -53.220  51.680  7
708351  98.444  -53.223  51.647  7
708352  98.441  -53.228  51.614  7
708353  98.452  -53.236  51.581  7
708354  98.463  -53.245  51.546  7
708355  98.481  -53.261  51.513  7
708356  98.498  -53.277  51.480  7
708357  98.516  -53.292  51.448  7
708358  98.533  -53.308  51.415  7
708359  98.551  -53.321  51.380  7
708360  98.569  -53.334  51.346  7
708361  98.587  -53.347  51.312  7
708362  98.605  -53.360  51.278  7
708363  98.623  -53.373  51.243  7
708364  98.641  -53.386  51.208  7
708365  98.659  -53.399  51.173  7
708366  98.676  -53.411  51.137  7
708367  98.699  -53.417  51.101  7
708368  98.719  -53.433  51.065  7
708369  98.736  -53.449  51.029  7
708370  98.754  -53.462  50.992  7
708371  98.778  -53.472  50.954  7
708372  98.804  -53.481  50.915  7
708373  98.831  -53.490  50.877  7
708374  98.857  -53.499  50.840  7
708375  98.884  -53.509  50.801  7
708376  98.910  -53.518  50.763  7
708377  98.937  -53.527  50.725  7
708378  98.963  -53.537  50.687  7
708379  98.990  -53.546  50.648  7
708380  99.016  -53.555  50.609  7
708381  99.043  -53.564  50.569  7
708382  99.069  -53.573  50.529  7
708383  99.095  -53.582  50.490  7
708384  99.122  -53.591  50.449  7
708385  99.148  -53.600  50.409  7
709026  97.766  -52.966  52.375  7
709027  97.788  -52.972  52.351  7
709028  97.810  -52.978  52.327  7
709029  97.832  -52.984  52.302  7
709030  97.854  -52.990  52.278  7
709031  97.876  -52.996  52.255  7
709032  97.897  -53.002  52.231  7
709033  97.920  -53.008  52.207  7
709034  97.949  -53.016  52.184  7
709035  98.010  -53.014  52.161  7
709036  98.094  -53.004  52.136  7
709037  98.179  -52.998  52.108  7
709038  98.236  -53.003  52.078  7
709039  98.268  -53.018  52.046  7
709040  98.293  -53.034  52.016  7
709041  98.310  -53.050  51.988  7
709042  98.327  -53.066  51.962  7
709043  98.345  -53.082  51.938  7
709044  98.362  -53.098  51.910  7
709045  98.379  -53.114  51.881  7
709046  98.397  -53.130  51.851  7
709047  98.414  -53.147  51.820  7
709048  98.432  -53.163  51.790  7
709049  98.449  -53.179  51.759  7
709050  98.465  -53.195  51.725  7
709051  98.456  -53.198  51.692  7
709052  98.447  -53.202  51.659  7
709053  98.440  -53.207  51.628  7
709054  98.452  -53.216  51.594  7
709055  98.469  -53.232  51.558  7
709056  98.487  -53.246  51.523  7
709057  98.505  -53.259  51.489  7
709058  98.523  -53.272  51.456  7
709059  98.541  -53.285  51.423  7
709060  98.559  -53.298  51.388  7
709061  98.577  -53.311  51.352  7
709062  98.595  -53.324  51.318  7
709063  98.613  -53.336  51.284  7
709064  98.631  -53.349  51.249  7
709065  98.649  -53.362  51.214  7
709066  98.667  -53.375  51.178  7
709067  98.687  -53.384  51.141  7
709068  98.711  -53.387  51.105  7
709069  98.729  -53.406  51.069  7
709070  98.747  -53.425  51.033  7
709071  98.765  -53.438  50.996  7
709072  98.782  -53.451  50.958  7
709073  98.806  -53.461  50.920  7
709074  98.833  -53.470  50.883  7
709075  98.859  -53.479  50.845  7
709076  98.885  -53.489  50.807  7
709077  98.912  -53.498  50.768  7
709078  98.938  -53.507  50.730  7
709079  98.965  -53.516  50.692  7
709080  98.992  -53.525  50.653  7
709081  99.018  -53.534  50.614  7
709082  99.045  -53.543  50.574  7
709083  99.071  -53.552  50.534  7
709084  99.097  -53.562  50.494  7
709085  99.124  -53.571  50.453  7
709086  99.150  -53.580  50.412  7
709087  99.177  -53.589  50.372  7
709727  97.776  -52.951  52.385  7
709728  97.797  -52.957  52.361  7
709729  97.819  -52.963  52.337  7
709730  97.841  -52.969  52.312  7
709731  97.863  -52.975  52.289  7
709732  97.885  -52.981  52.267  7
709733  97.907  -52.987  52.243  7
709734  97.929  -52.993  52.220  7
709735  97.951  -52.999  52.198  7
709736  97.984  -53.006  52.176  7
709737  98.069  -52.996  52.151  7
709738  98.153  -52.991  52.122  7
709739  98.227  -52.990  52.091  7
709740  98.258  -53.006  52.059  7
709741  98.289  -53.021  52.029  7
709742  98.320  -53.036  52.000  7
709743  98.345  -53.051  51.973  7
709744  98.363  -53.068  51.947  7
709745  98.380  -53.084  51.918  7
709746  98.397  -53.100  51.889  7
709747  98.415  -53.116  51.859  7
709748  98.432  -53.132  51.830  7
709749  98.449  -53.148  51.801  7
709750  98.466  -53.164  51.768  7
709751  98.469  -53.173  51.733  7
709752  98.460  -53.177  51.700  7
709753  98.450  -53.181  51.668  7
709754  98.444  -53.188  51.636  7
709755  98.459  -53.197  51.603  7
709756  98.478  -53.210  51.568  7
709757  98.495  -53.223  51.532  7
709758  98.513  -53.236  51.497  7
709759  98.531  -53.248  51.464  7
709760  98.549  -53.261  51.429  7
709761  98.567  -53.274  51.394  7
709762  98.585  -53.287  51.359  7
709763  98.603  -53.300  51.324  7
709764  98.621  -53.313  51.289  7
709765  98.639  -53.326  51.255  7
709766  98.657  -53.339  51.219  7
709767  98.675  -53.352  51.183  7
709768  98.699  -53.355  51.147  7
709769  98.722  -53.361  51.110  7
709770  98.739  -53.380  51.073  7
709771  98.758  -53.399  51.037  7
709772  98.775  -53.414  51.001  7
709773  98.792  -53.427  50.963  7
709774  98.810  -53.440  50.926  7
709775  98.835  -53.449  50.889  7
709776  98.861  -53.458  50.850  7
709777  98.887  -53.468  50.813  7
709778  98.914  -53.477  50.774  7
709779  98.940  -53.487  50.735  7
709780  98.967  -53.496  50.697  7
709781  98.993  -53.505  50.659  7
709782  99.020  -53.514  50.619  7
709783  99.046  -53.523  50.579  7
709784  99.073  -53.532  50.538  7
709785  99.099  -53.541  50.498  7
709786  99.126  -53.550  50.457  7
709787  99.152  -53.559  50.416  7
709788  99.179  -53.568  50.376  7
709789  99.205  -53.577  50.335  7
710428  97.785  -52.935  52.395  7
710429  97.807  -52.941  52.371  7
710430  97.829  -52.948  52.348  7
710431  97.851  -52.954  52.323  7
710432  97.873  -52.960  52.301  7
710433  97.894  -52.966  52.278  7
710434  97.917  -52.972  52.255  7
710435  97.938  -52.978  52.232  7
710436  97.960  -52.984  52.211  7
710437  97.982  -52.990  52.189  7
710438  98.042  -52.988  52.164  7
710439  98.127  -52.985  52.135  7
710440  98.211  -52.980  52.103  7
710441  98.248  -52.993  52.071  7
710442  98.280  -53.008  52.040  7
710443  98.311  -53.023  52.011  7
710444  98.343  -53.038  51.983  7
710445  98.374  -53.054  51.956  7
710446  98.397  -53.070  51.927  7
710447  98.415  -53.086  51.897  7
710448  98.432  -53.102  51.869  7
710449  98.449  -53.118  51.840  7
710450  98.467  -53.134  51.809  7
710451  98.482  -53.149  51.775  7
710452  98.473  -53.153  51.740  7
710453  98.463  -53.157  51.706  7
710454  98.459  -53.167  51.674  7
710455  98.456  -53.176  51.643  7
710456  98.471  -53.182  51.610  7
710457  98.486  -53.186  51.575  7
710458  98.503  -53.198  51.539  7
710459  98.521  -53.211  51.504  7
710460  98.539  -53.224  51.471  7
710461  98.557  -53.237  51.435  7
710462  98.575  -53.250  51.401  7
710463  98.593  -53.263  51.365  7
710464  98.611  -53.276  51.330  7
710465  98.629  -53.289  51.295  7
710466  98.647  -53.302  51.259  7
710467  98.665  -53.314  51.223  7
710468  98.687  -53.322  51.188  7
710469  98.711  -53.325  51.151  7
710470  98.732  -53.334  51.114  7
710471  98.750  -53.354  51.077  7
710472  98.768  -53.374  51.041  7
710473  98.785  -53.389  51.004  7
710474  98.803  -53.402  50.967  7
710475  98.820  -53.415  50.930  7
710476  98.838  -53.429  50.892  7
710477  98.863  -53.438  50.854  7
710478  98.889  -53.448  50.817  7
710479  98.916  -53.457  50.779  7
710480  98.942  -53.466  50.740  7
710481  98.969  -53.475  50.701  7
710482  98.995  -53.484  50.663  7
710483  99.021  -53.493  50.623  7
710484  99.048  -53.502  50.583  7
710485  99.074  -53.512  50.542  7
710486  99.101  -53.521  50.501  7
710487  99.128  -53.530  50.459  7
710488  99.154  -53.539  50.418  7
710489  99.181  -53.548  50.378  7
710490  99.207  -53.557  50.336  7
710491  99.233  -53.566  50.296  7
711129  97.794  -52.920  52.405  7
711130  97.816  -52.926  52.382  7
711131  97.839  -52.932  52.358  7
711132  97.860  -52.938  52.334  7
711133  97.882  -52.944  52.312  7
711134  97.904  -52.951  52.290  7
711135  97.926  -52.957  52.267  7
711136  97.948  -52.963  52.244  7
711137  97.968  -52.968  52.223  7
711138  97.990  -52.973  52.201  7
711139  98.016  -52.980  52.175  7
711140  98.100  -52.978  52.145  7
711141  98.184  -52.974  52.113  7
711142  98.239  -52.980  52.081  7
711143  98.271  -52.995  52.051  7
711144  98.302  -53.010  52.022  7
711145  98.333  -53.026  51.993  7
711146  98.364  -53.042  51.965  7
711147  98.395  -53.057  51.936  7
711148  98.427  -53.072  51.907  7
711149  98.450  -53.088  51.879  7
711150  98.467  -53.104  51.850  7
711151  98.485  -53.120  51.818  7
711152  98.485  -53.128  51.782  7
711153  98.479  -53.135  51.747  7
711154  98.475  -53.145  51.713  7
711155  98.471  -53.155  51.680  7
711156  98.468  -53.165  51.648  7
711157  98.483  -53.170  51.615  7
711158  98.498  -53.175  51.581  7
711159  98.513  -53.180  51.545  7
711160  98.529  -53.188  51.510  7
711161  98.547  -53.201  51.477  7
711162  98.565  -53.214  51.441  7
711163  98.583  -53.227  51.407  7
711164  98.601  -53.239  51.371  7
711165  98.619  -53.252  51.335  7
711166  98.637  -53.265  51.300  7
711167  98.655  -53.278  51.263  7
711168  98.674  -53.289  51.227  7
711169  98.698  -53.292  51.192  7
711170  98.722  -53.295  51.154  7
711171  98.742  -53.308  51.117  7
711172  98.761  -53.327  51.080  7
711173  98.778  -53.347  51.043  7
711174  98.796  -53.366  51.007  7
711175  98.813  -53.379  50.970  7
711176  98.831  -53.392  50.933  7
711177  98.849  -53.405  50.895  7
711178  98.866  -53.418  50.857  7
711179  98.891  -53.427  50.820  7
711180  98.918  -53.437  50.782  7
711181  98.944  -53.446  50.744  7
711182  98.971  -53.455  50.705  7
711183  98.997  -53.464  50.666  7
711184  99.023  -53.473  50.626  7
711185  99.050  -53.482  50.585  7
711186  99.076  -53.491  50.544  7
711187  99.103  -53.500  50.503  7
711188  99.129  -53.509  50.461  7
711189  99.156  -53.518  50.420  7
711190  99.182  -53.527  50.379  7
711191  99.209  -53.537  50.337  7
711192  99.235  -53.546  50.296  7
711775  96.622  -52.584  53.564  11
711776  96.630  -52.593  53.537  11
711777  96.640  -52.600  53.511  11
711778  96.650  -52.603  53.483  11
711779  96.672  -52.606  53.459  11
711780  96.699  -52.608  53.434  11
711830  97.804  -52.905  52.415  7
711831  97.826  -52.911  52.391  7
711832  97.847  -52.916  52.369  7
711833  97.868  -52.922  52.345  7
711834  97.889  -52.927  52.322  7
711835  97.910  -52.932  52.301  7
711836  97.931  -52.938  52.278  7
711837  97.952  -52.943  52.255  7
711838  97.973  -52.948  52.232  7
711839  97.994  -52.954  52.210  7
711840  98.015  -52.959  52.184  7
711841  98.074  -52.972  52.155  7
711842  98.158  -52.967  52.124  7
711843  98.230  -52.968  52.092  7
711844  98.261  -52.983  52.062  7
711845  98.292  -52.998  52.032  7
711846  98.324  -53.013  52.003  7
711847  98.355  -53.029  51.976  7
711848  98.386  -53.044  51.947  7
711849  98.418  -53.059  51.918  7
711850  98.449  -53.074  51.890  7
711851  98.480  -53.089  51.861  7
711852  98.497  -53.103  51.829  7
711853  98.494  -53.114  51.792  7
711854  98.490  -53.123  51.756  7
711855  98.487  -53.133  51.721  7
711856  98.483  -53.144  51.686  7
711857  98.481  -53.154  51.653  7
711858  98.496  -53.158  51.620  7
711859  98.511  -53.164  51.586  7
711860  98.526  -53.169  51.551  7
711861  98.541  -53.173  51.515  7
711862  98.556  -53.179  51.482  7
711863  98.573  -53.190  51.446  7
711864  98.591  -53.203  51.412  7
711865  98.609  -53.216  51.376  7
711866  98.627  -53.229  51.340  7
711867  98.645  -53.242  51.303  7
711868  98.663  -53.255  51.267  7
711869  98.686  -53.259  51.231  7
711870  98.710  -53.263  51.194  7
711871  98.734  -53.266  51.157  7
711872  98.753  -53.282  51.119  7
711873  98.771  -53.302  51.082  7
711874  98.789  -53.321  51.045  7
711875  98.806  -53.340  51.009  7
711876  98.824  -53.355  50.973  7
711877  98.842  -53.368  50.935  7
711878  98.859  -53.380  50.897  7
711879  98.876  -53.393  50.859  7
711880  98.894  -53.406  50.822  7
711881  98.920  -53.416  50.785  7
711882  98.946  -53.425  50.746  7
711883  98.973  -53.434  50.707  7
711884  98.999  -53.443  50.668  7
711885  99.025  -53.452  50.628  7
711886  99.052  -53.462  50.587  7
711887  99.078  -53.471  50.546  7
711888  99.104  -53.480  50.504  7
711889  99.131  -53.489  50.462  7
711890  99.157  -53.498  50.421  7
711891  99.184  -53.507  50.379  7
711892  99.211  -53.516  50.336  7
711893  99.237  -53.525  50.295  7
711894  99.264  -53.534  50.255  7
712474  96.608  -52.533  53.635  11
712475  96.622  -52.556  53.608  11
712476  96.633  -52.568  53.582  11
712477  96.642  -52.575  53.555  11
712478  96.651  -52.583  53.528  11
712479  96.661  -52.587  53.501  11
712480  96.683  -52.589  53.476  11
712481  96.711  -52.591  53.452  11
712482  96.739  -52.593  53.426  11
712483  96.761  -52.599  53.402  11
712484  96.783  -52.605  53.378  11
712531  97.809  -52.886  52.425  7
712532  97.830  -52.891  52.401  7
712533  97.851  -52.897  52.379  7
712534  97.872  -52.902  52.356  7
712535  97.893  -52.907  52.333  7
712536  97.914  -52.913  52.311  7
712537  97.935  -52.918  52.289  7
712538  97.956  -52.923  52.265  7
712539  97.977  -52.929  52.241  7
712540  97.998  -52.934  52.219  7
712541  98.019  -52.939  52.193  7
712542  98.051  -52.948  52.165  7
712543  98.132  -52.961  52.134  7
712544  98.216  -52.957  52.103  7
712545  98.252  -52.970  52.073  7
712546  98.283  -52.985  52.043  7
712547  98.314  -53.001  52.014  7
712548  98.346  -53.016  51.987  7
712549  98.377  -53.031  51.959  7
712550  98.408  -53.047  51.930  7
712551  98.439  -53.062  51.902  7
712552  98.473  -53.074  51.873  7
712553  98.502  -53.089  51.842  7
712554  98.506  -53.102  51.804  7
712555  98.502  -53.112  51.766  7
712556  98.498  -53.122  51.730  7
712557  98.495  -53.132  51.694  7
712558  98.494  -53.142  51.661  7
712559  98.508  -53.147  51.627  7
712560  98.523  -53.152  51.593  7
712561  98.538  -53.157  51.557  7
712562  98.554  -53.162  51.522  7
712563  98.568  -53.167  51.488  7
712564  98.583  -53.172  51.453  7
712565  98.599  -53.180  51.418  7
712566  98.617  -53.192  51.382  7
712567  98.635  -53.205  51.345  7
712568  98.653  -53.218  51.309  7
712569  98.673  -53.227  51.273  7
712570  98.698  -53.230  51.236  7
712571  98.722  -53.233  51.198  7
712572  98.746  -53.236  51.160  7
712573  98.764  -53.255  51.123  7
712574  98.781  -53.275  51.086  7
712575  98.799  -53.295  51.049  7
712576  98.817  -53.314  51.012  7
712577  98.835  -53.330  50.975  7
712578  98.852  -53.343  50.938  7
712579  98.869  -53.356  50.900  7
712580  98.887  -53.369  50.862  7
712581  98.905  -53.382  50.825  7
712582  98.922  -53.395  50.788  7
712583  98.948  -53.405  50.749  7
712584  98.974  -53.414  50.710  7
712585  99.001  -53.423  50.670  7
712586  99.027  -53.432  50.631  7
712587  99.054  -53.441  50.590  7
712588  99.080  -53.450  50.549  7
712589  99.106  -53.459  50.507  7
712590  99.133  -53.468  50.465  7
712591  99.159  -53.477  50.423  7
712592  99.186  -53.487  50.381  7
712593  99.212  -53.496  50.339  7
712594  99.239  -53.505  50.296  7
712595  99.265  -53.514  50.256  7
713174  96.603  -52.487  53.679  11
713175  96.617  -52.509  53.653  11
713176  96.631  -52.532  53.626  11
713177  96.644  -52.550  53.600  11
713178  96.653  -52.558  53.573  11
713179  96.662  -52.566  53.547  11
713180  96.672  -52.570  53.520  11
713181  96.695  -52.572  53.495  11
713182  96.723  -52.575  53.470  11
713183  96.749  -52.578  53.444  11
713184  96.770  -52.584  53.420  11
713185  96.793  -52.590  53.395  11
713186  96.814  -52.596  53.371  11
713232  97.813  -52.867  52.434  7
713233  97.835  -52.872  52.412  7
713234  97.856  -52.877  52.389  7
713235  97.876  -52.882  52.366  7
713236  97.897  -52.888  52.343  7
713237  97.919  -52.893  52.321  7
713238  97.940  -52.898  52.299  7
713239  97.960  -52.904  52.274  7
713240  97.982  -52.909  52.251  7
713241  98.003  -52.914  52.227  7
713242  98.023  -52.919  52.202  7
713243  98.044  -52.925  52.175  7
713244  98.107  -52.941  52.146  7
713245  98.190  -52.951  52.115  7
713246  98.242  -52.957  52.084  7
713247  98.274  -52.973  52.054  7
713248  98.305  -52.988  52.025  7
713249  98.337  -53.004  51.999  7
713250  98.368  -53.018  51.971  7
713251  98.402  -53.031  51.942  7
713252  98.435  -53.044  51.915  7
713253  98.469  -53.056  51.887  7
713254  98.498  -53.070  51.856  7
713255  98.512  -53.089  51.818  7
713256  98.514  -53.101  51.778  7
713257  98.510  -53.111  51.740  7
713258  98.506  -53.121  51.704  7
713259  98.506  -53.130  51.670  7
713260  98.521  -53.136  51.636  7
713261  98.536  -53.140  51.601  7
713262  98.551  -53.145  51.565  7
713263  98.566  -53.151  51.530  7
713264  98.581  -53.155  51.495  7
713265  98.596  -53.161  51.460  7
713266  98.611  -53.166  51.425  7
713267  98.626  -53.170  51.389  7
713268  98.643  -53.181  51.352  7
713269  98.661  -53.194  51.315  7
713270  98.685  -53.197  51.278  7
713271  98.709  -53.200  51.241  7
713272  98.733  -53.203  51.203  7
713273  98.756  -53.210  51.164  7
713274  98.774  -53.230  51.127  7
713275  98.792  -53.249  51.090  7
713276  98.809  -53.268  51.052  7
713277  98.828  -53.288  51.015  7
713278  98.845  -53.306  50.978  7
713279  98.862  -53.319  50.940  7
713280  98.880  -53.332  50.903  7
713281  98.898  -53.345  50.865  7
713282  98.915  -53.358  50.828  7
713283  98.933  -53.371  50.791  7
713284  98.950  -53.383  50.752  7
713285  98.976  -53.393  50.713  7
713286  99.003  -53.402  50.673  7
713287  99.029  -53.411  50.634  7
713288  99.056  -53.421  50.593  7
713289  99.082  -53.430  50.552  7
713290  99.109  -53.439  50.510  7
713291  99.135  -53.448  50.467  7
713292  99.161  -53.457  50.425  7
713293  99.188  -53.466  50.383  7
713294  99.214  -53.475  50.340  7
713295  99.240  -53.484  50.298  7
713296  99.267  -53.493  50.257  7
713874  96.598  -52.441  53.720  11
713875  96.612  -52.464  53.694  11
713876  96.626  -52.486  53.669  11
713877  96.640  -52.508  53.643  11
713878  96.654  -52.531  53.617  11
713879  96.664  -52.541  53.590  11
713880  96.673  -52.549  53.564  11
713881  96.683  -52.553  53.537  11
713882  96.707  -52.556  53.512  11
713883  96.734  -52.558  53.487  11
713884  96.758  -52.562  53.462  11
713885  96.780  -52.568  53.437  11
713886  96.802  -52.575  53.412  11
713887  96.824  -52.581  53.387  11
713888  96.846  -52.587  53.363  11
713933  97.818  -52.847  52.445  7
713934  97.839  -52.853  52.421  7
713935  97.860  -52.858  52.399  7
713936  97.881  -52.863  52.376  7
713937  97.902  -52.868  52.353  7
713938  97.923  -52.873  52.331  7
713939  97.944  -52.879  52.309  7
713940  97.965  -52.884  52.284  7
713941  97.986  -52.889  52.261  7
713942  98.007  -52.894  52.237  7
713943  98.028  -52.900  52.211  7
713944  98.049  -52.905  52.185  7
713945  98.084  -52.914  52.156  7
713946  98.164  -52.935  52.124  7
713947  98.233  -52.945  52.095  7
713948  98.265  -52.960  52.065  7
713949  98.296  -52.975  52.036  7
713950  98.330  -52.988  52.010  7
713951  98.364  -53.000  51.982  7
713952  98.397  -53.013  51.954  7
713953  98.432  -53.026  51.928  7
713954  98.465  -53.038  51.901  7
713955  98.494  -53.052  51.869  7
713956  98.508  -53.070  51.831  7
713957  98.522  -53.088  51.789  7
713958  98.522  -53.100  51.751  7
713959  98.518  -53.110  51.715  7
713960  98.518  -53.119  51.680  7
713961  98.533  -53.124  51.645  7
713962  98.549  -53.129  51.609  7
713963  98.564  -53.134  51.572  7
713964  98.578  -53.139  51.537  7
713965  98.593  -53.144  51.502  7
713966  98.608  -53.149  51.467  7
713967  98.624  -53.154  51.433  7
713968  98.638  -53.159  51.397  7
713969  98.654  -53.163  51.359  7
713970  98.673  -53.164  51.322  7
713971  98.697  -53.167  51.284  7
713972  98.721  -53.170  51.246  7
713973  98.745  -53.173  51.208  7
713974  98.767  -53.183  51.168  7
713975  98.784  -53.203  51.131  7
713976  98.802  -53.223  51.094  7
713977  98.820  -53.242  51.056  7
713978  98.838  -53.262  51.019  7
713979  98.856  -53.282  50.982  7
713980  98.873  -53.295  50.943  7
713981  98.890  -53.308  50.906  7
713982  98.908  -53.321  50.868  7
713983  98.926  -53.334  50.831  7
713984  98.943  -53.347  50.794  7
713985  98.960  -53.360  50.756  7
713986  98.978  -53.373  50.716  7
713987  99.004  -53.382  50.677  7
713988  99.031  -53.391  50.636  7
713989  99.057  -53.400  50.597  7
713990  99.084  -53.409  50.555  7
713991  99.111  -53.418  50.513  7
713992  99.137  -53.427  50.470  7
713993  99.163  -53.437  50.427  7
713994  99.190  -53.446  50.385  7
713995  99.216  -53.455  50.342  7
713996  99.242  -53.464  50.301  7
713997  99.269  -53.473  50.260  7
714574  96.593  -52.396  53.759  11
714575  96.607  -52.418  53.734  11
714576  96.621  -52.440  53.708  11
714577  96.635  -52.462  53.683  11
714578  96.649  -52.484  53.658  11
714579  96.663  -52.507  53.632  11
714580  96.675  -52.524  53.607  11
714581  96.684  -52.532  53.580  11
714582  96.694  -52.537  53.554  11
714583  96.718  -52.539  53.528  11
714584  96.746  -52.541  53.503  11
714585  96.767  -52.547  53.478  11
714586  96.790  -52.553  53.453  11
714587  96.811  -52.559  53.427  11
714588  96.833  -52.565  53.402  11
714589  96.855  -52.572  53.377  11
714590  96.877  -52.578  53.353  11
714634  97.822  -52.828  52.455  7
714635  97.843  -52.833  52.431  7
714636  97.864  -52.838  52.409  7
714637  97.885  -52.844  52.386  7
714638  97.906  -52.849  52.363  7
714639  97.927  -52.854  52.342  7
714640  97.948  -52.860  52.319  7
714641  97.969  -52.864  52.295  7
714642  97.990  -52.869  52.271  7
714643  98.011  -52.875  52.247  7
714644  98.032  -52.880  52.222  7
714645  98.053  -52.885  52.196  7
714646  98.074  -52.891  52.166  7
714647  98.142  -52.909  52.135  7
714648  98.222  -52.930  52.106  7
714649  98.258  -52.944  52.077  7
714650  98.292  -52.957  52.049  7
714651  98.326  -52.970  52.022  7
714652  98.360  -52.982  51.995  7
714653  98.394  -52.995  51.969  7
714654  98.428  -53.007  51.943  7
714655  98.461  -53.020  51.915  7
714656  98.490  -53.034  51.883  7
714657  98.504  -53.052  51.844  7
714658  98.518  -53.070  51.802  7
714659  98.532  -53.088  51.763  7
714660  98.530  -53.098  51.728  7
714661  98.531  -53.107  51.692  7
714662  98.546  -53.112  51.655  7
714663  98.561  -53.117  51.618  7
714664  98.576  -53.123  51.581  7
714665  98.591  -53.127  51.545  7
714666  98.606  -53.132  51.510  7
714667  98.622  -53.135  51.474  7
714668  98.638  -53.136  51.440  7
714669  98.655  -53.136  51.403  7
714670  98.671  -53.136  51.365  7
714671  98.688  -53.136  51.327  7
714672  98.709  -53.138  51.290  7
714673  98.733  -53.141  51.252  7
714674  98.757  -53.144  51.213  7
714675  98.777  -53.158  51.174  7
714676  98.795  -53.177  51.136  7
714677  98.812  -53.196  51.098  7
714678  98.831  -53.216  51.060  7
714679  98.848  -53.236  51.023  7
714680  98.866  -53.255  50.986  7
714681  98.883  -53.271  50.947  7
714682  98.901  -53.284  50.910  7
714683  98.919  -53.297  50.872  7
714684  98.936  -53.310  50.834  7
714685  98.953  -53.323  50.796  7
714686  98.971  -53.336  50.759  7
714687  98.989  -53.349  50.721  7
714688  99.006  -53.361  50.681  7
714689  99.033  -53.371  50.640  7
714690  99.059  -53.380  50.600  7
714691  99.086  -53.389  50.559  7
714692  99.112  -53.398  50.517  7
714693  99.139  -53.407  50.474  7
714694  99.165  -53.416  50.431  7
714695  99.192  -53.425  50.389  7
714696  99.218  -53.434  50.346  7
714697  99.244  -53.443  50.305  7
714698  99.271  -53.452  50.263  7
715274  96.588  -52.350  53.794  11
715275  96.602  -52.372  53.770  11
715276  96.616  -52.395  53.746  11
715277  96.630  -52.417  53.721  11
715278  96.644  -52.439  53.696  11
715279  96.658  -52.461  53.672  11
715280  96.672  -52.484  53.647  11
715281  96.686  -52.506  53.622  11
715282  96.695  -52.515  53.596  11
715283  96.705  -52.520  53.569  11
715284  96.730  -52.522  53.543  11
715285  96.755  -52.526  53.519  11
715286  96.777  -52.532  53.494  11
715287  96.799  -52.538  53.468  11
715288  96.821  -52.544  53.442  11
715289  96.843  -52.550  53.416  11
715290  96.865  -52.556  53.391  11
715291  96.887  -52.562  53.365  11
715335  97.826  -52.808  52.465  7
715336  97.848  -52.813  52.441  7
715337  97.868  -52.819  52.419  7
715338  97.889  -52.824  52.396  7
715339  97.911  -52.829  52.374  7
715340  97.931  -52.835  52.352  7
715341  97.952  -52.840  52.329  7
715342  97.973  -52.845  52.305  7
715343  97.994  -52.850  52.281  7
715344  98.015  -52.856  52.258  7
715345  98.036  -52.860  52.235  7
715346  98.057  -52.866  52.207  7
715347  98.078  -52.871  52.178  7
715348  98.119  -52.882  52.148  7
715349  98.199  -52.903  52.118  7
715350  98.247  -52.919  52.088  7
715351  98.283  -52.934  52.062  7
715352  98.319  -52.948  52.036  7
715353  98.355  -52.963  52.010  7
715354  98.390  -52.976  51.984  7
715355  98.424  -52.989  51.957  7
715356  98.457  -53.002  51.929  7
715357  98.486  -53.016  51.897  7
715358  98.500  -53.034  51.856  7
715359  98.514  -53.051  51.815  7
715360  98.528  -53.070  51.775  7
715361  98.542  -53.087  51.740  7
715362  98.544  -53.095  51.703  7
715363  98.559  -53.101  51.665  7
715364  98.574  -53.106  51.627  7
715365  98.590  -53.107  51.589  7
715366  98.606  -53.107  51.552  7
715367  98.623  -53.107  51.517  7
715368  98.640  -53.107  51.480  7
715369  98.656  -53.108  51.445  7
715370  98.673  -53.108  51.408  7
715371  98.690  -53.108  51.370  7
715372  98.706  -53.109  51.332  7
715373  98.722  -53.109  51.295  7
715374  98.744  -53.111  51.257  7
715375  98.769  -53.114  51.218  7
715376  98.787  -53.131  51.179  7
715377  98.805  -53.151  51.140  7
715378  98.823  -53.170  51.102  7
715379  98.841  -53.190  51.064  7
715380  98.859  -53.210  51.027  7
715381  98.876  -53.230  50.989  7
715382  98.894  -53.247  50.951  7
715383  98.912  -53.260  50.913  7
715384  98.929  -53.273  50.875  7
715385  98.947  -53.286  50.837  7
715386  98.964  -53.299  50.799  7
715387  98.982  -53.311  50.762  7
715388  98.999  -53.324  50.723  7
715389  99.017  -53.337  50.683  7
715390  99.034  -53.350  50.644  7
715391  99.061  -53.359  50.603  7
715392  99.087  -53.368  50.561  7
715393  99.114  -53.377  50.519  7
715394  99.140  -53.386  50.477  7
715395  99.167  -53.396  50.434  7
715396  99.194  -53.405  50.392  7
715397  99.220  -53.414  50.350  7
715398  99.246  -53.423  50.308  7
715399  99.273  -53.432  50.266  7
715400  99.299  -53.441  50.225  7
715975  96.597  -52.327  53.804  11
715976  96.611  -52.349  53.781  11
715977  96.625  -52.371  53.757  11
715978  96.639  -52.393  53.733  11
715979  96.653  -52.415  53.709  11
715980  96.667  -52.438  53.685  11
715981  96.681  -52.460  53.661  11
715982  96.695  -52.482  53.636  11
715983  96.707  -52.497  53.610  11
715984  96.716  -52.503  53.583  11
715985  96.741  -52.506  53.558  11
715986  96.764  -52.511  53.533  11
715987  96.787  -52.517  53.507  11
715988  96.809  -52.523  53.481  11
715989  96.830  -52.529  53.455  11
715990  96.853  -52.535  53.429  11
715991  96.874  -52.541  53.403  11
715992  96.896  -52.547  53.377  11
715993  96.918  -52.553  53.352  11
716036  97.830  -52.788  52.475  7
716037  97.852  -52.794  52.451  7
716038  97.873  -52.799  52.429  7
716039  97.893  -52.804  52.406  7
716040  97.915  -52.810  52.384  7
716041  97.936  -52.815  52.362  7
716042  97.956  -52.820  52.339  7
716043  97.978  -52.825  52.315  7
716044  97.999  -52.831  52.291  7
716045  98.020  -52.836  52.268  7
716046  98.040  -52.841  52.246  7
716047  98.062  -52.847  52.219  7
716048  98.083  -52.851  52.189  7
716049  98.103  -52.857  52.159  7
716050  98.175  -52.876  52.129  7
716051  98.234  -52.894  52.100  7
716052  98.270  -52.908  52.074  7
716053  98.306  -52.923  52.049  7
716054  98.342  -52.938  52.023  7
716055  98.378  -52.952  51.997  7
716056  98.414  -52.966  51.969  7
716057  98.450  -52.981  51.940  7
716058  98.476  -52.997  51.909  7
716059  98.490  -53.015  51.870  7
716060  98.504  -53.032  51.828  7
716061  98.518  -53.051  51.789  7
716062  98.532  -53.068  51.751  7
716063  98.556  -53.082  51.713  7
716064  98.573  -53.081  51.674  7
716065  98.591  -53.080  51.635  7
716066  98.607  -53.079  51.597  7
716067  98.624  -53.080  51.559  7
716068  98.641  -53.080  51.521  7
716069  98.657  -53.080  51.485  7
716070  98.674  -53.081  51.448  7
716071  98.691  -53.081  51.411  7
716072  98.707  -53.081  51.374  7
716073  98.724  -53.081  51.336  7
716074  98.740  -53.082  51.299  7
716075  98.757  -53.082  51.260  7
716076  98.780  -53.086  51.222  7
716077  98.798  -53.105  51.183  7
716078  98.815  -53.124  51.144  7
716079  98.834  -53.144  51.106  7
716080  98.851  -53.164  51.067  7
716081  98.869  -53.183  51.030  7
716082  98.887  -53.203  50.992  7
716083  98.905  -53.223  50.954  7
716084  98.922  -53.236  50.917  7
716085  98.940  -53.248  50.879  7
716086  98.957  -53.261  50.841  7
716087  98.975  -53.274  50.803  7
716088  98.992  -53.287  50.765  7
716089  99.010  -53.300  50.725  7
716090  99.027  -53.313  50.685  7
716091  99.045  -53.326  50.646  7
716092  99.063  -53.339  50.605  7
716093  99.089  -53.348  50.563  7
716094  99.116  -53.357  50.521  7
716095  99.142  -53.366  50.480  7
716096  99.169  -53.375  50.437  7
716097  99.195  -53.384  50.394  7
716098  99.222  -53.393  50.353  7
716099  99.248  -53.402  50.310  7
716100  99.275  -53.411  50.268  7
716101  99.301  -53.421  50.227  7
716675  96.592  -52.281  53.833  11
716676  96.606  -52.303  53.812  11
716677  96.620  -52.326  53.790  11
716678  96.634  -52.348  53.768  11
716679  96.648  -52.370  53.744  11
716680  96.662  -52.392  53.721  11
716681  96.676  -52.415  53.697  11
716682  96.690  -52.437  53.673  11
716683  96.704  -52.459  53.649  11
716684  96.718  -52.481  53.623  11
716685  96.727  -52.487  53.597  11
716686  96.752  -52.490  53.572  11
716687  96.774  -52.496  53.547  11
716688  96.796  -52.502  53.521  11
716689  96.818  -52.508  53.494  11
716690  96.840  -52.514  53.468  11
716691  96.862  -52.520  53.441  11
716692  96.884  -52.526  53.415  11
716693  96.906  -52.532  53.389  11
716694  96.928  -52.538  53.364  11
716738  97.856  -52.774  52.461  7
716739  97.877  -52.779  52.439  7
716740  97.898  -52.785  52.416  7
716741  97.919  -52.790  52.393  7
716742  97.940  -52.795  52.371  7
716743  97.961  -52.800  52.349  7
716744  97.982  -52.806  52.324  7
716745  98.003  -52.811  52.301  7
716746  98.024  -52.816  52.279  7
716747  98.045  -52.822  52.256  7
716748  98.066  -52.827  52.229  7
716749  98.087  -52.832  52.200  7
716750  98.108  -52.838  52.170  7
716751  98.153  -52.849  52.140  7
716752  98.222  -52.869  52.112  7
716753  98.258  -52.883  52.086  7
716754  98.294  -52.897  52.060  7
716755  98.329  -52.912  52.034  7
716756  98.366  -52.926  52.007  7
716757  98.402  -52.941  51.979  7
716758  98.430  -52.957  51.951  7
716759  98.444  -52.975  51.919  7
716760  98.458  -52.992  51.881  7
716761  98.472  -53.010  51.839  7
716762  98.494  -53.027  51.798  7
716763  98.531  -53.044  51.758  7
716764  98.562  -53.057  51.719  7
716765  98.579  -53.062  51.681  7
716766  98.598  -53.067  51.642  7
716767  98.616  -53.065  51.603  7
716768  98.633  -53.064  51.564  7
716769  98.650  -53.064  51.527  7
716770  98.668  -53.063  51.490  7
716771  98.686  -53.062  51.452  7
716772  98.703  -53.060  51.414  7
716773  98.720  -53.060  51.376  7
716774  98.738  -53.059  51.339  7
716775  98.755  -53.058  51.301  7
716776  98.773  -53.057  51.263  7
716777  98.791  -53.059  51.225  7
716778  98.808  -53.079  51.186  7
716779  98.826  -53.098  51.147  7
716780  98.844  -53.118  51.108  7
716781  98.862  -53.138  51.069  7
716782  98.879  -53.157  51.032  7
716783  98.897  -53.176  50.994  7
716784  98.915  -53.196  50.956  7
716785  98.933  -53.211  50.919  7
716786  98.950  -53.224  50.881  7
716787  98.968  -53.237  50.843  7
716788  98.985  -53.250  50.805  7
716789  99.003  -53.263  50.766  7
716790  99.020  -53.276  50.728  7
716791  99.038  -53.289  50.688  7
716792  99.055  -53.302  50.648  7
716793  99.073  -53.315  50.607  7
716794  99.091  -53.327  50.565  7
716795  99.118  -53.336  50.524  7
716796  99.144  -53.346  50.482  7
716797  99.170  -53.355  50.439  7
716798  99.197  -53.364  50.396  7
716799  99.223  -53.373  50.354  7
716800  99.250  -53.382  50.312  7
716801  99.276  -53.391  50.271  7
716802  99.303  -53.401  50.229  7
717302  95.426  -50.641  55.421  10
717303  95.453  -50.661  55.406  10
717304  95.480  -50.681  55.391  10
717305  95.507  -50.701  55.375  10
717306  95.533  -50.720  55.359  10
717307  95.560  -50.740  55.342  10
717308  95.587  -50.760  55.325  10
717309  95.614  -50.779  55.307  10
717376  96.601  -52.258  53.841  11
717377  96.615  -52.280  53.821  11
717378  96.629  -52.302  53.799  11
717379  96.643  -52.324  53.777  11
717380  96.657  -52.346  53.755  11
717381  96.671  -52.368  53.731  11
717382  96.685  -52.391  53.708  11
717383  96.699  -52.413  53.686  11
717384  96.713  -52.435  53.662  11
717385  96.727  -52.458  53.637  11
717386  96.738  -52.470  53.611  11
717387  96.762  -52.474  53.585  11
717388  96.784  -52.481  53.559  11
717389  96.806  -52.487  53.533  11
717390  96.827  -52.493  53.507  11
717391  96.850  -52.499  53.481  11
717392  96.871  -52.505  53.452  11
717393  96.893  -52.511  53.426  11
717394  96.915  -52.517  53.400  11
717395  96.937  -52.522  53.375  11
717439  97.860  -52.754  52.471  7
717440  97.881  -52.760  52.447  7
717441  97.902  -52.765  52.425  7
717442  97.923  -52.770  52.402  7
717443  97.944  -52.775  52.380  7
717444  97.965  -52.781  52.357  7
717445  97.986  -52.786  52.334  7
717446  98.007  -52.791  52.310  7
717447  98.028  -52.797  52.289  7
717448  98.049  -52.802  52.265  7
717449  98.070  -52.807  52.239  7
717450  98.091  -52.813  52.210  7
717451  98.112  -52.818  52.180  7
717452  98.133  -52.823  52.151  7
717453  98.209  -52.843  52.123  7
717454  98.245  -52.857  52.098  7
717455  98.281  -52.872  52.071  7
717456  98.317  -52.887  52.044  7
717457  98.353  -52.901  52.017  7
717458  98.384  -52.916  51.989  7
717459  98.397  -52.934  51.960  7
717460  98.412  -52.952  51.927  7
717461  98.426  -52.970  51.890  7
717462  98.463  -52.986  51.847  7
717463  98.500  -53.003  51.805  7
717464  98.536  -53.020  51.764  7
717465  98.570  -53.035  51.724  7
717466  98.583  -53.035  51.686  7
717467  98.602  -53.043  51.648  7
717468  98.623  -53.051  51.609  7
717469  98.640  -53.051  51.569  7
717470  98.658  -53.050  51.532  7
717471  98.675  -53.049  51.494  7
717472  98.693  -53.048  51.456  7
717473  98.710  -53.047  51.418  7
717474  98.728  -53.046  51.380  7
717475  98.745  -53.045  51.341  7
717476  98.763  -53.045  51.303  7
717477  98.780  -53.044  51.266  7
717478  98.797  -53.043  51.227  7
717479  98.818  -53.055  51.188  7
717480  98.837  -53.072  51.150  7
717481  98.854  -53.092  51.111  7
717482  98.872  -53.111  51.072  7
717483  98.890  -53.131  51.034  7
717484  98.908  -53.151  50.997  7
717485  98.925  -53.170  50.959  7
717486  98.943  -53.187  50.922  7
717487  98.960  -53.200  50.883  7
717488  98.978  -53.213  50.845  7
717489  98.996  -53.226  50.807  7
717490  99.013  -53.239  50.769  7
717491  99.031  -53.252  50.730  7
717492  99.048  -53.265  50.691  7
717493  99.066  -53.278  50.651  7
717494  99.083  -53.291  50.609  7
717495  99.101  -53.304  50.567  7
717496  99.120  -53.316  50.526  7
717497  99.146  -53.325  50.484  7
717498  99.172  -53.334  50.441  7
717499  99.199  -53.343  50.398  7
717500  99.225  -53.352  50.356  7
717501  99.252  -53.361  50.315  7
717502  99.278  -53.371  50.273  7
717503  99.305  -53.380  50.231  7
718001  95.383  -50.581  55.473  10
718002  95.414  -50.598  55.458  10
718003  95.445  -50.616  55.443  10
718004  95.471  -50.636  55.428  10
718005  95.498  -50.656  55.412  10
718006  95.525  -50.676  55.396  10
718007  95.552  -50.695  55.380  10
718008  95.579  -50.715  55.362  10
718009  95.606  -50.735  55.344  10
718010  95.633  -50.754  55.325  10
718011  95.660  -50.774  55.306  10
718012  95.687  -50.794  55.288  10
718077  96.610  -52.234  53.850  11
718078  96.624  -52.256  53.829  11
718079  96.638  -52.279  53.808  11
718080  96.652  -52.301  53.787  11
718081  96.666  -52.323  53.764  11
718082  96.680  -52.346  53.741  11
718083  96.694  -52.368  53.719  11
718084  96.708  -52.390  53.697  11
718085  96.722  -52.412  53.673  11
718086  96.736  -52.434  53.649  11
718087  96.749  -52.454  53.623  11
718088  96.771  -52.459  53.597  11
718089  96.793  -52.465  53.572  11
718090  96.815  -52.471  53.546  11
718091  96.836  -52.476  53.519  11
718092  96.857  -52.481  53.492  11
718093  96.878  -52.487  53.465  11
718094  96.899  -52.492  53.438  11
718095  96.920  -52.497  53.411  11
718096  96.941  -52.503  53.385  11
718140  97.865  -52.735  52.480  7
718141  97.885  -52.740  52.456  7
718142  97.907  -52.745  52.433  7
718143  97.928  -52.750  52.411  7
718144  97.948  -52.756  52.388  7
718145  97.969  -52.761  52.365  7
718146  97.991  -52.766  52.342  7
718147  98.011  -52.772  52.319  7
718148  98.032  -52.777  52.296  7
718149  98.054  -52.782  52.273  7
718150  98.074  -52.788  52.247  7
718151  98.095  -52.793  52.218  7
718152  98.116  -52.798  52.189  7
718153  98.137  -52.803  52.161  7
718154  98.186  -52.816  52.133  7
718155  98.233  -52.832  52.108  7
718156  98.269  -52.847  52.082  7
718157  98.305  -52.861  52.055  7
718158  98.338  -52.876  52.027  7
718159  98.352  -52.894  51.999  7
718160  98.366  -52.912  51.968  7
718161  98.395  -52.929  51.932  7
718162  98.432  -52.945  51.894  7
718163  98.469  -52.962  51.852  7
718164  98.506  -52.979  51.812  7
718165  98.543  -52.995  51.771  7
718166  98.578  -53.012  51.729  7
718167  98.589  -53.010  51.690  7
718168  98.606  -53.016  51.653  7
718169  98.626  -53.023  51.615  7
718170  98.646  -53.031  51.575  7
718171  98.665  -53.036  51.536  7
718172  98.683  -53.035  51.498  7
718173  98.700  -53.035  51.460  7
718174  98.717  -53.033  51.422  7
718175  98.735  -53.032  51.384  7
718176  98.752  -53.032  51.345  7
718177  98.770  -53.031  51.306  7
718178  98.787  -53.030  51.269  7
718179  98.805  -53.029  51.231  7
718180  98.825  -53.039  51.191  7
718181  98.845  -53.051  51.153  7
718182  98.865  -53.066  51.114  7
718183  98.882  -53.085  51.075  7
718184  98.901  -53.104  51.038  7
718185  98.918  -53.124  50.999  7
718186  98.936  -53.144  50.962  7
718187  98.953  -53.163  50.923  7
718188  98.971  -53.176  50.884  7
718189  98.989  -53.189  50.846  7
718190  99.006  -53.202  50.809  7
718191  99.024  -53.215  50.771  7
718192  99.041  -53.228  50.733  7
718193  99.059  -53.241  50.694  7
718194  99.076  -53.254  50.654  7
718195  99.094  -53.267  50.611  7
718196  99.112  -53.280  50.569  7
718197  99.129  -53.292  50.527  7
718198  99.148  -53.305  50.486  7
718199  99.174  -53.314  50.443  7
718200  99.201  -53.323  50.401  7
718201  99.227  -53.332  50.358  7
718202  99.254  -53.341  50.317  7
718203  99.280  -53.350  50.276  7
718204  99.306  -53.360  50.234  7
718701  95.369  -50.539  55.507  10
718702  95.400  -50.556  55.493  10
718703  95.431  -50.574  55.479  10
718704  95.462  -50.591  55.464  10
718705  95.490  -50.610  55.449  10
718706  95.517  -50.630  55.433  10
718707  95.544  -50.650  55.418  10
718708  95.571  -50.670  55.400  10
718709  95.598  -50.690  55.382  10
718710  95.625  -50.710  55.363  10
718711  95.652  -50.729  55.344  10
718712  95.679  -50.749  55.324  10
718713  95.706  -50.769  55.305  10
718714  95.723  -50.790  55.286  10
718778  96.619  -52.211  53.857  11
718779  96.633  -52.233  53.837  11
718780  96.647  -52.255  53.817  11
718781  96.661  -52.277  53.795  11
718782  96.675  -52.299  53.774  11
718783  96.689  -52.322  53.751  11
718784  96.704  -52.343  53.730  11
718785  96.719  -52.365  53.708  11
718786  96.734  -52.386  53.685  11
718787  96.749  -52.407  53.660  11
718788  96.764  -52.428  53.635  11
718789  96.782  -52.442  53.610  11
718790  96.803  -52.446  53.584  11
718791  96.823  -52.452  53.558  11
718792  96.843  -52.456  53.531  11
718793  96.864  -52.462  53.503  11
718794  96.885  -52.467  53.476  11
718795  96.905  -52.472  53.448  11
718796  96.926  -52.478  53.422  11
718797  96.947  -52.483  53.395  11
718841  97.869  -52.715  52.489  7
718842  97.890  -52.720  52.464  7
718843  97.911  -52.725  52.441  7
718844  97.932  -52.731  52.419  7
718845  97.953  -52.736  52.396  7
718846  97.973  -52.741  52.373  7
718847  97.995  -52.747  52.349  7
718848  98.016  -52.752  52.326  7
718849  98.037  -52.757  52.303  7
718850  98.058  -52.763  52.280  7
718851  98.079  -52.768  52.255  7
718852  98.100  -52.773  52.227  7
718853  98.121  -52.778  52.198  7
718854  98.142  -52.784  52.170  7
718855  98.163  -52.789  52.142  7
718856  98.220  -52.807  52.116  7
718857  98.256  -52.822  52.091  7
718858  98.291  -52.836  52.063  7
718859  98.305  -52.854  52.035  7
718860  98.327  -52.871  52.005  7
718861  98.364  -52.888  51.972  7
718862  98.401  -52.904  51.935  7
718863  98.438  -52.921  51.896  7
718864  98.475  -52.938  51.855  7
718865  98.511  -52.954  51.816  7
718866  98.548  -52.971  51.775  7
718867  98.585  -52.988  51.735  7
718868  98.597  -52.988  51.697  7
718869  98.609  -52.988  51.658  7
718870  98.629  -52.996  51.620  7
718871  98.649  -53.004  51.580  7
718872  98.669  -53.011  51.542  7
718873  98.689  -53.020  51.503  7
718874  98.707  -53.021  51.465  7
718875  98.725  -53.020  51.427  7
718876  98.742  -53.019  51.388  7
718877  98.760  -53.018  51.349  7
718878  98.777  -53.017  51.311  7
718879  98.794  -53.017  51.272  7
718880  98.812  -53.015  51.234  7
718881  98.832  -53.023  51.195  7
718882  98.852  -53.035  51.156  7
718883  98.872  -53.048  51.117  7
718884  98.892  -53.060  51.078  7
718885  98.911  -53.079  51.040  7
718886  98.928  -53.098  51.002  7
718887  98.946  -53.118  50.963  7
718888  98.964  -53.137  50.925  7
718889  98.982  -53.152  50.887  7
718890  98.999  -53.165  50.849  7
718891  99.017  -53.178  50.812  7
718892  99.034  -53.191  50.774  7
718893  99.052  -53.204  50.736  7
718894  99.069  -53.217  50.696  7
718895  99.087  -53.230  50.656  7
718896  99.104  -53.242  50.614  7
718897  99.122  -53.255  50.572  7
718898  99.139  -53.268  50.530  7
718899  99.157  -53.281  50.488  7
718900  99.176  -53.293  50.446  7
718901  99.203  -53.302  50.404  7
718902  99.229  -53.311  50.362  7
718903  99.256  -53.321  50.320  7
718904  99.282  -53.330  50.278  7
718905  99.308  -53.339  50.238  7
719401  95.355  -50.497  55.542  10
719402  95.386  -50.515  55.528  10
719403  95.417  -50.532  55.514  10
719404  95.448  -50.550  55.500  10
719405  95.479  -50.567  55.486  10
719406  95.509  -50.585  55.470  10
719407  95.536  -50.605  55.455  10
719408  95.563  -50.625  55.439  10
719409  95.590  -50.644  55.421  10
719410  95.617  -50.664  55.402  10
719411  95.644  -50.684  55.384  10
719412  95.671  -50.704  55.364  10
719413  95.698  -50.723  55.344  10
719414  95.718  -50.745  55.324  10
719415  95.732  -50.766  55.303  10
719416  95.746  -50.789  55.283  10
719479  96.633  -52.183  53.863  11
719480  96.649  -52.204  53.844  11
719481  96.664  -52.225  53.824  11
719482  96.679  -52.246  53.803  11
719483  96.693  -52.268  53.781  11
719484  96.709  -52.289  53.760  11
719485  96.724  -52.310  53.740  11
719486  96.739  -52.331  53.717  11
719487  96.754  -52.352  53.694  11
719488  96.769  -52.374  53.670  11
719489  96.784  -52.396  53.645  11
719490  96.799  -52.417  53.621  11
719491  96.816  -52.432  53.596  11
719492  96.837  -52.435  53.569  11
719493  96.858  -52.438  53.543  11
719494  96.879  -52.442  53.515  11
719495  96.900  -52.447  53.487  11
719496  96.921  -52.452  53.458  11
719497  96.941  -52.458  53.431  11
719498  96.961  -52.463  53.405  11
719542  97.873  -52.696  52.497  7
719543  97.894  -52.701  52.473  7
719544  97.915  -52.706  52.449  7
719545  97.936  -52.711  52.425  7
719546  97.957  -52.716  52.403  7
719547  97.978  -52.722  52.381  7
719548  97.999  -52.727  52.356  7
719549  98.020  -52.732  52.333  7
719550  98.041  -52.738  52.310  7
719551  98.062  -52.743  52.286  7
719552  98.083  -52.748  52.261  7
719553  98.104  -52.753  52.235  7
719554  98.125  -52.759  52.206  7
719555  98.146  -52.764  52.178  7
719556  98.167  -52.769  52.150  7
719557  98.208  -52.782  52.124  7
719558  98.244  -52.796  52.098  7
719559  98.260  -52.813  52.070  7
719560  98.297  -52.830  52.040  7
719561  98.334  -52.847  52.010  7
719562  98.370  -52.863  51.975  7
719563  98.407  -52.880  51.937  7
719564  98.444  -52.897  51.898  7
719565  98.481  -52.913  51.857  7
719566  98.517  -52.930  51.819  7
719567  98.554  -52.947  51.780  7
719568  98.591  -52.963  51.742  7
719569  98.605  -52.965  51.704  7
719570  98.616  -52.963  51.665  7
719571  98.633  -52.969  51.626  7
719572  98.653  -52.976  51.587  7
719573  98.672  -52.985  51.547  7
719574  98.693  -52.992  51.508  7
719575  98.713  -53.000  51.470  7
719576  98.732  -53.007  51.431  7
719577  98.749  -53.005  51.392  7
719578  98.767  -53.004  51.353  7
719579  98.784  -53.004  51.315  7
719580  98.802  -53.003  51.276  7
719581  98.819  -53.001  51.237  7
719582  98.838  -53.007  51.198  7
719583  98.859  -53.020  51.159  7
719584  98.879  -53.032  51.120  7
719585  98.900  -53.044  51.081  7
719586  98.920  -53.056  51.043  7
719587  98.939  -53.072  51.005  7
719588  98.957  -53.092  50.966  7
719589  98.975  -53.111  50.928  7
719590  98.992  -53.128  50.890  7
719591  99.010  -53.141  50.853  7
719592  99.027  -53.154  50.815  7
719593  99.045  -53.167  50.777  7
719594  99.062  -53.180  50.738  7
719595  99.080  -53.192  50.699  7
719596  99.097  -53.205  50.658  7
719597  99.115  -53.218  50.617  7
719598  99.132  -53.231  50.575  7
719599  99.150  -53.244  50.533  7
719600  99.167  -53.257  50.491  7
719601  99.185  -53.270  50.449  7
719602  99.205  -53.282  50.407  7
719603  99.231  -53.291  50.366  7
719604  99.258  -53.300  50.324  7
719605  99.284  -53.310  50.282  7
720101  95.335  -50.449  55.576  10
720102  95.370  -50.470  55.563  10
720103  95.403  -50.491  55.549  10
720104  95.434  -50.508  55.536  10
720105  95.465  -50.525  55.523  10
720106  95.496  -50.543  55.509  10
720107  95.527  -50.560  55.493  10
720108  95.555  -50.580  55.477  10
720109  95.582  -50.600  55.461  10
720110  95.609  -50.619  55.443  10
720111  95.636  -50.639  55.424  10
720112  95.663  -50.659  55.404  10
720113  95.689  -50.679  55.384  10
720114  95.713  -50.699  55.363  10
720115  95.727  -50.721  55.343  10
720116  95.741  -50.743  55.321  10
720117  95.755  -50.766  55.300  10
720180  96.653  -52.149  53.868  11
720181  96.668  -52.171  53.849  11
720182  96.683  -52.192  53.830  11
720183  96.698  -52.214  53.809  11
720184  96.714  -52.235  53.788  11
720185  96.729  -52.256  53.767  11
720186  96.744  -52.277  53.746  11
720187  96.759  -52.299  53.724  11
720188  96.773  -52.320  53.702  11
720189  96.789  -52.341  53.678  11
720190  96.804  -52.362  53.654  11
720191  96.819  -52.384  53.629  11
720192  96.834  -52.405  53.604  11
720193  96.850  -52.423  53.578  11
720194  96.871  -52.426  53.551  11
720195  96.892  -52.428  53.524  11
720196  96.913  -52.431  53.495  11
720197  96.935  -52.434  53.467  11
720198  96.956  -52.438  53.440  11
720199  96.976  -52.443  53.413  11
720243  97.882  -52.676  52.504  7
720244  97.902  -52.681  52.481  7
720245  97.923  -52.687  52.457  7
720246  97.943  -52.691  52.433  7
720247  97.964  -52.697  52.410  7
720248  97.985  -52.702  52.387  7
720249  98.005  -52.707  52.362  7
720250  98.025  -52.713  52.338  7
720251  98.046  -52.718  52.315  7
720252  98.067  -52.723  52.291  7
720253  98.087  -52.728  52.267  7
720254  98.108  -52.734  52.241  7
720255  98.129  -52.739  52.214  7
720256  98.150  -52.744  52.186  7
720257  98.171  -52.750  52.157  7
720258  98.196  -52.756  52.130  7
720259  98.229  -52.772  52.103  7
720260  98.266  -52.789  52.073  7
720261  98.302  -52.806  52.043  7
720262  98.339  -52.822  52.011  7
720263  98.376  -52.839  51.975  7
720264  98.413  -52.856  51.938  7
720265  98.449  -52.872  51.900  7
720266  98.486  -52.889  51.860  7
720267  98.523  -52.906  51.824  7
720268  98.560  -52.923  51.787  7
720269  98.596  -52.939  51.751  7
720270  98.613  -52.942  51.714  7
720271  98.624  -52.941  51.674  7
720272  98.636  -52.941  51.634  7
720273  98.656  -52.949  51.593  7
720274  98.676  -52.957  51.553  7
720275  98.696  -52.965  51.514  7
720276  98.716  -52.973  51.475  7
720277  98.736  -52.980  51.436  7
720278  98.756  -52.988  51.397  7
720279  98.774  -52.991  51.358  7
720280  98.792  -52.990  51.319  7
720281  98.809  -52.989  51.280  7
720282  98.827  -52.988  51.241  7
720283  98.845  -52.991  51.202  7
720284  98.865  -53.004  51.163  7
720285  98.886  -53.016  51.123  7
720286  98.906  -53.028  51.084  7
720287  98.927  -53.040  51.046  7
720288  98.947  -53.052  51.009  7
720289  98.967  -53.065  50.970  7
720290  98.985  -53.085  50.933  7
720291  99.003  -53.104  50.894  7
720292  99.020  -53.117  50.856  7
720293  99.038  -53.129  50.818  7
720294  99.055  -53.142  50.780  7
720295  99.073  -53.155  50.740  7
720296  99.090  -53.168  50.701  7
720297  99.108  -53.181  50.660  7
720298  99.125  -53.194  50.619  7
720299  99.143  -53.207  50.578  7
720300  99.160  -53.220  50.537  7
720301  99.178  -53.233  50.495  7
720302  99.196  -53.246  50.453  7
720303  99.213  -53.259  50.411  7
720304  99.233  -53.270  50.370  7
720305  99.259  -53.280  50.329  7
720306  99.286  -53.289  50.287  7
720802  95.348  -50.419  55.594  10
720803  95.382  -50.440  55.581  10
720804  95.416  -50.462  55.568  10
720805  95.451  -50.484  55.556  10
720806  95.482  -50.501  55.544  10
720807  95.513  -50.519  55.529  10
720808  95.544  -50.536  55.515  10
720809  95.574  -50.554  55.499  10
720810  95.601  -50.574  55.482  10
720811  95.627  -50.594  55.464  10
720812  95.655  -50.614  55.445  10
720813  95.681  -50.634  55.424  10
720814  95.708  -50.654  55.404  10
720815  95.722  -50.676  55.382  10
720816  95.736  -50.698  55.362  10
720817  95.750  -50.720  55.340  10
720818  95.764  -50.742  55.317  10
720819  95.778  -50.764  55.294  10
720882  96.688  -52.138  53.854  11
720883  96.703  -52.159  53.834  11
720884  96.718  -52.180  53.814  11
720885  96.733  -52.202  53.794  11
720886  96.748  -52.223  53.772  11
720887  96.763  -52.244  53.751  11
720888  96.779  -52.265  53.730  11
720889  96.794  -52.286  53.708  11
720890  96.809  -52.308  53.685  11
720891  96.824  -52.329  53.661  11
720892  96.838  -52.350  53.636  11
720893  96.854  -52.372  53.612  11
720894  96.869  -52.393  53.587  11
720895  96.884  -52.413  53.559  11
720896  96.905  -52.416  53.533  11
720897  96.927  -52.419  53.504  11
720898  96.948  -52.422  53.476  11
720899  96.969  -52.424  53.449  11
720900  96.990  -52.427  53.422  11
720944  97.896  -52.656  52.512  7
720945  97.917  -52.661  52.488  7
720946  97.938  -52.666  52.464  7
720947  97.958  -52.672  52.440  7
720948  97.979  -52.677  52.416  7
720949  97.999  -52.682  52.393  7
720950  98.020  -52.687  52.368  7
720951  98.040  -52.693  52.343  7
720952  98.061  -52.698  52.319  7
720953  98.082  -52.703  52.295  7
720954  98.102  -52.709  52.271  7
720955  98.123  -52.714  52.246  7
720956  98.143  -52.719  52.219  7
720957  98.164  -52.725  52.192  7
720958  98.184  -52.730  52.163  7
720959  98.205  -52.735  52.135  7
720960  98.234  -52.748  52.107  7
720961  98.271  -52.765  52.076  7
720962  98.308  -52.782  52.043  7
720963  98.345  -52.798  52.010  7
720964  98.381  -52.815  51.975  7
720965  98.419  -52.832  51.939  7
720966  98.455  -52.848  51.903  7
720967  98.492  -52.865  51.866  7
720968  98.529  -52.882  51.832  7
720969  98.566  -52.898  51.797  7
720970  98.602  -52.915  51.762  7
720971  98.622  -52.919  51.725  7
720972  98.632  -52.918  51.685  7
720973  98.642  -52.916  51.642  7
720974  98.659  -52.923  51.599  7
720975  98.679  -52.930  51.558  7
720976  98.699  -52.938  51.518  7
720977  98.719  -52.945  51.479  7
720978  98.739  -52.954  51.439  7
720979  98.759  -52.961  51.400  7
720980  98.779  -52.969  51.361  7
720981  98.799  -52.976  51.321  7
720982  98.816  -52.976  51.283  7
720983  98.834  -52.975  51.245  7
720984  98.852  -52.976  51.205  7
720985  98.872  -52.988  51.166  7
720986  98.892  -53.000  51.127  7
720987  98.913  -53.012  51.088  7
720988  98.933  -53.024  51.048  7
720989  98.954  -53.036  51.010  7
720990  98.974  -53.049  50.973  7
720991  98.995  -53.061  50.934  7
720992  99.013  -53.079  50.897  7
720993  99.030  -53.092  50.859  7
720994  99.048  -53.105  50.821  7
720995  99.066  -53.118  50.782  7
720996  99.083  -53.131  50.743  7
720997  99.101  -53.144  50.702  7
720998  99.118  -53.157  50.662  7
720999  99.136  -53.170  50.621  7
721000  99.153  -53.183  50.580  7
721001  99.171  -53.196  50.540  7
721002  99.189  -53.209  50.499  7
721003  99.206  -53.222  50.457  7
721004  99.223  -53.235  50.415  7
721005  99.241  -53.248  50.374  7
721006  99.261  -53.259  50.332  7
721007  99.288  -53.269  50.291  7
721503  95.361  -50.390  55.611  10
721504  95.395  -50.412  55.598  10
721505  95.429  -50.433  55.586  10
721506  95.464  -50.454  55.575  10
721507  95.498  -50.475  55.562  10
721508  95.530  -50.494  55.549  10
721509  95.561  -50.512  55.535  10
721510  95.592  -50.529  55.519  10
721511  95.619  -50.549  55.502  10
721512  95.647  -50.569  55.484  10
721513  95.673  -50.588  55.464  10
721514  95.700  -50.608  55.443  10
721515  95.717  -50.630  55.422  10
721516  95.731  -50.652  55.400  10
721517  95.745  -50.674  55.378  10
721518  95.759  -50.697  55.356  10
721519  95.773  -50.719  55.332  10
721520  95.787  -50.741  55.309  10
721583  96.708  -52.105  53.855  11
721584  96.723  -52.126  53.835  11
721585  96.738  -52.148  53.816  11
721586  96.753  -52.169  53.796  11
721587  96.768  -52.190  53.775  11
721588  96.783  -52.211  53.756  11
721589  96.798  -52.233  53.735  11
721590  96.813  -52.254  53.713  11
721591  96.828  -52.275  53.691  11
721592  96.843  -52.296  53.667  11
721593  96.859  -52.318  53.643  11
721594  96.874  -52.339  53.619  11
721595  96.889  -52.360  53.595  11
721596  96.904  -52.381  53.568  11
721597  96.919  -52.402  53.541  11
721598  96.940  -52.406  53.513  11
721599  96.961  -52.409  53.485  11
721600  96.982  -52.412  53.458  11
721645  97.912  -52.636  52.520  7
721646  97.932  -52.641  52.495  7
721647  97.952  -52.647  52.470  7
721648  97.973  -52.652  52.446  7
721649  97.994  -52.657  52.422  7
721650  98.014  -52.662  52.397  7
721651  98.035  -52.668  52.373  7
721652  98.056  -52.673  52.348  7
721653  98.076  -52.678  52.323  7
721654  98.096  -52.684  52.298  7
721655  98.117  -52.689  52.273  7
721656  98.138  -52.694  52.249  7
721657  98.158  -52.700  52.223  7
721658  98.179  -52.705  52.196  7
721659  98.200  -52.710  52.168  7
721660  98.220  -52.716  52.139  7
721661  98.243  -52.724  52.110  7
721662  98.277  -52.741  52.077  7
721663  98.314  -52.757  52.043  7
721664  98.351  -52.774  52.009  7
721665  98.387  -52.791  51.974  7
721666  98.424  -52.807  51.940  7
721667  98.461  -52.824  51.906  7
721668  98.498  -52.841  51.873  7
721669  98.534  -52.857  51.841  7
721670  98.571  -52.874  51.807  7
721671  98.608  -52.891  51.772  7
721672  98.630  -52.897  51.735  7
721673  98.640  -52.896  51.694  7
721674  98.650  -52.894  51.649  7
721675  98.663  -52.895  51.604  7
721676  98.683  -52.903  51.562  7
721677  98.703  -52.910  51.523  7
721678  98.723  -52.918  51.483  7
721679  98.742  -52.926  51.443  7
721680  98.763  -52.934  51.403  7
721681  98.783  -52.941  51.363  7
721682  98.802  -52.949  51.324  7
721683  98.822  -52.957  51.285  7
721684  98.841  -52.961  51.248  7
721685  98.859  -52.960  51.209  7
721686  98.879  -52.972  51.169  7
721687  98.900  -52.984  51.130  7
721688  98.920  -52.996  51.090  7
721689  98.940  -53.008  51.051  7
721690  98.960  -53.021  51.012  7
721691  98.981  -53.033  50.975  7
721692  99.001  -53.045  50.936  7
721693  99.022  -53.056  50.899  7
721694  99.041  -53.068  50.861  7
721695  99.059  -53.081  50.823  7
721696  99.076  -53.094  50.784  7
721697  99.094  -53.107  50.744  7
721698  99.112  -53.120  50.703  7
721699  99.129  -53.133  50.664  7
721700  99.146  -53.146  50.624  7
721701  99.164  -53.159  50.582  7
721702  99.182  -53.172  50.542  7
721703  99.199  -53.185  50.501  7
721704  99.216  -53.198  50.460  7
721705  99.234  -53.211  50.418  7
721706  99.252  -53.223  50.377  7
721707  99.269  -53.236  50.335  7
721708  99.289  -53.248  50.294  7
722203  95.339  -50.339  55.637  10
722204  95.374  -50.361  55.624  10
722205  95.408  -50.382  55.612  10
722206  95.442  -50.403  55.601  10
722207  95.476  -50.425  55.590  10
722208  95.511  -50.447  55.579  10
722209  95.545  -50.468  55.567  10
722210  95.578  -50.488  55.553  10
722211  95.609  -50.505  55.538  10
722212  95.638  -50.524  55.522  10
722213  95.665  -50.544  55.504  10
722214  95.692  -50.563  55.483  10
722215  95.712  -50.585  55.461  10
722216  95.726  -50.607  55.438  10
722217  95.740  -50.629  55.416  10
722218  95.754  -50.650  55.393  10
722219  95.768  -50.673  55.370  10
722220  95.782  -50.695  55.346  10
722221  95.796  -50.717  55.322  10
722222  95.810  -50.740  55.299  10
722285  96.743  -52.093  53.837  11
722286  96.758  -52.114  53.817  11
722287  96.773  -52.136  53.797  11
722288  96.788  -52.157  53.777  11
722289  96.803  -52.178  53.759  11
722290  96.818  -52.199  53.738  11
722291  96.833  -52.221  53.717  11
722292  96.849  -52.242  53.695  11
722293  96.863  -52.263  53.672  11
722294  96.878  -52.284  53.649  11
722295  96.893  -52.305  53.625  11
722296  96.908  -52.327  53.601  11
722297  96.924  -52.349  53.575  11
722298  96.939  -52.370  53.548  11
722299  96.954  -52.391  53.521  11
722300  96.974  -52.396  53.493  11
722301  96.995  -52.399  53.466  11
722346  97.926  -52.616  52.527  7
722347  97.947  -52.622  52.501  7
722348  97.967  -52.627  52.476  7
722349  97.988  -52.632  52.451  7
722350  98.009  -52.637  52.426  7
722351  98.029  -52.643  52.403  7
722352  98.050  -52.648  52.378  7
722353  98.070  -52.653  52.351  7
722354  98.091  -52.659  52.326  7
722355  98.111  -52.664  52.301  7
722356  98.132  -52.669  52.277  7
722357  98.153  -52.675  52.251  7
722358  98.173  -52.680  52.224  7
722359  98.194  -52.685  52.198  7
722360  98.214  -52.691  52.169  7
722361  98.235  -52.696  52.140  7
722362  98.255  -52.701  52.110  7
722363  98.283  -52.716  52.078  7
722364  98.319  -52.733  52.044  7
722365  98.356  -52.750  52.009  7
722366  98.393  -52.766  51.975  7
722367  98.430  -52.783  51.942  7
722368  98.466  -52.800  51.911  7
722369  98.504  -52.816  51.881  7
722370  98.541  -52.833  51.850  7
722371  98.577  -52.850  51.816  7
722372  98.614  -52.866  51.780  7
722373  98.638  -52.875  51.741  7
722374  98.648  -52.873  51.699  7
722375  98.658  -52.872  51.653  7
722376  98.668  -52.870  51.609  7
722377  98.686  -52.876  51.566  7
722378  98.706  -52.883  51.526  7
722379  98.726  -52.891  51.487  7
722380  98.746  -52.899  51.446  7
722381  98.766  -52.907  51.406  7
722382  98.786  -52.914  51.366  7
722383  98.806  -52.922  51.327  7
722384  98.826  -52.930  51.288  7
722385  98.846  -52.938  51.250  7
722386  98.866  -52.945  51.213  7
722387  98.886  -52.955  51.173  7
722388  98.907  -52.966  51.132  7
722389  98.927  -52.977  51.092  7
722390  98.947  -52.988  51.053  7
722391  98.968  -52.999  51.015  7
722392  98.988  -53.010  50.977  7
722393  99.009  -53.020  50.938  7
722394  99.030  -53.030  50.901  7
722395  99.054  -53.042  50.863  7
722396  99.069  -53.057  50.824  7
722397  99.087  -53.070  50.785  7
722398  99.104  -53.083  50.745  7
722399  99.122  -53.096  50.705  7
722400  99.139  -53.109  50.666  7
722401  99.157  -53.122  50.626  7
722402  99.174  -53.135  50.585  7
722403  99.192  -53.148  50.544  7
722404  99.209  -53.161  50.503  7
722405  99.227  -53.173  50.462  7
722406  99.244  -53.186  50.421  7
722407  99.262  -53.199  50.380  7
722408  99.280  -53.212  50.339  7
722409  99.297  -53.225  50.297  7
722904  95.352  -50.310  55.648  10
722905  95.387  -50.331  55.635  10
722906  95.421  -50.353  55.624  10
722907  95.455  -50.374  55.614  10
722908  95.489  -50.396  55.603  10
722909  95.524  -50.417  55.592  10
722910  95.558  -50.438  55.580  10
722911  95.592  -50.459  55.567  10
722912  95.626  -50.481  55.552  10
722913  95.657  -50.499  55.536  10
722914  95.684  -50.518  55.518  10
722915  95.707  -50.538  55.498  10
722916  95.721  -50.561  55.476  10
722917  95.735  -50.583  55.454  10
722918  95.749  -50.605  55.430  10
722919  95.763  -50.628  55.406  10
722920  95.777  -50.650  55.384  10
722921  95.791  -50.672  55.359  10
722922  95.805  -50.694  55.335  10
722923  95.819  -50.716  55.310  10
722987  96.778  -52.081  53.818  11
722988  96.793  -52.102  53.799  11
722989  96.808  -52.124  53.780  11
722990  96.823  -52.145  53.761  11
722991  96.838  -52.167  53.741  11
722992  96.853  -52.188  53.721  11
722993  96.868  -52.209  53.699  11
722994  96.883  -52.230  53.676  11
722995  96.898  -52.252  53.654  11
722996  96.913  -52.273  53.631  11
722997  96.929  -52.294  53.607  11
722998  96.943  -52.315  53.583  11
722999  96.958  -52.336  53.556  11
723000  96.973  -52.358  53.529  11
723001  96.989  -52.379  53.502  11
723047  97.941  -52.597  52.534  7
723048  97.962  -52.602  52.508  7
723049  97.983  -52.607  52.482  7
723050  98.003  -52.612  52.456  7
723051  98.023  -52.618  52.432  7
723052  98.044  -52.623  52.407  7
723053  98.065  -52.628  52.382  7
723054  98.085  -52.634  52.355  7
723055  98.106  -52.639  52.330  7
723056  98.127  -52.644  52.304  7
723057  98.147  -52.650  52.279  7
723058  98.167  -52.655  52.253  7
723059  98.188  -52.660  52.225  7
723060  98.209  -52.666  52.198  7
723061  98.229  -52.671  52.169  7
723062  98.250  -52.676  52.140  7
723063  98.270  -52.681  52.110  7
723064  98.295  -52.692  52.078  7
723065  98.325  -52.709  52.045  7
723066  98.362  -52.725  52.011  7
723067  98.399  -52.742  51.977  7
723068  98.436  -52.759  51.945  7
723069  98.473  -52.775  51.915  7
723070  98.509  -52.792  51.887  7
723071  98.546  -52.809  51.855  7
723072  98.583  -52.825  51.820  7
723073  98.620  -52.842  51.783  7
723074  98.646  -52.852  51.744  7
723075  98.656  -52.850  51.701  7
723076  98.666  -52.849  51.656  7
723077  98.677  -52.847  51.612  7
723078  98.690  -52.848  51.570  7
723079  98.710  -52.856  51.530  7
723080  98.729  -52.864  51.490  7
723081  98.749  -52.872  51.449  7
723082  98.769  -52.879  51.408  7
723083  98.789  -52.887  51.368  7
723084  98.809  -52.895  51.330  7
723085  98.829  -52.903  51.291  7
723086  98.849  -52.910  51.255  7
723087  98.872  -52.919  51.216  7
723088  98.894  -52.931  51.176  7
723089  98.914  -52.941  51.135  7
723090  98.934  -52.952  51.095  7
723091  98.955  -52.963  51.056  7
723092  98.975  -52.973  51.018  7
723093  98.996  -52.985  50.979  7
723094  99.016  -52.995  50.941  7
723095  99.043  -53.003  50.903  7
723096  99.064  -53.017  50.865  7
723097  99.082  -53.029  50.826  7
723098  99.098  -53.045  50.788  7
723099  99.115  -53.059  50.748  7
723100  99.132  -53.072  50.708  7
723101  99.150  -53.085  50.668  7
723102  99.167  -53.098  50.629  7
723103  99.185  -53.111  50.588  7
723104  99.203  -53.123  50.547  7
723105  99.220  -53.136  50.507  7
723106  99.237  -53.149  50.466  7
723107  99.255  -53.162  50.425  7
723108  99.273  -53.175  50.384  7
723109  99.290  -53.188  50.343  7
723110  99.307  -53.201  50.302  7
723605  95.365  -50.281  55.656  10
723606  95.399  -50.302  55.644  10
723607  95.433  -50.324  55.634  10
723608  95.468  -50.345  55.625  10
723609  95.502  -50.366  55.614  10
723610  95.536  -50.387  55.603  10
723611  95.570  -50.409  55.591  10
723612  95.605  -50.431  55.579  10
723613  95.639  -50.452  55.564  10
723614  95.673  -50.473  55.548  10
723615  95.702  -50.493  55.531  10
723616  95.716  -50.516  55.510  10
723617  95.730  -50.538  55.488  10
723618  95.744  -50.560  55.465  10
723619  95.759  -50.581  55.441  10
723620  95.774  -50.602  55.418  10
723621  95.789  -50.623  55.394  10
723622  95.804  -50.645  55.368  10
723623  95.819  -50.666  55.343  10
723624  95.834  -50.688  55.319  10
723689  96.813  -52.070  53.800  11
723690  96.828  -52.091  53.780  11
723691  96.843  -52.112  53.762  11
723692  96.858  -52.133  53.743  11
723693  96.873  -52.155  53.723  11
723694  96.888  -52.176  53.702  11
723695  96.903  -52.197  53.680  11
723696  96.918  -52.218  53.658  11
723697  96.933  -52.239  53.637  11
723698  96.948  -52.261  53.614  11
723699  96.963  -52.282  53.590  11
723700  96.978  -52.303  53.565  11
723701  96.994  -52.325  53.538  11
723748  97.956  -52.577  52.541  7
723749  97.977  -52.582  52.514  7
723750  97.997  -52.587  52.488  7
723751  98.018  -52.593  52.462  7
723752  98.038  -52.598  52.437  7
723753  98.059  -52.603  52.412  7
723754  98.080  -52.609  52.385  7
723755  98.100  -52.614  52.359  7
723756  98.121  -52.619  52.334  7
723757  98.141  -52.625  52.307  7
723758  98.162  -52.630  52.281  7
723759  98.182  -52.635  52.255  7
723760  98.203  -52.641  52.226  7
723761  98.223  -52.646  52.198  7
723762  98.244  -52.651  52.169  7
723763  98.265  -52.656  52.140  7
723764  98.285  -52.662  52.110  7
723765  98.306  -52.668  52.079  7
723766  98.335  -52.684  52.046  7
723767  98.368  -52.701  52.013  7
723768  98.405  -52.718  51.980  7
723769  98.441  -52.735  51.948  7
723770  98.478  -52.751  51.919  7
723771  98.515  -52.768  51.890  7
723772  98.552  -52.785  51.857  7
723773  98.589  -52.801  51.821  7
723774  98.626  -52.818  51.784  7
723775  98.654  -52.829  51.745  7
723776  98.664  -52.828  51.702  7
723777  98.675  -52.826  51.658  7
723778  98.685  -52.825  51.614  7
723779  98.695  -52.823  51.573  7
723780  98.713  -52.828  51.533  7
723781  98.733  -52.837  51.493  7
723782  98.753  -52.844  51.453  7
723783  98.773  -52.852  51.411  7
723784  98.793  -52.860  51.371  7
723785  98.812  -52.868  51.332  7
723786  98.833  -52.876  51.294  7
723787  98.853  -52.883  51.258  7
723788  98.880  -52.894  51.219  7
723789  98.904  -52.906  51.179  7
723790  98.921  -52.916  51.138  7
723791  98.942  -52.927  51.098  7
723792  98.962  -52.938  51.058  7
723793  98.983  -52.948  51.021  7
723794  99.003  -52.960  50.982  7
723795  99.024  -52.970  50.944  7
723796  99.055  -52.975  50.907  7
723797  99.074  -52.991  50.868  7
723798  99.096  -53.002  50.830  7
723799  99.111  -53.018  50.791  7
723800  99.127  -53.033  50.751  7
723801  99.143  -53.048  50.711  7
723802  99.160  -53.060  50.672  7
723803  99.178  -53.073  50.632  7
723804  99.196  -53.086  50.592  7
723805  99.213  -53.099  50.551  7
723806  99.230  -53.112  50.511  7
723807  99.248  -53.125  50.470  7
723808  99.266  -53.139  50.429  7
723809  99.283  -53.151  50.388  7
723810  99.300  -53.164  50.348  7
723811  99.318  -53.177  50.307  7
723812  99.336  -53.190  50.266  7
724306  95.378  -50.252  55.662  10
724307  95.412  -50.273  55.651  10
724308  95.449  -50.294  55.641  10
724309  95.486  -50.315  55.632  10
724310  95.524  -50.337  55.622  10
724311  95.560  -50.358  55.611  10
724312  95.598  -50.380  55.599  10
724313  95.634  -50.401  55.588  10
724314  95.672  -50.422  55.574  10
724315  95.678  -50.460  55.558  10
724316  95.709  -50.468  55.541  10
724317  95.734  -50.484  55.520  10
724318  95.749  -50.506  55.497  10
724319  95.764  -50.527  55.474  10
724320  95.779  -50.548  55.449  10
724321  95.794  -50.569  55.426  10
724322  95.809  -50.591  55.402  10
724323  95.824  -50.612  55.376  10
724324  95.839  -50.633  55.350  10
724325  95.854  -50.654  55.325  10
724391  96.848  -52.058  53.780  11
724392  96.863  -52.079  53.761  11
724393  96.878  -52.101  53.742  11
724394  96.893  -52.122  53.723  11
724395  96.908  -52.143  53.703  11
724396  96.923  -52.164  53.682  11
724397  96.938  -52.186  53.660  11
724398  96.953  -52.207  53.640  11
724399  96.968  -52.228  53.617  11
724400  96.983  -52.249  53.595  11
724449  97.971  -52.557  52.548  7
724450  97.992  -52.562  52.520  7
724451  98.012  -52.568  52.493  7
724452  98.033  -52.573  52.467  7
724453  98.053  -52.578  52.441  7
724454  98.074  -52.584  52.417  7
724455  98.094  -52.589  52.389  7
724456  98.115  -52.594  52.363  7
724457  98.136  -52.600  52.336  7
724458  98.156  -52.605  52.310  7
724459  98.176  -52.610  52.284  7
724460  98.197  -52.615  52.258  7
724461  98.218  -52.621  52.229  7
724462  98.238  -52.626  52.200  7
724463  98.259  -52.631  52.170  7
724464  98.280  -52.637  52.141  7
724465  98.300  -52.641  52.112  7
724466  98.320  -52.647  52.081  7
724467  98.347  -52.660  52.048  7
724468  98.375  -52.677  52.014  7
724469  98.411  -52.694  51.983  7
724470  98.447  -52.710  51.951  7
724471  98.484  -52.727  51.922  7
724472  98.521  -52.744  51.891  7
724473  98.558  -52.760  51.857  7
724474  98.594  -52.777  51.820  7
724475  98.631  -52.794  51.783  7
724476  98.662  -52.807  51.744  7
724477  98.672  -52.805  51.703  7
724478  98.683  -52.803  51.660  7
724479  98.693  -52.802  51.617  7
724480  98.704  -52.800  51.575  7
724481  98.716  -52.802  51.535  7
724482  98.736  -52.810  51.496  7
724483  98.756  -52.817  51.457  7
724484  98.776  -52.825  51.415  7
724485  98.796  -52.833  51.375  7
724486  98.816  -52.841  51.335  7
724487  98.836  -52.848  51.297  7
724488  98.858  -52.857  51.260  7
724489  98.889  -52.869  51.222  7
724490  98.915  -52.882  51.182  7
724491  98.932  -52.892  51.141  7
724492  98.949  -52.902  51.101  7
724493  98.970  -52.913  51.061  7
724494  98.990  -52.923  51.023  7
724495  99.010  -52.935  50.985  7
724496  99.036  -52.942  50.948  7
724497  99.066  -52.947  50.910  7
724498  99.083  -52.968  50.871  7
724499  99.106  -52.976  50.833  7
724500  99.125  -52.990  50.794  7
724501  99.140  -53.006  50.755  7
724502  99.155  -53.021  50.715  7
724503  99.171  -53.036  50.676  7
724504  99.189  -53.049  50.636  7
724505  99.206  -53.062  50.596  7
724506  99.223  -53.076  50.556  7
724507  99.241  -53.089  50.515  7
724508  99.259  -53.101  50.474  7
724509  99.276  -53.114  50.434  7
724510  99.293  -53.127  50.393  7
724511  99.311  -53.140  50.353  7
724512  99.329  -53.153  50.312  7
724513  99.346  -53.166  50.271  7
724514  99.364  -53.179  50.231  7
724515  99.381  -53.192  50.190  7
725007  95.425  -50.221  55.665  10
725008  95.462  -50.243  55.654  10
725009  95.499  -50.264  55.644  10
725010  95.536  -50.286  55.635  10
725011  95.573  -50.307  55.626  10
725012  95.610  -50.328  55.616  10
725013  95.648  -50.350  55.605  10
725014  95.654  -50.389  55.592  10
725015  95.645  -50.434  55.578  10
725016  95.678  -50.435  55.562  10
725017  95.708  -50.445  55.545  10
725018  95.735  -50.460  55.525  10
725019  95.761  -50.476  55.503  10
725020  95.783  -50.494  55.480  10
725021  95.799  -50.515  55.455  10
725022  95.814  -50.536  55.432  10
725023  95.829  -50.557  55.407  10
725024  95.844  -50.578  55.382  10
725025  95.859  -50.600  55.355  10
725026  95.874  -50.622  55.330  10
725094  96.897  -52.067  53.741  11
725095  96.912  -52.089  53.722  11
725096  96.928  -52.110  53.702  11
725097  96.943  -52.131  53.682  11
725098  96.958  -52.152  53.661  11
725099  96.973  -52.174  53.641  11
725150  97.986  -52.537  52.555  7
725151  98.006  -52.543  52.527  7
725152  98.027  -52.548  52.499  7
725153  98.048  -52.553  52.473  7
725154  98.068  -52.559  52.446  7
725155  98.089  -52.564  52.421  7
725156  98.109  -52.569  52.393  7
725157  98.130  -52.575  52.366  7
725158  98.150  -52.580  52.340  7
725159  98.171  -52.585  52.313  7
725160  98.192  -52.590  52.288  7
725161  98.212  -52.596  52.261  7
725162  98.233  -52.601  52.232  7
725163  98.253  -52.606  52.203  7
725164  98.274  -52.611  52.173  7
725165  98.294  -52.616  52.144  7
725166  98.315  -52.622  52.114  7
725167  98.336  -52.627  52.083  7
725168  98.358  -52.635  52.050  7
725169  98.387  -52.653  52.017  7
725170  98.416  -52.669  51.985  7
725171  98.453  -52.686  51.953  7
725172  98.490  -52.703  51.922  7
725173  98.526  -52.719  51.890  7
725174  98.563  -52.736  51.854  7
725175  98.600  -52.753  51.817  7
725176  98.637  -52.769  51.780  7
725177  98.670  -52.784  51.742  7
725178  98.681  -52.782  51.702  7
725179  98.691  -52.781  51.661  7
725180  98.702  -52.780  51.619  7
725181  98.712  -52.778  51.578  7
725182  98.722  -52.777  51.538  7
725183  98.739  -52.782  51.499  7
725184  98.760  -52.790  51.459  7
725185  98.780  -52.797  51.419  7
725186  98.799  -52.806  51.379  7
725187  98.819  -52.813  51.340  7
725188  98.839  -52.821  51.301  7
725189  98.866  -52.832  51.263  7
725190  98.898  -52.845  51.224  7
725191  98.926  -52.857  51.184  7
725192  98.943  -52.867  51.144  7
725193  98.959  -52.878  51.104  7
725194  98.977  -52.888  51.065  7
725195  98.997  -52.898  51.028  7
725196  99.018  -52.910  50.989  7
725197  99.048  -52.915  50.952  7
725198  99.078  -52.919  50.913  7
725199  99.092  -52.944  50.875  7
725200  99.117  -52.951  50.838  7
725201  99.138  -52.963  50.799  7
725202  99.153  -52.978  50.759  7
725203  99.168  -52.994  50.720  7
725204  99.184  -53.010  50.681  7
725205  99.199  -53.025  50.641  7
725206  99.216  -53.038  50.600  7
725207  99.234  -53.051  50.561  7
725208  99.252  -53.064  50.520  7
725209  99.269  -53.077  50.480  7
725210  99.287  -53.090  50.439  7
725211  99.304  -53.103  50.399  7
725212  99.322  -53.116  50.358  7
725213  99.339  -53.129  50.317  7
725214  99.357  -53.142  50.276  7
725215  99.374  -53.154  50.236  7
725216  99.392  -53.167  50.196  7
725217  99.409  -53.180  50.155  7
725708  95.475  -50.191  55.666  10
725709  95.512  -50.213  55.655  10
725710  95.549  -50.234  55.644  10
725711  95.586  -50.256  55.636  10
725712  95.623  -50.277  55.627  10
725713  95.631  -50.315  55.619  10
725714  95.618  -50.366  55.608  10
725715  95.612  -50.409  55.595  10
725716  95.644  -50.409  55.580  10
725717  95.678  -50.410  55.564  10
725718  95.708  -50.422  55.547  10
725719  95.734  -50.437  55.527  10
725720  95.761  -50.453  55.504  10
725721  95.787  -50.469  55.481  10
725722  95.813  -50.484  55.457  10
725723  95.833  -50.503  55.433  10
725724  95.848  -50.525  55.409  10
725725  95.864  -50.546  55.384  10
725726  95.879  -50.567  55.358  10
725727  95.894  -50.588  55.333  10
725851  98.001  -52.518  52.562  7
725852  98.021  -52.523  52.533  7
725853  98.042  -52.528  52.505  7
725854  98.063  -52.534  52.478  7
725855  98.083  -52.539  52.451  7
725856  98.103  -52.544  52.427  7
725857  98.124  -52.550  52.398  7
725858  98.145  -52.555  52.370  7
725859  98.165  -52.560  52.343  7
725860  98.186  -52.565  52.317  7
725861  98.207  -52.571  52.291  7
725862  98.227  -52.575  52.265  7
725863  98.247  -52.581  52.235  7
725864  98.268  -52.586  52.206  7
725865  98.289  -52.591  52.176  7
725866  98.309  -52.597  52.147  7
725867  98.330  -52.602  52.117  7
725868  98.351  -52.607  52.085  7
725869  98.371  -52.612  52.053  7
725870  98.398  -52.628  52.020  7
725871  98.427  -52.645  51.988  7
725872  98.459  -52.662  51.955  7
725873  98.496  -52.678  51.922  7
725874  98.532  -52.695  51.889  7
725875  98.569  -52.712  51.852  7
725876  98.606  -52.728  51.815  7
725877  98.643  -52.745  51.777  7
725878  98.678  -52.762  51.740  7
725879  98.689  -52.760  51.701  7
725880  98.699  -52.759  51.662  7
725881  98.710  -52.757  51.621  7
725882  98.720  -52.756  51.581  7
725883  98.730  -52.754  51.541  7
725884  98.743  -52.755  51.502  7
725885  98.763  -52.763  51.462  7
725886  98.783  -52.770  51.422  7
725887  98.803  -52.778  51.383  7
725888  98.823  -52.786  51.343  7
725889  98.844  -52.794  51.304  7
725890  98.875  -52.807  51.265  7
725891  98.906  -52.820  51.226  7
725892  98.937  -52.833  51.187  7
725893  98.953  -52.843  51.147  7
725894  98.971  -52.854  51.107  7
725895  98.987  -52.863  51.070  7
725896  99.005  -52.873  51.032  7
725897  99.029  -52.882  50.994  7
725898  99.060  -52.887  50.956  7
725899  99.090  -52.891  50.917  7
725900  99.101  -52.919  50.879  7
725901  99.128  -52.926  50.842  7
725902  99.149  -52.937  50.803  7
725903  99.167  -52.951  50.764  7
725904  99.182  -52.966  50.725  7
725905  99.197  -52.982  50.685  7
725906  99.213  -52.998  50.645  7
725907  99.228  -53.013  50.605  7
725908  99.244  -53.027  50.565  7
725909  99.262  -53.040  50.525  7
725910  99.280  -53.053  50.485  7
725911  99.297  -53.066  50.445  7
725912  99.314  -53.079  50.404  7
725913  99.332  -53.092  50.363  7
725914  99.350  -53.104  50.322  7
725915  99.367  -53.117  50.282  7
725916  99.384  -53.130  50.242  7
725917  99.402  -53.143  50.201  7
725918  99.420  -53.156  50.160  7
725919  99.437  -53.169  50.119  7
726410  95.562  -50.183  55.654  10
726411  95.599  -50.204  55.644  10
726412  95.609  -50.241  55.635  10
726413  95.595  -50.293  55.626  10
726414  95.582  -50.343  55.618  10
726415  95.579  -50.383  55.607  10
726416  95.611  -50.384  55.594  10
726417  95.644  -50.384  55.580  10
726418  95.677  -50.385  55.564  10
726419  95.707  -50.398  55.546  10
726420  95.734  -50.415  55.527  10
726421  95.760  -50.431  55.504  10
726422  95.787  -50.446  55.481  10
726423  95.813  -50.462  55.458  10
726424  95.839  -50.478  55.433  10
726425  95.866  -50.493  55.409  10
726426  95.883  -50.513  55.385  10
726427  95.898  -50.534  55.359  10
726553  98.036  -52.503  52.540  7
726554  98.057  -52.509  52.512  7
726555  98.077  -52.514  52.484  7
726556  98.098  -52.519  52.458  7
726557  98.119  -52.525  52.431  7
726558  98.139  -52.530  52.403  7
726559  98.160  -52.535  52.375  7
726560  98.180  -52.540  52.348  7
726561  98.201  -52.545  52.321  7
726562  98.221  -52.550  52.295  7
726563  98.242  -52.556  52.268  7
726564  98.263  -52.561  52.238  7
726565  98.283  -52.566  52.209  7
726566  98.304  -52.572  52.179  7
726567  98.324  -52.577  52.150  7
726568  98.345  -52.582  52.120  7
726569  98.365  -52.587  52.088  7
726570  98.386  -52.593  52.056  7
726571  98.410  -52.603  52.022  7
726572  98.439  -52.621  51.989  7
726573  98.468  -52.637  51.957  7
726574  98.501  -52.654  51.923  7
726575  98.538  -52.671  51.888  7
726576  98.575  -52.687  51.851  7
726577  98.612  -52.704  51.814  7
726578  98.648  -52.721  51.777  7
726579  98.685  -52.738  51.740  7
726580  98.697  -52.738  51.702  7
726581  98.708  -52.736  51.663  7
726582  98.718  -52.735  51.622  7
726583  98.728  -52.733  51.583  7
726584  98.738  -52.731  51.545  7
726585  98.748  -52.730  51.506  7
726586  98.766  -52.735  51.466  7
726587  98.786  -52.744  51.426  7
726588  98.806  -52.751  51.386  7
726589  98.826  -52.759  51.346  7
726590  98.852  -52.769  51.307  7
726591  98.883  -52.782  51.268  7
726592  98.915  -52.795  51.228  7
726593  98.946  -52.808  51.189  7
726594  98.964  -52.819  51.151  7
726595  98.981  -52.828  51.112  7
726596  98.998  -52.839  51.073  7
726597  99.015  -52.849  51.037  7
726598  99.041  -52.854  50.998  7
726599  99.072  -52.859  50.960  7
726600  99.102  -52.863  50.922  7
726601  99.111  -52.895  50.884  7
726602  99.138  -52.901  50.846  7
726603  99.159  -52.912  50.807  7
726604  99.181  -52.923  50.768  7
726605  99.196  -52.938  50.729  7
726606  99.211  -52.954  50.690  7
726607  99.226  -52.970  50.649  7
726608  99.241  -52.985  50.610  7
726609  99.257  -53.001  50.570  7
726610  99.273  -53.016  50.530  7
726611  99.290  -53.029  50.490  7
726612  99.307  -53.042  50.450  7
726613  99.325  -53.054  50.409  7
726614  99.343  -53.067  50.368  7
726615  99.360  -53.080  50.328  7
726616  99.377  -53.093  50.287  7
726617  99.395  -53.106  50.247  7
726618  99.413  -53.120  50.206  7
726619  99.430  -53.132  50.165  7
726620  99.448  -53.145  50.124  7
726621  99.466  -53.158  50.084  7
726622  99.488  -53.169  50.043  7
727111  95.587  -50.168  55.652  10
727112  95.573  -50.219  55.642  10
727113  95.559  -50.270  55.633  10
727114  95.545  -50.321  55.624  10
727115  95.545  -50.357  55.616  10
727116  95.578  -50.358  55.604  10
727117  95.611  -50.359  55.591  10
727118  95.644  -50.359  55.577  10
727119  95.677  -50.360  55.560  10
727120  95.706  -50.375  55.543  10
727121  95.733  -50.392  55.524  10
727122  95.760  -50.408  55.502  10
727123  95.786  -50.423  55.479  10
727124  95.812  -50.439  55.456  10
727125  95.839  -50.454  55.431  10
727126  95.865  -50.470  55.407  10
727127  95.891  -50.486  55.384  10
727128  95.918  -50.501  55.359  10
727255  98.072  -52.489  52.519  7
727256  98.092  -52.494  52.491  7
727257  98.113  -52.499  52.464  7
727258  98.134  -52.505  52.436  7
727259  98.154  -52.509  52.408  7
727260  98.174  -52.515  52.380  7
727261  98.195  -52.520  52.353  7
727262  98.216  -52.525  52.326  7
727263  98.236  -52.531  52.299  7
727264  98.257  -52.536  52.272  7
727265  98.277  -52.541  52.242  7
727266  98.298  -52.546  52.212  7
727267  98.318  -52.552  52.183  7
727268  98.339  -52.557  52.153  7
727269  98.360  -52.562  52.123  7
727270  98.380  -52.568  52.091  7
727271  98.401  -52.573  52.058  7
727272  98.422  -52.579  52.025  7
727273  98.450  -52.596  51.992  7
727274  98.480  -52.613  51.959  7
727275  98.508  -52.630  51.925  7
727276  98.544  -52.647  51.889  7
727277  98.581  -52.663  51.853  7
727278  98.618  -52.680  51.815  7
727279  98.654  -52.697  51.778  7
727280  98.691  -52.713  51.741  7
727281  98.705  -52.715  51.703  7
727282  98.716  -52.713  51.665  7
727283  98.726  -52.712  51.625  7
727284  98.736  -52.710  51.586  7
727285  98.746  -52.709  51.547  7
727286  98.757  -52.707  51.509  7
727287  98.770  -52.708  51.470  7
727288  98.790  -52.716  51.429  7
727289  98.809  -52.724  51.389  7
727290  98.830  -52.731  51.349  7
727291  98.861  -52.744  51.310  7
727292  98.892  -52.757  51.270  7
727293  98.923  -52.770  51.232  7
727294  98.954  -52.784  51.193  7
727295  98.975  -52.794  51.154  7
727296  98.992  -52.804  51.116  7
727297  99.009  -52.815  51.078  7
727298  99.031  -52.822  51.040  7
727299  99.058  -52.826  51.003  7
727300  99.084  -52.832  50.965  7
727301  99.114  -52.837  50.927  7
727302  99.120  -52.871  50.888  7
727303  99.147  -52.877  50.849  7
727304  99.170  -52.886  50.811  7
727305  99.192  -52.897  50.772  7
727306  99.209  -52.911  50.733  7
727307  99.224  -52.926  50.694  7
727308  99.239  -52.942  50.654  7
727309  99.255  -52.958  50.614  7
727310  99.270  -52.973  50.575  7
727311  99.285  -52.989  50.535  7
727312  99.300  -53.004  50.494  7
727313  99.318  -53.017  50.454  7
727314  99.336  -53.030  50.413  7
727315  99.353  -53.043  50.373  7
727316  99.371  -53.057  50.333  7
727317  99.388  -53.070  50.292  7
727318  99.406  -53.082  50.251  7
727319  99.423  -53.095  50.210  7
727320  99.441  -53.108  50.169  7
727321  99.458  -53.121  50.128  7
727322  99.476  -53.134  50.088  7
727323  99.493  -53.147  50.047  7
727324  99.516  -53.158  50.007  7
727813  95.523  -50.247  55.640  10
727814  95.509  -50.298  55.631  10
727815  95.512  -50.331  55.621  10
727816  95.545  -50.332  55.612  10
727817  95.578  -50.333  55.600  10
727818  95.611  -50.334  55.586  10
727819  95.643  -50.334  55.571  10
727820  95.676  -50.335  55.555  10
727821  95.705  -50.351  55.538  10
727822  95.733  -50.369  55.520  10
727823  95.759  -50.384  55.498  10
727824  95.785  -50.400  55.474  10
727825  95.812  -50.416  55.451  10
727826  95.838  -50.431  55.428  10
727827  95.865  -50.447  55.404  10
727828  95.891  -50.462  55.380  10
727957  98.107  -52.474  52.498  7
727958  98.128  -52.479  52.470  7
727959  98.148  -52.484  52.441  7
727960  98.169  -52.490  52.413  7
727961  98.190  -52.495  52.386  7
727962  98.210  -52.500  52.358  7
727963  98.230  -52.506  52.330  7
727964  98.251  -52.511  52.303  7
727965  98.272  -52.516  52.276  7
727966  98.292  -52.521  52.246  7
727967  98.313  -52.527  52.216  7
727968  98.334  -52.532  52.186  7
727969  98.354  -52.537  52.156  7
727970  98.374  -52.543  52.126  7
727971  98.395  -52.548  52.094  7
727972  98.416  -52.553  52.061  7
727973  98.436  -52.559  52.028  7
727974  98.462  -52.572  51.995  7
727975  98.491  -52.588  51.961  7
727976  98.520  -52.606  51.927  7
727977  98.550  -52.622  51.891  7
727978  98.586  -52.639  51.855  7
727979  98.623  -52.656  51.818  7
727980  98.660  -52.672  51.780  7
727981  98.697  -52.689  51.744  7
727982  98.714  -52.692  51.705  7
727983  98.724  -52.691  51.667  7
727984  98.734  -52.689  51.629  7
727985  98.744  -52.687  51.589  7
727986  98.755  -52.686  51.551  7
727987  98.765  -52.684  51.512  7
727988  98.775  -52.683  51.473  7
727989  98.793  -52.689  51.433  7
727990  98.813  -52.697  51.393  7
727991  98.838  -52.706  51.352  7
727992  98.869  -52.720  51.313  7
727993  98.901  -52.733  51.274  7
727994  98.932  -52.746  51.235  7
727995  98.963  -52.759  51.197  7
727996  98.986  -52.770  51.158  7
727997  99.003  -52.780  51.119  7
727998  99.023  -52.788  51.081  7
727999  99.049  -52.794  51.045  7
728000  99.075  -52.798  51.007  7
728001  99.101  -52.803  50.970  7
728002  99.124  -52.812  50.931  7
728003  99.130  -52.847  50.892  7
728004  99.156  -52.853  50.854  7
728005  99.181  -52.861  50.816  7
728006  99.202  -52.872  50.777  7
728007  99.222  -52.883  50.738  7
728008  99.238  -52.899  50.698  7
728009  99.253  -52.915  50.658  7
728010  99.268  -52.930  50.619  7
728011  99.283  -52.946  50.579  7
728012  99.299  -52.962  50.539  7
728013  99.314  -52.977  50.499  7
728014  99.329  -52.993  50.459  7
728015  99.346  -53.007  50.418  7
728016  99.364  -53.020  50.378  7
728017  99.381  -53.032  50.338  7
728018  99.399  -53.045  50.297  7
728019  99.416  -53.058  50.256  7
728020  99.434  -53.071  50.215  7
728021  99.451  -53.084  50.174  7
728022  99.469  -53.097  50.133  7
728023  99.486  -53.110  50.093  7
728024  99.504  -53.123  50.052  7
728025  99.521  -53.136  50.012  7
728514  95.473  -50.276  55.638  10
728515  95.479  -50.306  55.628  10
728516  95.512  -50.306  55.617  10
728517  95.545  -50.307  55.607  10
728518  95.578  -50.308  55.595  10
728519  95.610  -50.309  55.580  10
728520  95.643  -50.309  55.564  10
728521  95.676  -50.310  55.549  10
728522  95.705  -50.328  55.533  10
728523  95.732  -50.346  55.514  10
728524  95.759  -50.362  55.492  10
728525  95.785  -50.378  55.469  10
728526  95.811  -50.394  55.446  10
728527  95.838  -50.409  55.423  10
728528  95.864  -50.425  55.399  10
728662  98.204  -52.475  52.391  7
728663  98.225  -52.481  52.363  7
728664  98.245  -52.486  52.335  7
728665  98.266  -52.491  52.308  7
728666  98.287  -52.496  52.281  7
728667  98.307  -52.502  52.251  7
728668  98.327  -52.507  52.220  7
728669  98.348  -52.512  52.190  7
728670  98.369  -52.518  52.160  7
728671  98.389  -52.523  52.130  7
728672  98.410  -52.528  52.098  7
728673  98.431  -52.534  52.065  7
728674  98.451  -52.539  52.032  7
728675  98.474  -52.547  51.999  7
728676  98.503  -52.564  51.965  7
728677  98.531  -52.581  51.931  7
728678  98.560  -52.598  51.894  7
728679  98.592  -52.615  51.858  7
728680  98.629  -52.631  51.821  7
728681  98.666  -52.648  51.784  7
728682  98.703  -52.665  51.747  7
728683  98.722  -52.669  51.709  7
728684  98.732  -52.668  51.670  7
728685  98.742  -52.666  51.632  7
728686  98.752  -52.665  51.593  7
728687  98.763  -52.663  51.555  7
728688  98.773  -52.662  51.516  7
728689  98.783  -52.661  51.477  7
728690  98.796  -52.662  51.437  7
728691  98.816  -52.669  51.397  7
728692  98.847  -52.682  51.356  7
728693  98.878  -52.695  51.317  7
728694  98.909  -52.708  51.277  7
728695  98.940  -52.721  51.239  7
728696  98.972  -52.734  51.200  7
728697  98.997  -52.746  51.162  7
728698  99.014  -52.756  51.123  7
728699  99.040  -52.760  51.085  7
728700  99.066  -52.766  51.049  7
728701  99.088  -52.775  51.011  7
728702  99.108  -52.786  50.974  7
728703  99.128  -52.797  50.936  7
728704  99.140  -52.821  50.897  7
728705  99.165  -52.828  50.859  7
728706  99.191  -52.835  50.820  7
728707  99.212  -52.847  50.782  7
728708  99.234  -52.857  50.742  7
728709  99.251  -52.872  50.703  7
728710  99.267  -52.887  50.663  7
728711  99.282  -52.903  50.624  7
728712  99.297  -52.919  50.584  7
728713  99.312  -52.934  50.544  7
728714  99.327  -52.950  50.504  7
728715  99.343  -52.965  50.464  7
728716  99.358  -52.981  50.423  7
728717  99.374  -52.995  50.383  7
728718  99.392  -53.008  50.343  7
728719  99.409  -53.021  50.303  7
728720  99.427  -53.034  50.261  7
728721  99.444  -53.047  50.220  7
728722  99.462  -53.060  50.179  7
728723  99.479  -53.073  50.138  7
728724  99.497  -53.086  50.098  7
728725  99.514  -53.098  50.057  7
728726  99.532  -53.111  50.016  7
728727  99.550  -53.124  49.976  7
729216  95.479  -50.281  55.623  10
729217  95.512  -50.281  55.614  10
729218  95.544  -50.282  55.603  10
729219  95.577  -50.283  55.589  10
729220  95.610  -50.284  55.574  10
729221  95.643  -50.284  55.559  10
729222  95.676  -50.285  55.542  10
729223  95.704  -50.304  55.526  10
729224  95.732  -50.324  55.507  10
729225  95.758  -50.339  55.485  10
729226  95.784  -50.355  55.463  10
729227  95.811  -50.370  55.440  10
729228  95.837  -50.386  55.417  10
729367  98.301  -52.477  52.286  7
729368  98.322  -52.482  52.255  7
729369  98.343  -52.487  52.225  7
729370  98.363  -52.493  52.194  7
729371  98.384  -52.498  52.164  7
729372  98.405  -52.503  52.134  7
729373  98.425  -52.509  52.103  7
729374  98.445  -52.514  52.069  7
729375  98.466  -52.519  52.036  7
729376  98.487  -52.525  52.002  7
729377  98.514  -52.540  51.969  7
729378  98.543  -52.556  51.934  7
729379  98.572  -52.574  51.899  7
729380  98.600  -52.590  51.862  7
729381  98.635  -52.607  51.825  7
729382  98.671  -52.624  51.788  7
729383  98.708  -52.641  51.751  7
729384  98.730  -52.647  51.714  7
729385  98.740  -52.645  51.675  7
729386  98.750  -52.644  51.637  7
729387  98.761  -52.643  51.599  7
729388  98.771  -52.641  51.560  7
729389  98.781  -52.640  51.522  7
729390  98.792  -52.638  51.483  7
729391  98.802  -52.637  51.442  7
729392  98.824  -52.644  51.401  7
729393  98.855  -52.657  51.361  7
729394  98.886  -52.670  51.321  7
729395  98.918  -52.683  51.282  7
729396  98.949  -52.696  51.243  7
729397  98.980  -52.709  51.204  7
729398  99.007  -52.721  51.166  7
729399  99.031  -52.728  51.128  7
729400  99.052  -52.738  51.090  7
729401  99.072  -52.749  51.052  7
729402  99.091  -52.760  51.016  7
729403  99.112  -52.772  50.978  7
729404  99.131  -52.783  50.941  7
729405  99.150  -52.795  50.903  7
729406  99.174  -52.804  50.864  7
729407  99.201  -52.810  50.826  7
729408  99.223  -52.821  50.787  7
729409  99.244  -52.832  50.747  7
729410  99.265  -52.844  50.709  7
729411  99.280  -52.860  50.669  7
729412  99.295  -52.876  50.629  7
729413  99.310  -52.891  50.589  7
729414  99.326  -52.907  50.549  7
729415  99.341  -52.922  50.509  7
729416  99.356  -52.938  50.469  7
729417  99.371  -52.954  50.428  7
729418  99.386  -52.969  50.389  7
729419  99.402  -52.984  50.348  7
729420  99.420  -52.997  50.307  7
729421  99.437  -53.010  50.266  7
729422  99.455  -53.023  50.226  7
729423  99.472  -53.035  50.185  7
729424  99.490  -53.048  50.143  7
729425  99.507  -53.061  50.103  7
729426  99.525  -53.074  50.062  7
729427  99.543  -53.088  50.020  7
729428  99.560  -53.101  49.980  7
729429  99.577  -53.114  49.941  7
729919  95.544  -50.257  55.598  10
729920  95.577  -50.258  55.584  10
729921  95.610  -50.259  55.569  10
729922  95.642  -50.259  55.553  10
729923  95.675  -50.260  55.536  10
729924  95.703  -50.281  55.519  10
729925  95.731  -50.300  55.501  10
729926  95.758  -50.316  55.479  10
729927  95.784  -50.332  55.457  10
729928  95.810  -50.347  55.434  10
730071  98.378  -52.473  52.200  7
730072  98.398  -52.478  52.169  7
730073  98.419  -52.484  52.139  7
730074  98.440  -52.489  52.107  7
730075  98.460  -52.494  52.073  7
730076  98.481  -52.499  52.040  7
730077  98.502  -52.505  52.006  7
730078  98.526  -52.515  51.973  7
730079  98.555  -52.532  51.939  7
730080  98.583  -52.549  51.904  7
730081  98.612  -52.566  51.867  7
730082  98.641  -52.583  51.830  7
730083  98.677  -52.600  51.793  7
730084  98.714  -52.616  51.757  7
730085  98.738  -52.625  51.720  7
730086  98.748  -52.623  51.681  7
730087  98.759  -52.622  51.643  7
730088  98.769  -52.620  51.604  7
730089  98.779  -52.619  51.566  7
730090  98.790  -52.617  51.528  7
730091  98.800  -52.615  51.489  7
730092  98.813  -52.616  51.448  7
730093  98.841  -52.627  51.408  7
730094  98.871  -52.639  51.367  7
730095  98.902  -52.652  51.326  7
730096  98.933  -52.665  51.287  7
730097  98.963  -52.677  51.248  7
730098  98.994  -52.690  51.209  7
730099  99.018  -52.698  51.171  7
730100  99.040  -52.706  51.133  7
730101  99.060  -52.717  51.095  7
730102  99.080  -52.728  51.056  7
730103  99.100  -52.739  51.020  7
730104  99.121  -52.750  50.982  7
730105  99.141  -52.760  50.945  7
730106  99.161  -52.772  50.907  7
730107  99.184  -52.780  50.869  7
730108  99.211  -52.786  50.831  7
730109  99.233  -52.796  50.792  7
730110  99.255  -52.807  50.753  7
730111  99.276  -52.818  50.714  7
730112  99.293  -52.832  50.674  7
730113  99.308  -52.847  50.634  7
730114  99.324  -52.863  50.595  7
730115  99.339  -52.879  50.555  7
730116  99.354  -52.894  50.514  7
730117  99.369  -52.910  50.475  7
730118  99.384  -52.926  50.434  7
730119  99.400  -52.941  50.394  7
730120  99.415  -52.957  50.353  7
730121  99.430  -52.973  50.312  7
730122  99.448  -52.985  50.271  7
730123  99.465  -52.998  50.230  7
730124  99.483  -53.011  50.189  7
730125  99.500  -53.025  50.148  7
730126  99.518  -53.038  50.107  7
730127  99.536  -53.051  50.066  7
730128  99.553  -53.064  50.025  7
730129  99.570  -53.076  49.985  7
730130  99.588  -53.089  49.945  7
730622  95.609  -50.234  55.564  10
730623  95.642  -50.234  55.547  10
730624  95.675  -50.237  55.530  10
730625  95.702  -50.256  55.512  10
730626  95.731  -50.277  55.495  10
730627  95.757  -50.293  55.473  10
730773  98.414  -52.459  52.174  7
730774  98.434  -52.464  52.144  7
730775  98.455  -52.469  52.111  7
730776  98.475  -52.474  52.078  7
730777  98.496  -52.480  52.046  7
730778  98.516  -52.485  52.011  7
730779  98.537  -52.490  51.977  7
730780  98.566  -52.508  51.944  7
730781  98.595  -52.525  51.909  7
730782  98.624  -52.541  51.872  7
730783  98.652  -52.559  51.836  7
730784  98.683  -52.575  51.800  7
730785  98.720  -52.592  51.763  7
730786  98.746  -52.602  51.726  7
730787  98.757  -52.600  51.688  7
730788  98.767  -52.599  51.650  7
730789  98.777  -52.597  51.610  7
730790  98.787  -52.596  51.572  7
730791  98.799  -52.595  51.533  7
730792  98.814  -52.597  51.495  7
730793  98.833  -52.603  51.454  7
730794  98.864  -52.615  51.415  7
730795  98.895  -52.628  51.374  7
730796  98.925  -52.640  51.333  7
730797  98.956  -52.653  51.293  7
730798  98.982  -52.661  51.253  7
730799  99.006  -52.669  51.214  7
730800  99.028  -52.677  51.175  7
730801  99.050  -52.684  51.137  7
730802  99.072  -52.693  51.099  7
730803  99.094  -52.701  51.062  7
730804  99.114  -52.712  51.024  7
730805  99.134  -52.722  50.986  7
730806  99.154  -52.733  50.948  7
730807  99.174  -52.744  50.911  7
730808  99.195  -52.755  50.874  7
730809  99.220  -52.762  50.835  7
730810  99.244  -52.770  50.797  7
730811  99.265  -52.782  50.758  7
730812  99.287  -52.792  50.719  7
730813  99.307  -52.804  50.679  7
730814  99.322  -52.820  50.639  7
730815  99.337  -52.835  50.600  7
730816  99.353  -52.851  50.560  7
730817  99.368  -52.867  50.520  7
730818  99.383  -52.882  50.480  7
730819  99.398  -52.898  50.440  7
730820  99.413  -52.913  50.399  7
730821  99.429  -52.929  50.358  7
730822  99.444  -52.945  50.317  7
730823  99.459  -52.960  50.276  7
730824  99.476  -52.975  50.235  7
730825  99.493  -52.988  50.194  7
730826  99.511  -53.001  50.153  7
730827  99.528  -53.013  50.111  7
730828  99.546  -53.026  50.070  7
730829  99.563  -53.039  50.030  7
730830  99.581  -53.052  49.990  7
730831  99.598  -53.065  49.950  7
731474  98.428  -52.439  52.180  7
731475  98.449  -52.444  52.149  7
731476  98.469  -52.449  52.117  7
731477  98.490  -52.455  52.084  7
731478  98.511  -52.459  52.050  7
731479  98.531  -52.465  52.017  7
731480  98.552  -52.470  51.983  7
731481  98.578  -52.483  51.950  7
731482  98.606  -52.500  51.914  7
731483  98.635  -52.517  51.878  7
731484  98.664  -52.534  51.842  7
731485  98.693  -52.551  51.806  7
731486  98.726  -52.568  51.771  7
731487  98.755  -52.579  51.734  7
731488  98.765  -52.578  51.696  7
731489  98.775  -52.576  51.656  7
731490  98.785  -52.575  51.617  7
731491  98.800  -52.577  51.578  7
731492  98.815  -52.579  51.539  7
731493  98.830  -52.581  51.500  7
731494  98.856  -52.590  51.461  7
731495  98.886  -52.603  51.421  7
731496  98.917  -52.615  51.379  7
731497  98.944  -52.625  51.339  7
731498  98.969  -52.631  51.298  7
731499  98.993  -52.639  51.258  7
731500  99.015  -52.647  51.219  7
731501  99.038  -52.656  51.180  7
731502  99.059  -52.664  51.141  7
731503  99.081  -52.672  51.103  7
731504  99.103  -52.680  51.066  7
731505  99.125  -52.688  51.028  7
731506  99.147  -52.697  50.990  7
731507  99.168  -52.706  50.952  7
731508  99.188  -52.716  50.915  7
731509  99.208  -52.728  50.878  7
731510  99.229  -52.738  50.840  7
731511  99.255  -52.745  50.802  7
731512  99.276  -52.756  50.762  7
731513  99.297  -52.767  50.723  7
731514  99.319  -52.778  50.684  7
731515  99.336  -52.792  50.644  7
731516  99.351  -52.808  50.604  7
731517  99.366  -52.824  50.565  7
731518  99.381  -52.839  50.525  7
731519  99.397  -52.855  50.484  7
731520  99.412  -52.870  50.444  7
731521  99.427  -52.886  50.403  7
731522  99.442  -52.902  50.362  7
731523  99.457  -52.917  50.321  7
731524  99.473  -52.933  50.281  7
731525  99.488  -52.948  50.240  7
731526  99.504  -52.963  50.198  7
731527  99.521  -52.976  50.157  7
731528  99.539  -52.989  50.115  7
731529  99.556  -53.002  50.075  7
731530  99.574  -53.015  50.034  7
731531  99.591  -53.028  49.994  7
731532  99.609  -53.041  49.954  7
732175  98.443  -52.419  52.185  7
732176  98.464  -52.424  52.154  7
732177  98.485  -52.429  52.123  7
732178  98.505  -52.434  52.090  7
732179  98.525  -52.440  52.056  7
732180  98.546  -52.445  52.024  7
732181  98.567  -52.450  51.990  7
732182  98.589  -52.459  51.956  7
732183  98.618  -52.475  51.920  7
732184  98.647  -52.493  51.884  7
732185  98.675  -52.509  51.849  7
732186  98.704  -52.527  51.813  7
732187  98.733  -52.543  51.778  7
732188  98.763  -52.556  51.744  7
732189  98.773  -52.555  51.704  7
732190  98.786  -52.556  51.664  7
732191  98.801  -52.558  51.624  7
732192  98.816  -52.560  51.585  7
732193  98.831  -52.562  51.546  7
732194  98.848  -52.566  51.507  7
732195  98.878  -52.578  51.467  7
732196  98.907  -52.589  51.426  7
732197  98.931  -52.596  51.385  7
732198  98.955  -52.603  51.345  7
732199  98.980  -52.609  51.305  7
732200  99.003  -52.618  51.264  7
732201  99.025  -52.626  51.224  7
732202  99.047  -52.634  51.185  7
732203  99.069  -52.643  51.146  7
732204  99.090  -52.651  51.108  7
732205  99.113  -52.659  51.071  7
732206  99.134  -52.667  51.032  7
732207  99.156  -52.675  50.994  7
732208  99.179  -52.683  50.957  7
732209  99.200  -52.691  50.919  7
732210  99.222  -52.700  50.882  7
732211  99.242  -52.711  50.843  7
732212  99.265  -52.719  50.805  7
732213  99.286  -52.731  50.766  7
732214  99.307  -52.741  50.727  7
732215  99.329  -52.753  50.688  7
732216  99.349  -52.765  50.648  7
732217  99.364  -52.781  50.608  7
732218  99.379  -52.796  50.568  7
732219  99.395  -52.812  50.529  7
732220  99.410  -52.827  50.488  7
732221  99.425  -52.843  50.448  7
732222  99.440  -52.859  50.408  7
732223  99.455  -52.874  50.367  7
732224  99.471  -52.890  50.326  7
732225  99.486  -52.905  50.285  7
732226  99.501  -52.921  50.244  7
732227  99.516  -52.937  50.203  7
732228  99.532  -52.952  50.161  7
732229  99.549  -52.965  50.120  7
732230  99.567  -52.978  50.079  7
732231  99.584  -52.991  50.038  7
732232  99.602  -53.004  49.998  7
732233  99.620  -53.017  49.958  7
732876  98.458  -52.399  52.191  7
732877  98.479  -52.404  52.160  7
732878  98.499  -52.409  52.128  7
732879  98.520  -52.415  52.096  7
732880  98.541  -52.420  52.063  7
732881  98.561  -52.425  52.030  7
732882  98.582  -52.431  51.996  7
732883  98.602  -52.436  51.963  7
732884  98.630  -52.451  51.927  7
732885  98.658  -52.468  51.891  7
732886  98.687  -52.485  51.856  7
732887  98.716  -52.502  51.821  7
732888  98.744  -52.519  51.787  7
732889  98.772  -52.534  51.753  7
732890  98.787  -52.537  51.712  7
732891  98.802  -52.540  51.672  7
732892  98.817  -52.542  51.631  7
732893  98.832  -52.544  51.591  7
732894  98.847  -52.546  51.553  7
732895  98.869  -52.553  51.515  7
732896  98.894  -52.559  51.474  7
732897  98.918  -52.566  51.431  7
732898  98.942  -52.573  51.391  7
732899  98.967  -52.580  51.351  7
732900  98.990  -52.588  51.311  7
732901  99.012  -52.597  51.270  7
732902  99.034  -52.605  51.230  7
732903  99.056  -52.613  51.191  7
732904  99.078  -52.622  51.152  7
732905  99.100  -52.630  51.114  7
732906  99.122  -52.637  51.076  7
732907  99.144  -52.646  51.037  7
732908  99.166  -52.654  50.999  7
732909  99.188  -52.662  50.961  7
732910  99.210  -52.670  50.924  7
732911  99.231  -52.678  50.886  7
732912  99.254  -52.687  50.847  7
732913  99.275  -52.695  50.809  7
732914  99.297  -52.705  50.771  7
732915  99.318  -52.716  50.732  7
732916  99.340  -52.728  50.692  7
732917  99.361  -52.738  50.652  7
732918  99.378  -52.753  50.613  7
732919  99.393  -52.769  50.572  7
732920  99.408  -52.784  50.532  7
732921  99.423  -52.800  50.492  7
732922  99.438  -52.816  50.453  7
732923  99.454  -52.831  50.412  7
732924  99.469  -52.847  50.371  7
732925  99.484  -52.862  50.330  7
732926  99.499  -52.878  50.289  7
732927  99.515  -52.894  50.248  7
732928  99.530  -52.909  50.207  7
732929  99.545  -52.925  50.165  7
732930  99.560  -52.941  50.124  7
732931  99.577  -52.954  50.083  7
732932  99.595  -52.966  50.042  7
732933  99.613  -52.979  50.002  7
732934  99.630  -52.992  49.962  7
733577  98.473  -52.379  52.197  7
733578  98.494  -52.384  52.166  7
733579  98.514  -52.390  52.134  7
733580  98.535  -52.395  52.102  7
733581  98.556  -52.400  52.069  7
733582  98.576  -52.405  52.036  7
733583  98.596  -52.411  52.003  7
733584  98.617  -52.416  51.969  7
733585  98.641  -52.427  51.935  7
733586  98.670  -52.443  51.899  7
733587  98.699  -52.461  51.864  7
733588  98.727  -52.478  51.829  7
733589  98.756  -52.494  51.795  7
733590  98.780  -52.508  51.761  7
733591  98.799  -52.515  51.720  7
733592  98.814  -52.517  51.679  7
733593  98.830  -52.520  51.638  7
733594  98.845  -52.522  51.599  7
733595  98.860  -52.525  51.560  7
733596  98.880  -52.530  51.521  7
733597  98.905  -52.537  51.480  7
733598  98.929  -52.543  51.439  7
733599  98.953  -52.550  51.398  7
733600  98.977  -52.559  51.357  7
733601  99.000  -52.568  51.316  7
733602  99.022  -52.576  51.276  7
733603  99.044  -52.584  51.236  7
733604  99.066  -52.592  51.197  7
733605  99.087  -52.600  51.158  7
733606  99.110  -52.609  51.119  7
733607  99.131  -52.617  51.081  7
733608  99.153  -52.625  51.042  7
733609  99.175  -52.633  51.004  7
733610  99.197  -52.641  50.966  7
733611  99.219  -52.650  50.927  7
733612  99.241  -52.657  50.890  7
733613  99.263  -52.666  50.852  7
733614  99.285  -52.673  50.812  7
733615  99.307  -52.681  50.775  7
733616  99.329  -52.691  50.735  7
733617  99.350  -52.702  50.696  7
733618  99.371  -52.713  50.657  7
733619  99.391  -52.725  50.617  7
733620  99.407  -52.741  50.577  7
733621  99.422  -52.756  50.537  7
733622  99.437  -52.772  50.497  7
733623  99.452  -52.788  50.457  7
733624  99.467  -52.803  50.417  7
733625  99.483  -52.819  50.375  7
733626  99.498  -52.835  50.334  7
733627  99.513  -52.850  50.293  7
733628  99.528  -52.866  50.252  7
733629  99.544  -52.882  50.211  7
733630  99.559  -52.897  50.169  7
733631  99.574  -52.913  50.128  7
733632  99.589  -52.929  50.087  7
733633  99.606  -52.943  50.046  7
733634  99.623  -52.956  50.005  7
733635  99.640  -52.969  49.965  7
734278  98.488  -52.361  52.204  7
734279  98.509  -52.365  52.172  7
734280  98.529  -52.370  52.141  7
734281  98.550  -52.375  52.108  7
734282  98.570  -52.380  52.075  7
734283  98.591  -52.386  52.042  7
734284  98.612  -52.391  52.009  7
734285  98.632  -52.396  51.976  7
734286  98.653  -52.402  51.942  7
734287  98.681  -52.419  51.906  7
734288  98.710  -52.436  51.871  7
734289  98.739  -52.453  51.837  7
734290  98.764  -52.467  51.803  7
734291  98.788  -52.481  51.768  7
734292  98.808  -52.490  51.727  7
734293  98.826  -52.495  51.686  7
734294  98.841  -52.498  51.645  7
734295  98.856  -52.500  51.606  7
734296  98.872  -52.503  51.567  7
734297  98.891  -52.508  51.527  7
734298  98.916  -52.515  51.486  7
734299  98.940  -52.521  51.445  7
734300  98.964  -52.529  51.405  7
734301  98.987  -52.538  51.364  7
734302  99.009  -52.546  51.323  7
734303  99.031  -52.555  51.283  7
734304  99.053  -52.563  51.242  7
734305  99.075  -52.572  51.202  7
734306  99.097  -52.579  51.164  7
734307  99.119  -52.587  51.124  7
734308  99.141  -52.596  51.086  7
734309  99.162  -52.604  51.047  7
734310  99.185  -52.612  51.008  7
734311  99.207  -52.620  50.970  7
734312  99.228  -52.628  50.932  7
734313  99.251  -52.636  50.894  7
734314  99.273  -52.644  50.856  7
734315  99.295  -52.651  50.817  7
734316  99.317  -52.659  50.778  7
734317  99.339  -52.666  50.739  7
734318  99.360  -52.677  50.700  7
734319  99.382  -52.687  50.661  7
734320  99.403  -52.699  50.621  7
734321  99.420  -52.713  50.581  7
734322  99.435  -52.729  50.542  7
734323  99.450  -52.744  50.501  7
734324  99.466  -52.760  50.461  7
734325  99.481  -52.775  50.421  7
734326  99.496  -52.791  50.380  7
734327  99.511  -52.807  50.338  7
734328  99.526  -52.822  50.297  7
734329  99.542  -52.838  50.255  7
734330  99.557  -52.854  50.214  7
734331  99.572  -52.869  50.172  7
734332  99.587  -52.885  50.131  7
734333  99.603  -52.901  50.091  7
734334  99.618  -52.916  50.050  7
734335  99.633  -52.932  50.010  7
734336  99.651  -52.944  49.970  7
734979  98.501  -52.348  52.210  7
734980  98.522  -52.351  52.179  7
734981  98.543  -52.354  52.148  7
734982  98.564  -52.357  52.115  7
734983  98.585  -52.361  52.081  7
734984  98.606  -52.366  52.048  7
734985  98.626  -52.371  52.016  7
734986  98.647  -52.377  51.983  7
734987  98.667  -52.382  51.949  7
734988  98.693  -52.394  51.913  7
734989  98.722  -52.412  51.878  7
734990  98.748  -52.427  51.845  7
734991  98.772  -52.440  51.811  7
734992  98.795  -52.453  51.774  7
734993  98.818  -52.466  51.733  7
734994  98.836  -52.470  51.692  7
734995  98.852  -52.474  51.652  7
734996  98.868  -52.478  51.612  7
734997  98.883  -52.481  51.573  7
734998  98.903  -52.485  51.533  7
734999  98.927  -52.492  51.492  7
735000  98.951  -52.499  51.452  7
735001  98.974  -52.509  51.411  7
735002  98.996  -52.518  51.371  7
735003  99.018  -52.526  51.331  7
735004  99.041  -52.534  51.290  7
735005  99.062  -52.542  51.249  7
735006  99.084  -52.550  51.209  7
735007  99.106  -52.558  51.169  7
735008  99.128  -52.566  51.130  7
735009  99.150  -52.575  51.091  7
735010  99.172  -52.583  51.052  7
735011  99.194  -52.590  51.013  7
735012  99.216  -52.598  50.974  7
735013  99.238  -52.606  50.937  7
735014  99.260  -52.614  50.898  7
735015  99.282  -52.622  50.860  7
735016  99.304  -52.629  50.821  7
735017  99.327  -52.637  50.782  7
735018  99.349  -52.644  50.743  7
735019  99.371  -52.652  50.704  7
735020  99.393  -52.662  50.664  7
735021  99.414  -52.673  50.625  7
735022  99.433  -52.686  50.585  7
735023  99.448  -52.701  50.546  7
735024  99.464  -52.717  50.505  7
735025  99.479  -52.732  50.465  7
735026  99.494  -52.748  50.425  7
735027  99.509  -52.764  50.384  7
735028  99.524  -52.779  50.342  7
735029  99.540  -52.795  50.300  7
735030  99.555  -52.810  50.259  7
735031  99.570  -52.826  50.218  7
735032  99.585  -52.842  50.175  7
735033  99.600  -52.857  50.134  7
735034  99.616  -52.873  50.095  7
735035  99.631  -52.889  50.054  7
735036  99.646  -52.904  50.014  7
735037  99.661  -52.920  49.974  7
735680  98.514  -52.336  52.218  7
735681  98.535  -52.339  52.186  7
735682  98.556  -52.342  52.155  7
735683  98.577  -52.344  52.122  7
735684  98.598  -52.347  52.088  7
735685  98.620  -52.350  52.055  7
735686  98.641  -52.353  52.023  7
735687  98.662  -52.357  51.990  7
735688  98.683  -52.362  51.956  7
735689  98.705  -52.370  51.920  7
735690  98.732  -52.386  51.886  7
735691  98.756  -52.399  51.851  7
735692  98.779  -52.412  51.816  7
735693  98.803  -52.426  51.779  7
735694  98.827  -52.439  51.738  7
735695  98.845  -52.446  51.698  7
735696  98.862  -52.450  51.658  7
735697  98.879  -52.455  51.619  7
735698  98.896  -52.459  51.580  7
735699  98.914  -52.462  51.540  7
735700  98.938  -52.470  51.500  7
735701  98.960  -52.479  51.459  7
735702  98.984  -52.487  51.417  7
735703  99.006  -52.496  51.378  7
735704  99.028  -52.505  51.338  7
735705  99.050  -52.512  51.297  7
735706  99.072  -52.521  51.256  7
735707  99.094  -52.529  51.215  7
735708  99.116  -52.537  51.175  7
735709  99.138  -52.545  51.135  7
735710  99.159  -52.553  51.096  7
735711  99.182  -52.561  51.057  7
735712  99.204  -52.568  51.018  7
735713  99.226  -52.576  50.979  7
735714  99.248  -52.584  50.941  7
735715  99.270  -52.591  50.903  7
735716  99.292  -52.600  50.864  7
735717  99.314  -52.607  50.824  7
735718  99.337  -52.615  50.787  7
735719  99.359  -52.622  50.747  7
735720  99.380  -52.630  50.708  7
735721  99.403  -52.637  50.668  7
735722  99.424  -52.648  50.629  7
735723  99.445  -52.659  50.590  7
735724  99.462  -52.674  50.551  7
735725  99.477  -52.689  50.510  7
735726  99.492  -52.705  50.470  7
735727  99.508  -52.721  50.429  7
735728  99.523  -52.736  50.387  7
735729  99.538  -52.752  50.346  7
735730  99.553  -52.767  50.304  7
735731  99.569  -52.783  50.262  7
735732  99.584  -52.799  50.221  7
735733  99.599  -52.814  50.179  7
735734  99.614  -52.830  50.138  7
735735  99.629  -52.846  50.098  7
735736  99.645  -52.861  50.058  7
735737  99.660  -52.877  50.018  7
735738  99.675  -52.892  49.978  7
736381  98.527  -52.323  52.226  7
736382  98.548  -52.326  52.194  7
736383  98.569  -52.329  52.162  7
736384  98.590  -52.332  52.129  7
736385  98.612  -52.335  52.095  7
736386  98.633  -52.338  52.061  7
736387  98.654  -52.340  52.029  7
736388  98.675  -52.343  51.996  7
736389  98.696  -52.346  51.962  7
736390  98.717  -52.349  51.927  7
736391  98.740  -52.358  51.892  7
736392  98.763  -52.372  51.857  7
736393  98.787  -52.385  51.821  7
736394  98.810  -52.399  51.784  7
736395  98.834  -52.412  51.744  7
736396  98.855  -52.421  51.704  7
736397  98.872  -52.426  51.665  7
736398  98.889  -52.431  51.626  7
736399  98.906  -52.435  51.587  7
736400  98.925  -52.440  51.548  7
736401  98.948  -52.449  51.507  7
736402  98.971  -52.458  51.466  7
736403  98.993  -52.467  51.425  7
736404  99.015  -52.475  51.384  7
736405  99.038  -52.484  51.344  7
736406  99.059  -52.492  51.304  7
736407  99.081  -52.499  51.262  7
736408  99.103  -52.508  51.222  7
736409  99.125  -52.516  51.181  7
736410  99.147  -52.524  51.141  7
736411  99.169  -52.531  51.102  7
736412  99.191  -52.539  51.062  7
736413  99.213  -52.546  51.022  7
736414  99.235  -52.554  50.983  7
736415  99.258  -52.562  50.945  7
736416  99.280  -52.569  50.907  7
736417  99.302  -52.577  50.868  7
736418  99.324  -52.585  50.828  7
736419  99.346  -52.593  50.791  7
736420  99.368  -52.600  50.752  7
736421  99.391  -52.608  50.712  7
736422  99.413  -52.615  50.672  7
736423  99.435  -52.623  50.633  7
736424  99.456  -52.634  50.593  7
736425  99.476  -52.646  50.554  7
736426  99.491  -52.662  50.514  7
736427  99.506  -52.678  50.474  7
736428  99.521  -52.693  50.433  7
736429  99.537  -52.709  50.392  7
736430  99.552  -52.724  50.350  7
736431  99.567  -52.740  50.308  7
736432  99.582  -52.756  50.266  7
736433  99.597  -52.771  50.225  7
736434  99.613  -52.787  50.183  7
736435  99.628  -52.803  50.142  7
736436  99.643  -52.818  50.101  7
736437  99.658  -52.834  50.062  7
736438  99.674  -52.849  50.022  7
736439  99.689  -52.865  49.982  7
737082  98.539  -52.311  52.233  7
737083  98.561  -52.313  52.201  7
737084  98.582  -52.316  52.169  7
737085  98.603  -52.319  52.136  7
737086  98.625  -52.322  52.101  7
737087  98.646  -52.325  52.068  7
737088  98.667  -52.328  52.035  7
737089  98.688  -52.331  52.002  7
737090  98.709  -52.333  51.968  7
737091  98.730  -52.336  51.933  7
737092  98.751  -52.340  51.899  7
737093  98.770  -52.346  51.863  7
737094  98.795  -52.358  51.826  7
737095  98.818  -52.371  51.789  7
737096  98.842  -52.384  51.750  7
737097  98.865  -52.397  51.712  7
737098  98.882  -52.402  51.673  7
737099  98.899  -52.406  51.633  7
737100  98.916  -52.412  51.594  7
737101  98.935  -52.420  51.555  7
737102  98.957  -52.428  51.514  7
737103  98.981  -52.437  51.473  7
737104  99.003  -52.446  51.432  7
737105  99.025  -52.454  51.391  7
737106  99.047  -52.462  51.351  7
737107  99.069  -52.471  51.310  7
737108  99.090  -52.478  51.269  7
737109  99.113  -52.487  51.228  7
737110  99.135  -52.494  51.187  7
737111  99.157  -52.502  51.146  7
737112  99.179  -52.509  51.108  7
737113  99.201  -52.517  51.067  7
737114  99.223  -52.525  51.027  7
737115  99.245  -52.532  50.987  7
737116  99.268  -52.540  50.948  7
737117  99.290  -52.547  50.911  7
737118  99.311  -52.555  50.872  7
737119  99.334  -52.562  50.832  7
737120  99.356  -52.571  50.794  7
737121  99.378  -52.578  50.756  7
737122  99.400  -52.586  50.716  7
737123  99.422  -52.593  50.676  7
737124  99.444  -52.601  50.637  7
737125  99.467  -52.609  50.597  7
737126  99.488  -52.619  50.558  7
737127  99.504  -52.634  50.518  7
737128  99.519  -52.650  50.477  7
737129  99.535  -52.666  50.436  7
737130  99.550  -52.681  50.395  7
737131  99.565  -52.697  50.354  7
737132  99.580  -52.713  50.312  7
737133  99.595  -52.728  50.270  7
737134  99.611  -52.744  50.228  7
737135  99.626  -52.760  50.187  7
737136  99.641  -52.775  50.145  7
737137  99.656  -52.791  50.104  7
737138  99.671  -52.806  50.065  7
737139  99.687  -52.822  50.025  7
737140  99.702  -52.838  49.985  7
737783  98.553  -52.298  52.242  7
737784  98.574  -52.301  52.210  7
737785  98.595  -52.304  52.177  7
737786  98.616  -52.307  52.144  7
737787  98.638  -52.309  52.109  7
737788  98.659  -52.312  52.075  7
737789  98.680  -52.315  52.041  7
737790  98.701  -52.318  52.008  7
737791  98.722  -52.321  51.974  7
737792  98.743  -52.324  51.939  7
737793  98.765  -52.327  51.903  7
737794  98.785  -52.331  51.867  7
737795  98.803  -52.338  51.831  7
737796  98.821  -52.344  51.794  7
737797  98.847  -52.356  51.756  7
737798  98.873  -52.371  51.718  7
737799  98.892  -52.377  51.680  7
737800  98.910  -52.384  51.640  7
737801  98.927  -52.392  51.601  7
737802  98.945  -52.399  51.563  7
737803  98.968  -52.408  51.521  7
737804  98.990  -52.417  51.481  7
737805  99.012  -52.425  51.439  7
737806  99.034  -52.433  51.398  7
737807  99.056  -52.441  51.358  7
737808  99.078  -52.449  51.316  7
737809  99.100  -52.457  51.274  7
737810  99.122  -52.465  51.232  7
737811  99.144  -52.472  51.192  7
737812  99.166  -52.480  51.152  7
737813  99.189  -52.487  51.113  7
737814  99.211  -52.495  51.072  7
737815  99.233  -52.503  51.031  7
737816  99.255  -52.510  50.992  7
737817  99.277  -52.518  50.952  7
737818  99.299  -52.525  50.914  7
737819  99.322  -52.533  50.876  7
737820  99.344  -52.540  50.836  7
737821  99.366  -52.548  50.797  7
737822  99.388  -52.556  50.760  7
737823  99.410  -52.564  50.720  7
737824  99.432  -52.572  50.680  7
737825  99.454  -52.579  50.641  7
737826  99.476  -52.587  50.601  7
737827  99.498  -52.594  50.562  7
737828  99.517  -52.606  50.521  7
737829  99.533  -52.622  50.482  7
737830  99.548  -52.637  50.440  7
737831  99.563  -52.653  50.399  7
737832  99.578  -52.669  50.357  7
737833  99.594  -52.684  50.315  7
737834  99.609  -52.700  50.273  7
737835  99.624  -52.716  50.231  7
737836  99.639  -52.731  50.190  7
737837  99.654  -52.747  50.148  7
737838  99.670  -52.763  50.108  7
737839  99.685  -52.778  50.067  7
737840  99.700  -52.794  50.028  7
737841  99.715  -52.810  49.987  7
738484  98.566  -52.285  52.251  7
738485  98.587  -52.288  52.219  7
738486  98.608  -52.291  52.185  7
738487  98.629  -52.294  52.151  7
738488  98.650  -52.297  52.117  7
738489  98.671  -52.300  52.082  7
738490  98.693  -52.303  52.048  7
738491  98.714  -52.305  52.015  7
738492  98.735  -52.308  51.980  7
738493  98.757  -52.311  51.944  7
738494  98.778  -52.315  51.909  7
738495  98.799  -52.318  51.873  7
738496  98.818  -52.323  51.837  7
738497  98.837  -52.330  51.800  7
738498  98.855  -52.336  51.762  7
738499  98.873  -52.343  51.724  7
738500  98.899  -52.353  51.686  7
738501  98.921  -52.364  51.647  7
738502  98.938  -52.371  51.608  7
738503  98.956  -52.378  51.569  7
738504  98.977  -52.387  51.529  7
738505  99.000  -52.396  51.488  7
738506  99.022  -52.404  51.446  7
738507  99.044  -52.412  51.405  7
738508  99.066  -52.420  51.364  7
738509  99.088  -52.427  51.323  7
738510  99.110  -52.435  51.280  7
738511  99.132  -52.443  51.239  7
738512  99.154  -52.450  51.198  7
738513  99.177  -52.458  51.157  7
738514  99.199  -52.465  51.118  7
738515  99.221  -52.473  51.076  7
738516  99.242  -52.481  51.036  7
738517  99.265  -52.488  50.996  7
738518  99.287  -52.496  50.957  7
738519  99.309  -52.503  50.918  7
738520  99.331  -52.511  50.879  7
738521  99.353  -52.518  50.840  7
738522  99.375  -52.526  50.801  7
738523  99.398  -52.534  50.762  7
738524  99.420  -52.541  50.723  7
738525  99.442  -52.550  50.684  7
738526  99.464  -52.557  50.644  7
738527  99.486  -52.565  50.605  7
738528  99.508  -52.572  50.566  7
738529  99.530  -52.580  50.525  7
738530  99.546  -52.594  50.486  7
738531  99.562  -52.610  50.444  7
738532  99.577  -52.626  50.403  7
738533  99.592  -52.641  50.361  7
738534  99.607  -52.657  50.319  7
738535  99.623  -52.672  50.277  7
738536  99.638  -52.688  50.235  7
738537  99.653  -52.704  50.193  7
738538  99.668  -52.719  50.152  7
738539  99.683  -52.735  50.111  7
738540  99.699  -52.751  50.071  7
738541  99.714  -52.766  50.031  7
738542  99.729  -52.782  49.990  7
739185  98.579  -52.273  52.260  7
739186  98.600  -52.276  52.228  7
739187  98.621  -52.279  52.194  7
739188  98.642  -52.281  52.158  7
739189  98.663  -52.284  52.123  7
739190  98.685  -52.287  52.090  7
739191  98.706  -52.290  52.056  7
739192  98.727  -52.293  52.022  7
739193  98.748  -52.296  51.986  7
739194  98.770  -52.299  51.950  7
739195  98.791  -52.302  51.915  7
739196  98.812  -52.305  51.879  7
739197  98.833  -52.308  51.843  7
739198  98.851  -52.315  51.806  7
739199  98.870  -52.321  51.768  7
739200  98.888  -52.327  51.730  7
739201  98.907  -52.334  51.692  7
739202  98.925  -52.340  51.654  7
739203  98.949  -52.351  51.615  7
739204  98.967  -52.358  51.575  7
739205  98.987  -52.366  51.537  7
739206  99.009  -52.374  51.494  7
739207  99.031  -52.383  51.453  7
739208  99.053  -52.390  51.411  7
739209  99.075  -52.398  51.370  7
739210  99.097  -52.405  51.329  7
739211  99.120  -52.413  51.287  7
739212  99.142  -52.421  51.245  7
739213  99.164  -52.428  51.203  7
739214  99.186  -52.436  51.163  7
739215  99.208  -52.443  51.122  7
739216  99.230  -52.451  51.080  7
739217  99.253  -52.459  51.040  7
739218  99.275  -52.466  51.000  7
739219  99.297  -52.474  50.961  7
739220  99.319  -52.481  50.921  7
739221  99.341  -52.490  50.882  7
739222  99.363  -52.498  50.843  7
739223  99.385  -52.506  50.804  7
739224  99.408  -52.514  50.766  7
739225  99.430  -52.521  50.726  7
739226  99.452  -52.530  50.687  7
739227  99.475  -52.538  50.648  7
739228  99.497  -52.546  50.608  7
739229  99.519  -52.554  50.569  7
739230  99.542  -52.562  50.529  7
739231  99.561  -52.571  50.489  7
739232  99.575  -52.583  50.447  7
739233  99.590  -52.598  50.406  7
739234  99.606  -52.614  50.364  7
739235  99.621  -52.629  50.322  7
739236  99.636  -52.645  50.280  7
739237  99.651  -52.661  50.238  7
739238  99.666  -52.676  50.196  7
739239  99.682  -52.692  50.155  7
739240  99.697  -52.708  50.114  7
739241  99.712  -52.723  50.074  7
739242  99.727  -52.739  50.033  7
739243  99.743  -52.754  49.993  7
739886  98.592  -52.260  52.269  7
739887  98.613  -52.263  52.237  7
739888  98.634  -52.266  52.203  7
739889  98.655  -52.269  52.167  7
739890  98.676  -52.272  52.133  7
739891  98.698  -52.274  52.098  7
739892  98.719  -52.277  52.063  7
739893  98.740  -52.280  52.028  7
739894  98.761  -52.283  51.992  7
739895  98.782  -52.286  51.956  7
739896  98.804  -52.290  51.920  7
739897  98.825  -52.293  51.884  7
739898  98.846  -52.295  51.849  7
739899  98.866  -52.299  51.812  7
739900  98.885  -52.306  51.774  7
739901  98.903  -52.312  51.736  7
739902  98.922  -52.319  51.697  7
739903  98.940  -52.325  51.659  7
739904  98.959  -52.332  51.621  7
739905  98.977  -52.339  51.581  7
739906  98.997  -52.346  51.542  7
739907  99.019  -52.353  51.500  7
739908  99.041  -52.362  51.459  7
739909  99.064  -52.369  51.418  7
739910  99.086  -52.377  51.376  7
739911  99.108  -52.386  51.334  7
739912  99.130  -52.393  51.292  7
739913  99.152  -52.402  51.251  7
739914  99.175  -52.410  51.209  7
739915  99.197  -52.418  51.167  7
739916  99.219  -52.426  51.127  7
739917  99.241  -52.434  51.085  7
739918  99.264  -52.442  51.044  7
739919  99.286  -52.450  51.004  7
739920  99.308  -52.458  50.965  7
739921  99.331  -52.466  50.926  7
739922  99.353  -52.474  50.886  7
739923  99.375  -52.482  50.847  7
739924  99.398  -52.490  50.809  7
739925  99.420  -52.498  50.769  7
739926  99.442  -52.506  50.729  7
739927  99.464  -52.515  50.689  7
739928  99.486  -52.522  50.650  7
739929  99.509  -52.531  50.611  7
739930  99.531  -52.538  50.572  7
739931  99.553  -52.546  50.531  7
739932  99.575  -52.555  50.491  7
739933  99.591  -52.565  50.450  7
739934  99.605  -52.576  50.408  7
739935  99.619  -52.587  50.366  7
739936  99.634  -52.602  50.324  7
739937  99.649  -52.618  50.282  7
739938  99.664  -52.633  50.240  7
739939  99.680  -52.649  50.198  7
739940  99.695  -52.665  50.157  7
739941  99.710  -52.680  50.116  7
739942  99.725  -52.696  50.076  7
739943  99.740  -52.711  50.035  7
739944  99.756  -52.727  49.994  7
740588  98.626  -52.250  52.247  7
740589  98.647  -52.253  52.212  7
740590  98.668  -52.256  52.176  7
740591  98.690  -52.259  52.142  7
740592  98.711  -52.262  52.106  7
740593  98.732  -52.265  52.070  7
740594  98.753  -52.268  52.035  7
740595  98.774  -52.271  51.999  7
740596  98.795  -52.274  51.962  7
740597  98.816  -52.277  51.926  7
740598  98.838  -52.280  51.890  7
740599  98.859  -52.283  51.854  7
740600  98.880  -52.286  51.818  7
740601  98.900  -52.291  51.780  7
740602  98.918  -52.297  51.742  7
740603  98.937  -52.304  51.703  7
740604  98.955  -52.311  51.664  7
740605  98.974  -52.317  51.626  7
740606  98.992  -52.324  51.587  7
740607  99.011  -52.330  51.547  7
740608  99.031  -52.338  51.506  7
740609  99.053  -52.346  51.465  7
740610  99.075  -52.354  51.424  7
740611  99.097  -52.362  51.383  7
740612  99.120  -52.370  51.341  7
740613  99.142  -52.378  51.298  7
740614  99.164  -52.386  51.255  7
740615  99.187  -52.394  51.213  7
740616  99.209  -52.402  51.171  7
740617  99.231  -52.410  51.131  7
740619  99.276  -52.426  51.048  7
740620  99.298  -52.434  51.008  7
740621  99.320  -52.443  50.968  7
740622  99.342  -52.450  50.929  7
740623  99.365  -52.459  50.890  7
740624  99.387  -52.467  50.850  7
740625  99.409  -52.474  50.811  7
740626  99.431  -52.483  50.772  7
740627  99.453  -52.490  50.732  7
740628  99.476  -52.499  50.692  7
740629  99.498  -52.507  50.653  7
740630  99.520  -52.515  50.613  7
740631  99.543  -52.523  50.573  7
740632  99.565  -52.531  50.533  7
740633  99.587  -52.539  50.492  7
740634  99.607  -52.548  50.451  7
740635  99.621  -52.559  50.410  7
740636  99.635  -52.570  50.368  7
740637  99.649  -52.581  50.325  7
740638  99.663  -52.592  50.283  7
740639  99.678  -52.606  50.241  7
740640  99.693  -52.622  50.198  7
740641  99.708  -52.637  50.158  7
740642  99.724  -52.653  50.118  7
740643  99.739  -52.668  50.078  7
740644  99.754  -52.684  50.037  7
740645  99.769  -52.700  49.997  7
741291  98.681  -52.244  52.187  7
741292  98.703  -52.246  52.151  7
741293  98.724  -52.249  52.114  7
741294  98.745  -52.252  52.078  7
741295  98.766  -52.255  52.042  7
741296  98.787  -52.258  52.006  7
741297  98.808  -52.261  51.970  7
741298  98.830  -52.264  51.933  7
741299  98.851  -52.267  51.896  7
741300  98.872  -52.270  51.860  7
741301  98.893  -52.273  51.824  7
741302  98.914  -52.276  51.785  7
741303  98.933  -52.283  51.747  7
741304  98.951  -52.289  51.709  7
741305  98.970  -52.296  51.670  7
741306  98.989  -52.302  51.632  7
741307  99.007  -52.308  51.593  7
741308  99.025  -52.315  51.552  7
741309  99.044  -52.321  51.512  7
741310  99.065  -52.330  51.471  7
741311  99.087  -52.338  51.430  7
741312  99.110  -52.346  51.388  7
741313  99.132  -52.355  51.347  7
741314  99.154  -52.362  51.304  7
741315  99.176  -52.371  51.260  7
741316  99.198  -52.378  51.218  7
741317  99.221  -52.387  51.176  7
741318  99.243  -52.395  51.135  7
741322  99.332  -52.427  50.972  7
741323  99.354  -52.435  50.933  7
741324  99.376  -52.443  50.893  7
741325  99.399  -52.451  50.853  7
741326  99.421  -52.459  50.814  7
741327  99.443  -52.467  50.774  7
741328  99.466  -52.475  50.735  7
741329  99.488  -52.483  50.695  7
741330  99.510  -52.491  50.656  7
741331  99.532  -52.499  50.616  7
741332  99.555  -52.507  50.575  7
741333  99.577  -52.515  50.534  7
741334  99.599  -52.524  50.494  7
741335  99.621  -52.531  50.453  7
741336  99.637  -52.542  50.411  7
741337  99.651  -52.553  50.369  7
741338  99.665  -52.564  50.327  7
741339  99.679  -52.575  50.284  7
741340  99.693  -52.586  50.242  7
741341  99.707  -52.597  50.200  7
741342  99.722  -52.609  50.160  7
741343  99.737  -52.625  50.119  7
741344  99.753  -52.641  50.079  7
741345  99.768  -52.656  50.039  7
741346  99.783  -52.672  49.999  7
741993  98.716  -52.234  52.159  7
741994  98.737  -52.237  52.122  7
741995  98.758  -52.240  52.086  7
741996  98.779  -52.242  52.051  7
741997  98.800  -52.246  52.015  7
741998  98.821  -52.249  51.977  7
741999  98.843  -52.252  51.939  7
742000  98.864  -52.255  51.902  7
742001  98.885  -52.258  51.866  7
742002  98.906  -52.260  51.829  7
742003  98.927  -52.263  51.791  7
742004  98.948  -52.268  51.753  7
742005  98.966  -52.274  51.714  7
742006  98.985  -52.280  51.675  7
742007  99.003  -52.287  51.637  7
742008  99.022  -52.293  51.599  7
742009  99.040  -52.300  51.558  7
742010  99.059  -52.306  51.517  7
742011  99.077  -52.315  51.476  7
742012  99.099  -52.323  51.435  7
742013  99.121  -52.330  51.393  7
742014  99.143  -52.339  51.351  7
742015  99.165  -52.347  51.308  7
742016  99.188  -52.355  51.266  7
742017  99.210  -52.363  51.223  7
742018  99.232  -52.371  51.182  7
742024  99.366  -52.419  50.937  7
742025  99.388  -52.427  50.896  7
742026  99.411  -52.435  50.856  7
742027  99.433  -52.443  50.817  7
742028  99.455  -52.452  50.777  7
742029  99.477  -52.459  50.738  7
742030  99.499  -52.468  50.698  7
742031  99.522  -52.476  50.658  7
742032  99.544  -52.484  50.619  7
742033  99.566  -52.492  50.577  7
742034  99.588  -52.499  50.536  7
742035  99.611  -52.508  50.496  7
742036  99.633  -52.516  50.454  7
742037  99.653  -52.525  50.412  7
742038  99.667  -52.536  50.370  7
742039  99.681  -52.546  50.328  7
742040  99.695  -52.558  50.285  7
742041  99.709  -52.568  50.243  7
742042  99.723  -52.580  50.202  7
742043  99.737  -52.590  50.161  7
742044  99.752  -52.602  50.121  7
742045  99.766  -52.613  50.080  7
742046  99.781  -52.628  50.040  7
742047  99.796  -52.644  50.000  7
742696  98.771  -52.227  52.095  7
742697  98.792  -52.230  52.059  7
742698  98.813  -52.233  52.022  7
742699  98.835  -52.236  51.984  7
742700  98.856  -52.239  51.946  7
742701  98.877  -52.242  51.908  7
742702  98.898  -52.245  51.871  7
742703  98.919  -52.248  51.835  7
742704  98.940  -52.251  51.797  7
742705  98.961  -52.254  51.759  7
742706  98.981  -52.259  51.720  7
742707  99.000  -52.265  51.682  7
742708  99.018  -52.272  51.643  7
742709  99.037  -52.278  51.605  7
742710  99.055  -52.285  51.563  7
742711  99.074  -52.291  51.523  7
742712  99.092  -52.298  51.481  7
742713  99.111  -52.307  51.440  7
742714  99.133  -52.315  51.398  7
742715  99.155  -52.324  51.356  7
742716  99.178  -52.331  51.314  7
742717  99.200  -52.340  51.271  7
742718  99.222  -52.347  51.228  7
742719  99.244  -52.355  51.187  7
742726  99.400  -52.412  50.899  7
742727  99.422  -52.420  50.859  7
742728  99.444  -52.428  50.820  7
742729  99.467  -52.436  50.780  7
742730  99.489  -52.444  50.741  7
742731  99.511  -52.452  50.701  7
742732  99.534  -52.460  50.660  7
742733  99.556  -52.468  50.620  7
742734  99.578  -52.476  50.579  7
742735  99.600  -52.484  50.537  7
742736  99.623  -52.492  50.497  7
742737  99.645  -52.500  50.455  7
742738  99.667  -52.509  50.413  7
742739  99.683  -52.518  50.371  7
742740  99.697  -52.530  50.329  7
742741  99.711  -52.540  50.287  7
742742  99.725  -52.552  50.245  7
742743  99.739  -52.562  50.204  7
742744  99.754  -52.574  50.163  7
742745  99.768  -52.584  50.122  7
742746  99.782  -52.595  50.082  7
742747  99.796  -52.606  50.042  7
742748  99.810  -52.617  50.001  7
743398  98.805  -52.217  52.067  7
743399  98.827  -52.221  52.029  7
743400  98.848  -52.224  51.991  7
743401  98.869  -52.227  51.953  7
743402  98.890  -52.230  51.914  7
743403  98.911  -52.232  51.878  7
743404  98.932  -52.235  51.841  7
743405  98.953  -52.238  51.803  7
743406  98.975  -52.241  51.765  7
743407  98.996  -52.244  51.727  7
743408  99.014  -52.250  51.689  7
743409  99.033  -52.257  51.649  7
743410  99.052  -52.263  51.610  7
743411  99.070  -52.270  51.569  7
743412  99.088  -52.277  51.529  7
743413  99.107  -52.283  51.487  7
743414  99.126  -52.290  51.445  7
743415  99.145  -52.299  51.404  7
743416  99.167  -52.308  51.362  7
743417  99.189  -52.316  51.319  7
743418  99.211  -52.324  51.277  7
743419  99.234  -52.332  51.234  7
743420  99.256  -52.340  51.192  7
743427  99.412  -52.396  50.903  7
743428  99.434  -52.404  50.863  7
743429  99.456  -52.412  50.823  7
743430  99.479  -52.421  50.783  7
743431  99.501  -52.428  50.743  7
743432  99.523  -52.437  50.703  7
743433  99.545  -52.444  50.662  7
743434  99.568  -52.452  50.622  7
743435  99.590  -52.461  50.581  7
743436  99.612  -52.468  50.539  7
743437  99.634  -52.477  50.498  7
743438  99.656  -52.485  50.456  7
743439  99.679  -52.493  50.414  7
743440  99.699  -52.502  50.372  7
743441  99.713  -52.512  50.330  7
743442  99.727  -52.524  50.288  7
743443  99.741  -52.534  50.246  7
743444  99.755  -52.546  50.205  7
743445  99.769  -52.556  50.164  7
743446  99.783  -52.568  50.123  7
743447  99.798  -52.578  50.083  7
743448  99.812  -52.589  50.042  7
743449  99.826  -52.600  50.002  7
743480  100.432  -52.988  49.143  8
743481  100.459  -53.001  49.118  8
743482  100.487  -53.019  49.092  8
743483  100.514  -53.035  49.065  8
743484  100.542  -53.053  49.037  8
744100  98.839  -52.208  52.037  7
744101  98.861  -52.211  51.998  7
744102  98.882  -52.214  51.960  7
744103  98.903  -52.217  51.921  7
744104  98.924  -52.220  51.884  7
744105  98.945  -52.223  51.848  7
744106  98.967  -52.226  51.809  7
744107  98.988  -52.228  51.771  7
744108  99.009  -52.231  51.732  7
744109  99.029  -52.236  51.694  7
744110  99.048  -52.242  51.655  7
744111  99.066  -52.249  51.616  7
744112  99.085  -52.255  51.575  7
744113  99.103  -52.261  51.534  7
744114  99.122  -52.268  51.493  7
744115  99.140  -52.274  51.451  7
744116  99.159  -52.283  51.409  7
744117  99.179  -52.292  51.367  7
744118  99.201  -52.300  51.325  7
744119  99.223  -52.308  51.283  7
744120  99.245  -52.316  51.239  7
744121  99.268  -52.324  51.197  7
744129  99.446  -52.389  50.867  7
744130  99.468  -52.396  50.826  7
744131  99.490  -52.405  50.786  7
744132  99.512  -52.413  50.745  7
744133  99.535  -52.421  50.704  7
744134  99.557  -52.429  50.664  7
744135  99.579  -52.437  50.624  7
744136  99.602  -52.445  50.582  7
744137  99.624  -52.453  50.541  7
744138  99.646  -52.461  50.498  7
744139  99.668  -52.469  50.457  7
744140  99.691  -52.478  50.414  7
744141  99.713  -52.485  50.372  7
744142  99.729  -52.496  50.331  7
744143  99.743  -52.506  50.289  7
744144  99.757  -52.518  50.248  7
744145  99.771  -52.528  50.206  7
744146  99.785  -52.540  50.165  7
744147  99.799  -52.550  50.124  7
744148  99.814  -52.561  50.083  7
744149  99.828  -52.572  50.043  7
744150  99.842  -52.583  50.003  7
744178  100.354  -52.941  49.209  8
744179  100.381  -52.950  49.183  8
744180  100.407  -52.959  49.160  8
744181  100.433  -52.968  49.135  8
744182  100.461  -52.980  49.111  8
744183  100.488  -52.998  49.085  8
744184  100.516  -53.014  49.058  8
744185  100.544  -53.032  49.031  8
744186  100.572  -53.049  49.003  8
744187  100.600  -53.066  48.972  8
744188  100.628  -53.083  48.942  8
744803  98.895  -52.201  51.967  7
744804  98.916  -52.204  51.929  7
744805  98.937  -52.207  51.891  7
744806  98.958  -52.210  51.855  7
744807  98.980  -52.213  51.816  7
744808  99.001  -52.216  51.777  7
744809  99.022  -52.219  51.738  7
744810  99.043  -52.221  51.699  7
744811  99.063  -52.227  51.660  7
744812  99.081  -52.233  51.621  7
744813  99.099  -52.239  51.581  7
744814  99.118  -52.246  51.539  7
744815  99.137  -52.253  51.498  7
744816  99.155  -52.259  51.457  7
744817  99.173  -52.266  51.415  7
744818  99.192  -52.276  51.373  7
744819  99.213  -52.285  51.331  7
744820  99.235  -52.293  51.288  7
744821  99.257  -52.301  51.245  7
744822  99.280  -52.308  51.202  7
744831  99.480  -52.381  50.828  7
744832  99.502  -52.390  50.787  7
744833  99.524  -52.397  50.747  7
744834  99.547  -52.405  50.706  7
744835  99.569  -52.413  50.666  7
744836  99.591  -52.421  50.625  7
744837  99.614  -52.430  50.583  7
744838  99.636  -52.437  50.542  7
744839  99.658  -52.446  50.499  7
744840  99.680  -52.453  50.457  7
744841  99.702  -52.462  50.415  7
744842  99.725  -52.470  50.373  7
744843  99.745  -52.478  50.331  7
744844  99.759  -52.490  50.289  7
744845  99.773  -52.500  50.248  7
744846  99.787  -52.512  50.206  7
744847  99.801  -52.522  50.165  7
744848  99.816  -52.534  50.125  7
744849  99.830  -52.544  50.084  7
744850  99.844  -52.555  50.044  7
744878  100.330  -52.911  49.227  8
744879  100.356  -52.920  49.201  8
744880  100.382  -52.929  49.176  8
744881  100.409  -52.938  49.152  8
744882  100.435  -52.948  49.128  8
744883  100.462  -52.959  49.104  8
744884  100.490  -52.976  49.079  8
744885  100.518  -52.994  49.053  8
744886  100.546  -53.010  49.026  8
744887  100.573  -53.028  48.998  8
744888  100.602  -53.045  48.969  8
744889  100.629  -53.062  48.938  8
744890  100.657  -53.079  48.906  8
745505  98.929  -52.192  51.936  7
745506  98.950  -52.195  51.898  7
745507  98.972  -52.197  51.861  7
745508  98.993  -52.200  51.822  7
745509  99.014  -52.203  51.783  7
745510  99.035  -52.206  51.744  7
745511  99.056  -52.209  51.705  7
745512  99.077  -52.212  51.666  7
745513  99.096  -52.218  51.626  7
745514  99.115  -52.225  51.586  7
745515  99.133  -52.231  51.545  7
745516  99.151  -52.238  51.503  7
745517  99.170  -52.244  51.462  7
745518  99.189  -52.251  51.420  7
745519  99.207  -52.258  51.379  7
745520  99.225  -52.269  51.336  7
745521  99.247  -52.277  51.293  7
745522  99.269  -52.285  51.250  7
745533  99.514  -52.374  50.789  7
745534  99.536  -52.382  50.749  7
745535  99.558  -52.390  50.708  7
745536  99.581  -52.398  50.667  7
745537  99.603  -52.405  50.625  7
745538  99.625  -52.414  50.584  7
745539  99.647  -52.422  50.542  7
745540  99.669  -52.430  50.499  7
745541  99.692  -52.438  50.456  7
745542  99.714  -52.446  50.414  7
745543  99.736  -52.454  50.373  7
745544  99.759  -52.462  50.331  7
745545  99.775  -52.472  50.290  7
745546  99.789  -52.484  50.248  7
745547  99.803  -52.494  50.207  7
745548  99.817  -52.506  50.166  7
745549  99.831  -52.516  50.125  7
745550  99.846  -52.527  50.084  7
745551  99.860  -52.538  50.044  7
745578  100.305  -52.882  49.246  8
745579  100.332  -52.891  49.220  8
745580  100.358  -52.900  49.193  8
745581  100.385  -52.909  49.168  8
745582  100.411  -52.918  49.145  8
745583  100.437  -52.927  49.122  8
745584  100.464  -52.938  49.098  8
745585  100.492  -52.955  49.073  8
745586  100.519  -52.973  49.048  8
745587  100.548  -52.989  49.021  8
745588  100.575  -53.007  48.993  8
745589  100.603  -53.024  48.964  8
745590  100.631  -53.041  48.933  8
745591  100.659  -53.058  48.902  8
745592  100.687  -53.076  48.868  8
746208  98.984  -52.185  51.867  7
746209  99.005  -52.188  51.828  7
746210  99.027  -52.191  51.788  7
746211  99.048  -52.193  51.750  7
746212  99.069  -52.196  51.711  7
746213  99.090  -52.199  51.671  7
746214  99.111  -52.203  51.632  7
746215  99.129  -52.210  51.592  7
746216  99.148  -52.216  51.551  7
746217  99.166  -52.223  51.509  7
746218  99.185  -52.230  51.468  7
746219  99.203  -52.236  51.426  7
746220  99.222  -52.242  51.384  7
746221  99.240  -52.252  51.341  7
746222  99.259  -52.261  51.297  7
746234  99.525  -52.358  50.791  7
746235  99.548  -52.366  50.750  7
746236  99.570  -52.374  50.709  7
746237  99.592  -52.382  50.668  7
746238  99.615  -52.390  50.626  7
746239  99.637  -52.399  50.584  7
746240  99.659  -52.406  50.542  7
746241  99.682  -52.415  50.498  7
746242  99.704  -52.422  50.456  7
746243  99.726  -52.431  50.414  7
746244  99.748  -52.439  50.373  7
746245  99.771  -52.446  50.332  7
746246  99.791  -52.456  50.290  7
746247  99.805  -52.466  50.248  7
746248  99.819  -52.478  50.207  7
746249  99.833  -52.488  50.166  7
746250  99.847  -52.499  50.125  7
746251  99.861  -52.510  50.084  7
746278  100.280  -52.852  49.269  8
746279  100.307  -52.861  49.240  8
746280  100.333  -52.870  49.213  8
746281  100.360  -52.879  49.186  8
746282  100.387  -52.888  49.160  8
746283  100.413  -52.897  49.138  8
746284  100.439  -52.907  49.116  8
746285  100.466  -52.916  49.093  8
746286  100.494  -52.934  49.068  8
746287  100.522  -52.951  49.043  8
746288  100.549  -52.968  49.017  8
746289  100.577  -52.985  48.989  8
746290  100.605  -53.003  48.960  8
746291  100.633  -53.020  48.930  8
746292  100.661  -53.037  48.898  8
746293  100.688  -53.054  48.864  8
746294  100.716  -53.071  48.829  8
746910  99.018  -52.175  51.835  7
746911  99.040  -52.178  51.795  7
746912  99.061  -52.181  51.756  7
746913  99.082  -52.184  51.717  7
746914  99.103  -52.186  51.677  7
746915  99.125  -52.189  51.638  7
746916  99.144  -52.195  51.598  7
746917  99.162  -52.202  51.557  7
746918  99.181  -52.208  51.515  7
746919  99.200  -52.214  51.473  7
746920  99.218  -52.221  51.431  7
746921  99.236  -52.227  51.388  7
746922  99.255  -52.234  51.345  7
746936  99.560  -52.351  50.753  7
746937  99.582  -52.358  50.711  7
746938  99.604  -52.367  50.669  7
746939  99.627  -52.374  50.627  7
746940  99.649  -52.383  50.586  7
746941  99.671  -52.391  50.543  7
746942  99.693  -52.399  50.499  7
746943  99.715  -52.407  50.456  7
746944  99.738  -52.415  50.414  7
746945  99.760  -52.423  50.373  7
746946  99.782  -52.431  50.332  7
746947  99.804  -52.439  50.291  7
746948  99.821  -52.449  50.248  7
746949  99.835  -52.460  50.207  7
746950  99.849  -52.471  50.166  7
746951  99.863  -52.482  50.126  7
746978  100.261  -52.820  49.293  8
746979  100.282  -52.832  49.263  8
746980  100.309  -52.841  49.234  8
746981  100.335  -52.850  49.207  8
746982  100.362  -52.859  49.181  8
746983  100.388  -52.868  49.156  8
746984  100.415  -52.877  49.135  8
746985  100.441  -52.886  49.112  8
746986  100.468  -52.895  49.088  8
746987  100.495  -52.913  49.064  8
746988  100.523  -52.930  49.039  8
746989  100.551  -52.947  49.012  8
746990  100.579  -52.964  48.985  8
746991  100.607  -52.982  48.956  8
746992  100.634  -52.998  48.926  8
746993  100.662  -53.016  48.894  8
746994  100.690  -53.033  48.861  8
746995  100.718  -53.050  48.827  8
746996  100.746  -53.067  48.791  8
747614  99.095  -52.171  51.724  7
747615  99.116  -52.174  51.683  7
747616  99.137  -52.177  51.645  7
747617  99.159  -52.180  51.604  7
747618  99.178  -52.186  51.562  7
747619  99.196  -52.192  51.520  7
747639  99.616  -52.351  50.671  7
747640  99.638  -52.359  50.629  7
747641  99.660  -52.367  50.587  7
747642  99.683  -52.375  50.544  7
747643  99.705  -52.384  50.501  7
747644  99.727  -52.391  50.458  7
747645  99.750  -52.399  50.416  7
747646  99.772  -52.408  50.374  7
747647  99.794  -52.415  50.333  7
747648  99.816  -52.424  50.291  7
747649  99.837  -52.432  50.249  7
747650  99.851  -52.443  50.208  7
747651  99.865  -52.454  50.167  7
747678  100.254  -52.783  49.322  8
747679  100.271  -52.796  49.290  8
747680  100.289  -52.809  49.259  8
747681  100.311  -52.820  49.231  8
747682  100.337  -52.829  49.204  8
747683  100.363  -52.838  49.178  8
747684  100.390  -52.847  49.154  8
747685  100.416  -52.857  49.132  8
747686  100.443  -52.866  49.109  8
747687  100.470  -52.875  49.085  8
747688  100.497  -52.891  49.060  8
747689  100.525  -52.909  49.035  8
747690  100.553  -52.926  49.009  8
747691  100.580  -52.943  48.981  8
747692  100.609  -52.960  48.953  8
747693  100.636  -52.978  48.923  8
747694  100.664  -52.995  48.891  8
747695  100.692  -53.012  48.859  8
747696  100.720  -53.029  48.824  8
747697  100.748  -53.046  48.789  8
747698  100.775  -53.064  48.753  8
748343  99.695  -52.360  50.546  7
748344  99.717  -52.368  50.502  7
748345  99.739  -52.376  50.460  7
748379  100.268  -52.755  49.320  8
748380  100.283  -52.771  49.287  8
748381  100.299  -52.785  49.256  8
748382  100.317  -52.798  49.228  8
748383  100.339  -52.809  49.202  8
748384  100.365  -52.818  49.176  8
748385  100.392  -52.827  49.151  8
748386  100.418  -52.836  49.129  8
748387  100.445  -52.845  49.107  8
748388  100.471  -52.854  49.083  8
748389  100.499  -52.870  49.058  8
748390  100.527  -52.888  49.033  8
748391  100.555  -52.905  49.007  8
748392  100.582  -52.922  48.979  8
748393  100.610  -52.939  48.950  8
748394  100.638  -52.957  48.920  8
748395  100.666  -52.973  48.889  8
748396  100.694  -52.991  48.856  8
748397  100.721  -53.008  48.823  8
748398  100.749  -53.025  48.788  8
748399  100.777  -53.042  48.752  8
749079  100.266  -52.712  49.353  8
749080  100.281  -52.728  49.318  8
749081  100.296  -52.744  49.285  8
749082  100.312  -52.759  49.255  8
749083  100.327  -52.774  49.227  8
749084  100.345  -52.787  49.200  8
749085  100.367  -52.797  49.175  8
749086  100.394  -52.807  49.149  8
749087  100.420  -52.816  49.127  8
749088  100.446  -52.825  49.105  8
749089  100.473  -52.834  49.081  8
749090  100.500  -52.849  49.057  8
749091  100.528  -52.866  49.030  8
749092  100.556  -52.884  49.004  8
749093  100.584  -52.901  48.977  8
749094  100.612  -52.918  48.949  8
749095  100.640  -52.935  48.919  8
749096  100.668  -52.952  48.887  8
749097  100.695  -52.970  48.855  8
749098  100.723  -52.987  48.821  8
749099  100.751  -53.004  48.787  8
749100  100.779  -53.021  48.752  8
749101  100.807  -53.038  48.715  8
749780  100.280  -52.687  49.352  8
749781  100.294  -52.700  49.317  8
749782  100.310  -52.716  49.284  8
749783  100.325  -52.731  49.254  8
749784  100.340  -52.747  49.226  8
749785  100.355  -52.763  49.199  8
749786  100.373  -52.775  49.173  8
749787  100.396  -52.786  49.148  8
749788  100.422  -52.795  49.126  8
749789  100.449  -52.804  49.103  8
749790  100.475  -52.813  49.080  8
749791  100.502  -52.828  49.055  8
749792  100.530  -52.845  49.029  8
749793  100.558  -52.863  49.002  8
749794  100.586  -52.879  48.976  8
749795  100.614  -52.897  48.947  8
749796  100.641  -52.914  48.916  8
749797  100.669  -52.931  48.885  8
749798  100.697  -52.948  48.852  8
749799  100.725  -52.966  48.819  8
749800  100.753  -52.982  48.786  8
749801  100.780  -53.000  48.751  8
749802  100.809  -53.017  48.715  8
750481  100.296  -52.671  49.352  8
750482  100.310  -52.681  49.316  8
750483  100.324  -52.693  49.283  8
750484  100.339  -52.703  49.253  8
750485  100.354  -52.719  49.225  8
750486  100.369  -52.735  49.197  8
750487  100.384  -52.750  49.172  8
750488  100.401  -52.764  49.147  8
750489  100.424  -52.775  49.125  8
750490  100.451  -52.784  49.102  8
750491  100.477  -52.794  49.079  8
750492  100.504  -52.807  49.054  8
750493  100.532  -52.824  49.028  8
750494  100.560  -52.841  49.001  8
750495  100.587  -52.859  48.974  8
750496  100.615  -52.876  48.944  8
750497  100.643  -52.893  48.914  8
750498  100.671  -52.910  48.883  8
750499  100.699  -52.927  48.849  8
750500  100.726  -52.944  48.817  8
750501  100.755  -52.961  48.784  8
750502  100.783  -52.977  48.750  8
750503  100.812  -52.993  48.715  8
751182  100.312  -52.653  49.352  8
751183  100.326  -52.665  49.316  8
751184  100.340  -52.675  49.283  8
751185  100.354  -52.687  49.253  8
751186  100.368  -52.697  49.224  8
751187  100.382  -52.708  49.197  8
751188  100.398  -52.723  49.171  8
751189  100.413  -52.738  49.147  8
751190  100.429  -52.753  49.124  8
751191  100.452  -52.763  49.101  8
751192  100.479  -52.773  49.080  8
751193  100.506  -52.786  49.055  8
751194  100.534  -52.803  49.027  8
751195  100.561  -52.820  48.999  8
751196  100.590  -52.838  48.971  8
751197  100.617  -52.854  48.942  8
751198  100.645  -52.872  48.911  8
751199  100.673  -52.889  48.880  8
751200  100.701  -52.905  48.847  8
751201  100.729  -52.921  48.814  8
751202  100.758  -52.937  48.782  8
751203  100.786  -52.952  48.748  8
751204  100.815  -52.968  48.713  8
751883  100.328  -52.637  49.352  8
751884  100.342  -52.647  49.317  8
751885  100.356  -52.659  49.284  8
751886  100.370  -52.669  49.253  8
751887  100.385  -52.681  49.223  8
751888  100.399  -52.691  49.196  8
751889  100.413  -52.702  49.170  8
751890  100.427  -52.713  49.146  8
751891  100.441  -52.727  49.122  8
751892  100.457  -52.742  49.101  8
751893  100.481  -52.753  49.080  8
751894  100.507  -52.765  49.055  8
751895  100.536  -52.782  49.026  8
751896  100.563  -52.799  48.996  8
751897  100.591  -52.816  48.968  8
751898  100.619  -52.833  48.938  8
751899  100.647  -52.848  48.908  8
751900  100.676  -52.864  48.876  8
751901  100.705  -52.880  48.844  8
751902  100.733  -52.896  48.812  8
751903  100.762  -52.912  48.780  8
751904  100.790  -52.927  48.747  8
751905  100.819  -52.943  48.713  8
752584  100.344  -52.619  49.354  8
752585  100.358  -52.631  49.318  8
752586  100.372  -52.641  49.285  8
752587  100.386  -52.653  49.253  8
752588  100.400  -52.663  49.223  8
752589  100.414  -52.674  49.195  8
752590  100.429  -52.685  49.169  8
752591  100.443  -52.696  49.144  8
752592  100.457  -52.707  49.121  8
752593  100.471  -52.718  49.099  8
752594  100.485  -52.731  49.078  8
752595  100.509  -52.744  49.054  8
752596  100.537  -52.760  49.025  8
752597  100.566  -52.776  48.994  8
752598  100.594  -52.792  48.965  8
752599  100.623  -52.808  48.935  8
752600  100.651  -52.823  48.906  8
752601  100.680  -52.839  48.873  8
752602  100.708  -52.855  48.842  8
752603  100.738  -52.872  48.811  8
752604  100.767  -52.888  48.779  8
752605  100.795  -52.904  48.747  8
752606  100.825  -52.919  48.714  8
753285  100.360  -52.603  49.356  8
753286  100.374  -52.613  49.320  8
753287  100.388  -52.625  49.286  8
753288  100.402  -52.635  49.253  8
753289  100.416  -52.647  49.223  8
753290  100.430  -52.657  49.194  8
753291  100.444  -52.668  49.167  8
753292  100.459  -52.679  49.142  8
753293  100.473  -52.690  49.119  8
753294  100.487  -52.701  49.095  8
753295  100.501  -52.712  49.074  8
753296  100.516  -52.722  49.052  8
753297  100.546  -52.738  49.023  8
753298  100.574  -52.754  48.992  8
753299  100.604  -52.770  48.964  8
753300  100.633  -52.787  48.934  8
753301  100.662  -52.803  48.903  8
753302  100.691  -52.819  48.872  8
753303  100.720  -52.835  48.841  8
753304  100.749  -52.850  48.810  8
753305  100.778  -52.866  48.779  8
753306  100.807  -52.883  48.748  8
753307  100.836  -52.899  48.715  8
753986  100.376  -52.585  49.358  8
753987  100.390  -52.597  49.320  8
753988  100.404  -52.607  49.285  8
753989  100.418  -52.619  49.253  8
753990  100.432  -52.629  49.222  8
753991  100.446  -52.640  49.192  8
753992  100.461  -52.651  49.164  8
753993  100.475  -52.662  49.138  8
753994  100.489  -52.673  49.115  8
753995  100.503  -52.684  49.091  8
753996  100.517  -52.695  49.068  8
753997  100.532  -52.706  49.044  8
753998  100.557  -52.718  49.017  8
753999  100.586  -52.734  48.988  8
754000  100.615  -52.750  48.960  8
754001  100.644  -52.766  48.931  8
754002  100.673  -52.782  48.901  8
754003  100.702  -52.798  48.871  8
754004  100.731  -52.814  48.840  8
754005  100.760  -52.830  48.811  8
754006  100.789  -52.846  48.780  8
754007  100.818  -52.862  48.749  8
754008  100.847  -52.878  48.718  8
754687  100.392  -52.568  49.359  8
754688  100.406  -52.579  49.321  8
754689  100.420  -52.590  49.285  8
754690  100.434  -52.601  49.252  8
754691  100.448  -52.612  49.220  8
754692  100.462  -52.623  49.190  8
754693  100.477  -52.634  49.161  8
754694  100.491  -52.645  49.134  8
754695  100.505  -52.656  49.109  8
754696  100.519  -52.667  49.086  8
754697  100.533  -52.678  49.062  8
754698  100.548  -52.688  49.036  8
754699  100.568  -52.698  49.009  8
754700  100.597  -52.713  48.982  8
754701  100.626  -52.729  48.955  8
754702  100.655  -52.745  48.927  8
754703  100.684  -52.761  48.899  8
754704  100.713  -52.777  48.869  8
754705  100.743  -52.793  48.840  8
754706  100.771  -52.810  48.811  8
754707  100.800  -52.825  48.782  8
754708  100.830  -52.841  48.751  8
754709  100.858  -52.857  48.720  8
755389  100.422  -52.562  49.321  8
755390  100.436  -52.573  49.285  8
755391  100.450  -52.584  49.251  8
755392  100.464  -52.595  49.218  8
755393  100.478  -52.606  49.187  8
755394  100.492  -52.617  49.158  8
755395  100.506  -52.628  49.130  8
755396  100.521  -52.639  49.104  8
755397  100.535  -52.650  49.079  8
755398  100.549  -52.661  49.055  8
755399  100.564  -52.672  49.029  8
755400  100.583  -52.681  49.003  8
755401  100.609  -52.692  48.976  8
755402  100.637  -52.708  48.950  8
755403  100.667  -52.725  48.924  8
755404  100.696  -52.741  48.895  8
755405  100.724  -52.756  48.868  8
755406  100.754  -52.772  48.840  8
755407  100.783  -52.788  48.811  8
755408  100.812  -52.804  48.782  8
755409  100.841  -52.821  48.753  8
756090  100.438  -52.545  49.321  8
756091  100.452  -52.556  49.284  8
756092  100.466  -52.567  49.249  8
756093  100.480  -52.578  49.215  8
756094  100.494  -52.589  49.184  8
756095  100.508  -52.600  49.153  8
756096  100.522  -52.611  49.125  8
756097  100.537  -52.622  49.098  8
756098  100.551  -52.633  49.073  8
756099  100.565  -52.644  49.048  8
756100  100.579  -52.654  49.022  8
756101  100.599  -52.664  48.997  8
756102  100.619  -52.673  48.971  8
756103  100.649  -52.687  48.946  8
756104  100.678  -52.703  48.920  8
756105  100.707  -52.719  48.893  8
756106  100.736  -52.736  48.866  8
756107  100.765  -52.752  48.839  8
756108  100.794  -52.768  48.811  8
756109  100.823  -52.784  48.783  8
756110  100.852  -52.800  48.756  8
756792  100.468  -52.539  49.283  8
756793  100.482  -52.550  49.247  8
756794  100.496  -52.561  49.213  8
756795  100.510  -52.572  49.180  8
756796  100.525  -52.583  49.149  8
756797  100.539  -52.593  49.120  8
756798  100.553  -52.605  49.092  8
756799  100.567  -52.615  49.067  8
756800  100.581  -52.627  49.042  8
756801  100.596  -52.637  49.016  8
756802  100.614  -52.647  48.991  8
756803  100.633  -52.656  48.966  8
756804  100.660  -52.667  48.942  8
756805  100.689  -52.683  48.916  8
756806  100.718  -52.699  48.892  8
756807  100.747  -52.715  48.865  8
756808  100.776  -52.731  48.838  8
756809  100.805  -52.747  48.811  8
756810  100.834  -52.763  48.785  8
757493  100.484  -52.522  49.282  8
757494  100.498  -52.533  49.246  8
757495  100.512  -52.544  49.210  8
757496  100.526  -52.555  49.176  8
757497  100.540  -52.565  49.145  8
757498  100.554  -52.577  49.115  8
757499  100.568  -52.587  49.087  8
757500  100.582  -52.599  49.061  8
757501  100.597  -52.609  49.037  8
757502  100.611  -52.620  49.011  8
757503  100.630  -52.630  48.986  8
757504  100.649  -52.639  48.962  8
757505  100.671  -52.649  48.938  8
757506  100.700  -52.662  48.914  8
757507  100.729  -52.678  48.890  8
757508  100.758  -52.694  48.864  8
757509  100.787  -52.710  48.839  8
757510  100.817  -52.726  48.814  8
757511  100.845  -52.743  48.788  8
758195  100.514  -52.516  49.244  8
758196  100.528  -52.527  49.208  8
758197  100.542  -52.537  49.174  8
758198  100.556  -52.549  49.143  8
758199  100.570  -52.559  49.111  8
758200  100.584  -52.571  49.083  8
758201  100.599  -52.581  49.057  8
758202  100.613  -52.593  49.032  8
758203  100.627  -52.603  49.007  8
758204  100.646  -52.612  48.983  8
758205  100.665  -52.622  48.960  8
758206  100.684  -52.631  48.937  8
758207  100.711  -52.642  48.913  8
758208  100.741  -52.658  48.890  8
758209  100.770  -52.674  48.866  8
758210  100.798  -52.690  48.841  8
758211  100.828  -52.706  48.817  8
758897  100.544  -52.510  49.206  8
758898  100.558  -52.521  49.172  8
758899  100.572  -52.531  49.140  8
758900  100.586  -52.543  49.108  8
758901  100.601  -52.553  49.080  8
758902  100.615  -52.565  49.054  8
758903  100.629  -52.575  49.029  8
758904  100.643  -52.587  49.004  8
758905  100.662  -52.596  48.980  8
758906  100.681  -52.605  48.958  8
758907  100.700  -52.614  48.936  8
758908  100.722  -52.624  48.913  8
758909  100.752  -52.637  48.890  8
758910  100.781  -52.653  48.868  8
758911  100.810  -52.669  48.844  8
759600  100.588  -52.515  49.137  8
759601  100.602  -52.525  49.105  8
759602  100.616  -52.537  49.078  8
759603  100.630  -52.547  49.050  8
759604  100.644  -52.559  49.025  8
759605  100.658  -52.569  49.001  8
759606  100.678  -52.578  48.978  8
759607  100.697  -52.587  48.955  8
759608  100.715  -52.597  48.934  8
759609  100.735  -52.606  48.912  8
759610  100.763  -52.617  48.891  8
759611  100.792  -52.632  48.869  8
760302  100.618  -52.509  49.102  8
760303  100.632  -52.519  49.074  8
760304  100.646  -52.531  49.047  8
760305  100.661  -52.541  49.022  8
760306  100.675  -52.553  48.998  8
760307  100.693  -52.562  48.974  8
760308  100.712  -52.571  48.953  8
760309  100.732  -52.580  48.933  8
760310  100.750  -52.589  48.912  8
770837  101.263  -52.462  48.788  6
770838  101.292  -52.478  48.770  6
770839  101.321  -52.493  48.750  6
770840  101.350  -52.509  48.731  6
770841  101.379  -52.525  48.712  6
770842  101.408  -52.542  48.692  6
770843  101.437  -52.558  48.671  6
770844  101.466  -52.574  48.650  6
770845  101.495  -52.590  48.628  6
771536  101.215  -52.413  48.833  6
771537  101.245  -52.424  48.821  6
771538  101.274  -52.440  48.805  6
771539  101.303  -52.457  48.786  6
771540  101.332  -52.473  48.767  6
771541  101.361  -52.489  48.748  6
771542  101.390  -52.505  48.728  6
771543  101.419  -52.521  48.709  6
771544  101.448  -52.537  48.688  6
771545  101.477  -52.553  48.666  6
771546  101.506  -52.569  48.645  6
771547  101.535  -52.585  48.623  6
772235  101.171  -52.374  48.871  6
772236  101.196  -52.384  48.861  6
772237  101.226  -52.396  48.849  6
772238  101.256  -52.407  48.836  6
772239  101.285  -52.420  48.821  6
772240  101.314  -52.436  48.803  6
772241  101.343  -52.452  48.785  6
772242  101.373  -52.468  48.766  6
772243  101.401  -52.484  48.746  6
772244  101.430  -52.500  48.726  6
772245  101.460  -52.516  48.705  6
772246  101.488  -52.532  48.683  6
772247  101.518  -52.549  48.661  6
772248  101.547  -52.565  48.641  6
772249  101.575  -52.581  48.618  6
772935  101.168  -52.347  48.892  6
772936  101.187  -52.356  48.886  6
772937  101.207  -52.366  48.877  6
772938  101.237  -52.377  48.866  6
772939  101.266  -52.389  48.853  6
772940  101.296  -52.400  48.838  6
772941  101.326  -52.415  48.822  6
772942  101.354  -52.431  48.803  6
772943  101.384  -52.447  48.784  6
772944  101.413  -52.464  48.765  6
772945  101.442  -52.480  48.745  6
772946  101.471  -52.496  48.724  6
772947  101.500  -52.512  48.702  6
772948  101.529  -52.528  48.678  6
772949  101.558  -52.543  48.657  6
772950  101.587  -52.560  48.634  6
772951  101.616  -52.576  48.611  6
773635  101.165  -52.321  48.910  6
773636  101.183  -52.330  48.907  6
773637  101.202  -52.340  48.902  6
773638  101.221  -52.349  48.894  6
773639  101.247  -52.359  48.884  6
773640  101.277  -52.371  48.871  6
773641  101.307  -52.382  48.856  6
773642  101.337  -52.395  48.841  6
773643  101.366  -52.411  48.822  6
773644  101.395  -52.427  48.804  6
773645  101.424  -52.443  48.785  6
773646  101.453  -52.459  48.765  6
773647  101.482  -52.475  48.743  6
773648  101.511  -52.491  48.720  6
773649  101.540  -52.507  48.696  6
773650  101.569  -52.523  48.674  6
773651  101.598  -52.539  48.651  6
773652  101.627  -52.555  48.627  6
773653  101.656  -52.572  48.603  6
774335  101.162  -52.295  48.925  6
774336  101.180  -52.304  48.924  6
774337  101.199  -52.313  48.923  6
774338  101.218  -52.323  48.918  6
774339  101.237  -52.332  48.911  6
774340  101.258  -52.341  48.902  6
774341  101.288  -52.352  48.891  6
774342  101.318  -52.364  48.877  6
774343  101.348  -52.375  48.861  6
774344  101.377  -52.390  48.842  6
774345  101.406  -52.406  48.825  6
774346  101.435  -52.422  48.806  6
774347  101.464  -52.438  48.785  6
774348  101.493  -52.454  48.762  6
774349  101.522  -52.470  48.739  6
774350  101.551  -52.487  48.715  6
774351  101.581  -52.503  48.692  6
774352  101.609  -52.518  48.669  6
774353  101.638  -52.534  48.644  6
774354  101.668  -52.550  48.619  6
775035  101.158  -52.269  48.936  6
775036  101.177  -52.278  48.939  6
775037  101.196  -52.287  48.940  6
775038  101.215  -52.296  48.938  6
775039  101.234  -52.305  48.935  6
775040  101.253  -52.315  48.929  6
775041  101.272  -52.324  48.921  6
775042  101.299  -52.335  48.912  6
775043  101.329  -52.346  48.898  6
775044  101.358  -52.358  48.882  6
775045  101.388  -52.369  48.864  6
775046  101.417  -52.385  48.846  6
775047  101.447  -52.402  48.827  6
775048  101.475  -52.418  48.805  6
775049  101.504  -52.434  48.782  6
775050  101.534  -52.449  48.758  6
775051  101.562  -52.465  48.734  6
775052  101.592  -52.481  48.710  6
775053  101.621  -52.498  48.686  6
775054  101.650  -52.514  48.660  6
775055  101.679  -52.530  48.635  6
775056  101.708  -52.546  48.609  6
775734  101.136  -52.233  48.944  6
775735  101.155  -52.242  48.946  6
775736  101.174  -52.252  48.949  6
775737  101.193  -52.261  48.953  6
775738  101.212  -52.270  48.955  6
775739  101.231  -52.280  48.955  6
775740  101.250  -52.289  48.952  6
775741  101.269  -52.298  48.947  6
775742  101.288  -52.307  48.941  6
775743  101.310  -52.317  48.932  6
775744  101.339  -52.328  48.919  6
775745  101.370  -52.340  48.903  6
775746  101.399  -52.351  48.886  6
775747  101.428  -52.365  48.868  6
775748  101.458  -52.380  48.848  6
775749  101.487  -52.396  48.826  6
775750  101.516  -52.413  48.803  6
775751  101.545  -52.429  48.778  6
775752  101.574  -52.445  48.753  6
775753  101.603  -52.461  48.728  6
775754  101.632  -52.477  48.703  6
775755  101.661  -52.493  48.677  6
775756  101.690  -52.509  48.651  6
775757  101.719  -52.525  48.624  6
776434  101.133  -52.207  48.953  6
776435  101.152  -52.216  48.955  6
776436  101.171  -52.226  48.957  6
776437  101.190  -52.235  48.962  6
776438  101.209  -52.244  48.966  6
776439  101.228  -52.253  48.969  6
776440  101.247  -52.262  48.971  6
776441  101.266  -52.271  48.970  6
776442  101.284  -52.280  48.966  6
776443  101.304  -52.290  48.962  6
776444  101.323  -52.299  48.953  6
776445  101.350  -52.310  48.940  6
776446  101.380  -52.321  48.926  6
776447  101.410  -52.333  48.907  6
776448  101.440  -52.344  48.889  6
776449  101.469  -52.360  48.869  6
776450  101.498  -52.376  48.848  6
776451  101.527  -52.392  48.824  6
776452  101.556  -52.408  48.799  6
776453  101.585  -52.424  48.773  6
776454  101.614  -52.440  48.747  6
776455  101.642  -52.457  48.721  6
776456  101.671  -52.473  48.695  6
776457  101.699  -52.490  48.667  6
776458  101.728  -52.506  48.640  6
777135  101.149  -52.190  48.964  6
777136  101.168  -52.199  48.965  6
777137  101.187  -52.208  48.969  6
777138  101.206  -52.217  48.975  6
777139  101.225  -52.227  48.980  6
777140  101.244  -52.236  48.985  6
777141  101.262  -52.246  48.988  6
777142  101.281  -52.255  48.988  6
777143  101.301  -52.264  48.986  6
777144  101.319  -52.273  48.982  6
777145  101.338  -52.282  48.974  6
777146  101.361  -52.292  48.964  6
777147  101.391  -52.303  48.949  6
777148  101.421  -52.315  48.931  6
777149  101.451  -52.326  48.913  6
777150  101.480  -52.340  48.892  6
777151  101.509  -52.355  48.870  6
777152  101.537  -52.372  48.846  6
777153  101.565  -52.389  48.820  6
777154  101.594  -52.405  48.792  6
777155  101.623  -52.421  48.766  6
777156  101.651  -52.437  48.739  6
777157  101.680  -52.454  48.711  6
777158  101.708  -52.470  48.683  6
777159  101.737  -52.487  48.654  6
777835  101.145  -52.164  48.975  6
777836  101.165  -52.173  48.975  6
777837  101.184  -52.183  48.977  6
777838  101.202  -52.192  48.981  6
777839  101.221  -52.201  48.988  6
777840  101.241  -52.210  48.995  6
777841  101.259  -52.219  49.002  6
777842  101.278  -52.228  49.005  6
777843  101.297  -52.237  49.007  6
777844  101.316  -52.247  49.006  6
777845  101.335  -52.256  49.004  6
777846  101.354  -52.265  48.996  6
777847  101.373  -52.274  48.987  6
777848  101.402  -52.286  48.973  6
777849  101.431  -52.297  48.955  6
777850  101.461  -52.308  48.937  6
777851  101.488  -52.321  48.916  6
777852  101.517  -52.336  48.892  6
777853  101.546  -52.353  48.867  6
777854  101.574  -52.369  48.840  6
777855  101.603  -52.386  48.812  6
777856  101.631  -52.402  48.785  6
777857  101.659  -52.418  48.756  6
777858  101.688  -52.435  48.727  6
777859  101.717  -52.451  48.698  6
777860  101.745  -52.468  48.669  6
778535  101.142  -52.138  48.988  6
778536  101.162  -52.147  48.986  6
778537  101.180  -52.156  48.987  6
778538  101.199  -52.165  48.990  6
778539  101.218  -52.174  48.994  6
778540  101.237  -52.183  49.002  6
778541  101.256  -52.193  49.011  6
778542  101.275  -52.202  49.019  6
778543  101.294  -52.211  49.024  6
778544  101.313  -52.221  49.026  6
778545  101.332  -52.230  49.027  6
778546  101.351  -52.239  49.026  6
778547  101.370  -52.248  49.020  6
778548  101.389  -52.257  49.011  6
778549  101.412  -52.268  48.998  6
778550  101.443  -52.279  48.980  6
778551  101.471  -52.291  48.961  6
778552  101.495  -52.308  48.940  6
778553  101.526  -52.318  48.916  6
778554  101.554  -52.334  48.889  6
778555  101.583  -52.350  48.861  6
778556  101.611  -52.367  48.833  6
778557  101.640  -52.383  48.805  6
778558  101.669  -52.399  48.774  6
778559  101.697  -52.415  48.744  6
778560  101.726  -52.432  48.714  6
778561  101.754  -52.449  48.685  6
779236  101.159  -52.120  49.000  6
779237  101.177  -52.130  48.998  6
779238  101.196  -52.139  48.999  6
779239  101.215  -52.148  49.003  6
779240  101.234  -52.158  49.008  6
779241  101.253  -52.167  49.017  6
779242  101.272  -52.176  49.027  6
779243  101.291  -52.185  49.035  6
779244  101.310  -52.194  49.042  6
779245  101.329  -52.204  49.046  6
779246  101.348  -52.213  49.049  6
779247  101.367  -52.222  49.050  6
779248  101.386  -52.231  49.045  6
779249  101.405  -52.240  49.035  6
779250  101.423  -52.249  49.023  6
779251  101.453  -52.261  49.006  6
779252  101.479  -52.275  48.987  6
779253  101.503  -52.291  48.964  6
779254  101.534  -52.299  48.939  6
779255  101.563  -52.315  48.912  6
779256  101.592  -52.331  48.883  6
779257  101.620  -52.348  48.854  6
779258  101.649  -52.364  48.825  6
779259  101.677  -52.380  48.793  6
779260  101.705  -52.396  48.762  6
779261  101.734  -52.413  48.731  6
779262  101.763  -52.429  48.700  6
779937  101.174  -52.104  49.012  6
779938  101.193  -52.113  49.011  6
779939  101.212  -52.122  49.012  6
779940  101.231  -52.131  49.016  6
779941  101.250  -52.140  49.022  6
779942  101.269  -52.150  49.031  6
779943  101.288  -52.159  49.042  6
779944  101.307  -52.168  49.052  6
779945  101.326  -52.177  49.059  6
779946  101.345  -52.186  49.065  6
779947  101.363  -52.195  49.071  6
779948  101.383  -52.205  49.075  6
779949  101.402  -52.214  49.071  6
779950  101.420  -52.224  49.060  6
779951  101.440  -52.233  49.047  6
779952  101.463  -52.243  49.032  6
779953  101.488  -52.259  49.012  6
779954  101.512  -52.275  48.989  6
779955  101.543  -52.280  48.963  6
779956  101.571  -52.296  48.935  6
779957  101.600  -52.312  48.906  6
779958  101.628  -52.328  48.876  6
779959  101.657  -52.345  48.845  6
779960  101.686  -52.361  48.813  6
779961  101.714  -52.377  48.781  6
779962  101.743  -52.394  48.749  6
779963  101.771  -52.410  48.716  6
780638  101.190  -52.086  49.025  6
780639  101.209  -52.096  49.023  6
780640  101.228  -52.105  49.024  6
780641  101.247  -52.114  49.029  6
780642  101.266  -52.123  49.035  6
780643  101.285  -52.133  49.045  6
780644  101.304  -52.142  49.055  6
780645  101.323  -52.151  49.067  6
780646  101.341  -52.161  49.077  6
780647  101.360  -52.170  49.084  6
780648  101.379  -52.179  49.093  6
780649  101.398  -52.188  49.101  6
780650  101.417  -52.197  49.097  6
780651  101.437  -52.206  49.086  6
780652  101.455  -52.215  49.072  6
780653  101.472  -52.227  49.059  6
780654  101.496  -52.243  49.038  6
780655  101.521  -52.259  49.014  6
780656  101.555  -52.261  48.987  6
780657  101.580  -52.277  48.958  6
780658  101.609  -52.293  48.927  6
780659  101.637  -52.309  48.897  6
780660  101.666  -52.326  48.866  6
780661  101.694  -52.342  48.832  6
780662  101.723  -52.358  48.799  6
780663  101.751  -52.374  48.766  6
780664  101.780  -52.391  48.732  6
781339  101.206  -52.070  49.039  6
781340  101.225  -52.079  49.036  6
781341  101.244  -52.088  49.037  6
781342  101.263  -52.097  49.040  6
781343  101.281  -52.107  49.047  6
781344  101.301  -52.116  49.057  6
781345  101.320  -52.125  49.068  6
781346  101.338  -52.134  49.079  6
781347  101.357  -52.143  49.090  6
781348  101.376  -52.152  49.099  6
781349  101.395  -52.161  49.110  6
781350  101.414  -52.170  49.121  6
781351  101.433  -52.180  49.119  6
781352  101.452  -52.189  49.108  6
781353  101.471  -52.199  49.096  6
781354  101.488  -52.214  49.081  6
781355  101.504  -52.227  49.061  6
781356  101.529  -52.243  49.037  6
781357  101.557  -52.255  49.010  6
781358  101.589  -52.258  48.980  6
781359  101.617  -52.274  48.949  6
781360  101.646  -52.290  48.918  6
781361  101.675  -52.306  48.886  6
781362  101.703  -52.323  48.852  6
781363  101.732  -52.340  48.818  6
781364  101.760  -52.355  48.784  6
781365  101.788  -52.372  48.749  6
782040  101.221  -52.053  49.052  6
782041  101.241  -52.062  49.048  6
782042  101.259  -52.071  49.049  6
782043  101.278  -52.080  49.052  6
782044  101.298  -52.089  49.058  6
782045  101.316  -52.098  49.068  6
782046  101.335  -52.108  49.080  6
782047  101.354  -52.117  49.091  6
782048  101.373  -52.127  49.102  6
782049  101.392  -52.136  49.112  6
782050  101.411  -52.145  49.124  6
782051  101.430  -52.154  49.135  6
782052  101.449  -52.163  49.136  6
782053  101.468  -52.172  49.128  6
782054  101.488  -52.184  49.117  6
782055  101.504  -52.201  49.103  6
782056  101.513  -52.211  49.083  6
782057  101.538  -52.227  49.060  6
782058  101.562  -52.243  49.032  6
782059  101.598  -52.239  49.003  6
782060  101.626  -52.255  48.971  6
782061  101.655  -52.271  48.939  6
782062  101.683  -52.287  48.906  6
782063  101.711  -52.304  48.872  6
782064  101.740  -52.320  48.837  6
782065  101.769  -52.336  48.801  6
782066  101.797  -52.353  48.766  6
782067  101.826  -52.369  48.733  6
782741  101.238  -52.036  49.065  6
782742  101.256  -52.045  49.060  6
782743  101.275  -52.054  49.061  6
782744  101.294  -52.064  49.064  6
782745  101.313  -52.073  49.069  6
782746  101.332  -52.082  49.078  6
782747  101.351  -52.091  49.090  6
782748  101.370  -52.100  49.102  6
782749  101.389  -52.109  49.113  6
782750  101.408  -52.118  49.124  6
782751  101.427  -52.127  49.135  6
782752  101.446  -52.137  49.144  6
782753  101.465  -52.146  49.149  6
782754  101.484  -52.155  49.145  6
782755  101.505  -52.170  49.136  6
782756  101.521  -52.187  49.123  6
782757  101.529  -52.198  49.105  6
782758  101.546  -52.211  49.081  6
782759  101.570  -52.227  49.054  6
782760  101.608  -52.220  49.024  6
782761  101.634  -52.236  48.993  6
782762  101.663  -52.252  48.960  6
782763  101.692  -52.268  48.927  6
782764  101.721  -52.285  48.892  6
782765  101.749  -52.301  48.857  6
782766  101.777  -52.318  48.820  6
782767  101.806  -52.333  48.784  6
782768  101.834  -52.350  48.749  6
782769  101.863  -52.366  48.716  6
783443  101.272  -52.028  49.074  6
783444  101.291  -52.037  49.074  6
783445  101.310  -52.046  49.076  6
783446  101.329  -52.055  49.082  6
783447  101.348  -52.064  49.090  6
783448  101.367  -52.074  49.101  6
783449  101.386  -52.083  49.114  6
783450  101.405  -52.092  49.125  6
783451  101.424  -52.101  49.135  6
783452  101.443  -52.111  49.146  6
783453  101.462  -52.120  49.156  6
783454  101.481  -52.129  49.161  6
783455  101.500  -52.141  49.159  6
783456  101.522  -52.157  49.156  6
783457  101.538  -52.174  49.145  6
783458  101.545  -52.184  49.128  6
783459  101.554  -52.195  49.105  6
783460  101.579  -52.211  49.077  6
783461  101.622  -52.203  49.046  6
783462  101.643  -52.217  49.014  6
783463  101.672  -52.233  48.980  6
783464  101.700  -52.249  48.947  6
783465  101.729  -52.265  48.911  6
783466  101.757  -52.282  48.875  6
783467  101.786  -52.299  48.838  6
783468  101.815  -52.315  48.802  6
783469  101.843  -52.331  48.766  6
783470  101.872  -52.347  48.732  6
783471  101.900  -52.364  48.699  6
784144  101.288  -52.011  49.089  6
784145  101.307  -52.020  49.087  6
784146  101.326  -52.029  49.089  6
784147  101.345  -52.039  49.094  6
784148  101.364  -52.048  49.103  6
784149  101.383  -52.057  49.113  6
784150  101.402  -52.066  49.125  6
784151  101.420  -52.075  49.136  6
784152  101.440  -52.084  49.147  6
784153  101.459  -52.094  49.157  6
784154  101.477  -52.103  49.167  6
784155  101.496  -52.112  49.174  6
784156  101.518  -52.127  49.175  6
784157  101.538  -52.144  49.176  6
784158  101.554  -52.161  49.168  6
784159  101.562  -52.171  49.152  6
784160  101.569  -52.181  49.127  6
784161  101.588  -52.195  49.099  6
784162  101.622  -52.199  49.068  6
784163  101.652  -52.197  49.034  6
784164  101.680  -52.214  49.000  6
784165  101.709  -52.230  48.966  6
784166  101.738  -52.246  48.930  6
784167  101.766  -52.263  48.893  6
784168  101.795  -52.279  48.857  6
784169  101.823  -52.296  48.820  6
784170  101.852  -52.311  48.784  6
784171  101.880  -52.328  48.749  6
784172  101.909  -52.345  48.715  6
784173  101.938  -52.361  48.682  6
784845  101.304  -51.994  49.104  6
784846  101.323  -52.003  49.102  6
784847  101.342  -52.012  49.103  6
784848  101.360  -52.021  49.107  6
784849  101.379  -52.031  49.116  6
784850  101.399  -52.040  49.126  6
784851  101.417  -52.049  49.137  6
784852  101.437  -52.058  49.148  6
784853  101.455  -52.067  49.158  6
784854  101.474  -52.076  49.168  6
784855  101.493  -52.086  49.178  6
784856  101.513  -52.097  49.186  6
784857  101.534  -52.112  49.190  6
784858  101.555  -52.131  49.196  6
784859  101.571  -52.148  49.192  6
784860  101.579  -52.158  49.175  6
784861  101.586  -52.168  49.149  6
784862  101.596  -52.179  49.120  6
784863  101.620  -52.195  49.088  6
784864  101.661  -52.179  49.055  6
784865  101.689  -52.195  49.021  6
784866  101.717  -52.211  48.986  6
784867  101.746  -52.227  48.949  6
784868  101.775  -52.244  48.912  6
784869  101.803  -52.260  48.875  6
784870  101.832  -52.277  48.837  6
784871  101.861  -52.293  48.801  6
784872  101.889  -52.309  48.766  6
784873  101.917  -52.325  48.732  6
784874  101.946  -52.342  48.698  6
785546  101.320  -51.977  49.120  6
785547  101.338  -51.986  49.117  6
785548  101.357  -51.995  49.117  6
785549  101.376  -52.004  49.121  6
785550  101.395  -52.014  49.129  6
785551  101.414  -52.023  49.138  6
785552  101.433  -52.032  49.148  6
785553  101.452  -52.041  49.158  6
785554  101.471  -52.051  49.168  6
785555  101.490  -52.060  49.179  6
785556  101.509  -52.069  49.189  6
785557  101.530  -52.083  49.197  6
785558  101.551  -52.098  49.203  6
785559  101.571  -52.117  49.209  6
785560  101.586  -52.130  49.210  6
785561  101.595  -52.145  49.195  6
785562  101.603  -52.155  49.168  6
785563  101.610  -52.165  49.138  6
785564  101.629  -52.179  49.107  6
785565  101.676  -52.161  49.073  6
785566  101.698  -52.176  49.039  6
785567  101.727  -52.192  49.004  6
785568  101.755  -52.208  48.967  6
785569  101.783  -52.224  48.930  6
785570  101.812  -52.241  48.893  6
785571  101.840  -52.257  48.856  6
785572  101.869  -52.274  48.819  6
785573  101.898  -52.290  48.783  6
785574  101.926  -52.306  48.749  6
785575  101.955  -52.323  48.714  6
785576  101.983  -52.339  48.680  6
786247  101.335  -51.960  49.136  6
786248  101.354  -51.969  49.132  6
786249  101.373  -51.978  49.132  6
786250  101.392  -51.987  49.134  6
786251  101.411  -51.997  49.142  6
786252  101.430  -52.006  49.150  6
786253  101.449  -52.015  49.159  6
786254  101.468  -52.024  49.169  6
786255  101.487  -52.033  49.179  6
786256  101.506  -52.042  49.190  6
786257  101.526  -52.054  49.200  6
786258  101.547  -52.069  49.208  6
786259  101.568  -52.084  49.215  6
786260  101.588  -52.104  49.221  6
786261  101.601  -52.111  49.223  6
786262  101.610  -52.127  49.211  6
786263  101.619  -52.141  49.184  6
786264  101.627  -52.152  49.154  6
786265  101.637  -52.163  49.123  6
786266  101.690  -52.145  49.091  6
786267  101.706  -52.156  49.057  6
786268  101.735  -52.173  49.022  6
786269  101.763  -52.189  48.985  6
786270  101.792  -52.205  48.948  6
786271  101.821  -52.222  48.911  6
786272  101.849  -52.238  48.873  6
786273  101.878  -52.255  48.836  6
786274  101.906  -52.271  48.801  6
786275  101.935  -52.287  48.766  6
786276  101.963  -52.304  48.731  6
786277  101.992  -52.320  48.696  6
786948  101.351  -51.943  49.153  6
786949  101.370  -51.952  49.148  6
786950  101.389  -51.961  49.147  6
786951  101.408  -51.970  49.148  6
786952  101.427  -51.979  49.154  6
786953  101.446  -51.989  49.162  6
786954  101.465  -51.998  49.170  6
786955  101.484  -52.007  49.180  6
786956  101.503  -52.017  49.190  6
786957  101.522  -52.026  49.200  6
786958  101.543  -52.039  49.210  6
786959  101.564  -52.054  49.219  6
786960  101.585  -52.071  49.226  6
786961  101.602  -52.086  49.231  6
786962  101.616  -52.092  49.233  6
786963  101.625  -52.108  49.223  6
786964  101.634  -52.123  49.196  6
786965  101.643  -52.137  49.168  6
786966  101.651  -52.149  49.139  6
786967  101.687  -52.143  49.107  6
786968  101.715  -52.137  49.074  6
786969  101.744  -52.154  49.039  6
786970  101.772  -52.170  49.002  6
786971  101.801  -52.186  48.965  6
786972  101.829  -52.202  48.928  6
786973  101.858  -52.219  48.890  6
786974  101.886  -52.236  48.854  6
786975  101.915  -52.252  48.818  6
786976  101.944  -52.268  48.783  6
786977  101.972  -52.284  48.748  6
786978  102.000  -52.301  48.712  6
787649  101.367  -51.926  49.171  6
787650  101.386  -51.935  49.165  6
787651  101.405  -51.944  49.163  6
787652  101.424  -51.954  49.163  6
787653  101.443  -51.963  49.167  6
787654  101.462  -51.972  49.175  6
787655  101.481  -51.981  49.182  6
787656  101.499  -51.990  49.191  6
787657  101.519  -51.999  49.200  6
787658  101.538  -52.011  49.210  6
787659  101.559  -52.025  49.219  6
787660  101.581  -52.040  49.227  6
787661  101.601  -52.058  49.235  6
787662  101.617  -52.068  49.240  6
787663  101.631  -52.074  49.244  6
787664  101.640  -52.089  49.231  6
787665  101.650  -52.104  49.208  6
787666  101.658  -52.119  49.182  6
787667  101.667  -52.133  49.153  6
787668  101.682  -52.142  49.122  6
787669  101.729  -52.120  49.089  6
787670  101.752  -52.135  49.054  6
787671  101.781  -52.151  49.019  6
787672  101.809  -52.167  48.982  6
787673  101.838  -52.183  48.945  6
787674  101.867  -52.200  48.907  6
787675  101.895  -52.216  48.871  6
787676  101.923  -52.233  48.836  6
787677  101.952  -52.249  48.800  6
787678  101.981  -52.265  48.764  6
787679  102.009  -52.282  48.728  6
788351  101.402  -51.918  49.183  6
788352  101.421  -51.927  49.179  6
788353  101.440  -51.936  49.178  6
788354  101.459  -51.945  49.181  6
788355  101.478  -51.954  49.188  6
788356  101.496  -51.964  49.194  6
788357  101.516  -51.973  49.202  6
788358  101.534  -51.982  49.211  6
788359  101.555  -51.996  49.219  6
788360  101.576  -52.011  49.227  6
788361  101.598  -52.026  49.235  6
788362  101.617  -52.043  49.244  6
788363  101.631  -52.050  49.249  6
788364  101.646  -52.056  49.253  6
788365  101.656  -52.070  49.241  6
788366  101.665  -52.085  49.221  6
788367  101.673  -52.100  49.197  6
788368  101.682  -52.115  49.168  6
788369  101.693  -52.127  49.136  6
788370  101.743  -52.103  49.103  6
788371  101.761  -52.115  49.070  6
788372  101.790  -52.132  49.034  6
788373  101.818  -52.148  48.998  6
788374  101.846  -52.164  48.961  6
788375  101.875  -52.181  48.924  6
788376  101.904  -52.197  48.888  6
788377  101.932  -52.214  48.853  6
788378  101.961  -52.230  48.817  6
788379  101.989  -52.246  48.781  6
788380  102.018  -52.262  48.745  6
789052  101.417  -51.901  49.201  6
789053  101.437  -51.910  49.196  6
789054  101.456  -51.920  49.195  6
789055  101.474  -51.929  49.197  6
789056  101.493  -51.938  49.201  6
789057  101.513  -51.947  49.206  6
789058  101.531  -51.956  49.213  6
789059  101.551  -51.967  49.221  6
789060  101.572  -51.982  49.228  6
789061  101.593  -51.997  49.235  6
789062  101.614  -52.011  49.243  6
789063  101.632  -52.026  49.252  6
789064  101.646  -52.032  49.258  6
789065  101.661  -52.039  49.261  6
789066  101.671  -52.051  49.251  6
789067  101.680  -52.067  49.235  6
789068  101.688  -52.081  49.212  6
789069  101.699  -52.095  49.183  6
789070  101.714  -52.104  49.150  6
789071  101.756  -52.088  49.117  6
789072  101.769  -52.096  49.085  6
789073  101.798  -52.113  49.049  6
789074  101.827  -52.129  49.013  6
789075  101.855  -52.145  48.977  6
789076  101.884  -52.161  48.940  6
789077  101.912  -52.178  48.905  6
789078  101.941  -52.195  48.870  6
789079  101.969  -52.211  48.834  6
789080  101.998  -52.227  48.798  6
789081  102.027  -52.243  48.761  6
789753  101.433  -51.884  49.220  6
789754  101.452  -51.893  49.214  6
789755  101.471  -51.902  49.211  6
789756  101.490  -51.911  49.212  6
789757  101.509  -51.921  49.216  6
789758  101.528  -51.930  49.220  6
789759  101.547  -51.939  49.225  6
789760  101.568  -51.953  49.230  6
789761  101.589  -51.967  49.237  6
789762  101.610  -51.982  49.243  6
789763  101.631  -51.998  49.250  6
789764  101.646  -52.007  49.257  6
789765  101.661  -52.014  49.263  6
789766  101.676  -52.020  49.268  6
789767  101.686  -52.032  49.261  6
789768  101.695  -52.048  49.250  6
789769  101.705  -52.061  49.227  6
789770  101.720  -52.070  49.196  6
789771  101.735  -52.080  49.162  6
789772  101.752  -52.087  49.130  6
789773  101.782  -52.079  49.098  6
789774  101.807  -52.093  49.063  6
789775  101.835  -52.110  49.030  6
789776  101.864  -52.127  48.994  6
789777  101.892  -52.142  48.957  6
789778  101.921  -52.159  48.921  6
789779  101.950  -52.175  48.886  6
789780  101.978  -52.192  48.851  6
789781  102.007  -52.208  48.814  6
789782  102.035  -52.224  48.778  6
789783  102.063  -52.241  48.741  6
790420  100.841  -51.537  50.618  12
790421  100.859  -51.544  50.572  12
790422  100.878  -51.550  50.526  12
790423  100.896  -51.561  50.479  12
790424  100.914  -51.571  50.432  12
790425  100.932  -51.581  50.384  12
790426  100.951  -51.591  50.336  12
790453  101.430  -51.857  49.248  6
790454  101.449  -51.867  49.239  6
790455  101.468  -51.876  49.232  6
790456  101.487  -51.885  49.228  6
790457  101.506  -51.895  49.228  6
790458  101.525  -51.904  49.230  6
790459  101.544  -51.913  49.233  6
790460  101.563  -51.923  49.236  6
790461  101.585  -51.939  49.241  6
790462  101.606  -51.953  49.246  6
790463  101.627  -51.968  49.252  6
790464  101.646  -51.983  49.257  6
790465  101.661  -51.989  49.263  6
790466  101.676  -51.996  49.268  6
790467  101.690  -52.002  49.274  6
790468  101.701  -52.014  49.272  6
790469  101.710  -52.029  49.262  6
790470  101.726  -52.038  49.240  6
790471  101.740  -52.047  49.207  6
790472  101.755  -52.056  49.173  6
790473  101.770  -52.065  49.142  6
790474  101.796  -52.062  49.110  6
790475  101.815  -52.074  49.077  6
790476  101.844  -52.091  49.044  6
790477  101.873  -52.107  49.009  6
790478  101.901  -52.123  48.973  6
790479  101.929  -52.140  48.937  6
790480  101.958  -52.156  48.903  6
790481  101.986  -52.173  48.867  6
790482  102.015  -52.189  48.831  6
790483  102.044  -52.205  48.794  6
790484  102.073  -52.221  48.758  6
791119  100.813  -51.516  50.735  12
791120  100.834  -51.519  50.690  12
791121  100.855  -51.522  50.645  12
791122  100.874  -51.528  50.600  12
791123  100.893  -51.534  50.554  12
791124  100.911  -51.544  50.507  12
791125  100.929  -51.553  50.460  12
791126  100.948  -51.564  50.413  12
791127  100.966  -51.574  50.364  12
791128  100.984  -51.584  50.316  12
791129  101.002  -51.594  50.266  12
791154  101.446  -51.841  49.268  6
791155  101.465  -51.850  49.258  6
791156  101.484  -51.859  49.250  6
791157  101.503  -51.868  49.244  6
791158  101.522  -51.878  49.243  6
791159  101.541  -51.887  49.243  6
791160  101.560  -51.896  49.245  6
791161  101.581  -51.909  49.247  6
791162  101.602  -51.924  49.251  6
791163  101.623  -51.939  49.256  6
791164  101.644  -51.954  49.260  6
791165  101.661  -51.965  49.264  6
791166  101.676  -51.972  49.269  6
791167  101.690  -51.978  49.273  6
791168  101.705  -51.985  49.282  6
791169  101.716  -51.995  49.283  6
791170  101.731  -52.004  49.273  6
791171  101.746  -52.014  49.250  6
791172  101.761  -52.023  49.217  6
791173  101.776  -52.032  49.184  6
791174  101.791  -52.041  49.152  6
791175  101.811  -52.045  49.121  6
791176  101.824  -52.055  49.090  6
791177  101.852  -52.072  49.058  6
791178  101.881  -52.088  49.023  6
791179  101.910  -52.105  48.986  6
791180  101.938  -52.120  48.953  6
791181  101.967  -52.137  48.919  6
791182  101.995  -52.153  48.883  6
791183  102.024  -52.170  48.848  6
791184  102.052  -52.186  48.811  6
791185  102.081  -52.202  48.773  6
791819  100.805  -51.501  50.806  12
791820  100.826  -51.503  50.762  12
791821  100.847  -51.506  50.717  12
791822  100.868  -51.509  50.673  12
791823  100.889  -51.513  50.629  12
791824  100.907  -51.520  50.583  12
791825  100.926  -51.526  50.537  12
791826  100.945  -51.537  50.489  12
791827  100.963  -51.547  50.441  12
791828  100.981  -51.556  50.392  12
791829  100.999  -51.567  50.344  12
791830  101.018  -51.577  50.295  12
791831  101.036  -51.587  50.244  12
791832  101.054  -51.597  50.194  12
791855  101.462  -51.824  49.287  6
791856  101.481  -51.833  49.276  6
791857  101.500  -51.842  49.267  6
791858  101.519  -51.851  49.260  6
791859  101.538  -51.860  49.257  6
791860  101.557  -51.870  49.257  6
791861  101.576  -51.880  49.257  6
791862  101.597  -51.895  49.258  6
791863  101.618  -51.910  49.261  6
791864  101.639  -51.925  49.264  6
791865  101.661  -51.939  49.268  6
791866  101.676  -51.948  49.271  6
791867  101.690  -51.954  49.274  6
791868  101.704  -51.961  49.278  6
791869  101.717  -51.969  49.286  6
791870  101.732  -51.976  49.289  6
791871  101.747  -51.986  49.277  6
791872  101.762  -51.994  49.254  6
791873  101.777  -52.003  49.224  6
791874  101.793  -52.011  49.192  6
791875  101.808  -52.020  49.162  6
791876  101.824  -52.029  49.132  6
791877  101.835  -52.037  49.101  6
791878  101.861  -52.052  49.070  6
791879  101.890  -52.069  49.037  6
791880  101.918  -52.086  49.002  6
791881  101.947  -52.101  48.968  6
791882  101.975  -52.118  48.934  6
791883  102.004  -52.134  48.899  6
791884  102.033  -52.151  48.863  6
791885  102.061  -52.167  48.826  6
791886  102.090  -52.183  48.788  6
792519  100.796  -51.485  50.877  12
792520  100.818  -51.488  50.833  12
792521  100.839  -51.491  50.790  12
792522  100.860  -51.494  50.746  12
792523  100.882  -51.497  50.702  12
792524  100.903  -51.500  50.658  12
792525  100.922  -51.505  50.613  12
792526  100.941  -51.511  50.566  12
792527  100.959  -51.519  50.519  12
792528  100.978  -51.529  50.471  12
792529  100.996  -51.540  50.422  12
792530  101.014  -51.550  50.373  12
792531  101.033  -51.559  50.322  12
792532  101.051  -51.570  50.272  12
792533  101.069  -51.580  50.221  12
792534  101.088  -51.590  50.171  12
792556  101.478  -51.807  49.306  6
792557  101.496  -51.816  49.294  6
792558  101.516  -51.825  49.285  6
792559  101.535  -51.835  49.277  6
792560  101.553  -51.844  49.273  6
792561  101.572  -51.853  49.271  6
792562  101.593  -51.866  49.270  6
792563  101.614  -51.881  49.270  6
792564  101.635  -51.895  49.271  6
792565  101.656  -51.910  49.273  6
792566  101.673  -51.923  49.276  6
792567  101.686  -51.934  49.278  6
792568  101.700  -51.943  49.280  6
792569  101.713  -51.951  49.283  6
792570  101.727  -51.958  49.290  6
792571  101.741  -51.966  49.293  6
792572  101.755  -51.973  49.281  6
792573  101.770  -51.982  49.260  6
792574  101.785  -51.991  49.232  6
792575  101.801  -52.000  49.201  6
792576  101.816  -52.008  49.171  6
792577  101.834  -52.014  49.142  6
792578  101.849  -52.020  49.112  6
792579  101.870  -52.033  49.082  6
792580  101.898  -52.050  49.049  6
792581  101.927  -52.066  49.016  6
792582  101.956  -52.083  48.982  6
792583  101.984  -52.098  48.948  6
792584  102.013  -52.115  48.914  6
792585  102.041  -52.132  48.878  6
792586  102.069  -52.148  48.841  6
792587  102.098  -52.164  48.803  6
792588  102.127  -52.180  48.767  6
793219  100.788  -51.470  50.947  12
793220  100.810  -51.473  50.904  12
793221  100.831  -51.475  50.861  12
793222  100.852  -51.478  50.819  12
793223  100.873  -51.481  50.774  12
793224  100.894  -51.484  50.731  12
793225  100.916  -51.487  50.687  12
793226  100.937  -51.490  50.642  12
793227  100.956  -51.497  50.596  12
793228  100.974  -51.503  50.549  12
793229  100.992  -51.512  50.501  12
793230  101.011  -51.522  50.452  12
793231  101.029  -51.532  50.402  12
793232  101.047  -51.543  50.351  12
793233  101.066  -51.553  50.301  12
793234  101.084  -51.562  50.250  12
793235  101.102  -51.572  50.198  12
793257  101.493  -51.790  49.326  6
793258  101.513  -51.799  49.313  6
793259  101.531  -51.808  49.303  6
793260  101.550  -51.817  49.294  6
793261  101.569  -51.826  49.289  6
793262  101.589  -51.837  49.285  6
793263  101.610  -51.851  49.283  6
793264  101.631  -51.866  49.283  6
793265  101.652  -51.881  49.282  6
793266  101.671  -51.895  49.283  6
793267  101.683  -51.905  49.283  6
793268  101.696  -51.916  49.284  6
793269  101.709  -51.927  49.285  6
793270  101.723  -51.938  49.287  6
793271  101.737  -51.948  49.292  6
793272  101.750  -51.955  49.297  6
793273  101.764  -51.963  49.285  6
793274  101.778  -51.970  49.266  6
793275  101.793  -51.979  49.240  6
793276  101.809  -51.988  49.210  6
793277  101.824  -51.997  49.180  6
793278  101.844  -52.000  49.152  6
793279  101.864  -52.004  49.123  6
793280  101.879  -52.014  49.093  6
793281  101.907  -52.031  49.060  6
793282  101.936  -52.047  49.028  6
793283  101.964  -52.064  48.995  6
793284  101.992  -52.080  48.961  6
793285  102.021  -52.096  48.927  6
793286  102.050  -52.112  48.892  6
793287  102.079  -52.129  48.855  6
793288  102.107  -52.145  48.818  6
793289  102.135  -52.161  48.782  6
793290  102.164  -52.178  48.744  6
793920  100.802  -51.457  50.975  12
793921  100.823  -51.460  50.932  12
793922  100.844  -51.463  50.890  12
793923  100.865  -51.466  50.847  12
793924  100.886  -51.469  50.804  12
793925  100.907  -51.472  50.761  12
793926  100.928  -51.475  50.717  12
793927  100.950  -51.478  50.673  12
793928  100.971  -51.481  50.628  12
793929  100.989  -51.487  50.580  12
793930  101.007  -51.495  50.531  12
793931  101.025  -51.505  50.482  12
793932  101.044  -51.515  50.432  12
793933  101.062  -51.525  50.380  12
793934  101.080  -51.535  50.331  12
793935  101.099  -51.545  50.280  12
793936  101.117  -51.556  50.227  12
793937  101.135  -51.566  50.176  12
793958  101.510  -51.772  49.346  6
793959  101.528  -51.782  49.332  6
793960  101.547  -51.791  49.321  6
793961  101.566  -51.801  49.311  6
793962  101.585  -51.810  49.306  6
793963  101.606  -51.823  49.300  6
793964  101.627  -51.837  49.298  6
793965  101.648  -51.852  49.295  6
793966  101.669  -51.866  49.294  6
793967  101.681  -51.877  49.293  6
793968  101.693  -51.888  49.292  6
793969  101.705  -51.898  49.292  6
793970  101.718  -51.909  49.292  6
793971  101.733  -51.920  49.292  6
793972  101.746  -51.931  49.294  6
793973  101.760  -51.942  49.298  6
793974  101.773  -51.951  49.289  6
793975  101.787  -51.959  49.271  6
793976  101.802  -51.967  49.245  6
793977  101.817  -51.976  49.216  6
793978  101.834  -51.983  49.187  6
793979  101.854  -51.986  49.160  6
793980  101.875  -51.989  49.132  6
793981  101.889  -51.995  49.103  6
793982  101.916  -52.011  49.072  6
793983  101.944  -52.028  49.039  6
793984  101.973  -52.044  49.007  6
793985  102.001  -52.061  48.976  6
793986  102.030  -52.077  48.941  6
793987  102.058  -52.093  48.906  6
793988  102.087  -52.110  48.870  6
793989  102.115  -52.126  48.833  6
793990  102.144  -52.142  48.797  6
793991  102.173  -52.158  48.758  6
793992  102.201  -52.175  48.719  6
794620  100.793  -51.442  51.043  12
794621  100.815  -51.445  51.002  12
794622  100.836  -51.447  50.960  12
794623  100.857  -51.450  50.918  12
794624  100.878  -51.453  50.876  12
794625  100.899  -51.456  50.833  12
794626  100.920  -51.459  50.791  12
794627  100.941  -51.462  50.747  12
794628  100.963  -51.465  50.704  12
794629  100.984  -51.468  50.659  12
794630  101.004  -51.473  50.612  12
794631  101.022  -51.479  50.563  12
794632  101.041  -51.487  50.515  12
794633  101.059  -51.498  50.464  12
794634  101.077  -51.508  50.412  12
794635  101.096  -51.518  50.361  12
794636  101.114  -51.528  50.309  12
794637  101.132  -51.538  50.256  12
794638  101.150  -51.548  50.204  12
794639  101.169  -51.559  50.153  12
794658  101.506  -51.747  49.382  6
794659  101.525  -51.756  49.365  6
794660  101.544  -51.765  49.351  6
794661  101.563  -51.774  49.339  6
794662  101.582  -51.783  49.329  6
794663  101.601  -51.793  49.322  6
794664  101.622  -51.808  49.316  6
794665  101.643  -51.823  49.312  6
794666  101.665  -51.838  49.308  6
794667  101.679  -51.849  49.305  6
794668  101.691  -51.860  49.303  6
794669  101.703  -51.870  49.302  6
794670  101.715  -51.880  49.300  6
794671  101.728  -51.891  49.299  6
794672  101.742  -51.901  49.297  6
794673  101.755  -51.913  49.297  6
794674  101.769  -51.924  49.301  6
794675  101.783  -51.935  49.294  6
794676  101.796  -51.947  49.277  6
794677  101.810  -51.956  49.251  6
794678  101.825  -51.964  49.223  6
794679  101.844  -51.969  49.195  6
794680  101.864  -51.972  49.168  6
794681  101.885  -51.975  49.141  6
794682  101.903  -51.979  49.112  6
794683  101.924  -51.992  49.083  6
794684  101.953  -52.009  49.051  6
794685  101.981  -52.025  49.020  6
794686  102.010  -52.042  48.990  6
794687  102.038  -52.058  48.956  6
794688  102.067  -52.074  48.920  6
794689  102.096  -52.091  48.885  6
794690  102.124  -52.107  48.849  6
794691  102.153  -52.123  48.812  6
794692  102.181  -52.139  48.773  6
794693  102.210  -52.156  48.734  6
794694  102.238  -52.172  48.692  6
795321  100.806  -51.429  51.069  12
795322  100.828  -51.432  51.028  12
795323  100.849  -51.435  50.987  12
795324  100.870  -51.438  50.946  12
795325  100.891  -51.440  50.904  12
795326  100.912  -51.443  50.862  12
795327  100.933  -51.446  50.821  12
795328  100.955  -51.450  50.778  12
795329  100.976  -51.453  50.735  12
795330  100.997  -51.456  50.691  12
795331  101.018  -51.459  50.644  12
795332  101.037  -51.464  50.596  12
795333  101.056  -51.471  50.547  12
795334  101.074  -51.481  50.496  12
795335  101.092  -51.490  50.444  12
795336  101.111  -51.501  50.391  12
795337  101.129  -51.511  50.338  12
795338  101.147  -51.521  50.285  12
795339  101.165  -51.531  50.232  12
795358  101.503  -51.720  49.421  6
795359  101.522  -51.729  49.401  6
795360  101.541  -51.738  49.384  6
795361  101.560  -51.748  49.370  6
795362  101.579  -51.757  49.357  6
795363  101.598  -51.766  49.346  6
795364  101.618  -51.779  49.338  6
795365  101.639  -51.794  49.331  6
795366  101.660  -51.808  49.326  6
795367  101.677  -51.821  49.322  6
795368  101.689  -51.832  49.317  6
795369  101.701  -51.841  49.314  6
795370  101.713  -51.852  49.311  6
795371  101.726  -51.862  49.309  6
795372  101.738  -51.873  49.306  6
795373  101.751  -51.884  49.303  6
795374  101.765  -51.895  49.302  6
795375  101.778  -51.906  49.304  6
795376  101.793  -51.917  49.297  6
795377  101.806  -51.929  49.282  6
795378  101.820  -51.940  49.257  6
795379  101.834  -51.951  49.229  6
795380  101.854  -51.955  49.202  6
795381  101.874  -51.957  49.176  6
795382  101.895  -51.960  49.150  6
795383  101.915  -51.963  49.122  6
795384  101.933  -51.973  49.093  6
795385  101.962  -51.989  49.064  6
795386  101.990  -52.006  49.034  6
795387  102.019  -52.023  49.003  6
795388  102.047  -52.039  48.971  6
795389  102.076  -52.055  48.936  6
795390  102.104  -52.071  48.900  6
795391  102.133  -52.088  48.864  6
795392  102.161  -52.104  48.827  6
795393  102.190  -52.120  48.788  6
795394  102.219  -52.137  48.749  6
795395  102.247  -52.153  48.706  6
795396  102.275  -52.170  48.664  6
796021  100.798  -51.412  51.136  12
796022  100.819  -51.416  51.095  12
796023  100.840  -51.419  51.054  12
796024  100.861  -51.422  51.014  12
796025  100.883  -51.425  50.975  12
796026  100.904  -51.428  50.933  12
796027  100.925  -51.431  50.892  12
796028  100.947  -51.434  50.852  12
796029  100.968  -51.437  50.810  12
796030  100.989  -51.440  50.767  12
796031  101.010  -51.443  50.724  12
796032  101.031  -51.446  50.677  12
796033  101.052  -51.450  50.629  12
796034  101.070  -51.456  50.579  12
796035  101.089  -51.463  50.528  12
796036  101.107  -51.474  50.476  12
796037  101.125  -51.484  50.421  12
796038  101.144  -51.494  50.368  12
796039  101.162  -51.504  50.314  12
796040  101.180  -51.514  50.260  12
796041  101.199  -51.524  50.207  12
796057  101.488  -51.682  49.486  6
796058  101.502  -51.694  49.463  6
796059  101.519  -51.703  49.440  6
796060  101.538  -51.713  49.421  6
796061  101.557  -51.722  49.403  6
796062  101.575  -51.731  49.387  6
796063  101.595  -51.740  49.374  6
796064  101.614  -51.750  49.362  6
796065  101.635  -51.764  49.355  6
796066  101.656  -51.779  49.346  6
796067  101.676  -51.793  49.341  6
796068  101.687  -51.804  49.335  6
796069  101.699  -51.813  49.330  6
796070  101.711  -51.824  49.325  6
796071  101.724  -51.834  49.321  6
796072  101.736  -51.845  49.317  6
796073  101.748  -51.854  49.313  6
796074  101.760  -51.866  49.308  6
796075  101.774  -51.876  49.304  6
796076  101.788  -51.888  49.302  6
796077  101.802  -51.899  49.297  6
796078  101.815  -51.910  49.284  6
796079  101.829  -51.922  49.261  6
796080  101.846  -51.930  49.235  6
796081  101.865  -51.938  49.209  6
796082  101.884  -51.943  49.184  6
796083  101.905  -51.946  49.159  6
796084  101.925  -51.949  49.133  6
796085  101.942  -51.954  49.105  6
796086  101.970  -51.970  49.076  6
796087  101.998  -51.987  49.047  6
796088  102.027  -52.003  49.016  6
796089  102.056  -52.020  48.984  6
796090  102.084  -52.036  48.951  6
796091  102.113  -52.052  48.916  6
796092  102.141  -52.069  48.880  6
796093  102.170  -52.085  48.842  6
796094  102.198  -52.101  48.803  6
796095  102.227  -52.117  48.764  6
796096  102.256  -52.134  48.721  6
796097  102.284  -52.151  48.678  6
796098  102.313  -52.167  48.636  6
796722  100.819  -51.379  51.162  12
796723  100.834  -51.400  51.121  12
796724  100.853  -51.407  51.081  12
796725  100.875  -51.410  51.041  12
796726  100.896  -51.412  51.002  12
796727  100.917  -51.415  50.962  12
796728  100.938  -51.418  50.922  12
796729  100.960  -51.421  50.882  12
796730  100.981  -51.425  50.842  12
796731  101.002  -51.428  50.800  12
796732  101.023  -51.431  50.757  12
796733  101.044  -51.433  50.712  12
796734  101.065  -51.436  50.663  12
796735  101.086  -51.440  50.612  12
796736  101.104  -51.447  50.561  12
796737  101.122  -51.456  50.508  12
796738  101.140  -51.466  50.453  12
796739  101.159  -51.477  50.399  12
796740  101.177  -51.487  50.344  12
796741  101.195  -51.497  50.289  12
796757  101.489  -51.654  49.534  6
796758  101.503  -51.666  49.507  6
796759  101.518  -51.676  49.482  6
796760  101.535  -51.686  49.460  6
796761  101.554  -51.695  49.440  6
796762  101.572  -51.705  49.422  6
796763  101.592  -51.714  49.405  6
796764  101.611  -51.723  49.392  6
796765  101.631  -51.735  49.380  6
796766  101.652  -51.750  49.371  6
796767  101.673  -51.765  49.362  6
796768  101.686  -51.776  49.355  6
796769  101.698  -51.786  49.349  6
796770  101.709  -51.796  49.342  6
796771  101.722  -51.807  49.337  6
796772  101.734  -51.816  49.332  6
796773  101.746  -51.827  49.326  6
796774  101.758  -51.837  49.321  6
796775  101.770  -51.848  49.314  6
796776  101.783  -51.858  49.308  6
796777  101.797  -51.870  49.303  6
796778  101.811  -51.881  49.300  6
796779  101.825  -51.892  49.288  6
796780  101.840  -51.902  49.267  6
796781  101.859  -51.910  49.241  6
796782  101.877  -51.917  49.216  6
796783  101.896  -51.926  49.192  6
796784  101.915  -51.932  49.168  6
796785  101.936  -51.935  49.143  6
796786  101.956  -51.938  49.115  6
796787  101.979  -51.951  49.089  6
796788  102.007  -51.968  49.061  6
796789  102.036  -51.984  49.031  6
796790  102.064  -52.001  48.999  6
796791  102.093  -52.017  48.966  6
796792  102.121  -52.033  48.931  6
796793  102.150  -52.049  48.895  6
796794  102.179  -52.066  48.858  6
796795  102.207  -52.083  48.819  6
796796  102.236  -52.098  48.779  6
796797  102.263  -52.114  48.737  6
796798  102.290  -52.130  48.693  6
796799  102.318  -52.144  48.650  6
796800  102.344  -52.159  48.607  6
797423  100.838  -51.346  51.187  12
797424  100.853  -51.368  51.146  12
797425  100.868  -51.389  51.107  12
797426  100.888  -51.397  51.069  12
797427  100.909  -51.400  51.030  12
797428  100.930  -51.403  50.991  12
797429  100.951  -51.406  50.952  12
797430  100.972  -51.409  50.913  12
797431  100.994  -51.412  50.873  12
797432  101.015  -51.415  50.833  12
797433  101.036  -51.418  50.793  12
797434  101.057  -51.421  50.748  12
797435  101.078  -51.424  50.697  12
797436  101.100  -51.426  50.645  12
797437  101.119  -51.432  50.593  12
797438  101.137  -51.439  50.539  12
797439  101.156  -51.450  50.484  12
797440  101.174  -51.459  50.429  12
797441  101.192  -51.469  50.373  12
797442  101.210  -51.480  50.318  12
797456  101.476  -51.616  49.617  6
797457  101.491  -51.626  49.585  6
797458  101.505  -51.638  49.555  6
797459  101.519  -51.648  49.527  6
797460  101.534  -51.660  49.502  6
797461  101.550  -51.669  49.480  6
797462  101.569  -51.678  49.459  6
797463  101.589  -51.688  49.441  6
797464  101.607  -51.697  49.424  6
797465  101.626  -51.707  49.410  6
797466  101.647  -51.721  49.398  6
797467  101.669  -51.736  49.388  6
797468  101.684  -51.747  49.379  6
797469  101.696  -51.758  49.370  6
797470  101.708  -51.768  49.363  6
797471  101.720  -51.779  49.355  6
797472  101.732  -51.788  49.348  6
797473  101.744  -51.799  49.342  6
797474  101.756  -51.809  49.336  6
797475  101.768  -51.819  49.329  6
797476  101.780  -51.829  49.321  6
797477  101.793  -51.840  49.313  6
797478  101.807  -51.851  49.307  6
797479  101.820  -51.863  49.304  6
797480  101.834  -51.874  49.294  6
797481  101.853  -51.882  49.273  6
797482  101.871  -51.889  49.248  6
797483  101.890  -51.898  49.223  6
797484  101.908  -51.905  49.200  6
797485  101.927  -51.913  49.177  6
797486  101.946  -51.920  49.152  6
797487  101.966  -51.923  49.126  6
797488  101.987  -51.932  49.104  6
797489  102.016  -51.948  49.076  6
797490  102.044  -51.965  49.046  6
797491  102.073  -51.982  49.015  6
797492  102.102  -51.998  48.982  6
797493  102.130  -52.014  48.947  6
797494  102.159  -52.030  48.911  6
797495  102.186  -52.045  48.875  6
797496  102.213  -52.061  48.835  6
797497  102.240  -52.076  48.795  6
797498  102.267  -52.090  48.751  6
797499  102.294  -52.105  48.708  6
797500  102.321  -52.120  48.665  6
797501  102.348  -52.135  48.621  6
797502  102.375  -52.150  48.578  6
798124  100.858  -51.313  51.211  12
798125  100.873  -51.334  51.172  12
798126  100.888  -51.356  51.134  12
798127  100.903  -51.377  51.095  12
798128  100.922  -51.387  51.057  12
798129  100.943  -51.390  51.019  12
798130  100.964  -51.393  50.980  12
798131  100.985  -51.396  50.942  12
798132  101.006  -51.399  50.904  12
798133  101.028  -51.402  50.868  12
798134  101.049  -51.405  50.830  12
798135  101.070  -51.408  50.785  12
798136  101.092  -51.411  50.733  12
798137  101.113  -51.414  50.678  12
798138  101.133  -51.417  50.624  12
798139  101.152  -51.424  50.571  12
798140  101.171  -51.432  50.515  12
798141  101.189  -51.442  50.459  12
798142  101.207  -51.453  50.402  12
798143  101.226  -51.462  50.346  12
798144  101.244  -51.472  50.292  12
798155  101.445  -51.584  49.709  6
798156  101.466  -51.592  49.672  6
798157  101.488  -51.600  49.637  6
798158  101.507  -51.609  49.605  6
798159  101.522  -51.620  49.575  6
798160  101.536  -51.631  49.547  6
798161  101.550  -51.642  49.521  6
798162  101.566  -51.652  49.499  6
798163  101.585  -51.662  49.479  6
798164  101.604  -51.671  49.461  6
798165  101.623  -51.680  49.444  6
798166  101.643  -51.692  49.429  6
798167  101.664  -51.707  49.416  6
798168  101.682  -51.719  49.405  6
798169  101.694  -51.730  49.395  6
798170  101.706  -51.740  49.386  6
798171  101.718  -51.750  49.378  6
798172  101.730  -51.760  49.369  6
798173  101.742  -51.771  49.361  6
798174  101.754  -51.781  49.353  6
798175  101.766  -51.791  49.345  6
798176  101.778  -51.801  49.337  6
798177  101.790  -51.812  49.328  6
798178  101.802  -51.822  49.318  6
798179  101.816  -51.833  49.313  6
798180  101.830  -51.845  49.308  6
798181  101.846  -51.854  49.299  6
798182  101.865  -51.861  49.281  6
798183  101.884  -51.869  49.257  6
798184  101.902  -51.877  49.232  6
798185  101.921  -51.885  49.209  6
798186  101.940  -51.892  49.185  6
798187  101.958  -51.900  49.162  6
798188  101.976  -51.908  49.140  6
798189  101.996  -51.913  49.121  6
798190  102.025  -51.929  49.093  6
798191  102.053  -51.946  49.061  6
798192  102.082  -51.962  49.029  6
798193  102.108  -51.977  48.996  6
798194  102.135  -51.992  48.962  6
798195  102.163  -52.007  48.926  6
798196  102.189  -52.022  48.889  6
798197  102.217  -52.036  48.850  6
798198  102.244  -52.051  48.809  6
798199  102.270  -52.067  48.767  6
798200  102.298  -52.081  48.722  6
798201  102.325  -52.096  48.679  6
798202  102.351  -52.111  48.636  6
798203  102.379  -52.126  48.592  6
798825  100.878  -51.280  51.235  12
798826  100.893  -51.301  51.195  12
798827  100.908  -51.322  51.157  12
798828  100.923  -51.344  51.119  12
798829  100.938  -51.365  51.082  12
798830  100.956  -51.378  51.044  12
798831  100.977  -51.381  51.006  12
798832  100.998  -51.384  50.969  12
798833  101.019  -51.387  50.933  12
798834  101.041  -51.390  50.901  12
798835  101.062  -51.393  50.864  12
798836  101.083  -51.396  50.818  12
798837  101.105  -51.398  50.765  12
798838  101.126  -51.401  50.709  12
798839  101.147  -51.404  50.655  12
798840  101.167  -51.409  50.600  12
798841  101.185  -51.415  50.544  12
798842  101.204  -51.425  50.488  12
798843  101.222  -51.435  50.430  12
798844  101.240  -51.445  50.374  12
798845  101.259  -51.455  50.318  12
798855  101.442  -51.556  49.769  6
798856  101.460  -51.566  49.729  6
798857  101.478  -51.576  49.692  6
798858  101.500  -51.584  49.658  6
798859  101.522  -51.593  49.625  6
798860  101.537  -51.603  49.594  6
798861  101.551  -51.614  49.567  6
798862  101.565  -51.625  49.541  6
798863  101.582  -51.635  49.518  6
798864  101.601  -51.644  49.498  6
798865  101.620  -51.653  49.480  6
798866  101.639  -51.663  49.463  6
798867  101.660  -51.678  49.448  6
798868  101.680  -51.691  49.435  6
798869  101.692  -51.702  49.423  6
798870  101.704  -51.712  49.412  6
798871  101.716  -51.722  49.402  6
798872  101.728  -51.732  49.393  6
798873  101.740  -51.743  49.383  6
798874  101.752  -51.753  49.374  6
798875  101.764  -51.763  49.365  6
798876  101.776  -51.773  49.355  6
798877  101.788  -51.784  49.345  6
798878  101.800  -51.794  49.336  6
798879  101.812  -51.804  49.325  6
798880  101.825  -51.815  49.319  6
798881  101.840  -51.826  49.313  6
798882  101.859  -51.833  49.304  6
798883  101.878  -51.841  49.288  6
798884  101.896  -51.849  49.265  6
798885  101.915  -51.857  49.241  6
798886  101.933  -51.864  49.217  6
798887  101.952  -51.872  49.193  6
798888  101.970  -51.880  49.170  6
798889  101.988  -51.888  49.150  6
798890  102.006  -51.899  49.132  6
798891  102.031  -51.910  49.107  6
798892  102.058  -51.925  49.075  6
798893  102.085  -51.939  49.043  6
798894  102.112  -51.954  49.011  6
798895  102.139  -51.968  48.977  6
798896  102.166  -51.982  48.941  6
798897  102.193  -51.998  48.904  6
798898  102.220  -52.013  48.865  6
798899  102.247  -52.027  48.823  6
798900  102.274  -52.042  48.783  6
798901  102.301  -52.058  48.737  6
798902  102.328  -52.072  48.694  6
798903  102.355  -52.087  48.650  6
798904  102.382  -52.102  48.606  6
799526  100.898  -51.247  51.257  12
799527  100.913  -51.268  51.217  12
799528  100.928  -51.290  51.179  12
799529  100.943  -51.311  51.142  12
799530  100.958  -51.332  51.105  12
799531  100.973  -51.353  51.067  12
799532  100.990  -51.368  51.031  12
799533  101.011  -51.371  50.994  12
799534  101.033  -51.374  50.960  12
799535  101.054  -51.377  50.929  12
799536  101.075  -51.380  50.892  12
799537  101.096  -51.383  50.845  12
799538  101.117  -51.386  50.793  12
799539  101.138  -51.389  50.738  12
799540  101.160  -51.392  50.684  12
799541  101.181  -51.394  50.628  12
799542  101.200  -51.400  50.573  12
799543  101.218  -51.408  50.516  12
799544  101.237  -51.418  50.458  12
799545  101.255  -51.428  50.401  12
799546  101.273  -51.438  50.345  12
799555  101.438  -51.529  49.831  6
799556  101.457  -51.539  49.789  6
799557  101.475  -51.549  49.749  6
799558  101.493  -51.559  49.712  6
799559  101.512  -51.569  49.678  6
799560  101.534  -51.577  49.645  6
799561  101.553  -51.586  49.614  6
799562  101.567  -51.597  49.587  6
799563  101.582  -51.608  49.561  6
799564  101.598  -51.619  49.538  6
799565  101.617  -51.628  49.518  6
799566  101.636  -51.637  49.500  6
799567  101.656  -51.648  49.483  6
799568  101.677  -51.663  49.468  6
799569  101.690  -51.674  49.454  6
799570  101.702  -51.685  49.442  6
799571  101.714  -51.694  49.430  6
799572  101.726  -51.705  49.419  6
799573  101.738  -51.715  49.408  6
799574  101.750  -51.725  49.397  6
799575  101.762  -51.735  49.387  6
799576  101.774  -51.745  49.376  6
799577  101.786  -51.756  49.365  6
799578  101.798  -51.766  49.354  6
799579  101.810  -51.776  49.344  6
799580  101.822  -51.786  49.333  6
799581  101.835  -51.797  49.326  6
799582  101.853  -51.805  49.319  6
799583  101.872  -51.813  49.309  6
799584  101.889  -51.823  49.294  6
799585  101.906  -51.834  49.273  6
799586  101.924  -51.844  49.250  6
799587  101.941  -51.854  49.226  6
799588  101.959  -51.865  49.201  6
799589  101.976  -51.875  49.178  6
799590  101.993  -51.885  49.157  6
799591  102.013  -51.885  49.139  6
799592  102.034  -51.896  49.118  6
799593  102.061  -51.910  49.087  6
799594  102.088  -51.925  49.056  6
799595  102.115  -51.939  49.025  6
799596  102.142  -51.954  48.992  6
799597  102.169  -51.969  48.956  6
799598  102.196  -51.983  48.918  6
799599  102.223  -51.998  48.879  6
799600  102.250  -52.012  48.838  6
799601  102.277  -52.026  48.797  6
799602  102.305  -52.042  48.751  6
799603  102.331  -52.056  48.709  6
799604  102.359  -52.070  48.665  6
799605  102.386  -52.085  48.620  6
799606  102.412  -52.099  48.575  6
800227  100.918  -51.214  51.278  12
800228  100.933  -51.235  51.239  12
800229  100.948  -51.256  51.200  12
800230  100.963  -51.277  51.163  12
800231  100.978  -51.299  51.126  12
800232  100.993  -51.321  51.089  12
800233  101.008  -51.342  51.053  12
800234  101.025  -51.359  51.017  12
800235  101.046  -51.362  50.983  12
800236  101.067  -51.365  50.950  12
800237  101.088  -51.367  50.912  12
800238  101.109  -51.370  50.866  12
800239  101.130  -51.373  50.817  12
800240  101.151  -51.376  50.764  12
800241  101.173  -51.379  50.710  12
800242  101.194  -51.382  50.655  12
800243  101.215  -51.385  50.600  12
800244  101.234  -51.392  50.543  12
800245  101.252  -51.400  50.485  12
800246  101.270  -51.411  50.428  12
800247  101.288  -51.421  50.371  12
800255  101.435  -51.502  49.896  6
800256  101.453  -51.512  49.852  6
800257  101.471  -51.522  49.811  6
800258  101.490  -51.532  49.771  6
800259  101.508  -51.542  49.733  6
800260  101.526  -51.552  49.698  6
800261  101.546  -51.562  49.666  6
800262  101.568  -51.569  49.636  6
800263  101.584  -51.580  49.607  6
800264  101.598  -51.591  49.582  6
800265  101.614  -51.601  49.560  6
800266  101.633  -51.610  49.540  6
800267  101.652  -51.619  49.521  6
800268  101.673  -51.634  49.504  6
800269  101.688  -51.646  49.489  6
800270  101.700  -51.656  49.475  6
800271  101.712  -51.666  49.462  6
800272  101.724  -51.677  49.449  6
800273  101.736  -51.687  49.436  6
800274  101.748  -51.697  49.424  6
800275  101.760  -51.707  49.411  6
800276  101.772  -51.718  49.400  6
800277  101.784  -51.728  49.388  6
800278  101.796  -51.738  49.377  6
800279  101.808  -51.748  49.365  6
800280  101.820  -51.760  49.352  6
800281  101.831  -51.774  49.342  6
800282  101.844  -51.788  49.335  6
800283  101.859  -51.800  49.325  6
800284  101.877  -51.810  49.314  6
800285  101.894  -51.820  49.300  6
800286  101.911  -51.831  49.282  6
800287  101.929  -51.841  49.260  6
800288  101.946  -51.851  49.235  6
800289  101.964  -51.862  49.209  6
800290  101.981  -51.872  49.185  6
800291  101.998  -51.882  49.163  6
800292  102.022  -51.870  49.144  6
800293  102.037  -51.882  49.123  6
800294  102.064  -51.896  49.096  6
800295  102.092  -51.911  49.066  6
800296  102.118  -51.926  49.036  6
800297  102.146  -51.940  49.004  6
800298  102.173  -51.954  48.968  6
800299  102.199  -51.969  48.931  6
800300  102.227  -51.983  48.892  6
800301  102.254  -51.998  48.852  6
800302  102.280  -52.013  48.810  6
800303  102.308  -52.027  48.765  6
800304  102.335  -52.042  48.722  6
800305  102.362  -52.056  48.678  6
800306  102.389  -52.070  48.634  6
800307  102.416  -52.086  48.590  6
800928  100.937  -51.181  51.298  12
800929  100.953  -51.202  51.258  12
800930  100.968  -51.224  51.220  12
800931  100.983  -51.245  51.183  12
800932  100.998  -51.266  51.147  12
800933  101.013  -51.287  51.109  12
800934  101.028  -51.309  51.074  12
800935  101.043  -51.330  51.038  12
800936  101.059  -51.349  51.003  12
800937  101.080  -51.352  50.967  12
800938  101.101  -51.355  50.928  12
800939  101.122  -51.358  50.884  12
800940  101.143  -51.361  50.836  12
800941  101.165  -51.363  50.786  12
800942  101.186  -51.366  50.734  12
800943  101.207  -51.369  50.680  12
800944  101.228  -51.372  50.625  12
800945  101.248  -51.377  50.568  12
800946  101.267  -51.384  50.511  12
800947  101.285  -51.393  50.454  12
800948  101.304  -51.403  50.396  12
800955  101.431  -51.475  49.964  6
800956  101.450  -51.484  49.917  6
800957  101.468  -51.494  49.873  6
800958  101.486  -51.505  49.832  6
800959  101.504  -51.515  49.792  6
800960  101.523  -51.525  49.754  6
800961  101.541  -51.534  49.719  6
800962  101.559  -51.545  49.687  6
800963  101.580  -51.554  49.657  6
800964  101.599  -51.563  49.629  6
800965  101.613  -51.574  49.605  6
800966  101.629  -51.584  49.582  6
800967  101.649  -51.594  49.562  6
800968  101.668  -51.605  49.544  6
800969  101.686  -51.618  49.527  6
800970  101.698  -51.628  49.512  6
800971  101.710  -51.638  49.497  6
800972  101.722  -51.649  49.483  6
800973  101.734  -51.659  49.470  6
800974  101.746  -51.669  49.454  6
800975  101.758  -51.679  49.440  6
800976  101.770  -51.690  49.426  6
800977  101.782  -51.700  49.413  6
800978  101.794  -51.712  49.401  6
800979  101.806  -51.725  49.388  6
800980  101.817  -51.740  49.375  6
800981  101.828  -51.754  49.362  6
800982  101.839  -51.769  49.351  6
800983  101.852  -51.782  49.343  6
800984  101.867  -51.794  49.331  6
800985  101.882  -51.807  49.319  6
800986  101.899  -51.817  49.305  6
800987  101.916  -51.828  49.288  6
800988  101.934  -51.838  49.266  6
800989  101.952  -51.848  49.242  6
800990  101.969  -51.858  49.215  6
800991  101.986  -51.869  49.191  6
800992  102.004  -51.875  49.168  6
800993  102.030  -51.854  49.148  6
800994  102.041  -51.868  49.127  6
800995  102.067  -51.882  49.102  6
800996  102.095  -51.897  49.073  6
800997  102.122  -51.911  49.045  6
800998  102.149  -51.926  49.013  6
800999  102.176  -51.940  48.978  6
801000  102.203  -51.955  48.942  6
801001  102.230  -51.970  48.904  6
801002  102.257  -51.984  48.864  6
801003  102.284  -51.998  48.822  6
801004  102.311  -52.013  48.779  6
801005  102.338  -52.027  48.735  6
801006  102.365  -52.042  48.692  6
801007  102.392  -52.057  48.648  6
801008  102.419  -52.071  48.604  6
801629  100.957  -51.148  51.316  12
801630  100.972  -51.169  51.277  12
801631  100.987  -51.190  51.239  12
801632  101.002  -51.211  51.202  12
801633  101.018  -51.233  51.166  12
801634  101.033  -51.254  51.129  12
801635  101.048  -51.275  51.093  12
801636  101.063  -51.297  51.057  12
801637  101.078  -51.318  51.021  12
801638  101.093  -51.339  50.984  12
801639  101.114  -51.342  50.944  12
801640  101.135  -51.345  50.902  12
801641  101.156  -51.348  50.856  12
801642  101.178  -51.351  50.807  12
801643  101.199  -51.354  50.756  12
801644  101.220  -51.357  50.703  12
801645  101.241  -51.359  50.648  12
801646  101.262  -51.362  50.592  12
801647  101.282  -51.368  50.535  12
801648  101.300  -51.376  50.478  12
801649  101.318  -51.387  50.421  12
801654  101.410  -51.437  50.086  6
801655  101.428  -51.447  50.035  6
801656  101.447  -51.457  49.986  6
801657  101.465  -51.467  49.939  6
801658  101.483  -51.477  49.895  6
801659  101.501  -51.487  49.853  6
801660  101.519  -51.497  49.813  6
801661  101.538  -51.507  49.776  6
801662  101.556  -51.518  49.741  6
801663  101.574  -51.528  49.709  6
801664  101.593  -51.537  49.679  6
801665  101.614  -51.547  49.653  6
801666  101.629  -51.557  49.628  6
801667  101.645  -51.567  49.605  6
801668  101.664  -51.576  49.585  6
801669  101.684  -51.590  49.567  6
801670  101.696  -51.600  49.550  6
801671  101.708  -51.610  49.534  6
801672  101.720  -51.621  49.519  6
801673  101.732  -51.631  49.505  6
801674  101.744  -51.641  49.491  6
801675  101.756  -51.651  49.473  6
801676  101.768  -51.663  49.457  6
801677  101.779  -51.678  49.441  6
801678  101.790  -51.692  49.426  6
801679  101.802  -51.707  49.413  6
801680  101.813  -51.720  49.400  6
801681  101.825  -51.735  49.385  6
801682  101.836  -51.749  49.372  6
801683  101.847  -51.763  49.360  6
801684  101.861  -51.776  49.351  6
801685  101.875  -51.789  49.338  6
801686  101.889  -51.802  49.324  6
801687  101.904  -51.814  49.309  6
801688  101.921  -51.824  49.291  6
801689  101.939  -51.835  49.271  6
801690  101.957  -51.845  49.246  6
801691  101.974  -51.855  49.220  6
801692  101.991  -51.866  49.196  6
801693  102.013  -51.859  49.173  6
801694  102.038  -51.838  49.151  6
801695  102.063  -51.816  49.129  6
801696  102.071  -51.868  49.106  6
801697  102.098  -51.882  49.079  6
801698  102.125  -51.897  49.050  6
801699  102.152  -51.912  49.019  6
801700  102.179  -51.926  48.985  6
801701  102.206  -51.941  48.950  6
801702  102.233  -51.955  48.913  6
801703  102.260  -51.970  48.874  6
801704  102.287  -51.984  48.833  6
801705  102.314  -51.999  48.791  6
801706  102.341  -52.014  48.748  6
801707  102.368  -52.028  48.705  6
801708  102.395  -52.042  48.661  6
802331  100.992  -51.136  51.294  12
802332  101.007  -51.158  51.256  12
802333  101.022  -51.179  51.220  12
802334  101.037  -51.200  51.183  12
802335  101.052  -51.221  51.147  12
802336  101.067  -51.243  51.111  12
802337  101.082  -51.264  51.075  12
802338  101.098  -51.285  51.039  12
802339  101.113  -51.306  51.001  12
802340  101.128  -51.327  50.961  12
802341  101.148  -51.333  50.919  12
802342  101.170  -51.335  50.875  12
802343  101.191  -51.338  50.827  12
802344  101.212  -51.341  50.777  12
802345  101.233  -51.344  50.725  12
802346  101.254  -51.347  50.671  12
802347  101.275  -51.350  50.615  12
802348  101.296  -51.353  50.558  12
802349  101.315  -51.359  50.501  12
802355  101.425  -51.420  50.109  6
802356  101.443  -51.430  50.057  6
802357  101.461  -51.440  50.008  6
802358  101.480  -51.450  49.963  6
802359  101.498  -51.460  49.918  6
802360  101.516  -51.470  49.875  6
802361  101.535  -51.480  49.835  6
802362  101.553  -51.490  49.798  6
802363  101.571  -51.500  49.764  6
802364  101.590  -51.510  49.732  6
802365  101.608  -51.521  49.703  6
802366  101.626  -51.531  49.677  6
802367  101.645  -51.540  49.652  6
802368  101.661  -51.550  49.629  6
802369  101.681  -51.562  49.608  6
802370  101.694  -51.572  49.590  6
802371  101.706  -51.582  49.573  6
802372  101.718  -51.593  49.557  6
802373  101.730  -51.603  49.542  6
802374  101.742  -51.615  49.527  6
802375  101.753  -51.629  49.511  6
802376  101.765  -51.644  49.492  6
802377  101.776  -51.658  49.475  6
802378  101.787  -51.672  49.457  6
802379  101.799  -51.687  49.441  6
802380  101.810  -51.701  49.426  6
802381  101.821  -51.715  49.411  6
802382  101.833  -51.729  49.396  6
802383  101.844  -51.744  49.382  6
802384  101.855  -51.758  49.368  6
802385  101.870  -51.771  49.358  6
802386  101.884  -51.783  49.344  6
802387  101.898  -51.796  49.327  6
802388  101.912  -51.809  49.311  6
802389  101.927  -51.821  49.294  6
802390  101.944  -51.832  49.274  6
802391  101.962  -51.841  49.250  6
802392  101.979  -51.852  49.225  6
802393  101.996  -51.863  49.200  6
802394  102.021  -51.843  49.177  6
802395  102.046  -51.822  49.153  6
802396  102.071  -51.801  49.130  6
802397  102.074  -51.854  49.106  6
802398  102.101  -51.869  49.081  6
802399  102.128  -51.883  49.053  6
802400  102.155  -51.898  49.022  6
802401  102.182  -51.912  48.990  6
802402  102.209  -51.926  48.956  6
802403  102.236  -51.941  48.920  6
802404  102.263  -51.956  48.883  6
802405  102.290  -51.970  48.842  6
802406  102.317  -51.985  48.800  6
802407  102.344  -51.999  48.759  6
802408  102.372  -52.014  48.717  6
802409  102.398  -52.028  48.673  6
803032  101.012  -51.103  51.310  12
803033  101.027  -51.124  51.273  12
803034  101.042  -51.146  51.236  12
803035  101.057  -51.167  51.200  12
803036  101.072  -51.188  51.162  12
803037  101.088  -51.209  51.127  12
803038  101.103  -51.230  51.090  12
803039  101.117  -51.252  51.054  12
803040  101.132  -51.274  51.016  12
803041  101.147  -51.295  50.976  12
803042  101.162  -51.316  50.935  12
803043  101.183  -51.323  50.891  12
803044  101.204  -51.326  50.844  12
803045  101.225  -51.328  50.796  12
803046  101.246  -51.331  50.745  12
803047  101.267  -51.334  50.691  12
803048  101.288  -51.337  50.637  12
803049  101.310  -51.340  50.580  12
803050  101.330  -51.344  50.524  12
803055  101.421  -51.392  50.186  6
803056  101.440  -51.403  50.133  6
803057  101.458  -51.412  50.082  6
803058  101.476  -51.422  50.032  6
803059  101.494  -51.433  49.985  6
803060  101.513  -51.443  49.941  6
803061  101.531  -51.453  49.899  6
803062  101.549  -51.463  49.859  6
803063  101.568  -51.473  49.823  6
803064  101.586  -51.483  49.788  6
803065  101.604  -51.494  49.757  6
803066  101.623  -51.503  49.728  6
803067  101.641  -51.513  49.701  6
803068  101.659  -51.524  49.677  6
803069  101.677  -51.533  49.654  6
803070  101.692  -51.544  49.634  6
803071  101.704  -51.555  49.615  6
803072  101.716  -51.567  49.598  6
803073  101.727  -51.581  49.581  6
803074  101.739  -51.595  49.564  6
803075  101.750  -51.609  49.548  6
803076  101.761  -51.624  49.530  6
803077  101.773  -51.638  49.511  6
803078  101.784  -51.653  49.493  6
803079  101.796  -51.667  49.473  6
803080  101.807  -51.682  49.456  6
803081  101.818  -51.696  49.439  6
803082  101.829  -51.710  49.423  6
803083  101.841  -51.724  49.408  6
803084  101.852  -51.738  49.392  6
803085  101.864  -51.752  49.377  6
803086  101.878  -51.765  49.366  6
803087  101.893  -51.778  49.351  6
803088  101.907  -51.791  49.332  6
803089  101.921  -51.803  49.315  6
803090  101.935  -51.816  49.296  6
803091  101.949  -51.829  49.276  6
803092  101.967  -51.838  49.253  6
803093  101.984  -51.849  49.227  6
803094  102.004  -51.848  49.202  6
803095  102.029  -51.827  49.179  6
803096  102.054  -51.806  49.154  6
803097  102.079  -51.785  49.131  6
803098  102.078  -51.840  49.108  6
803099  102.104  -51.854  49.082  6
803100  102.131  -51.869  49.055  6
803101  102.159  -51.883  49.025  6
803102  102.185  -51.898  48.994  6
803103  102.212  -51.913  48.961  6
803104  102.240  -51.927  48.926  6
803105  102.266  -51.942  48.890  6
803106  102.293  -51.956  48.850  6
803107  102.321  -51.970  48.809  6
803108  102.348  -51.985  48.769  6
803109  102.375  -52.000  48.728  6
803110  102.402  -52.014  48.685  6
803734  101.047  -51.092  51.287  12
803735  101.062  -51.113  51.251  12
803736  101.077  -51.134  51.215  12
803737  101.092  -51.155  51.177  12
803738  101.107  -51.177  51.141  12
803739  101.122  -51.198  51.105  12
803740  101.137  -51.219  51.068  12
803741  101.152  -51.240  51.031  12
803742  101.168  -51.262  50.991  12
803743  101.183  -51.283  50.950  12
803744  101.197  -51.304  50.907  12
803745  101.216  -51.313  50.861  12
803746  101.238  -51.316  50.814  12
803747  101.259  -51.319  50.764  12
803748  101.280  -51.322  50.712  12
803749  101.302  -51.324  50.658  12
803750  101.323  -51.327  50.602  12
803751  101.344  -51.331  50.546  12
803755  101.418  -51.365  50.265  6
803756  101.437  -51.375  50.209  6
803757  101.455  -51.385  50.157  6
803758  101.473  -51.395  50.105  6
803759  101.491  -51.406  50.055  6
803760  101.510  -51.415  50.009  6
803761  101.528  -51.425  49.964  6
803762  101.546  -51.436  49.923  6
803763  101.564  -51.446  49.884  6
803764  101.583  -51.456  49.847  6
803765  101.601  -51.466  49.813  6
803766  101.619  -51.476  49.783  6
803767  101.637  -51.486  49.754  6
803768  101.656  -51.497  49.727  6
803769  101.674  -51.506  49.703  6
803770  101.690  -51.518  49.680  6
803771  101.701  -51.531  49.659  6
803772  101.712  -51.545  49.640  6
803773  101.724  -51.559  49.622  6
803774  101.735  -51.572  49.604  6
803775  101.746  -51.587  49.586  6
803776  101.757  -51.600  49.568  6
803777  101.768  -51.614  49.548  6
803778  101.779  -51.628  49.530  6
803779  101.790  -51.642  49.511  6
803780  101.802  -51.656  49.489  6
803781  101.813  -51.669  49.471  6
803782  101.824  -51.683  49.453  6
803783  101.836  -51.697  49.436  6
803784  101.847  -51.711  49.419  6
803785  101.858  -51.725  49.403  6
803786  101.872  -51.735  49.387  6
803787  101.886  -51.748  49.373  6
803788  101.901  -51.766  49.358  6
803789  101.915  -51.783  49.337  6
803790  101.929  -51.797  49.319  6
803791  101.944  -51.810  49.298  6
803792  101.958  -51.823  49.277  6
803793  101.972  -51.835  49.254  6
803794  101.989  -51.846  49.229  6
803795  102.013  -51.832  49.204  6
803796  102.037  -51.811  49.180  6
803797  102.062  -51.790  49.155  6
803798  102.087  -51.769  49.132  6
803799  102.081  -51.826  49.109  6
803800  102.108  -51.840  49.083  6
803801  102.135  -51.854  49.056  6
803802  102.162  -51.870  49.027  6
803803  102.189  -51.884  48.996  6
803804  102.216  -51.898  48.965  6
803805  102.243  -51.913  48.931  6
803806  102.270  -51.927  48.897  6
803807  102.297  -51.942  48.858  6
803808  102.324  -51.957  48.819  6
803809  102.351  -51.971  48.779  6
803810  102.378  -51.986  48.738  6
804435  101.054  -51.065  51.300  12
804436  101.080  -51.080  51.264  12
804437  101.097  -51.101  51.228  12
804438  101.112  -51.122  51.191  12
804439  101.127  -51.143  51.154  12
804440  101.142  -51.164  51.117  12
804441  101.157  -51.186  51.080  12
804442  101.172  -51.207  51.044  12
804443  101.187  -51.228  51.005  12
804444  101.202  -51.250  50.964  12
804445  101.217  -51.271  50.922  12
804446  101.233  -51.293  50.878  12
804447  101.251  -51.303  50.831  12
804448  101.272  -51.306  50.783  12
804449  101.293  -51.309  50.732  12
804450  101.315  -51.312  50.678  12
804451  101.336  -51.315  50.623  12
804456  101.433  -51.348  50.287  6
804457  101.452  -51.358  50.233  6
804458  101.470  -51.368  50.180  6
804459  101.488  -51.378  50.128  6
804460  101.506  -51.388  50.079  6
804461  101.525  -51.398  50.032  6
804462  101.543  -51.409  49.988  6
804463  101.561  -51.418  49.947  6
804464  101.580  -51.428  49.909  6
804465  101.598  -51.439  49.873  6
804466  101.616  -51.449  49.840  6
804467  101.634  -51.459  49.809  6
804468  101.653  -51.469  49.781  6
804469  101.671  -51.479  49.755  6
804470  101.689  -51.489  49.730  6
804471  101.699  -51.506  49.708  6
804472  101.709  -51.518  49.685  6
804473  101.720  -51.530  49.664  6
804474  101.730  -51.542  49.645  6
804475  101.740  -51.553  49.626  6
804476  101.751  -51.567  49.606  6
804477  101.762  -51.581  49.587  6
804478  101.773  -51.594  49.567  6
804479  101.784  -51.609  49.548  6
804480  101.796  -51.622  49.528  6
804481  101.807  -51.636  49.506  6
804482  101.818  -51.650  49.486  6
804483  101.829  -51.663  49.468  6
804484  101.840  -51.678  49.449  6
804485  101.851  -51.691  49.431  6
804486  101.863  -51.705  49.413  6
804487  101.878  -51.713  49.396  6
804488  101.893  -51.720  49.382  6
804489  101.908  -51.732  49.366  6
804490  101.922  -51.750  49.344  6
804491  101.937  -51.767  49.322  6
804492  101.952  -51.784  49.300  6
804493  101.966  -51.801  49.277  6
804494  101.980  -51.819  49.254  6
804495  101.995  -51.835  49.231  6
804496  102.021  -51.816  49.206  6
804497  102.045  -51.795  49.182  6
804498  102.070  -51.774  49.157  6
804499  102.095  -51.753  49.134  6
804500  102.109  -51.760  49.110  6
804501  102.111  -51.826  49.085  6
804502  102.138  -51.841  49.058  6
804503  102.165  -51.855  49.029  6
804504  102.192  -51.870  49.000  6
804505  102.219  -51.884  48.969  6
804506  102.246  -51.898  48.936  6
804507  102.273  -51.913  48.901  6
804508  102.300  -51.928  48.865  6
804509  102.327  -51.942  48.826  6
804510  102.354  -51.957  48.788  6
804511  102.381  -51.971  48.749  6
805137  101.080  -51.058  51.275  12
805138  101.106  -51.074  51.238  12
805139  101.132  -51.089  51.202  12
805140  101.147  -51.111  51.165  12
805141  101.162  -51.132  51.129  12
805142  101.177  -51.153  51.092  12
805143  101.192  -51.174  51.055  12
805144  101.207  -51.196  51.016  12
805145  101.222  -51.217  50.975  12
805146  101.237  -51.238  50.934  12
805147  101.252  -51.259  50.892  12
805148  101.267  -51.280  50.846  12
805149  101.285  -51.294  50.799  12
805150  101.306  -51.296  50.748  12
805151  101.327  -51.299  50.696  12
805156  101.430  -51.321  50.366  6
805157  101.448  -51.331  50.311  6
805158  101.466  -51.340  50.255  6
805159  101.485  -51.351  50.203  6
805160  101.503  -51.361  50.151  6
805161  101.521  -51.371  50.103  6
805162  101.540  -51.381  50.056  6
805163  101.558  -51.391  50.012  6
805164  101.576  -51.401  49.972  6
805165  101.595  -51.412  49.934  6
805166  101.613  -51.421  49.899  6
805167  101.631  -51.431  49.867  6
805168  101.650  -51.442  49.837  6
805169  101.668  -51.452  49.809  6
805170  101.686  -51.462  49.783  6
805171  101.704  -51.472  49.758  6
805172  101.709  -51.493  49.733  6
805173  101.718  -51.507  49.710  6
805174  101.729  -51.519  49.688  6
805175  101.739  -51.531  49.666  6
805176  101.749  -51.543  49.645  6
805177  101.759  -51.554  49.624  6
805178  101.769  -51.566  49.605  6
805179  101.779  -51.578  49.586  6
805180  101.790  -51.590  49.566  6
805181  101.800  -51.603  49.546  6
805182  101.812  -51.616  49.523  6
805183  101.823  -51.630  49.503  6
805184  101.834  -51.644  49.484  6
805185  101.845  -51.658  49.465  6
805186  101.856  -51.672  49.446  6
805187  101.870  -51.682  49.426  6
805188  101.885  -51.690  49.407  6
805189  101.900  -51.698  49.390  6
805190  101.915  -51.706  49.374  6
805191  101.930  -51.716  49.351  6
805192  101.944  -51.734  49.327  6
805193  101.959  -51.751  49.303  6
805194  101.973  -51.768  49.280  6
805195  101.987  -51.785  49.256  6
805196  102.004  -51.801  49.233  6
805197  102.029  -51.801  49.208  6
805198  102.053  -51.779  49.184  6
805199  102.079  -51.758  49.158  6
805200  102.103  -51.737  49.135  6
805201  102.128  -51.716  49.111  6
805202  102.114  -51.812  49.086  6
805203  102.141  -51.826  49.060  6
805204  102.168  -51.841  49.032  6
805205  102.195  -51.855  49.003  6
805206  102.223  -51.870  48.973  6
805207  102.249  -51.885  48.941  6
805208  102.276  -51.899  48.907  6
805209  102.304  -51.913  48.872  6
805210  102.330  -51.928  48.835  6
805211  102.358  -51.943  48.798  6
805839  101.106  -51.050  51.249  12
805840  101.132  -51.066  51.212  12
805841  101.159  -51.082  51.175  12
805842  101.182  -51.099  51.139  12
805843  101.197  -51.120  51.102  12
805844  101.212  -51.141  51.065  12
805845  101.227  -51.162  51.027  12
805846  101.242  -51.183  50.987  12
805847  101.257  -51.205  50.947  12
805848  101.272  -51.227  50.905  12
805849  101.287  -51.248  50.861  12
805850  101.302  -51.269  50.815  12
805851  101.319  -51.284  50.765  12
805856  101.425  -51.299  50.445  6
805857  101.445  -51.304  50.389  6
805858  101.463  -51.313  50.333  6
805859  101.481  -51.324  50.278  6
805860  101.499  -51.334  50.226  6
805861  101.518  -51.343  50.175  6
805862  101.536  -51.354  50.127  6
805863  101.554  -51.364  50.081  6
805864  101.573  -51.374  50.037  6
805865  101.591  -51.384  49.997  6
805866  101.609  -51.394  49.960  6
805867  101.628  -51.404  49.926  6
805868  101.646  -51.415  49.895  6
805869  101.664  -51.425  49.866  6
805870  101.683  -51.434  49.838  6
805871  101.701  -51.444  49.812  6
805872  101.714  -51.458  49.785  6
805873  101.720  -51.479  49.760  6
805874  101.728  -51.496  49.735  6
805875  101.738  -51.508  49.711  6
805876  101.748  -51.519  49.688  6
805877  101.758  -51.531  49.665  6
805878  101.768  -51.543  49.643  6
805879  101.778  -51.555  49.623  6
805880  101.789  -51.567  49.604  6
805881  101.799  -51.578  49.583  6
805882  101.809  -51.591  49.563  6
805883  101.819  -51.603  49.540  6
805884  101.829  -51.614  49.519  6
805885  101.839  -51.626  49.500  6
805886  101.850  -51.638  49.481  6
805887  101.861  -51.652  49.462  6
805888  101.876  -51.660  49.439  6
805889  101.891  -51.668  49.418  6
805890  101.906  -51.675  49.400  6
805891  101.921  -51.683  49.382  6
805892  101.937  -51.691  49.359  6
805893  101.952  -51.700  49.333  6
805894  101.966  -51.718  49.307  6
805895  101.980  -51.735  49.283  6
805896  101.995  -51.752  49.259  6
805897  102.013  -51.767  49.235  6
805898  102.037  -51.779  49.210  6
805899  102.062  -51.763  49.186  6
805900  102.087  -51.742  49.160  6
805901  102.112  -51.721  49.137  6
805902  102.136  -51.700  49.111  6
805903  102.117  -51.797  49.088  6
805904  102.144  -51.812  49.062  6
805905  102.172  -51.827  49.035  6
805906  102.198  -51.841  49.007  6
805907  102.226  -51.856  48.977  6
805908  102.253  -51.870  48.945  6
805909  102.279  -51.885  48.913  6
805910  102.307  -51.900  48.879  6
805911  102.334  -51.914  48.843  6
805912  102.361  -51.929  48.808  6
806542  101.158  -51.059  51.185  12
806543  101.184  -51.074  51.149  12
806544  101.210  -51.090  51.112  12
806545  101.232  -51.108  51.076  12
806546  101.247  -51.130  51.038  12
806547  101.262  -51.151  50.999  12
806548  101.277  -51.172  50.959  12
806549  101.292  -51.193  50.918  12
806550  101.307  -51.215  50.876  12
806551  101.322  -51.236  50.830  12
806557  101.438  -51.286  50.466  6
806558  101.460  -51.289  50.411  6
806559  101.478  -51.296  50.356  6
806560  101.496  -51.306  50.301  6
806561  101.515  -51.316  50.250  6
806562  101.533  -51.327  50.200  6
806563  101.551  -51.337  50.152  6
806564  101.569  -51.346  50.106  6
806565  101.588  -51.357  50.063  6
806566  101.606  -51.367  50.022  6
806567  101.624  -51.377  49.986  6
806568  101.642  -51.387  49.953  6
806569  101.661  -51.397  49.923  6
806570  101.679  -51.407  49.895  6
806571  101.697  -51.417  49.867  6
806572  101.716  -51.426  49.841  6
806573  101.725  -51.444  49.813  6
806574  101.731  -51.465  49.786  6
806575  101.737  -51.484  49.760  6
806576  101.747  -51.497  49.736  6
806577  101.757  -51.508  49.711  6
806578  101.768  -51.520  49.687  6
806579  101.778  -51.532  49.664  6
806580  101.788  -51.544  49.643  6
806581  101.798  -51.556  49.622  6
806582  101.808  -51.568  49.600  6
806583  101.818  -51.579  49.580  6
806584  101.829  -51.591  49.557  6
806585  101.839  -51.603  49.535  6
806586  101.849  -51.615  49.515  6
806587  101.858  -51.623  49.497  6
806588  101.869  -51.627  49.478  6
806589  101.884  -51.636  49.454  6
806590  101.898  -51.645  49.430  6
806591  101.913  -51.653  49.410  6
806592  101.928  -51.661  49.389  6
806593  101.943  -51.669  49.366  6
806594  101.958  -51.676  49.338  6
806595  101.973  -51.685  49.312  6
806596  101.988  -51.702  49.286  6
806597  102.002  -51.719  49.262  6
806598  102.023  -51.733  49.238  6
806599  102.046  -51.745  49.213  6
806600  102.070  -51.747  49.188  6
806601  102.095  -51.726  49.163  6
806602  102.120  -51.705  49.138  6
806603  102.144  -51.684  49.114  6
806604  102.121  -51.784  49.090  6
806605  102.147  -51.798  49.064  6
806606  102.175  -51.813  49.037  6
806607  102.202  -51.827  49.009  6
806608  102.229  -51.841  48.981  6
806609  102.256  -51.857  48.951  6
806610  102.283  -51.871  48.919  6
806611  102.310  -51.885  48.886  6
806612  102.337  -51.900  48.851  6
807245  101.210  -51.067  51.122  12
807246  101.237  -51.083  51.086  12
807247  101.263  -51.099  51.049  12
807248  101.282  -51.117  51.010  12
807249  101.296  -51.139  50.971  12
807250  101.312  -51.160  50.931  12
807258  101.451  -51.274  50.488  6
807259  101.472  -51.277  50.433  6
807260  101.493  -51.280  50.378  6
807261  101.511  -51.289  50.325  6
807262  101.530  -51.299  50.274  6
807263  101.548  -51.309  50.225  6
807264  101.566  -51.319  50.177  6
807265  101.585  -51.330  50.132  6
807266  101.603  -51.340  50.089  6
807267  101.621  -51.349  50.050  6
807268  101.639  -51.359  50.014  6
807269  101.658  -51.370  49.982  6
807270  101.676  -51.380  49.952  6
807271  101.694  -51.390  49.925  6
807272  101.712  -51.400  49.899  6
807273  101.731  -51.409  49.871  6
807274  101.736  -51.431  49.843  6
807275  101.741  -51.452  49.814  6
807276  101.747  -51.473  49.786  6
807277  101.757  -51.485  49.760  6
807278  101.767  -51.497  49.734  6
807279  101.777  -51.509  49.709  6
807280  101.787  -51.521  49.686  6
807281  101.797  -51.533  49.662  6
807282  101.808  -51.544  49.639  6
807283  101.818  -51.556  49.616  6
807284  101.828  -51.569  49.594  6
807285  101.838  -51.580  49.571  6
807286  101.848  -51.592  49.549  6
807287  101.856  -51.593  49.530  6
807288  101.864  -51.593  49.512  6
807289  101.878  -51.600  49.493  6
807290  101.892  -51.609  49.471  6
807291  101.907  -51.618  49.444  6
807292  101.921  -51.627  49.421  6
807293  101.936  -51.636  49.396  6
807294  101.950  -51.645  49.372  6
807295  101.965  -51.653  49.344  6
807296  101.980  -51.662  49.317  6
807297  101.995  -51.669  49.290  6
807298  102.010  -51.686  49.265  6
807299  102.032  -51.699  49.241  6
807300  102.055  -51.711  49.216  6
807301  102.079  -51.724  49.190  6
807302  102.103  -51.710  49.165  6
807303  102.128  -51.689  49.140  6
807304  102.153  -51.668  49.116  6
807305  102.149  -51.717  49.091  6
807306  102.151  -51.784  49.065  6
807307  102.178  -51.798  49.038  6
807308  102.205  -51.813  49.012  6
807309  102.232  -51.828  48.984  6
807310  102.259  -51.842  48.955  6
807311  102.286  -51.857  48.924  6
807312  102.313  -51.871  48.892  6
807960  101.485  -51.264  50.454  6
807961  101.506  -51.267  50.401  6
807962  101.526  -51.272  50.349  6
807963  101.544  -51.282  50.298  6
807964  101.563  -51.292  50.249  6
807965  101.581  -51.302  50.202  6
807966  101.599  -51.312  50.157  6
807967  101.618  -51.322  50.115  6
807968  101.636  -51.332  50.076  6
807969  101.654  -51.343  50.041  6
807970  101.673  -51.352  50.010  6
807971  101.691  -51.362  49.982  6
807972  101.709  -51.373  49.955  6
807973  101.728  -51.382  49.929  6
807974  101.741  -51.395  49.900  6
807975  101.746  -51.417  49.871  6
807976  101.752  -51.438  49.842  6
807977  101.757  -51.460  49.812  6
807978  101.766  -51.474  49.784  6
807979  101.776  -51.486  49.757  6
807980  101.786  -51.498  49.731  6
807981  101.796  -51.509  49.706  6
807982  101.807  -51.522  49.682  6
807983  101.817  -51.533  49.656  6
807984  101.827  -51.545  49.633  6
807985  101.837  -51.557  49.609  6
807986  101.846  -51.562  49.585  6
807987  101.854  -51.562  49.563  6
807988  101.862  -51.562  49.545  6
807989  101.872  -51.565  49.528  6
807990  101.886  -51.574  49.509  6
807991  101.901  -51.583  49.487  6
807992  101.915  -51.591  49.459  6
807993  101.930  -51.600  49.432  6
807994  101.944  -51.609  49.405  6
807995  101.959  -51.618  49.380  6
807996  101.973  -51.627  49.351  6
807997  101.988  -51.636  49.322  6
807998  102.003  -51.645  49.295  6
807999  102.019  -51.657  49.270  6
808000  102.041  -51.665  49.245  6
808001  102.064  -51.677  49.219  6
808002  102.088  -51.690  49.193  6
808003  102.111  -51.694  49.167  6
808004  102.136  -51.673  49.143  6
808005  102.161  -51.652  49.117  6
808006  102.179  -51.649  49.093  6
808007  102.154  -51.770  49.067  6
808008  102.181  -51.785  49.040  6
808009  102.208  -51.799  49.014  6
808010  102.235  -51.813  48.987  6
808011  102.262  -51.828  48.959  6
808012  102.290  -51.842  48.929  6
808013  102.316  -51.857  48.898  6
808661  101.498  -51.251  50.476  6
808662  101.519  -51.254  50.424  6
808663  101.541  -51.257  50.372  6
808664  101.559  -51.265  50.322  6
808665  101.578  -51.274  50.273  6
808666  101.596  -51.285  50.227  6
808667  101.614  -51.295  50.181  6
808668  101.632  -51.305  50.141  6
808669  101.651  -51.315  50.103  6
808670  101.669  -51.325  50.068  6
808671  101.687  -51.335  50.037  6
808672  101.706  -51.346  50.011  6
808673  101.724  -51.356  49.985  6
808674  101.745  -51.362  49.958  6
808675  101.752  -51.381  49.929  6
808676  101.757  -51.403  49.899  6
808677  101.762  -51.425  49.869  6
808678  101.767  -51.446  49.838  6
808679  101.775  -51.462  49.808  6
808680  101.785  -51.475  49.781  6
808681  101.796  -51.487  49.754  6
808682  101.806  -51.498  49.726  6
808683  101.816  -51.510  49.700  6
808684  101.826  -51.522  49.674  6
808685  101.836  -51.531  49.650  6
808686  101.843  -51.531  49.624  6
808687  101.851  -51.531  49.600  6
808688  101.859  -51.531  49.579  6
808689  101.867  -51.531  49.561  6
808690  101.880  -51.538  49.545  6
808691  101.895  -51.547  49.526  6
808692  101.909  -51.556  49.502  6
808693  101.924  -51.565  49.474  6
808694  101.939  -51.574  49.443  6
808695  101.953  -51.583  49.414  6
808696  101.967  -51.591  49.390  6
808697  101.983  -51.603  49.359  6
808698  101.999  -51.620  49.328  6
808699  102.016  -51.638  49.300  6
808700  102.033  -51.650  49.274  6
808701  102.050  -51.633  49.248  6
808702  102.073  -51.643  49.221  6
808703  102.096  -51.656  49.196  6
808704  102.120  -51.668  49.170  6
808705  102.144  -51.657  49.144  6
808706  102.169  -51.636  49.119  6
808707  102.194  -51.615  49.093  6
808708  102.158  -51.756  49.068  6
808709  102.184  -51.770  49.041  6
808710  102.211  -51.785  49.016  6
808711  102.239  -51.799  48.990  6
808712  102.266  -51.814  48.962  6
808713  102.293  -51.829  48.933  6
808714  102.320  -51.843  48.902  6
808715  102.347  -51.857  48.870  6
808716  102.374  -51.872  48.838  6
808717  102.401  -51.886  48.805  6
809362  101.512  -51.239  50.496  6
809363  101.533  -51.242  50.445  6
809364  101.554  -51.245  50.394  6
809365  101.574  -51.249  50.344  6
809366  101.593  -51.258  50.296  6
809367  101.611  -51.268  50.249  6
809368  101.629  -51.277  50.205  6
809369  101.647  -51.288  50.164  6
809370  101.666  -51.298  50.127  6
809371  101.684  -51.308  50.092  6
809372  101.702  -51.318  50.063  6
809373  101.721  -51.328  50.037  6
809374  101.739  -51.338  50.011  6
809375  101.757  -51.346  49.984  6
809376  101.762  -51.368  49.954  6
809377  101.767  -51.390  49.923  6
809378  101.773  -51.411  49.892  6
809379  101.778  -51.433  49.861  6
809380  101.785  -51.452  49.830  6
809381  101.795  -51.463  49.801  6
809382  101.805  -51.475  49.774  6
809383  101.815  -51.487  49.745  6
809384  101.825  -51.499  49.717  6
809385  101.833  -51.500  49.691  6
809386  101.841  -51.500  49.666  6
809387  101.849  -51.500  49.640  6
809388  101.857  -51.500  49.616  6
809389  101.865  -51.500  49.595  6
809390  101.875  -51.503  49.576  6
809391  101.889  -51.512  49.558  6
809392  101.903  -51.520  49.538  6
809393  101.918  -51.529  49.515  6
809394  101.933  -51.538  49.486  6
809395  101.947  -51.547  49.453  6
809396  101.964  -51.564  49.424  6
809397  101.980  -51.581  49.397  6
809398  101.997  -51.599  49.366  6
809399  102.014  -51.616  49.335  6
809400  102.031  -51.634  49.306  6
809401  102.048  -51.643  49.279  6
809402  102.065  -51.626  49.252  6
809403  102.082  -51.609  49.225  6
809404  102.105  -51.622  49.198  6
809405  102.129  -51.634  49.171  6
809406  102.152  -51.641  49.146  6
809407  102.177  -51.620  49.120  6
809408  102.202  -51.599  49.095  6
809409  102.161  -51.741  49.069  6
809410  102.188  -51.756  49.043  6
809411  102.215  -51.771  49.018  6
809412  102.242  -51.785  48.993  6
809413  102.269  -51.800  48.965  6
809414  102.296  -51.814  48.937  6
809415  102.323  -51.829  48.907  6
809416  102.350  -51.843  48.876  6
809417  102.377  -51.858  48.845  6
809418  102.404  -51.873  48.812  6
809419  102.431  -51.887  48.778  6
809420  102.458  -51.901  48.742  6
810063  101.527  -51.220  50.515  6
810064  101.546  -51.229  50.464  6
810065  101.567  -51.232  50.414  6
810066  101.588  -51.235  50.365  6
810067  101.608  -51.240  50.317  6
810068  101.626  -51.250  50.271  6
810069  101.644  -51.261  50.227  6
810070  101.663  -51.271  50.186  6
810071  101.681  -51.280  50.149  6
810072  101.699  -51.291  50.114  6
810073  101.717  -51.301  50.085  6
810074  101.736  -51.311  50.060  6
810075  101.756  -51.318  50.034  6
810076  101.767  -51.333  50.006  6
810077  101.773  -51.354  49.976  6
810078  101.778  -51.376  49.945  6
810079  101.783  -51.397  49.913  6
810080  101.788  -51.419  49.882  6
810081  101.794  -51.440  49.851  6
810082  101.804  -51.453  49.821  6
810083  101.814  -51.464  49.793  6
810084  101.823  -51.470  49.764  6
810085  101.831  -51.470  49.735  6
810086  101.839  -51.470  49.708  6
810087  101.847  -51.469  49.682  6
810088  101.854  -51.469  49.655  6
810089  101.863  -51.469  49.632  6
810090  101.870  -51.469  49.609  6
810091  101.883  -51.476  49.589  6
810092  101.898  -51.485  49.569  6
810093  101.912  -51.494  49.549  6
810094  101.928  -51.508  49.526  6
810095  101.945  -51.525  49.498  6
810096  101.962  -51.543  49.464  6
810097  101.978  -51.560  49.434  6
810098  101.995  -51.578  49.405  6
810099  102.012  -51.595  49.374  6
810100  102.029  -51.613  49.343  6
810101  102.045  -51.630  49.313  6
810102  102.062  -51.636  49.284  6
810103  102.080  -51.619  49.256  6
810104  102.097  -51.602  49.228  6
810105  102.114  -51.587  49.201  6
810106  102.138  -51.600  49.172  6
810107  102.161  -51.613  49.147  6
810108  102.185  -51.604  49.121  6
810109  102.210  -51.583  49.096  6
810110  102.189  -51.675  49.071  6
810111  102.191  -51.742  49.045  6
810112  102.218  -51.757  49.021  6
810113  102.245  -51.771  48.995  6
810114  102.272  -51.785  48.969  6
810115  102.299  -51.800  48.941  6
810116  102.326  -51.815  48.912  6
810117  102.353  -51.829  48.882  6
810118  102.380  -51.844  48.851  6
810119  102.407  -51.858  48.819  6
810120  102.435  -51.873  48.786  6
810121  102.461  -51.887  48.752  6
810122  102.488  -51.902  48.716  6
810764  101.546  -51.186  50.533  6
810765  101.561  -51.208  50.483  6
810766  101.580  -51.219  50.433  6
810767  101.601  -51.222  50.385  6
810768  101.622  -51.225  50.338  6
810769  101.641  -51.233  50.292  6
810770  101.659  -51.243  50.248  6
810771  101.678  -51.253  50.207  6
810772  101.696  -51.264  50.169  6
810773  101.714  -51.274  50.135  6
810774  101.733  -51.284  50.105  6
810775  101.751  -51.293  50.080  6
810776  101.772  -51.299  50.054  6
810777  101.777  -51.320  50.026  6
810778  101.783  -51.341  49.995  6
810779  101.788  -51.362  49.963  6
810780  101.794  -51.384  49.932  6
810781  101.799  -51.406  49.901  6
810782  101.805  -51.427  49.871  6
810783  101.813  -51.439  49.841  6
810784  101.821  -51.439  49.812  6
810785  101.829  -51.439  49.782  6
810786  101.837  -51.439  49.752  6
810787  101.844  -51.439  49.724  6
810788  101.852  -51.439  49.698  6
810789  101.860  -51.439  49.670  6
810790  101.868  -51.438  49.646  6
810791  101.877  -51.440  49.622  6
810792  101.892  -51.452  49.601  6
810793  101.909  -51.469  49.579  6
810794  101.926  -51.487  49.558  6
810795  101.943  -51.504  49.536  6
810796  101.959  -51.522  49.508  6
810797  101.976  -51.539  49.476  6
810798  101.993  -51.556  49.445  6
810799  102.010  -51.574  49.415  6
810800  102.027  -51.591  49.385  6
810801  102.043  -51.608  49.354  6
810802  102.060  -51.625  49.322  6
810803  102.077  -51.629  49.292  6
810804  102.094  -51.612  49.261  6
810805  102.111  -51.595  49.230  6
810806  102.128  -51.578  49.201  6
810807  102.147  -51.566  49.173  6
810808  102.170  -51.578  49.148  6
810809  102.193  -51.588  49.122  6
810810  102.219  -51.567  49.096  6
810811  102.219  -51.607  49.071  6
810812  102.194  -51.728  49.046  6
810813  102.222  -51.742  49.022  6
810814  102.248  -51.757  48.997  6
810815  102.275  -51.772  48.971  6
810816  102.303  -51.786  48.945  6
810817  102.329  -51.801  48.916  6
810818  102.357  -51.815  48.887  6
810819  102.384  -51.829  48.857  6
810820  102.410  -51.844  48.826  6
810821  102.438  -51.859  48.794  6
810822  102.465  -51.873  48.760  6
810823  102.491  -51.888  48.724  6
810824  102.519  -51.902  48.690  6
811465  101.566  -51.154  50.549  6
811466  101.582  -51.175  50.500  6
811467  101.597  -51.196  50.451  6
811468  101.614  -51.210  50.404  6
811469  101.635  -51.212  50.357  6
811470  101.656  -51.216  50.312  6
811471  101.674  -51.226  50.268  6
811472  101.692  -51.236  50.227  6
811473  101.711  -51.246  50.188  6
811474  101.729  -51.256  50.153  6
811475  101.747  -51.267  50.122  6
811476  101.767  -51.274  50.094  6
811477  101.778  -51.290  50.066  6
811478  101.784  -51.310  50.038  6
811479  101.790  -51.331  50.008  6
811480  101.795  -51.352  49.977  6
811481  101.801  -51.374  49.947  6
811482  101.807  -51.395  49.917  6
811483  101.813  -51.414  49.888  6
811484  101.825  -51.418  49.860  6
811485  101.832  -51.418  49.831  6
811486  101.840  -51.417  49.801  6
811487  101.847  -51.417  49.769  6
811488  101.855  -51.417  49.739  6
811489  101.863  -51.416  49.712  6
811490  101.871  -51.416  49.684  6
811491  101.879  -51.416  49.658  6
811492  101.891  -51.428  49.634  6
811493  101.907  -51.448  49.611  6
811494  101.924  -51.465  49.589  6
811495  101.941  -51.483  49.567  6
811496  101.957  -51.500  49.546  6
811497  101.974  -51.517  49.520  6
811498  101.991  -51.534  49.489  6
811499  102.007  -51.552  49.456  6
811500  102.024  -51.569  49.425  6
811501  102.041  -51.587  49.395  6
811502  102.058  -51.604  49.364  6
811503  102.075  -51.622  49.332  6
811504  102.092  -51.622  49.300  6
811505  102.109  -51.605  49.267  6
811506  102.126  -51.588  49.234  6
811507  102.143  -51.571  49.203  6
811508  102.161  -51.554  49.174  6
811509  102.179  -51.544  49.148  6
811510  102.202  -51.556  49.123  6
811511  102.227  -51.551  49.097  6
811512  102.248  -51.538  49.072  6
811513  102.197  -51.713  49.047  6
811514  102.225  -51.729  49.023  6
811515  102.252  -51.743  48.999  6
811516  102.278  -51.757  48.974  6
811517  102.306  -51.772  48.948  6
811518  102.333  -51.786  48.919  6
811519  102.360  -51.801  48.891  6
811520  102.387  -51.816  48.862  6
811521  102.414  -51.830  48.832  6
811522  102.441  -51.845  48.800  6
811523  102.468  -51.859  48.767  6
811524  102.495  -51.873  48.732  6
811525  102.522  -51.888  48.698  6
811526  102.549  -51.903  48.664  6
812166  101.575  -51.126  50.565  6
812167  101.601  -51.142  50.517  6
812168  101.616  -51.163  50.469  6
812169  101.631  -51.184  50.422  6
812170  101.649  -51.200  50.376  6
812171  101.670  -51.203  50.330  6
812172  101.689  -51.209  50.287  6
812173  101.707  -51.219  50.245  6
812174  101.726  -51.229  50.205  6
812175  101.744  -51.240  50.169  6
812176  101.762  -51.249  50.137  6
812177  101.779  -51.258  50.106  6
812178  101.784  -51.280  50.078  6
812179  101.790  -51.301  50.049  6
812180  101.796  -51.322  50.019  6
812181  101.802  -51.343  49.990  6
812182  101.808  -51.363  49.961  6
812183  101.814  -51.381  49.932  6
812184  101.820  -51.399  49.904  6
812185  101.839  -51.401  49.877  6
812186  101.846  -51.401  49.848  6
812187  101.854  -51.401  49.817  6
812188  101.862  -51.400  49.785  6
812189  101.870  -51.400  49.754  6
812190  101.877  -51.400  49.726  6
812191  101.885  -51.399  49.697  6
812192  101.893  -51.399  49.670  6
812193  101.908  -51.417  49.645  6
812194  101.923  -51.440  49.621  6
812195  101.939  -51.461  49.599  6
812196  101.955  -51.478  49.577  6
812197  101.972  -51.496  49.556  6
812198  101.988  -51.513  49.532  6
812199  102.006  -51.531  49.500  6
812200  102.022  -51.548  49.467  6
812201  102.039  -51.566  49.435  6
812202  102.056  -51.583  49.405  6
812203  102.073  -51.600  49.373  6
812204  102.089  -51.618  49.340  6
812205  102.106  -51.615  49.306  6
812206  102.123  -51.598  49.272  6
812207  102.140  -51.581  49.238  6
812208  102.158  -51.564  49.205  6
812209  102.175  -51.547  49.175  6
812210  102.192  -51.530  49.148  6
812211  102.211  -51.522  49.123  6
812212  102.235  -51.534  49.098  6
812213  102.260  -51.514  49.072  6
812214  102.201  -51.700  49.048  6
812215  102.228  -51.714  49.024  6
812216  102.255  -51.729  49.000  6
812217  102.282  -51.743  48.976  6
812218  102.309  -51.757  48.950  6
812219  102.336  -51.772  48.922  6
812220  102.363  -51.787  48.894  6
812221  102.390  -51.801  48.866  6
812222  102.417  -51.816  48.837  6
812223  102.444  -51.830  48.806  6
812224  102.471  -51.845  48.773  6
812225  102.498  -51.860  48.738  6
812226  102.525  -51.874  48.705  6
812227  102.552  -51.888  48.672  6
812228  102.579  -51.903  48.639  6
812867  101.575  -51.103  50.581  6
812868  101.601  -51.119  50.534  6
812869  101.628  -51.134  50.487  6
812870  101.651  -51.152  50.440  6
812871  101.666  -51.173  50.394  6
812872  101.683  -51.190  50.348  6
812873  101.704  -51.193  50.304  6
812874  101.723  -51.202  50.261  6
812875  101.741  -51.212  50.222  6
812876  101.759  -51.222  50.185  6
812877  101.779  -51.229  50.151  6
812878  101.785  -51.249  50.119  6
812879  101.791  -51.271  50.089  6
812880  101.796  -51.292  50.059  6
812881  101.802  -51.312  50.030  6
812882  101.809  -51.330  50.002  6
812883  101.815  -51.348  49.973  6
812884  101.821  -51.366  49.945  6
812885  101.832  -51.382  49.918  6
812886  101.853  -51.384  49.891  6
812887  101.861  -51.384  49.862  6
812888  101.869  -51.384  49.832  6
812889  101.876  -51.384  49.800  6
812890  101.884  -51.384  49.769  6
812891  101.891  -51.384  49.739  6
812892  101.899  -51.383  49.709  6
812893  101.907  -51.384  49.683  6
812894  101.925  -51.405  49.657  6
812895  101.940  -51.428  49.632  6
812896  101.955  -51.450  49.610  6
812897  101.970  -51.473  49.588  6
812898  101.986  -51.492  49.567  6
812899  102.003  -51.509  49.542  6
812900  102.020  -51.527  49.510  6
812901  102.037  -51.544  49.477  6
812902  102.053  -51.562  49.445  6
812903  102.070  -51.579  49.413  6
812904  102.087  -51.597  49.378  6
812905  102.104  -51.613  49.345  6
812906  102.121  -51.608  49.310  6
812907  102.138  -51.591  49.277  6
812908  102.155  -51.574  49.243  6
812909  102.173  -51.557  49.209  6
812910  102.190  -51.540  49.177  6
812911  102.207  -51.523  49.149  6
812912  102.224  -51.506  49.122  6
812913  102.244  -51.500  49.098  6
812914  102.268  -51.498  49.073  6
812915  102.229  -51.633  49.048  6
812916  102.231  -51.700  49.025  6
812917  102.258  -51.714  49.001  6
812918  102.285  -51.729  48.976  6
812919  102.312  -51.744  48.951  6
812920  102.339  -51.758  48.924  6
812921  102.366  -51.772  48.896  6
812922  102.393  -51.787  48.869  6
812923  102.420  -51.802  48.840  6
812924  102.447  -51.816  48.810  6
812925  102.474  -51.831  48.778  6
812926  102.501  -51.845  48.745  6
812927  102.529  -51.860  48.713  6
812928  102.555  -51.874  48.680  6
812929  102.583  -51.889  48.647  6
812930  102.610  -51.904  48.613  6
813568  101.574  -51.080  50.596  6
813569  101.601  -51.096  50.549  6
813570  101.627  -51.111  50.503  6
813571  101.653  -51.127  50.456  6
813572  101.680  -51.142  50.411  6
813573  101.701  -51.161  50.365  6
813574  101.716  -51.180  50.321  6
813575  101.737  -51.184  50.278  6
813576  101.756  -51.195  50.239  6
813577  101.774  -51.205  50.201  6
813578  101.786  -51.219  50.166  6
813579  101.792  -51.240  50.133  6
813580  101.798  -51.261  50.101  6
813581  101.804  -51.279  50.072  6
813582  101.810  -51.297  50.042  6
813583  101.816  -51.315  50.014  6
813584  101.822  -51.334  49.985  6
813585  101.828  -51.352  49.958  6
813586  101.844  -51.365  49.930  6
813587  101.867  -51.368  49.902  6
813588  101.875  -51.368  49.873  6
813589  101.883  -51.368  49.843  6
813590  101.890  -51.367  49.812  6
813591  101.898  -51.367  49.781  6
813592  101.906  -51.367  49.752  6
813593  101.913  -51.366  49.722  6
813594  101.924  -51.373  49.694  6
813595  101.942  -51.393  49.667  6
813596  101.957  -51.416  49.643  6
813597  101.972  -51.439  49.621  6
813598  101.987  -51.462  49.599  6
813599  102.002  -51.484  49.576  6
813600  102.018  -51.505  49.549  6
813601  102.035  -51.522  49.517  6
813602  102.051  -51.540  49.484  6
813603  102.068  -51.557  49.451  6
813604  102.085  -51.575  49.418  6
813605  102.102  -51.592  49.383  6
813606  102.118  -51.609  49.348  6
813607  102.135  -51.601  49.311  6
813608  102.153  -51.584  49.276  6
813609  102.170  -51.567  49.243  6
813610  102.187  -51.550  49.209  6
813611  102.204  -51.533  49.177  6
813612  102.222  -51.516  49.150  6
813613  102.239  -51.499  49.123  6
813614  102.256  -51.482  49.098  6
813615  102.276  -51.479  49.074  6
813616  102.259  -51.565  49.049  6
813617  102.234  -51.686  49.027  6
813618  102.261  -51.700  49.002  6
813619  102.289  -51.715  48.977  6
813620  102.315  -51.729  48.952  6
813621  102.342  -51.744  48.926  6
813622  102.370  -51.759  48.899  6
813623  102.397  -51.773  48.871  6
813624  102.423  -51.788  48.843  6
813625  102.451  -51.802  48.814  6
813626  102.478  -51.816  48.783  6
813627  102.504  -51.831  48.750  6
813628  102.532  -51.846  48.719  6
813629  102.559  -51.860  48.687  6
813630  102.586  -51.875  48.654  6
813631  102.613  -51.889  48.620  6
814269  101.574  -51.058  50.609  6
814270  101.601  -51.073  50.563  6
814271  101.627  -51.089  50.518  6
814272  101.653  -51.104  50.472  6
814273  101.679  -51.120  50.427  6
814274  101.706  -51.136  50.381  6
814275  101.732  -51.151  50.337  6
814276  101.751  -51.171  50.295  6
814277  101.770  -51.177  50.255  6
814278  101.786  -51.189  50.217  6
814279  101.793  -51.210  50.180  6
814280  101.799  -51.228  50.146  6
814281  101.805  -51.246  50.114  6
814282  101.811  -51.265  50.083  6
814283  101.817  -51.283  50.053  6
814284  101.823  -51.301  50.025  6
814285  101.829  -51.319  49.996  6
814286  101.835  -51.337  49.969  6
814287  101.857  -51.348  49.941  6
814288  101.881  -51.352  49.913  6
814289  101.889  -51.351  49.884  6
814290  101.897  -51.351  49.854  6
814291  101.904  -51.351  49.824  6
814292  101.912  -51.350  49.793  6
814293  101.920  -51.350  49.763  6
814294  101.927  -51.349  49.733  6
814295  101.941  -51.362  49.705  6
814296  101.959  -51.382  49.678  6
814297  101.974  -51.405  49.653  6
814298  101.989  -51.428  49.630  6
814299  102.004  -51.450  49.607  6
814300  102.019  -51.473  49.583  6
814301  102.034  -51.496  49.555  6
814302  102.049  -51.519  49.522  6
814303  102.066  -51.536  49.489  6
814304  102.083  -51.553  49.456  6
814305  102.099  -51.571  49.422  6
814306  102.116  -51.588  49.386  6
814307  102.133  -51.606  49.350  6
814308  102.150  -51.594  49.312  6
814309  102.167  -51.577  49.276  6
814310  102.184  -51.559  49.243  6
814311  102.202  -51.543  49.210  6
814312  102.219  -51.526  49.178  6
814313  102.236  -51.509  49.150  6
814314  102.253  -51.492  49.124  6
814315  102.270  -51.475  49.098  6
814316  102.288  -51.458  49.075  6
814317  102.288  -51.497  49.051  6
814318  102.238  -51.672  49.028  6
814319  102.265  -51.686  49.004  6
814320  102.292  -51.700  48.979  6
814321  102.319  -51.716  48.954  6
814322  102.346  -51.730  48.928  6
814323  102.373  -51.744  48.901  6
814324  102.400  -51.759  48.873  6
814325  102.427  -51.773  48.846  6
814326  102.454  -51.788  48.818  6
814327  102.481  -51.803  48.787  6
814328  102.508  -51.817  48.755  6
814329  102.535  -51.832  48.724  6
814330  102.562  -51.846  48.692  6
814331  102.589  -51.860  48.660  6
814332  102.616  -51.875  48.628  6
814333  102.643  -51.890  48.595  6
814970  101.573  -51.034  50.621  6
814971  101.600  -51.050  50.577  6
814972  101.626  -51.066  50.532  6
814973  101.653  -51.081  50.486  6
814974  101.679  -51.097  50.442  6
814975  101.705  -51.112  50.396  6
814976  101.732  -51.128  50.352  6
814977  101.758  -51.144  50.310  6
814978  101.784  -51.159  50.270  6
814979  101.793  -51.177  50.231  6
814980  101.799  -51.196  50.194  6
814981  101.806  -51.214  50.158  6
814982  101.812  -51.232  50.125  6
814983  101.818  -51.250  50.094  6
814984  101.824  -51.268  50.064  6
814985  101.830  -51.287  50.035  6
814986  101.836  -51.305  50.007  6
814987  101.842  -51.323  49.978  6
814988  101.869  -51.331  49.950  6
814989  101.895  -51.335  49.922  6
814990  101.903  -51.334  49.893  6
814991  101.911  -51.334  49.864  6
814992  101.918  -51.334  49.835  6
814993  101.926  -51.334  49.804  6
814994  101.934  -51.334  49.773  6
814995  101.942  -51.334  49.743  6
814996  101.958  -51.350  49.716  6
814997  101.976  -51.371  49.689  6
814998  101.991  -51.393  49.663  6
814999  102.007  -51.415  49.638  6
815000  102.022  -51.438  49.614  6
815001  102.036  -51.462  49.589  6
815002  102.051  -51.484  49.560  6
815003  102.066  -51.507  49.526  6
815004  102.081  -51.530  49.492  6
815005  102.097  -51.550  49.458  6
815006  102.114  -51.567  49.424  6
815007  102.131  -51.584  49.388  6
815008  102.147  -51.601  49.351  6
815009  102.165  -51.587  49.314  6
815010  102.182  -51.570  49.278  6
815011  102.199  -51.553  49.244  6
815012  102.217  -51.536  49.211  6
815013  102.234  -51.519  49.180  6
815014  102.251  -51.502  49.152  6
815015  102.268  -51.485  49.126  6
815016  102.285  -51.468  49.100  6
815017  102.296  -51.462  49.078  6
815018  102.307  -51.456  49.055  6
815019  102.241  -51.657  49.031  6
815020  102.268  -51.672  49.006  6
815021  102.295  -51.687  48.981  6
815022  102.322  -51.701  48.956  6
815023  102.349  -51.716  48.930  6
815024  102.376  -51.730  48.904  6
815025  102.403  -51.744  48.876  6
815026  102.430  -51.760  48.849  6
815027  102.457  -51.774  48.821  6
815028  102.484  -51.788  48.791  6
815029  102.511  -51.803  48.760  6
815030  102.538  -51.817  48.729  6
815031  102.565  -51.832  48.698  6
815032  102.592  -51.847  48.666  6
815033  102.619  -51.861  48.634  6
815034  102.647  -51.876  48.602  6
815035  102.673  -51.890  48.569  6
815036  102.700  -51.904  48.537  6
815670  101.547  -50.996  50.676  6
815671  101.573  -51.011  50.633  6
815672  101.600  -51.027  50.589  6
815673  101.626  -51.043  50.544  6
815674  101.652  -51.058  50.500  6
815675  101.679  -51.074  50.455  6
815676  101.705  -51.089  50.410  6
815677  101.731  -51.105  50.366  6
815678  101.758  -51.121  50.324  6
815679  101.784  -51.141  50.283  6
815680  101.801  -51.163  50.245  6
815681  101.807  -51.181  50.207  6
815682  101.813  -51.199  50.171  6
815683  101.819  -51.218  50.136  6
815684  101.825  -51.236  50.104  6
815685  101.831  -51.254  50.073  6
815686  101.837  -51.272  50.044  6
815687  101.843  -51.290  50.015  6
815688  101.850  -51.308  49.986  6
815689  101.881  -51.313  49.958  6
815690  101.910  -51.318  49.930  6
815691  101.917  -51.318  49.901  6
815692  101.925  -51.318  49.872  6
815693  101.933  -51.318  49.842  6
815694  101.941  -51.317  49.813  6
815695  101.948  -51.317  49.784  6
815696  101.957  -51.318  49.755  6
815697  101.975  -51.339  49.725  6
815698  101.993  -51.359  49.698  6
815699  102.009  -51.381  49.670  6
815700  102.024  -51.404  49.644  6
815701  102.039  -51.427  49.619  6
815702  102.053  -51.450  49.593  6
815703  102.068  -51.472  49.563  6
815704  102.084  -51.495  49.529  6
815705  102.098  -51.518  49.494  6
815706  102.113  -51.541  49.460  6
815707  102.128  -51.562  49.426  6
815708  102.146  -51.580  49.389  6
815709  102.162  -51.597  49.354  6
815710  102.179  -51.580  49.317  6
815711  102.196  -51.562  49.281  6
815712  102.214  -51.546  49.248  6
815713  102.231  -51.528  49.215  6
815714  102.246  -51.515  49.184  6
815715  102.257  -51.510  49.156  6
815716  102.267  -51.505  49.129  6
815717  102.277  -51.500  49.104  6
815718  102.288  -51.495  49.081  6
815719  102.298  -51.490  49.058  6
815720  102.269  -51.591  49.034  6
815721  102.271  -51.658  49.009  6
815722  102.298  -51.672  48.984  6
815723  102.325  -51.687  48.958  6
815724  102.352  -51.701  48.932  6
815725  102.379  -51.716  48.905  6
815726  102.406  -51.731  48.879  6
815727  102.434  -51.745  48.852  6
815728  102.460  -51.760  48.824  6
815729  102.487  -51.774  48.794  6
815730  102.515  -51.788  48.764  6
815731  102.541  -51.804  48.734  6
815732  102.569  -51.818  48.704  6
815733  102.596  -51.832  48.672  6
815734  102.622  -51.847  48.641  6
815735  102.650  -51.861  48.609  6
815736  102.677  -51.876  48.576  6
815737  102.703  -51.891  48.545  6
815738  102.731  -51.905  48.514  6
816371  101.546  -50.973  50.686  6
816372  101.572  -50.989  50.644  6
816373  101.599  -51.005  50.600  6
816374  101.625  -51.020  50.557  6
816375  101.652  -51.036  50.512  6
816376  101.678  -51.052  50.468  6
816377  101.704  -51.067  50.424  6
816378  101.731  -51.083  50.380  6
816379  101.757  -51.098  50.338  6
816380  101.784  -51.124  50.296  6
816381  101.808  -51.148  50.258  6
816382  101.814  -51.166  50.220  6
816383  101.820  -51.184  50.183  6
816384  101.826  -51.203  50.147  6
816385  101.832  -51.221  50.115  6
816386  101.838  -51.240  50.083  6
816387  101.844  -51.258  50.053  6
816388  101.850  -51.276  50.024  6
816389  101.863  -51.291  49.994  6
816390  101.893  -51.296  49.966  6
816391  101.924  -51.302  49.938  6
816392  101.932  -51.302  49.909  6
816393  101.939  -51.301  49.880  6
816394  101.947  -51.301  49.851  6
816395  101.955  -51.300  49.823  6
816396  101.962  -51.300  49.795  6
816397  101.973  -51.307  49.767  6
816398  101.991  -51.327  49.737  6
816399  102.010  -51.348  49.707  6
816400  102.026  -51.370  49.678  6
816401  102.041  -51.393  49.650  6
816402  102.056  -51.415  49.624  6
816403  102.070  -51.438  49.597  6
816404  102.086  -51.461  49.566  6
816405  102.101  -51.484  49.533  6
816406  102.115  -51.506  49.497  6
816407  102.130  -51.529  49.463  6
816408  102.146  -51.552  49.429  6
816409  102.161  -51.575  49.393  6
816410  102.177  -51.590  49.359  6
816411  102.194  -51.572  49.322  6
816412  102.206  -51.564  49.287  6
816413  102.217  -51.559  49.254  6
816414  102.228  -51.554  49.221  6
816415  102.238  -51.549  49.190  6
816416  102.248  -51.544  49.161  6
816417  102.258  -51.539  49.133  6
816418  102.269  -51.534  49.107  6
816419  102.279  -51.529  49.084  6
816420  102.290  -51.525  49.061  6
816421  102.299  -51.523  49.037  6
816422  102.274  -51.644  49.012  6
816423  102.302  -51.658  48.986  6
816424  102.328  -51.673  48.960  6
816425  102.356  -51.688  48.933  6
816426  102.383  -51.702  48.907  6
816427  102.409  -51.716  48.881  6
816428  102.437  -51.731  48.855  6
816429  102.464  -51.745  48.827  6
816430  102.490  -51.760  48.798  6
816431  102.518  -51.775  48.768  6
816432  102.545  -51.789  48.739  6
816433  102.572  -51.804  48.710  6
816434  102.599  -51.818  48.679  6
816435  102.626  -51.832  48.648  6
816436  102.653  -51.848  48.616  6
816437  102.680  -51.862  48.584  6
816438  102.707  -51.876  48.553  6
816439  102.734  -51.891  48.522  6
816440  102.761  -51.905  48.490  6
817072  101.546  -50.950  50.696  6
817073  101.572  -50.966  50.654  6
817074  101.599  -50.982  50.611  6
817075  101.625  -50.997  50.569  6
817076  101.651  -51.013  50.524  6
817077  101.678  -51.028  50.481  6
817078  101.704  -51.044  50.438  6
817079  101.730  -51.060  50.395  6
817080  101.757  -51.081  50.351  6
817081  101.783  -51.106  50.310  6
817082  101.810  -51.132  50.271  6
817083  101.821  -51.152  50.232  6
817084  101.827  -51.170  50.194  6
817085  101.833  -51.188  50.159  6
817086  101.839  -51.206  50.125  6
817087  101.845  -51.224  50.093  6
817088  101.852  -51.243  50.063  6
817089  101.858  -51.261  50.033  6
817090  101.875  -51.274  50.003  6
817091  101.905  -51.279  49.975  6
817092  101.936  -51.284  49.946  6
817093  101.946  -51.285  49.917  6
817094  101.953  -51.284  49.888  6
817095  101.961  -51.284  49.860  6
817096  101.969  -51.284  49.833  6
817097  101.976  -51.284  49.808  6
817098  101.990  -51.296  49.780  6
817099  102.009  -51.316  49.749  6
817100  102.027  -51.336  49.718  6
817101  102.043  -51.358  49.687  6
817102  102.058  -51.381  49.657  6
817103  102.073  -51.403  49.628  6
817104  102.088  -51.427  49.599  6
817105  102.103  -51.450  49.569  6
817106  102.118  -51.472  49.537  6
817107  102.132  -51.495  49.502  6
817108  102.147  -51.518  49.469  6
817109  102.163  -51.541  49.435  6
817110  102.178  -51.563  49.399  6
817111  102.193  -51.581  49.365  6
817112  102.199  -51.586  49.329  6
817113  102.203  -51.590  49.294  6
817114  102.208  -51.593  49.261  6
817115  102.219  -51.588  49.230  6
817116  102.229  -51.583  49.198  6
817117  102.239  -51.578  49.167  6
817118  102.250  -51.573  49.137  6
817119  102.260  -51.569  49.110  6
817120  102.270  -51.563  49.086  6
817121  102.281  -51.559  49.062  6
817122  102.291  -51.554  49.039  6
817123  102.277  -51.630  49.014  6
817124  102.305  -51.644  48.988  6
817125  102.332  -51.659  48.961  6
817126  102.359  -51.673  48.934  6
817127  102.386  -51.688  48.908  6
817128  102.413  -51.702  48.883  6
817129  102.440  -51.717  48.856  6
817130  102.467  -51.732  48.830  6
817131  102.494  -51.746  48.802  6
817132  102.521  -51.760  48.773  6
817133  102.548  -51.775  48.744  6
817134  102.575  -51.789  48.715  6
817135  102.602  -51.804  48.685  6
817136  102.629  -51.819  48.654  6
817137  102.656  -51.833  48.622  6
817138  102.683  -51.848  48.590  6
817139  102.710  -51.862  48.559  6
817140  102.737  -51.876  48.528  6
817141  102.764  -51.891  48.497  6
817142  102.791  -51.906  48.465  6
817773  101.545  -50.927  50.706  6
817774  101.571  -50.943  50.665  6
817775  101.598  -50.958  50.623  6
817776  101.624  -50.974  50.580  6
817777  101.650  -50.990  50.537  6
817778  101.677  -51.005  50.494  6
817779  101.703  -51.021  50.451  6
817780  101.730  -51.038  50.408  6
817781  101.757  -51.064  50.365  6
817782  101.783  -51.089  50.324  6
817783  101.810  -51.114  50.284  6
817784  101.828  -51.137  50.245  6
817785  101.834  -51.155  50.207  6
817786  101.840  -51.174  50.172  6
817787  101.847  -51.192  50.137  6
817788  101.853  -51.210  50.105  6
817789  101.859  -51.228  50.073  6
817790  101.865  -51.246  50.043  6
817791  101.887  -51.257  50.013  6
817792  101.917  -51.262  49.983  6
817793  101.948  -51.268  49.954  6
817794  101.960  -51.268  49.925  6
817795  101.968  -51.268  49.896  6
817796  101.975  -51.268  49.869  6
817797  101.983  -51.268  49.843  6
817798  101.991  -51.267  49.816  6
817799  102.007  -51.284  49.790  6
817800  102.025  -51.304  49.759  6
817801  102.043  -51.324  49.727  6
817802  102.060  -51.346  49.696  6
817803  102.075  -51.369  49.666  6
817804  102.090  -51.392  49.637  6
817805  102.105  -51.415  49.608  6
817806  102.120  -51.437  49.578  6
817807  102.135  -51.460  49.545  6
817808  102.150  -51.483  49.509  6
817809  102.165  -51.506  49.476  6
817810  102.180  -51.528  49.441  6
817811  102.195  -51.552  49.406  6
817812  102.210  -51.562  49.371  6
817813  102.222  -51.572  49.335  6
817814  102.227  -51.575  49.300  6
817815  102.231  -51.580  49.267  6
817816  102.235  -51.584  49.237  6
817817  102.240  -51.588  49.206  6
817818  102.244  -51.592  49.174  6
817819  102.248  -51.597  49.142  6
817820  102.253  -51.600  49.114  6
817821  102.262  -51.597  49.088  6
817822  102.272  -51.593  49.063  6
817823  102.282  -51.587  49.039  6
817824  102.281  -51.616  49.015  6
817825  102.308  -51.630  48.990  6
817826  102.335  -51.644  48.963  6
817827  102.362  -51.659  48.936  6
817828  102.389  -51.674  48.910  6
817829  102.416  -51.688  48.885  6
817830  102.443  -51.703  48.859  6
817831  102.470  -51.717  48.833  6
817832  102.497  -51.732  48.806  6
817833  102.524  -51.746  48.777  6
817834  102.551  -51.761  48.749  6
817835  102.578  -51.776  48.720  6
817836  102.605  -51.790  48.691  6
817837  102.632  -51.804  48.660  6
817838  102.660  -51.819  48.628  6
817839  102.688  -51.834  48.597  6
817840  102.716  -51.848  48.566  6
817841  102.743  -51.863  48.535  6
817842  102.771  -51.878  48.503  6
817843  102.799  -51.892  48.471  6
817844  102.826  -51.907  48.442  6
818475  101.571  -50.920  50.676  6
818476  101.598  -50.936  50.634  6
818477  101.624  -50.951  50.592  6
818478  101.650  -50.967  50.550  6
818479  101.677  -50.983  50.508  6
818480  101.703  -50.998  50.465  6
818481  101.730  -51.021  50.422  6
818482  101.756  -51.046  50.379  6
818483  101.783  -51.072  50.338  6
818484  101.810  -51.098  50.298  6
818485  101.835  -51.123  50.259  6
818486  101.842  -51.141  50.221  6
818487  101.848  -51.159  50.185  6
818488  101.854  -51.177  50.149  6
818489  101.860  -51.196  50.116  6
818490  101.866  -51.214  50.085  6
818491  101.872  -51.232  50.053  6
818492  101.899  -51.240  50.023  6
818493  101.929  -51.245  49.993  6
818494  101.961  -51.250  49.964  6
818495  101.974  -51.252  49.935  6
818496  101.982  -51.251  49.906  6
818497  101.989  -51.251  49.878  6
818498  101.997  -51.251  49.852  6
818499  102.006  -51.252  49.826  6
818500  102.024  -51.272  49.799  6
818501  102.042  -51.293  49.768  6
818502  102.060  -51.313  49.737  6
818503  102.077  -51.335  49.705  6
818504  102.092  -51.358  49.675  6
818505  102.107  -51.381  49.646  6
818506  102.122  -51.403  49.617  6
818507  102.137  -51.426  49.587  6
818508  102.152  -51.449  49.553  6
818509  102.167  -51.472  49.516  6
818510  102.182  -51.494  49.482  6
818511  102.197  -51.517  49.447  6
818512  102.212  -51.534  49.412  6
818513  102.228  -51.545  49.377  6
818514  102.244  -51.556  49.341  6
818515  102.250  -51.561  49.305  6
818516  102.254  -51.566  49.272  6
818517  102.258  -51.569  49.242  6
818518  102.263  -51.574  49.212  6
818519  102.267  -51.578  49.180  6
818520  102.271  -51.582  49.147  6
818521  102.276  -51.586  49.118  6
818522  102.280  -51.591  49.091  6
818523  102.284  -51.594  49.064  6
818524  102.289  -51.599  49.039  6
818525  102.293  -51.603  49.016  6
818526  102.315  -51.616  48.991  6
818527  102.342  -51.631  48.965  6
818528  102.370  -51.646  48.938  6
818529  102.398  -51.660  48.911  6
818530  102.426  -51.675  48.887  6
818531  102.453  -51.690  48.861  6
818532  102.481  -51.704  48.835  6
818533  102.509  -51.719  48.809  6
818534  102.536  -51.734  48.781  6
818535  102.564  -51.748  48.754  6
818536  102.592  -51.763  48.726  6
818537  102.619  -51.778  48.696  6
818538  102.647  -51.792  48.665  6
818539  102.675  -51.807  48.634  6
818540  102.703  -51.822  48.603  6
818541  102.731  -51.836  48.571  6
818542  102.758  -51.851  48.540  6
818543  102.786  -51.866  48.509  6
818544  102.814  -51.880  48.477  6
818545  102.841  -51.895  48.448  6
818546  102.869  -51.910  48.419  6
819177  101.597  -50.913  50.646  6
819178  101.623  -50.929  50.605  6
819179  101.650  -50.944  50.562  6
819180  101.676  -50.960  50.521  6
819181  101.702  -50.978  50.478  6
819182  101.729  -51.004  50.435  6
819183  101.756  -51.030  50.393  6
819184  101.783  -51.055  50.351  6
819185  101.810  -51.080  50.312  6
819186  101.836  -51.106  50.273  6
819187  101.849  -51.127  50.234  6
819188  101.855  -51.145  50.198  6
819189  101.861  -51.163  50.162  6
819190  101.867  -51.181  50.127  6
819191  101.873  -51.199  50.096  6
819192  101.880  -51.217  50.064  6
819193  101.911  -51.223  50.033  6
819194  101.942  -51.228  50.003  6
819195  101.973  -51.233  49.974  6
819196  101.988  -51.235  49.945  6
819197  101.996  -51.235  49.916  6
819198  102.004  -51.234  49.888  6
819199  102.012  -51.234  49.861  6
819200  102.023  -51.240  49.835  6
819201  102.041  -51.261  49.808  6
819202  102.059  -51.281  49.777  6
819203  102.077  -51.302  49.746  6
819204  102.094  -51.323  49.713  6
819205  102.109  -51.346  49.684  6
819206  102.124  -51.368  49.656  6
819207  102.139  -51.392  49.627  6
819208  102.154  -51.415  49.596  6
819209  102.169  -51.437  49.561  6
819210  102.184  -51.460  49.522  6
819211  102.199  -51.483  49.487  6
819212  102.214  -51.505  49.453  6
819213  102.230  -51.516  49.417  6
819214  102.246  -51.527  49.382  6
819215  102.262  -51.538  49.345  6
819216  102.273  -51.547  49.309  6
819217  102.277  -51.550  49.276  6
819218  102.282  -51.555  49.245  6
819219  102.286  -51.559  49.215  6
819220  102.290  -51.563  49.183  6
819221  102.295  -51.568  49.152  6
819222  102.299  -51.572  49.122  6
819223  102.304  -51.576  49.094  6
819224  102.308  -51.580  49.067  6
819225  102.312  -51.584  49.040  6
819226  102.316  -51.592  49.015  6
819227  102.330  -51.605  48.989  6
819228  102.358  -51.619  48.964  6
819229  102.385  -51.634  48.938  6
819230  102.413  -51.649  48.912  6
819231  102.441  -51.663  48.888  6
819232  102.468  -51.678  48.863  6
819233  102.496  -51.693  48.837  6
819234  102.524  -51.707  48.811  6
819235  102.551  -51.722  48.785  6
819236  102.579  -51.737  48.758  6
819237  102.607  -51.751  48.731  6
819238  102.634  -51.766  48.701  6
819239  102.662  -51.781  48.671  6
819240  102.690  -51.795  48.640  6
819241  102.718  -51.810  48.609  6
819242  102.745  -51.825  48.577  6
819243  102.773  -51.839  48.545  6
819244  102.801  -51.854  48.515  6
819245  102.829  -51.869  48.483  6
819246  102.857  -51.883  48.453  6
819247  102.884  -51.898  48.425  6
819879  101.623  -50.906  50.616  6
819880  101.650  -50.921  50.574  6
819881  101.676  -50.937  50.533  6
819882  101.702  -50.961  50.490  6
819883  101.729  -50.986  50.447  6
819884  101.756  -51.012  50.406  6
819885  101.782  -51.038  50.365  6
819886  101.809  -51.063  50.326  6
819887  101.836  -51.089  50.286  6
819888  101.856  -51.112  50.247  6
819889  101.862  -51.130  50.210  6
819890  101.868  -51.149  50.174  6
819891  101.875  -51.167  50.140  6
819892  101.881  -51.185  50.108  6
819893  101.892  -51.200  50.076  6
819894  101.923  -51.205  50.045  6
819895  101.954  -51.211  50.015  6
819896  101.985  -51.216  49.986  6
819897  102.003  -51.218  49.957  6
819898  102.010  -51.218  49.928  6
819899  102.018  -51.218  49.900  6
819900  102.026  -51.218  49.873  6
819901  102.039  -51.229  49.845  6
819902  102.057  -51.249  49.816  6
819903  102.076  -51.270  49.787  6
819904  102.094  -51.290  49.755  6
819905  102.111  -51.312  49.722  6
819906  102.126  -51.334  49.691  6
819907  102.141  -51.357  49.663  6
819908  102.156  -51.380  49.634  6
819909  102.171  -51.403  49.603  6
819910  102.186  -51.425  49.566  6
819911  102.201  -51.448  49.526  6
819912  102.216  -51.471  49.489  6
819913  102.232  -51.487  49.453  6
819914  102.248  -51.498  49.419  6
819915  102.263  -51.509  49.383  6
819916  102.279  -51.520  49.345  6
819917  102.296  -51.531  49.310  6
819918  102.301  -51.536  49.278  6
819919  102.305  -51.541  49.247  6
819920  102.310  -51.544  49.217  6
819921  102.314  -51.549  49.187  6
819922  102.318  -51.553  49.156  6
819923  102.323  -51.557  49.127  6
819924  102.327  -51.562  49.097  6
819925  102.331  -51.566  49.070  6
819926  102.336  -51.570  49.043  6
819927  102.339  -51.582  49.017  6
819928  102.345  -51.593  48.991  6
819929  102.373  -51.607  48.965  6
819930  102.400  -51.622  48.940  6
819931  102.428  -51.637  48.914  6
819932  102.456  -51.651  48.890  6
819933  102.483  -51.666  48.866  6
819934  102.511  -51.681  48.840  6
819935  102.539  -51.695  48.815  6
819936  102.567  -51.710  48.788  6
819937  102.594  -51.725  48.763  6
819938  102.622  -51.739  48.736  6
819939  102.650  -51.754  48.707  6
819940  102.677  -51.769  48.677  6
819941  102.705  -51.783  48.646  6
819942  102.733  -51.798  48.615  6
819943  102.760  -51.813  48.583  6
819944  102.788  -51.827  48.551  6
819945  102.816  -51.842  48.521  6
819946  102.843  -51.857  48.489  6
819947  102.872  -51.871  48.459  6
819948  102.899  -51.886  48.432  6
820581  101.649  -50.898  50.586  6
820582  101.675  -50.918  50.545  6
820583  101.702  -50.944  50.501  6
820584  101.729  -50.970  50.460  6
820585  101.756  -50.995  50.418  6
820586  101.782  -51.020  50.378  6
820587  101.809  -51.046  50.338  6
820588  101.836  -51.071  50.299  6
820589  101.863  -51.097  50.260  6
820590  101.870  -51.115  50.223  6
820591  101.876  -51.134  50.187  6
820592  101.882  -51.152  50.152  6
820593  101.888  -51.171  50.120  6
820594  101.904  -51.183  50.088  6
820595  101.935  -51.188  50.057  6
820596  101.966  -51.194  50.026  6
820597  101.997  -51.199  49.997  6
820598  102.017  -51.202  49.969  6
820599  102.024  -51.202  49.940  6
820600  102.032  -51.201  49.912  6
820601  102.040  -51.201  49.885  6
820602  102.056  -51.218  49.858  6
820603  102.075  -51.238  49.828  6
820604  102.093  -51.258  49.797  6
820605  102.111  -51.279  49.765  6
820606  102.128  -51.300  49.730  6
820607  102.144  -51.323  49.697  6
820608  102.159  -51.346  49.667  6
820609  102.173  -51.368  49.638  6
820610  102.188  -51.391  49.606  6
820611  102.203  -51.414  49.569  6
820612  102.218  -51.437  49.530  6
820613  102.233  -51.459  49.492  6
820614  102.249  -51.469  49.454  6
820615  102.265  -51.481  49.419  6
820616  102.281  -51.491  49.383  6
820617  102.297  -51.503  49.346  6
820618  102.313  -51.513  49.312  6
820619  102.324  -51.522  49.281  6
820620  102.328  -51.526  49.250  6
820621  102.333  -51.530  49.220  6
820622  102.337  -51.534  49.191  6
820623  102.341  -51.538  49.161  6
820624  102.346  -51.543  49.131  6
820625  102.350  -51.547  49.101  6
820626  102.355  -51.551  49.074  6
820627  102.359  -51.556  49.046  6
820628  102.362  -51.572  49.020  6
820629  102.360  -51.581  48.994  6
820630  102.388  -51.596  48.967  6
820631  102.415  -51.610  48.942  6
820632  102.443  -51.625  48.917  6
820633  102.471  -51.640  48.892  6
820634  102.499  -51.654  48.869  6
820635  102.526  -51.669  48.843  6
820636  102.554  -51.684  48.819  6
820637  102.582  -51.698  48.792  6
820638  102.609  -51.713  48.767  6
820639  102.637  -51.728  48.741  6
820640  102.665  -51.742  48.712  6
820641  102.692  -51.757  48.683  6
820642  102.720  -51.772  48.652  6
820643  102.748  -51.786  48.620  6
820644  102.775  -51.801  48.589  6
820645  102.803  -51.816  48.558  6
820646  102.831  -51.830  48.527  6
820647  102.859  -51.845  48.495  6
820648  102.886  -51.860  48.466  6
820649  102.914  -51.874  48.440  6
821283  101.675  -50.901  50.556  6
821284  101.702  -50.926  50.513  6
821285  101.729  -50.952  50.472  6
821286  101.755  -50.978  50.431  6
821287  101.782  -51.003  50.391  6
821288  101.809  -51.029  50.351  6
821289  101.835  -51.055  50.311  6
821290  101.862  -51.080  50.273  6
821291  101.877  -51.101  50.236  6
821292  101.883  -51.119  50.199  6
821293  101.889  -51.137  50.165  6
821294  101.895  -51.155  50.133  6
821295  101.916  -51.166  50.100  6
821296  101.948  -51.171  50.068  6
821297  101.978  -51.177  50.037  6
821298  102.009  -51.182  50.009  6
821299  102.031  -51.185  49.981  6
821300  102.038  -51.185  49.953  6
821301  102.046  -51.185  49.925  6
821302  102.055  -51.186  49.898  6
821303  102.073  -51.206  49.872  6
821304  102.091  -51.227  49.842  6
821305  102.109  -51.247  49.809  6
821306  102.127  -51.268  49.775  6
821307  102.146  -51.288  49.738  6
821308  102.161  -51.311  49.702  6
821309  102.176  -51.334  49.669  6
821310  102.190  -51.357  49.638  6
821311  102.205  -51.380  49.606  6
821312  102.221  -51.403  49.571  6
821313  102.235  -51.425  49.534  6
821314  102.251  -51.440  49.494  6
821315  102.267  -51.452  49.455  6
821316  102.283  -51.462  49.419  6
821317  102.299  -51.474  49.383  6
821318  102.315  -51.484  49.347  6
821319  102.331  -51.496  49.314  6
821320  102.346  -51.506  49.284  6
821321  102.352  -51.512  49.254  6
821322  102.357  -51.515  49.225  6
821323  102.361  -51.520  49.195  6
821324  102.365  -51.524  49.166  6
821325  102.369  -51.528  49.136  6
821326  102.374  -51.532  49.106  6
821327  102.378  -51.537  49.077  6
821328  102.382  -51.544  49.050  6
821329  102.385  -51.562  49.024  6
821330  102.375  -51.569  48.997  6
821331  102.403  -51.584  48.970  6
821332  102.430  -51.598  48.944  6
821333  102.458  -51.613  48.920  6
821334  102.486  -51.628  48.895  6
821335  102.514  -51.642  48.871  6
821336  102.541  -51.657  48.847  6
821337  102.569  -51.672  48.822  6
821338  102.597  -51.686  48.796  6
821339  102.624  -51.701  48.772  6
821340  102.652  -51.716  48.745  6
821341  102.680  -51.730  48.717  6
821342  102.708  -51.745  48.688  6
821343  102.735  -51.760  48.657  6
821344  102.763  -51.774  48.627  6
821345  102.790  -51.789  48.595  6
821346  102.818  -51.804  48.564  6
821347  102.846  -51.818  48.534  6
821348  102.874  -51.833  48.503  6
821349  102.901  -51.848  48.475  6
821350  102.929  -51.862  48.448  6
821985  101.701  -50.910  50.527  6
821986  101.728  -50.935  50.486  6
821987  101.755  -50.961  50.444  6
821988  101.782  -50.986  50.405  6
821989  101.809  -51.011  50.365  6
821990  101.835  -51.037  50.325  6
821991  101.862  -51.063  50.286  6
821992  101.884  -51.086  50.249  6
821993  101.890  -51.105  50.212  6
821994  101.896  -51.123  50.179  6
821995  101.902  -51.141  50.146  6
821996  101.928  -51.149  50.112  6
821997  101.960  -51.154  50.082  6
821998  101.990  -51.159  50.051  6
821999  102.021  -51.165  50.022  6
822000  102.045  -51.168  49.994  6
822001  102.053  -51.168  49.966  6
822002  102.060  -51.168  49.939  6
822003  102.071  -51.174  49.913  6
822004  102.090  -51.195  49.887  6
822005  102.108  -51.215  49.857  6
822006  102.126  -51.236  49.822  6
822007  102.144  -51.256  49.785  6
822008  102.163  -51.277  49.745  6
822009  102.178  -51.299  49.707  6
822010  102.193  -51.322  49.671  6
822011  102.207  -51.345  49.637  6
822012  102.223  -51.368  49.604  6
822013  102.238  -51.390  49.570  6
822014  102.253  -51.412  49.534  6
822015  102.268  -51.423  49.497  6
822016  102.284  -51.434  49.460  6
822017  102.301  -51.445  49.421  6
822018  102.316  -51.456  49.385  6
822019  102.332  -51.467  49.350  6
822020  102.348  -51.478  49.317  6
822021  102.364  -51.489  49.287  6
822022  102.375  -51.497  49.258  6
822023  102.380  -51.501  49.229  6
822024  102.384  -51.506  49.201  6
822025  102.388  -51.509  49.172  6
822026  102.393  -51.514  49.142  6
822027  102.397  -51.518  49.111  6
822028  102.401  -51.522  49.083  6
822029  102.405  -51.534  49.054  6
822030  102.407  -51.553  49.027  6
822031  102.392  -51.558  49.001  6
822032  102.418  -51.572  48.974  6
822033  102.446  -51.586  48.948  6
822034  102.473  -51.601  48.923  6
822035  102.501  -51.616  48.898  6
822036  102.529  -51.630  48.874  6
822037  102.556  -51.645  48.850  6
822038  102.584  -51.660  48.825  6
822039  102.612  -51.674  48.800  6
822040  102.640  -51.689  48.776  6
822041  102.667  -51.703  48.750  6
822042  102.695  -51.719  48.722  6
822043  102.723  -51.733  48.693  6
822044  102.750  -51.747  48.663  6
822045  102.778  -51.763  48.632  6
822046  102.806  -51.777  48.601  6
822047  102.833  -51.791  48.571  6
822048  102.861  -51.807  48.541  6
822049  102.889  -51.821  48.511  6
822050  102.916  -51.835  48.483  6
822051  102.944  -51.851  48.457  6
822052  102.972  -51.865  48.432  6
822685  101.675  -50.867  50.586  6
822686  101.701  -50.892  50.542  6
822687  101.728  -50.918  50.501  6
822688  101.755  -50.943  50.460  6
822689  101.781  -50.969  50.420  6
822690  101.808  -50.995  50.381  6
822691  101.835  -51.020  50.341  6
822692  101.862  -51.045  50.301  6
822693  101.888  -51.071  50.264  6
822694  101.897  -51.090  50.228  6
822695  101.903  -51.108  50.194  6
822696  101.910  -51.127  50.160  6
822697  101.941  -51.132  50.127  6
822698  101.972  -51.137  50.096  6
822699  102.003  -51.142  50.065  6
822700  102.033  -51.148  50.036  6
822701  102.059  -51.152  50.007  6
822702  102.067  -51.152  49.979  6
822703  102.075  -51.152  49.952  6
822704  102.089  -51.163  49.926  6
822705  102.107  -51.183  49.900  6
822706  102.125  -51.204  49.870  6
822707  102.143  -51.224  49.835  6
822708  102.161  -51.245  49.796  6
822709  102.179  -51.265  49.754  6
822710  102.195  -51.288  49.713  6
822711  102.210  -51.311  49.674  6
822712  102.225  -51.334  49.637  6
822713  102.240  -51.356  49.602  6
822714  102.255  -51.379  49.567  6
822715  102.270  -51.393  49.533  6
822716  102.286  -51.405  49.498  6
822717  102.302  -51.416  49.462  6
822718  102.318  -51.427  49.425  6
822719  102.334  -51.438  49.389  6
822720  102.350  -51.449  49.354  6
822721  102.366  -51.460  49.321  6
822722  102.382  -51.471  49.291  6
822723  102.398  -51.482  49.262  6
822724  102.403  -51.487  49.235  6
822725  102.407  -51.491  49.207  6
822726  102.412  -51.495  49.178  6
822727  102.416  -51.500  49.148  6
822728  102.420  -51.503  49.117  6
822729  102.425  -51.508  49.088  6
822730  102.427  -51.524  49.059  6
822731  102.430  -51.543  49.031  6
822732  102.416  -51.549  49.004  6
822733  102.433  -51.559  48.977  6
822734  102.461  -51.575  48.951  6
822735  102.488  -51.589  48.926  6
822736  102.516  -51.603  48.902  6
822737  102.544  -51.619  48.878  6
822738  102.572  -51.633  48.854  6
822739  102.599  -51.647  48.829  6
822740  102.627  -51.663  48.804  6
822741  102.655  -51.677  48.780  6
822742  102.682  -51.691  48.755  6
822743  102.710  -51.707  48.727  6
822744  102.738  -51.721  48.698  6
822745  102.765  -51.735  48.668  6
822746  102.793  -51.750  48.637  6
822747  102.821  -51.765  48.607  6
822748  102.848  -51.780  48.577  6
822749  102.876  -51.794  48.548  6
822750  102.904  -51.809  48.519  6
822751  102.932  -51.824  48.490  6
822752  102.959  -51.838  48.465  6
822753  102.987  -51.853  48.441  6
823386  101.674  -50.850  50.602  6
823387  101.701  -50.875  50.559  6
823388  101.728  -50.901  50.518  6
823389  101.755  -50.926  50.476  6
823390  101.781  -50.952  50.436  6
823391  101.808  -50.977  50.397  6
823392  101.835  -51.003  50.358  6
823393  101.862  -51.029  50.318  6
823394  101.888  -51.054  50.279  6
823395  101.904  -51.076  50.245  6
823396  101.910  -51.094  50.210  6
823397  101.922  -51.109  50.176  6
823398  101.953  -51.114  50.143  6
823399  101.984  -51.120  50.111  6
823400  102.015  -51.125  50.080  6
823401  102.045  -51.130  50.051  6
823402  102.074  -51.136  50.022  6
823403  102.081  -51.135  49.993  6
823404  102.089  -51.135  49.965  6
823405  102.105  -51.152  49.939  6
823406  102.123  -51.172  49.913  6
823407  102.141  -51.193  49.883  6
823408  102.160  -51.213  49.848  6
823409  102.178  -51.233  49.807  6
823410  102.196  -51.254  49.764  6
823411  102.212  -51.276  49.720  6
823412  102.227  -51.299  49.678  6
823413  102.242  -51.322  49.638  6
823414  102.257  -51.345  49.600  6
823415  102.272  -51.365  49.564  6
823416  102.288  -51.376  49.531  6
823417  102.304  -51.387  49.497  6
823418  102.320  -51.398  49.463  6
823419  102.336  -51.409  49.429  6
823420  102.351  -51.420  49.394  6
823421  102.368  -51.431  49.359  6
823422  102.384  -51.442  49.325  6
823423  102.399  -51.453  49.295  6
823424  102.415  -51.464  49.267  6
823425  102.427  -51.472  49.240  6
823426  102.430  -51.476  49.212  6
823427  102.435  -51.481  49.184  6
823428  102.440  -51.485  49.154  6
823429  102.444  -51.489  49.123  6
823430  102.448  -51.494  49.094  6
823431  102.451  -51.514  49.065  6
823432  102.453  -51.533  49.036  6
823433  102.441  -51.541  49.009  6
823434  102.448  -51.548  48.981  6
823435  102.476  -51.562  48.955  6
823436  102.504  -51.577  48.929  6
823437  102.531  -51.592  48.905  6
823438  102.559  -51.606  48.881  6
823439  102.587  -51.621  48.857  6
823440  102.614  -51.636  48.832  6
823441  102.642  -51.650  48.808  6
823442  102.670  -51.665  48.783  6
823443  102.697  -51.680  48.757  6
823444  102.725  -51.694  48.730  6
823445  102.753  -51.709  48.702  6
823446  102.781  -51.724  48.672  6
823447  102.808  -51.738  48.642  6
823448  102.836  -51.753  48.612  6
823449  102.864  -51.768  48.583  6
823450  102.891  -51.782  48.554  6
823451  102.919  -51.797  48.525  6
823452  102.947  -51.812  48.497  6
823453  102.974  -51.826  48.474  6
823454  103.002  -51.841  48.450  6
824086  101.647  -50.807  50.661  6
824087  101.674  -50.832  50.620  6
824088  101.701  -50.858  50.578  6
824089  101.728  -50.884  50.536  6
824090  101.754  -50.909  50.495  6
824091  101.781  -50.935  50.454  6
824092  101.808  -50.961  50.415  6
824093  101.834  -50.986  50.376  6
824094  101.861  -51.011  50.336  6
824095  101.888  -51.037  50.298  6
824096  101.911  -51.061  50.262  6
824097  101.917  -51.080  50.227  6
824098  101.934  -51.092  50.193  6
824099  101.965  -51.097  50.160  6
824100  101.996  -51.103  50.127  6
824101  102.027  -51.108  50.096  6
824102  102.058  -51.114  50.066  6
824103  102.088  -51.119  50.037  6
824104  102.095  -51.118  50.008  6
824105  102.104  -51.120  49.980  6
824106  102.122  -51.140  49.953  6
824107  102.140  -51.161  49.926  6
824108  102.159  -51.181  49.895  6
824109  102.177  -51.202  49.859  6
824110  102.195  -51.222  49.818  6
824111  102.213  -51.243  49.774  6
824112  102.229  -51.265  49.729  6
824113  102.244  -51.287  49.684  6
824114  102.259  -51.310  49.642  6
824115  102.274  -51.333  49.603  6
824116  102.290  -51.347  49.568  6
824117  102.306  -51.358  49.534  6
824118  102.321  -51.369  49.500  6
824119  102.337  -51.380  49.467  6
824120  102.353  -51.391  49.432  6
824121  102.369  -51.403  49.398  6
824122  102.385  -51.413  49.363  6
824123  102.401  -51.425  49.331  6
824124  102.417  -51.435  49.301  6
824125  102.433  -51.446  49.273  6
824126  102.449  -51.457  49.245  6
824127  102.454  -51.462  49.218  6
824128  102.458  -51.466  49.190  6
824129  102.463  -51.470  49.160  6
824130  102.467  -51.475  49.129  6
824131  102.471  -51.484  49.099  6
824132  102.473  -51.504  49.070  6
824133  102.476  -51.524  49.042  6
824134  102.465  -51.532  49.014  6
824135  102.463  -51.536  48.986  6
824136  102.491  -51.550  48.959  6
824137  102.519  -51.566  48.934  6
824138  102.546  -51.580  48.909  6
824139  102.574  -51.594  48.885  6
824140  102.602  -51.609  48.861  6
824141  102.629  -51.624  48.836  6
824142  102.657  -51.638  48.811  6
824143  102.685  -51.653  48.786  6
824144  102.713  -51.668  48.760  6
824145  102.740  -51.682  48.733  6
824146  102.768  -51.697  48.705  6
824147  102.796  -51.712  48.677  6
824148  102.823  -51.726  48.647  6
824149  102.851  -51.741  48.618  6
824150  102.879  -51.756  48.589  6
824151  102.906  -51.770  48.561  6
824152  102.934  -51.785  48.532  6
824153  102.962  -51.800  48.505  6
824154  102.989  -51.814  48.482  6
824155  103.017  -51.829  48.459  6
824788  101.674  -50.816  50.638  6
824789  101.700  -50.841  50.597  6
824790  101.727  -50.867  50.554  6
824791  101.754  -50.892  50.513  6
824792  101.781  -50.917  50.472  6
824793  101.808  -50.943  50.433  6
824794  101.834  -50.969  50.394  6
824795  101.861  -50.994  50.354  6
824796  101.888  -51.020  50.316  6
824797  101.914  -51.045  50.279  6
824798  101.924  -51.065  50.245  6
824799  101.947  -51.075  50.211  6
824800  101.977  -51.080  50.176  6
824801  102.008  -51.086  50.143  6
824802  102.039  -51.091  50.111  6
824803  102.070  -51.096  50.081  6
824804  102.101  -51.102  50.051  6
824805  102.109  -51.102  50.022  6
824806  102.121  -51.108  49.993  6
824807  102.139  -51.129  49.966  6
824808  102.157  -51.149  49.938  6
824809  102.175  -51.170  49.907  6
824810  102.193  -51.190  49.871  6
824811  102.211  -51.211  49.830  6
824812  102.230  -51.231  49.786  6
824813  102.246  -51.253  49.738  6
824814  102.261  -51.276  49.692  6
824815  102.276  -51.299  49.648  6
824816  102.291  -51.318  49.609  6
824817  102.307  -51.329  49.573  6
824818  102.323  -51.340  49.538  6
824819  102.339  -51.351  49.505  6
824820  102.355  -51.362  49.471  6
824821  102.371  -51.373  49.436  6
824822  102.387  -51.384  49.402  6
824823  102.403  -51.396  49.369  6
824824  102.419  -51.406  49.338  6
824825  102.435  -51.418  49.308  6
824826  102.451  -51.428  49.280  6
824827  102.467  -51.440  49.252  6
824828  102.477  -51.447  49.224  6
824829  102.482  -51.452  49.196  6
824830  102.486  -51.456  49.166  6
824831  102.490  -51.460  49.135  6
824832  102.493  -51.475  49.105  6
824833  102.496  -51.494  49.076  6
824834  102.499  -51.514  49.047  6
824835  102.489  -51.524  49.019  6
824836  102.478  -51.524  48.991  6
824837  102.506  -51.539  48.964  6
824838  102.534  -51.553  48.938  6
824839  102.561  -51.568  48.913  6
824840  102.589  -51.583  48.889  6
824841  102.617  -51.597  48.865  6
824842  102.644  -51.612  48.840  6
824843  102.672  -51.627  48.814  6
824844  102.700  -51.641  48.789  6
824845  102.728  -51.656  48.764  6
824846  102.755  -51.671  48.737  6
824847  102.783  -51.685  48.709  6
824848  102.811  -51.700  48.681  6
824849  102.838  -51.715  48.652  6
824850  102.866  -51.729  48.623  6
824851  102.894  -51.744  48.595  6
824852  102.921  -51.759  48.567  6
824853  102.949  -51.773  48.539  6
824854  102.977  -51.788  48.513  6
824855  103.005  -51.803  48.490  6
825489  101.674  -50.798  50.656  6
825490  101.700  -50.824  50.615  6
825491  101.727  -50.849  50.572  6
825492  101.754  -50.875  50.530  6
825493  101.780  -50.901  50.490  6
825494  101.807  -50.926  50.450  6
825495  101.834  -50.951  50.411  6
825496  101.861  -50.977  50.373  6
825497  101.887  -51.002  50.334  6
825498  101.914  -51.028  50.297  6
825499  101.932  -51.050  50.262  6
825500  101.959  -51.058  50.228  6
825501  101.989  -51.063  50.192  6
825502  102.020  -51.068  50.159  6
825503  102.051  -51.074  50.126  6
825504  102.082  -51.080  50.095  6
825505  102.113  -51.085  50.065  6
825506  102.123  -51.085  50.035  6
825507  102.137  -51.097  50.006  6
825508  102.156  -51.117  49.978  6
825509  102.174  -51.138  49.950  6
825510  102.192  -51.158  49.919  6
825511  102.210  -51.179  49.882  6
825512  102.229  -51.199  49.842  6
825513  102.247  -51.220  49.797  6
825514  102.263  -51.241  49.748  6
825515  102.278  -51.264  49.700  6
825516  102.293  -51.287  49.656  6
825517  102.309  -51.300  49.616  6
825518  102.325  -51.312  49.579  6
825519  102.341  -51.322  49.544  6
825520  102.357  -51.334  49.511  6
825521  102.373  -51.344  49.475  6
825522  102.389  -51.356  49.440  6
825523  102.405  -51.366  49.408  6
825524  102.420  -51.378  49.376  6
825525  102.437  -51.389  49.345  6
825526  102.453  -51.399  49.316  6
825527  102.468  -51.411  49.288  6
825528  102.484  -51.421  49.260  6
825529  102.501  -51.433  49.232  6
825530  102.505  -51.437  49.202  6
825531  102.510  -51.441  49.173  6
825532  102.514  -51.446  49.142  6
825533  102.516  -51.465  49.113  6
825534  102.519  -51.484  49.083  6
825535  102.522  -51.504  49.053  6
825536  102.514  -51.515  49.025  6
825537  102.493  -51.512  48.997  6
825538  102.521  -51.527  48.970  6
825539  102.548  -51.541  48.943  6
825540  102.576  -51.556  48.918  6
825541  102.604  -51.571  48.893  6
825542  102.632  -51.585  48.869  6
825543  102.660  -51.600  48.844  6
825544  102.687  -51.615  48.818  6
825545  102.715  -51.629  48.794  6
825546  102.743  -51.644  48.767  6
825547  102.770  -51.659  48.740  6
825548  102.798  -51.673  48.713  6
825549  102.826  -51.688  48.685  6
825550  102.854  -51.703  48.657  6
825551  102.881  -51.717  48.629  6
825552  102.909  -51.732  48.601  6
825553  102.937  -51.747  48.574  6
825554  102.964  -51.761  48.547  6
825555  102.992  -51.776  48.522  6
826190  101.673  -50.781  50.675  6
826191  101.700  -50.807  50.633  6
826192  101.727  -50.832  50.590  6
826193  101.753  -50.857  50.547  6
826194  101.780  -50.883  50.508  6
826195  101.807  -50.909  50.468  6
826196  101.834  -50.934  50.429  6
826197  101.861  -50.960  50.391  6
826198  101.887  -50.986  50.352  6
826199  101.914  -51.011  50.315  6
826200  101.940  -51.036  50.279  6
826201  101.971  -51.041  50.246  6
826202  102.001  -51.046  50.208  6
826203  102.032  -51.052  50.174  6
826204  102.063  -51.057  50.141  6
826205  102.094  -51.062  50.110  6
826206  102.125  -51.067  50.079  6
826207  102.138  -51.069  50.048  6
826208  102.154  -51.086  50.018  6
826209  102.172  -51.106  49.989  6
826210  102.191  -51.127  49.962  6
826211  102.209  -51.147  49.930  6
826212  102.227  -51.168  49.894  6
826213  102.245  -51.188  49.853  6
826214  102.263  -51.208  49.808  6
826215  102.280  -51.230  49.759  6
826216  102.296  -51.252  49.711  6
826217  102.311  -51.271  49.665  6
826218  102.327  -51.283  49.623  6
826219  102.342  -51.293  49.585  6
826220  102.359  -51.305  49.550  6
826221  102.375  -51.315  49.517  6
826222  102.390  -51.327  49.482  6
826223  102.406  -51.337  49.446  6
826224  102.422  -51.349  49.414  6
826225  102.438  -51.359  49.382  6
826226  102.454  -51.371  49.353  6
826227  102.470  -51.382  49.324  6
826228  102.486  -51.393  49.296  6
826229  102.502  -51.404  49.269  6
826230  102.518  -51.415  49.241  6
826231  102.528  -51.423  49.211  6
826232  102.533  -51.427  49.181  6
826233  102.537  -51.436  49.151  6
826234  102.539  -51.456  49.120  6
826235  102.542  -51.475  49.091  6
826236  102.544  -51.494  49.061  6
826237  102.538  -51.507  49.032  6
826238  102.508  -51.500  49.004  6
826239  102.536  -51.515  48.976  6
826240  102.563  -51.530  48.950  6
826241  102.591  -51.544  48.924  6
826242  102.619  -51.559  48.899  6
826243  102.647  -51.574  48.874  6
826244  102.674  -51.588  48.848  6
826245  102.702  -51.603  48.823  6
826246  102.730  -51.618  48.798  6
826247  102.758  -51.632  48.772  6
826248  102.786  -51.647  48.745  6
826249  102.813  -51.662  48.719  6
826250  102.841  -51.676  48.690  6
826251  102.869  -51.691  48.662  6
826252  102.896  -51.706  48.635  6
826253  102.924  -51.720  48.608  6
826254  102.952  -51.735  48.581  6
826255  102.979  -51.750  48.555  6
826256  103.007  -51.764  48.531  6
826891  101.673  -50.764  50.694  6
826892  101.700  -50.789  50.652  6
826893  101.727  -50.815  50.609  6
826894  101.753  -50.841  50.567  6
826895  101.780  -50.866  50.527  6
826896  101.807  -50.892  50.487  6
826897  101.833  -50.917  50.448  6
826898  101.860  -50.942  50.409  6
826899  101.887  -50.968  50.370  6
826900  101.914  -50.994  50.333  6
826901  101.942  -51.014  50.298  6
826902  101.973  -51.028  50.263  6
826903  102.012  -51.030  50.226  6
826904  102.045  -51.034  50.191  6
826905  102.076  -51.039  50.157  6
826906  102.106  -51.045  50.126  6
826907  102.137  -51.051  50.095  6
826908  102.153  -51.054  50.062  6
826909  102.171  -51.074  50.031  6
826910  102.189  -51.095  50.000  6
826911  102.207  -51.115  49.972  6
826912  102.226  -51.136  49.940  6
826913  102.244  -51.156  49.904  6
826914  102.262  -51.177  49.864  6
826915  102.280  -51.197  49.819  6
826916  102.298  -51.218  49.770  6
826917  102.313  -51.241  49.721  6
826918  102.328  -51.254  49.675  6
826919  102.344  -51.265  49.632  6
826920  102.360  -51.276  49.593  6
826921  102.376  -51.287  49.556  6
826922  102.392  -51.298  49.522  6
826923  102.408  -51.309  49.488  6
826924  102.424  -51.320  49.454  6
826925  102.440  -51.331  49.422  6
826926  102.456  -51.342  49.391  6
826927  102.472  -51.352  49.363  6
826928  102.488  -51.364  49.335  6
826929  102.504  -51.375  49.307  6
826930  102.520  -51.386  49.279  6
826931  102.536  -51.397  49.251  6
826932  102.551  -51.408  49.221  6
826933  102.556  -51.412  49.191  6
826934  102.559  -51.426  49.160  6
826935  102.562  -51.446  49.129  6
826936  102.564  -51.465  49.099  6
826937  102.567  -51.484  49.069  6
826938  102.563  -51.499  49.040  6
826939  102.533  -51.492  49.011  6
826940  102.551  -51.503  48.983  6
826941  102.579  -51.518  48.957  6
826942  102.606  -51.532  48.931  6
826943  102.634  -51.547  48.905  6
826944  102.662  -51.562  48.880  6
826945  102.689  -51.576  48.854  6
826946  102.717  -51.591  48.828  6
826947  102.745  -51.606  48.803  6
826948  102.772  -51.620  48.777  6
826949  102.800  -51.635  48.751  6
826950  102.828  -51.650  48.724  6
826951  102.856  -51.664  48.696  6
826952  102.884  -51.679  48.668  6
826953  102.911  -51.694  48.641  6
826954  102.939  -51.708  48.615  6
826955  102.967  -51.723  48.589  6
826956  102.995  -51.738  48.563  6
827592  101.673  -50.747  50.713  6
827593  101.699  -50.773  50.671  6
827594  101.726  -50.798  50.628  6
827595  101.753  -50.823  50.587  6
827596  101.780  -50.849  50.546  6
827597  101.807  -50.874  50.506  6
827598  101.833  -50.900  50.466  6
827599  101.860  -50.926  50.427  6
827600  101.887  -50.951  50.388  6
827601  101.914  -50.975  50.350  6
827602  101.944  -50.992  50.315  6
827603  101.975  -51.006  50.280  6
827604  102.006  -51.020  50.244  6
827605  102.043  -51.025  50.208  6
827606  102.083  -51.026  50.174  6
827607  102.118  -51.028  50.143  6
827608  102.149  -51.033  50.111  6
827609  102.170  -51.042  50.077  6
827610  102.188  -51.063  50.044  6
827611  102.206  -51.083  50.012  6
827612  102.224  -51.104  49.982  6
827613  102.242  -51.124  49.950  6
827614  102.261  -51.145  49.913  6
827615  102.279  -51.165  49.875  6
827616  102.297  -51.186  49.830  6
827617  102.315  -51.206  49.781  6
827618  102.330  -51.225  49.732  6
827619  102.346  -51.236  49.685  6
827620  102.362  -51.247  49.641  6
827621  102.378  -51.258  49.601  6
827622  102.394  -51.269  49.564  6
827623  102.410  -51.280  49.529  6
827624  102.426  -51.291  49.495  6
827625  102.442  -51.302  49.462  6
827626  102.458  -51.313  49.431  6
827627  102.473  -51.324  49.401  6
827628  102.489  -51.335  49.374  6
827629  102.506  -51.346  49.347  6
827630  102.521  -51.357  49.318  6
827631  102.537  -51.368  49.290  6
827632  102.553  -51.379  49.262  6
827633  102.569  -51.390  49.232  6
827634  102.580  -51.398  49.201  6
827635  102.582  -51.416  49.169  6
827636  102.585  -51.436  49.138  6
827637  102.587  -51.456  49.108  6
827638  102.590  -51.475  49.079  6
827639  102.587  -51.490  49.050  6
827640  102.557  -51.484  49.021  6
827641  102.566  -51.491  48.992  6
827642  102.594  -51.506  48.964  6
827643  102.621  -51.520  48.938  6
827644  102.649  -51.535  48.912  6
827645  102.677  -51.550  48.887  6
827646  102.704  -51.565  48.861  6
827647  102.732  -51.579  48.835  6
827648  102.760  -51.594  48.810  6
827649  102.787  -51.609  48.784  6
827650  102.815  -51.623  48.758  6
827651  102.843  -51.638  48.731  6
827652  102.871  -51.653  48.703  6
827653  102.898  -51.667  48.675  6
827654  102.927  -51.682  48.649  6
827655  102.954  -51.697  48.623  6
827656  102.982  -51.711  48.597  6
828293  101.673  -50.729  50.733  6
828294  101.699  -50.755  50.691  6
828295  101.726  -50.781  50.648  6
828296  101.753  -50.806  50.607  6
828297  101.779  -50.832  50.566  6
828298  101.806  -50.857  50.526  6
828299  101.833  -50.882  50.485  6
828300  101.859  -50.908  50.445  6
828301  101.886  -50.934  50.406  6
828302  101.914  -50.954  50.368  6
828303  101.945  -50.970  50.332  6
828304  101.976  -50.984  50.296  6
828305  102.007  -50.998  50.258  6
828306  102.038  -51.012  50.223  6
828307  102.074  -51.020  50.190  6
828308  102.113  -51.020  50.158  6
828309  102.153  -51.021  50.126  6
828310  102.185  -51.029  50.092  6
828311  102.204  -51.050  50.058  6
828312  102.223  -51.071  50.026  6
828313  102.241  -51.092  49.994  6
828314  102.259  -51.113  49.959  6
828315  102.277  -51.133  49.922  6
828316  102.296  -51.154  49.884  6
828317  102.314  -51.174  49.840  6
828318  102.332  -51.195  49.791  6
828319  102.347  -51.207  49.742  6
828320  102.364  -51.218  49.695  6
828321  102.380  -51.229  49.651  6
828322  102.395  -51.240  49.610  6
828323  102.411  -51.251  49.572  6
828324  102.427  -51.262  49.538  6
828325  102.443  -51.273  49.504  6
828326  102.459  -51.284  49.472  6
828327  102.475  -51.295  49.442  6
828328  102.490  -51.305  49.415  6
828329  102.506  -51.317  49.388  6
828330  102.522  -51.327  49.361  6
828331  102.538  -51.338  49.332  6
828332  102.553  -51.349  49.304  6
828333  102.569  -51.360  49.276  6
828334  102.585  -51.371  49.246  6
828335  102.602  -51.387  49.214  6
828336  102.605  -51.407  49.181  6
828337  102.608  -51.426  49.148  6
828338  102.610  -51.446  49.120  6
828339  102.613  -51.465  49.090  6
828340  102.612  -51.481  49.060  6
828341  102.582  -51.475  49.032  6
828342  102.581  -51.479  49.003  6
828343  102.609  -51.494  48.975  6
828344  102.636  -51.509  48.948  6
828345  102.664  -51.523  48.922  6
828346  102.692  -51.537  48.895  6
828347  102.720  -51.553  48.869  6
828348  102.747  -51.567  48.843  6
828349  102.775  -51.581  48.818  6
828350  102.803  -51.597  48.792  6
828351  102.830  -51.611  48.765  6
828352  102.858  -51.626  48.737  6
828353  102.886  -51.641  48.709  6
828354  102.913  -51.655  48.682  6
828355  102.941  -51.670  48.656  6
828356  102.969  -51.685  48.631  6
828994  101.672  -50.713  50.755  6
828995  101.699  -50.738  50.711  6
828996  101.726  -50.763  50.669  6
828997  101.752  -50.789  50.627  6
828998  101.779  -50.814  50.586  6
828999  101.806  -50.840  50.545  6
829000  101.833  -50.866  50.504  6
829001  101.859  -50.891  50.463  6
829002  101.887  -50.914  50.424  6
829003  101.915  -50.933  50.385  6
829004  101.946  -50.948  50.348  6
829005  101.977  -50.961  50.311  6
829006  102.009  -50.976  50.273  6
829007  102.040  -50.990  50.238  6
829008  102.071  -51.005  50.204  6
829009  102.105  -51.014  50.171  6
829010  102.144  -51.015  50.139  6
829011  102.184  -51.016  50.105  6
829012  102.215  -51.025  50.073  6
829013  102.233  -51.046  50.043  6
829014  102.251  -51.067  50.010  6
829015  102.270  -51.089  49.973  6
829016  102.289  -51.110  49.933  6
829017  102.307  -51.131  49.894  6
829018  102.326  -51.152  49.848  6
829019  102.344  -51.174  49.801  6
829020  102.360  -51.185  49.753  6
829021  102.376  -51.196  49.706  6
829022  102.391  -51.207  49.661  6
829023  102.407  -51.218  49.620  6
829024  102.423  -51.228  49.582  6
829025  102.439  -51.240  49.548  6
829026  102.454  -51.250  49.514  6
829027  102.470  -51.261  49.483  6
829028  102.486  -51.271  49.455  6
829029  102.501  -51.283  49.428  6
829030  102.517  -51.293  49.403  6
829031  102.533  -51.304  49.375  6
829032  102.548  -51.315  49.347  6
829033  102.564  -51.326  49.320  6
829034  102.580  -51.337  49.292  6
829035  102.599  -51.357  49.261  6
829036  102.618  -51.378  49.228  6
829037  102.628  -51.397  49.194  6
829038  102.630  -51.416  49.161  6
829039  102.633  -51.436  49.132  6
829040  102.635  -51.455  49.102  6
829041  102.636  -51.473  49.072  6
829042  102.606  -51.466  49.043  6
829043  102.596  -51.467  49.014  6
829044  102.624  -51.482  48.986  6
829045  102.652  -51.497  48.959  6
829046  102.679  -51.511  48.933  6
829047  102.707  -51.526  48.906  6
829048  102.735  -51.541  48.879  6
829049  102.762  -51.555  48.852  6
829050  102.790  -51.570  48.826  6
829051  102.818  -51.584  48.801  6
829052  102.845  -51.599  48.774  6
829053  102.873  -51.614  48.745  6
829054  102.901  -51.628  48.717  6
829055  102.929  -51.643  48.690  6
829056  102.956  -51.658  48.664  6
829696  101.699  -50.721  50.731  6
829697  101.726  -50.746  50.689  6
829698  101.752  -50.772  50.646  6
829699  101.779  -50.798  50.604  6
829700  101.806  -50.823  50.563  6
829701  101.832  -50.848  50.522  6
829702  101.859  -50.873  50.481  6
829703  101.887  -50.893  50.442  6
829704  101.916  -50.911  50.402  6
829705  101.948  -50.926  50.363  6
829706  101.979  -50.939  50.326  6
829707  102.010  -50.954  50.287  6
829708  102.041  -50.968  50.252  6
829709  102.073  -50.982  50.217  6
829710  102.104  -50.996  50.183  6
829711  102.135  -51.009  50.149  6
829712  102.175  -51.010  50.116  6
829713  102.215  -51.011  50.087  6
829714  102.243  -51.022  50.060  6
829715  102.262  -51.043  50.027  6
829716  102.280  -51.064  49.988  6
829717  102.299  -51.086  49.946  6
829718  102.318  -51.107  49.904  6
829719  102.336  -51.128  49.857  6
829720  102.355  -51.149  49.810  6
829721  102.371  -51.162  49.762  6
829722  102.387  -51.173  49.717  6
829723  102.402  -51.183  49.672  6
829724  102.418  -51.195  49.631  6
829725  102.434  -51.205  49.593  6
829726  102.450  -51.216  49.558  6
829727  102.465  -51.227  49.525  6
829728  102.481  -51.238  49.494  6
829729  102.497  -51.249  49.468  6
829730  102.512  -51.259  49.442  6
829731  102.528  -51.271  49.418  6
829732  102.544  -51.281  49.391  6
829733  102.559  -51.292  49.364  6
829734  102.577  -51.307  49.338  6
829735  102.596  -51.327  49.308  6
829736  102.615  -51.347  49.276  6
829737  102.634  -51.367  49.242  6
829738  102.650  -51.387  49.207  6
829739  102.653  -51.406  49.175  6
829740  102.656  -51.426  49.144  6
829741  102.658  -51.446  49.115  6
829742  102.661  -51.465  49.084  6
829743  102.630  -51.458  49.056  6
829744  102.611  -51.456  49.026  6
829745  102.639  -51.470  48.998  6
829746  102.667  -51.484  48.971  6
829747  102.694  -51.500  48.944  6
829748  102.722  -51.514  48.917  6
829749  102.750  -51.528  48.890  6
829750  102.777  -51.544  48.863  6
829751  102.805  -51.558  48.837  6
829752  102.833  -51.572  48.811  6
829753  102.861  -51.587  48.783  6
829754  102.888  -51.602  48.755  6
829755  102.916  -51.616  48.727  6
829756  102.944  -51.631  48.700  6
829757  102.971  -51.646  48.673  6
830397  101.698  -50.704  50.748  6
830398  101.725  -50.729  50.706  6
830399  101.752  -50.754  50.664  6
830400  101.779  -50.780  50.621  6
830401  101.806  -50.806  50.581  6
830402  101.832  -50.831  50.539  6
830403  101.860  -50.852  50.497  6
830404  101.888  -50.873  50.457  6
830405  101.918  -50.889  50.416  6
830406  101.949  -50.903  50.377  6
830407  101.980  -50.917  50.339  6
830408  102.012  -50.932  50.299  6
830409  102.043  -50.945  50.264  6
830410  102.074  -50.960  50.228  6
830411  102.105  -50.974  50.193  6
830412  102.136  -50.989  50.157  6
830413  102.167  -51.002  50.126  6
830414  102.206  -51.005  50.100  6
830415  102.245  -51.006  50.073  6
830416  102.272  -51.018  50.040  6
830417  102.291  -51.039  50.003  6
830418  102.310  -51.061  49.960  6
830419  102.328  -51.082  49.915  6
830420  102.346  -51.103  49.866  6
830421  102.365  -51.124  49.819  6
830422  102.382  -51.139  49.771  6
830423  102.398  -51.150  49.725  6
830424  102.413  -51.161  49.682  6
830425  102.429  -51.171  49.641  6
830426  102.445  -51.182  49.603  6
830427  102.460  -51.193  49.568  6
830428  102.476  -51.204  49.536  6
830429  102.492  -51.215  49.506  6
830430  102.507  -51.226  49.480  6
830431  102.523  -51.236  49.458  6
830432  102.539  -51.247  49.433  6
830433  102.554  -51.258  49.407  6
830434  102.573  -51.277  49.382  6
830435  102.592  -51.297  49.355  6
830436  102.611  -51.317  49.323  6
830437  102.630  -51.337  49.290  6
830438  102.650  -51.357  49.255  6
830439  102.668  -51.378  49.221  6
830440  102.676  -51.397  49.189  6
830441  102.678  -51.416  49.158  6
830442  102.681  -51.436  49.128  6
830443  102.684  -51.455  49.098  6
830444  102.655  -51.450  49.069  6
830445  102.626  -51.443  49.040  6
830446  102.654  -51.458  49.012  6
830447  102.682  -51.473  48.985  6
830448  102.710  -51.487  48.958  6
830449  102.737  -51.502  48.930  6
830450  102.765  -51.517  48.903  6
830451  102.793  -51.531  48.876  6
830452  102.820  -51.546  48.849  6
830453  102.848  -51.561  48.822  6
830454  102.876  -51.575  48.793  6
830455  102.903  -51.590  48.766  6
830456  102.931  -51.605  48.738  6
830457  102.959  -51.619  48.710  6
830458  102.986  -51.634  48.684  6
830459  103.014  -51.649  48.658  6
831099  101.725  -50.712  50.721  6
831100  101.752  -50.738  50.679  6
831101  101.778  -50.763  50.637  6
831102  101.805  -50.788  50.596  6
831103  101.832  -50.812  50.553  6
831104  101.861  -50.832  50.511  6
831105  101.888  -50.852  50.469  6
831106  101.919  -50.867  50.429  6
831107  101.950  -50.881  50.388  6
831108  101.981  -50.895  50.350  6
831109  102.013  -50.910  50.309  6
831110  102.044  -50.923  50.273  6
831111  102.075  -50.938  50.236  6
831112  102.106  -50.952  50.199  6
831113  102.137  -50.966  50.163  6
831114  102.169  -50.980  50.131  6
831115  102.200  -50.995  50.104  6
831116  102.237  -51.000  50.077  6
831117  102.276  -51.001  50.045  6
831118  102.302  -51.015  50.009  6
831119  102.320  -51.036  49.967  6
831120  102.338  -51.058  49.922  6
831121  102.357  -51.079  49.874  6
831122  102.376  -51.100  49.827  6
831123  102.393  -51.116  49.780  6
831124  102.408  -51.127  49.735  6
831125  102.424  -51.137  49.692  6
831126  102.440  -51.149  49.651  6
831127  102.456  -51.159  49.613  6
831128  102.471  -51.170  49.579  6
831129  102.487  -51.181  49.546  6
831130  102.503  -51.192  49.517  6
831131  102.518  -51.202  49.492  6
831132  102.534  -51.213  49.471  6
831133  102.550  -51.227  49.446  6
831134  102.570  -51.246  49.422  6
831135  102.589  -51.267  49.397  6
831136  102.608  -51.287  49.370  6
831137  102.627  -51.307  49.338  6
831138  102.646  -51.327  49.304  6
831139  102.665  -51.347  49.269  6
831140  102.684  -51.367  49.235  6
831141  102.699  -51.387  49.203  6
831142  102.701  -51.406  49.173  6
831143  102.704  -51.426  49.142  6
831144  102.706  -51.445  49.112  6
831145  102.679  -51.441  49.083  6
831146  102.649  -51.434  49.054  6
831147  102.669  -51.446  49.028  6
831148  102.697  -51.461  49.000  6
831149  102.725  -51.475  48.972  6
831150  102.752  -51.490  48.944  6
831151  102.780  -51.505  48.917  6
831152  102.808  -51.519  48.889  6
831153  102.835  -51.534  48.862  6
831154  102.863  -51.549  48.834  6
831155  102.891  -51.563  48.805  6
831156  102.918  -51.578  48.777  6
831157  102.946  -51.593  48.749  6
831158  102.974  -51.607  48.722  6
831159  103.001  -51.622  48.695  6
831160  103.029  -51.637  48.669  6
831161  103.057  -51.651  48.644  6
831801  101.751  -50.720  50.694  6
831802  101.778  -50.746  50.652  6
831803  101.805  -50.771  50.610  6
831804  101.833  -50.791  50.567  6
831805  101.861  -50.811  50.524  6
831806  101.889  -50.830  50.481  6
831807  101.920  -50.845  50.440  6
831808  101.952  -50.859  50.399  6
831809  101.983  -50.873  50.360  6
831810  102.014  -50.887  50.319  6
831811  102.045  -50.901  50.280  6
831812  102.077  -50.916  50.242  6
831813  102.108  -50.929  50.204  6
831814  102.139  -50.944  50.167  6
831815  102.170  -50.958  50.134  6
831816  102.201  -50.973  50.105  6
831817  102.233  -50.986  50.077  6
831818  102.267  -50.995  50.046  6
831819  102.307  -50.995  50.010  6
831820  102.330  -51.012  49.970  6
831821  102.349  -51.033  49.927  6
831822  102.368  -51.055  49.881  6
831823  102.386  -51.076  49.835  6
831824  102.404  -51.092  49.789  6
831825  102.419  -51.104  49.744  6
831826  102.435  -51.114  49.701  6
831827  102.451  -51.125  49.660  6
831828  102.466  -51.136  49.623  6
831829  102.482  -51.147  49.589  6
831830  102.498  -51.158  49.556  6
831831  102.514  -51.168  49.528  6
831832  102.529  -51.180  49.504  6
831833  102.547  -51.196  49.483  6
831834  102.566  -51.216  49.459  6
831835  102.585  -51.236  49.435  6
831836  102.604  -51.256  49.410  6
831837  102.623  -51.277  49.384  6
831838  102.643  -51.296  49.353  6
831839  102.662  -51.317  49.318  6
831840  102.681  -51.337  49.283  6
831841  102.699  -51.357  49.249  6
831842  102.719  -51.378  49.217  6
831843  102.724  -51.396  49.187  6
831844  102.727  -51.416  49.157  6
831845  102.729  -51.435  49.127  6
831846  102.704  -51.433  49.099  6
831847  102.674  -51.426  49.071  6
831848  102.684  -51.434  49.043  6
831849  102.712  -51.449  49.015  6
831850  102.740  -51.464  48.987  6
831851  102.767  -51.478  48.960  6
831852  102.795  -51.493  48.932  6
831853  102.823  -51.508  48.902  6
831854  102.851  -51.522  48.876  6
831855  102.878  -51.537  48.848  6
831856  102.906  -51.552  48.819  6
831857  102.934  -51.566  48.791  6
831858  102.961  -51.581  48.762  6
831859  102.989  -51.596  48.734  6
831860  103.017  -51.610  48.708  6
831861  103.044  -51.625  48.682  6
831862  103.072  -51.640  48.656  6
831863  103.100  -51.654  48.633  6
832502  101.751  -50.703  50.708  6
832503  101.778  -50.729  50.665  6
832504  101.806  -50.751  50.623  6
832505  101.833  -50.770  50.580  6
832506  101.862  -50.791  50.537  6
832507  101.891  -50.808  50.494  6
832508  101.922  -50.823  50.452  6
832509  101.953  -50.837  50.410  6
832510  101.984  -50.851  50.369  6
832511  102.016  -50.865  50.328  6
832512  102.047  -50.879  50.287  6
832513  102.078  -50.894  50.247  6
832514  102.109  -50.907  50.208  6
832515  102.140  -50.922  50.169  6
832516  102.172  -50.936  50.134  6
832517  102.203  -50.950  50.103  6
832518  102.234  -50.964  50.074  6
832519  102.265  -50.979  50.043  6
832520  102.298  -50.989  50.008  6
832521  102.338  -50.990  49.971  6
832522  102.360  -51.008  49.931  6
832523  102.378  -51.030  49.888  6
832524  102.397  -51.051  49.842  6
832525  102.414  -51.070  49.797  6
832526  102.430  -51.080  49.752  6
832527  102.446  -51.091  49.709  6
832528  102.462  -51.102  49.668  6
832529  102.477  -51.113  49.631  6
832530  102.493  -51.124  49.598  6
832531  102.509  -51.135  49.566  6
832532  102.525  -51.146  49.538  6
832533  102.544  -51.166  49.514  6
832534  102.562  -51.186  49.493  6
832535  102.582  -51.206  49.470  6
832536  102.601  -51.227  49.446  6
832537  102.620  -51.246  49.422  6
832538  102.639  -51.267  49.396  6
832539  102.658  -51.287  49.366  6
832540  102.677  -51.307  49.332  6
832541  102.696  -51.327  49.298  6
832542  102.715  -51.347  49.264  6
832543  102.734  -51.367  49.232  6
832544  102.747  -51.387  49.201  6
832545  102.749  -51.406  49.172  6
832546  102.752  -51.426  49.143  6
832547  102.728  -51.425  49.115  6
832548  102.698  -51.418  49.087  6
832549  102.699  -51.422  49.060  6
832550  102.727  -51.437  49.032  6
832551  102.755  -51.452  49.004  6
832552  102.783  -51.466  48.976  6
832553  102.810  -51.481  48.948  6
832554  102.838  -51.496  48.919  6
832555  102.866  -51.510  48.891  6
832556  102.893  -51.525  48.863  6
832557  102.921  -51.540  48.834  6
832558  102.949  -51.554  48.805  6
832559  102.976  -51.569  48.776  6
832560  103.004  -51.584  48.748  6
832561  103.032  -51.598  48.720  6
832562  103.059  -51.613  48.694  6
832563  103.087  -51.628  48.668  6
832564  103.115  -51.642  48.644  6
833204  101.778  -50.710  50.678  6
833205  101.806  -50.730  50.636  6
833206  101.834  -50.750  50.592  6
833207  101.862  -50.770  50.548  6
833208  101.892  -50.786  50.505  6
833209  101.923  -50.801  50.462  6
833210  101.955  -50.814  50.420  6
833211  101.986  -50.829  50.378  6
833212  102.017  -50.843  50.336  6
833213  102.048  -50.857  50.295  6
833214  102.079  -50.871  50.253  6
833215  102.110  -50.886  50.213  6
833216  102.141  -50.900  50.174  6
833217  102.173  -50.914  50.137  6
833218  102.204  -50.928  50.103  6
833219  102.235  -50.942  50.072  6
833220  102.266  -50.957  50.040  6
833221  102.298  -50.970  50.007  6
833222  102.329  -50.985  49.973  6
833223  102.369  -50.986  49.934  6
833224  102.389  -51.005  49.893  6
833225  102.407  -51.027  49.848  6
833226  102.426  -51.046  49.803  6
833227  102.441  -51.058  49.759  6
833228  102.457  -51.068  49.717  6
833229  102.472  -51.079  49.677  6
833230  102.488  -51.090  49.641  6
833231  102.504  -51.101  49.607  6
833232  102.521  -51.116  49.575  6
833233  102.540  -51.136  49.548  6
833234  102.559  -51.156  49.523  6
833235  102.578  -51.176  49.502  6
833236  102.597  -51.196  49.480  6
833237  102.616  -51.216  49.457  6
833238  102.635  -51.236  49.433  6
833239  102.655  -51.256  49.407  6
833240  102.674  -51.277  49.377  6
833241  102.693  -51.296  49.346  6
833242  102.712  -51.317  49.312  6
833243  102.731  -51.337  49.279  6
833244  102.750  -51.357  49.247  6
833245  102.769  -51.378  49.217  6
833246  102.772  -51.396  49.188  6
833247  102.775  -51.416  49.160  6
833248  102.753  -51.415  49.132  6
833249  102.723  -51.409  49.104  6
833250  102.715  -51.410  49.078  6
833251  102.742  -51.425  49.050  6
833252  102.770  -51.440  49.022  6
833253  102.798  -51.455  48.994  6
833254  102.825  -51.469  48.966  6
833255  102.853  -51.484  48.937  6
833256  102.881  -51.499  48.908  6
833257  102.908  -51.513  48.879  6
833258  102.936  -51.528  48.849  6
833259  102.964  -51.543  48.820  6
833260  102.992  -51.557  48.790  6
833261  103.019  -51.572  48.761  6
833262  103.047  -51.587  48.733  6
833263  103.075  -51.601  48.706  6
833264  103.102  -51.616  48.680  6
833265  103.130  -51.631  48.655  6
833906  101.807  -50.709  50.648  6
833907  101.835  -50.729  50.604  6
833908  101.863  -50.749  50.559  6
833909  101.893  -50.764  50.516  6
833910  101.924  -50.778  50.473  6
833911  101.956  -50.792  50.430  6
833912  101.987  -50.807  50.388  6
833913  102.018  -50.821  50.344  6
833914  102.049  -50.835  50.302  6
833915  102.081  -50.849  50.260  6
833916  102.112  -50.864  50.219  6
833917  102.143  -50.878  50.180  6
833918  102.174  -50.892  50.140  6
833919  102.205  -50.906  50.104  6
833920  102.237  -50.920  50.071  6
833921  102.268  -50.934  50.039  6
833922  102.299  -50.948  50.008  6
833923  102.330  -50.963  49.975  6
833924  102.362  -50.977  49.938  6
833925  102.399  -50.980  49.898  6
833926  102.417  -51.001  49.853  6
833927  102.436  -51.023  49.809  6
833928  102.452  -51.034  49.766  6
833929  102.468  -51.045  49.725  6
833930  102.483  -51.056  49.686  6
833931  102.499  -51.067  49.650  6
833932  102.518  -51.086  49.616  6
833933  102.537  -51.105  49.585  6
833934  102.556  -51.126  49.558  6
833935  102.575  -51.146  49.533  6
833936  102.594  -51.166  49.511  6
833937  102.613  -51.186  49.489  6
833938  102.632  -51.206  49.468  6
833939  102.651  -51.227  49.443  6
833940  102.670  -51.246  49.417  6
833941  102.689  -51.267  49.389  6
833942  102.709  -51.287  49.359  6
833943  102.728  -51.307  49.326  6
833944  102.746  -51.327  49.293  6
833945  102.765  -51.347  49.262  6
833946  102.784  -51.367  49.233  6
833947  102.795  -51.387  49.203  6
833948  102.798  -51.406  49.177  6
833949  102.777  -51.407  49.150  6
833950  102.747  -51.400  49.123  6
833951  102.729  -51.399  49.098  6
833952  102.757  -51.413  49.070  6
833953  102.785  -51.428  49.041  6
833954  102.813  -51.443  49.013  6
833955  102.840  -51.457  48.984  6
833956  102.868  -51.472  48.956  6
833957  102.896  -51.487  48.926  6
833958  102.924  -51.501  48.896  6
833959  102.951  -51.516  48.865  6
833960  102.979  -51.531  48.835  6
833961  103.007  -51.545  48.804  6
833962  103.034  -51.560  48.776  6
833963  103.062  -51.575  48.747  6
833964  103.090  -51.589  48.719  6
833965  103.117  -51.604  48.693  6
833966  103.145  -51.619  48.667  6
834608  101.835  -50.709  50.615  6
834609  101.864  -50.728  50.571  6
834610  101.895  -50.741  50.527  6
834611  101.926  -50.756  50.484  6
834612  101.957  -50.770  50.440  6
834613  101.988  -50.785  50.397  6
834614  102.020  -50.798  50.353  6
834615  102.051  -50.813  50.309  6
834616  102.082  -50.827  50.268  6
834617  102.113  -50.842  50.226  6
834618  102.144  -50.855  50.185  6
834619  102.176  -50.870  50.145  6
834620  102.207  -50.884  50.108  6
834621  102.238  -50.898  50.072  6
834622  102.269  -50.912  50.040  6
834623  102.301  -50.926  50.010  6
834624  102.332  -50.941  49.978  6
834625  102.363  -50.954  49.942  6
834626  102.394  -50.969  49.902  6
834627  102.428  -50.977  49.858  6
834628  102.447  -50.998  49.816  6
834629  102.463  -51.011  49.774  6
834630  102.478  -51.022  49.734  6
834631  102.495  -51.035  49.695  6
834632  102.514  -51.055  49.659  6
834633  102.533  -51.075  49.626  6
834634  102.552  -51.096  49.595  6
834635  102.572  -51.116  49.569  6
834636  102.591  -51.136  49.545  6
834637  102.609  -51.156  49.522  6
834638  102.628  -51.176  49.499  6
834639  102.647  -51.196  49.476  6
834640  102.667  -51.216  49.451  6
834641  102.686  -51.236  49.426  6
834642  102.705  -51.256  49.398  6
834643  102.724  -51.277  49.370  6
834644  102.743  -51.296  49.339  6
834645  102.762  -51.317  49.307  6
834646  102.781  -51.337  49.276  6
834647  102.800  -51.357  49.248  6
834648  102.818  -51.377  49.220  6
834649  102.820  -51.396  49.194  6
834650  102.802  -51.399  49.169  6
834651  102.771  -51.392  49.143  6
834652  102.744  -51.387  49.117  6
834653  102.772  -51.401  49.089  6
834654  102.800  -51.416  49.060  6
834655  102.827  -51.431  49.032  6
834656  102.855  -51.445  49.004  6
834657  102.883  -51.460  48.975  6
834658  102.911  -51.475  48.945  6
834659  102.939  -51.489  48.914  6
834660  102.966  -51.504  48.882  6
834661  102.994  -51.519  48.851  6
834662  103.022  -51.533  48.820  6
834663  103.049  -51.548  48.790  6
834664  103.077  -51.562  48.761  6
834665  103.105  -51.578  48.732  6
834666  103.132  -51.592  48.705  6
834667  103.160  -51.606  48.680  6
834668  103.188  -51.622  48.655  6
835310  101.865  -50.706  50.580  6
835311  101.896  -50.719  50.536  6
835312  101.927  -50.734  50.492  6
835313  101.959  -50.748  50.448  6
835314  101.990  -50.762  50.404  6
835315  102.021  -50.776  50.359  6
835316  102.052  -50.791  50.316  6
835317  102.084  -50.805  50.274  6
835318  102.115  -50.819  50.232  6
835319  102.146  -50.833  50.191  6
835320  102.177  -50.848  50.151  6
835321  102.208  -50.861  50.112  6
835322  102.239  -50.876  50.075  6
835323  102.270  -50.890  50.042  6
835324  102.302  -50.904  50.011  6
835325  102.333  -50.918  49.979  6
835326  102.364  -50.933  49.943  6
835327  102.395  -50.947  49.904  6
835328  102.427  -50.961  49.863  6
835329  102.457  -50.974  49.822  6
835330  102.474  -50.988  49.781  6
835331  102.491  -51.005  49.742  6
835332  102.511  -51.025  49.704  6
835333  102.530  -51.045  49.668  6
835334  102.549  -51.065  49.635  6
835335  102.568  -51.086  49.605  6
835336  102.587  -51.105  49.579  6
835337  102.606  -51.126  49.555  6
835338  102.625  -51.146  49.532  6
835339  102.644  -51.166  49.508  6
835340  102.663  -51.186  49.484  6
835341  102.682  -51.206  49.459  6
835342  102.701  -51.226  49.434  6
835343  102.721  -51.246  49.407  6
835344  102.740  -51.267  49.380  6
835345  102.759  -51.287  49.351  6
835346  102.777  -51.307  49.320  6
835347  102.797  -51.327  49.291  6
835348  102.816  -51.347  49.264  6
835349  102.835  -51.367  49.238  6
835350  102.843  -51.387  49.211  6
835351  102.826  -51.390  49.188  6
835352  102.796  -51.384  49.163  6
835353  102.765  -51.377  49.136  6
835354  102.787  -51.390  49.108  6
835355  102.815  -51.404  49.080  6
835356  102.842  -51.418  49.051  6
835357  102.870  -51.434  49.023  6
835358  102.898  -51.448  48.994  6
835359  102.926  -51.462  48.964  6
835360  102.953  -51.478  48.931  6
835361  102.981  -51.492  48.900  6
835362  103.009  -51.506  48.868  6
835363  103.037  -51.522  48.836  6
835364  103.065  -51.536  48.806  6
835365  103.092  -51.550  48.776  6
835366  103.120  -51.566  48.747  6
835367  103.148  -51.580  48.718  6
835368  103.175  -51.594  48.692  6
835369  103.203  -51.609  48.668  6
836012  101.898  -50.698  50.543  6
836013  101.929  -50.712  50.499  6
836014  101.960  -50.726  50.455  6
836015  101.991  -50.740  50.411  6
836016  102.022  -50.754  50.365  6
836017  102.053  -50.769  50.323  6
836018  102.085  -50.782  50.280  6
836019  102.116  -50.797  50.238  6
836020  102.147  -50.811  50.196  6
836021  102.178  -50.826  50.156  6
836022  102.209  -50.839  50.116  6
836023  102.241  -50.854  50.079  6
836024  102.272  -50.868  50.045  6
836025  102.303  -50.882  50.011  6
836026  102.334  -50.896  49.978  6
836027  102.366  -50.911  49.942  6
836028  102.397  -50.925  49.904  6
836029  102.428  -50.939  49.866  6
836030  102.459  -50.953  49.828  6
836031  102.484  -50.972  49.788  6
836032  102.503  -50.992  49.749  6
836033  102.524  -51.014  49.711  6
836034  102.545  -51.035  49.676  6
836035  102.564  -51.055  49.643  6
836036  102.584  -51.075  49.614  6
836037  102.603  -51.096  49.589  6
836038  102.622  -51.115  49.565  6
836039  102.641  -51.136  49.541  6
836040  102.660  -51.156  49.517  6
836041  102.679  -51.176  49.493  6
836042  102.698  -51.196  49.468  6
836043  102.717  -51.216  49.442  6
836044  102.736  -51.236  49.416  6
836045  102.755  -51.256  49.390  6
836046  102.774  -51.277  49.362  6
836047  102.793  -51.296  49.333  6
836048  102.812  -51.317  49.306  6
836049  102.831  -51.337  49.281  6
836050  102.851  -51.357  49.254  6
836051  102.866  -51.377  49.229  6
836052  102.851  -51.382  49.208  6
836053  102.820  -51.375  49.182  6
836054  102.790  -51.368  49.155  6
836055  102.802  -51.378  49.128  6
836056  102.830  -51.392  49.100  6
836057  102.858  -51.407  49.071  6
836058  102.885  -51.421  49.042  6
836059  102.913  -51.436  49.012  6
836060  102.941  -51.451  48.982  6
836061  102.968  -51.465  48.949  6
836062  102.996  -51.480  48.917  6
836063  103.024  -51.495  48.885  6
836064  103.051  -51.509  48.852  6
836065  103.080  -51.524  48.821  6
836066  103.107  -51.539  48.791  6
836067  103.135  -51.553  48.762  6
836068  103.163  -51.568  48.734  6
836069  103.190  -51.583  48.706  6
836070  103.218  -51.597  48.681  6
836714  101.930  -50.689  50.504  6
836715  101.961  -50.704  50.461  6
836716  101.992  -50.718  50.416  6
836717  102.024  -50.732  50.372  6
836718  102.055  -50.746  50.328  6
836719  102.086  -50.760  50.284  6
836720  102.117  -50.775  50.243  6
836721  102.149  -50.789  50.201  6
836722  102.180  -50.803  50.160  6
836723  102.211  -50.817  50.121  6
836724  102.242  -50.832  50.083  6
836725  102.273  -50.845  50.047  6
836726  102.305  -50.860  50.012  6
836727  102.336  -50.874  49.976  6
836728  102.367  -50.889  49.940  6
836729  102.398  -50.902  49.903  6
836730  102.430  -50.917  49.867  6
836731  102.460  -50.931  49.831  6
836732  102.485  -50.954  49.792  6
836733  102.510  -50.976  49.754  6
836734  102.526  -50.994  49.717  6
836735  102.540  -51.011  49.683  6
836736  102.560  -51.031  49.651  6
836737  102.581  -51.053  49.623  6
836738  102.602  -51.074  49.598  6
836739  102.624  -51.096  49.574  6
836740  102.645  -51.117  49.551  6
836741  102.666  -51.139  49.526  6
836742  102.687  -51.161  49.501  6
836743  102.709  -51.183  49.478  6
836744  102.730  -51.205  49.454  6
836745  102.751  -51.226  49.429  6
836746  102.771  -51.246  49.402  6
836747  102.790  -51.266  49.375  6
836748  102.809  -51.287  49.348  6
836749  102.828  -51.307  49.321  6
836750  102.847  -51.327  49.296  6
836751  102.866  -51.347  49.271  6
836752  102.885  -51.367  49.246  6
836753  102.875  -51.374  49.224  6
836754  102.845  -51.367  49.199  6
836755  102.815  -51.360  49.174  6
836756  102.817  -51.365  49.147  6
836757  102.845  -51.381  49.120  6
836758  102.873  -51.395  49.089  6
836759  102.900  -51.409  49.057  6
836760  102.928  -51.425  49.027  6
836761  102.956  -51.439  48.998  6
836762  102.983  -51.453  48.966  6
836763  103.011  -51.468  48.934  6
836764  103.039  -51.483  48.902  6
836765  103.067  -51.497  48.869  6
836766  103.094  -51.512  48.838  6
836767  103.122  -51.527  48.807  6
836768  103.150  -51.541  48.778  6
836769  103.178  -51.556  48.749  6
836770  103.206  -51.571  48.720  6
836771  103.233  -51.585  48.695  6
837415  101.932  -50.667  50.510  6
837416  101.963  -50.682  50.466  6
837417  101.994  -50.696  50.422  6
837418  102.025  -50.710  50.378  6
837419  102.056  -50.724  50.334  6
837420  102.088  -50.738  50.290  6
837421  102.119  -50.753  50.248  6
837422  102.150  -50.766  50.207  6
837423  102.181  -50.781  50.166  6
837424  102.212  -50.795  50.126  6
837425  102.244  -50.810  50.088  6
837426  102.275  -50.823  50.050  6
837427  102.306  -50.838  50.014  6
837428  102.337  -50.852  49.978  6
837429  102.368  -50.866  49.941  6
837430  102.399  -50.880  49.904  6
837431  102.430  -50.895  49.869  6
837432  102.459  -50.912  49.833  6
837433  102.484  -50.934  49.796  6
837434  102.509  -50.957  49.759  6
837435  102.533  -50.979  49.724  6
837436  102.554  -50.999  49.690  6
837437  102.568  -51.016  49.659  6
837438  102.582  -51.033  49.631  6
837439  102.596  -51.049  49.606  6
837440  102.617  -51.070  49.583  6
837441  102.638  -51.092  49.559  6
837442  102.659  -51.114  49.534  6
837443  102.681  -51.136  49.510  6
837444  102.702  -51.157  49.489  6
837445  102.723  -51.179  49.466  6
837446  102.744  -51.200  49.442  6
837447  102.766  -51.222  49.415  6
837448  102.787  -51.243  49.388  6
837449  102.808  -51.265  49.362  6
837450  102.829  -51.287  49.335  6
837451  102.851  -51.309  49.311  6
837452  102.872  -51.331  49.286  6
837453  102.893  -51.352  49.263  6
837454  102.899  -51.365  49.240  6
837455  102.869  -51.359  49.215  6
837456  102.839  -51.352  49.190  6
837457  102.832  -51.354  49.165  6
837458  102.860  -51.368  49.137  6
837459  102.888  -51.383  49.106  6
837460  102.915  -51.398  49.073  6
837461  102.943  -51.412  49.043  6
837462  102.971  -51.427  49.014  6
837463  102.999  -51.442  48.982  6
837464  103.026  -51.456  48.950  6
837465  103.054  -51.471  48.918  6
837466  103.082  -51.486  48.885  6
837467  103.109  -51.500  48.855  6
837468  103.137  -51.515  48.823  6
837469  103.165  -51.530  48.793  6
837470  103.192  -51.544  48.764  6
837471  103.220  -51.559  48.735  6
837472  103.248  -51.574  48.708  6
838117  101.964  -50.660  50.473  6
838118  101.995  -50.673  50.429  6
838119  102.027  -50.688  50.384  6
838120  102.058  -50.702  50.340  6
838121  102.089  -50.716  50.297  6
838122  102.120  -50.730  50.255  6
838123  102.151  -50.745  50.213  6
838124  102.182  -50.759  50.173  6
838125  102.214  -50.773  50.132  6
838126  102.245  -50.787  50.093  6
838127  102.276  -50.801  50.054  6
838128  102.307  -50.816  50.017  6
838129  102.338  -50.829  49.980  6
838130  102.370  -50.844  49.944  6
838131  102.401  -50.858  49.907  6
838132  102.432  -50.873  49.871  6
838133  102.459  -50.892  49.836  6
838134  102.483  -50.915  49.800  6
838135  102.508  -50.937  49.764  6
838136  102.533  -50.960  49.730  6
838137  102.557  -50.982  49.697  6
838138  102.582  -51.005  49.667  6
838139  102.596  -51.021  49.639  6
838140  102.610  -51.038  49.614  6
838141  102.624  -51.055  49.591  6
838142  102.638  -51.071  49.568  6
838143  102.653  -51.088  49.544  6
838144  102.674  -51.110  49.521  6
838145  102.695  -51.131  49.500  6
838146  102.716  -51.153  49.479  6
838147  102.737  -51.174  49.454  6
838148  102.759  -51.196  49.428  6
838149  102.780  -51.218  49.401  6
838150  102.801  -51.240  49.375  6
838151  102.823  -51.261  49.349  6
838152  102.844  -51.283  49.325  6
838153  102.865  -51.305  49.302  6
838154  102.886  -51.326  49.279  6
838155  102.908  -51.348  49.255  6
838156  102.894  -51.350  49.230  6
838157  102.864  -51.343  49.205  6
838158  102.847  -51.342  49.180  6
838159  102.875  -51.356  49.152  6
838160  102.903  -51.371  49.121  6
838161  102.930  -51.386  49.089  6
838162  102.958  -51.400  49.059  6
838163  102.986  -51.415  49.030  6
838164  103.014  -51.430  48.998  6
838165  103.041  -51.444  48.966  6
838166  103.069  -51.459  48.934  6
838167  103.097  -51.474  48.902  6
838168  103.124  -51.488  48.871  6
838169  103.152  -51.503  48.839  6
838170  103.180  -51.518  48.808  6
838171  103.208  -51.532  48.779  6
838172  103.235  -51.547  48.750  6
838173  103.263  -51.562  48.722  6
838819  101.996  -50.651  50.436  6
838820  102.028  -50.666  50.391  6
838821  102.059  -50.680  50.346  6
838822  102.090  -50.694  50.304  6
838823  102.121  -50.708  50.262  6
838824  102.153  -50.723  50.220  6
838825  102.184  -50.737  50.179  6
838826  102.215  -50.751  50.139  6
838827  102.246  -50.765  50.099  6
838828  102.277  -50.779  50.059  6
838829  102.309  -50.794  50.022  6
838830  102.340  -50.807  49.985  6
838831  102.371  -50.822  49.949  6
838832  102.402  -50.836  49.912  6
838833  102.433  -50.851  49.876  6
838834  102.458  -50.873  49.840  6
838835  102.482  -50.895  49.804  6
838836  102.507  -50.918  49.769  6
838837  102.532  -50.940  49.736  6
838838  102.556  -50.963  49.704  6
838839  102.581  -50.985  49.674  6
838840  102.606  -51.008  49.647  6
838841  102.623  -51.026  49.622  6
838842  102.638  -51.043  49.599  6
838843  102.652  -51.060  49.577  6
838844  102.666  -51.077  49.555  6
838845  102.680  -51.093  49.534  6
838846  102.694  -51.110  49.512  6
838847  102.709  -51.127  49.489  6
838848  102.730  -51.149  49.465  6
838849  102.752  -51.171  49.438  6
838850  102.773  -51.192  49.413  6
838851  102.794  -51.214  49.388  6
838852  102.816  -51.235  49.364  6
838853  102.837  -51.257  49.340  6
838854  102.858  -51.279  49.317  6
838855  102.879  -51.300  49.294  6
838856  102.901  -51.322  49.271  6
838857  102.918  -51.341  49.246  6
838858  102.888  -51.335  49.221  6
838859  102.863  -51.330  49.194  6
838860  102.890  -51.345  49.166  6
838861  102.918  -51.359  49.136  6
838862  102.946  -51.374  49.106  6
838863  102.973  -51.389  49.076  6
838864  103.001  -51.403  49.047  6
838865  103.029  -51.418  49.016  6
838866  103.056  -51.433  48.984  6
838867  103.084  -51.447  48.951  6
838868  103.112  -51.462  48.918  6
838869  103.140  -51.477  48.887  6
838870  103.167  -51.491  48.855  6
838871  103.195  -51.506  48.824  6
838872  103.223  -51.521  48.795  6
838873  103.250  -51.535  48.766  6
838874  103.278  -51.550  48.738  6
839520  101.998  -50.629  50.443  6
839521  102.029  -50.644  50.399  6
839522  102.060  -50.657  50.355  6
839523  102.092  -50.672  50.311  6
839524  102.123  -50.686  50.269  6
839525  102.154  -50.701  50.227  6
839526  102.185  -50.714  50.186  6
839527  102.217  -50.729  50.146  6
839528  102.248  -50.743  50.106  6
839529  102.279  -50.757  50.067  6
839530  102.310  -50.771  50.029  6
839531  102.341  -50.785  49.992  6
839532  102.373  -50.800  49.955  6
839533  102.404  -50.813  49.917  6
839534  102.432  -50.831  49.881  6
839535  102.457  -50.854  49.845  6
839536  102.481  -50.876  49.810  6
839537  102.506  -50.898  49.775  6
839538  102.531  -50.921  49.743  6
839539  102.555  -50.943  49.712  6
839540  102.580  -50.966  49.683  6
839541  102.605  -50.988  49.655  6
839542  102.629  -51.011  49.630  6
839543  102.650  -51.031  49.607  6
839544  102.665  -51.048  49.585  6
839545  102.679  -51.064  49.565  6
839546  102.693  -51.081  49.544  6
839547  102.708  -51.099  49.522  6
839548  102.722  -51.115  49.499  6
839549  102.736  -51.132  49.475  6
839550  102.750  -51.149  49.450  6
839551  102.766  -51.166  49.426  6
839552  102.787  -51.188  49.403  6
839553  102.809  -51.209  49.379  6
839554  102.830  -51.231  49.356  6
839555  102.851  -51.253  49.333  6
839556  102.872  -51.274  49.311  6
839557  102.894  -51.296  49.288  6
839558  102.915  -51.318  49.263  6
839559  102.912  -51.326  49.237  6
839560  102.882  -51.320  49.210  6
839561  102.905  -51.333  49.182  6
839562  102.933  -51.347  49.153  6
839563  102.961  -51.362  49.124  6
839564  102.988  -51.377  49.094  6
839565  103.016  -51.391  49.065  6
839566  103.044  -51.406  49.034  6
839567  103.072  -51.421  49.002  6
839568  103.099  -51.435  48.969  6
839569  103.127  -51.450  48.935  6
839570  103.155  -51.465  48.903  6
839571  103.182  -51.479  48.872  6
839572  103.210  -51.494  48.841  6
839573  103.238  -51.509  48.811  6
839574  103.265  -51.523  48.782  6
839575  103.293  -51.538  48.754  6
840222  102.031  -50.622  50.406  6
840223  102.062  -50.635  50.362  6
840224  102.093  -50.650  50.319  6
840225  102.124  -50.664  50.276  6
840226  102.156  -50.678  50.235  6
840227  102.187  -50.692  50.193  6
840228  102.218  -50.707  50.153  6
840229  102.249  -50.721  50.113  6
840230  102.280  -50.735  50.073  6
840231  102.311  -50.749  50.035  6
840232  102.342  -50.763  49.998  6
840233  102.374  -50.778  49.961  6
840234  102.405  -50.791  49.923  6
840235  102.432  -50.812  49.887  6
840236  102.456  -50.834  49.851  6
840237  102.481  -50.857  49.816  6
840238  102.506  -50.879  49.782  6
840239  102.530  -50.901  49.750  6
840240  102.554  -50.924  49.720  6
840241  102.579  -50.946  49.691  6
840242  102.604  -50.969  49.664  6
840243  102.628  -50.991  49.638  6
840244  102.653  -51.014  49.615  6
840245  102.678  -51.036  49.594  6
840246  102.692  -51.053  49.573  6
840247  102.706  -51.070  49.553  6
840248  102.721  -51.086  49.532  6
840249  102.735  -51.103  49.510  6
840250  102.749  -51.120  49.486  6
840251  102.763  -51.136  49.463  6
840252  102.777  -51.153  49.441  6
840253  102.792  -51.171  49.418  6
840254  102.806  -51.187  49.394  6
840255  102.823  -51.205  49.372  6
840256  102.844  -51.227  49.349  6
840257  102.866  -51.249  49.328  6
840258  102.887  -51.271  49.305  6
840259  102.908  -51.292  49.280  6
840260  102.929  -51.314  49.255  6
840261  102.906  -51.311  49.228  6
840262  102.921  -51.321  49.200  6
840263  102.948  -51.335  49.172  6
840264  102.976  -51.350  49.142  6
840265  103.004  -51.365  49.113  6
840266  103.031  -51.379  49.084  6
840267  103.059  -51.394  49.053  6
840268  103.087  -51.409  49.020  6
840269  103.114  -51.423  48.986  6
840270  103.142  -51.438  48.952  6
840271  103.170  -51.453  48.921  6
840272  103.197  -51.468  48.890  6
840273  103.225  -51.482  48.858  6
840274  103.253  -51.497  48.828  6
840275  103.281  -51.512  48.799  6
840276  103.308  -51.526  48.771  6
840923  102.032  -50.599  50.413  6
840924  102.063  -50.613  50.369  6
840925  102.094  -50.628  50.326  6
840926  102.125  -50.641  50.283  6
840927  102.157  -50.656  50.241  6
840928  102.188  -50.670  50.200  6
840929  102.219  -50.685  50.159  6
840930  102.250  -50.698  50.119  6
840931  102.281  -50.713  50.079  6
840932  102.313  -50.727  50.042  6
840933  102.344  -50.741  50.003  6
840934  102.375  -50.755  49.965  6
840935  102.406  -50.770  49.929  6
840936  102.430  -50.792  49.893  6
840937  102.455  -50.815  49.857  6
840938  102.480  -50.837  49.823  6
840939  102.504  -50.860  49.789  6
840940  102.529  -50.882  49.757  6
840941  102.554  -50.904  49.727  6
840942  102.579  -50.927  49.699  6
840943  102.603  -50.949  49.672  6
840944  102.628  -50.972  49.646  6
840945  102.653  -50.994  49.625  6
840946  102.677  -51.017  49.603  6
840947  102.701  -51.039  49.582  6
840948  102.720  -51.058  49.563  6
840949  102.734  -51.075  49.543  6
840950  102.748  -51.092  49.521  6
840951  102.763  -51.108  49.499  6
840952  102.777  -51.125  49.478  6
840953  102.791  -51.142  49.456  6
840954  102.805  -51.158  49.433  6
840955  102.819  -51.175  49.409  6
840956  102.833  -51.192  49.387  6
840957  102.848  -51.208  49.365  6
840958  102.862  -51.226  49.344  6
840959  102.880  -51.245  49.323  6
840960  102.901  -51.266  49.299  6
840961  102.922  -51.288  49.275  6
840962  102.931  -51.302  49.249  6
840963  102.936  -51.309  49.221  6
840964  102.963  -51.324  49.192  6
840965  102.991  -51.338  49.163  6
840966  103.019  -51.352  49.133  6
840967  103.046  -51.368  49.103  6
840968  103.074  -51.382  49.071  6
840969  103.102  -51.396  49.038  6
840970  103.129  -51.412  49.004  6
840971  103.157  -51.426  48.971  6
840972  103.184  -51.441  48.939  6
840973  103.211  -51.456  48.908  6
840974  103.237  -51.471  48.876  6
840975  103.264  -51.485  48.845  6
841625  102.064  -50.591  50.374  6
841626  102.096  -50.606  50.331  6
841627  102.127  -50.619  50.289  6
841628  102.158  -50.634  50.247  6
841629  102.189  -50.648  50.206  6
841630  102.221  -50.662  50.165  6
841631  102.252  -50.676  50.125  6
841632  102.283  -50.691  50.086  6
841633  102.314  -50.705  50.047  6
841634  102.345  -50.719  50.009  6
841635  102.377  -50.733  49.971  6
841636  102.405  -50.751  49.934  6
841637  102.430  -50.773  49.898  6
841638  102.454  -50.795  49.863  6
841639  102.479  -50.818  49.828  6
841640  102.504  -50.840  49.796  6
841641  102.528  -50.863  49.764  6
841642  102.553  -50.886  49.734  6
841643  102.578  -50.907  49.706  6
841644  102.602  -50.930  49.680  6
841645  102.627  -50.952  49.655  6
841646  102.652  -50.975  49.633  6
841647  102.676  -50.997  49.611  6
841648  102.701  -51.020  49.591  6
841649  102.726  -51.042  49.574  6
841650  102.748  -51.063  49.554  6
841651  102.762  -51.080  49.533  6
841652  102.776  -51.097  49.512  6
841653  102.790  -51.114  49.492  6
841654  102.805  -51.130  49.470  6
841655  102.819  -51.147  49.447  6
841656  102.833  -51.164  49.424  6
841657  102.847  -51.180  49.402  6
841658  102.861  -51.197  49.381  6
841659  102.875  -51.214  49.361  6
841660  102.890  -51.230  49.340  6
841661  102.904  -51.247  49.318  6
841662  102.918  -51.264  49.295  6
841663  102.937  -51.284  49.270  6
841664  102.951  -51.297  49.243  6
841665  102.978  -51.312  49.214  6
841666  103.006  -51.326  49.184  6
841667  103.033  -51.341  49.154  6
841668  103.059  -51.356  49.123  6
841669  103.086  -51.371  49.090  6
841670  103.113  -51.385  49.057  6
841671  103.140  -51.400  49.023  6
841672  103.167  -51.415  48.990  6
841673  103.193  -51.430  48.957  6
841674  103.220  -51.445  48.925  6
841675  103.247  -51.459  48.894  6
842327  102.097  -50.583  50.338  6
842328  102.128  -50.597  50.295  6
842329  102.160  -50.612  50.254  6
842330  102.191  -50.625  50.213  6
842331  102.222  -50.640  50.172  6
842332  102.253  -50.654  50.132  6
842333  102.284  -50.669  50.092  6
842334  102.316  -50.682  50.054  6
842335  102.347  -50.697  50.015  6
842336  102.378  -50.711  49.977  6
842337  102.404  -50.732  49.940  6
842338  102.429  -50.754  49.903  6
842339  102.454  -50.776  49.869  6
842340  102.478  -50.798  49.835  6
842341  102.503  -50.821  49.803  6
842342  102.527  -50.843  49.771  6
842343  102.552  -50.866  49.741  6
842344  102.577  -50.889  49.714  6
842345  102.601  -50.911  49.688  6
842346  102.626  -50.933  49.664  6
842347  102.650  -50.955  49.641  6
842348  102.675  -50.978  49.619  6
842349  102.700  -51.000  49.600  6
842350  102.725  -51.023  49.584  6
842351  102.749  -51.045  49.566  6
842352  102.774  -51.067  49.545  6
842353  102.790  -51.085  49.525  6
842354  102.804  -51.102  49.505  6
842355  102.818  -51.118  49.484  6
842356  102.832  -51.135  49.461  6
842357  102.846  -51.152  49.438  6
842358  102.861  -51.169  49.417  6
842359  102.875  -51.186  49.398  6
842360  102.889  -51.202  49.379  6
842361  102.903  -51.219  49.357  6
842362  102.917  -51.236  49.338  6
842363  102.931  -51.252  49.317  6
842364  102.946  -51.269  49.294  6
842365  102.962  -51.286  49.266  6
842366  102.989  -51.300  49.236  6
842367  103.016  -51.315  49.206  6
842368  103.043  -51.330  49.175  6
842369  103.070  -51.345  49.143  6
842370  103.096  -51.359  49.110  6
842371  103.123  -51.374  49.077  6
842372  103.150  -51.389  49.042  6
842373  103.176  -51.404  49.009  6
842374  103.204  -51.418  48.976  6
842375  103.230  -51.434  48.944  6
843029  102.130  -50.575  50.303  6
843030  102.161  -50.589  50.261  6
843031  102.192  -50.603  50.220  6
843032  102.223  -50.618  50.179  6
843033  102.254  -50.632  50.138  6
843034  102.286  -50.646  50.099  6
843035  102.317  -50.660  50.060  6
843036  102.348  -50.675  50.021  6
843037  102.379  -50.689  49.984  6
843038  102.403  -50.712  49.945  6
843039  102.428  -50.735  49.910  6
843040  102.453  -50.757  49.876  6
843041  102.477  -50.779  49.843  6
843042  102.502  -50.801  49.810  6
843043  102.527  -50.824  49.779  6
843044  102.551  -50.846  49.750  6
843045  102.576  -50.869  49.722  6
843046  102.601  -50.892  49.697  6
843047  102.625  -50.914  49.673  6
843048  102.650  -50.936  49.650  6
843049  102.674  -50.958  49.628  6
843050  102.699  -50.981  49.610  6
843051  102.724  -51.003  49.594  6
843052  102.748  -51.026  49.577  6
843053  102.773  -51.049  49.557  6
843054  102.798  -51.070  49.538  6
843055  102.817  -51.090  49.519  6
843056  102.831  -51.107  49.498  6
843057  102.845  -51.124  49.475  6
843058  102.860  -51.140  49.452  6
843059  102.874  -51.157  49.432  6
843060  102.888  -51.174  49.414  6
843061  102.902  -51.190  49.396  6
843062  102.916  -51.207  49.377  6
843063  102.930  -51.224  49.359  6
843064  102.945  -51.241  49.340  6
843065  102.959  -51.258  49.317  6
843066  102.973  -51.274  49.290  6
843067  102.999  -51.290  49.261  6
843068  103.026  -51.304  49.230  6
843069  103.052  -51.319  49.198  6
843070  103.079  -51.334  49.165  6
843071  103.106  -51.349  49.131  6
843072  103.133  -51.363  49.097  6
843073  103.160  -51.378  49.062  6
843074  103.186  -51.393  49.029  6
843075  103.213  -51.408  48.996  6
843076  103.240  -51.422  48.963  6
843077  103.267  -51.437  48.932  6
843733  102.225  -50.596  50.187  6
843734  102.256  -50.610  50.147  6
843735  102.287  -50.624  50.107  6
843736  102.318  -50.638  50.068  6
843737  102.349  -50.653  50.030  6
843738  102.378  -50.670  49.992  6
843739  102.402  -50.692  49.954  6
843740  102.427  -50.715  49.919  6
843741  102.452  -50.738  49.884  6
843742  102.476  -50.760  49.851  6
843743  102.501  -50.782  49.819  6
843744  102.526  -50.804  49.788  6
843745  102.550  -50.827  49.759  6
843746  102.575  -50.849  49.731  6
843747  102.600  -50.872  49.706  6
843748  102.624  -50.895  49.682  6
843749  102.649  -50.917  49.659  6
843750  102.674  -50.939  49.638  6
843751  102.698  -50.961  49.619  6
843752  102.723  -50.984  49.604  6
843753  102.748  -51.006  49.587  6
843754  102.772  -51.029  49.568  6
843755  102.797  -51.052  49.549  6
843756  102.821  -51.074  49.531  6
843757  102.844  -51.096  49.510  6
843758  102.859  -51.112  49.487  6
843759  102.873  -51.129  49.465  6
843760  102.887  -51.146  49.446  6
843761  102.901  -51.162  49.430  6
843762  102.915  -51.179  49.413  6
843763  102.930  -51.196  49.397  6
843764  102.944  -51.212  49.380  6
843765  102.958  -51.229  49.364  6
843766  102.972  -51.246  49.340  6
843767  102.986  -51.262  49.313  6
843768  103.009  -51.278  49.285  6
843769  103.035  -51.293  49.254  6
843770  103.062  -51.308  49.221  6
843771  103.089  -51.322  49.188  6
843772  103.116  -51.337  49.153  6
843773  103.143  -51.352  49.118  6
843774  103.169  -51.367  49.084  6
843775  103.196  -51.382  49.049  6
843776  103.223  -51.396  49.016  6
843777  103.250  -51.412  48.983  6
843778  103.277  -51.426  48.952  6
844439  102.377  -50.650  50.001  6
844440  102.402  -50.673  49.963  6
844441  102.427  -50.695  49.928  6
844442  102.451  -50.718  49.893  6
844443  102.476  -50.741  49.859  6
844444  102.501  -50.763  49.828  6
844445  102.525  -50.785  49.797  6
844446  102.549  -50.807  49.768  6
844447  102.574  -50.830  49.741  6
844448  102.599  -50.852  49.715  6
844449  102.623  -50.875  49.690  6
844450  102.648  -50.898  49.667  6
844451  102.673  -50.920  49.647  6
844452  102.697  -50.942  49.628  6
844453  102.722  -50.964  49.612  6
844454  102.747  -50.987  49.595  6
844455  102.771  -51.009  49.577  6
844456  102.796  -51.032  49.559  6
844457  102.821  -51.055  49.541  6
844458  102.845  -51.077  49.520  6
844459  102.870  -51.099  49.498  6
844460  102.886  -51.117  49.478  6
844461  102.900  -51.134  49.461  6
844462  102.915  -51.151  49.446  6
844463  102.929  -51.168  49.430  6
844464  102.943  -51.184  49.415  6
844465  102.957  -51.201  49.401  6
844466  102.971  -51.218  49.386  6
844467  102.985  -51.234  49.363  6
844468  103.000  -51.251  49.336  6
844469  103.019  -51.267  49.308  6
844470  103.045  -51.282  49.277  6
844471  103.072  -51.296  49.245  6
844472  103.099  -51.312  49.211  6
844473  103.125  -51.326  49.176  6
844474  103.152  -51.341  49.141  6
844475  103.179  -51.356  49.105  6
844476  103.206  -51.371  49.071  6
844477  103.233  -51.385  49.037  6
844478  103.259  -51.400  49.004  6
844479  103.286  -51.415  48.972  6
845143  102.450  -50.698  49.903  6
845144  102.475  -50.721  49.869  6
845145  102.500  -50.744  49.837  6
845146  102.524  -50.766  49.805  6
845147  102.549  -50.788  49.777  6
845148  102.574  -50.810  49.749  6
845149  102.598  -50.833  49.723  6
845150  102.623  -50.855  49.698  6
845151  102.647  -50.878  49.676  6
845152  102.672  -50.901  49.655  6
845153  102.696  -50.923  49.636  6
845154  102.721  -50.945  49.619  6
845155  102.746  -50.967  49.601  6
845156  102.770  -50.990  49.583  6
845157  102.795  -51.012  49.565  6
845158  102.820  -51.035  49.548  6
845159  102.844  -51.058  49.530  6
845160  102.869  -51.080  49.510  6
845161  102.894  -51.102  49.491  6
845162  102.914  -51.122  49.475  6
845163  102.928  -51.139  49.461  6
845164  102.942  -51.155  49.448  6
845165  102.957  -51.172  49.434  6
845166  102.971  -51.189  49.419  6
845167  102.985  -51.206  49.406  6
845168  102.999  -51.223  49.384  6
845169  103.013  -51.240  49.359  6
845170  103.028  -51.256  49.331  6
845171  103.055  -51.271  49.300  6
845172  103.082  -51.286  49.267  6
845173  103.109  -51.300  49.234  6
845174  103.135  -51.315  49.199  6
845175  103.162  -51.330  49.163  6
845176  103.189  -51.345  49.127  6
845177  103.216  -51.359  49.093  6
845178  103.242  -51.374  49.058  6
845179  103.269  -51.389  49.025  6
845180  103.296  -51.404  48.993  6
845181  103.323  -51.418  48.962  6
845844  102.449  -50.679  49.912  6
845845  102.474  -50.701  49.878  6
845846  102.499  -50.724  49.846  6
845847  102.523  -50.747  49.815  6
845848  102.548  -50.769  49.786  6
845849  102.573  -50.791  49.758  6
845850  102.597  -50.813  49.732  6
845851  102.622  -50.836  49.707  6
845852  102.647  -50.858  49.684  6
845853  102.671  -50.881  49.662  6
845854  102.696  -50.904  49.643  6
845855  102.721  -50.926  49.624  6
845856  102.745  -50.948  49.606  6
845857  102.769  -50.970  49.588  6
845858  102.794  -50.993  49.571  6
845859  102.819  -51.015  49.554  6
845860  102.843  -51.038  49.537  6
845861  102.868  -51.061  49.519  6
845862  102.893  -51.083  49.502  6
845863  102.917  -51.105  49.488  6
845864  102.942  -51.127  49.476  6
845865  102.956  -51.144  49.464  6
845866  102.970  -51.161  49.452  6
845867  102.984  -51.177  49.435  6
845868  102.998  -51.194  49.422  6
845869  103.013  -51.211  49.402  6
845870  103.027  -51.227  49.378  6
845871  103.041  -51.244  49.352  6
845872  103.065  -51.260  49.322  6
845873  103.092  -51.274  49.290  6
845874  103.118  -51.290  49.256  6
845875  103.145  -51.304  49.221  6
845876  103.172  -51.319  49.185  6
845877  103.199  -51.334  49.150  6
845878  103.226  -51.349  49.115  6
845879  103.252  -51.363  49.079  6
845880  103.279  -51.378  49.047  6
845881  103.306  -51.393  49.014  6
845882  103.333  -51.408  48.983  6
846546  102.473  -50.682  49.887  6
846547  102.498  -50.704  49.854  6
846548  102.522  -50.727  49.823  6
846549  102.547  -50.750  49.794  6
846550  102.572  -50.772  49.766  6
846551  102.596  -50.795  49.740  6
846552  102.621  -50.817  49.715  6
846553  102.646  -50.839  49.691  6
846554  102.670  -50.861  49.669  6
846555  102.695  -50.884  49.648  6
846556  102.720  -50.907  49.629  6
846557  102.744  -50.929  49.610  6
846558  102.769  -50.951  49.593  6
846559  102.794  -50.973  49.576  6
846560  102.818  -50.996  49.559  6
846561  102.843  -51.018  49.543  6
846562  102.868  -51.041  49.527  6
846563  102.892  -51.064  49.512  6
846564  102.916  -51.086  49.500  6
846565  102.941  -51.108  49.490  6
846566  102.966  -51.130  49.479  6
846567  102.983  -51.149  49.470  6
846568  102.998  -51.166  49.450  6
846569  103.012  -51.183  49.434  6
846570  103.026  -51.199  49.416  6
846571  103.040  -51.216  49.395  6
846572  103.054  -51.233  49.370  6
846573  103.075  -51.249  49.342  6
846574  103.101  -51.263  49.311  6
846575  103.128  -51.278  49.278  6
846576  103.155  -51.293  49.243  6
846577  103.182  -51.308  49.207  6
846578  103.209  -51.323  49.172  6
846579  103.235  -51.337  49.136  6
846580  103.262  -51.352  49.100  6
846581  103.289  -51.367  49.068  6
846582  103.316  -51.382  49.035  6
846583  103.342  -51.396  49.004  6
847247  102.472  -50.663  49.895  6
847248  102.497  -50.685  49.862  6
847249  102.522  -50.707  49.831  6
847250  102.546  -50.730  49.801  6
847251  102.571  -50.753  49.773  6
847252  102.596  -50.775  49.747  6
847253  102.620  -50.798  49.722  6
847254  102.644  -50.820  49.698  6
847255  102.669  -50.842  49.675  6
847256  102.694  -50.864  49.653  6
847257  102.719  -50.887  49.633  6
847258  102.743  -50.910  49.614  6
847259  102.768  -50.932  49.597  6
847260  102.793  -50.954  49.581  6
847261  102.817  -50.976  49.565  6
847262  102.842  -50.999  49.550  6
847263  102.867  -51.021  49.535  6
847264  102.891  -51.044  49.522  6
847265  102.916  -51.067  49.511  6
847266  102.941  -51.089  49.500  6
847267  102.965  -51.111  49.492  6
847268  102.990  -51.133  49.481  6
847269  103.011  -51.154  49.461  6
847270  103.025  -51.171  49.443  6
847271  103.039  -51.188  49.425  6
847272  103.053  -51.205  49.405  6
847273  103.068  -51.221  49.382  6
847274  103.085  -51.237  49.356  6
847275  103.111  -51.252  49.327  6
847276  103.138  -51.267  49.296  6
847277  103.165  -51.282  49.262  6
847278  103.191  -51.296  49.227  6
847279  103.218  -51.312  49.191  6
847280  103.245  -51.326  49.156  6
847281  103.272  -51.341  49.120  6
847282  103.299  -51.356  49.088  6
847283  103.325  -51.371  49.055  6
847284  103.352  -51.386  49.024  6
847949  102.496  -50.666  49.871  6
847950  102.521  -50.688  49.840  6
847951  102.545  -50.710  49.809  6
847952  102.570  -50.733  49.781  6
847953  102.595  -50.756  49.754  6
847954  102.619  -50.778  49.729  6
847955  102.644  -50.801  49.704  6
847956  102.669  -50.823  49.680  6
847957  102.693  -50.845  49.658  6
847958  102.718  -50.867  49.638  6
847959  102.743  -50.890  49.620  6
847960  102.767  -50.913  49.602  6
847961  102.792  -50.935  49.586  6
847962  102.816  -50.958  49.571  6
847963  102.841  -50.980  49.556  6
847964  102.866  -51.002  49.543  6
847965  102.890  -51.024  49.531  6
847966  102.915  -51.047  49.520  6
847967  102.940  -51.070  49.510  6
847968  102.964  -51.092  49.502  6
847969  102.989  -51.114  49.491  6
847970  103.014  -51.136  49.472  6
847971  103.038  -51.159  49.453  6
847972  103.052  -51.176  49.434  6
847973  103.067  -51.193  49.415  6
847974  103.081  -51.209  49.392  6
847975  103.095  -51.226  49.368  6
847976  103.121  -51.241  49.341  6
847977  103.148  -51.256  49.312  6
847978  103.175  -51.271  49.279  6
847979  103.201  -51.286  49.245  6
847980  103.228  -51.300  49.210  6
847981  103.255  -51.315  49.175  6
847982  103.281  -51.330  49.140  6
847983  103.308  -51.345  49.108  6
847984  103.335  -51.359  49.075  6
847985  103.362  -51.374  49.044  6
847986  103.389  -51.389  49.014  6
848650  102.495  -50.647  49.880  6
848651  102.520  -50.669  49.849  6
848652  102.544  -50.691  49.818  6
848653  102.569  -50.714  49.789  6
848654  102.594  -50.736  49.761  6
848655  102.618  -50.759  49.735  6
848656  102.643  -50.781  49.710  6
848657  102.668  -50.804  49.686  6
848658  102.692  -50.826  49.664  6
848659  102.717  -50.848  49.644  6
848660  102.742  -50.870  49.625  6
848661  102.766  -50.893  49.608  6
848662  102.791  -50.916  49.592  6
848663  102.816  -50.938  49.577  6
848664  102.840  -50.961  49.563  6
848665  102.865  -50.983  49.550  6
848666  102.889  -51.005  49.539  6
848667  102.914  -51.027  49.528  6
848668  102.939  -51.050  49.519  6
848669  102.963  -51.073  49.511  6
848670  102.988  -51.095  49.501  6
848671  103.013  -51.117  49.482  6
848672  103.037  -51.139  49.463  6
848673  103.062  -51.162  49.444  6
848674  103.080  -51.181  49.424  6
848675  103.094  -51.198  49.402  6
848676  103.109  -51.215  49.379  6
848677  103.131  -51.230  49.354  6
848678  103.158  -51.245  49.326  6
848679  103.184  -51.260  49.295  6
848680  103.211  -51.274  49.262  6
848681  103.238  -51.290  49.229  6
848682  103.265  -51.304  49.193  6
848683  103.292  -51.319  49.159  6
848684  103.318  -51.334  49.127  6
848685  103.345  -51.349  49.093  6
848686  103.372  -51.363  49.062  6
848687  103.399  -51.378  49.032  6
849352  102.519  -50.650  49.857  6
849353  102.544  -50.672  49.827  6
849354  102.569  -50.694  49.797  6
849355  102.593  -50.717  49.768  6
849356  102.617  -50.739  49.742  6
849357  102.642  -50.762  49.716  6
849358  102.667  -50.784  49.692  6
849359  102.691  -50.807  49.670  6
849360  102.716  -50.829  49.649  6
849361  102.741  -50.851  49.630  6
849362  102.765  -50.873  49.614  6
849363  102.790  -50.896  49.597  6
849364  102.815  -50.919  49.583  6
849365  102.839  -50.941  49.570  6
849366  102.864  -50.964  49.558  6
849367  102.889  -50.986  49.547  6
849368  102.913  -51.008  49.537  6
849369  102.938  -51.030  49.527  6
849370  102.963  -51.053  49.519  6
849371  102.987  -51.076  49.509  6
849372  103.012  -51.098  49.491  6
849373  103.036  -51.121  49.475  6
849374  103.061  -51.142  49.456  6
849375  103.086  -51.165  49.435  6
849376  103.108  -51.186  49.413  6
849377  103.122  -51.203  49.390  6
849378  103.141  -51.219  49.366  6
849379  103.167  -51.233  49.338  6
849380  103.194  -51.249  49.308  6
849381  103.221  -51.263  49.276  6
849382  103.248  -51.278  49.243  6
849383  103.275  -51.293  49.208  6
849384  103.301  -51.308  49.175  6
849385  103.328  -51.323  49.143  6
849386  103.355  -51.337  49.111  6
849387  103.380  -51.349  49.080  6
849388  103.406  -51.362  49.050  6
850054  102.543  -50.653  49.835  6
850055  102.568  -50.675  49.805  6
850056  102.592  -50.698  49.777  6
850057  102.617  -50.720  49.749  6
850058  102.641  -50.742  49.723  6
850059  102.666  -50.765  49.698  6
850060  102.691  -50.787  49.676  6
850061  102.716  -50.810  49.655  6
850062  102.740  -50.832  49.636  6
850063  102.764  -50.854  49.619  6
850064  102.789  -50.876  49.603  6
850065  102.814  -50.899  49.589  6
850066  102.838  -50.922  49.576  6
850067  102.863  -50.944  49.565  6
850068  102.888  -50.967  49.554  6
850069  102.912  -50.989  49.544  6
850070  102.937  -51.011  49.535  6
850071  102.962  -51.033  49.528  6
850072  102.986  -51.056  49.518  6
850073  103.011  -51.079  49.501  6
850074  103.036  -51.101  49.484  6
850075  103.061  -51.124  49.466  6
850076  103.085  -51.146  49.445  6
850077  103.110  -51.168  49.423  6
850078  103.134  -51.190  49.402  6
850079  103.151  -51.208  49.377  6
850080  103.177  -51.223  49.350  6
850081  103.204  -51.237  49.320  6
850082  103.231  -51.252  49.289  6
850083  103.257  -51.266  49.257  6
850084  103.283  -51.277  49.223  6
850085  103.308  -51.290  49.192  6
850086  103.333  -51.301  49.160  6
850087  103.359  -51.313  49.129  6
850088  103.384  -51.324  49.098  6
850089  103.409  -51.337  49.068  6
850756  102.567  -50.656  49.814  6
850757  102.591  -50.678  49.785  6
850758  102.616  -50.701  49.757  6
850759  102.641  -50.723  49.730  6
850760  102.665  -50.745  49.705  6
850761  102.690  -50.768  49.682  6
850762  102.715  -50.790  49.661  6
850763  102.739  -50.813  49.641  6
850764  102.764  -50.835  49.624  6
850765  102.789  -50.857  49.608  6
850766  102.813  -50.879  49.595  6
850767  102.838  -50.902  49.582  6
850768  102.862  -50.925  49.571  6
850769  102.887  -50.947  49.560  6
850770  102.911  -50.970  49.551  6
850771  102.936  -50.992  49.543  6
850772  102.961  -51.014  49.536  6
850773  102.985  -51.036  49.526  6
850774  103.010  -51.059  49.511  6
850775  103.035  -51.082  49.493  6
850776  103.059  -51.104  49.475  6
850777  103.084  -51.127  49.454  6
850778  103.109  -51.149  49.433  6
850779  103.134  -51.171  49.413  6
850780  103.158  -51.193  49.389  6
850781  103.184  -51.207  49.361  6
850782  103.210  -51.218  49.333  6
850783  103.235  -51.229  49.302  6
850784  103.260  -51.241  49.271  6
850785  103.286  -51.252  49.239  6
850786  103.311  -51.265  49.208  6
850787  103.336  -51.276  49.176  6
850788  103.362  -51.288  49.145  6
850789  103.387  -51.299  49.115  6
850790  103.412  -51.312  49.085  6
851458  102.591  -50.659  49.793  6
851459  102.615  -50.681  49.764  6
851460  102.640  -50.704  49.737  6
851461  102.664  -50.726  49.712  6
851462  102.689  -50.748  49.688  6
851463  102.714  -50.771  49.666  6
851464  102.738  -50.793  49.646  6
851465  102.763  -50.816  49.629  6
851466  102.787  -50.838  49.613  6
851467  102.812  -50.860  49.601  6
851468  102.837  -50.883  49.587  6
851469  102.862  -50.905  49.576  6
851470  102.886  -50.928  49.566  6
851471  102.911  -50.950  49.557  6
851472  102.936  -50.973  49.549  6
851473  102.960  -50.995  49.542  6
851474  102.984  -51.017  49.534  6
851475  103.009  -51.039  49.520  6
851476  103.034  -51.062  49.502  6
851477  103.058  -51.085  49.484  6
851478  103.083  -51.107  49.468  6
851479  103.108  -51.130  49.448  6
851480  103.132  -51.152  49.426  6
851481  103.158  -51.173  49.400  6
851482  103.185  -51.190  49.371  6
851483  103.211  -51.200  49.343  6
851484  103.237  -51.211  49.313  6
851485  103.262  -51.221  49.282  6
851486  103.288  -51.232  49.252  6
851487  103.313  -51.243  49.221  6
851488  103.339  -51.254  49.190  6
851489  103.365  -51.265  49.159  6
851490  103.390  -51.275  49.130  6
851491  103.416  -51.287  49.100  6
851492  103.441  -51.298  49.069  6
852161  102.639  -50.684  49.744  6
852162  102.664  -50.707  49.719  6
852163  102.688  -50.729  49.694  6
852164  102.713  -50.751  49.672  6
852165  102.737  -50.774  49.652  6
852166  102.762  -50.796  49.634  6
852167  102.787  -50.819  49.618  6
852168  102.811  -50.841  49.604  6
852169  102.836  -50.864  49.591  6
852170  102.861  -50.886  49.580  6
852171  102.885  -50.908  49.570  6
852172  102.910  -50.931  49.561  6
852173  102.935  -50.953  49.553  6
852174  102.959  -50.976  49.546  6
852175  102.984  -50.998  49.539  6
852176  103.009  -51.020  49.527  6
852177  103.033  -51.042  49.511  6
852178  103.058  -51.065  49.494  6
852179  103.083  -51.088  49.482  6
852180  103.107  -51.110  49.462  6
852181  103.132  -51.133  49.438  6
852182  103.159  -51.152  49.410  6
852183  103.186  -51.172  49.381  6
852184  103.212  -51.183  49.352  6
852185  103.238  -51.193  49.323  6
852186  103.263  -51.204  49.293  6
852187  103.289  -51.215  49.264  6
852188  103.315  -51.226  49.234  6
852189  103.340  -51.236  49.203  6
852190  103.366  -51.247  49.173  6
852191  103.392  -51.258  49.144  6
852192  103.418  -51.268  49.115  6
852193  103.443  -51.279  49.083  6
852865  102.712  -50.732  49.678  6
852866  102.737  -50.754  49.658  6
852867  102.761  -50.777  49.639  6
852868  102.786  -50.799  49.622  6
852869  102.811  -50.822  49.607  6
852870  102.835  -50.844  49.594  6
852871  102.860  -50.867  49.584  6
852872  102.884  -50.889  49.574  6
852873  102.909  -50.911  49.564  6
852874  102.934  -50.934  49.556  6
852875  102.958  -50.956  49.548  6
852876  102.983  -50.979  49.542  6
852877  103.008  -51.001  49.533  6
852878  103.032  -51.023  49.520  6
852879  103.057  -51.045  49.503  6
852880  103.082  -51.068  49.494  6
852881  103.106  -51.091  49.475  6
852882  103.132  -51.112  49.448  6
852883  103.160  -51.132  49.420  6
852884  103.187  -51.152  49.391  6
852885  103.213  -51.165  49.362  6
852886  103.239  -51.177  49.333  6
852887  103.264  -51.187  49.304  6
852888  103.290  -51.198  49.275  6
852889  103.316  -51.208  49.246  6
852890  103.341  -51.219  49.216  6
852891  103.367  -51.230  49.186  6
852892  103.393  -51.240  49.158  6
852893  103.418  -51.251  49.128  6
853566  102.711  -50.713  49.684  6
853567  102.736  -50.735  49.661  6
853568  102.760  -50.757  49.643  6
853569  102.785  -50.780  49.626  6
853570  102.810  -50.802  49.611  6
853571  102.834  -50.825  49.598  6
853572  102.859  -50.847  49.588  6
853573  102.884  -50.870  49.577  6
853574  102.908  -50.892  49.567  6
853575  102.933  -50.914  49.559  6
853576  102.958  -50.937  49.551  6
853577  102.982  -50.959  49.543  6
853578  103.007  -50.982  49.536  6
853579  103.031  -51.004  49.526  6
853580  103.056  -51.027  49.509  6
853581  103.081  -51.049  49.498  6
853582  103.105  -51.071  49.478  6
853583  103.132  -51.092  49.453  6
853584  103.160  -51.111  49.426  6
853585  103.187  -51.131  49.398  6
853586  103.215  -51.149  49.370  6
853587  103.240  -51.159  49.342  6
853588  103.266  -51.170  49.314  6
853589  103.292  -51.180  49.285  6
853590  103.317  -51.191  49.256  6
853591  103.343  -51.202  49.227  6
853592  103.369  -51.212  49.198  6
853593  103.394  -51.224  49.169  6
853594  103.420  -51.234  49.140  6
854268  102.735  -50.716  49.668  6
854269  102.759  -50.738  49.648  6
854270  102.784  -50.760  49.631  6
854271  102.809  -50.783  49.616  6
854272  102.833  -50.805  49.602  6
854273  102.858  -50.828  49.591  6
854274  102.883  -50.850  49.580  6
854275  102.907  -50.873  49.571  6
854276  102.932  -50.895  49.562  6
854277  102.957  -50.917  49.553  6
854278  102.981  -50.940  49.545  6
854279  103.006  -50.962  49.537  6
854280  103.031  -50.985  49.528  6
854281  103.055  -51.007  49.511  6
854282  103.080  -51.030  49.498  6
854283  103.106  -51.051  49.478  6
854284  103.133  -51.071  49.455  6
854285  103.161  -51.091  49.430  6
854286  103.188  -51.111  49.404  6
854287  103.216  -51.131  49.377  6
854288  103.241  -51.142  49.350  6
854289  103.267  -51.152  49.322  6
854290  103.293  -51.163  49.294  6
854291  103.318  -51.174  49.265  6
854292  103.344  -51.184  49.237  6
854293  103.370  -51.196  49.208  6
854294  103.395  -51.206  49.180  6
854295  103.421  -51.217  49.151  6
854969  102.734  -50.696  49.674  6
854970  102.759  -50.719  49.655  6
854971  102.784  -50.741  49.636  6
854972  102.808  -50.763  49.621  6
854973  102.832  -50.786  49.607  6
854974  102.857  -50.808  49.594  6
854975  102.882  -50.831  49.584  6
854976  102.906  -50.853  49.574  6
854977  102.931  -50.876  49.565  6
854978  102.956  -50.898  49.556  6
854979  102.980  -50.920  49.546  6
854980  103.005  -50.943  49.538  6
854981  103.030  -50.965  49.528  6
854982  103.054  -50.988  49.512  6
854983  103.079  -51.010  49.497  6
854984  103.106  -51.030  49.477  6
854985  103.134  -51.050  49.456  6
854986  103.161  -51.070  49.432  6
854987  103.188  -51.090  49.408  6
854988  103.216  -51.111  49.383  6
854989  103.243  -51.124  49.356  6
854990  103.268  -51.135  49.329  6
854991  103.294  -51.146  49.301  6
854992  103.319  -51.157  49.273  6
854993  103.345  -51.168  49.245  6
854994  103.371  -51.178  49.217  6
854995  103.396  -51.189  49.188  6
854996  103.422  -51.199  49.161  6
855671  102.758  -50.699  49.661  6
855672  102.783  -50.722  49.642  6
855673  102.807  -50.745  49.626  6
855674  102.832  -50.766  49.612  6
855675  102.857  -50.789  49.599  6
855676  102.881  -50.811  49.588  6
855677  102.906  -50.834  49.577  6
855678  102.930  -50.856  49.567  6
855679  102.955  -50.879  49.557  6
855680  102.979  -50.901  49.547  6
855681  103.004  -50.923  49.537  6
855682  103.029  -50.946  49.526  6
855683  103.053  -50.968  49.511  6
855684  103.079  -50.990  49.496  6
855685  103.107  -51.010  49.478  6
855686  103.134  -51.030  49.457  6
855687  103.162  -51.050  49.434  6
855688  103.189  -51.070  49.411  6
855689  103.217  -51.089  49.387  6
855690  103.244  -51.107  49.361  6
855691  103.269  -51.117  49.334  6
855692  103.295  -51.129  49.307  6
855693  103.321  -51.139  49.280  6
855694  103.347  -51.150  49.252  6
855695  103.372  -51.161  49.224  6
855696  103.398  -51.171  49.196  6
856372  102.757  -50.680  49.667  6
856373  102.781  -50.702  49.648  6
856374  102.806  -50.725  49.631  6
856375  102.831  -50.748  49.617  6
856376  102.856  -50.770  49.604  6
856377  102.880  -50.792  49.591  6
856378  102.905  -50.814  49.580  6
856379  102.930  -50.837  49.570  6
856380  102.954  -50.859  49.560  6
856381  102.979  -50.882  49.549  6
856382  103.004  -50.904  49.538  6
856383  103.028  -50.926  49.526  6
856384  103.053  -50.949  49.512  6
856385  103.080  -50.969  49.496  6
856386  103.107  -50.989  49.478  6
856387  103.135  -51.009  49.458  6
856388  103.162  -51.030  49.436  6
856389  103.190  -51.049  49.414  6
856390  103.217  -51.069  49.390  6
856391  103.245  -51.089  49.365  6
856392  103.270  -51.101  49.339  6
856393  103.296  -51.111  49.312  6
856394  103.322  -51.122  49.285  6
856395  103.348  -51.133  49.258  6
856396  103.373  -51.143  49.230  6
856397  103.399  -51.154  49.203  6
857074  102.781  -50.683  49.655  6
857075  102.806  -50.705  49.637  6
857076  102.830  -50.728  49.622  6
857077  102.855  -50.751  49.608  6
857078  102.879  -50.773  49.595  6
857079  102.904  -50.795  49.584  6
857080  102.929  -50.817  49.573  6
857081  102.953  -50.840  49.562  6
857082  102.978  -50.862  49.551  6
857083  103.003  -50.885  49.539  6
857084  103.027  -50.907  49.526  6
857085  103.053  -50.929  49.513  6
857086  103.080  -50.948  49.497  6
857087  103.108  -50.969  49.479  6
857088  103.135  -50.989  49.459  6
857089  103.163  -51.008  49.439  6
857090  103.190  -51.029  49.416  6
857091  103.218  -51.049  49.393  6
857092  103.245  -51.069  49.369  6
857093  103.272  -51.083  49.343  6
857094  103.298  -51.094  49.317  6
857095  103.323  -51.105  49.289  6
857096  103.349  -51.115  49.262  6
857097  103.375  -51.126  49.236  6
857098  103.400  -51.137  49.210  6
857775  102.780  -50.663  49.662  6
857776  102.805  -50.686  49.643  6
857777  102.829  -50.708  49.627  6
857778  102.854  -50.731  49.613  6
857779  102.879  -50.754  49.601  6
857780  102.903  -50.776  49.589  6
857781  102.928  -50.798  49.577  6
857782  102.952  -50.820  49.565  6
857783  102.977  -50.843  49.553  6
857784  103.001  -50.865  49.542  6
857785  103.026  -50.888  49.529  6
857786  103.053  -50.908  49.514  6
857787  103.081  -50.928  49.497  6
857788  103.108  -50.948  49.480  6
857789  103.135  -50.968  49.461  6
857790  103.163  -50.988  49.441  6
857791  103.191  -51.008  49.418  6
857792  103.218  -51.028  49.395  6
857793  103.246  -51.048  49.370  6
857794  103.273  -51.066  49.345  6
857795  103.299  -51.077  49.319  6
857796  103.324  -51.087  49.292  6
857797  103.350  -51.098  49.266  6
857798  103.376  -51.109  49.240  6
858477  102.804  -50.666  49.651  6
858478  102.828  -50.689  49.634  6
858479  102.853  -50.711  49.620  6
858480  102.878  -50.734  49.607  6
858481  102.902  -50.757  49.594  6
858482  102.927  -50.779  49.582  6
858483  102.952  -50.801  49.570  6
858484  102.976  -50.823  49.558  6
858485  103.001  -50.846  49.545  6
858486  103.026  -50.867  49.532  6
858487  103.054  -50.888  49.517  6
858488  103.081  -50.907  49.500  6
858489  103.109  -50.927  49.482  6
858490  103.136  -50.948  49.464  6
858491  103.164  -50.967  49.442  6
858492  103.191  -50.988  49.420  6
858493  103.219  -51.008  49.397  6
858494  103.246  -51.027  49.372  6
858495  103.274  -51.048  49.347  6
858496  103.300  -51.059  49.322  6
858497  103.325  -51.070  49.296  6
858498  103.351  -51.081  49.270  6
859179  102.827  -50.669  49.642  6
859180  102.852  -50.692  49.627  6
859181  102.877  -50.714  49.613  6
859182  102.901  -50.737  49.600  6
859183  102.926  -50.760  49.587  6
859184  102.951  -50.782  49.575  6
859185  102.975  -50.804  49.563  6
859186  103.000  -50.826  49.549  6
859187  103.027  -50.847  49.536  6
859188  103.054  -50.867  49.520  6
859189  103.082  -50.887  49.504  6
859190  103.109  -50.907  49.485  6
859191  103.137  -50.927  49.467  6
859192  103.164  -50.947  49.444  6
859193  103.192  -50.967  49.423  6
859194  103.219  -50.987  49.399  6
859195  103.247  -51.007  49.375  6
859196  103.275  -51.027  49.351  6
859197  103.301  -51.042  49.326  6
859880  102.827  -50.650  49.650  6
859881  102.852  -50.672  49.634  6
859882  102.876  -50.695  49.620  6
859883  102.901  -50.717  49.606  6
859884  102.926  -50.740  49.593  6
859885  102.950  -50.763  49.581  6
859886  102.974  -50.785  49.568  6
859887  103.000  -50.807  49.554  6
859888  103.028  -50.826  49.540  6
859889  103.055  -50.846  49.524  6
859890  103.082  -50.867  49.508  6
859891  103.110  -50.886  49.490  6
859892  103.137  -50.907  49.470  6
859893  103.165  -50.926  49.449  6
859894  103.192  -50.946  49.427  6
859895  103.220  -50.967  49.404  6
859896  103.247  -50.986  49.379  6
859897  103.275  -51.007  49.355  6
860582  102.851  -50.654  49.643  6
860583  102.875  -50.676  49.628  6
860584  102.900  -50.698  49.613  6
860585  102.924  -50.720  49.600  6
860586  102.949  -50.743  49.587  6
860587  102.974  -50.766  49.574  6
860588  103.001  -50.786  49.560  6
860589  103.028  -50.806  49.546  6
860590  103.055  -50.826  49.530  6
860591  103.083  -50.846  49.512  6
860592  103.110  -50.866  49.495  6
860593  103.138  -50.886  49.475  6
860594  103.165  -50.906  49.454  6
860595  103.193  -50.926  49.432  6
860596  103.221  -50.946  49.408  6
860597  103.248  -50.966  49.384  6
861284  102.874  -50.657  49.635  6
861285  102.899  -50.679  49.620  6
861286  102.924  -50.701  49.607  6
861287  102.948  -50.723  49.594  6
861288  102.974  -50.745  49.580  6
861289  103.001  -50.765  49.566  6
861290  103.029  -50.785  49.552  6
861291  103.056  -50.805  49.536  6
861292  103.083  -50.826  49.518  6
